/********************************************************************
# (C) Copyright IBM Corp.  2005-2006
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#********************************************************************/
/**
 * Copyright 2000 Systemcorp - All rights reserved. Made in Canada.
 *
 * Description:
 *
 * Author: Tudor Toma
 * Revision: 42
 * Date: 7/31/00 6:18p
 *
 **/
/*
#Stored Procedure  :SP_SEARCH_2
#Short Description :Search and Assign a resource or profile to a element.
#Description       :Search or Search and Assign a resource or profile with effort to a WBS or CRI element.
				   :If search/assign a participant (without effort) all effort related parameters are not required.
				   :Search criteria is a sum of input parameters, witch tells how to filter out the result set.
				   :This function gets called from RPM client, Import and Level/Calculate.
RULE1: cannot assign more then once a resource to a element.
RULE2: cannot assign a resource to a project if the resource is already assigned to a task whitin the project.
RULE3: cannot assign to a task from project reserve more effort then remaining effort at the project.
RULE4: if bitflag = 9 then assignment without effort, otherwise assignment with effort.
RULE5: if bitflag between 1 and 8 the assignment is contoured: contour > 0 and work > 0
RULE6: if search by name then partially ignore the search criteria: org_id, geo_id, pool_id, work_loc, and_roles, and_skills, shw_roles, shw_skills
RULE7: if effort = 0 and bitflag < 9 then both start  finish dates are required
RULE8: if assign units <> 100%, then bitflag < 9 and effort > 0 and both start  finish dates are required
RULE9: cannot assign a resource if is not active, effective date is in the future or discontinue date is in the past
#Table Name        :
#Parameters        :
 $$bitflag  = 0 - ASP ---------------------------------------------------------------------------------------------
            = 1 - Daily         -- contour3
            = 2 - Weekly        -- contour3{, contur1}, {amount falg}
            = 3 - Monthly(C)    -- contour3{, contur2}
            = 4 - Monthly(B)    -- contour3{, contur2}
            = 5 - Monthly(A)    -- contour3{, contur2 | contour2  countour1}
            = 6 - Yearly(C)     -- contour2, contur4
            = 7 - Yearly(B)     -- contour2, contur4, contur1(only one day)
            = 8 - Yearly(A)     -- contour2, contur4, contur1(many days)
            = 9 - Participant
 $$contour (contour structure) ------------------------------------------------------------------------------------
  contur1:  DAY:    bits 0-6    0 = Su, 1 = Mo, 2 = Tu, 3 = We, 4 = Th, 5 = Fr, 6 = Sa,
  contur2:  WEEK:   bits 7-11   A) 7 = week1, 8 = week2, 8 = week3, 9 = week4
                                B) 1-First/2-Second/3-Third/4-Fourth/5-Last
                                C) The Day 1 to 31
  contour3:     EVRY:   bits 12-16  EVRY 1 to 31 day / week / month
  contour4:     MONTH:  bits 17-28  17 = Jan, 18 = Feb, ... 28 = Dec
  2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
  8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
                                                S F T W T M S
                                      w1 to w4  A(7 days from the 1st)
                                      5 4 3 2 1 B(Last, Fourth, Third, Second, First)
                                      31 .... 1 C(The Day 6)
                            31 ........ 1 (Day)
                            31 ........ 1 (week)
                            12 ........ 1 (month)
  D N O S A J J M A M F J (Month)
  Exemple:
  2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1 
  9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 
                                      5-4-3-2-1               B) 1-First/2-Second/3-Third/4-Fourth/5-Last
  X D N O S A J J M A M F J --EVERY-- -THE-DAY- S F T W T M S C) The Day 1 to 31
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 = 4096      1 (every day) 	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 8192      1 (every 2nd day) 
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 12288     1 (every 3rd day) 
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 536875014 2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 4102      2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 1 0 = 8198      2 (Monday, Monday, every 2nd week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 4864      3 (6th day of every month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 = 8322      4 (1st Monday of every 2nd month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 = 4224      5 (week1 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 = 4480      5 (week1, week2 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 1 0 0 0 0 0 0 0 = 8576      5 (week1, week2 of every 2nd month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 8454      5 (Monday, Tuesday, week2 every 2nd month)	
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 536879366 5 (Monday, Tuesday, week2 every 2nd month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 301990656 6 (6th day of month 9, 12)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 = 301990146 7 (1st Monday of month 1, 2)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 = 4356      7 (2nd Tuesday, every month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 301990534 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
  1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 838861446 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
 $$consider_planned_sched ------------------------------------------------------------------------------------------
  CONSIDER                                              inner current project   outer current project   all projects
  scheduled                                                         1                   2                   3
  scheduled  planned                                               4                   5                   6
  NONE(consider all available time)                                 7
  scheduled outer current project				                                        13                  14
  scheduled  planned outer current project				                                15                  16
  scheduled outer current project  planned all projects            20
  scheduled outer current project  planned inner current project   21
  scheduled all projects    planned outer current project          22
  planned inner current project                                     24
  search from project assignments		= 10  pool_id   = resource_id
  search create new profile				= 12  and_roles = the first role_id is used to create a new profile
  duplicate profile						= 12  pool_id   = profile_id
  assign pool  org as participant to a template folder, all template views
  assign pool	= SC_SRCH_POOL (31)  pool_id	= pool_id
  assign org	= SC_SRCH_ORG  (32)  org_id	= org_id
  Note: bits 30 - 31 (in addition to above values): Consider All Scop Element Exceptions = 1 consider, 0 don't consider
  $$eunit, applies to effort
		= 0 MINUTE (default), 
		= 1 h, 
		= 2 d, 
		= 3 w
  $$unit, applies to work
		= 0 h/d,
		= 3 h/w, 
		= 4 h/m, 
		= 1 d/w, 
		= 2 d/m, 
		= 5 w/m
		= 100 then work = percent units
#Returns           :Result Set of resource(s), Best Start date, Best Finish date and daly contour (5*480,2*0,3*400,...) 
				   :For search the number of rows depends on search criteria and is limited by max_rows parameter.
				   :For search/assign is always only one row, the resource whith has been assigned
#Errors            :The errors are returned only in search/assign
				   : TASK_ASSIGNMENT_ERROR (200062) - many reasons the assignment failed.
				   : CHILD_TASK_ASSIGNMENT_ALREADY_EXISTS (20083) - violation of RULE2
				   : CANNOT_ASSIGN_FROM_PROJECT_AFFECTED (20085) - violation of RULE3
				   : RESOURCE_NOT_ACTIVE (200019) - violation of RULE9
				   : F_DATE_EARLIER_THAN_S_DATE - finish date is earlier then start date
				   : 200220 - violation of RULE7
*/
Prompt == FUNCTION SP_SEARCH_2 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2f8
2 :e:
1FUNCTION:
1SP_SEARCH_2:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1FNAME:
1COST001:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1WORK_LOCATION001:
1AND_ROLES:
1AND_SKILLS:
1SHW_ROLES:
1SHW_SKILLS:
1MAX_ROWS:
1P_UPDATE:
1WORK_TYPE:
1P_TYPE:
1LAST_ID:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_WBS_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RS_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_FNAME:
1255:
1H_COST:
110:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_SHW_ROLES:
1H_SHW_SKILLS:
1H_AND_ROLE:
1H_AND_SKILL:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SOURCE_IDS:
1H_TARGET_IDS:
1H_RES_ID:
1H_LAST_ID:
1H_RANK:
1200:
1H_DAYOFYEAR:
1DATE:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_START_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_ROLE_ID:
1H_SKILL_ID:
1H_FULL_NAME:
1H_REC_STATUS:
1H_BITFLAG:
10:
1H_EXISTS:
1H_TYPE:
1H_COUNT:
1H_UPDATE:
1H_WORK_TYPE:
1H_WORK_LOCATION:
1H_CRI:
1H_MAX_ROWS:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_DURATION:
1H_BIT_MINUTES:
1H_NUMBER:
1H_PRIORITY:
1H_DAYS:
1H_RES_COST:
1NUMBER:
10.00:
1H_RATE_ECHANGE:
1H_TOTAL:
1H_POOL_TYPE:
1H_CURRENCY_ID:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_TASK_TYPE:
1H_SCHED_WORK:
1H_PARTICIPANT:
1STMT:
17999:
1STWHERE:
12999:
1H_TEMP_STMT:
1H_TABLE_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_PROFILE_ID:
1H_RESOURCE_ID:
1H_CRI_SECURITY_ID:
1H_CHAR:
1H_TEMP_VAR:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1I:
1II:
1I_ROW:
1I_RETURN:
1ISF:
1TOKEN:
1I_NOSKILL:
1NUMITEMS:
1BCREATEPROFILE:
1LEN:
1K:
1NLEN:
1NLEN001:
1NLEN002:
1C12:
1CURSOR:
1C42:
1PROJECT_ASSIGNMENT_ID:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1SELECT PROJECT_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id:n         AND TASK_ID = h_project_id:n         AND +
1RESOURCE_ID = h_res_id:
1CU42:
1RS_ID:
1RES_ID:
1RTRIM:
1ROLE_ID:
1COALESCE:
1ROLE_NAME:
1SKILL_ID:
1SKILL_NAME:
1SHOW_ROLE:
1SHOW_SKILL:
1PMO_TMP_SEARCH:
1SELECT:n         RS_ID:n         , RES_ID:n         , RTRIM(ROLE_ID):n       +
1  , COALESCE(ROLE_NAME , ''):n         , RTRIM(SKILL_ID):n         , COALESCE+
1(SKILL_NAME , ''):n         , COALESCE(SHOW_ROLE , ''):n         , COALESCE(S+
1HOW_SKILL , ''):n         FROM PMO_TMP_SEARCH:n         ORDER BY RES_ID:
1C775C0:
1C775E1:
1C775E0:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_2(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1197:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_2(198) :: cplan.sql(355) :: :
1PMO_CNST:
1!=:
1SC_SRCH_PARTICIPANT:
1IS NULL:
18:
1240:
1      RETURN_INVALID:: SP_SEARCH_2(241) :: cplan.sql(398) :: :
1 :
1STATE:: :
1ELEMENT_ID_REQUIRED:
1243:
1                EXIT:: SP_SEARCH_2(244) :: cplan.sql(401) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_SRCH_FROM_PROJECT:
1=:
1SC_SRCH_PROFILE:
1252:
1      RETURN_INVALID:: SP_SEARCH_2(253) :: cplan.sql(410) :: :
1INVALID_PARAMS:
1                EXIT:: SP_SEARCH_2(256) :: cplan.sql(413) :: :
1ELSIF:
1260:
1      RETURN_INVALID:: SP_SEARCH_2(261) :: cplan.sql(418) :: :
1263:
1                EXIT:: SP_SEARCH_2(264) :: cplan.sql(421) :: :
15:
1271:
1      RETURN_INVALID:: SP_SEARCH_2(272) :: cplan.sql(429) :: :
1274:
1                EXIT:: SP_SEARCH_2(275) :: cplan.sql(432) :: :
1265:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1300:
1           EXCEPTION:: SP_SEARCH_2(301) :: cplan.sql(458) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1307:
1      RETURN_INVALID:: SP_SEARCH_2(308) :: cplan.sql(465) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1310:
1                EXIT:: SP_SEARCH_2(311) :: cplan.sql(468) :: :
1SELECT SYSTIMESTAMP INTO h_start_date FROM DUAL:
1328:
1           EXCEPTION:: SP_SEARCH_2(329) :: cplan.sql(486) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1SC_SRCH_POOL:
12:
1SC_SRCH_ORG:
13:
1>:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1372:
1           EXCEPTION:: SP_SEARCH_2(373) :: cplan.sql(530) :: :
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1390:
1           EXCEPTION:: SP_SEARCH_2(391) :: cplan.sql(548) :: :
1STRCMP:
1L:
1397:
1        RETURN_ERROR:: SP_SEARCH_2(398) :: cplan.sql(555) :: :
1LEV_LOCKED_BY_COPY:
1 ID:: :
1400:
1                EXIT:: SP_SEARCH_2(401) :: cplan.sql(558) :: :
1PMO_RETURN_ERROR_SP:
1GETTABLE:
1GETASSNTYPE:
1411:
1      RETURN_INVALID:: SP_SEARCH_2(412) :: cplan.sql(569) :: :
1414:
1                EXIT:: SP_SEARCH_2(415) :: cplan.sql(572) :: :
1SC_TABLE_WBS:
1427:
1      RETURN_INVALID:: SP_SEARCH_2(428) :: cplan.sql(585) :: :
1430:
1                EXIT:: SP_SEARCH_2(431) :: cplan.sql(588) :: :
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
1449:
1        RETURN_ERROR:: SP_SEARCH_2(450) :: cplan.sql(607) :: :
1452:
1                EXIT:: SP_SEARCH_2(453) :: cplan.sql(610) :: :
1459:
1        RETURN_ERROR:: SP_SEARCH_2(460) :: cplan.sql(617) :: :
1462:
1                EXIT:: SP_SEARCH_2(463) :: cplan.sql(620) :: :
1ISPROJECTTYPE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1SELECT:n               PROJECT_ID:n               , COALESCE(MINUTE_PER_DAY, +
1480):n               , COALESCE(MINUTE_PER_WEEK, 2400):n               , PRIO+
1RITY:n               INTO:n               h_project_id:n               , h_pe+
1r_day:n               , h_per_week:n               , h_priority:n            +
1   FROM TMT_WBS:n               WHERE ELEMENT_ID = h_task_id:
1489:
1           EXCEPTION:: SP_SEARCH_2(490) :: cplan.sql(647) :: :
1B:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1SELECT:n               B.TASK_TYPE:n               , B.UNRESOLVED_START:n    +
1           , B.UNRESOLVED_FINISH:n               , B.PROJECT_ID:n            +
1   , COALESCE(A.MINUTE_PER_DAY, 480):n               , COALESCE(A.MINUTE_PER_+
1WEEK, 2400):n               , A.PRIORITY:n               , B.PLANNED_EFFORT ++
1 B.SCHED_EFFORT:n               INTO:n               h_task_type:n           +
1    , h_task_start_DT:n               , h_task_finish_DT:n               , h_+
1project_id:n               , h_per_day:n               , h_per_week:n        +
1       , h_priority:n               , h_sched_work:n               FROM TMT_W+
1BS A, TMT_WBS B:n               WHERE B.ELEMENT_ID = h_task_id:n             +
1  AND A.ELEMENT_ID = B.PROJECT_ID:
1524:
1           EXCEPTION:: SP_SEARCH_2(525) :: cplan.sql(682) :: :
1532:
1        RETURN_ERROR:: SP_SEARCH_2(533) :: cplan.sql(690) :: :
1RECORD_NOT_FOUND:
1535:
1                EXIT:: SP_SEARCH_2(536) :: cplan.sql(693) :: :
1SC_TABLE_CRI:
1TYPE_ID:
1WBS_ID:
1TMT_CRI:
1SELECT:n            PROJECT_ID:n            , TYPE_ID:n            , WBS_ID:n+
1            INTO:n            h_project_id:n            , h_type:n           +
1 , h_wbs_id:n            FROM TMT_CRI:n            WHERE ELEMENT_ID = h_task_+
1id:
1559:
1           EXCEPTION:: SP_SEARCH_2(560) :: cplan.sql(717) :: :
1566:
1        RETURN_ERROR:: SP_SEARCH_2(567) :: cplan.sql(724) :: :
1569:
1                EXIT:: SP_SEARCH_2(570) :: cplan.sql(727) :: :
1START_DT:
1TO_TIMESTAMP:
1SELECT:n            CASE:n            WHEN START_DT > h_start_DT:n           +
1 THEN START_DT:n            ELSE TO_TIMESTAMP(h_start_DT):n            END:n +
1           , COALESCE(MINUTE_PER_DAY, 480):n            , COALESCE(MINUTE_PER+
1_WEEK, 2400):n            , PRIORITY:n            INTO:n            h_start_D+
1T:n            , h_per_day:n            , h_per_week:n            , h_priorit+
1y:n            FROM TMT_WBS:n            WHERE PROJECT_ID = h_project_id:n   +
1         AND ELEMENT_ID = h_project_id:
1602:
1           EXCEPTION:: SP_SEARCH_2(603) :: cplan.sql(760) :: :
1609:
1        RETURN_ERROR:: SP_SEARCH_2(610) :: cplan.sql(767) :: :
1612:
1                EXIT:: SP_SEARCH_2(613) :: cplan.sql(770) :: :
1FC_MIRROR_TYPE:
1627:
1        RETURN_ERROR:: SP_SEARCH_2(628) :: cplan.sql(785) :: :
1630:
1                EXIT:: SP_SEARCH_2(631) :: cplan.sql(788) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT:n            NICK_NAME:n            , PMO_ORASTD.JULIAN_DAY(h_start_DT+
1):n            , ACTIVE:n            , EFFECTIVE_DATE:n            , COALESCE+
1(PMO_ORASTD.JULIAN_DAY(EFFECTIVE_DATE) ,0):n            , COALESCE(PMO_ORASTD+
1.JULIAN_DAY(DISCONTINUE_DATE) ,0):n            INTO:n            h_full_name+
1:n            , h_julian_day:n            , h_active:n            , h_start_D+
1:n            , h_j_efective_date:n            , h_j_disconti_date:n         +
1   FROM RESOURCES:n            WHERE RESOURCE_ID = h_res_id:
1663:
1           EXCEPTION:: SP_SEARCH_2(664) :: cplan.sql(821) :: :
1SC_SQL_NO_DATA:
1670:
1        RETURN_ERROR:: SP_SEARCH_2(671) :: cplan.sql(828) :: :
1673:
1                EXIT:: SP_SEARCH_2(674) :: cplan.sql(831) :: :
1680:
1        RETURN_ERROR:: SP_SEARCH_2(681) :: cplan.sql(838) :: :
1RESOURCE_NOT_ACTIVE:
1683:
1                EXIT:: SP_SEARCH_2(684) :: cplan.sql(841) :: :
1DB2TIMESTAMP:
1TO_DATE:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_D, 1, 10)), PMO_ORASTD.+
1TIME('00.00.00')) INTO h_start_DT:n                  FROM DUAL:
1701:
1           EXCEPTION:: SP_SEARCH_2(702) :: cplan.sql(859) :: :
1721:
1        RETURN_ERROR:: SP_SEARCH_2(722) :: cplan.sql(879) :: :
1CANNOT_ASSIGN_COMPETENCY:
1724:
1                EXIT:: SP_SEARCH_2(725) :: cplan.sql(882) :: :
1SELECT:n            PRIORITY:n            , COALESCE(MINUTE_PER_DAY, 480):n  +
1          , COALESCE(MINUTE_PER_WEEK, 2400):n            INTO:n            h_+
1priority:n            , h_per_day:n            , h_per_week:n            FROM+
1 TMT_WBS:n            WHERE ELEMENT_ID = h_project_id:
1751:
1           EXCEPTION:: SP_SEARCH_2(752) :: cplan.sql(909) :: :
1TMT_POOLS:
1SELECT:n               480:n               , 2400:n               INTO:n     +
1          h_per_day:n               , h_per_week:n               FROM TMT_POO+
1LS WHERE ELEMENT_ID = h_project_id:
1775:
1           EXCEPTION:: SP_SEARCH_2(776) :: cplan.sql(933) :: :
1782:
1        RETURN_ERROR:: SP_SEARCH_2(783) :: cplan.sql(940) :: :
1785:
1                EXIT:: SP_SEARCH_2(786) :: cplan.sql(943) :: :
1100:
11899-12-31 00::00::00:
1:
1FC_CALC_DURATION:
1822:
1      RETURN_INVALID:: SP_SEARCH_2(823) :: cplan.sql(980) :: :
1825:
1                EXIT:: SP_SEARCH_2(826) :: cplan.sql(983) :: :
1830:
1        RETURN_ERROR:: SP_SEARCH_2(831) :: cplan.sql(988) :: :
1833:
1                EXIT:: SP_SEARCH_2(834) :: cplan.sql(991) :: :
1*:
14:
1SYS_GUID:
1PROFILES:
1PROFILE_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM PROFILES:n            W+
1HERE PROFILE_ID = h_res_id:
1894:
1           EXCEPTION:: SP_SEARCH_2(895) :: cplan.sql(1052) :: :
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_TYPE:
1PARTICIPANT:
1SC_TEAMMEMBER:
1SELECT:n                  RES_ASSIGNMENT_ID:n                  INTO:n        +
1          h_uniqueID:n                  FROM RESOURCE_ASSIGNMENTS:n          +
1        WHERE ELEMENT_ID = h_task_id:n                  AND RESOURCE_ID = h_r+
1es_id:n                  AND RESOURCE_TYPE = '1':n                  AND PARTI+
1CIPANT = pmo_cnst.SC_TEAMMEMBER:
1919:
1           EXCEPTION:: SP_SEARCH_2(920) :: cplan.sql(1077) :: :
1MAX:
1PROF_NUMBER:
1SELECT:n            COALESCE(MAX(PROF_NUMBER),0)+1:n            INTO:n       +
1     h_number:n            FROM PROFILES:n            WHERE PROJECT_ID=h_proj+
1ect_id:n            AND ROLE_ID=h_role_id:
1951:
1           EXCEPTION:: SP_SEARCH_2(952) :: cplan.sql(1109) :: :
1STRINGCONCAT:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT:n            PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORAST+
1D.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEM+
1ENT_NAME):n            , ', '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(+
1h_number))), ')'):n            INTO h_full_name:n            FROM TMT_COMPETE+
1NCIES TC, TMT_COMPETENCIES TCP:n            WHERE TC.ELEMENT_ID = h_role_id:n+
1            AND TCP.ELEMENT_ID = TC.PARENT_ID:
1972:
1           EXCEPTION:: SP_SEARCH_2(973) :: cplan.sql(1130) :: :
1979:
1        RETURN_ERROR:: SP_SEARCH_2(980) :: cplan.sql(1137) :: :
1982:
1                EXIT:: SP_SEARCH_2(983) :: cplan.sql(1140) :: :
1U:
1D:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES:n            (:n            PROFILE_ID:n            , PR+
1OJECT_ID:n            , ROLE_ID:n            , PROF_NUMBER:n            , PRO+
1FILE_NAME:n            , REC_STATUS:n            , POOL_ID:n            , GEO+
1_ID:n            , ORG_ID:n            ):n            VALUES:n            (:n+
1            h_res_id:n            , h_project_id:n            , h_role_id:n  +
1          , h_number:n            , h_full_name:n            , h_char:n      +
1      , pool_id001:n            , geo_id001:n            , org_id001:n       +
1     ):
1FOUND:
11030:
1           EXCEPTION:: SP_SEARCH_2(1031) :: cplan.sql(1188) :: :
1UPDATE PROFILES SET REC_STATUS = 'U',:n            POOL_ID = pool_id001,:n   +
1         GEO_ID  = geo_id001,:n            ORG_ID  = org_id001:n            W+
1HERE PROFILE_ID = h_res_id:
11055:
1           EXCEPTION:: SP_SEARCH_2(1056) :: cplan.sql(1213) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS:n         WHERE RES_ASSIGNMENT_ID IN (:n  +
1       SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID =+
1 h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_+
1id):
11083:
1           EXCEPTION:: SP_SEARCH_2(1084) :: cplan.sql(1241) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES:n         WHERE RES_ASSIGNMENT_ID IN (:n   +
1      SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID = +
1h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_i+
1d):
11108:
1           EXCEPTION:: SP_SEARCH_2(1109) :: cplan.sql(1266) :: :
1DELETE FROM PROFILES:n         WHERE PROJECT_ID = h_project_id:n         AND +
1REC_STATUS='D':n         AND PROFILE_ID <> h_res_id:
11130:
1           EXCEPTION:: SP_SEARCH_2(1131) :: cplan.sql(1288) :: :
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_MAX_ROWS:
1SELECT ':
1' AS RESOURCE_ID :
1FROM TMT_COMPETENCIES r :
1WHERE r.TYPE_ID=73 :
1      AND r.ELEMENT_ID = ':
1SELECT ra.RESOURCE_ID :
1FROM RESOURCE_ASSIGNMENTS ra :
1JOIN TASK_ASSIGNMENTS ta ON ra.ELEMENT_ID=':
1' :
1AND ra.RESOURCE_ID=':
1AND ra.RES_ASSIGNMENT_ID=ta.RES_ASSIGNMENT_ID :
1SELECT r.RESOURCE_ID :
1FROM RESOURCES r :
1WHERE r.CALENDAR_ID IS NOT NuLL :
1        AND r.RESOURCE_ID = ':
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0007:
1DELETE FROM PMO_TMP_CPLN_007a:
1PMO_TMP_CPLN_007A:
1RANK:
1PUBLIC_FLAG:
1P:
1JOIN:
1RA:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN_007a:n               SELECT ELEMENT_ID, RANK:n      +
1         FROM TMT_POOLS:n               WHERE PUBLIC_FLAG = '1':n            +
1   UNION ALL:n               ---- All pools to which the resource is assigned+
1:n               SELECT P.ELEMENT_ID, P.RANK:n               FROM TMT_POOLS P+
1:n               JOIN RESOURCE_ASSIGNMENTS RA ON:n               P.ELEMENT_ID+
1 = RA.ELEMENT_ID:n               AND RA.ELEMENT_TYPE = 11:n               AND+
1 RA.RESOURCE_ID = h_rec_user:
11257:
1           EXCEPTION:: SP_SEARCH_2(1258) :: cplan.sql(1415) :: :
1PMO_TMP_CPLN_0007:
1M:
1LENGTH:
1INSERT INTO PMO_TMP_CPLN_0007:n               SELECT M.RANK:n               F+
1ROM PMO_TMP_CPLN_007a M:n               WHERE NOT EXISTS (:n               SE+
1LECT A.ELEMENT_ID:n               FROM PMO_TMP_CPLN_007a A:n               WH+
1ERE A.RANK < M.RANK:n               AND SUBSTR(M.RANK, 1, LENGTH(A.RANK)) = A+
1.RANK):
11285:
1           EXCEPTION:: SP_SEARCH_2(1286) :: cplan.sql(1443) :: :
132767:
165535:
1-:
165536:
1WHILE:
1LOOP:
1ASCII:
137:
195:
1EXIT:
11312:
1      RETURN_INVALID:: SP_SEARCH_2(1313) :: cplan.sql(1470) :: :
11315:
1                EXIT:: SP_SEARCH_2(1316) :: cplan.sql(1473) :: :
1REPLACE:
1SELECT REPLACE(h_fname,'''',''''''):n            INTO h_fname:n            FR+
1OM DUAL:
11332:
1           EXCEPTION:: SP_SEARCH_2(1333) :: cplan.sql(1490) :: :
1SELECT p.PROFILE_ID AS RESOURCE_ID FROM PROFILES p JOIN TMT_COMPETENCIES r ON+
1 p.ROLE_ID = r.ELEMENT_ID:
1 WHERE p.PROFILE_ID=':
1SELECT r.RESOURCE_ID FROM RESOURCES r JOIN RESOURCE_ASSIGNMENTS ra ON BITAND(+
1ra.PARTICIPANT,4096)>0 AND ra.ELEMENT_ID=':
1' AND ra.RESOURCE_ID=r.RESOURCE_ID:
1 WHERE 0=0 :
1SELECT DISTINCT r.RESOURCE_ID FROM RESOURCES r:
1 AND r.RESOURCE_ID > ':
1 AND r.CALENDAR_ID IS NOT NuLL :
1AND UPPER(r.FULL_NAME) like UPPER(':
1%'):
1SELECT r.RESOURCE_ID FROM RESOURCES r:
1SELECT DISTINCT r.RESOURCE_ID :
1FROM TMT_POOLS TP, PMO_TMP_CPLN_0007 MP, RESOURCES r:
1AND TP.ELEMENT_ID=R.RESOURCE_ID :
1  AND (MP.RANK >= SUBSTR(TP.RANK, 1, 8) :
1        AND MP.RANK <= TP.RANK :
1        AND length(MP.RANK) <= length(TP.RANK) :
1        AND substr(TP.RANK, 1, length(MP.RANK)) = MP.RANK) :
1  AND r.CALENDAR_ID IS NOT NuLL :
1  AND UPPER(r.FULL_NAME) LIKE UPPER(':
1SELECT RANK INTO h_rank:n               FROM TMT_POOLS:n               WHERE +
1ELEMENT_ID = pool_id001:
11417:
1           EXCEPTION:: SP_SEARCH_2(1418) :: cplan.sql(1575) :: :
1,TMT_POOLS p:
1 AND r.RESOURCE_ID = p.ELEMENT_ID :
1AND p.RANK LIKE ':
1%' :
11431:
1        RETURN_ERROR:: SP_SEARCH_2(1432) :: cplan.sql(1589) :: :
11434:
1                EXIT:: SP_SEARCH_2(1435) :: cplan.sql(1592) :: :
1TMT_ORGANIZATIONS:
1SELECT RANK INTO h_rank:n               FROM TMT_ORGANIZATIONS:n             +
1  WHERE ELEMENT_ID = org_id001:
11453:
1           EXCEPTION:: SP_SEARCH_2(1454) :: cplan.sql(1611) :: :
1,TMT_ORGANIZATIONS o:
1 AND r.RESOURCE_ID=o.ELEMENT_ID :
1AND o.RANK LIKE ':
11464:
1        RETURN_ERROR:: SP_SEARCH_2(1465) :: cplan.sql(1622) :: :
11467:
1                EXIT:: SP_SEARCH_2(1468) :: cplan.sql(1625) :: :
1TMT_GEOGRAPHIES:
1SELECT RANK INTO h_rank:n               FROM TMT_GEOGRAPHIES:n               +
1WHERE ELEMENT_ID = geo_id001:
11486:
1           EXCEPTION:: SP_SEARCH_2(1487) :: cplan.sql(1644) :: :
1,TMT_GEOGRAPHIES g:
1 AND r.RESOURCE_ID=g.ELEMENT_ID :
1AND g.RANK LIKE ':
11497:
1        RETURN_ERROR:: SP_SEARCH_2(1498) :: cplan.sql(1655) :: :
11500:
1                EXIT:: SP_SEARCH_2(1501) :: cplan.sql(1658) :: :
1 AND r.WORK_LOCATION=:
1PMO_STPU:
1STRNPCPY:
1SELECT RANK INTO h_rank:n               FROM TMT_COMPETENCIES:n              +
1 WHERE ELEMENT_ID = h_role_id:
11532:
1           EXCEPTION:: SP_SEARCH_2(1533) :: cplan.sql(1690) :: :
11539:
1        RETURN_ERROR:: SP_SEARCH_2(1540) :: cplan.sql(1697) :: :
11542:
1                EXIT:: SP_SEARCH_2(1543) :: cplan.sql(1700) :: :
1 AND EXISTS :
1(SELECT t1.ELEMENT_ID :
1  FROM TMT_COMPETENCIES t1:
1  WHERE t1.RANK LIKE ':
1%':
1AND r.ELEMENT_ID=t1.ELEMENT_ID) :
1AND r.RESOURCE_ID=t1.RESOURCE_ID) :
11587:
1           EXCEPTION:: SP_SEARCH_2(1588) :: cplan.sql(1745) :: :
11594:
1        RETURN_ERROR:: SP_SEARCH_2(1595) :: cplan.sql(1752) :: :
11597:
1                EXIT:: SP_SEARCH_2(1598) :: cplan.sql(1755) :: :
1     AND r.RESOURCE_ID=t1.RESOURCE_ID) :
1 ORDER BY RESOURCE_ID  :
1OPEN:
1CLOSE:
11661:
1           EXCEPTION:: SP_SEARCH_2(1662) :: cplan.sql(1819) :: :
1CONTINUE0000:
11681:
1           EXCEPTION:: SP_SEARCH_2(1682) :: cplan.sql(1839) :: :
1COUNT:
1TSK_ASSIGNMENT_ID:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var :n                  FROM TASK+
1_ASSIGNMENTS:n                  WHERE PROJECT_ID = h_project_id:n            +
1      AND RESOURCE_ID = h_res_id:n                  AND RESOURCE_TYPE = '0':
11712:
1           EXCEPTION:: SP_SEARCH_2(1713) :: cplan.sql(1870) :: :
11728:
1           EXCEPTION:: SP_SEARCH_2(1729) :: cplan.sql(1886) :: :
11734:
1        RETURN_ERROR:: SP_SEARCH_2(1735) :: cplan.sql(1892) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
11737:
1                EXIT:: SP_SEARCH_2(1738) :: cplan.sql(1895) :: :
1FC_SEARCH_2:
11763:
1           EXCEPTION:: SP_SEARCH_2(1764) :: cplan.sql(1921) :: :
1DB_OFFSET:
1TASK_ASSIGNMENT_ERROR:
11773:
1        RETURN_ERROR:: SP_SEARCH_2(1774) :: cplan.sql(1931) :: :
11776:
1                EXIT:: SP_SEARCH_2(1777) :: cplan.sql(1934) :: :
1UPDATE PROFILES SET REC_STATUS='U' WHERE PROFILE_ID = h_res_id AND REC_STATUS+
1='D':
11794:
1           EXCEPTION:: SP_SEARCH_2(1795) :: cplan.sql(1952) :: :
11838:
1           EXCEPTION:: SP_SEARCH_2(1839) :: cplan.sql(1996) :: :
1ASSIGN_STRING_TOLONG:
11847:
1        RETURN_ERROR:: SP_SEARCH_2(1848) :: cplan.sql(2005) :: :
11850:
1                EXIT:: SP_SEARCH_2(1851) :: cplan.sql(2008) :: :
1NOTNULL:
1UPDATE PMO_TMP_SEARCH SET:n                  ROLE_ID = h_source_ids:n        +
1          , ROLE_NAME = h_and_roles:n                  , SKILL_ID = h_target_+
1ids:n                  , SKILL_NAME = h_and_skills:n                  , SHOW_+
1ROLE = h_shw_roles:n                  , SHOW_SKILL = h_shw_skills:n          +
1        WHERE RS_ID = h_last_id:
11918:
1           EXCEPTION:: SP_SEARCH_2(1919) :: cplan.sql(2076) :: :
1UPDATE PMO_TMP_SEARCH SET:n               ROLE_ID = NuLL:n               , RO+
1LE_NAME = NuLL:n               , SKILL_ID = NuLL:n               , SKILL_NAME+
1 = NuLL:n               , SHOW_ROLE = NuLL:n               , SHOW_SKILL = NuL+
1L:n               WHERE RS_ID = h_last_id:
11961:
1           EXCEPTION:: SP_SEARCH_2(1962) :: cplan.sql(2119) :: :
1,:
12022:
1           EXCEPTION:: SP_SEARCH_2(2023) :: cplan.sql(2180) :: :
1UPDATE PMO_TMP_SEARCH SET:n            ROLE_ID = h_source_ids:n            , +
1ROLE_NAME = h_and_roles:n            , SKILL_ID = h_target_ids:n            ,+
1 SKILL_NAME = h_and_skills:n            , SHOW_ROLE = h_shw_roles:n          +
1  , SHOW_SKILL = h_shw_skills:n            WHERE RS_ID = h_last_id:
12050:
1           EXCEPTION:: SP_SEARCH_2(2051) :: cplan.sql(2208) :: :
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT COALESCE(SUM(AVAILABLE_MIN),0) INTO h_effort:n            FROM CALENDA+
1R_DAY_OF_YEAR:n            WHERE ELEMENT_ID=h_project_id:n            AND DAY+
1_YEAR BETWEEN TO_DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_+
1DT, 1, 10)):
12072:
1           EXCEPTION:: SP_SEARCH_2(2073) :: cplan.sql(2230) :: :
1CURRENCY_ID:
1TODECIMAL:
1TD:
1TW:
1TMT_DATAFIELDS:
1SELECT CURRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) INTO h_currenc+
1y_id, h_rate_echange:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURR+
1ENCY_ID = td.ELEMENT_ID:n      WHERE tw.ELEMENT_ID = h_project_id:
12094:
1           EXCEPTION:: SP_SEARCH_2(2095) :: cplan.sql(2252) :: :
1DELETE FROM PMO_TMP_CPLN_0005:
1PMO_TMP_CPLN_0005:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1INSERT INTO PMO_TMP_CPLN_0005:n         SELECT RES_ID:n         , REGULAR_COS+
1T:n         , REGULAR_SALE:n         , SPECIAL_COST:n         , SPECIAL_SALE+
1:n         FROM PMO_TMP_SEARCH:n         WHERE RS_ID = h_rs_id:n         AND +
1(REGULAR_COST + REGULAR_SALE) > 0:
12132:
1           EXCEPTION:: SP_SEARCH_2(2133) :: cplan.sql(2290) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n            SELECT RES_ID:n            , MAX(R+
1EGULAR_COST) AS REGULAR_COST:n            , MAX(REGULAR_SALE) AS REGULAR_SALE+
1:n            , MAX(SPECIAL_COST) AS SPECIAL_COST:n            , MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE:n            FROM PMO_TMP_SEARCH:n            WHERE RS_+
1ID <> h_rs_id:n            GROUP BY RES_ID:
12161:
1           EXCEPTION:: SP_SEARCH_2(2162) :: cplan.sql(2319) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n               SELECT RES_ID, 0.00, 0.00, 0.00+
1, 0.00:n               FROM PMO_TMP_SEARCH:n               WHERE RS_ID = h_rs+
1_id:n               GROUP BY RES_ID:
12185:
1           EXCEPTION:: SP_SEARCH_2(2186) :: cplan.sql(2343) :: :
1RS:
1WORK_LOCATION:
1O1:
1ORGANIZATION:
1G1:
1GEOGRAPHY:
1ROUND:
1PA:
1RES_SALE_RATE:
1TEMP:
1REGULAR_RATE:
1SPECIAL_RATE:
1START_DATE:
1FINISH_DATE:
1ASSIGNABLE:
1PLANNED:
1SCHED:
1PROPOSED:
1WORK_EFFORT:
1UNIT_EFFORT:
1AVAILABLE:
1VERIFIED:
1STATUS2_ID:
1FULL_NAME:
1PP:
1POOL_NAME:
1E_MAIL_ADDRESS:
1UNIQUE_ID:
1CONTOUR:
1ASSIGN_STRING:
1ASSIGNED_FLAG:
1FS_LABOR_CODE:
1RES_MODIFIED_DATE:
1EXTERNAL_ID:
1LEFT:
1OUTER:
1PROJECT_ASSIGNMENTS:
1R:
1RATES:
1RATE_ID:
1SELECT h_res_id AS ELEMENT_ID, 41 AS TYPE_ID, p.PROFILE_NAME AS ELEMENT_NAME,+
1 rs.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, h_work_location AS+
1 WORK_LOCATION,:n      o1.ELEMENT_NAME AS ORGANIZATION,g1.ELEMENT_NAME AS GEO+
1GRAPHY,:n      ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST WHEN rs+
1.RES_SALE_RATE=0 THEN temp.REGULAR_COST * h_rate_echange ELSE a.REGULAR_COST +
1* h_rate_echange END,2) AS REGULAR_COST,:n      ROUND(CASE WHEN pa.REGULAR_RA+
1TE>0 THEN pa.REGULAR_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.REGULAR_SALE * h_+
1rate_echange ELSE a.REGULAR_SALE * h_rate_echange END,2) AS REGULAR_SALE,:n  +
1    ROUND(CASE WHEN pa.SPECIAL_COST>0 THEN pa.SPECIAL_COST WHEN rs.RES_SALE_R+
1ATE=0 THEN temp.SPECIAL_COST * h_rate_echange ELSE a.SPECIAL_COST * h_rate_ec+
1hange END,2) AS SPECIAL_COST,:n      ROUND(CASE WHEN pa.SPECIAL_RATE>0 THEN p+
1a.SPECIAL_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.SPECIAL_SALE * h_rate_echang+
1e ELSE a.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n      rs.STAR+
1T_DATE,rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSE+
1D > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFO+
1RT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n      '' AS VERIFIE+
1D, 0 AS STATUS2_ID, '' AS FULL_NAME, pp.ELEMENT_NAME AS POOL_NAME, '' AS E_MA+
1IL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIG+
1N_STRING, h_and_roles AS ROLE_ID, h_and_skills AS SKILL_ID, 0 AS ASSIGNED_FLA+
1G,:n      'PMOFFICE' AS FS_LABOR_CODE, TO_TIMESTAMP('1899-12-31 00::00::00') +
1AS RES_MODIFIED_DATE, '' AS EXTERNAL_ID:n      FROM PMO_TMP_CPLN_0005 temp JO+
1IN PMO_TMP_SEARCH rs ON rs.RES_ID = temp.RES_ID:n      LEFT OUTER JOIN PROJEC+
1T_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n+
1      JOIN PROFILES p ON p.PROFILE_ID = h_res_id:n      JOIN TMT_COMPETENCIES+
1 r ON p.ROLE_ID=r.ELEMENT_ID:n      LEFT OUTER JOIN RATES a ON r.RATE_ID=a.RA+
1TE_ID:n      LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON p.ORG_ID = o1.ELEMENT_ID+
1:n      LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON p.GEO_ID = g1.ELEMENT_ID:n     +
1 LEFT OUTER JOIN TMT_POOLS pp ON pp.ELEMENT_ID = p.POOL_ID:n      WHERE NOT (+
1rs.ROLE_NAME IS NuLL AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND r+
1s.SHOW_SKILL IS NuLL):
12211:
1                EXIT:: SP_SEARCH_2(2212) :: cplan.sql(2369) :: :
1O2:
1G2:
1DEFAULT_FLAG:
1RV:
1RM:
1PLANNED_WORK:
1SCHED_WORK:
1REC_DATETIME:
1MANAGER_ID:
1VERIFIED_1:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_COST * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG=+
1'1' THEN rs.REGULAR_COST ELSE rs.REGULAR_COST * h_rate_echange END,2) AS REGU+
1LAR_COST,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.REGULAR_SALE +
1* CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id+
1 = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DA+
1TAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELE+
1MENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHE+
1N rs.DEFAULT_FLAG='1' THEN rs.REGULAR_SALE ELSE rs.REGULAR_SALE * h_rate_echa+
1nge END,2) AS REGULAR_SALE,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THE+
1N rs.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_+
1ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME+
1,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_OR+
1ASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CU+
1RRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_COST ELSE rs.SPECIAL_+
1COST * h_rate_echange END,2) AS SPECIAL_COST,:n         ROUND(CASE WHEN rs.DE+
1FAULT_FLAG='0' THEN rs.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_i+
1d) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODE+
1CIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id+
1) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE+
1 ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.SPECIAL_SAL+
1E ELSE rs.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n         rs.+
1START_DATE, rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PR+
1OPOSED > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT+
1_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FU+
1LL_NAME AS VERIFIED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME+
1, RM.E_MAIL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR+
1 AS ASSIGN_STRING, rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCH+
1ED_WORK,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES+
1_MODIFIED_DATE, r.EXTERNAL_ID:n         FROM PMO_TMP_SEARCH rs JOIN TMT_POOLS+
1 p ON rs.RES_ID=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON pp.ELEMENT_ID=p.P+
1ARENT_ID:n         LEFT OUTER JOIN RESOURCES RM ON pp.MANAGER_ID=RM.RESOURCE_+
1ID:n         JOIN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID LEFT OUTER JOIN RESO+
1URCES rv ON rv.RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER JOIN PROJECT_ASS+
1IGNMENTS pa ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n     +
1    LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEMENT_ID:n    +
1     LEFT OUTER JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.ELEMENT_ID:n    +
1     LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMENT_ID:n     +
1    LEFT OUTER JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n       +
1  ORDER BY ELEMENT_ID:
12236:
1                EXIT:: SP_SEARCH_2(2237) :: cplan.sql(2394) :: :
1DELETE FROM PMO_TMP_CPLN_0006:
1PMO_TMP_CPLN_0006:
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT RES_ID, REGULAR_COST, REGUL+
1AR_SALE, SPECIAL_COST, SPECIAL_SALE, 1:n            FROM PMO_TMP_SEARCH WHERE+
1 DEFAULT_FLAG = '1':
12259:
1           EXCEPTION:: SP_SEARCH_2(2260) :: cplan.sql(2417) :: :
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT  RES_ID,                   +
1          MAX(REGULAR_COST) AS REGULAR_COST,:n            MAX(REGULAR_SALE) A+
1S REGULAR_SALE,  MAX(SPECIAL_COST) AS SPECIAL_COST,:n            MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE , 0:n            FROM PMO_TMP_SEARCH:n            WHERE+
1 RES_ID NOT IN (SELECT RES_ID FROM PMO_TMP_SEARCH WHERE DEFAULT_FLAG = '1' AN+
1D RES_ID IS NOT NuLL):n            GROUP BY RES_ID:
12284:
1           EXCEPTION:: SP_SEARCH_2(2285) :: cplan.sql(2442) :: :
1DEF:
1PRF:
1RR:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME, r+
1s.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOCATION,:n  +
1       o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY,:n       +
1  :n         ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST:n        +
1 WHEN a.REGULAR_COST>0 THEN a.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_cur+
1rency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORAS+
1TD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_curr+
1ency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELD+
1S WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THE+
1N def.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY+
1_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAM+
1E,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_O+
1RASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.C+
1URRENCY_ID) END:n         else prf.REGULAR_COST * h_rate_echange:n         EN+
1D,2) AS REGULAR_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_COST> 0+
1 THEN pa.REGULAR_RATE:n         WHEN a.REGULAR_COST > 0 THEN a.REGULAR_SALE *+
1 CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id +
1= 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DAT+
1AFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEM+
1ENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n   +
1      WHEN def.REGULAR_COST>0 THEN def.REGULAR_SALE * CASE WHEN (r.CURRENCY_I+
1D = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT+
1 PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID+
1 = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_+
1DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.REGULAR_S+
1ALE * h_rate_echange:n         END,2) AS REGULAR_SALE,:n         :n         R+
1OUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.SPECIAL_COST:n         WHEN a.REGULA+
1R_COST>0 THEN a.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (+
1r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(E+
1LEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SE+
1LECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMEN+
1T_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THEN def.SPECIAL_+
1COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_curren+
1cy_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM T+
1MT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMA+
1L(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) EN+
1D:n         else prf.SPECIAL_COST * h_rate_echange:n         END,2) AS SPECIA+
1L_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_RATE>0 THEN pa.SPECIA+
1L_RATE:n         WHEN a.REGULAR_SALE>0 THEN a.SPECIAL_SALE * CASE WHEN (r.CUR+
1RENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE +
1(SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELE+
1MENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.RE+
1GULAR_COST>0 THEN def.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_id+
1) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODEC+
1IMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id)+
1 / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE +
1ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.SPECIAL_SALE * h_rate_echa+
1nge:n         END,2) AS SPECIAL_SALE,:n         :n         rs.START_DATE,rs.F+
1INISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSED > 0 THEN +
1rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFORT,(rs.ASSI+
1GNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FULL_NAME AS VERIF+
1IED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME, RM.E_MAIL_ADDR+
1ESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRIN+
1G,:n         rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCHED_WOR+
1K,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES_MODIF+
1IED_DATE, r.EXTERNAL_ID:n         FROM PMO_TMP_SEARCH rs:n         LEFT JOIN +
1PMO_TMP_CPLN_0006 def ON rs.RES_ID=def.RES_ID AND def.DEFAULT_FLAG = 1:n     +
1    LEFT JOIN PMO_TMP_CPLN_0006 prf ON rs.RES_ID=prf.RES_ID AND prf.DEFAULT_F+
1LAG = 0:n         JOIN TMT_POOLS p ON rs.RES_ID=p.ELEMENT_ID:n         JOIN T+
1MT_POOLS pp ON pp.ELEMENT_ID=p.PARENT_ID:n         LEFT OUTER JOIN RESOURCES +
1RM ON pp.MANAGER_ID=RM.RESOURCE_ID:n         JOIN RESOURCES r ON rs.RES_ID=r.+
1RESOURCE_ID LEFT OUTER JOIN RESOURCES rv ON rv.RESOURCE_ID=r.VERIFIED_1:n    +
1     LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id AND+
1 pa.RESOURCE_ID=rs.RES_ID:n         LEFT OUTER JOIN RESOURCES rr ON r.VERIFIE+
1D_1=rr.RESOURCE_ID:n         LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON r.RESOUR+
1CE_ID=o1.ELEMENT_ID LEFT OUTER JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.E+
1LEMENT_ID:n         LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.EL+
1EMENT_ID LEFT OUTER JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_ID:n  +
1       LEFT OUTER JOIN RATES a ON r.RATE_ID=a.RATE_ID:n         WHERE NOT (rs+
1.ROLE_NAME IS NuLL AND rs.SKILL_NAME IS NuLL AND rs.SHOW_ROLE IS NuLL AND rs.+
1SHOW_SKILL IS NuLL):n         ORDER BY ELEMENT_ID:
12335:
1                EXIT:: SP_SEARCH_2(2336) :: cplan.sql(2493) :: :
1RETURN_ERROR_EXCEPTION:
12345:
1           EXCEPTION:: SP_SEARCH_2(2346) :: cplan.sql(2503) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
12357:
1           EXCEPTION:: SP_SEARCH_2(2358) :: cplan.sql(2515) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
373d
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a0 f4
b4 bf c8 :8 a0 12a bd b7 11
a4 b1 a0 f4 b4 bf c8 :10 a0
12a bd b7 11 a4 b1 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d a0 51 d a0 51 d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
a0 7e b4 2e :2 5a a 10 a0
7e b4 2e :2 5a a 10 :2 a0 51
a5 b a0 7e a0 6b b4 2e
5a a 10 a0 7e b4 2e :2 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 a0 b7 a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 :2 19 3c b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 51 a5 b 7e 51 b4
2e a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c a0 7e b4
2e :2 5a a0 51 d b7 :2 a0 d
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 a0 7e b4
2e :2 5a a 10 :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 51 d b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a a 10 :3 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c :2 a0 d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b d :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
6e d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 6e
d b7 19 :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 6e d
b7 a0 6e d b7 :2 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e a0 51 d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 6e a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
:4 a0 51 a5 b a5 b d :2 a0
51 a5 b 7e 51 b4 2e :4 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:3 a0 6b d b7 19 3c :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 :2 19 3c :8 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :3 a0 51 a5 b a5
b 7e 51 b4 2e :d a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:27 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 b7 :2 a0 51 a5 b a0 7e
a0 6b b4 2e :9 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :13 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :3 a0 6b d :3 a0 a5
b d b7 19 3c b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :17 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a 10 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :9 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :2 19 3c b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :b a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 19 3c b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 a0
51 d b7 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a a0 6e d a0
6e d b7 :2 a0 d :2 a0 d b7
:2 19 3c a0 51 d b7 a0 7e
51 b4 2e a0 6e d :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
b7 :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 51 d
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e a0 51 d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 a0 51 d a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 :2 19 3c
b7 19 3c b7 :2 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 51 d :2 a0 d :2 a0 d :3 a0
:2 51 a5 b d a0 4d d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
b4 2e d a0 51 d b7 :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :b a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
a0 51 d b7 :2 19 3c b7 :2 19
3c a0 7e 51 b4 2e :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:1f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 6e d
b7 a0 6e d b7 :2 19 3c :13 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :a a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :6 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :2 a0
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 :2 a0
51 a5 b a0 7e a0 6b b4
2e a 10 a0 7e b4 2e 5a
:2 a0 d b7 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b d b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
a 10 a0 7e b4 2e 5a a
10 a0 7e b4 2e :2 5a a 10
a0 51 d b7 19 3c a0 6e
d a0 6e d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e d b7 19 a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d b7 :2 19 3c b7 :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e a 10 :2 a0 51 a5
b a0 7e a0 6b b4 2e a
10 :2 a0 6e 11e 11d :2 a0 6b 51
d a0 7e b4 2e 5a :2 a0 6e
11e 11d :2 a0 6b 51 d :17 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :15 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 a0
d b7 :2 19 3c b7 19 3c a0
7e b4 2e 5a :4 a0 a5 b 51
a5 b 7e 51 b4 2e :4 a0 a5
b 51 a5 b 51 a5 b 7e
51 b4 2e a6 122 :4 a0 a5 b
51 a5 b 51 a5 b 122 124
d a0 51 d :3 a0 7e a0 b4
2e 82 :5 a0 7e 51 b4 2e 51
a5 b a5 b 51 a5 b 7e
51 b4 2e :5 a0 7e 51 b4 2e
51 a5 b a5 b 51 a5 b
7e 51 b4 2e a 10 a0 2b
b7 19 3c :2 a0 7e 51 b4 2e
d b7 a0 47 :2 a0 7e b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :4 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e a0 6e d a0 6e d :2 a0
7e a0 b4 2e d :2 a0 7e 6e
b4 2e d a0 b7 :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
6e d :2 a0 7e a0 b4 2e d
:2 a0 7e 6e b4 2e d a0 6e
d b7 19 :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 6e d
a0 6e d a0 7e b4 2e 5a
:2 a0 7e 6e b4 2e d :2 a0 7e
a0 b4 2e d :2 a0 7e 6e b4
2e d b7 19 3c :2 a0 7e 6e
b4 2e d a0 7e b4 2e 5a
:2 a0 7e 6e b4 2e d :2 a0 7e
a0 b4 2e d :2 a0 7e 6e b4
2e d b7 19 3c b7 a0 7e
b4 2e 5a :2 a0 7e 6e b4 2e
d a0 6e d b7 :2 a0 7e 6e
b4 2e 7e 6e b4 2e d a0
6e d a0 7e b4 2e 5a :2 a0
7e 6e b4 2e d :2 a0 7e a0
b4 2e d :2 a0 7e 6e b4 2e
d b7 19 3c :2 a0 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e d b7 :2 19
3c a0 7e b4 2e 5a :2 a0 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 19 3c b7
:2 19 3c b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :4 a0
a5 b 51 a5 b d :2 a0 7e
6e b4 2e d :2 a0 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d b7 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c b7 19 3c a0 7e b4 2e
5a :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 7e 6e b4
2e d :2 a0 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c b7
19 3c a0 7e b4 2e 5a :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 7e 6e b4 2e d
:2 a0 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e d b7 19 3c
b7 19 3c a0 7e b4 2e 5a
:4 a0 a5 b 51 a5 b d a0
51 d :3 a0 7e a0 b4 2e 82
:3 a0 6b :2 51 a0 7e 51 b4 2e
a0 a5 b d :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 7e 6e
b4 2e d b7 :2 a0 7e 6e b4
2e d b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
2b b7 19 3c :2 a0 7e 51 b4
2e d b7 a0 47 b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :4 a0 a5 b 51 a5 b
d a0 51 d :3 a0 7e a0 b4
2e 82 :3 a0 6b :2 51 a0 7e 51
b4 2e a0 a5 b d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
d :2 a0 7e 51 b4 2e d b7
a0 47 b7 19 3c :2 a0 7e a0
b4 2e d b7 :2 19 3c :2 a0 7e
6e b4 2e d :3 a0 11c 11d :3 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
a 10 :2 a0 51 a5 b a0 7e
a0 6b b4 2e a 10 :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 7e b4 2e 5a 52 10 5a
a 10 :2 a0 e9 dd b3 :2 a0 e9
d3 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 3b b7 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 19 3c :2 a0
d :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 :2 51 a5 b 7e
6e b4 2e :2 a0 b4 2e d a0
51 d b7 :3 a0 51 a5 b a5
b 7e 51 b4 2e :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 19 3c b7
:2 19 3c :20 a0 51 a5 b :4 51 a5
b d a0 7e 51 b4 2e :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 7e a0 6b b4 2e
:3 a0 6b d b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :3 a0
a5 57 a0 b7 :2 a0 :2 51 a5 b
7e 6e b4 2e 5a :2 a0 :2 51 a5
b 7e 6e b4 2e 5a a 10
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c a0 2b b7 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 d :2 a0 d b7 19 3c :1e a0
:5 51 a5 b d a0 7e 51 b4
2e :2 a0 7e 51 b4 2e d a0
b7 a0 7e 51 b4 2e a0 2b
b7 :2 19 3c :2 a0 7e a0 51 a5
b b4 2e a0 2b b7 19 3c
b7 :2 19 3c 93 4f b0 46 b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 7e a0
6b b4 2e 5a a0 7e 51 b4
2e 5a 52 10 a0 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e a 10 5a 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :3 a0
a5 57 b7 19 3c a0 7e 51
b4 2e a0 6e d a0 6e d
a0 6e d :2 a0 e9 dd b3 a0
51 d :a a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c a0 7e b4 2e 5a :2 a0
6b :2 a0 a5 b 7e 51 b4 2e
a 10 :3 a0 a5 b 51 a5 b
7e 51 b4 2e a 10 :2 a0 d
b7 19 3c :2 a0 6b :2 a0 a5 b
7e 51 b4 2e a0 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c a0 6e d a0
6e d a0 6e d a0 6e d
a0 6e d a0 6e d :2 a0 d
a0 51 d b7 19 3c a0 7e
51 b4 2e a0 7e b4 2e 5a
a 10 :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a :3 a0
7e 6e b4 2e :2 51 a5 b d
b7 19 3c :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 19 3c a0
7e b4 2e 5a :3 a0 7e a0 b4
2e :2 51 a5 b d b7 19 3c
a0 7e b4 2e 5a a0 7e b4
2e 5a :3 a0 7e 6e b4 2e :2 51
a5 b d b7 19 3c :3 a0 7e
a0 b4 2e :2 51 a5 b d b7
19 3c a0 7e b4 2e 5a :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a :3 a0 7e 6e
b4 2e :2 51 a5 b d b7 19
3c :3 a0 7e a0 b4 2e :2 51 a5
b d b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a :3 a0
7e 6e b4 2e :2 51 a5 b d
b7 19 3c :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 19 3c :2 a0
7e 51 b4 2e d :2 a0 d b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 7e 51
b4 2e :f a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e :e a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 51 d 4f b7 :2 19 3c b7
19 3c :13 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 6e
11e 11d :2 a0 6b 51 d :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 19 3c :cd a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 b7
a0 7e 51 b4 2e :12f a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 b7 :2 a0
6e 11e 11d :2 a0 6b 51 d :8 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :15 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :1b9 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
b7 :2 19 3c b7 :2 19 3c b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
373d
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 1b4
1b0 186 1bc 1c5 1c1 1af 1cd 1da
1d6 1ac 1e2 1eb 1e7 1d5 1f3 200
1fc 1d2 208 211 20d 1fb 219 1f8
21e 222 226 22a 22d 231 24e 239
23d 240 241 249 238 26b 259 235
25d 25e 266 258 288 276 255 27a
27b 283 275 2a5 293 272 297 298
2a0 292 2c2 2b0 28f 2b4 2b5 2bd
2af 2df 2cd 2ac 2d1 2d2 2da 2cc
2fc 2ea 2c9 2ee 2ef 2f7 2e9 319
307 2e6 30b 30c 314 306 336 324
303 328 329 331 323 353 341 320
345 346 34e 340 370 35e 33d 362
363 36b 35d 38d 37b 35a 37f 380
388 37a 3aa 398 377 39c 39d 3a5
397 3c7 3b5 394 3b9 3ba 3c2 3b4
3e4 3d2 3b1 3d6 3d7 3df 3d1 401
3ef 3ce 3f3 3f4 3fc 3ee 41e 40c
3eb 410 411 419 40b 43b 429 408
42d 42e 436 428 458 446 425 44a
44b 453 445 475 463 442 467 468
470 462 492 480 45f 484 485 48d
47f 4ae 49d 4a1 4a9 47c 4ca 4b5
4b9 4bc 4bd 4c5 49c 4e7 4d5 499
4d9 4da 4e2 4d4 504 4f2 4d1 4f6
4f7 4ff 4f1 521 50f 4ee 513 514
51c 50e 53e 52c 50b 530 531 539
52b 55a 549 54d 555 528 576 561
565 568 569 571 548 593 581 545
585 586 58e 580 5b0 59e 57d 5a2
5a3 5ab 59d 5cd 5bb 59a 5bf 5c0
5c8 5ba 5ea 5d8 5b7 5dc 5dd 5e5
5d7 607 5f5 5d4 5f9 5fa 602 5f4
623 612 616 5f1 61e 611 63f 62e
632 60e 63a 62d 65b 64a 64e 62a
656 649 677 666 66a 646 672 665
693 682 686 662 68e 681 6af 69e
6a2 67e 6aa 69d 6cb 6ba 6be 69a
6c6 6b9 6e7 6d6 6da 6b6 6e2 6d5
703 6f2 6f6 6d2 6fe 6f1 71f 70e
712 6ee 71a 70d 73b 72a 72e 70a
736 729 757 746 74a 726 752 745
773 762 766 742 76e 761 78f 77e
782 75e 78a 77d 7ab 79a 79e 77a
7a6 799 7c7 7b6 7ba 796 7c2 7b5
7e3 7d2 7d6 7b2 7de 7d1 7ff 7ee
7f2 7ce 7fa 7ed 81b 80a 80e 7ea
816 809 837 826 82a 806 832 825
853 842 846 822 84e 841 86f 85e
862 83e 86a 85d 88b 87a 87e 85a
886 879 8a7 896 89a 876 8a2 895
8c3 8b2 8b6 892 8be 8b1 8df 8ce
8d2 8ae 8da 8cd 8fb 8ea 8ee 8ca
8f6 8e9 917 906 90a 8e6 912 905
933 922 926 902 92e 921 94f 93e
942 91e 94a 93d 96b 95a 95e 93a
966 959 987 976 97a 956 982 975
9a3 992 996 972 99e 991 9c0 9ae
98e 9b2 9b3 9bb 9ad 9dc 9cb 9cf
9aa 9d7 9ca 9f8 9e7 9eb 9c7 9f3
9e6 a14 a03 a07 9e3 a0f a02 a31
a1f 9ff a23 a24 a2c a1e a4e a3c
a1b a40 a41 a49 a3b a6b a59 a38
a5d a5e a66 a58 a87 a76 a7a a55
a82 a75 aa3 a92 a96 a72 a9e a91
ac0 aae a8e ab2 ab3 abb aad add
acb aaa acf ad0 ad8 aca afa ae8
ac7 aec aed af5 ae7 b17 b05 ae4
b09 b0a b12 b04 b34 b22 b01 b26
b27 b2f b21 b51 b3f b1e b43 b44
b4c b3e b6d b5c b60 b3b b68 b5b
b89 b78 b7c b58 b84 b77 ba5 b94
b98 b74 ba0 b93 bc1 bb0 bb4 b90
bbc baf bdd bcc bd0 bac bd8 bcb
bf9 be8 bec bc8 bf4 be7 c15 c04
c08 be4 c10 c03 c31 c20 c24 c00
c2c c1f c4e c3c c1c c40 c41 c49
c3b c6a c59 c5d c38 c65 c58 c86
c75 c79 c81 c55 c9e c8d c91 c99
c74 cba ca9 cad cb5 c71 cd2 cc1
cc5 ccd ca8 cee cdd ce1 ce9 ca5
d06 cf5 cf9 d01 cdc d22 d11 d15
d1d cd9 d41 d29 d2d d31 d34 d3c
d10 d48 d4c d0d d5d d60 d64 d68
d6c d70 d74 d78 d7c d80 d84 d90
d95 d97 da3 da7 da9 dad dbe dbf
dc2 dc6 dca dce dd2 dd6 dda dde
de2 de6 dea dee df2 df6 dfa dfe
e02 e06 e12 e17 e19 e25 e29 e47
e2f e33 e37 e3a e42 e2e e67 e52
e56 e2b e5a e62 e51 e87 e72 e76
e4e e7a e82 e71 ea7 e92 e96 e6e
e9a ea2 e91 eae eb2 e8e eb6 eba
ebe ec1 ec6 ec7 1 ec9 ece ed2
ed6 ed9 ede ee2 ee6 ee9 eee eef
ef1 ef6 ef9 efd efe f03 f08 f0b
f10 f11 f16 f19 f1d f1e f23 f26
f2b f2c f31 f34 f39 f3a f3f f42
f47 f48 f4d f50 f54 f55 f5a f5d
f62 f63 f68 f6b f70 f71 f76 f79
f7e f7f f84 f87 f8b f8c f91 f94
f99 f9a f9f fa2 fa7 fa8 fad fb0
fb4 fb8 fbc fbd fbf fc4 fc5 fc7
fc8 fcd fd0 fd5 fd6 fdb fde fe2
fe6 fea feb fed ff2 ff3 ff5 ff6
ffb ffe 1003 1004 1009 100c 1010 1014
1018 1019 101b 1020 1021 1023 1024 1029
102c 1031 1032 1037 103a 103e 1042 1046
1047 1049 104e 104f 1051 1052 1057 105a
105f 1060 1065 1068 106c 1070 1074 1075
1077 107c 107d 107f 1080 1085 1088 108d
108e 1093 1096 109a 109e 10a2 10a3 10a5
10aa 10ab 10ad 10ae 10b3 10b6 10bb 10bc
10c1 10c4 10c8 10cc 10d0 10d1 10d3 10d8
10d9 10db 10dc 10e1 10e4 10e9 10ea 10ef
10f2 10f6 10fa 10fe 10ff 1101 1106 1107
1109 110a 110f 1112 1117 1118 111d 1120
1125 1126 112b 112e 1132 1133 1138 113b
1140 1141 1146 1149 114e 114f 1154 1157
115c 115d 1162 1165 1169 116a 116f 1172
1177 1178 117d 1180 1185 1186 118b 118e
1193 1194 1199 119c 11a0 11a1 11a6 11a9
11ae 11af 11b4 11b7 11bc 11bd 11c2 11c5
11ca 11cb 11d0 11d3 11d7 11d8 11dd 11e0
11e5 11e6 11eb 11ee 11f3 11f4 11f9 11fc
1201 1202 1207 120a 120e 120f 1214 1217
121c 121d 1222 1225 122a 122b 1230 1233
1237 123b 123f 1240 1242 1247 1248 124a
124b 1250 1253 1258 1259 125e 1261 1266
1267 126c 126f 1273 1274 1279 127c 1281
1282 1287 128a 128f 1290 1295 1298 129d
129e 12a3 12a6 12aa 12ab 12b0 12b3 12b8
12b9 12be 12c1 12c6 12c7 12cc 12cf 12d4
12d5 12da 12dd 12e1 12e2 12e7 12ea 12ef
12f0 12f5 12f8 12fd 12fe 1303 1306 130b
130c 1311 1314 1318 1319 131e 1321 1326
1327 132c 132f 1334 1335 133a 133d 1341
1345 1349 134a 134c 1351 1352 1354 1355
135a 135d 1362 1363 1368 136b 136f 1373
1377 1378 137a 137f 1380 1382 1383 1388
138b 1390 1391 1396 1399 139d 13a1 13a5
13a6 13a8 13ad 13ae 13b0 13b1 13b6 13b9
13be 13bf 13c4 13c7 13cb 13cf 13d3 13d4
13d6 13db 13dc 13de 13df 13e4 13e7 13ec
13ed 13f2 13f5 13fa 13fb 1400 1403 1407
1408 140d 1410 1415 1416 141b 141e 1423
1424 1429 142c 1431 1432 1437 143a 143e
143f 1444 1447 144c 144d 1452 1455 145a
145b 1460 1461 1466 1468 146c 146f 1473
1477 147a 147e 1482 1485 1488 148d 1490
1493 1496 1497 149c 149d 1 149f 14a4
14a8 14ac 14af 14b4 14b9 14bc 14c0 14c1
14c6 14c7 14cc 14ce 14d2 14d5 14d9 14dd
14e1 14e5 14e9 14ed 14f1 14f5 14f9 14fd
1501 1505 1509 150d 1511 1515 1519 151d
1521 1525 1529 152d 1531 1535 1539 153d
1541 1545 1549 154d 1551 1555 1559 155d
1561 1565 1569 156d 1571 1575 1579 157d
1581 1585 1589 158d 1591 1595 1599 159d
15a1 15a5 15a9 15ad 15b1 15b5 15b9 15bd
15c1 15c5 15c9 15cd 15d1 15d5 15d9 15dd
15e1 15e4 15e8 15ec 15ef 15f3 15f7 15fb
15fe 15ff 1601 1605 1608 160c 160f 1610
1615 1618 161c 161f 1620 1625 1628 1
162b 1630 1634 1638 163b 163f 1643 1646
1649 164e 1651 1654 1657 1658 165d 165e
1 1660 1665 1669 166d 1670 1675 167a
167d 1681 1682 1687 168a 168f 1690 1695
1698 169d 169e 16a3 16a6 16aa 16ae 16b2
16b6 16b9 16ba 16bc 16c1 16c2 16c4 16c5
16ca 16cb 16d0 16d2 16d6 16d9 16dd 16e1
16e4 16e8 16ec 16ef 16f2 16f7 16fa 16fd
1700 1701 1706 1707 1 1709 170e 1712
1716 1719 171e 1723 1726 172a 172b 1730
1731 1736 1738 173c 173f 1743 1747 174a
174e 1752 1755 1759 175a 175f 1761 1765
1768 176c 176f 1770 1775 1778 177b 177f
1782 1783 1788 178b 1 178e 1793 1797
179a 179b 17a0 17a3 1 17a6 17ab 17af
17b2 17b3 17b8 17bb 1 17be 17c3 17c7
17cb 17ce 17cf 17d1 17d5 17d8 17dc 17df
17e0 17e5 1 17e8 17ed 17f1 17f4 17f5
17fa 17fd 1800 1804 1808 180b 180c 180e
1812 1815 1819 181c 181d 1822 1 1825
182a 182e 1832 1835 1839 183d 1840 1843
1848 184b 184e 1851 1852 1857 1858 1
185a 185f 1863 1867 186a 186f 1874 1877
187b 187c 1881 1884 1889 188a 188f 1892
1897 1898 189d 18a0 18a4 18a8 18ac 18b0
18b3 18b4 18b6 18bb 18bc 18be 18bf 18c4
18c5 18ca 18cc 18d0 18d3 18d7 18db 18de
18e2 18e6 18e9 18ec 18f1 18f4 18f7 18fa
18fb 1900 1901 1 1903 1908 190c 1910
1913 1918 191d 1920 1924 1925 192a 192b
1930 1932 1936 1939 193d 1941 1944 1948
194c 194f 1953 1954 1959 195d 195f 1963
1966 1967 196c 196f 1972 1976 1979 197a
197f 1982 1 1985 198a 198e 1992 1995
1999 199d 19a0 19a3 19a8 19ab 19ae 19b1
19b2 19b7 19b8 1 19ba 19bf 19c3 19c7
19ca 19cf 19d4 19d7 19db 19dc 19e1 19e4
19e9 19ea 19ef 19f2 19f7 19f8 19fd 1a00
1a04 1a08 1a0c 1a10 1a13 1a14 1a16 1a1b
1a1c 1a1e 1a1f 1a24 1a25 1a2a 1a2c 1a30
1a33 1a37 1a3b 1a3e 1a42 1a46 1a49 1a4c
1a51 1a54 1a57 1a5a 1a5b 1a60 1a61 1
1a63 1a68 1a6c 1a70 1a73 1a78 1a7d 1a80
1a84 1a85 1a8a 1a8b 1a90 1a92 1a96 1a99
1a9d 1aa1 1aa4 1aa8 1aac 1aaf 1ab3 1ab4
1ab9 1abb 1abf 1ac3 1ac6 1ac8 1acc 1acf
1ad3 1ad7 1ada 1adb 1add 1ae0 1ae3 1ae4
1ae9 1aed 1af1 1af4 1af5 1af7 1afa 1afd
1afe 1 1b03 1b08 1b0c 1b10 1b13 1b14
1b16 1b19 1b1c 1b1d 1 1b22 1b27 1b2b
1b2f 1b32 1b36 1b3a 1b3d 1b40 1b45 1b48
1b4b 1b4e 1b4f 1b54 1b55 1 1b57 1b5c
1b60 1b64 1b67 1b6c 1b71 1b74 1b78 1b79
1b7e 1b81 1b86 1b87 1b8c 1b8f 1b94 1b95
1b9a 1b9d 1ba1 1ba5 1ba9 1bad 1bb0 1bb1
1bb3 1bb8 1bb9 1bbb 1bbc 1bc1 1bc2 1bc7
1bc9 1bcd 1bd0 1bd4 1bd8 1bdb 1bdf 1be3
1be6 1be9 1bee 1bf1 1bf4 1bf7 1bf8 1bfd
1bfe 1 1c00 1c05 1c09 1c0d 1c10 1c15
1c1a 1c1d 1c21 1c22 1c27 1c28 1c2d 1c2f
1c33 1c36 1c3a 1c3e 1c41 1c45 1c49 1c4c
1c50 1c51 1c56 1c58 1c5c 1c5f 1c63 1c66
1c67 1c6c 1c6f 1c72 1c76 1c79 1c7d 1c7f
1c83 1c87 1c8b 1c8d 1c91 1c95 1c98 1c9c
1ca0 1ca3 1ca4 1ca6 1caa 1cad 1cb1 1cb4
1cb5 1cba 1cbd 1cc1 1cc4 1cc5 1cca 1ccd
1 1cd0 1cd5 1cd9 1cdc 1cdd 1ce2 1ce5
1 1ce8 1ced 1cf1 1cf5 1cf9 1cfd 1d01
1d05 1d09 1d0d 1d19 1d1d 1d21 1d24 1d28
1d2c 1d2e 1d32 1d36 1d3a 1d3d 1d41 1d45
1d47 1d48 1d4d 1 1d51 1d55 1d59 1d5c
1d60 1d64 1d68 1d6c 1d6f 1d73 1d77 1d7a
1d7d 1d82 1d85 1d88 1d8b 1d8c 1d91 1d92
1 1d94 1d99 1d9d 1da1 1da4 1da9 1dae
1db1 1db5 1db6 1dbb 1dbe 1dc3 1dc4 1dc9
1dcc 1dd1 1dd2 1dd7 1dda 1dde 1ddf 1de4
1de7 1dec 1ded 1df2 1df5 1df9 1dfd 1e00
1e03 1e04 1e06 1e07 1e0c 1e0d 1e12 1e14
1e18 1e1b 1e1d 1e21 1e23 1e2f 1e31 1e33
1e34 1e39 1e3d 1e3f 1e4b 1e4d 1e51 1e55
1e58 1e5c 1e5f 1e63 1e66 1e67 1e6c 1e6f
1e73 1e77 1e7a 1e7b 1e7d 1e80 1e83 1e84
1e89 1 1e8c 1e91 1e95 1e99 1e9c 1ea0
1ea4 1ea7 1eaa 1eaf 1eb2 1eb5 1eb8 1eb9
1ebe 1ebf 1 1ec1 1ec6 1eca 1ece 1ed1
1ed6 1edb 1ede 1ee2 1ee3 1ee8 1eeb 1ef0
1ef1 1ef6 1ef9 1efe 1eff 1f04 1f07 1f0b
1f0f 1f13 1f17 1f1a 1f1b 1f1d 1f22 1f23
1f25 1f26 1f2b 1f2c 1f31 1f33 1f37 1f3a
1f3e 1f42 1f45 1f49 1f4d 1f50 1f53 1f58
1f5b 1f5e 1f61 1f62 1f67 1f68 1 1f6a
1f6f 1f73 1f77 1f7a 1f7f 1f84 1f87 1f8b
1f8c 1f91 1f92 1f97 1f99 1f9d 1fa0 1fa4
1fa8 1fab 1faf 1fb3 1fb6 1fba 1fbb 1fc0
1fc2 1fc6 1fc9 1fcd 1fd0 1fd4 1fd6 1fda
1fdd 1fe1 1fe4 1fe5 1fea 1fed 1ff0 1ff4
1ff7 1ff8 1ffd 2000 1 2003 2008 200c
2010 2014 2020 2024 2028 202b 202f 2033
2035 2039 203d 2041 2044 2048 204c 204e
204f 2054 1 2058 205c 2060 2063 2067
206b 206f 2073 2076 207a 207e 2081 2084
2089 208c 208f 2092 2093 2098 2099 1
209b 20a0 20a4 20a8 20ab 20b0 20b5 20b8
20bc 20bd 20c2 20c5 20ca 20cb 20d0 20d3
20d8 20d9 20de 20e1 20e5 20e6 20eb 20ee
20f3 20f4 20f9 20fc 2100 2104 2107 210a
210b 210d 210e 2113 2114 2119 211b 211f
2122 2124 2128 212a 2136 2138 213a 213b
2140 2144 2146 2152 2154 2156 215a 215d
2161 2165 2169 216d 2171 2175 2178 217c
2180 2184 2187 2188 218a 218e 2192 2195
2196 2198 219b 219e 219f 21a1 21a5 21a9
21ad 21b1 21b5 21b8 21b9 21bb 21bf 21c3
21c6 21c7 21c9 21cd 21d1 21d5 21d9 21dc
21e0 21e4 21e8 21eb 21ec 21ee 21f2 21f6
21f9 21fa 21fc 21ff 2202 2203 2205 2209
220d 2211 2215 2219 221c 221d 221f 2223
2227 222a 222b 222d 2231 2235 2239 223c
223d 223f 2243 2246 224a 224d 224e 2253
2257 225c 2260 2264 2266 226a 226e 2271
2272 2274 2278 227b 227f 2282 2283 2288
228c 2291 2295 2297 229b 229f 22a3 22a6
22a7 22a9 22ad 22b0 22b4 22b7 22b8 22bd
22c1 22c6 22ca 22cc 22d0 22d5 22d9 22db
22df 22e3 22e6 22e8 22ec 22f0 22f3 22f7
22fb 22fe 22ff 2301 2304 2307 2308 230d
2311 2314 2318 231c 2320 2324 2328 232c
2338 233c 2340 2343 2347 234b 234d 2351
2355 2359 235c 2360 2364 2366 2367 236c
1 2370 2374 2378 237b 237f 2383 2387
238b 238e 2392 2396 2399 239c 23a1 23a4
23a7 23aa 23ab 23b0 23b1 1 23b3 23b8
23bc 23c0 23c3 23c8 23cd 23d0 23d4 23d5
23da 23dd 23e2 23e3 23e8 23eb 23f0 23f1
23f6 23f9 23fd 23fe 2403 2406 240b 240c
2411 2414 2418 241c 241f 2422 2423 2425
2426 242b 242c 2431 2433 2437 243a 243c
2440 2442 244e 2450 2452 2453 2458 245c
245e 246a 246c 2470 2474 2477 2478 247a
247d 2480 2481 2486 248a 248e 2492 2496
249a 24a6 24aa 24ae 24b1 24b5 24b9 24bb
24bf 24c3 24c7 24ca 24ce 24d2 24d4 24d5
24da 1 24de 24e2 24e6 24e9 24ed 24f1
24f5 24f9 24fc 2500 2504 2507 250a 250f
2512 2515 2518 2519 251e 251f 1 2521
2526 252a 252e 2531 2536 253b 253e 2542
2543 2548 254b 2550 2551 2556 2559 255e
255f 2564 2567 256b 256c 2571 2574 2579
257a 257f 2582 2586 258a 258d 2590 2591
2593 2594 2599 259a 259f 25a1 25a5 25a8
25aa 25ae 25b0 25bc 25be 25c0 25c1 25c6
25ca 25cc 25d8 25da 25de 25e2 25e5 25e9
25ee 25ef 25f1 25f4 25f7 25f8 25fd 2601
2605 2608 260c 2610 2613 2616 261b 261e
2621 2624 2625 262a 262b 1 262d 2632
2636 263a 263d 2642 2647 264a 264e 264f
2654 2657 265c 265d 2662 2665 266a 266b
2670 2673 2677 267b 267f 2683 2686 2687
2689 268e 268f 2691 2692 2697 269a 269f
26a0 26a5 26a8 26ad 26ae 26b3 26b6 26ba
26bb 26c0 26c3 26c8 26c9 26ce 26cf 26d4
26d6 26da 26dd 26e1 26e5 26e8 26ec 26f0
26f3 26f6 26fb 26fe 2701 2704 2705 270a
270b 1 270d 2712 2716 271a 271d 2722
2727 272a 272e 272f 2734 2735 273a 273c
2740 2743 2747 274b 274e 2752 2756 2759
275d 2761 2762 2767 2769 276d 2770 2772
2776 2779 277d 2781 2785 2789 278c 278d
278f 2790 2792 2796 279a 279e 27a1 27a2
27a4 27a7 27aa 27ab 27b0 27b4 27b8 27bc
27c0 27c3 27c4 27c6 27c7 27c9 27cd 27d1
27d5 27d8 27d9 27db 27de 27e1 27e2 27e7
27eb 27ef 27f2 27f6 27fa 27fd 2800 2805
2808 280b 280e 280f 2814 2815 1 2817
281c 2820 2824 2827 282c 2831 2834 2838
2839 283e 2841 2846 2847 284c 284f 2854
2855 285a 285d 2861 2865 2869 286d 2870
2871 2873 2878 2879 287b 287c 2881 2882
2887 2889 288d 2890 2894 2898 289b 289f
28a3 28a6 28a9 28ae 28b1 28b4 28b7 28b8
28bd 28be 1 28c0 28c5 28c9 28cd 28d0
28d5 28da 28dd 28e1 28e2 28e7 28e8 28ed
28ef 28f3 28f6 28fa 28fe 2901 2905 2909
290c 2910 2911 2916 2918 291c 291f 2923
2927 292b 292e 2932 2934 2938 293b 293f
2943 2947 294b 294f 2952 2953 2955 2958
295b 295c 2961 2965 2969 296d 296f 2973
2977 297a 297e 2982 2985 2988 298d 2990
2993 2996 2997 299c 299d 1 299f 29a4
29a8 29ac 29af 29b4 29b9 29bc 29c0 29c1
29c6 29c9 29ce 29cf 29d4 29d7 29dc 29dd
29e2 29e5 29e9 29ed 29f1 29f5 29f8 29f9
29fb 2a00 2a01 2a03 2a04 2a09 2a0a 2a0f
2a11 2a15 2a18 2a1c 2a20 2a23 2a27 2a2b
2a2e 2a31 2a36 2a39 2a3c 2a3f 2a40 2a45
2a46 1 2a48 2a4d 2a51 2a55 2a58 2a5d
2a62 2a65 2a69 2a6a 2a6f 2a70 2a75 2a77
2a7b 2a7e 2a82 2a86 2a89 2a8d 2a91 2a94
2a98 2a99 2a9e 2aa0 2aa4 2aa8 2aab 2aaf
2ab3 2ab7 2abb 2abf 2ac3 2ac7 2acb 2acc
2ace 2ad2 2ad6 2ada 2add 2ade 2ae0 2ae4
2ae7 2aeb 2aee 2aef 2af4 2af8 2afc 2aff
2b00 2b02 2b05 2b08 2b09 2b0e 2b12 2b16
2b1a 2b1d 2b21 2b23 2b27 2b2a 2b2e 2b32
2b35 2b39 2b3d 2b40 2b43 2b48 2b4b 2b4e
2b51 2b52 2b57 2b58 1 2b5a 2b5f 2b63
2b67 2b6a 2b6f 2b74 2b77 2b7b 2b7c 2b81
2b84 2b89 2b8a 2b8f 2b92 2b97 2b98 2b9d
2ba0 2ba4 2ba8 2bac 2bad 2baf 2bb4 2bb5
2bb7 2bb8 2bbd 2bc0 2bc5 2bc6 2bcb 2bce
2bd3 2bd4 2bd9 2bdc 2be0 2be1 2be6 2be9
2bee 2bef 2bf4 2bf5 2bfa 2bfc 2c00 2c03
2c07 2c0b 2c0e 2c12 2c16 2c19 2c1c 2c21
2c24 2c27 2c2a 2c2b 2c30 2c31 1 2c33
2c38 2c3c 2c40 2c43 2c48 2c4d 2c50 2c54
2c55 2c5a 2c5b 2c60 2c62 2c66 2c69 2c6d
2c71 2c74 2c78 2c7c 2c7f 2c80 2c82 2c86
2c8a 2c8b 2c90 2c92 2c96 2c99 2c9d 2ca1
2ca4 2ca5 2ca7 2caa 2cad 2cae 2cb3 2cb7
2cbb 2cbe 2cbf 2cc1 2cc4 2cc7 2cc8 1
2ccd 2cd2 2cd6 2cda 2cdd 2ce1 2ce5 2ce8
2ceb 2cf0 2cf3 2cf6 2cf9 2cfa 2cff 2d00
1 2d02 2d07 2d0b 2d0f 2d12 2d17 2d1c
2d1f 2d23 2d24 2d29 2d2c 2d31 2d32 2d37
2d3a 2d3f 2d40 2d45 2d48 2d4c 2d50 2d54
2d55 2d57 2d5c 2d5d 2d5f 2d60 2d65 2d68
2d6d 2d6e 2d73 2d76 2d7b 2d7c 2d81 2d84
2d88 2d89 2d8e 2d91 2d96 2d97 2d9c 2d9d
2da2 2da4 2da8 2dab 2daf 2db3 2db6 2dba
2dbe 2dc1 2dc4 2dc9 2dcc 2dcf 2dd2 2dd3
2dd8 2dd9 1 2ddb 2de0 2de4 2de8 2deb
2df0 2df5 2df8 2dfc 2dfd 2e02 2e03 2e08
2e0a 2e0e 2e11 2e15 2e19 2e1c 2e20 2e24
2e27 2e28 2e2a 2e2e 2e32 2e33 2e38 2e3a
2e3e 2e41 2e45 2e49 2e4c 2e4d 2e4f 2e53
2e56 2e5a 2e5d 2e5e 2e63 2e67 2e6b 2e6f
2e72 2e73 2e75 2e76 2e78 2e7b 2e7e 2e7f
2e84 2e88 2e8c 2e90 2e94 2e98 2e9c 2ea0
2ea4 2ea8 2eac 2eb0 2eb4 2eb8 2ec4 2ec8
2ecc 2ecf 2ed3 2ed7 2ed9 2edd 2ee1 2ee5
2ee8 2eec 2ef0 2ef2 2ef3 2ef8 1 2efc
2f00 2f04 2f07 2f0b 2f0f 2f13 2f17 2f1a
2f1e 2f22 2f25 2f28 2f2d 2f30 2f33 2f36
2f37 2f3c 2f3d 1 2f3f 2f44 2f48 2f4c
2f4f 2f54 2f59 2f5c 2f60 2f61 2f66 2f69
2f6e 2f6f 2f74 2f77 2f7c 2f7d 2f82 2f85
2f89 2f8a 2f8f 2f92 2f97 2f98 2f9d 2fa0
2fa4 2fa8 2fab 2fae 2faf 2fb1 2fb2 2fb7
2fb8 2fbd 2fbf 2fc3 2fc6 2fc8 2fcc 2fce
2fda 2fdc 2fde 2fdf 2fe4 2fe8 2fea 2ff6
2ff8 2ffa 2ffe 3002 3006 300a 300e 3012
3016 301a 301e 3022 3026 302a 302e 3032
3036 303a 303e 3042 3046 304a 304e 3052
3056 305a 305e 3062 3066 306a 306e 3072
3076 307a 307e 3082 3086 308a 308e 3092
3096 30a2 30a6 30aa 30ad 30b1 30b5 30b7
30bb 30bf 30c3 30c6 30ca 30ce 30d0 30d1
30d6 1 30da 30de 30e2 30e5 30e9 30ed
30f1 30f5 30f8 30fc 3100 3103 3106 310b
310e 3111 3114 3115 311a 311b 1 311d
3122 3126 312a 312d 3132 3137 313a 313e
313f 3144 3147 314c 314d 3152 3155 315a
315b 3160 3163 3167 3168 316d 3170 3175
3176 317b 317e 3182 3186 3189 318c 318d
318f 3190 3195 3196 319b 319d 31a1 31a4
31a6 31aa 31ac 31b8 31ba 31bc 31bd 31c2
31c6 31c8 31d4 31d6 31d8 31dc 31e0 31e3
31e7 31eb 31ee 31f2 31f5 31f9 31fc 31fd
3202 3205 3209 320d 3210 3214 3218 321b
321e 3223 3226 3229 322c 322d 3232 3233
1 3235 323a 323e 3242 3245 324a 324f
3252 3256 3257 325c 325f 3264 3265 326a
326d 3272 3273 3278 327b 327f 3283 3287
328b 328e 328f 3291 3296 3297 3299 329a
329f 32a2 32a7 32a8 32ad 32b0 32b5 32b6
32bb 32be 32c2 32c3 32c8 32cb 32d0 32d1
32d6 32d7 32dc 32de 32e2 32e5 32e9 32ed
32f0 32f4 32f8 32fb 32fe 3303 3306 3309
330c 330d 3312 3313 1 3315 331a 331e
3322 3325 332a 332f 3332 3336 3337 333c
333d 3342 3344 3348 334b 334f 3353 3356
335a 335e 3361 3365 3369 336a 336f 3371
3375 3378 337c 337e 3382 3386 3389 338a
338c 3390 3393 3397 339a 339b 33a0 33a4
33a8 33ac 33b0 33b4 33b8 33bc 33c0 33c4
33d0 33d4 33d8 33db 33df 33e3 33e5 33e9
33ed 33f1 33f4 33f8 33fc 33fe 33ff 3404
1 3408 340c 3410 3413 3417 341b 341f
3423 3426 342a 342e 3431 3434 3439 343c
343f 3442 3443 3448 3449 1 344b 3450
3454 3458 345b 3460 3465 3468 346c 346d
3472 3475 347a 347b 3480 3483 3488 3489
348e 3491 3495 3496 349b 349e 34a3 34a4
34a9 34ac 34b0 34b4 34b7 34ba 34bb 34bd
34be 34c3 34c4 34c9 34cb 34cf 34d2 34d4
34d8 34da 34e6 34e8 34ea 34eb 34f0 34f4
34f6 3502 3504 3508 350c 350f 3513 3516
351a 351d 351e 3523 3526 352a 352e 3531
3535 3539 353c 353f 3544 3547 354a 354d
354e 3553 3554 1 3556 355b 355f 3563
3566 356b 3570 3573 3577 3578 357d 3580
3585 3586 358b 358e 3593 3594 3599 359c
35a0 35a4 35a8 35ac 35af 35b0 35b2 35b7
35b8 35ba 35bb 35c0 35c3 35c8 35c9 35ce
35d1 35d6 35d7 35dc 35df 35e3 35e4 35e9
35ec 35f1 35f2 35f7 35f8 35fd 35ff 3603
3606 360a 360e 3611 3615 3619 361c 361f
3624 3627 362a 362d 362e 3633 3634 1
3636 363b 363f 3643 3646 364b 3650 3653
3657 3658 365d 365e 3663 3665 3669 366c
3670 3674 3677 367b 367f 3682 3686 368a
368b 3690 3692 3696 3699 369d 36a1 36a5
36a9 36ad 36b1 36b5 36b9 36bd 36c1 36c5
36c9 36cd 36d1 36d5 36d9 36dd 36e1 36e5
36f1 36f5 36f9 36fc 3700 3704 3706 370a
370e 3712 3715 3719 371d 371f 3720 3725
1 3729 372d 3731 3734 3738 373c 3740
3744 3747 374b 374f 3752 3755 375a 375d
3760 3763 3764 3769 376a 1 376c 3771
3775 3779 377c 3781 3786 3789 378d 378e
3793 3796 379b 379c 37a1 37a4 37a9 37aa
37af 37b2 37b6 37b7 37bc 37bf 37c4 37c5
37ca 37cd 37d1 37d5 37d8 37db 37dc 37de
37df 37e4 37e5 37ea 37ec 37f0 37f3 37f5
37f9 37fb 3807 3809 380b 380c 3811 3815
3817 3823 3825 3829 382d 3830 3834 3837
383b 383e 383f 3844 3847 384b 384f 3852
3856 385a 385d 3860 3865 3868 386b 386e
386f 3874 3875 1 3877 387c 3880 3884
3887 388c 3891 3894 3898 3899 389e 38a1
38a6 38a7 38ac 38af 38b4 38b5 38ba 38bd
38c1 38c5 38c9 38cd 38d0 38d1 38d3 38d8
38d9 38db 38dc 38e1 38e4 38e9 38ea 38ef
38f2 38f7 38f8 38fd 3900 3904 3905 390a
390d 3912 3913 3918 3919 391e 3920 3924
3927 392b 392f 3932 3936 393a 393d 3940
3945 3948 394b 394e 394f 3954 3955 1
3957 395c 3960 3964 3967 396c 3971 3974
3978 3979 397e 397f 3984 3986 398a 398d
3991 3995 3998 399c 39a0 39a3 39a7 39ab
39ac 39b1 39b3 39b7 39ba 39be 39c1 39c2
39c7 39ca 39ce 39d2 39d6 39d9 39dd 39e1
39e5 39e9 39ea 39ec 39f0 39f2 39f6 39f9
39fb 39ff 3a03 3a07 3a0a 3a0e 3a12 3a15
3a18 3a1d 3a20 3a23 3a26 3a27 3a2c 3a2d
1 3a2f 3a34 3a38 3a3c 3a3f 3a44 3a49
3a4c 3a50 3a51 3a56 3a59 3a5e 3a5f 3a64
3a67 3a6c 3a6d 3a72 3a75 3a79 3a7d 3a81
3a85 3a88 3a89 3a8b 3a90 3a91 3a93 3a94
3a99 3a9c 3aa1 3aa2 3aa7 3aaa 3aaf 3ab0
3ab5 3ab8 3abc 3abd 3ac2 3ac5 3aca 3acb
3ad0 3ad1 3ad6 3ad8 3adc 3adf 3ae3 3ae7
3aea 3aee 3af2 3af5 3af8 3afd 3b00 3b03
3b06 3b07 3b0c 3b0d 1 3b0f 3b14 3b18
3b1c 3b1f 3b24 3b29 3b2c 3b30 3b31 3b36
3b37 3b3c 3b3e 3b42 3b45 3b49 3b4d 3b50
3b54 3b58 3b5b 3b5f 3b63 3b64 3b69 3b6b
3b6f 3b73 3b76 3b7a 3b7e 3b81 3b82 3b84
3b88 3b8b 3b8f 3b92 3b93 3b98 3b9c 3ba0
3ba4 3ba8 3bac 3bb0 3bb4 3bb8 3bbc 3bc0
3bc4 3bc8 3bcc 3bd0 3bd4 3bd8 3bdc 3be0
3be4 3be8 3bec 3bf0 3bf4 3c00 3c04 3c08
3c0b 3c0f 3c13 3c15 3c19 3c1d 3c21 3c24
3c28 3c2c 3c2e 3c2f 3c34 1 3c38 3c3c
3c40 3c43 3c47 3c4b 3c4f 3c53 3c56 3c5a
3c5e 3c61 3c64 3c69 3c6c 3c6f 3c72 3c73
3c78 3c79 1 3c7b 3c80 3c84 3c88 3c8b
3c90 3c95 3c98 3c9c 3c9d 3ca2 3ca5 3caa
3cab 3cb0 3cb3 3cb8 3cb9 3cbe 3cc1 3cc5
3cc6 3ccb 3cce 3cd3 3cd4 3cd9 3cdc 3ce0
3ce4 3ce7 3cea 3ceb 3ced 3cee 3cf3 3cf4
3cf9 3cfb 3cff 3d02 3d04 3d08 3d0a 3d16
3d18 3d1a 3d1b 3d20 3d24 3d26 3d32 3d34
3d38 3d3c 3d3f 3d43 3d46 3d4a 3d4d 3d4e
3d53 3d56 3d5a 3d5e 3d61 3d65 3d69 3d6c
3d6f 3d74 3d77 3d7a 3d7d 3d7e 3d83 3d84
1 3d86 3d8b 3d8f 3d93 3d96 3d9b 3da0
3da3 3da7 3da8 3dad 3db0 3db5 3db6 3dbb
3dbe 3dc3 3dc4 3dc9 3dcc 3dd0 3dd4 3dd8
3ddc 3ddf 3de0 3de2 3de7 3de8 3dea 3deb
3df0 3df3 3df8 3df9 3dfe 3e01 3e06 3e07
3e0c 3e0f 3e13 3e14 3e19 3e1c 3e21 3e22
3e27 3e28 3e2d 3e2f 3e33 3e36 3e3a 3e3e
3e41 3e45 3e49 3e4c 3e4f 3e54 3e57 3e5a
3e5d 3e5e 3e63 3e64 1 3e66 3e6b 3e6f
3e73 3e76 3e7b 3e80 3e83 3e87 3e88 3e8d
3e8e 3e93 3e95 3e99 3e9c 3ea0 3ea4 3ea7
3eab 3eaf 3eb2 3eb6 3eba 3ebb 3ec0 3ec4
3ec6 3eca 3ece 3ed1 3ed5 3ed8 3edc 3edf
3ee0 3ee5 3ee8 3eec 3ef0 3ef3 3ef6 3ef7
3ef9 3efc 3f01 3f02 3f07 3f0b 3f0f 3f12
3f13 3f15 3f18 3f1b 3f1c 3f21 3f25 3f29
3f2c 3f2d 3f2f 3f33 3f36 3f3a 3f3d 3f3e
3f40 3f41 1 3f46 3f4b 1 3f4e 3f53
3f57 3f5b 3f5e 3f62 3f66 3f69 3f6c 3f71
3f74 3f77 3f7a 3f7b 3f80 3f81 1 3f83
3f88 3f8c 3f90 3f93 3f98 3f9d 3fa0 3fa4
3fa5 3faa 3fad 3fb2 3fb3 3fb8 3fbb 3fc0
3fc1 3fc6 3fc9 3fcd 3fd1 3fd5 3fd9 3fdc
3fdd 3fdf 3fe4 3fe5 3fe7 3fe8 3fed 3ff0
3ff5 3ff6 3ffb 3ffe 4003 4004 4009 400c
4010 4011 4016 4019 401e 401f 4024 4025
402a 402c 4030 4033 4037 403b 403e 4042
4046 4049 404c 4051 4054 4057 405a 405b
4060 4061 1 4063 4068 406c 4070 4073
4078 407d 4080 4084 4085 408a 408b 4090
4092 4096 4099 409d 40a1 40a4 40a8 40ac
40af 40b3 40b7 40b8 40bd 40bf 40c3 40c6
40ca 40ce 40d1 40d2 40d4 40d8 40db 40df
40e2 40e3 40e5 40e6 40eb 40ef 40f3 40f7
40fb 40ff 4103 4107 410b 410f 411b 411f
4123 4126 412a 412e 4130 4134 4138 413c
413f 4143 4147 4149 414a 414f 1 4153
4157 415b 415e 4162 4166 416a 416e 4171
4175 4179 417c 417f 4184 4187 418a 418d
418e 4193 4194 1 4196 419b 419f 41a3
41a6 41ab 41b0 41b3 41b7 41b8 41bd 41c0
41c5 41c6 41cb 41ce 41d3 41d4 41d9 41dc
41e0 41e1 41e6 41e9 41ee 41ef 41f4 41f7
41fb 41ff 4202 4205 4206 4208 4209 420e
420f 4214 4216 421a 421d 421f 4223 4225
4231 4233 4235 4236 423b 423f 4241 424d
424f 4251 4255 4258 425a 425e 4262 4265
4267 426b 426e 4270 4274 4277 427b 427f
4282 4283 4285 4288 428b 428c 4291 4295
4299 429c 429d 429f 42a3 42a6 42aa 42ad
42ae 42b3 42b7 42ba 42bb 42c0 1 42c3
42c8 42cc 42d0 42d3 42d4 42d6 42d9 42dc
42dd 1 42e2 42e7 42eb 42ef 42f2 42f6
42fa 42fd 4300 4305 4308 430b 430e 430f
4314 4315 1 4317 431c 4320 4324 4327
432c 4331 4334 4338 4339 433e 4341 4346
4347 434c 434f 4354 4355 435a 435d 4361
4365 4369 436d 4370 4371 4373 4378 4379
437b 437c 4381 4384 4389 438a 438f 4392
4397 4398 439d 43a0 43a4 43a5 43aa 43ad
43b2 43b3 43b8 43b9 43be 43c0 43c4 43c7
43cb 43cf 43d2 43d6 43da 43dd 43e0 43e5
43e8 43eb 43ee 43ef 43f4 43f5 1 43f7
43fc 4400 4404 4407 440c 4411 4414 4418
4419 441e 441f 4424 4426 442a 442d 4431
4435 4438 443c 4440 4443 4447 444b 444c
4451 4453 4457 445a 445e 4462 4465 4466
4468 446c 446f 4473 4476 4477 447c 4480
4484 4488 448c 4490 4494 4498 449c 44a0
44a4 44a8 44b4 44b8 44bc 44bf 44c3 44c7
44c9 44cd 44d1 44d5 44d8 44dc 44e0 44e2
44e3 44e8 1 44ec 44f0 44f4 44f7 44fb
44ff 4503 4507 450a 450e 4512 4515 4518
451d 4520 4523 4526 4527 452c 452d 1
452f 4534 4538 453c 453f 4544 4549 454c
4550 4551 4556 4559 455e 455f 4564 4567
456c 456d 4572 4575 4579 457a 457f 4582
4587 4588 458d 4590 4594 4598 459b 459e
459f 45a1 45a2 45a7 45a8 45ad 45af 45b3
45b6 45b8 45bc 45be 45ca 45cc 45ce 45cf
45d4 45d8 45da 45e6 45e8 45ec 45f0 45f3
45f7 45fa 45fe 4601 4602 4607 460a 460e
4612 4616 461a 461e 462a 462e 4632 4635
4639 463d 463f 4643 4647 464b 464e 4652
4656 4658 4659 465e 1 4662 4666 466a
466d 4671 4675 4679 467d 4680 4684 4688
468b 468e 4693 4696 4699 469c 469d 46a2
46a3 1 46a5 46aa 46ae 46b2 46b5 46ba
46bf 46c2 46c6 46c7 46cc 46cf 46d4 46d5
46da 46dd 46e2 46e3 46e8 46eb 46ef 46f0
46f5 46f8 46fd 46fe 4703 4706 470a 470e
4711 4714 4715 4717 4718 471d 471e 4723
4725 4729 472c 472e 4732 4734 4740 4742
4744 4745 474a 474e 4750 475c 475e 4762
4766 4769 476d 4770 4774 4777 4778 477d
4780 4784 4788 478b 478f 4793 4796 4799
479e 47a1 47a4 47a7 47a8 47ad 47ae 1
47b0 47b5 47b9 47bd 47c0 47c5 47ca 47cd
47d1 47d2 47d7 47da 47df 47e0 47e5 47e8
47ed 47ee 47f3 47f6 47fa 47fe 4802 4806
4809 480a 480c 4811 4812 4814 4815 481a
481d 4822 4823 4828 482b 4830 4831 4836
4839 483d 483e 4843 4846 484b 484c 4851
4852 4857 4859 485d 4860 4864 4868 486b
486f 4873 4876 4879 487e 4881 4884 4887
4888 488d 488e 1 4890 4895 4899 489d
48a0 48a5 48aa 48ad 48b1 48b2 48b7 48b8
48bd 48bf 48c3 48c6 48ca 48ce 48d1 48d5
48d9 48dc 48e0 48e4 48e5 48ea 48ec 48f0
48f3 48f5 48f9 48fc 48fe 4902 4905 4907
490b 490e 4912 4916 4919 491a 491c 491f
4922 4923 4928 492c 4930 4933 4934 4936
4939 493c 493d 1 4942 4947 494b 494e
4952 4954 4958 495b 495f 4963 4966 4967
4969 496d 4970 4974 4977 4978 497d 4981
4984 4985 498a 498d 4991 4996 499a 499e
49a3 49a7 49a9 49ad 49b1 49b5 49b9 49bd
49c1 49c3 49c7 49cb 49ce 49d2 49d5 49d9
49db 49df 49e2 49e5 49e6 49eb 49ef 49f4
49f8 49fc 4a00 4a04 4a08 4a0c 4a10 4a13
4a14 4a16 4a1a 4a1e 4a21 4a22 4a24 4a28
4a2c 4a2f 4a30 4a32 4a36 4a3a 4a3d 4a3e
4a40 4a44 4a48 4a4b 4a4c 4a4e 4a52 4a56
4a59 4a5a 4a5c 4a60 4a64 4a67 4a68 4a6a
4a6e 4a72 4a75 4a76 4a78 4a7c 4a80 4a84
4a85 4a87 4a8b 4a8f 4a93 4a96 4a97 4a99
4a9d 4aa0 4aa4 4aa7 4aa8 4aad 4ab1 4ab5
4ab8 4abc 4ac0 4ac3 4ac6 4acb 4ace 4ad1
4ad4 4ad5 4ada 4adb 1 4add 4ae2 4ae6
4aea 4aed 4af2 4af7 4afa 4afe 4aff 4b04
4b07 4b0c 4b0d 4b12 4b15 4b1a 4b1b 4b20
4b23 4b27 4b2b 4b2f 4b33 4b36 4b37 4b39
4b3e 4b3f 4b41 4b42 4b47 4b48 4b4d 4b4f
4b53 4b56 4b5a 4b5e 4b61 4b65 4b69 4b6c
4b6f 4b74 4b77 4b7a 4b7d 4b7e 4b83 4b84
1 4b86 4b8b 4b8f 4b93 4b96 4b9b 4ba0
4ba3 4ba7 4ba8 4bad 4bae 4bb3 4bb5 4bb9
4bbc 4bc0 4bc4 4bc7 4bcb 4bcf 4bd2 4bd6
4bd7 4bdc 4be0 4be2 4be6 4bea 4bed 4bee
4bf0 4bf3 4bf6 4bf7 4bfc 4c00 4c04 4c07
4c0b 4c0f 4c12 4c15 4c1a 4c1d 4c20 4c23
4c24 4c29 4c2a 1 4c2c 4c31 4c35 4c39
4c3c 4c41 4c46 4c49 4c4d 4c4e 4c53 4c56
4c5b 4c5c 4c61 4c64 4c69 4c6a 4c6f 4c72
4c76 4c7a 4c7e 4c7f 4c81 4c86 4c87 4c89
4c8a 4c8f 4c92 4c97 4c98 4c9d 4ca0 4ca5
4ca6 4cab 4cae 4cb2 4cb3 4cb8 4cbb 4cc0
4cc1 4cc6 4cc7 4ccc 4cce 4cd2 4cd5 4cd9
4cdd 4ce0 4ce4 4ce8 4ceb 4cee 4cf3 4cf6
4cf9 4cfc 4cfd 4d02 4d03 1 4d05 4d0a
4d0e 4d12 4d15 4d1a 4d1f 4d22 4d26 4d27
4d2c 4d2d 4d32 4d34 4d38 4d3b 4d3f 4d43
4d46 4d4a 4d4e 4d51 4d52 4d54 4d58 4d5c
4d5d 4d62 4d64 4d68 4d6c 4d6f 4d71 4d75
4d79 4d7d 4d81 4d85 4d88 4d89 4d8b 4d8e
4d91 4d92 4d97 4d9b 4d9f 4da3 4da6 4da7
4da9 4dac 4db0 4db4 4db7 4db8 4dba 4dbb
4dc0 4dc4 4dc6 4dca 4dcd 4dcf 4dd3 4dd7
4dda 4dde 4de2 4de5 4de6 4de8 4deb 4dee
4def 4df4 4df7 4dfb 4dff 4e02 4e03 4e05
4e08 4e0b 4e0c 4e11 1 4e14 4e19 4e1d
4e21 4e24 4e25 4e27 4e2a 4e2d 4e2e 4e33
4e36 4e3a 4e3e 4e41 4e42 4e44 4e47 4e4a
4e4b 4e50 1 4e53 4e58 4e5c 4e5f 4e63
4e67 4e69 4e6d 4e71 4e74 4e75 4e77 4e7a
4e7d 4e7e 4e83 4e87 4e8a 4e8e 4e92 4e94
4e98 4e9c 4ea0 4ea3 4ea4 4ea6 4ea9 4eac
4ead 4eb2 4eb5 4eb9 4ebd 4ec0 4ec1 4ec3
4ec6 4ec9 4eca 4ecf 1 4ed2 4ed7 4edb
4ede 4ee2 4ee6 4ee8 4eec 4ef0 4ef4 4ef7
4ef8 4efa 4efd 4f00 4f01 4f06 4f0a 4f0d
4f11 4f13 4f17 4f1b 4f1e 4f20 4f24 4f27
4f29 4f2d 4f31 4f34 4f38 4f3c 4f3f 4f40
4f42 4f46 4f49 4f4d 4f50 4f51 4f56 4f5a
4f5d 4f61 4f65 4f69 4f6d 4f71 4f75 4f79
4f7d 4f81 4f85 4f88 4f8b 4f8c 4f8e 4f92
4f96 4f97 4f9b 4f9f 4fa3 4fa6 4fa7 4fa9
4fac 4faf 4fb0 4fb5 4fb9 4fbd 4fbe 4fc3
4fc7 4fcb 4fce 4fd2 4fd4 4fd8 4fdc 4fe0
4fe4 4fe8 4ff4 4ff8 4ffc 4fff 5003 5007
5009 500d 5011 5015 5018 501c 5020 5022
5023 5028 1 502c 5030 5034 5037 503b
503f 5043 5047 504a 504e 5052 5055 5058
505d 5060 5063 5066 5067 506c 506d 1
506f 5074 5078 507c 507f 5084 5089 508c
5090 5091 5096 5099 509e 509f 50a4 50a7
50ac 50ad 50b2 50b5 50b9 50ba 50bf 50c2
50c7 50c8 50cd 50d0 50d4 50d8 50db 50de
50df 50e1 50e2 50e7 50e8 50ed 50ef 50f3
50f6 50f8 50fc 50fe 510a 510c 510e 510f
5114 5118 511a 5126 5128 512c 5130 5133
5137 513a 513e 5141 5142 5147 514a 514e
5152 5155 5156 5158 515b 515e 515f 5164
5168 516c 5170 5174 5178 517c 5180 5184
5188 518c 5190 519c 51a0 51a4 51a7 51ab
51af 51b1 51b5 51b9 51bd 51c0 51c4 51c8
51ca 51cb 51d0 1 51d4 51d8 51dc 51df
51e3 51e7 51eb 51ef 51f2 51f6 51fa 51fd
5200 5205 5208 520b 520e 520f 5214 5215
1 5217 521c 5220 5224 5227 522c 5231
5234 5238 5239 523e 5241 5246 5247 524c
524f 5254 5255 525a 525d 5261 5262 5267
526a 526f 5270 5275 5278 527c 5280 5283
5286 5287 5289 528a 528f 5290 5295 5297
529b 529e 52a0 52a4 52a6 52b2 52b4 52b6
52b7 52bc 52c0 52c2 52ce 52d0 52d2 52d6
52d9 52db 52df 52e2 52e6 52e8 52ec 52f0
52f3 52f5 52f9 52fd 5300 5304 5307 530a
530b 5310 5314 5318 531c 5320 5324 5328
532c 5330 5334 5340 5344 5348 534b 534f
5353 5355 5359 535d 5361 5364 5368 536c
536e 536f 5374 1 5378 537c 5380 5383
5387 538b 538f 5393 5396 539a 539e 53a1
53a4 53a9 53ac 53af 53b2 53b3 53b8 53b9
1 53bb 53c0 53c4 53c8 53cb 53d0 53d5
53d8 53dc 53dd 53e2 53e5 53ea 53eb 53f0
53f3 53f8 53f9 53fe 5401 5405 5406 540b
540e 5413 5414 5419 541c 5420 5424 5427
542a 542b 542d 542e 5433 5434 5439 543b
543f 5442 5444 5448 544a 5456 5458 545a
545b 5460 5464 5466 5472 5474 5478 547c
5480 5484 5488 548c 5490 5494 5498 549c
54a0 54a4 54a8 54ac 54b0 54b4 54b8 54bc
54c0 54c4 54c8 54cc 54d0 54d4 54d8 54dc
54e0 54e4 54e8 54ec 54f0 54fc 5500 5504
5507 550b 550f 5511 5515 5519 551d 5520
5524 5528 552a 552b 5530 1 5534 5538
553c 553f 5543 5547 554b 554f 5552 5556
555a 555d 5560 5565 5568 556b 556e 556f
5574 5575 1 5577 557c 5580 5584 5587
558c 5591 5594 5598 5599 559e 55a1 55a6
55a7 55ac 55af 55b4 55b5 55ba 55bd 55c1
55c2 55c7 55ca 55cf 55d0 55d5 55d8 55dc
55e0 55e3 55e6 55e7 55e9 55ea 55ef 55f0
55f5 55f7 55fb 55fe 5600 5604 5606 5612
5614 5616 5617 561c 5620 5622 562e 5630
5634 5638 563b 563f 5642 5646 5649 564a
564f 5652 5656 565a 565d 5661 5665 5668
566b 5670 5673 5676 5679 567a 567f 5680
1 5682 5687 568b 568f 5692 5697 569c
569f 56a3 56a4 56a9 56ac 56b1 56b2 56b7
56ba 56bf 56c0 56c5 56c8 56cc 56d0 56d4
56d8 56db 56dc 56de 56e3 56e4 56e6 56e7
56ec 56ef 56f4 56f5 56fa 56fd 5702 5703
5708 570b 570f 5710 5715 5718 571d 571e
5723 5724 5729 572b 572f 5732 5736 573a
573d 5741 5745 5748 574b 5750 5753 5756
5759 575a 575f 5760 1 5762 5767 576b
576f 5772 5777 577c 577f 5783 5784 5789
578a 578f 5791 5795 5798 579c 57a0 57a3
57a7 57ab 57ae 57b2 57b6 57b7 57bc 57be
57c2 57c5 57c9 57cd 57d0 57d1 57d3 57d6
57d9 57da 57df 57e3 57e8 57ec 57ee 57f2
57f7 57fb 57fd 5801 5805 5808 580c 5810
5814 5818 581c 5820 5824 5828 582c 5830
5834 5838 583c 5840 5844 5848 584c 5850
5854 5860 5864 5869 586d 5870 5871 5876
587a 587e 5881 5884 5888 588a 588e 5892
5895 5898 589c 589e 58a2 58a6 58a9 58ab
58af 58b3 58b7 58ba 58be 58c2 58c4 58c5
58ca 1 58ce 58d2 58d6 58d9 58dd 58e1
58e5 58e9 58ec 58f0 58f4 58f7 58fa 58ff
5902 5905 5908 5909 590e 590f 1 5911
5916 591a 591e 5921 5926 592b 592e 5932
5933 5938 593b 5940 5941 5946 5949 594e
594f 5954 5957 595b 595c 5961 5964 5969
596a 596f 5972 5976 597a 597d 5980 5981
5983 5984 5989 598a 598f 5991 5995 5998
599a 599e 59a0 59ac 59ae 59b0 59b1 59b6
59ba 59bc 59c8 59ca 59ce 59d0 59d4 59d8
59db 59de 59df 59e1 59e4 59e9 59ea 59ef
59f3 59f7 59fb 59ff 5a03 5a07 5a0b 5a0f
5a13 5a17 5a23 5a27 5a2c 5a30 5a33 5a34
5a39 5a3d 5a41 5a44 5a47 5a4b 5a4d 5a51
5a55 5a58 5a5b 5a5f 5a61 5a65 5a69 5a6c
5a6e 5a72 5a76 5a7a 5a7d 5a81 5a85 5a87
5a88 5a8d 1 5a91 5a95 5a99 5a9c 5aa0
5aa4 5aa8 5aac 5aaf 5ab3 5ab7 5aba 5abd
5ac2 5ac5 5ac8 5acb 5acc 5ad1 5ad2 1
5ad4 5ad9 5add 5ae1 5ae4 5ae9 5aee 5af1
5af5 5af6 5afb 5afe 5b03 5b04 5b09 5b0c
5b11 5b12 5b17 5b1a 5b1e 5b1f 5b24 5b27
5b2c 5b2d 5b32 5b35 5b39 5b3d 5b40 5b43
5b44 5b46 5b47 5b4c 5b4d 5b52 5b54 5b58
5b5b 5b5d 5b61 5b63 5b6f 5b71 5b73 5b74
5b79 5b7d 5b7f 5b8b 5b8d 5b8f 5b93 5b97
5b9a 5b9e 5ba2 5ba6 5baa 5bae 5bb2 5bb6
5bba 5bbe 5bca 5bce 5bd3 5bd7 5bda 5bdb
5be0 5be4 5be8 5beb 5bee 5bf2 5bf4 5bf8
5bfc 5bff 5c02 5c06 5c08 5c0c 5c10 5c13
5c15 5c19 5c1d 5c21 5c24 5c28 5c2c 5c2e
5c2f 5c34 1 5c38 5c3c 5c40 5c43 5c47
5c4b 5c4f 5c53 5c56 5c5a 5c5e 5c61 5c64
5c69 5c6c 5c6f 5c72 5c73 5c78 5c79 1
5c7b 5c80 5c84 5c88 5c8b 5c90 5c95 5c98
5c9c 5c9d 5ca2 5ca5 5caa 5cab 5cb0 5cb3
5cb8 5cb9 5cbe 5cc1 5cc5 5cc6 5ccb 5cce
5cd3 5cd4 5cd9 5cdc 5ce0 5ce4 5ce7 5cea
5ceb 5ced 5cee 5cf3 5cf4 5cf9 5cfb 5cff
5d02 5d04 5d08 5d0a 5d16 5d18 5d1a 5d1b
5d20 5d24 5d26 5d32 5d34 5d38 5d3c 5d40
5d44 5d48 5d4c 5d50 5d54 5d58 5d64 5d68
5d6d 5d71 5d74 5d75 5d7a 5d7e 5d82 5d85
5d88 5d8c 5d8e 5d92 5d96 5d99 5d9c 5da0
5da2 5da6 5daa 5dad 5daf 5db3 5db7 5dbb
5dbe 5dc2 5dc6 5dc8 5dc9 5dce 1 5dd2
5dd6 5dda 5ddd 5de1 5de5 5de9 5ded 5df0
5df4 5df8 5dfb 5dfe 5e03 5e06 5e09 5e0c
5e0d 5e12 5e13 1 5e15 5e1a 5e1e 5e22
5e25 5e2a 5e2f 5e32 5e36 5e37 5e3c 5e3f
5e44 5e45 5e4a 5e4d 5e52 5e53 5e58 5e5b
5e5f 5e60 5e65 5e68 5e6d 5e6e 5e73 5e76
5e7a 5e7e 5e81 5e84 5e85 5e87 5e88 5e8d
5e8e 5e93 5e95 5e99 5e9c 5e9e 5ea2 5ea4
5eb0 5eb2 5eb4 5eb5 5eba 5ebe 5ec0 5ecc
5ece 5ed2 5ed6 5eda 5ede 5ee2 5ee6 5ef2
5ef6 5efb 5eff 5f02 5f03 5f08 5f0c 5f10
5f13 5f16 5f1a 5f1c 5f20 5f24 5f27 5f2a
5f2e 5f30 5f34 5f38 5f3b 5f3d 5f41 5f45
5f49 5f4c 5f50 5f54 5f56 5f57 5f5c 1
5f60 5f64 5f68 5f6b 5f6f 5f73 5f77 5f7b
5f7e 5f82 5f86 5f89 5f8c 5f91 5f94 5f97
5f9a 5f9b 5fa0 5fa1 1 5fa3 5fa8 5fac
5fb0 5fb3 5fb8 5fbd 5fc0 5fc4 5fc5 5fca
5fcd 5fd2 5fd3 5fd8 5fdb 5fe0 5fe1 5fe6
5fe9 5fed 5fee 5ff3 5ff6 5ffb 5ffc 6001
6004 6008 600c 600f 6012 6013 6015 6016
601b 601c 6021 6023 6027 602a 602c 6030
6032 603e 6040 6042 6043 6048 604c 604e
605a 605c 605e 6062 6065 6069 606d 606e
6073 6077 607b 607f 6082 6083 6085 6088
608b 608c 6091 6095 6099 609c 609d 609f
60a3 60a6 60aa 60ad 60ae 1 60b3 60b8
60bc 60c0 60c3 60c4 60c6 60ca 60cd 60d1
60d4 60d5 1 60da 60df 60e3 60e6 60e7
60ec 60ef 60f3 60f7 60fb 60fd 6101 6104
6106 610a 610d 6111 6115 6118 6119 611b
611e 6121 6122 6127 612b 612f 6133 6136
613a 613c 6140 6143 6147 614a 614b 6150
6153 6157 615a 615b 6160 1 6163 6168
616c 616f 6170 6175 1 6178 617d 6181
6184 6185 618a 618d 1 6190 6195 6199
619c 61a0 61a2 61a6 61a9 61ad 61b2 61b6
61ba 61bf 61c3 61c7 61cb 61ce 61cf 61d1
61d4 61d7 61d8 61dd 61e1 61e5 61e8 61e9
61eb 61ef 61f2 61f6 61f9 61fa 61ff 6203
6208 620b 620f 6210 6215 6218 621d 621e
6223 6226 622b 622c 6231 6234 6239 623a
623f 6242 6247 6248 624d 6250 6254 6255
625a 625d 6262 6263 6268 626c 6270 6272
6276 627a 627d 627e 6280 6283 6286 6287
628c 6290 6295 6298 629d 629e 62a3 62a6
62ab 62ac 62b1 62b4 62b8 62b9 62be 62c1
62c6 62c7 62cc 62cf 62d4 62d5 62da 62dd
62e1 62e2 62e7 62ea 62ef 62f0 62f5 62f8
62fd 62fe 6303 6307 6309 630d 6311 6316
6319 631e 631f 6324 6327 632c 632d 6332
6335 633a 633b 6340 6343 6347 6348 634d
6350 6355 6356 635b 635f 6361 6365 6369
636c 636e 6372 6376 6379 637a 637c 6380
6383 6387 638a 638b 6390 6394 6398 639b
639c 639e 63a2 63a5 63a9 63ac 63ad 1
63b2 63b7 63bb 63bf 63c2 63c3 63c5 63c9
63cc 63d0 63d3 63d4 1 63d9 63de 63e2
63e6 63eb 63f0 63f4 63f8 63fc 63ff 6402
6406 640a 640d 640e 6413 6416 641a 641e
6423 6428 642c 6430 6434 6437 643a 643e
6442 6446 644a 644e 6452 6456 645a 645e
6462 6466 646a 646e 6472 6476 647a 647e
6482 6486 648a 648e 6492 6496 649a 64a6
64aa 64af 64b3 64b6 64b7 64bc 64c0 64c4
64c7 64ca 64ce 64d0 64d4 64d8 64db 64de
64e2 64e4 64e8 64ec 64ef 64f1 64f5 64f9
64fd 6500 6504 6508 650a 650b 6510 1
6514 6518 651c 651f 6523 6527 652b 652f
6532 6536 653a 653d 6540 6545 6548 654b
654e 654f 6554 6555 1 6557 655c 6560
6564 6567 656c 6571 6574 6578 6579 657e
6581 6586 6587 658c 658f 6594 6595 659a
659d 65a1 65a2 65a7 65aa 65af 65b0 65b5
65b8 65bc 65c0 65c3 65c6 65c7 65c9 65ca
65cf 65d0 65d5 65d7 65db 65de 65e0 65e4
65e6 65f2 65f4 65f6 65f7 65fc 6600 6602
660e 6610 6614 6618 661c 6620 6624 6628
662c 6630 6634 6638 663c 6640 6644 6648
664c 6650 6654 6658 665c 6660 6664 6670
6674 6679 667d 6680 6681 6686 668a 668e
6691 6694 6698 669a 669e 66a2 66a5 66a8
66ac 66ae 66b2 66b6 66b9 66bb 66bf 66c3
66c7 66ca 66ce 66d2 66d4 66d5 66da 1
66de 66e2 66e6 66e9 66ed 66f1 66f5 66f9
66fc 6700 6704 6707 670a 670f 6712 6715
6718 6719 671e 671f 1 6721 6726 672a
672e 6731 6736 673b 673e 6742 6743 6748
674b 6750 6751 6756 6759 675e 675f 6764
6767 676b 676c 6771 6774 6779 677a 677f
6782 6786 678a 678d 6790 6791 6793 6794
6799 679a 679f 67a1 67a5 67a8 67aa 67ae
67b0 67bc 67be 67c0 67c1 67c6 67ca 67cc
67d8 67da 67dc 67e0 67e4 67e8 67ea 67ee
67f2 67f5 67f7 67fb 67fe 6802 6805 6806
680b 680e 6812 6816 681a 681e 681f 6821
6824 6825 6827 682a 682d 682e 6833 6837
683b 683f 6843 6844 6846 6849 684a 684c
684f 6850 6852 6855 6858 6859 685e 685f
6861 6865 6869 686d 6871 6872 6874 6877
6878 687a 687d 687e 6880 6882 6886 688a
688e 6891 6895 6899 689d 68a1 68a4 68a8
68a9 68ae 68b0 68b4 68b8 68bc 68c0 68c4
68c7 68ca 68cb 68d0 68d3 68d4 68d6 68d7
68d9 68dc 68dd 68df 68e2 68e5 68e6 68eb
68ef 68f3 68f7 68fb 68ff 6902 6905 6906
690b 690e 690f 6911 6912 6914 6917 6918
691a 691d 6920 6921 1 6926 692b 692f
6935 6937 693b 693e 6942 6946 6949 694c
694d 6952 6956 6958 695c 6963 6967 696b
696e 696f 6974 6978 697c 697f 6983 6987
698a 698d 6992 6995 6998 699b 699c 69a1
69a2 1 69a4 69a9 69ad 69b1 69b4 69b9
69be 69c1 69c5 69c6 69cb 69ce 69d3 69d4
69d9 69dc 69e1 69e2 69e7 69ea 69ee 69f2
69f6 69fa 69fd 69fe 6a00 6a05 6a06 6a08
6a09 6a0e 6a0f 6a14 6a16 6a1a 6a1d 6a21
6a25 6a28 6a2c 6a30 6a33 6a36 6a3b 6a3e
6a41 6a44 6a45 6a4a 6a4b 1 6a4d 6a52
6a56 6a5a 6a5d 6a62 6a67 6a6a 6a6e 6a6f
6a74 6a75 6a7a 6a7c 6a80 6a83 6a87 6a8b
6a8e 6a92 6a96 6a99 6a9d 6a9e 6aa3 6aa5
6aa9 6aac 6ab0 6ab4 6ab8 6abc 6ac8 6acc
6ad0 6ad3 6ad7 6adb 6add 6ae1 6ae5 6ae9
6aec 6af0 6af4 6af6 6af7 6afc 1 6b00
6b04 6b08 6b0b 6b0f 6b13 6b17 6b1b 6b1e
6b22 6b26 6b29 6b2c 6b31 6b34 6b37 6b3a
6b3b 6b40 6b41 1 6b43 6b48 6b4c 6b50
6b53 6b58 6b5d 6b60 6b64 6b65 6b6a 6b6d
6b72 6b73 6b78 6b7b 6b80 6b81 6b86 6b89
6b8d 6b8e 6b93 6b96 6b9b 6b9c 6ba1 6ba4
6ba8 6bac 6baf 6bb2 6bb3 6bb5 6bb6 6bbb
6bbc 6bc1 6bc3 6bc7 6bca 6bcc 6bd0 6bd2
6bde 6be0 6be2 6be3 6be8 6bec 6bee 6bfa
6bfc 6bfe 6c02 6c05 6c09 6c0d 6c10 6c11
6c13 6c17 6c1a 6c1e 6c21 6c22 6c27 6c2b
6c30 6c34 6c38 6c3d 6c41 6c45 6c49 6c4c
6c50 6c51 6c56 6c5a 6c5e 6c62 6c65 6c6a
6c6b 6c70 6c74 6c78 6c7a 6c7e 6c82 6c85
6c86 6c88 6c8c 6c8f 6c93 6c96 6c97 6c9c
6ca0 6ca5 6ca9 6cad 6cb1 6cb4 6cb8 6cb9
6cbe 6cc2 6cc6 6cca 6ccd 6cd2 6cd3 6cd8
6cdc 6ce0 6ce5 6ce9 6ceb 6cef 6cf3 6cf7
6cfa 6cfb 6cfd 6d01 6d04 6d08 6d0b 6d0c
6d11 6d15 6d1a 6d1e 6d22 6d27 6d2b 6d2f
6d32 6d33 6d38 6d3b 6d3f 6d43 6d46 6d4b
6d4c 6d51 6d55 6d59 6d5d 6d60 6d64 6d65
6d6a 6d6e 6d72 6d76 6d79 6d7e 6d7f 6d84
6d88 6d8a 6d8e 6d91 6d95 6d99 6d9c 6da1
6da2 6da7 6dab 6daf 6db2 6db3 6db8 6dbb
6dbf 6dc3 6dc6 6dcb 6dcc 6dd1 6dd5 6dd9
6ddd 6de0 6de4 6de5 6dea 6dee 6df2 6df6
6df9 6dfe 6dff 6e04 6e08 6e0a 6e0e 6e11
6e13 6e17 6e1a 6e1b 6e20 6e23 6e27 6e2b
6e2e 6e33 6e34 6e39 6e3d 6e41 6e46 6e4a
6e4c 6e50 6e54 6e57 6e5c 6e5d 6e62 6e65
6e6a 6e6b 6e70 6e74 6e78 6e7d 6e81 6e85
6e88 6e89 6e8e 6e91 6e95 6e99 6e9c 6ea1
6ea2 6ea7 6eab 6eaf 6eb3 6eb6 6eba 6ebb
6ec0 6ec4 6ec8 6ecc 6ecf 6ed4 6ed5 6eda
6ede 6ee0 6ee4 6ee7 6eeb 6eef 6ef2 6ef7
6ef8 6efd 6f00 6f05 6f06 6f0b 6f0e 6f13
6f14 6f19 6f1c 6f21 6f22 6f27 6f2a 6f2f
6f30 6f35 6f38 6f3d 6f3e 6f43 6f47 6f49
6f4d 6f51 6f54 6f58 6f5b 6f5c 6f61 6f64
6f68 6f6c 6f6f 6f74 6f75 6f7a 6f7d 6f81
6f82 6f87 6f8a 6f8f 6f90 6f95 6f99 6f9b
6f9f 6fa2 6fa4 6fa8 6fac 6faf 6fb1 6fb5
6fb9 6fbc 6fc0 6fc4 6fc7 6fc8 6fca 6fce
6fd1 6fd5 6fd8 6fd9 6fde 6fe2 6fe5 6fe6
6feb 6fee 6ff2 6ff6 6ffa 6ffe 7002 700e
7012 7016 7019 701d 7021 7023 7027 702b
702f 7032 7036 703a 703c 703d 7042 1
7046 704a 704e 7051 7055 7059 705d 7061
7064 7068 706c 706f 7072 7077 707a 707d
7080 7081 7086 7087 1 7089 708e 7092
7096 7099 709e 70a3 70a6 70aa 70ab 70b0
70b3 70b8 70b9 70be 70c1 70c6 70c7 70cc
70cf 70d3 70d4 70d9 70dc 70e1 70e2 70e7
70ea 70ee 70f2 70f5 70f8 70f9 70fb 70fc
7101 7102 7107 7109 710d 7110 7112 7116
7118 7124 7126 7128 7129 712e 7132 7134
7140 7142 7146 714a 714d 7151 7154 7158
715b 715c 7161 7164 7168 716c 7170 7174
7175 7177 717a 717b 717d 7181 7185 7189
718c 7191 7192 7197 719b 719f 71a3 71a6
71ab 71ac 71b1 71b4 71b9 71ba 71bf 71c2
71c6 71c7 71cc 71cf 71d4 71d5 71da 71de
71e0 71e4 71e8 71eb 71ef 71f3 71f6 71f9
71fe 7201 7204 7207 7208 720d 720e 1
7210 7215 7219 721d 7220 7225 722a 722d
7231 7232 7237 723a 723f 7240 7245 7248
724d 724e 7253 7256 725a 725e 7262 7266
7269 726a 726c 7271 7272 7274 7275 727a
727d 7282 7283 7288 728b 7290 7291 7296
7299 729d 729e 72a3 72a6 72ab 72ac 72b1
72b2 72b7 72b9 72bd 72c0 72c4 72c8 72cb
72cf 72d3 72d6 72d9 72de 72e1 72e4 72e7
72e8 72ed 72ee 1 72f0 72f5 72f9 72fd
7300 7305 730a 730d 7311 7312 7317 7318
731d 731f 7323 7326 732a 732e 7331 7335
7339 733c 7340 7344 7345 734a 734c 7350
7354 7357 7359 735d 7360 7364 7367 7368
736d 7370 7374 7378 737c 7380 7384 7390
7394 7398 739b 739f 73a3 73a5 73a9 73ad
73b1 73b4 73b8 73bc 73be 73bf 73c4 1
73c8 73cc 73d0 73d3 73d7 73db 73df 73e3
73e6 73ea 73ee 73f1 73f4 73f9 73fc 73ff
7402 7403 7408 7409 1 740b 7410 7414
7418 741b 7420 7425 7428 742c 742d 7432
7435 743a 743b 7440 7443 7448 7449 744e
7451 7455 7456 745b 745e 7463 7464 7469
746c 7470 7474 7477 747a 747b 747d 747e
7483 7484 7489 748b 748f 7492 7494 7498
749a 74a6 74a8 74aa 74ab 74b0 74b4 74b6
74c2 74c4 74c8 74cc 74cf 74d3 74d6 74da
74dd 74de 74e3 74e6 74ea 74ee 74f1 74f6
74f7 74fc 7500 7504 7508 750b 7510 7511
7516 7519 751e 751f 7524 7527 752b 752c
7531 7534 7539 753a 753f 7543 7545 7549
754d 7550 7554 7558 755b 755e 7563 7566
7569 756c 756d 7572 7573 1 7575 757a
757e 7582 7585 758a 758f 7592 7596 7597
759c 759f 75a4 75a5 75aa 75ad 75b2 75b3
75b8 75bb 75bf 75c3 75c7 75cb 75ce 75cf
75d1 75d6 75d7 75d9 75da 75df 75e2 75e7
75e8 75ed 75f0 75f5 75f6 75fb 75fe 7602
7603 7608 760b 7610 7611 7616 7617 761c
761e 7622 7625 7629 762d 7630 7634 7638
763b 763e 7643 7646 7649 764c 764d 7652
7653 1 7655 765a 765e 7662 7665 766a
766f 7672 7676 7677 767c 767d 7682 7684
7688 768b 768f 7693 7696 769a 769e 76a1
76a5 76a9 76aa 76af 76b1 76b5 76b9 76bc
76be 76c2 76c5 76c9 76cc 76cd 76d2 76d5
76d9 76dd 76e1 76e5 76e9 76f5 76f9 76fd
7700 7704 7708 770a 770e 7712 7716 7719
771d 7721 7723 7724 7729 1 772d 7731
7735 7738 773c 7740 7744 7748 774b 774f
7753 7756 7759 775e 7761 7764 7767 7768
776d 776e 1 7770 7775 7779 777d 7780
7785 778a 778d 7791 7792 7797 779a 779f
77a0 77a5 77a8 77ad 77ae 77b3 77b6 77ba
77bb 77c0 77c3 77c8 77c9 77ce 77d1 77d5
77d9 77dc 77df 77e0 77e2 77e3 77e8 77e9
77ee 77f0 77f4 77f7 77f9 77fd 77ff 780b
780d 780f 7810 7815 7819 781b 7827 7829
782d 7831 7834 7838 783b 783f 7842 7843
7848 784b 784f 7853 7856 785b 785c 7861
7865 7869 786d 7870 7875 7876 787b 787e
7883 7884 7889 788c 7890 7891 7896 7899
789e 789f 78a4 78a8 78aa 78ae 78b2 78b5
78b9 78bd 78c0 78c3 78c8 78cb 78ce 78d1
78d2 78d7 78d8 1 78da 78df 78e3 78e7
78ea 78ef 78f4 78f7 78fb 78fc 7901 7904
7909 790a 790f 7912 7917 7918 791d 7920
7924 7928 792c 7930 7933 7934 7936 793b
793c 793e 793f 7944 7947 794c 794d 7952
7955 795a 795b 7960 7963 7967 7968 796d
7970 7975 7976 797b 797c 7981 7983 7987
798a 798e 7992 7995 7999 799d 79a0 79a3
79a8 79ab 79ae 79b1 79b2 79b7 79b8 1
79ba 79bf 79c3 79c7 79ca 79cf 79d4 79d7
79db 79dc 79e1 79e2 79e7 79e9 79ed 79f0
79f4 79f8 79fb 79ff 7a03 7a06 7a0a 7a0e
7a0f 7a14 7a16 7a1a 7a1e 7a21 7a23 7a27
7a2a 7a2e 7a32 7a35 7a36 7a38 7a3b 7a3e
7a3f 7a44 7a48 7a4c 7a4f 7a50 7a52 7a55
7a58 7a59 1 7a5e 7a63 7a67 7a6b 7a6e
7a73 7a74 7a79 7a7c 7a80 7a84 7a88 7a8b
7a8c 7a8e 7a8f 7a91 7a92 7a97 7a9a 7a9f
7aa0 7aa5 7aa9 7aab 7aaf 7ab2 7ab4 7ab8
7abb 7abf 7ac2 7ac3 7ac8 7acb 7acf 7ad3
7ad7 7adb 7adc 7ade 7ae1 7ae2 7ae4 7ae8
7aec 7aef 7af3 7af7 7afb 7aff 7b02 7b06
7b07 7b0c 7b0e 7b12 7b16 7b1a 7b1d 7b20
7b23 7b27 7b2a 7b2d 7b2e 7b33 7b37 7b38
7b3a 7b3e 7b42 7b46 7b4a 7b4e 7b52 7b5e
7b62 7b66 7b69 7b6d 7b71 7b73 7b77 7b7b
7b7f 7b82 7b86 7b8a 7b8c 7b8d 7b92 1
7b96 7b9a 7b9e 7ba1 7ba5 7ba9 7bad 7bb1
7bb4 7bb8 7bbc 7bbf 7bc2 7bc7 7bca 7bcd
7bd0 7bd1 7bd6 7bd7 1 7bd9 7bde 7be2
7be6 7be9 7bee 7bf3 7bf6 7bfa 7bfb 7c00
7c03 7c08 7c09 7c0e 7c11 7c16 7c17 7c1c
7c1f 7c23 7c24 7c29 7c2c 7c31 7c32 7c37
7c3a 7c3e 7c42 7c45 7c48 7c49 7c4b 7c4c
7c51 7c52 7c57 7c59 7c5d 7c60 7c62 7c66
7c68 7c74 7c76 7c78 7c79 7c7e 7c82 7c84
7c90 7c92 7c96 7c9a 7c9d 7ca1 7ca4 7ca8
7cab 7cac 7cb1 7cb4 7cb8 7cbc 7cbf 7cc3
7cc7 7cca 7ccd 7cd2 7cd5 7cd8 7cdb 7cdc
7ce1 7ce2 1 7ce4 7ce9 7ced 7cf1 7cf4
7cf9 7cfe 7d01 7d05 7d06 7d0b 7d0e 7d13
7d14 7d19 7d1c 7d21 7d22 7d27 7d2a 7d2e
7d32 7d36 7d3a 7d3d 7d3e 7d40 7d45 7d46
7d48 7d49 7d4e 7d51 7d56 7d57 7d5c 7d5f
7d64 7d65 7d6a 7d6d 7d71 7d72 7d77 7d7a
7d7f 7d80 7d85 7d86 7d8b 7d8d 7d91 7d94
7d98 7d9c 7d9f 7da3 7da7 7daa 7dad 7db2
7db5 7db8 7dbb 7dbc 7dc1 7dc2 1 7dc4
7dc9 7dcd 7dd1 7dd4 7dd9 7dde 7de1 7de5
7de6 7deb 7dec 7df1 7df3 7df7 7dfa 7dfe
7e02 7e05 7e09 7e0d 7e10 7e14 7e18 7e19
7e1e 7e20 7e24 7e27 7e2b 7e2f 7e32 7e37
7e38 7e3d 7e40 7e45 7e46 7e4b 7e4e 7e53
7e54 7e59 7e5c 7e61 7e62 7e67 7e6a 7e6e
7e6f 7e74 7e77 7e7c 7e7d 7e82 7e86 7e8a
7e8e 7e91 7e92 7e94 7e98 7e9b 7e9f 7ea2
7ea3 7ea8 7eac 7eb0 7eb3 7eb8 7eb9 7ebe
7ec2 7ec4 7ec8 7ecc 7ecf 7ed4 7ed5 7eda
7ede 7ee0 7ee4 7ee8 7eeb 7eef 7ef3 7ef6
7ef7 7ef9 7efd 7f00 7f04 7f07 7f08 7f0d
7f11 7f17 7f19 7f1d 7f20 7f24 7f28 7f2b
7f2e 7f2f 7f34 7f38 7f3a 7f3e 7f45 7f47
7f4b 7f4e 7f52 7f56 7f59 7f5a 7f5c 7f60
7f63 7f67 7f6a 7f6b 7f70 7f74 7f78 7f7c
7f80 7f81 7f83 7f86 7f87 7f89 7f8d 7f91
7f94 7f98 7f9c 7fa0 7fa4 7fa7 7fab 7fac
7fb1 7fb3 7fb7 7fbb 7fbf 7fc2 7fc5 7fc8
7fcc 7fcf 7fd2 7fd3 7fd8 7fdc 7fdd 7fdf
7fe3 7fe7 7feb 7fef 7ff3 7ff7 8003 8007
800b 800e 8012 8016 8018 801c 8020 8024
8027 802b 802f 8031 8032 8037 1 803b
803f 8043 8046 804a 804e 8052 8056 8059
805d 8061 8064 8067 806c 806f 8072 8075
8076 807b 807c 1 807e 8083 8087 808b
808e 8093 8098 809b 809f 80a0 80a5 80a8
80ad 80ae 80b3 80b6 80bb 80bc 80c1 80c4
80c8 80c9 80ce 80d1 80d6 80d7 80dc 80df
80e3 80e7 80ea 80ed 80ee 80f0 80f1 80f6
80f7 80fc 80fe 8102 8105 8107 810b 810d
8119 811b 811d 811e 8123 8127 8129 8135
8137 813b 813f 8142 8146 8149 814d 8150
8151 8156 8159 815d 8161 8164 8168 816c
816f 8172 8177 817a 817d 8180 8181 8186
8187 1 8189 818e 8192 8196 8199 819e
81a3 81a6 81aa 81ab 81b0 81b3 81b8 81b9
81be 81c1 81c6 81c7 81cc 81cf 81d3 81d7
81db 81df 81e2 81e3 81e5 81ea 81eb 81ed
81ee 81f3 81f6 81fb 81fc 8201 8204 8209
820a 820f 8212 8216 8217 821c 821f 8224
8225 822a 822b 8230 8232 8236 8239 823d
8241 8244 8248 824c 824f 8252 8257 825a
825d 8260 8261 8266 8267 1 8269 826e
8272 8276 8279 827e 8283 8286 828a 828b
8290 8291 8296 8298 829c 829f 82a3 82a7
82aa 82ae 82b2 82b5 82b9 82bd 82be 82c3
82c5 82c9 82cc 82d0 82d4 82d7 82dc 82dd
82e2 82e5 82ea 82eb 82f0 82f3 82f8 82f9
82fe 8301 8306 8307 830c 830f 8313 8314
8319 831c 8321 8322 8327 832a 832f 8330
8335 8339 833d 8341 8344 8347 8348 834d
8351 8353 8357 835e 8360 8364 8367 836b
836f 8372 8376 8377 837c 8380 8382 8386
838a 838d 8391 8395 8398 839d 839e 83a3
83a7 83ab 83af 83b3 83b6 83ba 83be 83c2
83c6 83cb 83d0 83d4 83d8 83dd 83e1 83e5
83e8 83eb 83ef 83f1 83f5 83f9 83fc 83ff
8403 8405 8409 840d 8410 8414 8418 841b
841f 8422 8426 8429 842a 842f 8432 8436
843c 843e 8442 8445 8449 844d 8450 8451
8453 8456 8459 845a 845f 8463 8467 846a
846b 846d 8471 8474 8478 847b 847c 1
8481 8486 848a 848e 8491 8492 8494 8498
849b 849f 84a2 84a3 1 84a8 84ad 84b1
84b5 84b8 84b9 84bb 84bf 84c2 84c6 84c9
84ca 84cf 84d3 84d6 84d7 84dc 1 84df
84e4 1 84e7 84ec 84f0 84f4 84f9 84fd
84fe 8502 8506 850b 8510 8514 8518 851d
8521 8525 8528 852b 852f 8531 8535 8539
853c 853f 8543 8545 8549 854d 8550 8554
8558 855b 855f 8562 8566 8569 856a 856f
8572 8576 857a 857f 8581 8585 8589 858c
8590 8594 8596 859a 859e 85a2 85a5 85a9
85ad 85af 85b0 85b5 1 85b9 85bd 85c1
85c4 85c8 85cc 85d0 85d4 85d7 85db 85df
85e2 85e5 85ea 85ed 85f0 85f3 85f4 85f9
85fa 1 85fc 8601 8605 8609 860c 8611
8616 8619 861d 861e 8623 8626 862b 862c
8631 8634 8639 863a 863f 8642 8646 8647
864c 864f 8654 8655 865a 865d 8661 8665
8668 866b 866c 866e 866f 8674 8675 867a
867c 8680 8683 8685 8689 868b 8697 8699
869b 869c 86a1 86a5 86a7 86b3 86b5 86b9
86bf 86c1 86c5 86c9 86ce 86d0 86d4 86d8
86db 86df 86e3 86e5 86e9 86ed 86f1 86f4
86f8 86fc 86fe 86ff 8704 1 8708 870c
8710 8713 8717 871b 871f 8723 8726 872a
872e 8731 8734 8739 873c 873f 8742 8743
8748 8749 1 874b 8750 8754 8758 875b
8760 8765 8768 876c 876d 8772 8775 877a
877b 8780 8783 8788 8789 878e 8791 8795
8796 879b 879e 87a3 87a4 87a9 87ac 87b0
87b4 87b7 87ba 87bb 87bd 87be 87c3 87c4
87c9 87cb 87cf 87d2 87d4 87d8 87da 87e6
87e8 87ea 87eb 87f0 87f4 87f6 8802 8804
8806 880a 880e 8811 8813 8817 881a 881e
8822 8826 882a 882e 8832 8836 883a 883d
883e 8840 8843 8846 8847 884c 8850 8854
8857 885a 885b 885d 8860 8865 8866 886b
886f 8873 8874 8879 887d 8881 8884 8888
888a 888e 8892 8896 8899 889a 889c 889d
889f 88a2 88a5 88a6 88ab 88af 88b3 88b7
88bb 88bf 88c3 88c7 88cb 88cf 88db 88df
88e3 88e6 88ea 88ee 88f0 88f4 88f8 88fc
88ff 8903 8907 8909 890a 890f 1 8913
8917 891b 891e 8922 8926 892a 892e 8931
8935 8939 893c 893f 8944 8947 894a 894d
894e 8953 8954 1 8956 895b 895f 8963
8966 896b 8970 8973 8977 8978 897d 8980
8985 8986 898b 898e 8993 8994 8999 899c
89a0 89a1 89a6 89a9 89ae 89af 89b4 89b7
89bb 89bf 89c2 89c5 89c6 89c8 89c9 89ce
89cf 89d4 89d6 89da 89dd 89df 89e3 89e5
89f1 89f3 89f5 89f6 89fb 89ff 8a01 8a0d
8a0f 8a13 8a17 8a1a 8a1b 8a1d 8a20 8a23
8a24 8a29 8a2d 8a31 8a36 8a38 8a3c 8a40
8a43 8a47 8a4b 8a4d 8a51 8a55 8a59 8a5c
8a60 8a64 8a66 8a67 8a6c 1 8a70 8a74
8a78 8a7b 8a7f 8a83 8a87 8a8b 8a8e 8a92
8a96 8a99 8a9c 8aa1 8aa4 8aa7 8aaa 8aab
8ab0 8ab1 1 8ab3 8ab8 8abc 8ac0 8ac3
8ac8 8acd 8ad0 8ad4 8ad5 8ada 8add 8ae2
8ae3 8ae8 8aeb 8af0 8af1 8af6 8af9 8afd
8afe 8b03 8b06 8b0b 8b0c 8b11 8b14 8b18
8b1c 8b1f 8b22 8b23 8b25 8b26 8b2b 8b2c
8b31 8b33 8b37 8b3a 8b3c 8b40 8b42 8b4e
8b50 8b52 8b53 8b58 8b5c 8b5e 8b6a 8b6c
8b70 8b74 8b77 8b7b 8b7f 8b82 8b85 8b8a
8b8d 8b90 8b93 8b94 8b99 8b9a 1 8b9c
8ba1 8ba5 8ba9 8bac 8bb1 8bb6 8bb9 8bbd
8bbe 8bc3 8bc6 8bcb 8bcc 8bd1 8bd4 8bd9
8bda 8bdf 8be2 8be6 8bea 8bee 8bf2 8bf5
8bf6 8bf8 8bfd 8bfe 8c00 8c01 8c06 8c09
8c0e 8c0f 8c14 8c17 8c1c 8c1d 8c22 8c25
8c29 8c2a 8c2f 8c32 8c37 8c38 8c3d 8c3e
8c43 8c45 8c49 8c4c 8c50 8c54 8c57 8c5b
8c5f 8c62 8c65 8c6a 8c6d 8c70 8c73 8c74
8c79 8c7a 1 8c7c 8c81 8c85 8c89 8c8c
8c91 8c96 8c99 8c9d 8c9e 8ca3 8ca4 8ca9
8cab 8caf 8cb2 8cb6 8cba 8cbd 8cc1 8cc5
8cc8 8ccc 8cd0 8cd1 8cd6 8cd8 8cdc 8cdf
8ce1 8ce5 8ce8 8cea 8cee 8cf2 8cf5 8cf9
8cfd 8d01 8d05 8d09 8d0d 8d11 8d15 8d19
8d1d 8d21 8d25 8d29 8d2d 8d31 8d35 8d39
8d3d 8d41 8d45 8d49 8d4d 8d51 8d55 8d59
8d5d 8d61 8d65 8d69 8d6d 8d71 8d75 8d78
8d79 8d7b 8d7e 8d81 8d84 8d87 8d88 8d8a
8d8e 8d92 8d95 8d98 8d99 8d9e 8da2 8da6
8dab 8dad 8db1 8db5 8db8 8dbc 8dc0 8dc2
8dc6 8dca 8dce 8dd1 8dd5 8dd9 8ddb 8ddc
8de1 1 8de5 8de9 8ded 8df0 8df4 8df8
8dfc 8e00 8e03 8e07 8e0b 8e0e 8e11 8e16
8e19 8e1c 8e1f 8e20 8e25 8e26 1 8e28
8e2d 8e31 8e35 8e38 8e3d 8e42 8e45 8e49
8e4a 8e4f 8e52 8e57 8e58 8e5d 8e60 8e65
8e66 8e6b 8e6e 8e72 8e73 8e78 8e7b 8e80
8e81 8e86 8e89 8e8d 8e91 8e94 8e97 8e98
8e9a 8e9b 8ea0 8ea1 8ea6 8ea8 8eac 8eaf
8eb1 8eb5 8eb7 8ec3 8ec5 8ec7 8ec8 8ecd
8ed1 8ed3 8edf 8ee1 8ee5 8ee9 8eec 8ef0
8ef3 8ef4 8ef9 8efd 8f01 8f05 8f08 8f0c
8f0e 8f12 8f15 8f19 8f1d 8f20 8f24 8f28
8f2b 8f2e 8f33 8f36 8f39 8f3c 8f3d 8f42
8f43 1 8f45 8f4a 8f4e 8f52 8f55 8f5a
8f5f 8f62 8f66 8f67 8f6c 8f6f 8f74 8f75
8f7a 8f7d 8f82 8f83 8f88 8f8b 8f8f 8f93
8f97 8f98 8f9a 8f9f 8fa0 8fa2 8fa3 8fa8
8fab 8fb0 8fb1 8fb6 8fb9 8fbe 8fbf 8fc4
8fc7 8fcb 8fcc 8fd1 8fd4 8fd9 8fda 8fdf
8fe0 8fe5 8fe7 8feb 8fee 8ff2 8ff6 8ff9
8ffd 9001 9004 9007 900c 900f 9012 9015
9016 901b 901c 1 901e 9023 9027 902b
902e 9033 9038 903b 903f 9040 9045 9046
904b 904d 9051 9054 9058 905c 905f 9063
9067 906b 906c 9071 9075 9077 907b 907f
9082 9085 9086 9088 908b 9090 9091 9096
9099 909d 90a1 90a4 90a7 90a8 90aa 90ad
90b2 90b3 90b8 1 90bb 90c0 90c4 90c8
90cc 90d0 90d4 90e0 90e4 90e9 90ed 90f0
90f1 90f6 90fa 90fe 9101 9104 9108 910a
910e 9112 9115 9118 911c 911e 9122 9126
9129 912b 912f 9133 9137 913a 913e 9142
9144 9145 914a 1 914e 9152 9156 9159
915d 9161 9165 9169 916c 9170 9174 9177
917a 917f 9182 9185 9188 9189 918e 918f
1 9191 9196 919a 919e 91a1 91a6 91ab
91ae 91b2 91b3 91b8 91bb 91c0 91c1 91c6
91c9 91ce 91cf 91d4 91d7 91db 91dc 91e1
91e4 91e9 91ea 91ef 91f2 91f6 91fa 91fd
9200 9201 9203 9204 9209 920a 920f 9211
9215 9218 921a 921e 9220 922c 922e 9230
9231 9236 923a 923c 9248 924a 924c 9250
9254 9257 925b 9261 9263 9267 926b 926e
926f 9271 9275 9278 927c 927f 9280 9285
9289 928d 9291 9295 9299 929d 929f 92a3
92a6 92aa 92ae 92b2 92b6 92ba 92be 92c2
92c6 92ca 92ce 92d2 92d6 92da 92de 92e2
92e6 92ea 92ee 92f2 92f6 92fa 92fe 9302
9306 930a 930e 9312 9316 931a 931e 9321
9324 9327 932a 932d 932e 9330 9334 9338
933b 933e 933f 9344 9348 934c 934f 9352
9353 9358 935c 9360 9362 9366 9369 936c
936d 9372 9376 937c 937e 9382 9386 9389
938d 9391 9394 9398 939b 939c 939e 939f
93a4 93a8 93ae 93b0 93b4 93b7 93b9 93bd
93c1 93c4 93cc 93ce 93cf 93d2 93d4 93d8
93df 93e3 93e7 93ec 93ee 93f2 93f6 93f9
93fd 9401 9403 9407 940b 940f 9412 9416
941a 941c 941d 9422 1 9426 942a 942e
9431 9435 9439 943d 9441 9444 9448 944c
944f 9452 9457 945a 945d 9460 9461 9466
9467 1 9469 946e 9472 9476 9479 947e
9483 9486 948a 948b 9490 9493 9498 9499
949e 94a1 94a6 94a7 94ac 94af 94b3 94b4
94b9 94bc 94c1 94c2 94c7 94ca 94ce 94d2
94d5 94d8 94d9 94db 94dc 94e1 94e2 94e7
94e9 94ed 94f0 94f2 94f6 94f8 9504 9506
9508 9509 950e 9512 9514 9520 9522 9526
952a 952d 9531 9534 9535 953a 953d 9541
9544 9547 9548 954d 1 9550 9555 9559
955c 955f 9560 9565 9569 956d 9570 9571
9573 9576 9579 957a 1 957f 9584 1
9587 958c 9590 9594 9597 959b 959f 95a2
95a5 95aa 95ad 95b0 95b3 95b4 95b9 95ba
1 95bc 95c1 95c5 95c9 95cc 95d1 95d6
95d9 95dd 95de 95e3 95e6 95eb 95ec 95f1
95f4 95f9 95fa 95ff 9602 9606 960a 960e
960f 9611 9616 9617 9619 961a 961f 9622
9627 9628 962d 9630 9635 9636 963b 963e
9642 9643 9648 964b 9650 9651 9656 9657
965c 965e 9662 9665 9669 966d 9670 9674
9678 967b 967e 9683 9686 9689 968c 968d
9692 9693 1 9695 969a 969e 96a2 96a5
96aa 96af 96b2 96b6 96b7 96bc 96bd 96c2
96c4 96c8 96cb 96cf 96d3 96d6 96da 96de
96e2 96e3 96e8 96ea 96ee 96f1 96f5 96f8
96fb 96fc 9701 9705 970a 970e 9712 9717
971b 971f 9724 9728 972c 9730 9735 9739
973a 973e 9741 9745 9749 974d 9751 9755
9759 975d 9761 9765 9769 976d 9772 9777
977b 977f 9783 9788 978c 9790 9793 9796
979a 979c 97a0 97a4 97a7 97aa 97ae 97b0
97b4 97b8 97bb 97bf 97c3 97c6 97ca 97cd
97d1 97d4 97d5 97da 97dd 97e1 97e7 97e9
97ed 97f0 97f4 97f7 97f8 97fd 9800 9804
9808 980b 980f 9813 9814 9816 9819 981c
981d 1 9822 9827 982b 982f 9833 9834
9836 9839 983a 983c 983f 9842 9843 1
9848 984d 9851 9855 9859 985b 985f 9862
9866 986a 986d 9871 9875 9876 9878 987b
987e 987f 9884 9888 988b 988e 988f 9894
9898 989c 98a0 98a4 98a8 98ac 98b0 98b4
98b8 98bc 98c0 98c4 98c8 98cc 98d0 98dc
98e0 98e5 98e9 98ec 98ed 98f2 98f6 98fa
98fd 9900 9904 9906 990a 990e 9911 9914
9918 991a 991e 9922 9925 9927 992b 992f
9933 9936 993a 993e 9940 9941 9946 1
994a 994e 9952 9955 9959 995d 9961 9965
9968 996c 9970 9973 9976 997b 997e 9981
9984 9985 998a 998b 1 998d 9992 9996
999a 999d 99a2 99a7 99aa 99ae 99af 99b4
99b7 99bc 99bd 99c2 99c5 99ca 99cb 99d0
99d3 99d7 99d8 99dd 99e0 99e5 99e6 99eb
99ee 99f2 99f6 99f9 99fc 99fd 99ff 9a00
9a05 9a06 9a0b 9a0d 9a11 9a14 9a16 9a1a
9a1c 9a28 9a2a 9a2c 9a2d 9a32 9a36 9a38
9a44 9a46 9a48 9a4c 9a4f 9a53 9a58 9a5c
9a60 9a65 9a69 9a6d 9a72 9a76 9a7a 9a7f
9a83 9a87 9a8c 9a90 9a94 9a99 9a9d 9aa1
9aa5 9aa9 9aad 9ab0 9ab4 9ab6 9aba 9abd
9ac1 9ac4 9ac7 9ac8 9acd 9ad1 9ad4 9ad5
9ada 1 9add 9ae2 9ae6 9aea 9aee 9af2
9af6 9afa 9afe 9b02 9b06 9b12 9b16 9b1b
9b1f 9b22 9b23 9b28 9b2c 9b30 9b33 9b36
9b3a 9b3c 9b40 9b44 9b47 9b4a 9b4e 9b50
9b54 9b58 9b5b 9b5d 9b61 9b65 9b69 9b6c
9b70 9b74 9b76 9b77 9b7c 1 9b80 9b84
9b88 9b8b 9b8f 9b93 9b97 9b9b 9b9e 9ba2
9ba6 9ba9 9bac 9bb1 9bb4 9bb7 9bba 9bbb
9bc0 9bc1 1 9bc3 9bc8 9bcc 9bd0 9bd3
9bd8 9bdd 9be0 9be4 9be5 9bea 9bed 9bf2
9bf3 9bf8 9bfb 9c00 9c01 9c06 9c09 9c0d
9c0e 9c13 9c16 9c1b 9c1c 9c21 9c24 9c28
9c2c 9c2f 9c32 9c33 9c35 9c36 9c3b 9c3c
9c41 9c43 9c47 9c4a 9c4c 9c50 9c52 9c5e
9c60 9c62 9c63 9c68 9c6c 9c6e 9c7a 9c7c
9c7e 9c82 9c85 9c89 9c8c 9c8d 9c92 9c95
9c99 9c9c 9c9d 9ca2 9ca5 9ca9 9cad 9cb1
9cb4 9cb9 9cba 9cbf 9cc2 9cc5 9cc6 9cc8
9ccc 9cce 9cd2 9cd5 9cd9 9cdd 9ce1 9ce4
9ce8 9ce9 9cee 9cf1 9cf4 9cf5 9cf7 9cfb
9cfd 9d01 9d04 9d08 9d0b 9d0c 9d11 9d14
9d18 9d1c 9d20 9d23 9d27 9d28 9d2d 9d30
9d33 9d34 9d36 9d3a 9d3c 9d40 9d43 9d47
9d4a 9d4b 9d50 9d53 9d57 9d5a 9d5b 9d60
9d63 9d67 9d6b 9d6f 9d72 9d77 9d78 9d7d
9d80 9d83 9d84 9d86 9d8a 9d8c 9d90 9d93
9d97 9d9b 9d9f 9da2 9da6 9da7 9dac 9daf
9db2 9db3 9db5 9db9 9dbb 9dbf 9dc2 9dc6
9dc9 9dca 9dcf 9dd2 9dd6 9dda 9dde 9de1
9de5 9de6 9deb 9dee 9df1 9df2 9df4 9df8
9dfa 9dfe 9e01 9e05 9e08 9e09 9e0e 9e11
9e15 9e18 9e19 9e1e 9e21 9e25 9e29 9e2d
9e30 9e35 9e36 9e3b 9e3e 9e41 9e42 9e44
9e48 9e4a 9e4e 9e51 9e55 9e59 9e5d 9e60
9e64 9e65 9e6a 9e6d 9e70 9e71 9e73 9e77
9e79 9e7d 9e80 9e84 9e87 9e88 9e8d 9e90
9e94 9e97 9e98 9e9d 9ea0 9ea4 9ea8 9eac
9eaf 9eb4 9eb5 9eba 9ebd 9ec0 9ec1 9ec3
9ec7 9ec9 9ecd 9ed0 9ed4 9ed8 9edc 9edf
9ee3 9ee4 9ee9 9eec 9eef 9ef0 9ef2 9ef6
9ef8 9efc 9eff 9f03 9f07 9f0a 9f0d 9f0e
9f13 9f17 9f1b 9f1f 9f23 9f25 9f29 9f30
9f34 9f38 9f3d 9f3f 9f43 9f47 9f4a 9f4e
9f52 9f54 9f58 9f5c 9f60 9f63 9f67 9f6b
9f6d 9f6e 9f73 1 9f77 9f7b 9f7f 9f82
9f86 9f8a 9f8e 9f92 9f95 9f99 9f9d 9fa0
9fa3 9fa8 9fab 9fae 9fb1 9fb2 9fb7 9fb8
1 9fba 9fbf 9fc3 9fc7 9fca 9fcf 9fd4
9fd7 9fdb 9fdc 9fe1 9fe4 9fe9 9fea 9fef
9ff2 9ff7 9ff8 9ffd a000 a004 a005 a00a
a00d a012 a013 a018 a01b a01f a023 a026
a029 a02a a02c a02d a032 a033 a038 a03a
a03e a041 a043 a047 a049 a055 a057 a059
a05a a05f a063 a065 a071 a073 a077 a07a
a07d a07e a083 a087 a08b a08f a093 a097
a09b a09f a0a3 a0a7 a0ab a0af a0b3 a0b7
a0bb a0bf a0cb a0cf a0d4 a0d8 a0db a0dc
a0e1 a0e5 a0e9 a0ec a0ef a0f3 a0f5 a0f9
a0fd a100 a103 a107 a109 a10d a111 a114
a116 a11a a11e a122 a125 a129 a12d a12f
a130 a135 1 a139 a13d a141 a144 a148
a14c a150 a154 a157 a15b a15f a162 a165
a16a a16d a170 a173 a174 a179 a17a 1
a17c a181 a185 a189 a18c a191 a196 a199
a19d a19e a1a3 a1a6 a1ab a1ac a1b1 a1b4
a1b9 a1ba a1bf a1c2 a1c6 a1c7 a1cc a1cf
a1d4 a1d5 a1da a1dd a1e1 a1e5 a1e8 a1eb
a1ec a1ee a1ef a1f4 a1f5 a1fa a1fc a200
a203 a205 a209 a20b a217 a219 a21b a21c
a221 a225 a227 a233 a235 a237 a23b a23e
a240 a244 a247 a24b a24e a24f a254 a257
a25b a25f a262 a263 a265 a268 a26b a26c
a271 a275 a279 a27d a281 a285 a289 a28d
a291 a295 a299 a29d a2a1 a2a5 a2a9 a2b5
a2b9 a2bd a2c0 a2c4 a2c8 a2ca a2ce a2d2
a2d6 a2d9 a2dd a2e1 a2e3 a2e4 a2e9 1
a2ed a2f1 a2f5 a2f8 a2fc a300 a304 a308
a30b a30f a313 a316 a319 a31e a321 a324
a327 a328 a32d a32e 1 a330 a335 a339
a33d a340 a345 a34a a34d a351 a352 a357
a35a a35f a360 a365 a368 a36d a36e a373
a376 a37a a37b a380 a383 a388 a389 a38e
a391 a395 a399 a39c a39f a3a0 a3a2 a3a3
a3a8 a3a9 a3ae a3b0 a3b4 a3b7 a3b9 a3bd
a3bf a3cb a3cd a3cf a3d0 a3d5 a3d9 a3db
a3e7 a3e9 a3eb a3ef a3f2 a3f6 a3f8 a3fa
a3fe a402 a405 a407 a40b a40e a412 a416
a41a a41e a422 a426 a42a a42e a432 a436
a43a a43e a442 a446 a44a a44e a452 a456
a45a a466 a46a a46e a471 a475 a479 a47b
a47f a483 a487 a48a a48e a492 a494 a495
a49a 1 a49e a4a2 a4a6 a4a9 a4ad a4b1
a4b5 a4b9 a4bc a4c0 a4c4 a4c7 a4ca a4cf
a4d2 a4d5 a4d8 a4d9 a4de a4df 1 a4e1
a4e6 a4ea a4ee a4f1 a4f6 a4fb a4fe a502
a503 a508 a50b a510 a511 a516 a519 a51e
a51f a524 a527 a52b a52c a531 a534 a539
a53a a53f a542 a546 a54a a54d a550 a551
a553 a554 a559 a55a a55f a561 a565 a568
a56a a56e a570 a57c a57e a580 a581 a586
a58a a58c a598 a59a a59e a5a2 a5a5 a5a6
a5a8 a5ac a5af a5b3 a5b6 a5b7 a5bc a5c0
a5c4 a5c9 a5ce a5d2 a5d6 a5da a5dd a5e0
a5e4 a5e8 a5ec a5f0 a5f4 a5f8 a5fc a600
a604 a608 a60c a610 a61c a620 a625 a629
a62c a62d a632 a636 a63a a63d a640 a644
a646 a64a a64e a651 a654 a658 a65a a65e
a662 a665 a667 a66b a66f a673 a676 a67a
a67e a680 a681 a686 1 a68a a68e a692
a695 a699 a69d a6a1 a6a5 a6a8 a6ac a6b0
a6b3 a6b6 a6bb a6be a6c1 a6c4 a6c5 a6ca
a6cb 1 a6cd a6d2 a6d6 a6da a6dd a6e2
a6e7 a6ea a6ee a6ef a6f4 a6f7 a6fc a6fd
a702 a705 a70a a70b a710 a713 a717 a718
a71d a720 a725 a726 a72b a72e a732 a736
a739 a73c a73d a73f a740 a745 a746 a74b
a74d a751 a754 a756 a75a a75c a768 a76a
a76c a76d a772 a776 a778 a784 a786 a78a
a78e a791 a795 a798 a79c a79f a7a0 a7a5
a7a8 a7ac a7b0 a7b4 a7b8 a7bc a7c0 a7c4
a7c8 a7cc a7d0 a7d4 a7d8 a7dc a7e0 a7e4
a7e8 a7ec a7f0 a7fc a800 a805 a809 a80c
a80d a812 a816 a81a a81d a820 a824 a826
a82a a82e a831 a834 a838 a83a a83e a842
a845 a847 a84b a84f a853 a856 a85a a85e
a860 a861 a866 1 a86a a86e a872 a875
a879 a87d a881 a885 a888 a88c a890 a893
a896 a89b a89e a8a1 a8a4 a8a5 a8aa a8ab
1 a8ad a8b2 a8b6 a8ba a8bd a8c2 a8c7
a8ca a8ce a8cf a8d4 a8d7 a8dc a8dd a8e2
a8e5 a8ea a8eb a8f0 a8f3 a8f7 a8f8 a8fd
a900 a905 a906 a90b a90e a912 a916 a919
a91c a91d a91f a920 a925 a926 a92b a92d
a931 a934 a936 a93a a93c a948 a94a a94c
a94d a952 a956 a958 a964 a966 a96a a96e
a971 a975 a978 a97c a97f a980 a985 a988
a98c a990 a994 a998 a99c a9a0 a9ac a9b0
a9b5 a9b9 a9bc a9bd a9c2 a9c6 a9ca a9cd
a9d0 a9d4 a9d6 a9da a9de a9e1 a9e4 a9e8
a9ea a9ee a9f2 a9f5 a9f7 a9fb a9ff aa03
aa06 aa0a aa0e aa10 aa11 aa16 1 aa1a
aa1e aa22 aa25 aa29 aa2d aa31 aa35 aa38
aa3c aa40 aa43 aa46 aa4b aa4e aa51 aa54
aa55 aa5a aa5b 1 aa5d aa62 aa66 aa6a
aa6d aa72 aa77 aa7a aa7e aa7f aa84 aa87
aa8c aa8d aa92 aa95 aa9a aa9b aaa0 aaa3
aaa7 aaa8 aaad aab0 aab5 aab6 aabb aabe
aac2 aac6 aac9 aacc aacd aacf aad0 aad5
aad6 aadb aadd aae1 aae4 aae6 aaea aaec
aaf8 aafa aafc aafd ab02 ab06 ab08 ab14
ab16 ab18 ab1c ab1f ab21 ab25 ab28 ab2c
ab30 ab34 ab38 ab3c ab40 ab44 ab48 ab4c
ab50 ab54 ab58 ab5c ab60 ab64 ab68 ab6c
ab70 ab74 ab78 ab7c ab80 ab84 ab88 ab8c
ab90 ab94 ab98 ab9c aba0 aba4 aba8 abac
abb0 abb4 abb8 abbc abc0 abc4 abc8 abcc
abd0 abd4 abd8 abdc abe0 abe4 abe8 abec
abf0 abf4 abf8 abfc ac00 ac04 ac08 ac0c
ac10 ac14 ac18 ac1c ac20 ac24 ac28 ac2c
ac30 ac34 ac38 ac3c ac40 ac44 ac48 ac4c
ac50 ac54 ac58 ac5c ac60 ac64 ac68 ac6c
ac70 ac74 ac78 ac7c ac80 ac84 ac88 ac8c
ac90 ac94 ac98 ac9c aca0 aca4 aca8 acac
acb0 acb4 acb8 acbc acc0 acc4 acc8 accc
acd0 acd4 acd8 acdc ace0 ace4 ace8 acec
acf0 acf4 acf8 acfc ad00 ad04 ad08 ad0c
ad10 ad14 ad18 ad1c ad20 ad24 ad28 ad2c
ad30 ad34 ad38 ad3c ad40 ad44 ad48 ad4c
ad50 ad54 ad58 ad5c ad60 ad64 ad68 ad6c
ad70 ad74 ad78 ad7c ad80 ad84 ad88 ad8c
ad90 ad94 ad98 ad9c ada0 ada4 ada8 adac
adb0 adb4 adb8 adbc adc0 adc4 adc8 adcc
add0 add4 add8 addc ade0 ade4 ade8 adec
adf0 adf4 adf8 adfc ae00 ae04 ae08 ae0c
ae10 ae14 ae18 ae1c ae20 ae24 ae28 ae2c
ae30 ae34 ae38 ae3c ae40 ae44 ae48 ae4c
ae50 ae54 ae58 ae5c ae68 ae6d ae71 ae75
ae79 ae7c ae80 ae84 ae87 ae8a ae8f ae92
ae95 ae98 ae99 ae9e ae9f 1 aea1 aea6
aeaa aeae aeb1 aeb6 aebb aebe aec2 aec3
aec8 aec9 aece aed0 aed4 aed7 aedb aedf
aee3 aee5 aee9 aeec aeef aef0 aef5 aef9
aefd af01 af05 af09 af0d af11 af15 af19
af1d af21 af25 af29 af2d af31 af35 af39
af3d af41 af45 af49 af4d af51 af55 af59
af5d af61 af65 af69 af6d af71 af75 af79
af7d af81 af85 af89 af8d af91 af95 af99
af9d afa1 afa5 afa9 afad afb1 afb5 afb9
afbd afc1 afc5 afc9 afcd afd1 afd5 afd9
afdd afe1 afe5 afe9 afed aff1 aff5 aff9
affd b001 b005 b009 b00d b011 b015 b019
b01d b021 b025 b029 b02d b031 b035 b039
b03d b041 b045 b049 b04d b051 b055 b059
b05d b061 b065 b069 b06d b071 b075 b079
b07d b081 b085 b089 b08d b091 b095 b099
b09d b0a1 b0a5 b0a9 b0ad b0b1 b0b5 b0b9
b0bd b0c1 b0c5 b0c9 b0cd b0d1 b0d5 b0d9
b0dd b0e1 b0e5 b0e9 b0ed b0f1 b0f5 b0f9
b0fd b101 b105 b109 b10d b111 b115 b119
b11d b121 b125 b129 b12d b131 b135 b139
b13d b141 b145 b149 b14d b151 b155 b159
b15d b161 b165 b169 b16d b171 b175 b179
b17d b181 b185 b189 b18d b191 b195 b199
b19d b1a1 b1a5 b1a9 b1ad b1b1 b1b5 b1b9
b1bd b1c1 b1c5 b1c9 b1cd b1d1 b1d5 b1d9
b1dd b1e1 b1e5 b1e9 b1ed b1f1 b1f5 b1f9
b1fd b201 b205 b209 b20d b211 b215 b219
b21d b221 b225 b229 b22d b231 b235 b239
b23d b241 b245 b249 b24d b251 b255 b259
b25d b261 b265 b269 b26d b271 b275 b279
b27d b281 b285 b289 b28d b291 b295 b299
b29d b2a1 b2a5 b2a9 b2ad b2b1 b2b5 b2b9
b2bd b2c1 b2c5 b2c9 b2cd b2d1 b2d5 b2d9
b2dd b2e1 b2e5 b2e9 b2ed b2f1 b2f5 b2f9
b2fd b301 b305 b309 b30d b311 b315 b319
b31d b321 b325 b329 b32d b331 b335 b339
b33d b341 b345 b349 b34d b351 b355 b359
b35d b361 b365 b369 b36d b371 b375 b379
b37d b381 b385 b389 b38d b391 b395 b399
b39d b3a1 b3a5 b3a9 b3ad b3b1 b3bd b3c2
b3c6 b3ca b3ce b3d1 b3d5 b3d9 b3dc b3df
b3e4 b3e7 b3ea b3ed b3ee b3f3 b3f4 1
b3f6 b3fb b3ff b403 b406 b40b b410 b413
b417 b418 b41d b41e b423 b425 b429 b42c
b430 b434 b438 b43a b43e b442 b447 b44c
b450 b454 b458 b45b b45e b462 b466 b46a
b46e b472 b476 b47a b47e b482 b48e b492
b497 b49b b49e b49f b4a4 b4a8 b4ac b4af
b4b2 b4b6 b4b8 b4bc b4c0 b4c3 b4c6 b4ca
b4cc b4d0 b4d4 b4d7 b4d9 b4dd b4e1 b4e5
b4e8 b4ec b4f0 b4f2 b4f3 b4f8 1 b4fc
b500 b504 b507 b50b b50f b513 b517 b51a
b51e b522 b525 b528 b52d b530 b533 b536
b537 b53c b53d 1 b53f b544 b548 b54c
b54f b554 b559 b55c b560 b561 b566 b569
b56e b56f b574 b577 b57c b57d b582 b585
b589 b58a b58f b592 b597 b598 b59d b5a0
b5a4 b5a8 b5ab b5ae b5af b5b1 b5b2 b5b7
b5b8 b5bd b5bf b5c3 b5c6 b5c8 b5cc b5ce
b5da b5dc b5de b5df b5e4 b5e8 b5ea b5f6
b5f8 b5fc b600 b604 b608 b60c b610 b614
b618 b61c b620 b624 b628 b62c b630 b634
b638 b63c b640 b644 b648 b64c b658 b65c
b661 b665 b668 b669 b66e b672 b676 b679
b67c b680 b682 b686 b68a b68d b690 b694
b696 b69a b69e b6a1 b6a3 b6a7 b6ab b6af
b6b2 b6b6 b6ba b6bc b6bd b6c2 1 b6c6
b6ca b6ce b6d1 b6d5 b6d9 b6dd b6e1 b6e4
b6e8 b6ec b6ef b6f2 b6f7 b6fa b6fd b700
b701 b706 b707 1 b709 b70e b712 b716
b719 b71e b723 b726 b72a b72b b730 b733
b738 b739 b73e b741 b746 b747 b74c b74f
b753 b754 b759 b75c b761 b762 b767 b76a
b76e b772 b775 b778 b779 b77b b77c b781
b782 b787 b789 b78d b790 b792 b796 b798
b7a4 b7a6 b7a8 b7a9 b7ae b7b2 b7b4 b7c0
b7c2 b7c6 b7ca b7ce b7d2 b7d6 b7da b7de
b7e2 b7e6 b7ea b7ee b7f2 b7f6 b7fa b7fe
b802 b806 b80a b80e b812 b816 b81a b81e
b822 b826 b82a b82e b832 b836 b83a b83e
b842 b846 b84a b84e b852 b856 b85a b85e
b862 b866 b86a b86e b872 b876 b87a b87e
b882 b886 b88a b88e b892 b896 b89a b89e
b8a2 b8a6 b8aa b8ae b8b2 b8b6 b8ba b8be
b8c2 b8c6 b8ca b8ce b8d2 b8d6 b8da b8de
b8e2 b8e6 b8ea b8ee b8f2 b8f6 b8fa b8fe
b902 b906 b90a b90e b912 b916 b91a b91e
b922 b926 b92a b92e b932 b936 b93a b93e
b942 b946 b94a b94e b952 b956 b95a b95e
b962 b966 b96a b96e b972 b976 b97a b97e
b982 b986 b98a b98e b992 b996 b99a b99e
b9a2 b9a6 b9aa b9ae b9b2 b9b6 b9ba b9be
b9c2 b9c6 b9ca b9ce b9d2 b9d6 b9da b9de
b9e2 b9e6 b9ea b9ee b9f2 b9f6 b9fa b9fe
ba02 ba06 ba0a ba0e ba12 ba16 ba1a ba1e
ba22 ba26 ba2a ba2e ba32 ba36 ba3a ba3e
ba42 ba46 ba4a ba4e ba52 ba56 ba5a ba5e
ba62 ba66 ba6a ba6e ba72 ba76 ba7a ba7e
ba82 ba86 ba8a ba8e ba92 ba96 ba9a ba9e
baa2 baa6 baaa baae bab2 bab6 baba babe
bac2 bac6 baca bace bad2 bad6 bada bade
bae2 bae6 baea baee baf2 baf6 bafa bafe
bb02 bb06 bb0a bb0e bb12 bb16 bb1a bb1e
bb22 bb26 bb2a bb2e bb32 bb36 bb3a bb3e
bb42 bb46 bb4a bb4e bb52 bb56 bb5a bb5e
bb62 bb66 bb6a bb6e bb72 bb76 bb7a bb7e
bb82 bb86 bb8a bb8e bb92 bb96 bb9a bb9e
bba2 bba6 bbaa bbae bbb2 bbb6 bbba bbbe
bbc2 bbc6 bbca bbce bbd2 bbd6 bbda bbde
bbe2 bbe6 bbea bbee bbf2 bbf6 bbfa bbfe
bc02 bc06 bc0a bc0e bc12 bc16 bc1a bc1e
bc22 bc26 bc2a bc2e bc32 bc36 bc3a bc3e
bc42 bc46 bc4a bc4e bc52 bc56 bc5a bc5e
bc62 bc66 bc6a bc6e bc72 bc76 bc7a bc7e
bc82 bc86 bc8a bc8e bc92 bc96 bc9a bc9e
bca2 bca6 bcaa bcae bcb2 bcb6 bcba bcbe
bcc2 bcc6 bcca bcce bcd2 bcd6 bcda bcde
bce2 bce6 bcea bcee bcf2 bcf6 bcfa bcfe
bd02 bd06 bd0a bd0e bd12 bd16 bd1a bd1e
bd22 bd26 bd2a bd2e bd32 bd36 bd3a bd3e
bd42 bd46 bd4a bd4e bd52 bd56 bd5a bd5e
bd62 bd66 bd6a bd6e bd72 bd76 bd7a bd7e
bd82 bd86 bd8a bd8e bd92 bd96 bd9a bd9e
bda2 bda6 bdaa bdae bdb2 bdb6 bdba bdbe
bdc2 bdc6 bdca bdce bdd2 bdd6 bdda bdde
bde2 bde6 bdea bdee bdf2 bdf6 bdfa bdfe
be02 be06 be0a be0e be12 be16 be1a be1e
be22 be26 be2a be2e be32 be36 be3a be3e
be42 be46 be4a be4e be52 be56 be5a be5e
be62 be66 be6a be6e be72 be76 be7a be7e
be82 be86 be8a be8e be92 be96 be9a be9e
bea2 bea6 beb2 beb7 bebb bebf bec3 bec6
beca bece bed1 bed4 bed9 bedc bedf bee2
bee3 bee8 bee9 1 beeb bef0 bef4 bef8
befb bf00 bf05 bf08 bf0c bf0d bf12 bf13
bf18 bf1a bf1e bf21 bf25 bf29 bf2d bf2f
bf33 bf37 bf3a bf3c bf40 bf44 bf47 bf49
bf4d bf51 bf54 bf58 bf5c bf5f bf63 bf67
bf6a bf6d bf72 bf75 bf78 bf7b bf7c bf81
bf82 1 bf84 bf89 bf8d bf91 bf94 bf99
bf9e bfa1 bfa5 bfa6 bfab bfac bfb1 bfb5
bfb9 bfbc bfc1 bfc6 bfc9 bfcd bfd1 bfd4
bfd5 bfda bfdd bfe2 bfe3 bfe8 bfeb bfef
bff3 bff6 bff7 bffc bffd c002 c004 c008
c00b c00f c013 c017 c01b c01f c023 c027
c02b c02f c03b c040 c044 c048 c04c c050
c052 c053 c058 1 c05c c060 c064 c067
c06b c06f c073 c077 c07a c07e c082 c085
c088 c08d c090 c093 c096 c097 c09c c09d
1 c09f c0a4 c0a8 c0ac c0af c0b4 c0b9
c0bc c0c0 c0c1 c0c6 c0c7 c0cc c0d0 c0d4
c0d7 c0dc c0e1 c0e4 c0e8 c0e9 c0ee c0f1
c0f6 c0f7 c0fc c0ff c103 c107 c10a c10d
c10e c110 c111 c116 c117 c11c c11e c122
c125 c129 c12d c131 c135 c139 c13d c141
c14d c152 c156 c15a c15e c162 c164 c168
c16a c176 c178 c17a c17b c180 c184 c186
c192 c196 c198 c199 c1a2 
373d
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 c :3 6 e :3 6 10 :3 6
10 :3 6 11 :3 6 17 :3 6 10 :3 6
11 :3 6 10 :3 6 11 :3 6 f :3 6
f :3 6 10 :3 6 d :3 6 e :3 6
12 :2 6 1 3 a 13 a :2 1
4 d 16 15 :2 d :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 c
15 14 :2 c :2 4 b 14 13 :2 b
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 10 19 18 :2 10 :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 11 1a
19 :2 11 :2 4 d 16 15 :2 d :2 4
e 17 16 :2 e :2 4 b 14 13
:2 b :2 4 :3 10 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 14 1d 1c :2 14 :2 4
15 1e 1d :2 15 :2 4 :3 e :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 :2 e 1d e
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 c 1b c :2 4 :2 d 1c d
:2 4 :2 10 1f 10 :2 4 :2 14 23 14
:2 4 :2 a 19 a :2 4 :2 f 1e f
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 b 1a b :2 4 :2 f 19 f
:2 4 :2 13 1d 13 :2 4 :2 c 1b c
:2 4 :2 10 1f 10 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 16 25 16
:2 4 :2 16 25 16 :2 4 :2 b 1a b
:2 4 d 16 15 :2 d :2 4 :2 10 1f
10 :2 4 :2 11 20 11 :2 4 :2 12 21
12 :2 4 9 12 11 :2 9 :2 4 c
15 14 :2 c :2 4 10 19 18 :2 10
:2 4 :2 11 20 11 :2 4 :2 17 26 17
:2 4 17 1c 1b :2 17 :2 4 18 1d
1c :2 18 :2 4 11 1a 19 :2 11 :2 4
12 1b 1a :2 12 :2 4 16 1f 1e
:2 16 :2 4 b 14 13 :2 b :2 4 :2 f
1e f :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 6 1e 6 :2 4 :2 7
1f 7 :2 4 :2 a 22 a :2 4 :2 d
25 d :2 4 :2 8 20 8 :2 4 a
13 12 :2 a :2 4 :2 e 26 e :2 4
:3 d :2 4 :3 13 :2 4 :3 8 :2 4 :3 6 :2 4
:3 9 :2 4 :3 c :2 4 :3 c 4 7 b
14 :3 b :2 7 e 0 :2 7 11 f
10 1d e 18 e 1c a :6 7
e 0 :2 7 a :2 c 12 c 15
c 12 c 15 c 15 c 15
f 13 fffa :6 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 17 1a :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 2c 2f :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2d 30 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
33 :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 31 :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 2f :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 2e :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 34
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 34 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 40 :2 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 24 27 :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 26 29 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 28 2b :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 29 2c :2 6a b e :2 6a 13
16 1f 27 :2 1f 3a :2 16 :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
28 2b :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 29 2c :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
28 2b :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 29 2c :2 6a b
e :2 6a 13 16 1f 27 :2 1f 32
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 32 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 33 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
30 :2 16 :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 26 29 :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2a 2d :2 6a 32 35 :2 6a :2 7 49
:2 4 7 :2 11 23 :2 2d 39 3c 4b
4e 4f :2 4b :2 23 :3 7 :2 d 12 1e
5b 5e :2 1e :2 7 52 :3 4 14 :2 4
14 :2 4 13 :2 4 f :2 4 e :2 4
13 :2 4 14 :2 4 13 :2 4 14 :2 4
12 :2 4 10 :2 4 e :2 4 14 :2 4
12 :2 4 f :2 4 12 :2 4 e :2 4
e :2 4 11 :2 4 11 :2 4 10 :2 4
13 :2 4 13 :2 4 14 4 8 11
1c :2 8 22 1f :2 2b :2 1f 7 :4 46
45 44 :2 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b5 :2 85 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 57 :2 4 :4 9 8 7 :4 1f 1e
1d :2 7 :4 39 38 37 :2 7 :4 53 52
51 :2 7 f 18 24 :2 f 2a 27
:2 33 :2 27 e :2 7 :4 c b a 25
2e 3a :2 25 3f 3d :2 48 :2 3d 24
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 85 88 91 99 :2 a2 :2 91 b3
:2 88 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 :2 d
58 :3 a :2 15 2b :2 34 44 :2 a 7
59 :4 f e d :4 29 28 27 :3 d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 85
88 91 99 :2 a2 :2 91 b3 :2 88 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 61 64 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 44 :2 a 3e 59 :2 7
49 :2 4 7 10 1b :2 7 1e 20
:2 1e 26 2f 37 :2 26 3a 3c :2 3a
:2 7 42 4b 53 :2 42 56 58 :2 56
:2 7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5e 61 :2 21 6e 71 :2 21 75 78
:2 21 82 85 8e 96 :2 9f :2 8e b0
:2 85 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5e 61 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 5a
:2 4 :4 9 8 :2 7 1a 7 24 7
1a 7 :4 4 8 11 1c :2 8 22
1f :2 2b :2 1f 7 :4 46 45 44 :2 7
:4 14 13 12 :2 7 11 1c 21 33
3e 43 :2 f :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 31 b :2 14 1f 1d :2 28 :2 1d a
3d 46 4f :2 3d 52 54 :2 52 3c
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 85 88 91 99 :2 a2 :2 91 bf
:2 88 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 :2 d
58 :3 a :2 15 2b :2 34 50 :2 a 57
:3 7 e 7 31 :2 4 :4 9 8 7
:4 27 26 25 :2 7 11 23 35 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
8a 8d :2 27 95 98 :2 27 a4 a7
ae b7 ba :2 a7 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :4 40 :3 4 12 :2 4
13 :2 1c 28 2f 38 40 :2 2f 44
:2 4d :2 28 27 5c :2 13 :2 4 e 15
1e 26 :2 15 2a :2 33 :2 e :2 4 d
:2 16 22 29 32 3e :2 29 42 :2 4b
:2 22 21 5a :2 d :2 4 12 19 22
2e :2 19 32 :2 3b :2 12 4 7 10
1c :2 7 21 1f :2 2a :2 1f 7 15
7 4 37 a 13 1f :2 a 24
22 :2 2d :2 22 7 15 7 39 37
a 13 1f :2 a 24 22 :2 2d :2 22
a 18 a 3d a 18 a :4 7
:4 4 7 10 18 :2 7 1b 1d :2 1b
7 15 7 11 21 f 10 1d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 1f a 13
1f :2 a 22 24 :2 22 14 24 12
13 20 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 67 6a :2 2a 77 7a :2 2a
7e 81 :2 2a 8d 90 :2 2a 98 9b
:2 2a a7 aa b1 ba bd :2 aa :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 26
d :2 18 1f 2d :2 d 32 34 :2 32
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 a5 :2 94 ba :2 8b
:2 27 c2 c5 :2 27 cd d0 :2 27 d5
d8 :2 27 e5 e8 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2c :2 35
49 57 :2 d 36 :2 a 26 :3 7 17
20 29 31 :2 20 :2 17 7 a 13
21 :2 a 24 26 :2 24 a 14 20
29 31 :2 20 :2 14 a d 16 1e
:2 d 21 23 :2 21 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 27 :2 10 5b :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2e :2 37
47 :2 d 25 :3 a 1a :2 23 a 28
:3 7 14 7 a 13 20 :2 a 23
26 :2 23 a 16 a 28 d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 61 64 :2 24
71 74 :2 24 78 7b :2 24 85 88
91 99 :2 a2 :2 91 b3 :2 88 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
2b :2 34 44 :2 a :5 7 1a 29 37
3f 4a 54 25 :2 1a 7 a 13
1e :2 a 23 21 :2 2c :2 21 d 16
27 :2 d 2a 2c :2 2a d 20 :2 29
d 2e :2 a d :2 17 29 :2 33 3f
43 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 61 64 :2 24 71 74 :2 24
78 7b :2 24 85 88 91 99 :2 91
ab :2 88 :2 24 b3 b6 :2 24 be c1
:2 24 c6 c9 :2 24 d5 d8 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 32 43 :2 29 47 54 :2 a 40
:2 7 a 13 24 :2 a 27 2a :2 27
30 39 4a :2 30 4d 50 :2 4d :2 a
d :2 17 29 :2 33 3f 43 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
85 88 91 99 :2 91 ab :2 88 :2 24
b3 b6 :2 24 be c1 :2 24 c6 c9
:2 24 d5 d8 :2 24 :2 d 59 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 :2 d 58 :3 a :2 15 29 32 43
:2 29 47 54 :2 a 52 :2 7 a 13
21 :2 a 26 24 :2 2f :2 24 d 1b
24 2c :2 1b :2 d 30 33 :2 30 10
12 1b 12 1b 12 10 :3 12 15
16 23 fffa 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6a 6d :2 2d 7a 7d
:2 2d 81 84 :2 2d 90 93 :2 2d 9b
9e :2 2d aa ad b4 bd c0 :2 ad
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:4 35 10 :2 12 14 12 14 12 14
12 1b 1d 12 1b 1d 12 14
12 14 25 27 10 :7 12 15 1d
20 28 16 18 25 14 16 23
25 fffa 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6a 6d :2 2d 7a 7d :2 2d
81 84 :2 2d 90 93 :2 2d 9b 9e
:2 2d aa ad b4 bd c0 :2 ad :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :7 a
e :2 17 23 20 :2 2c :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 88
8b 94 9c :2 a5 :2 94 b8 :2 8b :2 27
c0 c3 :2 27 cb ce :2 27 d3 d6
:2 27 e0 e3 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3c :2 a 7 3c d 16
24 :2 d 29 27 :2 32 :2 27 d :2 f
d :2 f 12 13 20 fffa d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 3f e :2 17 23 20
:2 2c :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 88 8b 94 9c :2 a5
:2 94 b8 :2 8b :2 27 c0 c3 :2 27 cb
ce :2 27 d3 d6 :2 27 e0 e3 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 52 :2 d 3c :2 a
12 1d :2 12 1f f 18 f 18
f d :3 f 12 13 20 11 1e
fffa d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8d 90 :2 2a 98 9b :2 2a
a7 aa b1 ba bd :2 aa :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 3f e
:2 17 23 20 :2 2c :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 88 8b
94 9c :2 a5 :2 94 b8 :2 8b :2 27 c0
c3 :2 27 cb ce :2 27 d3 d6 :2 27
e3 e6 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
:2 10 5b :3 d :2 18 2c :2 35 47 55
:2 d 3c :2 a :4 e :2 d 1d :2 26 :2 d
17 26 :2 17 d 24 :2 a 3f 3c
d :2 17 29 :2 33 3f 43 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 24 bb be :2 24 c6 c9 :2 24 ce
d1 :2 24 de e1 :2 24 :2 d 59 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 61
64 :2 24 :2 d 58 :3 a :2 15 29 :2 32
42 50 :2 a :4 7 a 13 1f :2 a
25 22 :2 2e :2 22 d f 1a 25
:3 f 18 23 2e f 18 23 2e
d :5 f 12 13 21 fffa d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 3e e :2 17 22 20
:2 2b :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 88 8b 94 9c :2 a5
:2 94 b8 :2 8b :2 27 c0 c3 :2 27 cb
ce :2 27 d3 d6 :2 27 df e2 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 51 :2 d a 3b
11 :2 1a 25 23 :2 2e :2 23 :2 10 17
21 24 :2 10 27 29 :2 27 31 3a
4d :2 31 50 52 :2 50 58 13 21
:2 58 26 24 2f 42 :2 26 :2 24 :2 31
30 :2 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8b 8e 97 9f :2 a8 :2 97
be :2 8e :2 2a c6 c9 :2 2a d1 d4
:2 2a d9 dc :2 2a e5 e8 :2 2a :2 13
5f :2 10 13 :2 1d 2f :2 39 45 48
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a :2 13 5e :3 10 :2 1b
2f :2 38 4d 57 :2 10 46 :2 d 10
19 27 :2 10 2c 2a 35 48 :2 2c
:2 2a 1a 25 32 3a 41 55 60
77 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6d 70 :2 30 7d 80 :2 30
84 87 :2 30 93 96 :2 30 9e a1
:2 30 ad b0 b7 c0 c3 :2 b0 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :4 4b
:2 d 3e 3b :2 a 3e :2 7 1f :2 4
7 10 18 :2 7 1b 1d :2 1b a
13 1f :2 a 24 22 :2 2d :2 22 :4 42
41 :2 a 59 d 1a :2 59 1d 1f
:2 1d :2 a d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 85 88 91 99 :2 a2 :2 91
bd :2 88 :2 24 c5 c8 :2 24 d0 d3
:2 24 d8 db :2 24 e8 eb :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 :2 32 4c 12 :2 a 21 :2 7 a
13 1e :2 a 24 21 :2 2d :2 21 d
f 18 f 18 d :2 f 12 13
20 fffa d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 67 6a :2 2a 77 7a :2 2a
7e 81 :2 2a 8d 90 :2 2a 98 9b
:2 2a a7 aa b1 ba bd :2 aa :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 41
e :2 17 22 20 :2 2b :2 20 d 10
12 15 25 32 fffa 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6a 6d :2 2d
7a 7d :2 2d 81 84 :2 2d 90 93
:2 2d 9b 9e :2 2d aa ad b4 bd
c0 :2 ad :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :3 3b 11 :2 1a 25 23 :2 2e
:2 23 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8b 8e 97 9f :2 a8 :2 97
b9 :2 8e :2 2a c1 c4 :2 2a cc cf
:2 2a d4 d7 :2 2a e4 e7 :2 2a :2 13
5f :2 10 13 :2 1d 2f :2 39 45 48
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a :2 13 5e :3 10 :2 1b
2f :2 38 48 56 :2 10 3e :2 d 3b
:2 a 41 :2 7 1f :2 4 7 10 1c
:2 7 1f 21 :2 1f 27 30 38 :2 27
3b 3e :2 3b :3 7 11 7 42 :2 4
7 10 1b :2 7 20 1e :2 29 :2 1e
:4 b :2 a 18 :2 a 19 a 22 a
18 :2 a 19 a :5 7 13 7 3d
a e 10 :2 e a 19 :2 a 18
29 35 42 4b 54 :2 42 58 61
69 :2 58 22 2b 37 :2 22 3b 44
4f :2 3b 53 20 2b :2 53 2f 38
46 :2 2f 4a 53 5e :2 4a 22 2b
37 :2 22 3b 43 4d :2 18 a d
16 22 :2 d 27 25 :2 30 :2 25 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 88
8b 94 9c :2 a5 :2 94 b6 :2 8b :2 27
:2 10 5b :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2e :2 37 47 :2 d a 3f 10
19 25 :2 10 28 2b :2 28 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 88 8b
94 9c :2 94 a9 :2 8b :2 27 b1 b4
:2 27 bc bf :2 27 c4 c7 :2 27 d4
d7 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 64 67 :2 27 :2 10
5b :3 d :2 18 2c 35 41 :2 2c 45
53 :2 d 2d 3f :2 a 12 a 19
a d 16 1e :2 d 21 23 :2 21
d 17 20 28 :2 17 2b 2d 36
42 :2 2d :2 17 d 25 :2 a :4 7 b
14 1c :2 b 1f 21 :2 1f a 29
32 3a :2 29 3d 40 :2 3d 28 :2 a
e 17 1f :2 e 22 24 :2 22 d
2b 34 3c :2 2b 3f 41 :2 3f 2a
:3 d 18 d a 44 10 19 21
:2 10 24 26 :2 24 d 18 d a
28 44 11 1a 22 :2 11 25 27
:2 25 10 2e 37 3f :2 2e 42 44
:2 42 2d :2 10 d 18 d a 47
44 10 19 21 :2 10 24 26 :2 24
d 18 d 28 44 :2 a 45 :2 7
:4 4 7 10 1c :2 7 21 1f :2 2a
:2 1f 7 19 :2 7 16 :2 7 17 :2 7
14 1b 28 2b :2 14 :2 7 17 7
a 13 20 :2 a 23 25 :2 23 a
:3 16 :2 a 1c a 27 14 24 12
13 20 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 7
e :2 17 22 20 :2 2b :2 20 d 10
19 21 :2 10 24 26 :2 24 :2 13 18
19 26 17 25 :2 17 25 2e fffa
13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 5e
61 62 :2 5e :2 35 :3 19 :2 1f 24 30
6e 71 :2 30 7e 81 :2 30 85 88
:2 30 94 97 :2 30 9f a2 :2 30 ae
b1 b8 c1 c4 :2 b1 :2 30 :2 19 65
:2 16 :2 13 :4 1f :2 13 10 :4 28 :2 d 3b
d 1f d :4 a :4 7 a 19 1c
:2 19 d 16 1a d 12 13 1e
11 19 fffa d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 1e d 18 25 30 3d 48 55
60 6d 78 85 8b 8f 16 1c
1f 35 3b 43 :2 12 23 27 38
13 16 23 11 15 22 25 fffa
d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 1e e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 27 c1 c4
:2 27 cc cf :2 27 d4 d7 :2 27 e1
e4 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 47 52 :2 d
3b :2 a d 16 1e :2 d 21 23
:2 21 d 17 d 25 d 17 d
:4 a 19 d :8 f d :8 f d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 1e 7
1e d 14 22 25 :2 d 28 2a
:2 28 14 21 d 17 d 17 d
17 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :4 2e 1e :2 7 16 10
11 f 10 1d :2 e 1c a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 59 5a :2 55 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 3a 16
10 11 f 10 1d :2 e 1c a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 3a
16 10 1d :2 e 1c a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
59 5a :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :4 3a :3 4 :3 17
4 7 10 18 :2 7 1b 1d :2 1b
23 2c 38 :2 23 3e 3b :2 47 :2 3b
:2 7 5b d 19 :2 5b 1f 1c :2 28
:2 1c :2 7 :4 b :2 a 17 a 20 :2 7
3d :2 4 7 10 1c :2 7 1f 21
:2 1f 7 15 :2 1e 7 23 :2 4 :4 8
7 :4 20 1f :2 7 :4 39 38 :2 7 :4 10
f e :3 7 14 7 25 :3 4 c
:2 4 f 4 7 10 18 :2 7 1b
1d :2 1b a 13 1f :2 a 24 22
:2 2d :2 22 a 12 1e 21 :2 12 2a
2d :2 12 11 14 :2 12 11 14 :2 12
11 14 :2 12 32 35 :2 12 3f 42
:2 12 a 7 3d d 16 22 :2 d
25 27 :2 25 a 12 11 14 :2 12
11 14 :2 12 43 46 :2 12 53 56
:2 12 11 14 :2 12 2c 2f :2 12 38
3b :2 12 11 14 :2 12 a 2a 3d
a 12 11 14 :2 12 11 14 :2 12
11 14 :2 12 35 38 :2 12 41 44
:2 12 a :4 7 1f a 13 1f :2 a
25 22 :2 2e :2 22 42 d 19 :2 42
1f 1c :2 28 :2 1c :2 a 41 d 19
:2 41 1f 1c :2 28 :2 1c :3 a 12 1c
:3 a :2 13 1f a :4 e :2 d 15 1f
:3 d :2 16 22 d 1c 17 23 15
16 17 19 25 27 15 1f 10
15 2a 10 12 1f 22 14 17
14 17 25 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 22 1c 17 19 15
27 17 19 15 27 16 18 1f
21 14 1b 1d 26 2d 2f 38
3a 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5b 5f 60 :2 5b :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 92 95 :2 2d
9d a0 :2 2d ac af b6 bf c2
:2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10
d :4 22 d 19 d :4 a 3c :2 7
:4 b :2 a 12 1b 22 :2 1b 2a :2 12
2d 2f :2 2d 3a 41 4a 51 :2 4a
59 :2 41 5d :2 3a 64 66 :2 3a :2 16
71 78 81 88 :2 81 90 :2 78 94
:2 71 :2 11 :2 a f :2 a 10 14 12
18 :2 12 a 10 19 1f 26 2f
31 33 :2 2f 36 :2 1f :2 19 3b :2 10
3e 41 :2 3e 17 20 26 2d 36
38 3a :2 36 3d :2 26 :2 20 42 :2 17
45 48 :2 45 :4 10 4b :3 d 12 14
16 :2 12 d 18 e a d 11
:3 f 10 :2 1a 2c :2 36 42 45 54
58 59 :2 54 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8a 8d 96 9e :2 a7 :2 96 b8
:2 8d :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 58 59 :2 54 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 :2 10
5c :3 d :2 18 2e :2 37 47 :2 d 15
:2 a 14 1c :2 12 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 1e :2 7 a 13 1f :2 a 24
22 :2 2d :2 22 a 10 :2 a 15 :2 a
15 1d 20 :2 15 :2 a 15 1d 20
:2 15 a 7 3d d 16 22 :2 d
27 25 :2 30 :2 25 a 10 :2 a 12
17 1a :2 12 :2 a 12 17 1a :2 12
:2 a 15 a 45 3d d 16 22
:2 d 27 25 :2 30 :2 25 d 15 :2 d
18 d :4 11 :2 10 1b 23 26 :2 1b
:2 10 1b 23 26 :2 1b :2 10 1b 23
26 :2 1b 10 26 :3 d 18 20 23
:2 18 d :4 11 :2 10 1b 23 26 :2 1b
:2 10 1b 23 26 :2 1b :2 10 1b 23
26 :2 1b 10 24 :2 d 44 :4 11 :2 10
18 1d 20 :2 18 :2 10 1b 10 29
10 18 1d 20 :2 18 17 1a :2 18
:2 10 1b 10 :4 14 :2 13 1e 26 29
:2 1e :2 13 1e 26 29 :2 1e :2 13 1e
26 29 :2 1e 13 29 :3 10 1b 23
26 :2 1b 17 1a :2 1b 17 1a :2 1b
17 1a :2 1b 17 1a :2 1b 17 1a
:2 1b 10 :4 d :4 11 :2 10 1b 23 26
:2 1b 4f 52 :2 1b 5a 5d :2 1b 10
24 :2 d :4 a :4 7 a 13 1f :2 a
25 22 :2 2e :2 22 :4 e d 17 21
15 16 23 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:3 26 11 :2 1a 25 23 :2 2e :2 23 :2 10
18 21 28 :2 21 31 :2 18 :2 10 18
1d 20 :2 18 :2 10 1b 23 26 :2 1b
17 1a :2 1b 2f 32 :2 1b 39 3c
:2 1b 10 3e 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8d 90 99 a1 :2 aa
:2 99 bb :2 90 :2 2a c3 c6 :2 2a ce
d1 :2 2a d6 d9 :2 2a e4 e7 :2 2a
:2 13 60 :2 10 13 :2 1d 2f :2 39 45
48 57 5b 5c :2 57 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a :2 13 5f :3 10
:2 1b 2f :2 38 48 54 :2 10 :4 d 26
:2 a :4 e d 17 21 15 16 23
:2 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 92 95 :2 2d 9d a0 :2 2d ac
af b6 bf c2 :2 af :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :3 25 11 :2 1a
25 23 :2 2e :2 23 :2 10 18 1d 20
:2 18 :2 10 1b 23 26 :2 1b 17 1a
:2 1b 2f 32 :2 1b 39 3c :2 1b 10
3e 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8d 90 99 a1 :2 aa :2 99 bb
:2 90 :2 2a c3 c6 :2 2a ce d1 :2 2a
d6 d9 :2 2a e3 e6 :2 2a :2 13 60
:2 10 13 :2 1d 2f :2 39 45 48 57
5b 5c :2 57 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a :2 13 5f :3 10 :2 1b 2f
:2 38 48 53 :2 10 :4 d 25 :2 a :4 e
d 17 21 15 16 23 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 25 11 :2 1a 25 23
:2 2e :2 23 :2 10 18 1d 20 :2 18 :2 10
1b 23 26 :2 1b 17 1a :2 1b 2f
32 :2 1b 39 3c :2 1b 10 3e 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8d
90 99 a1 :2 aa :2 99 bb :2 90 :2 2a
c3 c6 :2 2a ce d1 :2 2a d6 d9
:2 2a e3 e6 :2 2a :2 13 60 :2 10 13
:2 1d 2f :2 39 45 48 57 5b 5c
:2 57 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a :2 13 5f :3 10 :2 1b 2f :2 38 48
53 :2 10 :4 d 25 :2 a d 16 27
:2 d 2a 2c :2 2a 32 3b 4c :2 32
4f 52 :2 4f :3 d 18 20 23 :2 18
3b 3e 46 4f 61 :2 46 :2 3e :2 18
65 68 :2 18 d 56 :2 a 3e :2 7
:4 b :2 a 15 1e 25 :2 1e 33 :2 15
:2 a f :2 a 10 14 12 1c :2 12
a d 1a :2 23 2c 30 34 35
36 :2 34 39 :2 1a d 17 21 15
16 23 :2 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 1c
11 :2 1a 26 23 :2 2f :2 23 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8d
90 99 a1 :2 aa :2 99 bb :2 90 :2 2a
c3 c6 :2 2a ce d1 :2 2a d6 d9
:2 2a e3 e6 :2 2a :2 13 60 :2 10 13
:2 1d 2f :2 39 45 48 57 5b 5c
:2 57 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a :2 13 5f :3 10 :2 1b 2f :2 38 48
53 :2 10 3f :3 d 18 20 23 :2 18
14 17 :2 18 14 17 :2 18 14 17
:2 18 31 34 :2 18 3b 3e :2 18 d
10 19 25 :2 10 2a 28 :2 33 :2 28
10 1b 23 26 :2 1b 10 43 10
1b 23 26 :2 1b 10 :4 d 10 19
25 :2 10 2a 28 :2 33 :2 28 :2 10 43
:2 d a f 11 13 :2 f a 1c
e a 22 :2 7 a 13 1f :2 a
25 22 :2 2e :2 22 a 15 1e 25
:2 1e 34 :2 15 :2 a f :2 a 10 14
12 1c :2 12 a d 1a :2 23 2c
30 34 35 36 :2 34 39 :2 1a d
17 21 15 16 23 :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :3 1c 11 :2 1a 26 23 :2 2f
:2 23 10 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8d 90 99 a1 :2 aa :2 99
bb :2 90 :2 2a c3 c6 :2 2a ce d1
:2 2a d6 d9 :2 2a e3 e6 :2 2a :2 13
60 :2 10 13 :2 1d 2f :2 39 45 48
57 5b 5c :2 57 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a :2 13 5f :3 10 :2 1b
2f :2 38 48 53 :2 10 3f :3 d 18
20 23 :2 18 14 17 :2 18 14 17
:2 18 14 17 :2 18 31 34 :2 18 3b
3e :2 18 14 17 :2 18 d a f
11 13 :2 f a 1c e a 3e
:3 7 f 14 17 :2 f 7 :5 4 c
11 14 :2 c :2 4 9 :2 11 :2 4 d
16 :2 7 a e :2 a :2 13 1f a
14 a :2 13 1f a :4 7 b :2 14
20 1d :2 29 :2 1d :3 a 39 :2 7 a
13 1b :2 a 1e 20 :2 1e 26 2f
3b :2 26 41 3e :2 4a :2 3e :2 a 62
d 19 :2 62 1f 1c :2 28 :2 1c :2 a
42 d 19 :2 42 1f 1c :2 28 :2 1c
:4 3c 3b :2 42 41 :3 a f :3 a 10
19 :2 a d 11 :2 d :2 16 22 d
17 d :2 16 22 d :4 a e :2 17
22 20 :2 2b :2 20 d 10 16 :3 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 3b 12 d 3b
10 16 :3 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :7 a
51 :3 7 16 :2 7 17 7 a 13
1b :2 a 1e 20 :2 1e d 14 20
23 :2 d 26 28 :2 26 d :3 1c :2 d
19 d 2c 10 1e 27 2f :2 1e
:2 10 33 36 :2 33 1a 20 38 18
19 26 17 25 17 :2 13 :2 1c 28
13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 62 63 :2 5e
:2 35 :3 19 :2 1f 24 30 6f 72 :2 30
7f 82 :2 30 86 89 :2 30 95 98
:2 30 a0 a3 :2 30 af b2 b9 c2
c5 :2 b2 :2 30 :2 19 66 :2 16 :2 13 :4 1f
:2 13 10 :3 38 13 1c 28 :2 13 2b
2d :2 2b 16 1c :3 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 61 65 66 :2 61 :2 38
:3 1c :2 22 27 33 72 75 :2 33 82
85 :2 33 89 8c :2 33 98 9b :2 33
a3 a6 :2 33 b2 b5 bc c5 c8
:2 b5 :2 33 :2 1c 69 :2 19 :2 16 :4 22 :2 16
13 :3 2f 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 90 93 9c a4 :2 ad :2 9c
ce :2 93 :2 2d d6 d9 :2 2d e1 e4
:2 2d e9 ec :2 2d f5 f8 :2 2d :2 16
63 :2 13 16 :2 20 32 :2 3c 48 4b
5a 5e 5f :2 5a :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d :2 16 62 :3 13 :2 1e
32 :2 3b 5b 1b :2 13 2f :2 10 38
:2 d :5 a 16 22 2f 3d 48 52
5e 1b 28 36 43 51 1b 28
34 3e 46 4f 57 1b 27 33
40 4b 56 1b 25 30 3c 48
51 5c :2 48 60 1b 21 27 :2 16
a d 16 19 :2 16 10 16 :3 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 1b 10 1b 19
:2 24 :2 19 10 1c :2 25 10 2e :2 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8a 8d 96 9e :2 96 a9 :2 8d :2 27
b1 b4 :2 27 bc bf :2 27 c4 c7
:2 27 d3 d6 :2 27 :2 10 5d :2 d 10
:2 1a 2c :2 36 42 45 54 58 59
:2 54 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 :2 10 5c :3 d :2 18 2c 36 43
:2 d a 1b 11 18 24 27 :2 11
2a 2c :2 2a 10 36 3d 4b 4e
:2 36 51 53 :2 51 35 :2 10 17 24
39 46 53 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :4 58 1b :4 a 22 d
16 21 :2 d 27 24 :2 30 :2 24 d
1b :2 d 1c d 44 :3 a 16 22
2f 3d 48 52 5e 1b 28 36
43 51 1b 28 34 3e 46 4f
57 1b 27 33 40 4b 56 1b
25 30 3c 48 4b 4e 54 5a
:2 16 a d 16 18 :2 16 d 16
1c 1e :2 16 d a 1a 10 19
1b :2 19 :2 d 1d 1a :2 a d 15
13 1e 2a :2 15 :2 13 :2 d 2d :2 a
:4 7 9 7 :3 4 8 1 7 d
:3 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 52
56 57 :2 52 :2 29 :3 d :2 13 18 24
63 66 :2 24 73 76 :2 24 7a 7d
:2 24 89 8c :2 24 94 97 :2 24 a3
a6 ad b6 b9 :2 a6 :2 24 :2 d 5a
:2 a :2 7 :4 13 :2 7 4 :3 1 8 13
11 :2 1c :2 11 7 36 3f 41 :2 3f
35 :2 7 48 51 54 :2 51 5a a
12 :2 5a 15 17 :2 15 :2 48 47 :2 7
a :2 14 26 :2 30 3c 40 4f 53
54 :2 4f :2 26 :3 a :2 10 15 21 60
63 :2 21 70 73 :2 21 77 7a :2 21
84 87 90 98 :2 90 a3 :2 87 :2 21
ab ae :2 21 b6 b9 :2 21 be c1
:2 21 cd d0 :2 21 :2 a 57 :2 7 a
:2 14 26 :2 30 3c 3f 4e 52 53
:2 4e :2 26 :3 a :2 10 15 21 60 63
:2 21 :2 a 56 :3 7 :2 12 26 30 3d
:2 7 1a :2 4 7 11 14 :2 11 7
12 :2 7 15 :2 7 14 :2 7 c :4 7
c :2 7 10 a :7 c :3 a d 12
:2 d :2 16 22 d 18 d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a :4 e d 29 :2 34 3b
46 :2 29 50 52 :2 50 :2 d 14 1d
24 :2 1d 2e :2 14 31 33 :2 31 :3 d
18 d 35 :2 a d :2 18 1f 2b
:2 d 35 38 :2 35 10 12 15 :2 12
1a 13 1d 15 21 15 20 15
22 15 21 15 22 19 21 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 62 63 :2 5e :2 35 :3 19 :2 1f
24 30 6f 72 :2 30 7f 82 :2 30
86 89 :2 30 95 98 :2 30 a0 a3
:2 30 af b2 b9 c2 c5 :2 b2 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :4 17
:3 d 1c :2 d 1d :2 d 1c :2 d 1d
:2 d 1d :2 d 1d :2 d 1b :2 d 12
d 3a :2 a d f 12 :2 f :4 19
18 :2 d 17 10 :5 12 16 1e 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :4 30
:2 a :4 e d :4 11 :2 10 1f 26 32
35 :2 26 3a 3d :2 1f 10 2a :3 d
1c 23 2f 32 :2 23 3e 41 :2 1c
d 26 :2 a :4 e :2 d 1d 24 31
34 :2 24 3f 42 :2 1d d 25 :2 a
:4 e d :4 11 :2 10 20 27 34 37
:2 27 3c 3f :2 20 10 2b :3 d 1d
24 31 34 :2 24 41 44 :2 1d d
27 :2 a :4 e :2 d 1d 24 31 34
:2 24 40 43 :2 1d d 26 :2 a :4 e
d :4 11 :2 10 1f 26 32 35 :2 26
3a 3d :2 1f 10 2a :3 d 1c 23
2f 32 :2 23 3e 41 :2 1c d 26
:2 a :4 e d :4 11 :2 10 20 27 34
37 :2 27 3c 3f :2 20 10 2b :3 d
1d 24 31 34 :2 24 41 44 :2 1d
d 27 :3 a f 11 13 :2 f :2 a
17 a 7 b 16 a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 16 a c f
:2 c 14 d 17 f 1b f 1a
f 1c f 1b f 1c 13 1b
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:4 11 :2 7 16 :2 4 :4 8 7 a 13
1b :2 a 1e 20 :2 1e 14 1d 21
38 12 13 1e 11 22 2a 31
49 51 58 :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:4 22 a 18 :2 a :4 7 24 :2 4 e
1b 26 30 33 4b 5a c 14
17 1c 2b 31 34 42 45 d
10 1d :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 52 56 57 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 73 76 :2 24
7a 7d :2 24 89 8c :2 24 94 97
:2 24 a3 a6 ad b6 b9 :2 a6 :2 24
:2 d 5a :2 a :2 7 :4 13 :2 7 4 :3 1
7 10 1c :2 7 21 1f :2 2a :2 1f
7 f 19 :3 7 :2 10 1c 7 16
11 :4 c f 10 18 f 1e a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 3a
b :2 14 1f 1d :2 28 :2 1d a 19
14 f 13 24 f 13 24 f
13 24 f 13 24 12 13 1c
16 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 38 e :2 17 22 20 :2 2b :2 20
d 1c 17 15 16 1e 19 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :4 3b
:2 a 38 :3 7 c 1e 2a 3c 45
47 57 65 68 73 76 82 85
90 93 9f b2 7 a 1a 27
2a 3a 7 17 1a 2e 31 43
46 5b 60 6f 83 85 94 ad
7 17 1a 2e 31 43 46 5b
60 6f 83 85 94 ad 7 17
1a 2e 31 43 46 5b 60 6f
83 85 94 ad 7 17 1a 2e
31 43 46 5b 60 6f 83 85
94 ad 7 a 15 18 24 27
32 35 3d 40 51 54 66 69
77 87 94 9f ac af bc bf
c9 cc d6 d 1c 2e 39 3c
4c 5d 73 7e 8b 9b 9e a9
b8 c7 d0 e0 ef 15 24 4b
64 c 1e 23 28 37 3d 40
49 4e 7 c 12 17 2b 31
34 3f 50 53 5f 62 7 c
15 1a 1c 29 7 c 1d 22
24 2c 2e 7 c 12 17 1d
22 24 2c 2e 7 c 12 17
29 2f 31 3a 3d 7 c 12
17 27 2d 2f 38 3b 7 c
12 17 21 27 2a 37 39 12
15 2b 2e 45 48 5e 61 17
7 17 a :2 14 26 :2 30 3c 3f
4e 52 53 :2 4e :2 26 :3 a :2 10 15
21 60 63 :2 21 :2 a 56 :3 7 e
7 3a a 14 16 :2 14 a f
21 24 2e 40 49 4b 58 66
69 74 77 83 86 91 94 a0
a2 a d 1d 2a 2d 3d a
1a 1d 33 36 50 52 60 73
75 83 aa b5 bf d7 ec f9
112 11d 127 13f 154 161 163 179
17c 192 195 1a7 1aa 1b9 1d2 a
1a 1d 33 36 50 52 60 73
75 83 aa b5 bf d7 ec f9
112 11d 127 13f 154 161 163 179
17c 192 195 1a7 1aa 1b9 1d2 a
1a 1d 33 36 50 52 60 73
75 83 aa b5 bf d7 ec f9
112 11d 127 13f 154 161 163 179
17c 192 195 1a7 1aa 1b9 1d2 a
1a 1d 33 36 50 52 60 73
75 83 aa b5 bf d7 ec f9
112 11d 127 13f 154 161 163 179
17c 192 195 1a7 1aa 1b9 1d2 a
d 19 1c 28 2b 36 39 41
44 55 58 6a 6d 7b 8b 98
a3 b0 b3 c0 c3 cd d0 da
a d 1a 24 26 32 35 45
50 53 5e 61 77 82 8f 9f
a2 ad bc bf c8 cb d5 de
e1 f0 f3 104 a c 1b 1d
2d 40 42 f 1e 21 26 30
35 38 3f 41 a f 19 1f
22 2d 2f a f 15 1a 24
2a 2d 38 3b a f 19 1e
21 28 2a 36 3b 41 46 50
56 59 65 67 a f 15 1a
2e 34 37 42 53 56 62 65
a f 15 1a 2c 32 34 40
43 a f 15 1a 2c 32 35
3f 42 a f 15 1a 2a 30
32 3e 41 a f 15 1a 2a
30 33 3d 40 13 1a a 1a
d :2 17 29 :2 33 3f 42 51 55
56 :2 51 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a 11 a 18
a 12 1c :3 a :2 13 1f a 19
14 1c 2a 38 46 12 27 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :3 7
19 15 39 3d 4e d 11 22
31 35 46 d 11 22 12 13
29 35 4a 61 16 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 7 a f
21 24 2e 40 49 4b 58 66
69 74 77 83 86 91 94 a0
a2 a d 1d 2a 2d 3d a
1a 1d 31 34 f 11 25 27
41 43 51 64 66 74 9b a6
b0 c8 dd ea 103 10e 118 130
145 152 154 f 13 27 2b 45
47 55 68 6a 78 9f aa b4
cc e1 ee 107 112 11c 134 149
156 158 f 13 22 14 a 1a
1d 32 35 f 11 27 29 43
45 53 66 68 76 9d a8 b2
ca df ec 105 110 11a 132 147
154 156 f 13 27 2b 45 47
55 68 6a 78 9f aa b4 cc
e1 ee 107 112 11c 134 149 156
158 f 13 22 14 a 1a 1d
31 34 f 11 25 27 41 43
51 64 66 74 9b a6 b0 c8
dd ea 103 10e 118 130 145 152
154 f 13 27 2b 45 47 55
68 6a 78 9f aa b4 cc e1
ee 107 112 11c 134 149 156 158
f 13 22 14 a 1a 1d 31
34 f 11 25 27 41 43 51
64 66 74 9b a6 b0 c8 dd
ea 103 10e 118 130 145 152 154
f 13 27 2b 45 47 55 68
6a 78 9f aa b4 cc e1 ee
107 112 11c 134 149 156 158 f
13 22 14 a d 18 1b 27
2a 35 38 40 43 54 57 69
6c 7a 8a 97 a2 af b2 bf
c2 cc cf d9 a d 1a 24
26 32 35 45 50 53 5e 61
77 82 8f 9f a2 ad a d
16 19 23 2c 2f 3e 41 52
a c 1b 1d 2d 40 42 f
1e a f 14 26 2d 30 37
3b 46 4a a f 14 26 2d
30 37 3b 46 4a a f 19
1e 21 28 2a a f 19 1f
22 2d 2f a f 15 1a 24
2a 2d 38 3b a f 19 1e
21 28 2a 36 3b 41 46 50
56 59 65 67 a f 15 1a
2e 34 37 42 53 56 62 65
a f 15 1a 24 2a 2c 37
3a a f 15 1a 2c 32 34
40 43 4e 53 59 5e 70 76
79 83 86 a f 15 1a 2a
30 32 3e 41 4c 51 57 5c
6c 72 75 7f 82 a f 15
1a 20 25 27 2f 31 15 18
2e 31 48 4b 61 64 13 1a
a 1a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a 11
a :4 7 :4 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 60 63
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 57 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4c 50 51
:2 4c :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 54 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
373d
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 :4 18
:4 19 :4 1a :4 1b :4 1c
:4 1d 2 :4 1e :2 1
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :7 2e :7 2f
:7 30 :7 31 :7 32 :7 33
:7 34 :5 35 :7 36 :7 37
:7 38 :7 39 :7 3a :5 3b
:7 3c :7 3d :7 3e :7 3f
:7 40 :7 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :6 61 :6 62 :7 63
:6 64 :6 65 :6 66 :7 67
:7 68 :7 69 :6 6a :6 6b
:7 6c :7 6d :7 6e :7 6f
:7 70 :7 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:6 78 :6 79 :7 7a :6 7b
:5 7c :5 7d :5 7e :5 7f
:5 80 :5 81 :5 82 :7 85
:2 87 0 :2 87 88
89 :2 8a :2 8b :2 8c
88 :5 87 :2 8e 0
:2 8e 90 91 :2 92
:2 93 :2 94 :2 95 :2 96
:2 97 98 99 90
:5 8e :7 9c :7 9f :7 a2
:7 a4 :b a6 :11 a7 a8
:2 a7 :2 a8 :2 a7 :2 a8
:2 a7 :2 a9 :2 a7 :2 a9
:2 a7 :2 a9 :2 a7 :2 a9
:2 a7 :2 aa :2 a7 :2 aa
:2 a7 :2 aa :2 a7 :2 aa
:2 a7 :2 ab :2 a7 :9 ab
:2 a7 :2 ac :2 a7 :9 ac
:2 a7 :2 ad :2 a7 :9 ad
:2 a7 :2 ae :2 a7 :9 ae
:2 a7 :2 af :2 a7 :9 af
:2 a7 :2 b0 :2 a7 :9 b0
:2 a7 :2 b1 :2 a7 :9 b1
:2 a7 :2 b2 :2 a7 :9 b2
:2 a7 :2 b3 :2 a7 :2 b3
:2 a7 :2 b3 :2 a7 :2 b3
:2 a7 :2 b4 :2 a7 :2 b4
:2 a7 :2 b4 :2 a7 :2 b4
:2 a7 :2 b5 :2 a7 :2 b5
:2 a7 :2 b5 :2 a7 :2 b5
:2 a7 :2 b6 :2 a7 :2 b6
:2 a7 :2 b6 :2 a7 :2 b6
:2 a7 :2 b7 :2 a7 :2 b7
:2 a7 :2 b7 :2 a7 :2 b7
:2 a7 :2 b8 :2 a7 :9 b8
:2 a7 :2 b9 :2 a7 :2 b9
:2 a7 :2 b9 :2 a7 :2 b9
:2 a7 :2 ba :2 a7 :2 ba
:2 a7 :2 ba :2 a7 :2 ba
:2 a7 :2 bb :2 a7 :2 bb
:2 a7 :2 bb :2 a7 :2 bb
:2 a7 :2 bc :2 a7 :2 bc
:2 a7 :2 bc :2 a7 :2 bc
:2 a7 :2 bd :2 a7 :9 bd
:2 a7 :2 be :2 a7 :9 be
:2 a7 :2 bf :2 a7 :9 bf
:2 a7 :2 c0 :2 a7 :9 c0
:2 a7 :2 c1 :2 a7 :2 c1
:2 a7 :2 c1 :2 a7 :2 c1
:2 a7 :2 c2 :2 a7 :2 c2
:2 a7 :2 c2 :2 a7 :2 c2
:2 a7 :2 c2 :4 a7 :3 a6
:11 c5 :b c6 :3 c5 :3 ce
:3 cf :3 d0 :3 d1 :3 d2
:3 d3 :3 d4 :3 d5 :3 d6
:3 d7 :3 d9 :3 db :3 dd
:3 df :3 e0 :3 e1 :3 e2
:3 e3 :3 e4 :3 e5 :3 e6
:3 e7 :3 e9 :3 ea :14 ef
:11 f0 :20 f1 :3 f0 :11 f3
:b f4 :3 f3 :9 f6 :3 ef
:1e f9 :c fa :2 f9 :14 fb
:11 fc :20 fd :3 fc :11 ff
:b 100 :3 ff :9 102 103
fb :e 103 :11 104 :20 105
:3 104 :11 107 :b 108 :3 107
:9 10a 103 :3 fb fa
:2 f9 :1f 10e :11 10f :20 110
:3 10f :11 112 :b 113 :3 112
:9 115 :3 10e :6 119 :3 11a
119 :3 11c 11b :3 119
:14 11f :6 120 :2 11f :6 122
123 124 122 :5 125
121 127 :5 128 :3 127
:2 129 :5 12b :11 12c :24 12d
:3 12c :2 12a :6 129 126
:3 120 :16 132 :11 133 :20 134
:3 133 :11 136 :b 137 :3 136
:9 139 :3 132 :3 13b 120
:2 11f :e 13e :4 140 :5 141
13f 143 :5 144 :3 143
:2 145 :5 147 :11 148 :24 149
:3 148 :2 146 :6 145 142
:6 13e :3 14f :14 153 :d 155
:14 157 :d 159 :b 15b :3 15c
15d 15b :b 15d :3 15e
15d 15b :b 160 :3 161
160 :3 163 162 :3 160
15f :3 15b :9 167 :3 168
:2 16a 16b :2 16c 16a
:5 16d 169 16f :5 170
:3 16f :2 171 :5 173 :11 174
:24 175 :3 174 :2 172 :6 171
16e :3 167 :9 17a :2 17c
17d :2 17e 17c :5 17f
17b 181 :5 182 :3 181
:2 183 :5 185 :11 186 :24 187
:3 186 :2 184 :6 183 180
:3 17a :b 18c :11 18d :30 18e
:3 18d :11 190 :b 191 :3 190
:a 193 :3 18c :3 17a :a 197
:9 198 :a 199 :9 19a :11 19b
:20 19c :3 19b :11 19e :b 19f
:3 19e :9 1a1 :3 19a :5 1a3
:3 198 :3 1a5 :9 1a7 :3 1a8
1a7 :11 1ab :20 1ac :3 1ab
:11 1ae :b 1af :3 1ae :9 1b1
1a9 :3 1a7 :7 1b9 1ba
:3 1b9 :b 1bc :9 1bd :5 1be
:3 1bd :11 1c1 :2e 1c2 :3 1c1
:11 1c4 :b 1c5 :3 1c4 :c 1c7
:3 1bc :14 1ca :11 1cb :2e 1cc
:3 1cb :11 1ce :b 1cf :3 1ce
:c 1d1 :3 1ca :b 1d3 :c 1d4
1d7 :2 1d8 :2 1d9 1da
1dc 1dd 1de 1df
1e0 :2 1e1 1d7 :5 1e2
1d5 1e4 :5 1e5 :3 1e4
:2 1e6 :5 1e8 :11 1e9 :24 1ea
:3 1e9 :2 1e7 :6 1e6 1e3
:4 1d4 :2 1f1 :2 1f2 :2 1f3
:2 1f4 :3 1f5 :3 1f6 :2 1f7
:4 1f8 1fa 1fb 1fc
1fd 1fe 1ff 200
201 :4 202 :3 203 :4 204
1f1 :5 205 1ef 207
:5 208 :3 207 :2 209 :5 20b
:11 20c :24 20d :3 20c :2 20a
:6 209 206 :4 1ee :3 1d4
:a 213 :11 214 :30 215 :3 214
:11 217 :b 218 :3 217 :a 21a
:3 213 21c 1d3 :b 21c
21f 220 221 223
224 225 226 :2 227
21f :5 228 21d 22a
:5 22b :3 22a :2 22c :5 22e
:11 22f :24 230 :3 22f :2 22d
:6 22c 229 :3 21c :a 235
:11 236 :30 237 :3 236 :11 239
:b 23a :3 239 :a 23c :3 235
:2 244 245 :2 246 :2 248
:2 249 24a 24c 24d
24e 24f 250 :2 251
:2 252 243 :5 253 241
255 :5 256 :3 255 :2 257
:5 259 :11 25a :24 25b :3 25a
:2 258 :6 257 254 :3 21c
:a 260 :11 261 :30 262 :3 261
:11 264 :b 265 :3 264 :a 267
:3 260 :5 26a :5 26e :6 26f
:3 26a 21c 1d3 :11 273
:30 274 :3 273 :11 276 :b 277
:3 276 :a 279 271 :3 1d3
:b 27d 281 :3 282 283
284 :4 285 :4 286 288
289 28a 28b 28c
28d 28e :2 28f 281
:5 290 27f 292 :5 293
:3 292 :2 294 :5 296 :11 297
:24 298 :3 297 :2 295 :6 294
291 :3 27d :a 29d :11 29e
:30 29f :3 29e :11 2a1 :b 2a2
:3 2a1 :a 2a4 2a5 29d
:a 2a5 :14 2a6 :2 2a7 :2 2a6
:8 2a7 :5 2a6 :11 2a8 :30 2a9
:3 2a8 :11 2ab :b 2ac :3 2ab
:a 2ae 2a7 :2 2a6 :d 2b1
:8 2b4 2b5 2b4 :5 2b6
2b3 2b8 :5 2b9 :3 2b8
:2 2ba :5 2bc :11 2bd :24 2be
:3 2bd :2 2bb :6 2ba 2b7
:6 2b1 2a5 :3 29d :3 27d
:3 167 :9 2c9 :13 2cf :2 2d0
:2 2cf :4 2d0 :2 2cf :11 2d1
:30 2d2 :3 2d1 :11 2d4 :b 2d5
:3 2d4 :7 2d7 2d8 :2 2d7
2d0 :2 2cf :b 2dc 2df
:2 2e0 :2 2e1 2e3 2e4
2e5 2e6 :2 2e7 2df
:5 2e8 2dd 2ea :5 2eb
:3 2ea :2 2ec :5 2ee :11 2ef
:24 2f0 :3 2ef :2 2ed :6 2ec
2e9 :3 2dc :a 2f7 2fd
2fe :3 2ff 2fa :5 300
2f8 302 :5 303 :3 302
:2 304 :5 306 :11 307 :24 308
:3 307 :2 305 :6 304 301
:3 2f7 :a 30d :11 30e :30 30f
:3 30e :11 311 :b 312 :3 311
:a 314 :3 30d :3 2f7 :3 2dc
:3 2c9 :14 31b :3 31c :3 31b
:b 31f :5 321 :3 322 :3 323
321 :3 325 :3 326 324
:3 321 :3 329 31f :5 32c
:3 32e :e 330 :b 331 :2 332
:2 331 :a 332 :8 333 :3 330
:b 335 :11 336 :20 337 :3 336
:11 339 :b 33a :3 339 :9 33c
33d 335 :9 33d :11 33e
:2e 33f :3 33e :11 341 :b 342
:3 341 :c 344 33d :3 335
32c :3 347 :9 349 :f 34a
:3 349 346 :3 32c :16 34d
:16 34e :3 34f 350 34e
:9 350 :3 351 352 350
34e :16 352 :3 353 354
352 34e :9 354 :3 355
354 :3 34e :3 34d 32a
:3 31f :b 35f :3 360 :3 362
:3 363 :8 366 :3 367 :9 36e
:5 36f :3 370 36e :2 374
375 :2 376 374 :5 377
373 379 :5 37a :3 379
:2 37b :5 37d :11 37e :24 37f
:3 37e :2 37c :6 37b 378
:3 371 :a 384 :9 385 388
38a 38b :2 38c :2 38d
38e :3 38f 388 :5 390
386 392 :5 393 :3 392
:2 394 :5 396 :11 397 :24 398
:3 397 :2 395 :6 394 391
:6 385 384 :3 3a3 3a2
:3 384 371 :3 36e :5 3a7
:3 3aa 3ac 3ad :2 3ae
:2 3af 3aa :5 3b0 3a8
3b2 :5 3b3 :3 3b2 :2 3b4
:5 3b6 :11 3b7 :24 3b8 :3 3b7
:2 3b5 :6 3b4 3b1 :3 3a7
:d 3bf :6 3c0 3c1 :4 3c2
:3 3c3 :4 3c4 3bf :5 3c5
3bd 3c7 :5 3c8 :3 3c7
:2 3c9 :5 3cb :11 3cc :24 3cd
:3 3cc :2 3ca :6 3c9 3c6
:3 3a7 :a 3d2 :11 3d3 :30 3d4
:3 3d3 :11 3d6 :b 3d7 :3 3d6
:a 3d9 :3 3d2 :9 3dc :3 3dd
3dc :3 3df 3de :3 3dc
3e3 3e5 3e6 3e7
3e8 3e9 3ea 3eb
3ec 3ed 3f1 3f2
3f3 3f4 3f5 3f6
3f7 3f8 3f9 3e3
:6 3fb :5 3fc 3fb :5 3fe
3fd :3 3fb 3e2 401
:5 402 :3 401 :2 403 :5 405
:11 406 :24 407 :3 406 :2 404
:6 403 400 :3 3a7 40b
3a7 :a 40b :2 40f :2 410
:2 411 :2 412 :2 413 40f
:6 414 :5 415 414 :5 417
416 :3 414 40e 41a
:5 41b :3 41a :2 41c :5 41e
:11 41f :24 420 :3 41f :2 41d
:6 41c 419 :4 40b :3 3a7
429 42a 42b 42c
:2 42d 42e :2 42f 429
:6 430 :5 431 430 :5 433
432 :3 430 428 436
:5 437 :3 436 :2 438 :5 43a
:11 43b :24 43c :3 43b :2 439
:6 438 435 :3 35f 442
443 444 445 :2 446
447 :2 448 442 :6 449
:5 44a 449 :5 44c 44b
:3 449 441 44f :5 450
:3 44f :2 451 :5 453 :11 454
:24 455 :3 454 :2 452 :6 451
44e :3 35f 45b :2 45c
45d :2 45e 45b :6 45f
:5 460 45f :5 462 461
:3 45f 45a 465 :5 466
:3 465 :2 467 :5 469 :11 46a
:24 46b :3 46a :2 468 :6 467
464 :6 35f :5 48d :17 48f
:2 490 :2 48f :6 490 :2 48f
:5 491 :3 492 :3 491 490
:2 48f :9 496 :5 497 :3 496
:13 49a :6 49b :2 49a :3 49c
49b :2 49a :3 4a0 :3 4a1
:9 4a2 :b 4a9 :a 4aa :2 4ab
:2 4aa :2 4ac :2 4aa :2 4ad
:2 4aa :2 4ad :2 4aa :2 4ad
:3 4aa 4ae 4a9 :9 4ae
:2 4af :2 4b0 :2 4af :2 4b1
:2 4af :2 4b1 :2 4af :2 4b1
:2 4af :2 4b2 :2 4af :2 4b2
:2 4af :2 4b2 :2 4af :2 4b3
:3 4af 4ae 4a9 :2 4b5
:2 4b6 :2 4b5 :2 4b7 :2 4b5
:2 4b8 :2 4b5 :2 4b8 :2 4b5
:2 4b8 :3 4b5 4b4 :3 4a9
4a2 :c 4c2 :2 4c3 :2 4c2
:6 4c3 :2 4c2 4c3 :2 4c4
:2 4c3 :6 4c4 :2 4c2 :5 4c8
:5 4c9 :5 4cb :5 4ce :5 4cf
4d2 :2 4d3 4d4 4d5
:4 4d8 :2 4d9 :3 4da :4 4db
:2 4dc :3 4dd 4d2 :6 4de
:5 4df 4de :5 4e1 4e0
:3 4de 4d1 4e4 :5 4e5
:3 4e4 :2 4e6 :5 4e8 :11 4e9
:24 4ea :3 4e9 :2 4e7 :6 4e6
4e3 :3 4cb 4f2 :2 4f3
:2 4f4 :2 4f6 :2 4f7 :4 4f8
:8 4f9 4f2 :6 4fa :5 4fb
4fa :5 4fd 4fc :3 4fa
4f1 500 :5 501 :3 500
:2 502 :5 504 :11 505 :24 506
:3 505 :2 503 :6 502 4ff
:4 4cb :3 50c 50a :3 4cb
4c4 :2 4c2 :5 510 512
:1c 513 :2 512 :c 513 :3 512
:3 514 :8 517 :15 518 :15 519
:2 518 :2 51a 519 :2 518
:7 51c 517 51d 517
:5 51f :11 520 :20 521 :3 520
:11 523 :b 524 :3 523 :9 526
:3 51f :2 52a 52b 52c
52a :5 52d 529 52f
:5 530 :3 52f :2 531 :5 533
:11 534 :24 535 :3 534 :2 532
:6 531 52e :6 510 :b 53b
53d 53e 53d :3 53f
:7 540 :7 541 542 53b
:b 542 544 545 544
:7 546 :7 547 :3 548 542
53b :b 54a :3 54d :3 54e
:5 550 :7 551 :7 552 :7 553
:3 550 :7 556 :5 558 :7 559
:7 55a :7 55b :3 558 54a
:5 55e :7 55f :3 560 55e
:6 563 :2 564 :3 563 :3 566
:5 568 :7 569 :7 56a :7 56b
:3 568 :6 56e :2 56f :2 56e
:2 570 :2 56e :2 571 :2 56e
:2 572 :2 56e :2 573 :3 56e
561 :3 55e :5 576 :f 577
:3 576 55d :3 54a 549
:3 53b :b 57c :5 57d :2 57f
580 :2 581 57f :5 582
57e 584 :5 585 :3 584
:2 586 :5 588 :11 589 :24 58a
:3 589 :2 587 :6 586 583
:3 57d :a 58f :a 590 :7 593
:6 594 :2 595 :2 594 :2 595
:2 594 :2 595 :3 594 58f
:11 597 :30 598 :3 597 :11 59a
:b 59b :3 59a :a 59d 596
:3 58f :3 57d :5 5a1 :2 5a3
5a4 :2 5a5 5a3 :5 5a6
5a2 5a8 :5 5a9 :3 5a8
:2 5aa :5 5ac :11 5ad :24 5ae
:3 5ad :2 5ab :6 5aa 5a7
:3 5a1 :a 5b3 :7 5b4 :6 5b5
:2 5b6 :2 5b5 :2 5b6 :2 5b5
:2 5b6 :3 5b5 5b3 :11 5b8
:30 5b9 :3 5b8 :11 5bb :b 5bc
:3 5bb :a 5be 5b7 :3 5b3
:3 5a1 :5 5c2 :2 5c4 5c5
:2 5c6 5c4 :5 5c7 5c3
5c9 :5 5ca :3 5c9 :2 5cb
:5 5cd :11 5ce :24 5cf :3 5ce
:2 5cc :6 5cb 5c8 :3 5c2
:a 5d4 :7 5d5 :6 5d6 :2 5d7
:2 5d6 :2 5d7 :2 5d6 :2 5d7
:3 5d6 5d4 :11 5d9 :30 5da
:3 5d9 :11 5dc :b 5dd :3 5dc
:a 5df 5d8 :3 5d4 :3 5c2
:14 5e3 :16 5e4 :3 5e3 :3 57c
:5 5e9 :a 5ea :3 5ec :8 5ed
:f 5ef :2 5f2 5f3 :2 5f4
5f2 :5 5f5 5f1 5f7
:5 5f8 :3 5f7 :2 5f9 :5 5fb
:11 5fc :24 5fd :3 5fc :2 5fa
:6 5f9 5f6 :3 5ed :a 602
:11 603 :30 604 :3 603 :11 606
:b 607 :3 606 :a 609 :3 602
:6 60c :2 60d :2 60c :2 60e
:2 60c :2 60f :2 60c :2 60f
:2 60c :2 60f :3 60c :b 611
:7 612 611 :7 614 613
:3 611 :b 618 :2 619 :3 618
:7 61b 5ed 61c 5ed
:3 5e9 :b 620 :a 621 :3 623
:8 624 :f 626 :2 629 62a
:2 62b 629 :5 62c 628
62e :5 62f :3 62e :2 630
:5 632 :11 633 :24 634 :3 633
:2 631 :6 630 62d :3 624
:a 639 :11 63a :30 63b :3 63a
:11 63d :b 63e :3 63d :a 640
:3 639 :6 643 :2 644 :2 643
:2 645 :2 643 :2 646 :2 643
:2 646 :2 643 :2 646 :2 643
:2 647 :3 643 :7 648 624
649 624 :3 620 :7 64c
4ba :3 4a2 :7 64f :5 653
656 :4 657 :3 658 :5 659
658 :5 65b 65a :3 658
:a 65f :2 660 :3 65f :17 665
:2 666 :2 665 :6 666 :2 665
666 :2 667 :2 666 :b 667
:3 666 :2 665 :5 66a :4 66c
:3 66d :5 66e 66d :5 670
66f :3 66d :a 673 :4 675
:5 676 674 678 :5 679
:3 678 :2 67a :5 67c :11 67d
:24 67e :3 67d :2 67b :6 67a
677 :3 673 :2 686 673
:4 689 :5 68a 688 68c
:5 68d :3 68c :2 68e :5 690
:11 691 :24 692 :3 691 :2 68f
:6 68e 68b :4 687 :3 673
667 :2 665 :3 699 :3 69a
:9 69b :a 69c :5 69e :3 69f
69c :c 6a1 :3 6a4 6a5
:2 6a6 :2 6a7 6a8 6a4
:5 6a9 6a3 6ab :5 6ac
:3 6ab :2 6ad :5 6af :11 6b0
:24 6b1 :3 6b0 :2 6ae :6 6ad
6aa :3 6a1 :9 6b6 :4 6b8
:5 6b9 6b7 6bb :5 6bc
:3 6bb :2 6bd :5 6bf :11 6c0
:24 6c1 :3 6c0 :2 6be :6 6bd
6ba :3 6b6 :11 6c6 :30 6c7
:3 6c6 :11 6c9 :b 6ca :3 6c9
:7 6cc 6cd :2 6cc :3 6b6
:3 6a1 6a0 :3 69c :8 6d2
:5 6d3 :7 6d4 :6 6d5 :a 6d6
:3 6d7 :3 6d2 :5 6d9 :4 6db
:5 6dc 6da 6de :5 6df
:3 6de :2 6e0 :5 6e2 :11 6e3
:24 6e4 :3 6e3 :2 6e1 :6 6e0
6dd :3 6d9 :7 6e9 :5 6ea
:3 6e9 :11 6ed :2e 6ee :3 6ed
:11 6f0 :b 6f1 :3 6f0 :8 6f3
6f4 6d9 :18 6f4 :6 6f6
:6 6f7 :5 6f8 6f7 :5 6fa
6f9 :3 6f7 6f5 6fd
:5 6fe :3 6fd :2 6ff :5 701
:11 702 :24 703 :3 702 :2 700
:6 6ff 6fc :4 6f4 :3 6d9
:2 709 69b :b 70b :3 70c
:3 70d :3 70b :8 710 :5 711
:7 712 :6 713 :9 714 :3 710
:5 716 :7 717 718 716
:5 718 :2 719 718 :3 716
:9 71c :2 71d :3 71c 70a
:3 69b 720 721 :3 656
722 a5 :4 726 :5 727
725 729 :5 72a :3 729
:2 72b :5 72d :11 72e :24 72f
:3 72e :2 72c :6 72b 728
:3 a5 :16 735 :2 736 :2 735
:4 736 :5 735 :11 737 :2e 738
:3 737 :11 73a :b 73b :3 73a
:8 73d 736 :2 735 :5 740
:3 741 :3 742 :3 743 :5 745
:3 747 749 74a 74b
74c 74d 74e 74f
750 751 752 :3 74a
:3 753 :5 754 753 :5 756
755 :3 753 :a 759 :2 75a
:3 759 :12 75f :c 760 :2 75f
:3 762 760 :2 75f :b 766
:5 768 76b :2 76c :2 76d
:2 76e :2 76f :2 770 :2 771
:2 772 76b :6 773 :5 774
773 :5 776 775 :3 773
76a 779 :5 77a :3 779
:2 77b :5 77d :11 77e :24 77f
:3 77e :2 77c :6 77b 778
:6 768 :3 785 :3 786 :3 787
:3 788 :3 789 :3 78b :3 78f
:3 790 :3 766 :c 793 796
797 798 799 79a
79b 79c :2 79d 796
:6 79e :5 79f 79e :5 7a1
7a0 :3 79e 795 7a4
:5 7a5 :3 7a4 :2 7a6 :5 7a8
:11 7a9 :24 7aa :3 7a9 :2 7a7
:6 7a6 7a3 :6 793 :5 7b0
:5 7b1 :c 7b2 :3 7b1 :c 7b5
:3 7b0 :5 7b8 :c 7b9 :3 7b8
:5 7bc :5 7bd :c 7be :3 7bd
:c 7c1 :3 7bc :5 7c4 :c 7c5
:3 7c4 :5 7c8 :5 7c9 :c 7ca
:3 7c9 :c 7cd :3 7c8 :5 7d0
:5 7d1 :c 7d2 :3 7d1 :c 7d5
:3 7d0 :7 7d9 :3 7db 749
7dc 740 :4 7de :5 7df
7dd 7e1 :5 7e2 :3 7e1
:2 7e3 :5 7e5 :11 7e6 :24 7e7
:3 7e6 :2 7e4 :6 7e3 7e0
:3 740 :5 7ec 7ef :2 7f0
:2 7f1 :2 7f2 :2 7f3 :2 7f4
:2 7f5 :2 7f6 7ef :6 7f7
:5 7f8 7f7 :5 7fa 7f9
:3 7f7 7ee 7fd :5 7fe
:3 7fd :2 7ff :5 801 :11 802
:24 803 :3 802 :2 800 :6 7ff
7fc :6 7ec :3 740 :5 80a
:9 80b :4 80d 80e :2 80f
:7 810 80d :5 811 80c
813 :5 814 :3 813 :2 815
:5 817 :11 818 :24 819 :3 818
:2 816 :6 815 812 :4 80b
:3 81e 81f 81d :3 80b
:3 80a :7 824 :9 825 :3 826
824 :5 827 823 829
:5 82a :3 829 :2 82b :5 82d
:11 82e :24 82f :3 82e :2 82c
:6 82b 828 :3 a5 :b 837
:5 83a :5 83b 840 841
842 843 844 845
846 :2 847 :2 848 840
:6 849 :5 84a 849 :5 84c
84b :3 849 83f 84f
:5 850 :3 84f :2 851 :5 853
:11 854 :24 855 :3 854 :2 852
:6 851 84e :3 837 :a 85b
85d 85e :3 85f :3 860
:3 861 :3 862 863 :2 864
865 85d :6 866 :5 867
866 :5 869 868 :3 866
85c 86c :5 86d :3 86c
:2 86e :5 870 :11 871 :24 872
:3 871 :2 86f :6 86e 86b
:3 85b :a 877 879 87a
87b :2 87c 87d 879
:6 87e :5 87f 87e :5 881
880 :3 87e 878 884
:5 885 :3 884 :2 886 :5 888
:11 889 :24 88a :3 889 :2 887
:6 886 883 :6 877 :3 85b
:12 891 :6 892 :e 893 :e 894
:e 895 :e 896 :19 897 :12 898
:4 899 :9 89a :c 89b :6 89c
:7 89d :9 89e :9 89f :9 8a0
:9 8a1 :8 8a2 :3 891 :11 8a3
:b 8a4 :3 8a3 :3 8a6 837
:5 8a8 :13 8a9 :6 8aa :20 8ab
:20 8ac :20 8ad :20 8ae :19 8af
:1c 8b0 :7 8b1 :9 8b2 :7 8b3
:9 8b4 :10 8b5 :c 8b6 :9 8b7
:9 8b8 :9 8b9 :9 8ba 8bb
:3 8a9 :11 8bc :b 8bd :3 8bc
:3 8bf 8a8 :5 8c2 :5 8c3
8c5 :5 8c6 :2 8c7 8c5
:6 8c8 :5 8c9 8c8 :5 8cb
8ca :3 8c8 8c4 8ce
:5 8cf :3 8ce :2 8d0 :5 8d2
:11 8d3 :24 8d4 :3 8d3 :2 8d1
:6 8d0 8cd :3 8c0 8da
:4 8db :6 8dc :3 8dd 8de
:5 8df 8e0 8da :6 8e1
:5 8e2 8e1 :5 8e4 8e3
:3 8e1 8d9 8e7 :5 8e8
:3 8e7 :2 8e9 :5 8eb :11 8ec
:24 8ed :3 8ec :2 8ea :6 8e9
8e6 :3 8c0 :13 8f2 :6 8f3
:5 8f5 :17 8f6 :17 8f7 :3 8f8
8f9 :5 8fb :17 8fc :17 8fd
:3 8fe 8ff :5 901 :17 902
:17 903 :3 904 905 :5 907
:17 908 :17 909 :3 90a 90b
:19 90d :12 90e :a 90f :7 910
:2 911 :a 912 :a 913 :7 914
:7 915 :9 916 :10 917 :c 918
:9 919 :12 91a :12 91b :9 91c
:8 91d 91e :3 8f2 :11 91f
:b 920 :3 91f :3 922 8c0
:3 8a8 8a7 :3 837 a5
:3 928 :11 929 :b 92a :17 92b
:3 929 :2 92d :3 92e :3 92f
930 92e 92d 92e
:3 931 :3 928 :2 932 :5 934
:11 935 :b 936 :18 937 :3 935
:2 939 93a :3 93b 93c
93a 939 93a :3 93d
:2 933 :6 932 927 :7 1

c1a4
4
:3 0 1 :3 0 2
:a 0 3738 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 4 :3 0 10
:7 0 31 30 :3 0
4 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 4 :3 0 14
:7 0 41 40 :3 0
8 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d 1ac 0
2b 4 :3 0 18
:7 0 51 50 :3 0
4 :3 0 19 :7 0
55 54 :3 0 31
1d2 0 2f 8
:3 0 1a :7 0 59
58 :3 0 8 :3 0
1b :7 0 5d 5c
:3 0 35 1f8 0
33 8 :3 0 1c
:7 0 61 60 :3 0
8 :3 0 1d :7 0
65 64 :3 0 39
:2 0 37 4 :3 0
1e :7 0 69 68
:3 0 4 :3 0 1f
:7 0 6d 6c :3 0
20 :3 0 21 :3 0
22 :2 0 4 71
72 0 6f 73
0 3738 2 74
:2 0 24 :2 0 57
4 :3 0 24 :2 0
55 77 79 :6 0
7c 7a 0 3736
0 23 :6 0 24
:2 0 5b 4 :3 0
59 7e 80 :6 0
83 81 0 3736
0 25 :6 0 24
:2 0 5f 4 :3 0
5d 85 87 :6 0
8a 88 0 3736
0 26 :6 0 24
:2 0 63 4 :3 0
61 8c 8e :6 0
91 8f 0 3736
0 27 :6 0 24
:2 0 67 4 :3 0
65 93 95 :6 0
98 96 0 3736
0 28 :6 0 2b
:2 0 6b 4 :3 0
69 9a 9c :6 0
9f 9d 0 3736
0 29 :6 0 2d
:2 0 6f 4 :3 0
6d a1 a3 :6 0
a6 a4 0 3736
0 2a :6 0 2f
:2 0 73 4 :3 0
71 a8 aa :6 0
ad ab 0 3736
0 2c :6 0 2f
:2 0 77 4 :3 0
75 af b1 :6 0
b4 b2 0 3736
0 2e :6 0 2f
:2 0 7b 4 :3 0
79 b6 b8 :6 0
bb b9 0 3736
0 30 :6 0 2f
:2 0 7f 4 :3 0
7d bd bf :6 0
c2 c0 0 3736
0 31 :6 0 2f
:2 0 83 4 :3 0
81 c4 c6 :6 0
c9 c7 0 3736
0 32 :6 0 2f
:2 0 87 4 :3 0
85 cb cd :6 0
d0 ce 0 3736
0 33 :6 0 2f
:2 0 8b 4 :3 0
89 d2 d4 :6 0
d7 d5 0 3736
0 34 :6 0 2f
:2 0 8f 4 :3 0
8d d9 db :6 0
de dc 0 3736
0 35 :6 0 2f
:2 0 93 4 :3 0
91 e0 e2 :6 0
e5 e3 0 3736
0 36 :6 0 2f
:2 0 97 4 :3 0
95 e7 e9 :6 0
ec ea 0 3736
0 37 :6 0 24
:2 0 9b 4 :3 0
99 ee f0 :6 0
f3 f1 0 3736
0 38 :6 0 24
:2 0 9f 4 :3 0
9d f5 f7 :6 0
fa f8 0 3736
0 39 :6 0 3c
:2 0 a3 4 :3 0
a1 fc fe :6 0
101 ff 0 3736
0 3a :6 0 a9
499 0 a7 4
:3 0 a5 103 105
:6 0 108 106 0
3736 0 3b :6 0
40 :2 0 ad 3e
:3 0 10a :7 0 10d
10b 0 3736 0
3d :6 0 4 :3 0
40 :2 0 ab 10f
111 :6 0 114 112
0 3736 0 3f
:6 0 40 :2 0 b1
4 :3 0 af 116
118 :6 0 11b 119
0 3736 0 41
:6 0 40 :2 0 b5
4 :3 0 b3 11d
11f :6 0 122 120
0 3736 0 42
:6 0 40 :2 0 b9
4 :3 0 b7 124
126 :6 0 129 127
0 3736 0 43
:6 0 bf 545 0
bd 4 :3 0 bb
12b 12d :6 0 130
12e 0 3736 0
44 :6 0 24 :2 0
c3 3e :3 0 132
:7 0 135 133 0
3736 0 45 :6 0
4 :3 0 47 :2 0
c1 137 139 :6 0
13c 13a 0 3736
0 46 :6 0 24
:2 0 c7 4 :3 0
c5 13e 140 :6 0
143 141 0 3736
0 48 :6 0 24
:2 0 cb 4 :3 0
c9 145 147 :6 0
14a 148 0 3736
0 49 :6 0 2b
:2 0 cf 4 :3 0
cd 14c 14e :6 0
151 14f 0 3736
0 4a :6 0 47
:2 0 d3 4 :3 0
d1 153 155 :6 0
158 156 0 3736
0 4b :6 0 4e
:2 0 d7 4 :3 0
d5 15a 15c :6 0
15f 15d 0 3736
0 4c :6 0 4e
:2 0 d9 8 :3 0
161 :7 0 165 162
163 3736 0 4d
:6 0 4e :2 0 db
8 :3 0 167 :7 0
16b 168 169 3736
0 4f :6 0 4e
:2 0 dd 8 :3 0
16d :7 0 171 16e
16f 3736 0 50
:6 0 4e :2 0 df
8 :3 0 173 :7 0
177 174 175 3736
0 51 :6 0 4e
:2 0 e1 8 :3 0
179 :7 0 17d 17a
17b 3736 0 52
:6 0 4e :2 0 e3
8 :3 0 17f :7 0
183 180 181 3736
0 53 :6 0 4e
:2 0 e5 8 :3 0
185 :7 0 189 186
187 3736 0 54
:6 0 4e :2 0 e7
8 :3 0 18b :7 0
18f 18c 18d 3736
0 55 :6 0 4e
:2 0 e9 8 :3 0
191 :7 0 195 192
193 3736 0 56
:6 0 4e :2 0 eb
8 :3 0 197 :7 0
19b 198 199 3736
0 57 :6 0 4e
:2 0 ed 8 :3 0
19d :7 0 1a1 19e
19f 3736 0 58
:6 0 4e :2 0 ef
8 :3 0 1a3 :7 0
1a7 1a4 1a5 3736
0 59 :6 0 4e
:2 0 f1 8 :3 0
1a9 :7 0 1ad 1aa
1ab 3736 0 5a
:6 0 4e :2 0 f3
8 :3 0 1af :7 0
1b3 1b0 1b1 3736
0 5b :6 0 4e
:2 0 f5 8 :3 0
1b5 :7 0 1b9 1b6
1b7 3736 0 5c
:6 0 4e :2 0 f7
8 :3 0 1bb :7 0
1bf 1bc 1bd 3736
0 5d :6 0 4e
:2 0 f9 8 :3 0
1c1 :7 0 1c5 1c2
1c3 3736 0 5e
:6 0 4e :2 0 fb
8 :3 0 1c7 :7 0
1cb 1c8 1c9 3736
0 5f :6 0 4e
:2 0 fd 8 :3 0
1cd :7 0 1d1 1ce
1cf 3736 0 60
:6 0 4e :2 0 ff
8 :3 0 1d3 :7 0
1d7 1d4 1d5 3736
0 61 :6 0 4e
:2 0 101 8 :3 0
1d9 :7 0 1dd 1da
1db 3736 0 62
:6 0 4e :2 0 103
8 :3 0 1df :7 0
1e3 1e0 1e1 3736
0 63 :6 0 4e
:2 0 105 8 :3 0
1e5 :7 0 1e9 1e6
1e7 3736 0 64
:6 0 68 :2 0 107
8 :3 0 1eb :7 0
1ef 1ec 1ed 3736
0 65 :6 0 68
:2 0 109 67 :3 0
1f1 :7 0 1f5 1f2
1f3 3736 0 66
:6 0 4e :2 0 10b
67 :3 0 1f7 :7 0
1fb 1f8 1f9 3736
0 69 :6 0 4e
:2 0 10d 8 :3 0
1fd :7 0 201 1fe
1ff 3736 0 6a
:6 0 4e :2 0 10f
8 :3 0 203 :7 0
207 204 205 3736
0 6b :6 0 4e
:2 0 111 8 :3 0
209 :7 0 20d 20a
20b 3736 0 6c
:6 0 4e :2 0 113
8 :3 0 20f :7 0
213 210 211 3736
0 6d :6 0 4e
:2 0 115 8 :3 0
215 :7 0 219 216
217 3736 0 6e
:6 0 4e :2 0 117
8 :3 0 21b :7 0
21f 21c 21d 3736
0 6f :6 0 47
:2 0 119 8 :3 0
221 :7 0 225 222
223 3736 0 70
:6 0 4e :2 0 11d
4 :3 0 11b 227
229 :6 0 22c 22a
0 3736 0 71
:6 0 4e :2 0 11f
8 :3 0 22e :7 0
232 22f 230 3736
0 72 :6 0 4e
:2 0 121 8 :3 0
234 :7 0 238 235
236 3736 0 73
:6 0 76 :2 0 123
8 :3 0 23a :7 0
23e 23b 23c 3736
0 74 :6 0 78
:2 0 127 4 :3 0
125 240 242 :6 0
245 243 0 3736
0 75 :6 0 76
:2 0 12b 4 :3 0
129 247 249 :6 0
24c 24a 0 3736
0 77 :6 0 4e
:2 0 12f 4 :3 0
12d 24e 250 :6 0
253 251 0 3736
0 79 :6 0 4e
:2 0 131 8 :3 0
255 :7 0 259 256
257 3736 0 7a
:6 0 24 :2 0 133
8 :3 0 25b :7 0
25f 25c 25d 3736
0 7b :6 0 24
:2 0 137 7d :3 0
135 261 263 :6 0
266 264 0 3736
0 7c :6 0 24
:2 0 13b 7d :3 0
139 268 26a :6 0
26d 26b 0 3736
0 7e :6 0 24
:2 0 13f 4 :3 0
13d 26f 271 :6 0
274 272 0 3736
0 7f :6 0 24
:2 0 143 4 :3 0
141 276 278 :6 0
27b 279 0 3736
0 80 :6 0 47
:2 0 147 4 :3 0
145 27d 27f :6 0
282 280 0 3736
0 81 :6 0 4e
:2 0 14b 4 :3 0
149 284 286 :6 0
289 287 0 3736
0 82 :6 0 4e
:2 0 14d 8 :3 0
28b :7 0 28f 28c
28d 3736 0 83
:6 0 4e :2 0 14f
8 :3 0 291 :7 0
295 292 293 3736
0 84 :6 0 47
:2 0 151 8 :3 0
297 :7 0 29b 298
299 3736 0 85
:6 0 47 :2 0 153
8 :3 0 29d 0
2 :5 0 2a1 29e
29f 3736 0 86
:6 0 4e :2 0 155
8 :3 0 2a3 0
2 :5 0 2a7 2a4
2a5 3736 0 87
:6 0 4e :2 0 157
8 :3 0 2a9 0
2 :5 0 2ad 2aa
2ab 3736 0 88
:6 0 4e :2 0 159
8 :3 0 2af 0
2 :5 0 2b3 2b0
2b1 3736 0 89
:6 0 24 :2 0 15b
8 :3 0 2b5 0
2 :5 0 2b9 2b6
2b7 3736 0 8a
:6 0 4e :2 0 15f
4 :3 0 15d 2bb
2bd :6 0 2c0 2be
0 3736 0 8b
:6 0 163 c71 0
161 8 :3 0 2c2
0 2 :5 0 2c6
2c3 2c4 3736 0
8c :6 0 167 ca5
0 165 8 :3 0
2c8 :7 0 2cb 2c9
0 3736 0 8d
:6 0 8 :3 0 2cd
:7 0 2d0 2ce 0
3736 0 8e :6 0
16b cd9 0 169
8 :3 0 2d2 :7 0
2d5 2d3 0 3736
0 8f :6 0 8
:3 0 2d7 :7 0 2da
2d8 0 3736 0
90 :6 0 16f d0d
0 16d 8 :3 0
2dc :7 0 2df 2dd
0 3736 0 91
:6 0 8 :3 0 2e1
:7 0 2e4 2e2 0
3736 0 92 :9 0
171 8 :3 0 2e6
:7 0 2e9 2e7 0
3736 0 93 :6 0
21 :3 0 22 :2 0
4 2eb 2ec 0
2ed :7 0 2f0 2ee
0 3736 0 94
:6 0 95 :3 0 96
:a 0 2 2ff :4 0
2f2 2f5 0 2f3
:3 0 97 :3 0 98
:3 0 99 :3 0 25
:3 0 9a :3 0 25
:3 0 9b :3 0 39
:4 0 9c 1 :8 0
300 2f2 2f5 301
0 3736 173 301
303 300 302 :6 0
2ff :7 0 301 95
:3 0 9d :a 0 3
31a :5 0 305 308
0 306 :3 0 9e
:3 0 9f :3 0 a0
:3 0 a1 :3 0 a2
:3 0 a3 :3 0 a0
:3 0 a4 :3 0 a2
:3 0 a5 :3 0 a2
:3 0 a6 :3 0 a2
:3 0 a7 :3 0 a8
:3 0 9f :4 0 a9
1 :8 0 31b 305
308 31c 0 3736
175 31c 31e 31b
31d :6 0 31a :7 0
31c 327 328 0
177 21 :3 0 22
:2 0 4 320 321
0 322 :7 0 325
323 0 3736 0
aa :6 0 32e 32f
0 179 21 :3 0
22 :2 0 4 329
:7 0 32c 32a 0
3736 0 ab :6 0
335 336 0 17b
21 :3 0 22 :2 0
4 330 :7 0 333
331 0 3736 0
ac :6 0 33b 33c
0 17d 21 :3 0
22 :2 0 4 337
:7 0 33a 338 0
3736 0 ad :6 0
ae :3 0 af :3 0
ae :3 0 b0 :3 0
33e 33f 0 2
:4 0 17f 340 342
33d 344 343 :2 0
b1 :3 0 b2 :3 0
346 347 0 b3
:4 0 ae :3 0 b4
:3 0 34a 34b 0
2 :4 0 181 34c
34e b5 :4 0 b6
:2 0 b7 :3 0 183
351 353 :3 0 b8
:4 0 b6 :2 0 b9
:4 0 186 356 358
:3 0 b6 :2 0 3
:3 0 189 35a 35c
:3 0 b6 :2 0 b9
:4 0 18c 35e 360
:3 0 b6 :2 0 ba
:4 0 18f 362 364
:3 0 b6 :2 0 b9
:4 0 192 366 368
:3 0 b6 :2 0 5
:3 0 195 36a 36c
:3 0 b6 :2 0 b9
:4 0 198 36e 370
:3 0 b6 :2 0 ba
:4 0 19b 372 374
:3 0 b6 :2 0 b9
:4 0 19e 376 378
:3 0 b6 :2 0 6
:3 0 1a1 37a 37c
:3 0 b6 :2 0 b9
:4 0 1a4 37e 380
:3 0 b6 :2 0 ba
:4 0 1a7 382 384
:3 0 b6 :2 0 a2
:3 0 bb :3 0 7
:3 0 1aa 388 38a
bc :4 0 1ac 387
38d 1af 386 38f
:3 0 b6 :2 0 ba
:4 0 1b2 391 393
:3 0 b6 :2 0 a2
:3 0 bb :3 0 9
:3 0 1b5 397 399
bc :4 0 1b7 396
39c 1ba 395 39e
:3 0 b6 :2 0 ba
:4 0 1bd 3a0 3a2
:3 0 b6 :2 0 a2
:3 0 bb :3 0 a
:3 0 1c0 3a6 3a8
bc :4 0 1c2 3a5
3ab 1c5 3a4 3ad
:3 0 b6 :2 0 ba
:4 0 1c8 3af 3b1
:3 0 b6 :2 0 a2
:3 0 bb :3 0 b
:3 0 1cb 3b5 3b7
bc :4 0 1cd 3b4
3ba 1d0 3b3 3bc
:3 0 b6 :2 0 ba
:4 0 1d3 3be 3c0
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c
:3 0 1d6 3c4 3c6
bc :4 0 1d8 3c3
3c9 1db 3c2 3cb
:3 0 b6 :2 0 ba
:4 0 1de 3cd 3cf
:3 0 b6 :2 0 a2
:3 0 bb :3 0 d
:3 0 1e1 3d3 3d5
bc :4 0 1e3 3d2
3d8 1e6 3d1 3da
:3 0 b6 :2 0 ba
:4 0 1e9 3dc 3de
:3 0 b6 :2 0 a2
:3 0 bb :3 0 e
:3 0 1ec 3e2 3e4
bc :4 0 1ee 3e1
3e7 1f1 3e0 3e9
:3 0 b6 :2 0 ba
:4 0 1f4 3eb 3ed
:3 0 b6 :2 0 a2
:3 0 bb :3 0 f
:3 0 1f7 3f1 3f3
bc :4 0 1f9 3f0
3f6 1fc 3ef 3f8
:3 0 b6 :2 0 ba
:4 0 1ff 3fa 3fc
:3 0 b6 :2 0 b9
:4 0 202 3fe 400
:3 0 b6 :2 0 10
:3 0 205 402 404
:3 0 b6 :2 0 b9
:4 0 208 406 408
:3 0 b6 :2 0 ba
:4 0 20b 40a 40c
:3 0 b6 :2 0 b9
:4 0 20e 40e 410
:3 0 b6 :2 0 11
:3 0 211 412 414
:3 0 b6 :2 0 b9
:4 0 214 416 418
:3 0 b6 :2 0 ba
:4 0 217 41a 41c
:3 0 b6 :2 0 b9
:4 0 21a 41e 420
:3 0 b6 :2 0 12
:3 0 21d 422 424
:3 0 b6 :2 0 b9
:4 0 220 426 428
:3 0 b6 :2 0 ba
:4 0 223 42a 42c
:3 0 b6 :2 0 b9
:4 0 226 42e 430
:3 0 b6 :2 0 13
:3 0 229 432 434
:3 0 b6 :2 0 b9
:4 0 22c 436 438
:3 0 b6 :2 0 ba
:4 0 22f 43a 43c
:3 0 b6 :2 0 b9
:4 0 232 43e 440
:3 0 b6 :2 0 14
:3 0 235 442 444
:3 0 b6 :2 0 b9
:4 0 238 446 448
:3 0 b6 :2 0 ba
:4 0 23b 44a 44c
:3 0 b6 :2 0 a2
:3 0 bb :3 0 15
:3 0 23e 450 452
bc :4 0 240 44f
455 243 44e 457
:3 0 b6 :2 0 ba
:4 0 246 459 45b
:3 0 b6 :2 0 b9
:4 0 249 45d 45f
:3 0 b6 :2 0 16
:3 0 24c 461 463
:3 0 b6 :2 0 b9
:4 0 24f 465 467
:3 0 b6 :2 0 ba
:4 0 252 469 46b
:3 0 b6 :2 0 b9
:4 0 255 46d 46f
:3 0 b6 :2 0 17
:3 0 258 471 473
:3 0 b6 :2 0 b9
:4 0 25b 475 477
:3 0 b6 :2 0 ba
:4 0 25e 479 47b
:3 0 b6 :2 0 b9
:4 0 261 47d 47f
:3 0 b6 :2 0 18
:3 0 264 481 483
:3 0 b6 :2 0 b9
:4 0 267 485 487
:3 0 b6 :2 0 ba
:4 0 26a 489 48b
:3 0 b6 :2 0 b9
:4 0 26d 48d 48f
:3 0 b6 :2 0 19
:3 0 270 491 493
:3 0 b6 :2 0 b9
:4 0 273 495 497
:3 0 b6 :2 0 ba
:4 0 276 499 49b
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1a
:3 0 279 49f 4a1
bc :4 0 27b 49e
4a4 27e 49d 4a6
:3 0 b6 :2 0 ba
:4 0 281 4a8 4aa
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1b
:3 0 284 4ae 4b0
bc :4 0 286 4ad
4b3 289 4ac 4b5
:3 0 b6 :2 0 ba
:4 0 28c 4b7 4b9
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1c
:3 0 28f 4bd 4bf
bc :4 0 291 4bc
4c2 294 4bb 4c4
:3 0 b6 :2 0 ba
:4 0 297 4c6 4c8
:3 0 b6 :2 0 a2
:3 0 bb :3 0 1d
:3 0 29a 4cc 4ce
bc :4 0 29c 4cb
4d1 29f 4ca 4d3
:3 0 b6 :2 0 ba
:4 0 2a2 4d5 4d7
:3 0 b6 :2 0 b9
:4 0 2a5 4d9 4db
:3 0 b6 :2 0 1e
:3 0 2a8 4dd 4df
:3 0 b6 :2 0 b9
:4 0 2ab 4e1 4e3
:3 0 b6 :2 0 ba
:4 0 2ae 4e5 4e7
:3 0 b6 :2 0 b9
:4 0 2b1 4e9 4eb
:3 0 b6 :2 0 1f
:3 0 2b4 4ed 4ef
:3 0 b6 :2 0 b9
:4 0 2b7 4f1 4f3
:3 0 b6 :2 0 bd
:4 0 2ba 4f5 4f7
:3 0 2bd 348 4f9
:2 0 4fb 2c2 4fc
345 4fb 0 4fd
2c4 0 3696 ae
:3 0 af :3 0 4fe
4ff 0 ae :3 0
be :3 0 501 502
0 47 :2 0 2
:4 0 bf :2 0 c0
:2 0 47 :2 0 2c6
507 509 :3 0 2c9
503 50b 500 50d
50c :2 0 b1 :3 0
c1 :3 0 50f 510
0 b3 :4 0 c2
:4 0 b6 :2 0 b7
:3 0 2cd 514 516
:3 0 2d0 511 518
:2 0 51a 2d3 51b
50e 51a 0 51c
2d5 0 3696 25
:3 0 3 :3 0 51d
51e 0 3696 3f
:3 0 5 :3 0 520
521 0 3696 42
:3 0 6 :3 0 523
524 0 3696 2a
:3 0 10 :3 0 526
527 0 3696 2c
:3 0 11 :3 0 529
52a 0 3696 2e
:3 0 16 :3 0 52c
52d 0 3696 30
:3 0 17 :3 0 52f
530 0 3696 31
:3 0 18 :3 0 532
533 0 3696 32
:3 0 19 :3 0 535
536 0 3696 29
:3 0 1f :3 0 538
539 0 3696 59
:3 0 7 :3 0 53b
53c 0 3696 57
:3 0 9 :3 0 53e
53f 0 3696 58
:3 0 e :3 0 541
542 0 3696 56
:3 0 1a :3 0 544
545 0 3696 5a
:3 0 b :3 0 547
548 0 3696 5c
:3 0 f :3 0 54a
54b 0 3696 5b
:3 0 c :3 0 54d
54e 0 3696 50
:3 0 1d :3 0 550
551 0 3696 4d
:3 0 a :3 0 553
554 0 3696 5d
:3 0 d :3 0 556
557 0 3696 52
:3 0 1b :3 0 559
55a 0 3696 53
:3 0 1c :3 0 55c
55d 0 3696 72
:3 0 4e :2 0 55f
560 0 3696 73
:3 0 4e :2 0 562
563 0 3696 a2
:3 0 4d :3 0 4e
:2 0 2d7 565 568
c3 :3 0 c4 :2 0
c5 :3 0 56a 56c
0 2dc 56b 56e
:3 0 56f :2 0 3
:3 0 c6 :2 0 2df
572 573 :3 0 574
:2 0 575 :2 0 570
577 576 :2 0 ae
:3 0 af :3 0 579
57a 0 ae :3 0
be :3 0 57c 57d
0 c7 :2 0 2
:4 0 c8 :2 0 c0
:2 0 47 :2 0 2e1
582 584 :3 0 2e4
57e 586 57b 588
587 :2 0 b1 :3 0
c1 :3 0 58a 58b
0 b3 :4 0 c9
:4 0 b6 :2 0 b7
:3 0 2e8 58f 591
:3 0 b6 :2 0 ca
:4 0 2eb 593 595
:3 0 b6 :2 0 cb
:4 0 2ee 597 599
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 cc :3 0 59e
59f 0 2f1 59d
5a1 bc :4 0 2f3
59c 5a4 2f6 59b
5a6 :3 0 2f9 58c
5a8 :2 0 5aa 2fc
5ab 589 5aa 0
5ac 2fe 0 5d5
ae :3 0 af :3 0
5ad 5ae 0 ae
:3 0 be :3 0 5b0
5b1 0 47 :2 0
2 :4 0 cd :2 0
c0 :2 0 47 :2 0
300 5b6 5b8 :3 0
303 5b2 5ba 5af
5bc 5bb :2 0 b1
:3 0 c1 :3 0 5be
5bf 0 b3 :4 0
ce :4 0 b6 :2 0
b7 :3 0 307 5c3
5c5 :3 0 30a 5c0
5c7 :2 0 5c9 30d
5ca 5bd 5c9 0
5cb 30f 0 5d5
cf :3 0 d0 :3 0
5cc 5cd 0 c3
:3 0 cc :3 0 5cf
5d0 0 d1 :3 0
311 5ce 5d3 :2 0
5d5 314 5d6 578
5d5 0 5d7 318
0 3696 10 :3 0
c6 :2 0 31a 5d9
5da :3 0 5db :2 0
5dc :2 0 12 :3 0
c6 :2 0 31c 5df
5e0 :3 0 5e1 :2 0
5e2 :2 0 5dd 5e4
5e3 :2 0 13 :3 0
c6 :2 0 31e 5e7
5e8 :3 0 5e9 :2 0
5ea :2 0 5e5 5ec
5eb :2 0 14 :3 0
c6 :2 0 320 5ef
5f0 :3 0 5f1 :2 0
5f2 :2 0 5ed 5f4
5f3 :2 0 a2 :3 0
5c :3 0 4e :2 0
322 5f6 5f9 c3
:3 0 c4 :2 0 d2
:3 0 5fb 5fd 0
327 5fc 5ff :3 0
600 :2 0 5f5 602
601 :2 0 16 :3 0
c6 :2 0 32a 605
606 :3 0 607 :2 0
608 :2 0 a2 :3 0
5c :3 0 4e :2 0
32c 60a 60d c3
:3 0 d3 :2 0 d4
:3 0 60f 611 0
331 610 613 :3 0
614 :2 0 609 616
615 :2 0 ae :3 0
af :3 0 618 619
0 ae :3 0 be
:3 0 61b 61c 0
c7 :2 0 2 :4 0
d5 :2 0 c0 :2 0
47 :2 0 334 621
623 :3 0 337 61d
625 61a 627 626
:2 0 b1 :3 0 c1
:3 0 629 62a 0
b3 :4 0 d6 :4 0
b6 :2 0 b7 :3 0
33b 62e 630 :3 0
b6 :2 0 ca :4 0
33e 632 634 :3 0
b6 :2 0 cb :4 0
341 636 638 :3 0
b6 :2 0 a2 :3 0
bb :3 0 c3 :3 0
d7 :3 0 63d 63e
0 344 63c 640
bc :4 0 346 63b
643 349 63a 645
:3 0 34c 62b 647
:2 0 649 34f 64a
628 649 0 64b
351 0 675 ae
:3 0 af :3 0 64c
64d 0 ae :3 0
be :3 0 64f 650
0 47 :2 0 2
:4 0 2b :2 0 c0
:2 0 47 :2 0 353
655 657 :3 0 356
651 659 64e 65b
65a :2 0 b1 :3 0
c1 :3 0 65d 65e
0 b3 :4 0 d8
:4 0 b6 :2 0 b7
:3 0 35a 662 664
:3 0 35d 65f 666
:2 0 668 360 669
65c 668 0 66a
362 0 675 cf
:3 0 d0 :3 0 66b
66c 0 c3 :3 0
d7 :3 0 66e 66f
0 d1 :3 0 364
66d 672 :2 0 675
d9 :3 0 367 6e2
16 :3 0 c6 :2 0
36b 677 678 :3 0
679 :2 0 67a :2 0
17 :3 0 c6 :2 0
36d 67d 67e :3 0
67f :2 0 680 :2 0
67b 682 681 :2 0
ae :3 0 af :3 0
684 685 0 ae
:3 0 be :3 0 687
688 0 c7 :2 0
2 :4 0 da :2 0
c0 :2 0 47 :2 0
36f 68d 68f :3 0
372 689 691 686
693 692 :2 0 b1
:3 0 c1 :3 0 695
696 0 b3 :4 0
db :4 0 b6 :2 0
b7 :3 0 376 69a
69c :3 0 b6 :2 0
ca :4 0 379 69e
6a0 :3 0 b6 :2 0
cb :4 0 37c 6a2
6a4 :3 0 b6 :2 0
a2 :3 0 bb :3 0
c3 :3 0 d7 :3 0
6a9 6aa 0 37f
6a8 6ac bc :4 0
381 6a7 6af 384
6a6 6b1 :3 0 387
697 6b3 :2 0 6b5
38a 6b6 694 6b5
0 6b7 38c 0
6e0 ae :3 0 af
:3 0 6b8 6b9 0
ae :3 0 be :3 0
6bb 6bc 0 47
:2 0 2 :4 0 dc
:2 0 c0 :2 0 47
:2 0 38e 6c1 6c3
:3 0 391 6bd 6c5
6ba 6c7 6c6 :2 0
b1 :3 0 c1 :3 0
6c9 6ca 0 b3
:4 0 dd :4 0 b6
:2 0 b7 :3 0 395
6ce 6d0 :3 0 398
6cb 6d2 :2 0 6d4
39b 6d5 6c8 6d4
0 6d6 39d 0
6e0 cf :3 0 d0
:3 0 6d7 6d8 0
c3 :3 0 d7 :3 0
6da 6db 0 d1
:3 0 39f 6d9 6de
:2 0 6e0 3a2 6e1
683 6e0 0 6e3
617 675 0 6e3
3a6 0 6e4 3a9
6e5 603 6e4 0
6e6 3ab 0 3696
a2 :3 0 4d :3 0
4e :2 0 3ad 6e7
6ea d3 :2 0 de
:2 0 3b2 6ec 6ee
:3 0 a2 :3 0 5b
:3 0 4e :2 0 3b5
6f0 6f3 d3 :2 0
de :2 0 3ba 6f5
6f7 :3 0 6ef 6f9
6f8 :2 0 a2 :3 0
57 :3 0 4e :2 0
3bd 6fb 6fe d3
:2 0 de :2 0 3c2
700 702 :3 0 6fa
704 703 :2 0 ae
:3 0 af :3 0 706
707 0 ae :3 0
be :3 0 709 70a
0 c7 :2 0 2
:4 0 df :2 0 c0
:2 0 47 :2 0 3c5
70f 711 :3 0 3c8
70b 713 708 715
714 :2 0 b1 :3 0
c1 :3 0 717 718
0 b3 :4 0 e0
:4 0 b6 :2 0 b7
:3 0 3cc 71c 71e
:3 0 b6 :2 0 ca
:4 0 3cf 720 722
:3 0 b6 :2 0 cb
:4 0 3d2 724 726
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 72b
72c 0 3d5 72a
72e bc :4 0 3d7
729 731 3da 728
733 :3 0 3dd 719
735 :2 0 737 3e0
738 716 737 0
739 3e2 0 762
ae :3 0 af :3 0
73a 73b 0 ae
:3 0 be :3 0 73d
73e 0 47 :2 0
2 :4 0 e1 :2 0
c0 :2 0 47 :2 0
3e4 743 745 :3 0
3e7 73f 747 73c
749 748 :2 0 b1
:3 0 c1 :3 0 74b
74c 0 b3 :4 0
e2 :4 0 b6 :2 0
b7 :3 0 3eb 750
752 :3 0 3ee 74d
754 :2 0 756 3f1
757 74a 756 0
758 3f3 0 762
cf :3 0 d0 :3 0
759 75a 0 c3
:3 0 d7 :3 0 75c
75d 0 d1 :3 0
3f5 75b 760 :2 0
762 3f8 763 705
762 0 764 3fc
0 3696 15 :3 0
c6 :2 0 3fe 766
767 :3 0 768 :2 0
769 :2 0 54 :3 0
e3 :2 0 76b 76c
0 76e 400 773
54 :3 0 15 :3 0
76f 770 0 772
402 774 76a 76e
0 775 0 772
0 775 404 0
3696 a2 :3 0 4d
:3 0 4e :2 0 407
776 779 c3 :3 0
c4 :2 0 c5 :3 0
77b 77d 0 40c
77c 77f :3 0 780
:2 0 5 :3 0 e4
:2 0 40f 783 784
:3 0 785 :2 0 786
:2 0 781 788 787
:2 0 6 :3 0 e4
:2 0 411 78b 78c
:3 0 78d :2 0 78e
:2 0 789 790 78f
:2 0 e5 :3 0 e6
:3 0 6 :3 0 e5
:3 0 e6 :3 0 5
:3 0 6a :3 0 e7
:4 0 e8 1 :8 0
7a0 21 :3 0 e9
:3 0 79b 79c 0
ea :3 0 79d 79e
0 7a0 413 7f3
eb :3 0 21 :3 0
e9 :3 0 7a2 7a3
0 ea :3 0 7a4
7a5 0 7a7 416
7a9 418 7a8 7a7
:2 0 7f1 ec :3 0
21 :3 0 e9 :3 0
7ac 7ad 0 ea
:3 0 7ae 7af 0
7e9 ae :3 0 af
:3 0 7b1 7b2 0
ae :3 0 be :3 0
7b4 7b5 0 ed
:2 0 2 :4 0 ee
:2 0 c0 :2 0 47
:2 0 41a 7ba 7bc
:3 0 41d 7b6 7be
7b3 7c0 7bf :2 0
b1 :3 0 c1 :3 0
7c2 7c3 0 b3
:4 0 ef :4 0 b6
:2 0 b7 :3 0 421
7c7 7c9 :3 0 b6
:2 0 ca :4 0 424
7cb 7cd :3 0 b6
:2 0 f0 :4 0 427
7cf 7d1 :3 0 b6
:2 0 ea :3 0 42a
7d3 7d5 :3 0 b6
:2 0 f1 :4 0 42d
7d7 7d9 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 430 7dc 7e0
434 7db 7e2 :3 0
437 7c4 7e4 :2 0
7e6 43a 7e7 7c1
7e6 0 7e8 43c
0 7e9 43e 7ec
:3 0 7ec 0 7ec
7eb 7e9 7ea :6 0
7ee 4 :3 0 441
7f0 443 7ef 7ee
:2 0 7f1 445 :2 0
7f3 0 7f3 7f2
7a0 7f1 :6 0 86d
1 :3 0 21 :3 0
e9 :3 0 7f5 7f6
0 21 :3 0 d3
:2 0 f5 :3 0 7f8
7fa 0 44a 7f9
7fc :3 0 7fd :2 0
a2 :3 0 6a :3 0
4e :2 0 44d 7ff
802 f6 :2 0 4e
:2 0 452 804 806
:3 0 807 :2 0 7fe
809 808 :2 0 ae
:3 0 af :3 0 80b
80c 0 ae :3 0
be :3 0 80e 80f
0 c7 :2 0 2
:4 0 f7 :2 0 c0
:2 0 47 :2 0 455
814 816 :3 0 458
810 818 80d 81a
819 :2 0 b1 :3 0
c1 :3 0 81c 81d
0 b3 :4 0 f8
:4 0 b6 :2 0 b7
:3 0 45c 821 823
:3 0 b6 :2 0 ca
:4 0 45f 825 827
:3 0 b6 :2 0 cb
:4 0 462 829 82b
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 f9 :3 0 830
831 0 465 82f
833 bc :4 0 467
82e 836 46a 82d
838 :3 0 46d 81e
83a :2 0 83c 470
83d 81b 83c 0
83e 472 0 867
ae :3 0 af :3 0
83f 840 0 ae
:3 0 be :3 0 842
843 0 47 :2 0
2 :4 0 fa :2 0
c0 :2 0 47 :2 0
474 848 84a :3 0
477 844 84c 841
84e 84d :2 0 b1
:3 0 c1 :3 0 850
851 0 b3 :4 0
fb :4 0 b6 :2 0
b7 :3 0 47b 855
857 :3 0 47e 852
859 :2 0 85b 481
85c 84f 85b 0
85d 483 0 867
cf :3 0 d0 :3 0
85e 85f 0 c3
:3 0 f9 :3 0 861
862 0 d1 :3 0
485 860 865 :2 0
867 488 868 80a
867 0 869 48c
0 86d 8a :3 0
47 :2 0 86a 86b
0 86d 48e 86e
791 86d 0 86f
492 0 3696 5
:3 0 c6 :2 0 494
871 872 :3 0 873
:2 0 874 :2 0 6
:3 0 c6 :2 0 496
877 878 :3 0 879
:2 0 87a :2 0 875
87c 87b :2 0 b7
:3 0 3f :3 0 e7
:4 0 fc 1 :8 0
887 21 :3 0 e9
:3 0 882 883 0
ea :3 0 884 885
0 887 498 8da
eb :3 0 21 :3 0
e9 :3 0 889 88a
0 ea :3 0 88b
88c 0 88e 49b
890 49d 88f 88e
:2 0 8d8 ec :3 0
21 :3 0 e9 :3 0
893 894 0 ea
:3 0 895 896 0
8d0 ae :3 0 af
:3 0 898 899 0
ae :3 0 be :3 0
89b 89c 0 ed
:2 0 2 :4 0 fd
:2 0 c0 :2 0 47
:2 0 49f 8a1 8a3
:3 0 4a2 89d 8a5
89a 8a7 8a6 :2 0
b1 :3 0 c1 :3 0
8a9 8aa 0 b3
:4 0 fe :4 0 b6
:2 0 b7 :3 0 4a6
8ae 8b0 :3 0 b6
:2 0 ca :4 0 4a9
8b2 8b4 :3 0 b6
:2 0 f0 :4 0 4ac
8b6 8b8 :3 0 b6
:2 0 ea :3 0 4af
8ba 8bc :3 0 b6
:2 0 f1 :4 0 4b2
8be 8c0 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 4b5 8c3 8c7
4b9 8c2 8c9 :3 0
4bc 8ab 8cb :2 0
8cd 4bf 8ce 8a8
8cd 0 8cf 4c1
0 8d0 4c3 8d3
:3 0 8d3 0 8d3
8d2 8d0 8d1 :6 0
8d5 6 :3 0 4c6
8d7 4c8 8d6 8d5
:2 0 8d8 4ca :2 0
8da 0 8da 8d9
887 8d8 :6 0 8dc
1 :3 0 4cd 8dd
87d 8dc 0 8de
4cf 0 3696 41
:3 0 3f :3 0 8df
8e0 0 3696 6b
:3 0 ff :3 0 100
:3 0 8e3 8e4 0
101 :3 0 a2 :3 0
50 :3 0 4e :2 0
4d1 8e7 8ea c3
:3 0 102 :3 0 8ec
8ed 0 4d4 8e6
8ef 8f0 :2 0 103
:2 0 4d7 8e5 8f3
8e2 8f4 0 3696
50 :3 0 101 :3 0
a2 :3 0 50 :3 0
4e :2 0 4da 8f8
8fb c3 :3 0 104
:3 0 8fd 8fe 0
4dd 8f7 900 8f6
901 0 3696 55
:3 0 ff :3 0 100
:3 0 904 905 0
101 :3 0 a2 :3 0
5c :3 0 4e :2 0
4e0 908 90b c3
:3 0 102 :3 0 90d
90e 0 4e3 907
910 911 :2 0 103
:2 0 4e6 906 914
903 915 0 3696
5c :3 0 101 :3 0
a2 :3 0 5c :3 0
4e :2 0 4e9 919
91c c3 :3 0 104
:3 0 91e 91f 0
4ec 918 921 917
922 0 3696 a2
:3 0 5c :3 0 4e
:2 0 4ef 924 927
c3 :3 0 d3 :2 0
105 :3 0 929 92b
0 4f4 92a 92d
:3 0 46 :3 0 106
:4 0 92f 930 0
933 d9 :3 0 4f7
95b a2 :3 0 5c
:3 0 4e :2 0 4f9
934 937 c3 :3 0
d3 :2 0 107 :3 0
939 93b 0 4fe
93a 93d :3 0 46
:3 0 108 :4 0 93f
940 0 942 501
943 93e 942 0
95d a2 :3 0 5c
:3 0 4e :2 0 503
944 947 c3 :3 0
d3 :2 0 d4 :3 0
949 94b 0 508
94a 94d :3 0 46
:3 0 47 :4 0 94f
950 0 952 50b
957 46 :3 0 4e
:4 0 953 954 0
956 50d 958 94e
952 0 959 0
956 0 959 50f
0 95a 512 95c
92e 933 0 95d
0 95a 0 95d
514 0 3696 a2
:3 0 50 :3 0 4e
:2 0 518 95e 961
109 :2 0 4e :2 0
51d 963 965 :3 0
83 :3 0 4e :2 0
967 968 0 12b2
10a :3 0 83 :3 0
10b :3 0 99 :3 0
25 :4 0 10c 1
:8 0 975 21 :3 0
e9 :3 0 970 971
0 ea :3 0 972
973 0 975 520
9c8 eb :3 0 21
:3 0 e9 :3 0 977
978 0 ea :3 0
979 97a 0 97c
523 97e 525 97d
97c :2 0 9c6 ec
:3 0 21 :3 0 e9
:3 0 981 982 0
ea :3 0 983 984
0 9be ae :3 0
af :3 0 986 987
0 ae :3 0 be
:3 0 989 98a 0
ed :2 0 2 :4 0
10d :2 0 c0 :2 0
47 :2 0 527 98f
991 :3 0 52a 98b
993 988 995 994
:2 0 b1 :3 0 c1
:3 0 997 998 0
b3 :4 0 10e :4 0
b6 :2 0 b7 :3 0
52e 99c 99e :3 0
b6 :2 0 ca :4 0
531 9a0 9a2 :3 0
b6 :2 0 f0 :4 0
534 9a4 9a6 :3 0
b6 :2 0 ea :3 0
537 9a8 9aa :3 0
b6 :2 0 f1 :4 0
53a 9ac 9ae :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 53d 9b1
9b5 541 9b0 9b7
:3 0 544 999 9b9
:2 0 9bb 547 9bc
996 9bb 0 9bd
549 0 9be 54b
9c1 :3 0 9c1 0
9c1 9c0 9be 9bf
:6 0 9c3 8 :3 0
54e 9c5 550 9c4
9c3 :2 0 9c6 552
:2 0 9c8 0 9c8
9c7 975 9c6 :6 0
12b2 1 :3 0 a2
:3 0 83 :3 0 4e
:2 0 555 9ca 9cd
109 :2 0 4e :2 0
55a 9cf 9d1 :3 0
10f :3 0 4c :3 0
110 :3 0 111 :3 0
25 :4 0 112 1
:8 0 9de 21 :3 0
e9 :3 0 9d9 9da
0 ea :3 0 9db
9dc 0 9de 55d
a31 eb :3 0 21
:3 0 e9 :3 0 9e0
9e1 0 ea :3 0
9e2 9e3 0 9e5
560 9e7 562 9e6
9e5 :2 0 a2f ec
:3 0 21 :3 0 e9
:3 0 9ea 9eb 0
ea :3 0 9ec 9ed
0 a27 ae :3 0
af :3 0 9ef 9f0
0 ae :3 0 be
:3 0 9f2 9f3 0
ed :2 0 2 :4 0
113 :2 0 c0 :2 0
47 :2 0 564 9f8
9fa :3 0 567 9f4
9fc 9f1 9fe 9fd
:2 0 b1 :3 0 c1
:3 0 a00 a01 0
b3 :4 0 114 :4 0
b6 :2 0 b7 :3 0
56b a05 a07 :3 0
b6 :2 0 ca :4 0
56e a09 a0b :3 0
b6 :2 0 f0 :4 0
571 a0d a0f :3 0
b6 :2 0 ea :3 0
574 a11 a13 :3 0
b6 :2 0 f1 :4 0
577 a15 a17 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 57a a1a
a1e 57e a19 a20
:3 0 581 a02 a22
:2 0 a24 584 a25
9ff a24 0 a26
586 0 a27 588
a2a :3 0 a2a 0
a2a a29 a27 a28
:6 0 a2c a :3 0
58b a2e 58d a2d
a2c :2 0 a2f 58f
:2 0 a31 0 a31
a30 9de a2f :6 0
aae 1 :3 0 e5
:3 0 115 :3 0 a33
a34 0 4c :3 0
116 :4 0 592 a35
a38 d3 :2 0 4e
:2 0 597 a3a a3c
:3 0 ae :3 0 af
:3 0 a3e a3f 0
ae :3 0 be :3 0
a41 a42 0 24
:2 0 2 :4 0 117
:2 0 c0 :2 0 47
:2 0 59a a47 a49
:3 0 59d a43 a4b
a40 a4d a4c :2 0
b1 :3 0 c1 :3 0
a4f a50 0 b3
:4 0 118 :4 0 b6
:2 0 b7 :3 0 5a1
a54 a56 :3 0 b6
:2 0 ca :4 0 5a4
a58 a5a :3 0 b6
:2 0 cb :4 0 5a7
a5c a5e :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 119
:3 0 a63 a64 0
5aa a62 a66 bc
:4 0 5ac a61 a69
5af a60 a6b :3 0
b6 :2 0 11a :4 0
5b2 a6d a6f :3 0
b6 :2 0 b9 :4 0
5b5 a71 a73 :3 0
b6 :2 0 25 :3 0
5b8 a75 a77 :3 0
b6 :2 0 b9 :4 0
5bb a79 a7b :3 0
5be a51 a7d :2 0
a7f 5c1 a80 a4e
a7f 0 a81 5c3
0 aab ae :3 0
af :3 0 a82 a83
0 ae :3 0 be
:3 0 a85 a86 0
47 :2 0 2 :4 0
11b :2 0 c0 :2 0
47 :2 0 5c5 a8b
a8d :3 0 5c8 a87
a8f a84 a91 a90
:2 0 b1 :3 0 c1
:3 0 a93 a94 0
b3 :4 0 11c :4 0
b6 :2 0 b7 :3 0
5cc a98 a9a :3 0
5cf a95 a9c :2 0
a9e 5d2 a9f a92
a9e 0 aa0 5d4
0 aab cf :3 0
11d :3 0 aa1 aa2
0 c3 :3 0 119
:3 0 aa4 aa5 0
25 :3 0 d1 :3 0
5d6 aa3 aa9 :2 0
aab 5da aac a3d
aab 0 aad 5de
0 aae 5e0 aaf
9d2 aae 0 ab0
5e3 0 12b2 7a
:3 0 11e :3 0 a2
:3 0 50 :3 0 4e
:2 0 5e5 ab3 ab6
5e8 ab2 ab8 ab1
ab9 0 12b2 a2
:3 0 7a :3 0 4e
:2 0 5ea abb abe
d3 :2 0 4e :2 0
5ef ac0 ac2 :3 0
50 :3 0 11f :3 0
a2 :3 0 50 :3 0
4e :2 0 5f2 ac6
ac9 5f5 ac5 acb
ac4 acc 0 b3b
a2 :3 0 50 :3 0
4e :2 0 5f7 ace
ad1 d3 :2 0 4e
:2 0 5fc ad3 ad5
:3 0 ae :3 0 af
:3 0 ad7 ad8 0
ae :3 0 be :3 0
ada adb 0 c7
:2 0 2 :4 0 120
:2 0 c0 :2 0 47
:2 0 5ff ae0 ae2
:3 0 602 adc ae4
ad9 ae6 ae5 :2 0
b1 :3 0 c1 :3 0
ae8 ae9 0 b3
:4 0 121 :4 0 b6
:2 0 b7 :3 0 606
aed aef :3 0 b6
:2 0 ca :4 0 609
af1 af3 :3 0 b6
:2 0 cb :4 0 60c
af5 af7 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 d7
:3 0 afc afd 0
60f afb aff bc
:4 0 611 afa b02
614 af9 b04 :3 0
617 aea b06 :2 0
b08 61a b09 ae7
b08 0 b0a 61c
0 b33 ae :3 0
af :3 0 b0b b0c
0 ae :3 0 be
:3 0 b0e b0f 0
47 :2 0 2 :4 0
122 :2 0 c0 :2 0
47 :2 0 61e b14
b16 :3 0 621 b10
b18 b0d b1a b19
:2 0 b1 :3 0 c1
:3 0 b1c b1d 0
b3 :4 0 123 :4 0
b6 :2 0 b7 :3 0
625 b21 b23 :3 0
628 b1e b25 :2 0
b27 62b b28 b1b
b27 0 b29 62d
0 b33 cf :3 0
d0 :3 0 b2a b2b
0 c3 :3 0 d7
:3 0 b2d b2e 0
d1 :3 0 62f b2c
b31 :2 0 b33 632
b34 ad6 b33 0
b35 636 0 b3b
7a :3 0 c3 :3 0
124 :3 0 b37 b38
0 b36 b39 0
b3b 638 b3c ac3
b3b 0 b3d 63c
0 12b2 26 :3 0
25 :3 0 b3e b3f
0 12b2 a2 :3 0
6b :3 0 4e :2 0
63e b41 b44 c4
:2 0 4e :2 0 643
b46 b48 :3 0 39
:3 0 14 :3 0 b4a
b4b 0 b4d 646
bab ae :3 0 af
:3 0 b4e b4f 0
ae :3 0 be :3 0
b51 b52 0 c7
:2 0 2 :4 0 125
:2 0 c0 :2 0 47
:2 0 648 b57 b59
:3 0 64b b53 b5b
b50 b5d b5c :2 0
b1 :3 0 c1 :3 0
b5f b60 0 b3
:4 0 126 :4 0 b6
:2 0 b7 :3 0 64f
b64 b66 :3 0 b6
:2 0 ca :4 0 652
b68 b6a :3 0 b6
:2 0 cb :4 0 655
b6c b6e :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 d7
:3 0 b73 b74 0
658 b72 b76 bc
:4 0 65a b71 b79
65d b70 b7b :3 0
660 b61 b7d :2 0
b7f 663 b80 b5e
b7f 0 b81 665
0 baa ae :3 0
af :3 0 b82 b83
0 ae :3 0 be
:3 0 b85 b86 0
47 :2 0 2 :4 0
127 :2 0 c0 :2 0
47 :2 0 667 b8b
b8d :3 0 66a b87
b8f b84 b91 b90
:2 0 b1 :3 0 c1
:3 0 b93 b94 0
b3 :4 0 128 :4 0
b6 :2 0 b7 :3 0
66e b98 b9a :3 0
671 b95 b9c :2 0
b9e 674 b9f b92
b9e 0 ba0 676
0 baa cf :3 0
d0 :3 0 ba1 ba2
0 c3 :3 0 d7
:3 0 ba4 ba5 0
d1 :3 0 678 ba3
ba8 :2 0 baa 67b
bac b49 b4d 0
bad 0 baa 0
bad 67f 0 12b2
85 :3 0 129 :3 0
7a :3 0 50 :3 0
26 :3 0 39 :3 0
29 :3 0 48 :3 0
682 baf bb6 bae
bb7 0 12b2 a2
:3 0 4d :3 0 4e
:2 0 689 bb9 bbc
c3 :3 0 d3 :2 0
c5 :3 0 bbe bc0
0 68e bbf bc2
:3 0 a2 :3 0 85
:3 0 4e :2 0 691
bc4 bc7 d3 :2 0
47 :2 0 696 bc9
bcb :3 0 85 :3 0
c3 :3 0 12a :3 0
bce bcf 0 bcd
bd0 0 bd2 699
bd3 bcc bd2 0
bd4 69b 0 c42
ae :3 0 af :3 0
bd5 bd6 0 ae
:3 0 be :3 0 bd8
bd9 0 24 :2 0
2 :4 0 12b :2 0
c0 :2 0 47 :2 0
69d bde be0 :3 0
6a0 bda be2 bd7
be4 be3 :2 0 b1
:3 0 c1 :3 0 be6
be7 0 b3 :4 0
12c :4 0 b6 :2 0
b7 :3 0 6a4 beb
bed :3 0 b6 :2 0
ca :4 0 6a7 bef
bf1 :3 0 b6 :2 0
cb :4 0 6aa bf3
bf5 :3 0 b6 :2 0
a2 :3 0 bb :3 0
85 :3 0 6ad bf9
bfb bc :4 0 6af
bf8 bfe 6b2 bf7
c00 :3 0 b6 :2 0
11a :4 0 6b5 c02
c04 :3 0 b6 :2 0
b9 :4 0 6b8 c06
c08 :3 0 b6 :2 0
48 :3 0 6bb c0a
c0c :3 0 b6 :2 0
b9 :4 0 6be c0e
c10 :3 0 6c1 be8
c12 :2 0 c14 6c4
c15 be5 c14 0
c16 6c6 0 c42
ae :3 0 af :3 0
c17 c18 0 ae
:3 0 be :3 0 c1a
c1b 0 47 :2 0
2 :4 0 12d :2 0
c0 :2 0 47 :2 0
6c8 c20 c22 :3 0
6cb c1c c24 c19
c26 c25 :2 0 b1
:3 0 c1 :3 0 c28
c29 0 b3 :4 0
12e :4 0 b6 :2 0
b7 :3 0 6cf c2d
c2f :3 0 6d2 c2a
c31 :2 0 c33 6d5
c34 c27 c33 0
c35 6d7 0 c42
cf :3 0 11d :3 0
c36 c37 0 a2
:3 0 85 :3 0 4e
:2 0 6d9 c39 c3c
48 :3 0 d1 :3 0
6dc c38 c40 :2 0
c42 6e0 c43 bc3
c42 0 c44 6e5
0 12b2 a2 :3 0
85 :3 0 4e :2 0
6e7 c45 c48 c4
:2 0 4e :2 0 6ec
c4a c4c :3 0 a2
:3 0 85 :3 0 4e
:2 0 6ef c4e c51
c4 :2 0 47 :2 0
6f4 c53 c55 :3 0
c4d c57 c56 :2 0
ae :3 0 af :3 0
c59 c5a 0 ae
:3 0 be :3 0 c5c
c5d 0 24 :2 0
2 :4 0 12f :2 0
c0 :2 0 47 :2 0
6f7 c62 c64 :3 0
6fa c5e c66 c5b
c68 c67 :2 0 b1
:3 0 c1 :3 0 c6a
c6b 0 b3 :4 0
130 :4 0 b6 :2 0
b7 :3 0 6fe c6f
c71 :3 0 b6 :2 0
ca :4 0 701 c73
c75 :3 0 b6 :2 0
cb :4 0 704 c77
c79 :3 0 b6 :2 0
a2 :3 0 bb :3 0
85 :3 0 707 c7d
c7f bc :4 0 709
c7c c82 70c c7b
c84 :3 0 b6 :2 0
11a :4 0 70f c86
c88 :3 0 b6 :2 0
b9 :4 0 712 c8a
c8c :3 0 b6 :2 0
48 :3 0 715 c8e
c90 :3 0 b6 :2 0
b9 :4 0 718 c92
c94 :3 0 71b c6c
c96 :2 0 c98 71e
c99 c69 c98 0
c9a 720 0 cc6
ae :3 0 af :3 0
c9b c9c 0 ae
:3 0 be :3 0 c9e
c9f 0 47 :2 0
2 :4 0 131 :2 0
c0 :2 0 47 :2 0
722 ca4 ca6 :3 0
725 ca0 ca8 c9d
caa ca9 :2 0 b1
:3 0 c1 :3 0 cac
cad 0 b3 :4 0
132 :4 0 b6 :2 0
b7 :3 0 729 cb1
cb3 :3 0 72c cae
cb5 :2 0 cb7 72f
cb8 cab cb7 0
cb9 731 0 cc6
cf :3 0 11d :3 0
cba cbb 0 a2
:3 0 85 :3 0 4e
:2 0 733 cbd cc0
48 :3 0 d1 :3 0
736 cbc cc4 :2 0
cc6 73a cc7 c58
cc6 0 cc8 73e
0 12b2 a2 :3 0
7a :3 0 4e :2 0
740 cc9 ccc c3
:3 0 d3 :2 0 124
:3 0 cce cd0 0
745 ccf cd2 :3 0
133 :3 0 a2 :3 0
50 :3 0 4e :2 0
748 cd5 cd8 74b
cd4 cda c4 :2 0
4e :2 0 74f cdc
cde :3 0 99 :3 0
a2 :3 0 134 :3 0
a2 :3 0 135 :3 0
136 :3 0 25 :3 0
5f :3 0 60 :3 0
64 :3 0 110 :3 0
111 :3 0 26 :4 0
137 1 :8 0 cf3
21 :3 0 e9 :3 0
cee cef 0 ea
:3 0 cf0 cf1 0
cf3 752 d46 eb
:3 0 21 :3 0 e9
:3 0 cf5 cf6 0
ea :3 0 cf7 cf8
0 cfa 755 cfc
757 cfb cfa :2 0
d44 ec :3 0 21
:3 0 e9 :3 0 cff
d00 0 ea :3 0
d01 d02 0 d3c
ae :3 0 af :3 0
d04 d05 0 ae
:3 0 be :3 0 d07
d08 0 ed :2 0
2 :4 0 138 :2 0
c0 :2 0 47 :2 0
759 d0d d0f :3 0
75c d09 d11 d06
d13 d12 :2 0 b1
:3 0 c1 :3 0 d15
d16 0 b3 :4 0
139 :4 0 b6 :2 0
b7 :3 0 760 d1a
d1c :3 0 b6 :2 0
ca :4 0 763 d1e
d20 :3 0 b6 :2 0
f0 :4 0 766 d22
d24 :3 0 b6 :2 0
ea :3 0 769 d26
d28 :3 0 b6 :2 0
f1 :4 0 76c d2a
d2c :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
76f d2f d33 773
d2e d35 :3 0 776
d17 d37 :2 0 d39
779 d3a d14 d39
0 d3b 77b 0
d3c 77d d3f :3 0
d3f 0 d3f d3e
d3c d3d :6 0 d41
c :3 0 780 d43
782 d42 d41 :2 0
d44 784 :2 0 d46
0 d46 d45 cf3
d44 :6 0 d48 1
:3 0 787 dcc 13a
:3 0 13b :3 0 13a
:3 0 13c :3 0 13a
:3 0 13d :3 0 13a
:3 0 99 :3 0 a2
:3 0 13e :3 0 134
:3 0 a2 :3 0 13e
:3 0 135 :3 0 13e
:3 0 136 :3 0 13a
:3 0 13f :3 0 13a
:3 0 140 :3 0 72
:3 0 43 :3 0 44
:3 0 25 :3 0 5f
:3 0 60 :3 0 64
:3 0 73 :3 0 110
:3 0 13e :3 0 110
:3 0 13a :3 0 13a
:3 0 111 :3 0 26
:3 0 13e :3 0 111
:3 0 13a :3 0 99
:4 0 141 1 :8 0
d76 21 :3 0 e9
:3 0 d71 d72 0
ea :3 0 d73 d74
0 d76 789 dc9
eb :3 0 21 :3 0
e9 :3 0 d78 d79
0 ea :3 0 d7a
d7b 0 d7d 78c
d7f 78e d7e d7d
:2 0 dc7 ec :3 0
21 :3 0 e9 :3 0
d82 d83 0 ea
:3 0 d84 d85 0
dbf ae :3 0 af
:3 0 d87 d88 0
ae :3 0 be :3 0
d8a d8b 0 ed
:2 0 2 :4 0 142
:2 0 c0 :2 0 47
:2 0 790 d90 d92
:3 0 793 d8c d94
d89 d96 d95 :2 0
b1 :3 0 c1 :3 0
d98 d99 0 b3
:4 0 143 :4 0 b6
:2 0 b7 :3 0 797
d9d d9f :3 0 b6
:2 0 ca :4 0 79a
da1 da3 :3 0 b6
:2 0 f0 :4 0 79d
da5 da7 :3 0 b6
:2 0 ea :3 0 7a0
da9 dab :3 0 b6
:2 0 f1 :4 0 7a3
dad daf :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 7a6 db2 db6
7aa db1 db8 :3 0
7ad d9a dba :2 0
dbc 7b0 dbd d97
dbc 0 dbe 7b2
0 dbf 7b4 dc2
:3 0 dc2 0 dc2
dc1 dbf dc0 :6 0
dc4 e :3 0 7b7
dc6 7b9 dc5 dc4
:2 0 dc7 7bb :2 0
dc9 0 dc9 dc8
d76 dc7 :6 0 dcb
1 :3 0 7be dcd
cdf d48 0 dce
0 dcb 0 dce
7c0 0 e4a 21
:3 0 e9 :3 0 dcf
dd0 0 21 :3 0
c4 :2 0 f5 :3 0
dd2 dd4 0 7c5
dd3 dd6 :3 0 dd7
:2 0 ae :3 0 af
:3 0 dd9 dda 0
ae :3 0 be :3 0
ddc ddd 0 24
:2 0 2 :4 0 144
:2 0 c0 :2 0 47
:2 0 7c8 de2 de4
:3 0 7cb dde de6
ddb de8 de7 :2 0
b1 :3 0 c1 :3 0
dea deb 0 b3
:4 0 145 :4 0 b6
:2 0 b7 :3 0 7cf
def df1 :3 0 b6
:2 0 ca :4 0 7d2
df3 df5 :3 0 b6
:2 0 cb :4 0 7d5
df7 df9 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 146
:3 0 dfe dff 0
7d8 dfd e01 bc
:4 0 7da dfc e04
7dd dfb e06 :3 0
b6 :2 0 11a :4 0
7e0 e08 e0a :3 0
b6 :2 0 b9 :4 0
7e3 e0c e0e :3 0
b6 :2 0 26 :3 0
7e6 e10 e12 :3 0
b6 :2 0 b9 :4 0
7e9 e14 e16 :3 0
7ec dec e18 :2 0
e1a 7ef e1b de9
e1a 0 e1c 7f1
0 e46 ae :3 0
af :3 0 e1d e1e
0 ae :3 0 be
:3 0 e20 e21 0
47 :2 0 2 :4 0
147 :2 0 c0 :2 0
47 :2 0 7f3 e26
e28 :3 0 7f6 e22
e2a e1f e2c e2b
:2 0 b1 :3 0 c1
:3 0 e2e e2f 0
b3 :4 0 148 :4 0
b6 :2 0 b7 :3 0
7fa e33 e35 :3 0
7fd e30 e37 :2 0
e39 800 e3a e2d
e39 0 e3b 802
0 e46 cf :3 0
11d :3 0 e3c e3d
0 c3 :3 0 146
:3 0 e3f e40 0
26 :3 0 d1 :3 0
804 e3e e44 :2 0
e46 808 e47 dd8
e46 0 e48 80c
0 e4a d9 :3 0
80e 109f a2 :3 0
7a :3 0 4e :2 0
811 e4b e4e c3
:3 0 d3 :2 0 149
:3 0 e50 e52 0
816 e51 e54 :3 0
99 :3 0 14a :3 0
14b :3 0 25 :3 0
50 :3 0 23 :3 0
14c :3 0 111 :3 0
26 :4 0 14d 1
:8 0 e65 21 :3 0
e9 :3 0 e60 e61
0 ea :3 0 e62
e63 0 e65 819
eb8 eb :3 0 21
:3 0 e9 :3 0 e67
e68 0 ea :3 0
e69 e6a 0 e6c
81c e6e 81e e6d
e6c :2 0 eb6 ec
:3 0 21 :3 0 e9
:3 0 e71 e72 0
ea :3 0 e73 e74
0 eae ae :3 0
af :3 0 e76 e77
0 ae :3 0 be
:3 0 e79 e7a 0
ed :2 0 2 :4 0
14e :2 0 c0 :2 0
47 :2 0 820 e7f
e81 :3 0 823 e7b
e83 e78 e85 e84
:2 0 b1 :3 0 c1
:3 0 e87 e88 0
b3 :4 0 14f :4 0
b6 :2 0 b7 :3 0
827 e8c e8e :3 0
b6 :2 0 ca :4 0
82a e90 e92 :3 0
b6 :2 0 f0 :4 0
82d e94 e96 :3 0
b6 :2 0 ea :3 0
830 e98 e9a :3 0
b6 :2 0 f1 :4 0
833 e9c e9e :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 836 ea1
ea5 83a ea0 ea7
:3 0 83d e89 ea9
:2 0 eab 840 eac
e86 eab 0 ead
842 0 eae 844
eb1 :3 0 eb1 0
eb1 eb0 eae eaf
:6 0 eb3 10 :3 0
847 eb5 849 eb4
eb3 :2 0 eb6 84b
:2 0 eb8 0 eb8
eb7 e65 eb6 :6 0
102f 1 :3 0 21
:3 0 e9 :3 0 eba
ebb 0 21 :3 0
c4 :2 0 f5 :3 0
ebd ebf 0 850
ebe ec1 :3 0 ec2
:2 0 ae :3 0 af
:3 0 ec4 ec5 0
ae :3 0 be :3 0
ec7 ec8 0 24
:2 0 2 :4 0 150
:2 0 c0 :2 0 47
:2 0 853 ecd ecf
:3 0 856 ec9 ed1
ec6 ed3 ed2 :2 0
b1 :3 0 c1 :3 0
ed5 ed6 0 b3
:4 0 151 :4 0 b6
:2 0 b7 :3 0 85a
eda edc :3 0 b6
:2 0 ca :4 0 85d
ede ee0 :3 0 b6
:2 0 cb :4 0 860
ee2 ee4 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 146
:3 0 ee9 eea 0
863 ee8 eec bc
:4 0 865 ee7 eef
868 ee6 ef1 :3 0
b6 :2 0 11a :4 0
86b ef3 ef5 :3 0
b6 :2 0 b9 :4 0
86e ef7 ef9 :3 0
b6 :2 0 26 :3 0
871 efb efd :3 0
b6 :2 0 b9 :4 0
874 eff f01 :3 0
877 ed7 f03 :2 0
f05 87a f06 ed4
f05 0 f07 87c
0 f31 ae :3 0
af :3 0 f08 f09
0 ae :3 0 be
:3 0 f0b f0c 0
47 :2 0 2 :4 0
152 :2 0 c0 :2 0
47 :2 0 87e f11
f13 :3 0 881 f0d
f15 f0a f17 f16
:2 0 b1 :3 0 c1
:3 0 f19 f1a 0
b3 :4 0 153 :4 0
b6 :2 0 b7 :3 0
885 f1e f20 :3 0
888 f1b f22 :2 0
f24 88b f25 f18
f24 0 f26 88d
0 f31 cf :3 0
11d :3 0 f27 f28
0 c3 :3 0 146
:3 0 f2a f2b 0
26 :3 0 d1 :3 0
88f f29 f2f :2 0
f31 893 f32 ec3
f31 0 f33 897
0 102f 154 :3 0
41 :3 0 154 :3 0
155 :3 0 41 :3 0
a2 :3 0 134 :3 0
a2 :3 0 135 :3 0
136 :3 0 41 :3 0
5f :3 0 60 :3 0
64 :3 0 110 :3 0
99 :3 0 25 :3 0
111 :3 0 25 :4 0
156 1 :8 0 f4d
21 :3 0 e9 :3 0
f48 f49 0 ea
:3 0 f4a f4b 0
f4d 899 fa0 eb
:3 0 21 :3 0 e9
:3 0 f4f f50 0
ea :3 0 f51 f52
0 f54 89c f56
89e f55 f54 :2 0
f9e ec :3 0 21
:3 0 e9 :3 0 f59
f5a 0 ea :3 0
f5b f5c 0 f96
ae :3 0 af :3 0
f5e f5f 0 ae
:3 0 be :3 0 f61
f62 0 ed :2 0
2 :4 0 157 :2 0
c0 :2 0 47 :2 0
8a0 f67 f69 :3 0
8a3 f63 f6b f60
f6d f6c :2 0 b1
:3 0 c1 :3 0 f6f
f70 0 b3 :4 0
158 :4 0 b6 :2 0
b7 :3 0 8a7 f74
f76 :3 0 b6 :2 0
ca :4 0 8aa f78
f7a :3 0 b6 :2 0
f0 :4 0 8ad f7c
f7e :3 0 b6 :2 0
ea :3 0 8b0 f80
f82 :3 0 b6 :2 0
f1 :4 0 8b3 f84
f86 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
8b6 f89 f8d 8ba
f88 f8f :3 0 8bd
f71 f91 :2 0 f93
8c0 f94 f6e f93
0 f95 8c2 0
f96 8c4 f99 :3 0
f99 0 f99 f98
f96 f97 :6 0 f9b
12 :3 0 8c7 f9d
8c9 f9c f9b :2 0
f9e 8cb :2 0 fa0
0 fa0 f9f f4d
f9e :6 0 102f 1
:3 0 21 :3 0 e9
:3 0 fa2 fa3 0
21 :3 0 c4 :2 0
f5 :3 0 fa5 fa7
0 8d0 fa6 fa9
:3 0 faa :2 0 ae
:3 0 af :3 0 fac
fad 0 ae :3 0
be :3 0 faf fb0
0 24 :2 0 2
:4 0 159 :2 0 c0
:2 0 47 :2 0 8d3
fb5 fb7 :3 0 8d6
fb1 fb9 fae fbb
fba :2 0 b1 :3 0
c1 :3 0 fbd fbe
0 b3 :4 0 15a
:4 0 b6 :2 0 b7
:3 0 8da fc2 fc4
:3 0 b6 :2 0 ca
:4 0 8dd fc6 fc8
:3 0 b6 :2 0 cb
:4 0 8e0 fca fcc
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 146 :3 0 fd1
fd2 0 8e3 fd0
fd4 bc :4 0 8e5
fcf fd7 8e8 fce
fd9 :3 0 b6 :2 0
11a :4 0 8eb fdb
fdd :3 0 b6 :2 0
b9 :4 0 8ee fdf
fe1 :3 0 b6 :2 0
25 :3 0 8f1 fe3
fe5 :3 0 b6 :2 0
b9 :4 0 8f4 fe7
fe9 :3 0 8f7 fbf
feb :2 0 fed 8fa
fee fbc fed 0
fef 8fc 0 1019
ae :3 0 af :3 0
ff0 ff1 0 ae
:3 0 be :3 0 ff3
ff4 0 47 :2 0
2 :4 0 15b :2 0
c0 :2 0 47 :2 0
8fe ff9 ffb :3 0
901 ff5 ffd ff2
fff ffe :2 0 b1
:3 0 c1 :3 0 1001
1002 0 b3 :4 0
15c :4 0 b6 :2 0
b7 :3 0 905 1006
1008 :3 0 908 1003
100a :2 0 100c 90b
100d 1000 100c 0
100e 90d 0 1019
cf :3 0 11d :3 0
100f 1010 0 c3
:3 0 146 :3 0 1012
1013 0 25 :3 0
d1 :3 0 90f 1011
1017 :2 0 1019 913
101a fab 1019 0
101b 917 0 102f
23 :3 0 e4 :2 0
919 101d 101e :3 0
101f :2 0 7a :3 0
c3 :3 0 124 :3 0
1022 1023 0 1021
1024 0 102c 50
:3 0 15d :3 0 50
:3 0 91b 1027 1029
1026 102a 0 102c
91d 102d 1020 102c
0 102e 920 0
102f 922 1030 e55
102f 0 10a1 ae
:3 0 af :3 0 1031
1032 0 ae :3 0
be :3 0 1034 1035
0 24 :2 0 2
:4 0 15e :2 0 c0
:2 0 47 :2 0 928
103a 103c :3 0 92b
1036 103e 1033 1040
103f :2 0 b1 :3 0
c1 :3 0 1042 1043
0 b3 :4 0 15f
:4 0 b6 :2 0 b7
:3 0 92f 1047 1049
:3 0 b6 :2 0 ca
:4 0 932 104b 104d
:3 0 b6 :2 0 cb
:4 0 935 104f 1051
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 1056
1057 0 938 1055
1059 bc :4 0 93a
1054 105c 93d 1053
105e :3 0 b6 :2 0
11a :4 0 940 1060
1062 :3 0 b6 :2 0
b9 :4 0 943 1064
1066 :3 0 b6 :2 0
25 :3 0 946 1068
106a :3 0 b6 :2 0
b9 :4 0 949 106c
106e :3 0 94c 1044
1070 :2 0 1072 94f
1073 1041 1072 0
1074 951 0 109e
ae :3 0 af :3 0
1075 1076 0 ae
:3 0 be :3 0 1078
1079 0 47 :2 0
2 :4 0 160 :2 0
c0 :2 0 47 :2 0
953 107e 1080 :3 0
956 107a 1082 1077
1084 1083 :2 0 b1
:3 0 c1 :3 0 1086
1087 0 b3 :4 0
161 :4 0 b6 :2 0
b7 :3 0 95a 108b
108d :3 0 95d 1088
108f :2 0 1091 960
1092 1085 1091 0
1093 962 0 109e
cf :3 0 11d :3 0
1094 1095 0 c3
:3 0 d7 :3 0 1097
1098 0 25 :3 0
d1 :3 0 964 1096
109c :2 0 109e 968
10a0 cd3 e4a 0
10a1 0 109e 0
10a1 96c 0 12b2
a2 :3 0 5c :3 0
4e :2 0 970 10a2
10a5 c3 :3 0 c4
:2 0 d4 :3 0 10a7
10a9 0 975 10a8
10ab :3 0 162 :3 0
e5 :3 0 163 :3 0
41 :3 0 164 :3 0
165 :3 0 a2 :3 0
e5 :3 0 163 :3 0
165 :3 0 a2 :3 0
e5 :3 0 163 :3 0
166 :3 0 4b :3 0
6d :3 0 71 :3 0
45 :3 0 6e :3 0
6f :3 0 167 :3 0
9b :3 0 39 :4 0
168 1 :8 0 10ca
21 :3 0 e9 :3 0
10c5 10c6 0 ea
:3 0 10c7 10c8 0
10ca 978 111d eb
:3 0 21 :3 0 e9
:3 0 10cc 10cd 0
ea :3 0 10ce 10cf
0 10d1 97b 10d3
97d 10d2 10d1 :2 0
111b ec :3 0 21
:3 0 e9 :3 0 10d6
10d7 0 ea :3 0
10d8 10d9 0 1113
ae :3 0 af :3 0
10db 10dc 0 ae
:3 0 be :3 0 10de
10df 0 ed :2 0
2 :4 0 169 :2 0
c0 :2 0 47 :2 0
97f 10e4 10e6 :3 0
982 10e0 10e8 10dd
10ea 10e9 :2 0 b1
:3 0 c1 :3 0 10ec
10ed 0 b3 :4 0
16a :4 0 b6 :2 0
b7 :3 0 986 10f1
10f3 :3 0 b6 :2 0
ca :4 0 989 10f5
10f7 :3 0 b6 :2 0
f0 :4 0 98c 10f9
10fb :3 0 b6 :2 0
ea :3 0 98f 10fd
10ff :3 0 b6 :2 0
f1 :4 0 992 1101
1103 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
995 1106 110a 999
1105 110c :3 0 99c
10ee 110e :2 0 1110
99f 1111 10eb 1110
0 1112 9a1 0
1113 9a3 1116 :3 0
1116 0 1116 1115
1113 1114 :6 0 1118
14 :3 0 9a6 111a
9a8 1119 1118 :2 0
111b 9aa :2 0 111d
0 111d 111c 10ca
111b :6 0 12af 1
:3 0 21 :3 0 e9
:3 0 111f 1120 0
21 :3 0 d3 :2 0
16b :3 0 1122 1124
0 9af 1123 1126
:3 0 1127 :2 0 ae
:3 0 af :3 0 1129
112a 0 ae :3 0
be :3 0 112c 112d
0 24 :2 0 2
:4 0 16c :2 0 c0
:2 0 47 :2 0 9b2
1132 1134 :3 0 9b5
112e 1136 112b 1138
1137 :2 0 b1 :3 0
c1 :3 0 113a 113b
0 b3 :4 0 16d
:4 0 b6 :2 0 b7
:3 0 9b9 113f 1141
:3 0 b6 :2 0 ca
:4 0 9bc 1143 1145
:3 0 b6 :2 0 cb
:4 0 9bf 1147 1149
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 146 :3 0 114e
114f 0 9c2 114d
1151 bc :4 0 9c4
114c 1154 9c7 114b
1156 :3 0 b6 :2 0
11a :4 0 9ca 1158
115a :3 0 b6 :2 0
b9 :4 0 9cd 115c
115e :3 0 b6 :2 0
39 :3 0 9d0 1160
1162 :3 0 b6 :2 0
b9 :4 0 9d3 1164
1166 :3 0 9d6 113c
1168 :2 0 116a 9d9
116b 1139 116a 0
116c 9db 0 1197
ae :3 0 af :3 0
116d 116e 0 ae
:3 0 be :3 0 1170
1171 0 47 :2 0
2 :4 0 16e :2 0
c0 :2 0 47 :2 0
9dd 1176 1178 :3 0
9e0 1172 117a 116f
117c 117b :2 0 b1
:3 0 c1 :3 0 117e
117f 0 b3 :4 0
16f :4 0 b6 :2 0
b7 :3 0 9e4 1183
1185 :3 0 9e7 1180
1187 :2 0 1189 9ea
118a 117d 1189 0
118b 9ec 0 1197
cf :3 0 11d :3 0
118c 118d 0 c3
:3 0 146 :3 0 118f
1190 0 39 :3 0
d1 :3 0 9ee 118e
1194 :2 0 1197 d9
:3 0 9f2 12ad 21
:3 0 e9 :3 0 1198
1199 0 21 :3 0
d3 :2 0 f5 :3 0
119b 119d 0 9f8
119c 119f :3 0 11a0
:2 0 f2 :3 0 71
:3 0 47 :2 0 47
:2 0 9fb 11a2 11a6
d3 :2 0 4e :4 0
a01 11a8 11aa :3 0
a2 :3 0 6f :3 0
4e :2 0 a04 11ac
11af 109 :2 0 4e
:2 0 a09 11b1 11b3
:3 0 a2 :3 0 6d
:3 0 4e :2 0 a0c
11b5 11b8 a2 :3 0
109 :2 0 6f :3 0
4e :2 0 a0f 11ba
11be a14 11bb 11c0
:3 0 11b4 11c2 11c1
:2 0 11c3 :2 0 11ab
11c5 11c4 :2 0 ae
:3 0 af :3 0 11c7
11c8 0 ae :3 0
be :3 0 11ca 11cb
0 24 :2 0 2
:4 0 170 :2 0 c0
:2 0 47 :2 0 a17
11d0 11d2 :3 0 a1a
11cc 11d4 11c9 11d6
11d5 :2 0 b1 :3 0
c1 :3 0 11d8 11d9
0 b3 :4 0 171
:4 0 b6 :2 0 b7
:3 0 a1e 11dd 11df
:3 0 b6 :2 0 ca
:4 0 a21 11e1 11e3
:3 0 b6 :2 0 cb
:4 0 a24 11e5 11e7
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 172 :3 0 11ec
11ed 0 a27 11eb
11ef bc :4 0 a29
11ea 11f2 a2c 11e9
11f4 :3 0 b6 :2 0
11a :4 0 a2f 11f6
11f8 :3 0 b6 :2 0
b9 :4 0 a32 11fa
11fc :3 0 b6 :2 0
39 :3 0 a35 11fe
1200 :3 0 b6 :2 0
b9 :4 0 a38 1202
1204 :3 0 a3b 11da
1206 :2 0 1208 a3e
1209 11d7 1208 0
120a a40 0 1234
ae :3 0 af :3 0
120b 120c 0 ae
:3 0 be :3 0 120e
120f 0 47 :2 0
2 :4 0 173 :2 0
c0 :2 0 47 :2 0
a42 1214 1216 :3 0
a45 1210 1218 120d
121a 1219 :2 0 b1
:3 0 c1 :3 0 121c
121d 0 b3 :4 0
174 :4 0 b6 :2 0
b7 :3 0 a49 1221
1223 :3 0 a4c 121e
1225 :2 0 1227 a4f
1228 121b 1227 0
1229 a51 0 1234
cf :3 0 11d :3 0
122a 122b 0 c3
:3 0 172 :3 0 122d
122e 0 39 :3 0
d1 :3 0 a53 122c
1232 :2 0 1234 a57
1235 11c6 1234 0
1236 a5b 0 12ab
a2 :3 0 6d :3 0
4e :2 0 a5d 1237
123a a2 :3 0 f6
:2 0 6e :3 0 4e
:2 0 a60 123c 1240
a65 123d 1242 :3 0
e5 :3 0 175 :3 0
176 :3 0 f2 :3 0
45 :3 0 e5 :3 0
177 :3 0 41 :3 0
e7 :4 0 178 1
:8 0 1253 21 :3 0
e9 :3 0 124e 124f
0 ea :3 0 1250
1251 0 1253 a68
12a6 eb :3 0 21
:3 0 e9 :3 0 1255
1256 0 ea :3 0
1257 1258 0 125a
a6b 125c a6d 125b
125a :2 0 12a4 ec
:3 0 21 :3 0 e9
:3 0 125f 1260 0
ea :3 0 1261 1262
0 129c ae :3 0
af :3 0 1264 1265
0 ae :3 0 be
:3 0 1267 1268 0
ed :2 0 2 :4 0
179 :2 0 c0 :2 0
47 :2 0 a6f 126d
126f :3 0 a72 1269
1271 1266 1273 1272
:2 0 b1 :3 0 c1
:3 0 1275 1276 0
b3 :4 0 17a :4 0
b6 :2 0 b7 :3 0
a76 127a 127c :3 0
b6 :2 0 ca :4 0
a79 127e 1280 :3 0
b6 :2 0 f0 :4 0
a7c 1282 1284 :3 0
b6 :2 0 ea :3 0
a7f 1286 1288 :3 0
b6 :2 0 f1 :4 0
a82 128a 128c :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 a85 128f
1293 a89 128e 1295
:3 0 a8c 1277 1297
:2 0 1299 a8f 129a
1274 1299 0 129b
a91 0 129c a93
129f :3 0 129f 0
129f 129e 129c 129d
:6 0 12a1 16 :3 0
a96 12a3 a98 12a2
12a1 :2 0 12a4 a9a
:2 0 12a6 0 12a6
12a5 1253 12a4 :6 0
12a8 1 :3 0 a9d
12a9 1243 12a8 0
12aa a9f 0 12ab
aa1 12ac 11a1 12ab
0 12ae 1128 1197
0 12ae aa4 0
12af aa7 12b0 10ac
12af 0 12b1 aaa
0 12b2 aac 12b3
966 12b2 0 12b4
ab9 0 3696 a2
:3 0 50 :3 0 4e
:2 0 abb 12b5 12b8
d3 :2 0 4e :2 0
ac0 12ba 12bc :3 0
a2 :3 0 5c :3 0
4e :2 0 ac3 12be
12c1 c3 :3 0 d3
:2 0 d4 :3 0 12c3
12c5 0 ac8 12c4
12c7 :3 0 16 :3 0
c6 :2 0 acb 12ca
12cb :3 0 12cc :2 0
12c8 12ce 12cd :2 0
a2 :3 0 6b :3 0
4e :2 0 acd 12d0
12d3 d3 :2 0 4e
:2 0 ad2 12d5 12d7
:3 0 12cf 12d9 12d8
:2 0 ae :3 0 af
:3 0 12db 12dc 0
ae :3 0 be :3 0
12de 12df 0 24
:2 0 2 :4 0 17b
:2 0 c0 :2 0 47
:2 0 ad5 12e4 12e6
:3 0 ad8 12e0 12e8
12dd 12ea 12e9 :2 0
b1 :3 0 c1 :3 0
12ec 12ed 0 b3
:4 0 17c :4 0 b6
:2 0 b7 :3 0 adc
12f1 12f3 :3 0 b6
:2 0 ca :4 0 adf
12f5 12f7 :3 0 b6
:2 0 cb :4 0 ae2
12f9 12fb :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 17d
:3 0 1300 1301 0
ae5 12ff 1303 bc
:4 0 ae7 12fe 1306
aea 12fd 1308 :3 0
b6 :2 0 11a :4 0
aed 130a 130c :3 0
b6 :2 0 b9 :4 0
af0 130e 1310 :3 0
b6 :2 0 25 :3 0
af3 1312 1314 :3 0
b6 :2 0 b9 :4 0
af6 1316 1318 :3 0
af9 12ee 131a :2 0
131c afc 131d 12eb
131c 0 131e afe
0 1348 ae :3 0
af :3 0 131f 1320
0 ae :3 0 be
:3 0 1322 1323 0
47 :2 0 2 :4 0
17e :2 0 c0 :2 0
47 :2 0 b00 1328
132a :3 0 b03 1324
132c 1321 132e 132d
:2 0 b1 :3 0 c1
:3 0 1330 1331 0
b3 :4 0 17f :4 0
b6 :2 0 b7 :3 0
b07 1335 1337 :3 0
b0a 1332 1339 :2 0
133b b0d 133c 132f
133b 0 133d b0f
0 1348 cf :3 0
11d :3 0 133e 133f
0 c3 :3 0 17d
:3 0 1341 1342 0
25 :3 0 d1 :3 0
b11 1340 1346 :2 0
1348 b15 1349 12da
1348 0 134a b19
0 14a6 a2 :3 0
4d :3 0 4e :2 0
b1b 134b 134e c3
:3 0 c4 :2 0 c5
:3 0 1350 1352 0
b20 1351 1354 :3 0
136 :3 0 a2 :3 0
134 :3 0 a2 :3 0
135 :3 0 64 :3 0
5f :3 0 60 :3 0
110 :3 0 111 :3 0
25 :4 0 180 1
:8 0 1367 21 :3 0
e9 :3 0 1362 1363
0 ea :3 0 1364
1365 0 1367 b23
13ba eb :3 0 21
:3 0 e9 :3 0 1369
136a 0 ea :3 0
136b 136c 0 136e
b26 1370 b28 136f
136e :2 0 13b8 ec
:3 0 21 :3 0 e9
:3 0 1373 1374 0
ea :3 0 1375 1376
0 13b0 ae :3 0
af :3 0 1378 1379
0 ae :3 0 be
:3 0 137b 137c 0
ed :2 0 2 :4 0
181 :2 0 c0 :2 0
47 :2 0 b2a 1381
1383 :3 0 b2d 137d
1385 137a 1387 1386
:2 0 b1 :3 0 c1
:3 0 1389 138a 0
b3 :4 0 182 :4 0
b6 :2 0 b7 :3 0
b31 138e 1390 :3 0
b6 :2 0 ca :4 0
b34 1392 1394 :3 0
b6 :2 0 f0 :4 0
b37 1396 1398 :3 0
b6 :2 0 ea :3 0
b3a 139a 139c :3 0
b6 :2 0 f1 :4 0
b3d 139e 13a0 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 b40 13a3
13a7 b44 13a2 13a9
:3 0 b47 138b 13ab
:2 0 13ad b4a 13ae
1388 13ad 0 13af
b4c 0 13b0 b4e
13b3 :3 0 13b3 0
13b3 13b2 13b0 13b1
:6 0 13b5 18 :3 0
b51 13b7 b53 13b6
13b5 :2 0 13b8 b55
:2 0 13ba 0 13ba
13b9 1367 13b8 :6 0
14a3 1 :3 0 21
:3 0 e9 :3 0 13bc
13bd 0 21 :3 0
d3 :2 0 16b :3 0
13bf 13c1 0 b5a
13c0 13c3 :3 0 13c4
:2 0 5f :3 0 60
:3 0 183 :3 0 111
:3 0 25 :4 0 184
1 :8 0 13d1 21
:3 0 e9 :3 0 13cc
13cd 0 ea :3 0
13ce 13cf 0 13d1
b5d 1424 eb :3 0
21 :3 0 e9 :3 0
13d3 13d4 0 ea
:3 0 13d5 13d6 0
13d8 b60 13da b62
13d9 13d8 :2 0 1422
ec :3 0 21 :3 0
e9 :3 0 13dd 13de
0 ea :3 0 13df
13e0 0 141a ae
:3 0 af :3 0 13e2
13e3 0 ae :3 0
be :3 0 13e5 13e6
0 ed :2 0 2
:4 0 185 :2 0 c0
:2 0 47 :2 0 b64
13eb 13ed :3 0 b67
13e7 13ef 13e4 13f1
13f0 :2 0 b1 :3 0
c1 :3 0 13f3 13f4
0 b3 :4 0 186
:4 0 b6 :2 0 b7
:3 0 b6b 13f8 13fa
:3 0 b6 :2 0 ca
:4 0 b6e 13fc 13fe
:3 0 b6 :2 0 f0
:4 0 b71 1400 1402
:3 0 b6 :2 0 ea
:3 0 b74 1404 1406
:3 0 b6 :2 0 f1
:4 0 b77 1408 140a
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 b7a
140d 1411 b7e 140c
1413 :3 0 b81 13f5
1415 :2 0 1417 b84
1418 13f2 1417 0
1419 b86 0 141a
b88 141d :3 0 141d
0 141d 141c 141a
141b :6 0 141f 1a
:3 0 b8b 1421 b8d
1420 141f :2 0 1422
b8f :2 0 1424 0
1424 1423 13d1 1422
:6 0 14a0 1 :3 0
21 :3 0 e9 :3 0
1426 1427 0 21
:3 0 d3 :2 0 16b
:3 0 1429 142b 0
b94 142a 142d :3 0
142e :2 0 ae :3 0
af :3 0 1430 1431
0 ae :3 0 be
:3 0 1433 1434 0
24 :2 0 2 :4 0
187 :2 0 c0 :2 0
47 :2 0 b97 1439
143b :3 0 b9a 1435
143d 1432 143f 143e
:2 0 b1 :3 0 c1
:3 0 1441 1442 0
b3 :4 0 188 :4 0
b6 :2 0 b7 :3 0
b9e 1446 1448 :3 0
b6 :2 0 ca :4 0
ba1 144a 144c :3 0
b6 :2 0 cb :4 0
ba4 144e 1450 :3 0
b6 :2 0 a2 :3 0
bb :3 0 c3 :3 0
d7 :3 0 1455 1456
0 ba7 1454 1458
bc :4 0 ba9 1453
145b bac 1452 145d
:3 0 b6 :2 0 11a
:4 0 baf 145f 1461
:3 0 b6 :2 0 b9
:4 0 bb2 1463 1465
:3 0 b6 :2 0 25
:3 0 bb5 1467 1469
:3 0 b6 :2 0 b9
:4 0 bb8 146b 146d
:3 0 bbb 1443 146f
:2 0 1471 bbe 1472
1440 1471 0 1473
bc0 0 149d ae
:3 0 af :3 0 1474
1475 0 ae :3 0
be :3 0 1477 1478
0 47 :2 0 2
:4 0 189 :2 0 c0
:2 0 47 :2 0 bc2
147d 147f :3 0 bc5
1479 1481 1476 1483
1482 :2 0 b1 :3 0
c1 :3 0 1485 1486
0 b3 :4 0 18a
:4 0 b6 :2 0 b7
:3 0 bc9 148a 148c
:3 0 bcc 1487 148e
:2 0 1490 bcf 1491
1484 1490 0 1492
bd1 0 149d cf
:3 0 11d :3 0 1493
1494 0 c3 :3 0
d7 :3 0 1496 1497
0 25 :3 0 d1
:3 0 bd3 1495 149b
:2 0 149d bd7 149e
142f 149d 0 149f
bdb 0 14a0 bdd
14a1 13c5 14a0 0
14a2 be0 0 14a3
be2 14a4 1355 14a3
0 14a5 be5 0
14a6 be7 14a7 12bd
14a6 0 14a8 bea
0 3696 a2 :3 0
d :3 0 4e :2 0
bec 14a9 14ac d3
:2 0 4e :2 0 bf1
14ae 14b0 :3 0 a2
:3 0 5b :3 0 4e
:2 0 bf4 14b2 14b5
c4 :2 0 18b :2 0
bf9 14b7 14b9 :3 0
14b1 14bb 14ba :2 0
57 :3 0 4e :2 0
14bd 14be 0 14c0
bfc 14c1 14bc 14c0
0 14c2 bfe 0
3696 a2 :3 0 4d
:3 0 4e :2 0 c00
14c3 14c6 c3 :3 0
d3 :2 0 c5 :3 0
14c8 14ca 0 c05
14c9 14cc :3 0 5
:3 0 c6 :2 0 c08
14cf 14d0 :3 0 14d1
:2 0 41 :3 0 18c
:4 0 14d3 14d4 0
14d9 42 :3 0 18c
:4 0 14d6 14d7 0
14d9 c0a 14e1 41
:3 0 5 :3 0 14da
14db 0 14e0 42
:3 0 5 :3 0 14dd
14de 0 14e0 c0d
14e2 14d2 14d9 0
14e3 0 14e0 0
14e3 c10 0 14e7
59 :3 0 4e :2 0
14e4 14e5 0 14e7
c13 1698 8a :3 0
d3 :2 0 4e :2 0
c18 14e9 14eb :3 0
42 :3 0 18d :4 0
14ed 14ee 0 1605
83 :3 0 18e :3 0
41 :3 0 42 :3 0
a2 :3 0 5a :3 0
4e :2 0 c1b 14f4
14f7 a2 :3 0 5b
:3 0 4e :2 0 c1e
14f9 14fc a2 :3 0
5c :3 0 4e :2 0
c21 14fe 1501 a2
:3 0 4d :3 0 4e
:2 0 c24 1503 1506
a2 :3 0 5d :3 0
4e :2 0 c27 1508
150b a2 :3 0 58
:3 0 4e :2 0 c2a
150d 1510 a2 :3 0
5f :3 0 4e :2 0
c2d 1512 1515 a2
:3 0 60 :3 0 4e
:2 0 c30 1517 151a
57 :3 0 59 :3 0
61 :3 0 c33 14f1
151f 14f0 1520 0
1605 a2 :3 0 83
:3 0 4e :2 0 c41
1522 1525 c3 :3 0
d3 :2 0 d7 :3 0
1527 1529 0 c46
1528 152b :3 0 ae
:3 0 af :3 0 152d
152e 0 ae :3 0
be :3 0 1530 1531
0 c7 :2 0 2
:4 0 18f :2 0 c0
:2 0 47 :2 0 c49
1536 1538 :3 0 c4c
1532 153a 152f 153c
153b :2 0 b1 :3 0
c1 :3 0 153e 153f
0 b3 :4 0 190
:4 0 b6 :2 0 b7
:3 0 c50 1543 1545
:3 0 b6 :2 0 ca
:4 0 c53 1547 1549
:3 0 b6 :2 0 cb
:4 0 c56 154b 154d
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 1552
1553 0 c59 1551
1555 bc :4 0 c5b
1550 1558 c5e 154f
155a :3 0 c61 1540
155c :2 0 155e c64
155f 153d 155e 0
1560 c66 0 158a
ae :3 0 af :3 0
1561 1562 0 ae
:3 0 be :3 0 1564
1565 0 47 :2 0
2 :4 0 191 :2 0
c0 :2 0 47 :2 0
c68 156a 156c :3 0
c6b 1566 156e 1563
1570 156f :2 0 b1
:3 0 c1 :3 0 1572
1573 0 b3 :4 0
192 :4 0 b6 :2 0
b7 :3 0 c6f 1577
1579 :3 0 c72 1574
157b :2 0 157d c75
157e 1571 157d 0
157f c77 0 158a
cf :3 0 d0 :3 0
1580 1581 0 c3
:3 0 d7 :3 0 1583
1584 0 d1 :3 0
c79 1582 1587 :2 0
158a d9 :3 0 c7c
1603 a2 :3 0 83
:3 0 4e :2 0 c80
158b 158e c4 :2 0
4e :2 0 c85 1590
1592 :3 0 ae :3 0
af :3 0 1594 1595
0 ae :3 0 be
:3 0 1597 1598 0
24 :2 0 2 :4 0
193 :2 0 c0 :2 0
47 :2 0 c88 159d
159f :3 0 c8b 1599
15a1 1596 15a3 15a2
:2 0 b1 :3 0 c1
:3 0 15a5 15a6 0
b3 :4 0 194 :4 0
b6 :2 0 b7 :3 0
c8f 15aa 15ac :3 0
b6 :2 0 ca :4 0
c92 15ae 15b0 :3 0
b6 :2 0 cb :4 0
c95 15b2 15b4 :3 0
b6 :2 0 a2 :3 0
bb :3 0 83 :3 0
c98 15b8 15ba bc
:4 0 c9a 15b7 15bd
c9d 15b6 15bf :3 0
b6 :2 0 11a :4 0
ca0 15c1 15c3 :3 0
b6 :2 0 b9 :4 0
ca3 15c5 15c7 :3 0
b6 :2 0 25 :3 0
ca6 15c9 15cb :3 0
b6 :2 0 b9 :4 0
ca9 15cd 15cf :3 0
cac 15a7 15d1 :2 0
15d3 caf 15d4 15a4
15d3 0 15d5 cb1
0 1601 ae :3 0
af :3 0 15d6 15d7
0 ae :3 0 be
:3 0 15d9 15da 0
47 :2 0 2 :4 0
195 :2 0 c0 :2 0
47 :2 0 cb3 15df
15e1 :3 0 cb6 15db
15e3 15d8 15e5 15e4
:2 0 b1 :3 0 c1
:3 0 15e7 15e8 0
b3 :4 0 196 :4 0
b6 :2 0 b7 :3 0
cba 15ec 15ee :3 0
cbd 15e9 15f0 :2 0
15f2 cc0 15f3 15e6
15f2 0 15f4 cc2
0 1601 cf :3 0
11d :3 0 15f5 15f6
0 a2 :3 0 83
:3 0 4e :2 0 cc4
15f8 15fb 25 :3 0
d1 :3 0 cc7 15f7
15ff :2 0 1601 ccb
1602 1593 1601 0
1604 152c 158a 0
1604 ccf 0 1605
cd2 1625 42 :3 0
6 :3 0 1606 1607
0 1624 a2 :3 0
5b :3 0 4e :2 0
cd6 1609 160c d3
:2 0 de :2 0 cdb
160e 1610 :3 0 57
:3 0 a2 :3 0 57
:3 0 4e :2 0 cde
1613 1616 197 :2 0
a2 :3 0 60 :3 0
4e :2 0 ce1 1619
161c ce4 1618 161e
:3 0 1612 161f 0
1621 ce7 1622 1611
1621 0 1623 ce9
0 1624 ceb 1626
14ec 1605 0 1627
0 1624 0 1627
cee 0 1697 a2
:3 0 57 :3 0 4e
:2 0 cf1 1628 162b
109 :2 0 4e :2 0
cf6 162d 162f :3 0
1630 :2 0 a2 :3 0
5b :3 0 4e :2 0
cf9 1632 1635 c4
:2 0 18b :2 0 cfe
1637 1639 :3 0 163a
:2 0 1631 163c 163b
:2 0 a2 :3 0 5b
:3 0 4e :2 0 d01
163e 1641 d3 :2 0
47 :2 0 d06 1643
1645 :3 0 1646 :2 0
a2 :3 0 5b :3 0
4e :2 0 d09 1648
164b d3 :2 0 106
:2 0 d0e 164d 164f
:3 0 1650 :2 0 1647
1652 1651 :2 0 5a
:3 0 106 :2 0 1654
1655 0 1658 d9
:3 0 d11 1692 a2
:3 0 5b :3 0 4e
:2 0 d13 1659 165c
d3 :2 0 4e :2 0
d18 165e 1660 :3 0
5a :3 0 47 :2 0
1662 1663 0 1666
d9 :3 0 d1b 1667
1661 1666 0 1693
a2 :3 0 5b :3 0
4e :2 0 d1d 1668
166b d3 :2 0 108
:2 0 d22 166d 166f
:3 0 1670 :2 0 a2
:3 0 5b :3 0 4e
:2 0 d25 1672 1675
d3 :2 0 198 :2 0
d2a 1677 1679 :3 0
167a :2 0 1671 167c
167b :2 0 5a :3 0
47 :2 0 167e 167f
0 1682 d9 :3 0
d2d 1683 167d 1682
0 1693 a2 :3 0
5b :3 0 4e :2 0
d2f 1684 1687 d3
:2 0 de :2 0 d34
1689 168b :3 0 5a
:3 0 108 :2 0 168d
168e 0 1690 d37
1691 168c 1690 0
1693 1653 1658 0
1693 d39 0 1694
d3e 1695 163d 1694
0 1696 d40 0
1697 d42 1699 14cd
14e7 0 169a 0
1697 0 169a d45
0 3696 a2 :3 0
5c :3 0 4e :2 0
d48 169b 169e c3
:3 0 d3 :2 0 d4
:3 0 16a0 16a2 0
d4d 16a1 16a4 :3 0
8e :3 0 4e :2 0
16a6 16a7 0 1b81
2e :3 0 16 :3 0
16a9 16aa 0 1b81
30 :3 0 17 :3 0
16ac 16ad 0 1b81
49 :3 0 f2 :3 0
2e :3 0 47 :2 0
24 :2 0 d50 16b0
16b4 16af 16b5 0
1b81 4c :4 0 16b7
16b8 0 1b81 a2
:3 0 6b :3 0 4e
:2 0 d54 16ba 16bd
d3 :2 0 4e :2 0
d59 16bf 16c1 :3 0
39 :3 0 199 :4 0
16c4 16c5 :3 0 16c3
16c6 0 16cb 8e
:3 0 47 :2 0 16c8
16c9 0 16cb d5c
17b1 10f :3 0 4c
:3 0 19a :3 0 19b
:3 0 39 :4 0 19c
1 :8 0 16d7 21
:3 0 e9 :3 0 16d2
16d3 0 ea :3 0
16d4 16d5 0 16d7
d5f 172a eb :3 0
21 :3 0 e9 :3 0
16d9 16da 0 ea
:3 0 16db 16dc 0
16de d62 16e0 d64
16df 16de :2 0 1728
ec :3 0 21 :3 0
e9 :3 0 16e3 16e4
0 ea :3 0 16e5
16e6 0 1720 ae
:3 0 af :3 0 16e8
16e9 0 ae :3 0
be :3 0 16eb 16ec
0 ed :2 0 2
:4 0 19d :2 0 c0
:2 0 47 :2 0 d66
16f1 16f3 :3 0 d69
16ed 16f5 16ea 16f7
16f6 :2 0 b1 :3 0
c1 :3 0 16f9 16fa
0 b3 :4 0 19e
:4 0 b6 :2 0 b7
:3 0 d6d 16fe 1700
:3 0 b6 :2 0 ca
:4 0 d70 1702 1704
:3 0 b6 :2 0 f0
:4 0 d73 1706 1708
:3 0 b6 :2 0 ea
:3 0 d76 170a 170c
:3 0 b6 :2 0 f1
:4 0 d79 170e 1710
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 d7c
1713 1717 d80 1712
1719 :3 0 d83 16fb
171b :2 0 171d d86
171e 16f8 171d 0
171f d88 0 1720
d8a 1723 :3 0 1723
0 1723 1722 1720
1721 :6 0 1725 1c
:3 0 d8d 1727 d8f
1726 1725 :2 0 1728
d91 :2 0 172a 0
172a 1729 16d7 1728
:6 0 17b0 1 :3 0
21 :3 0 e9 :3 0
172c 172d 0 21
:3 0 d3 :2 0 f5
:3 0 172f 1731 0
d96 1730 1733 :3 0
1734 :2 0 a2 :3 0
50 :3 0 4e :2 0
d99 1736 1739 109
:2 0 4e :2 0 d9e
173b 173d :3 0 19f
:3 0 28 :3 0 1a0
:3 0 111 :3 0 26
:3 0 9b :3 0 39
:3 0 1a1 :3 0 1a2
:3 0 c3 :3 0 1a3
:4 0 1a4 1 :8 0
1750 21 :3 0 e9
:3 0 174b 174c 0
ea :3 0 174d 174e
0 1750 da1 17a3
eb :3 0 21 :3 0
e9 :3 0 1752 1753
0 ea :3 0 1754
1755 0 1757 da4
1759 da6 1758 1757
:2 0 17a1 ec :3 0
21 :3 0 e9 :3 0
175c 175d 0 ea
:3 0 175e 175f 0
1799 ae :3 0 af
:3 0 1761 1762 0
ae :3 0 be :3 0
1764 1765 0 ed
:2 0 2 :4 0 1a5
:2 0 c0 :2 0 47
:2 0 da8 176a 176c
:3 0 dab 1766 176e
1763 1770 176f :2 0
b1 :3 0 c1 :3 0
1772 1773 0 b3
:4 0 1a6 :4 0 b6
:2 0 b7 :3 0 daf
1777 1779 :3 0 b6
:2 0 ca :4 0 db2
177b 177d :3 0 b6
:2 0 f0 :4 0 db5
177f 1781 :3 0 b6
:2 0 ea :3 0 db8
1783 1785 :3 0 b6
:2 0 f1 :4 0 dbb
1787 1789 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 dbe 178c 1790
dc2 178b 1792 :3 0
dc5 1774 1794 :2 0
1796 dc8 1797 1771
1796 0 1798 dca
0 1799 dcc 179c
:3 0 179c 0 179c
179b 1799 179a :6 0
179e 1e :3 0 dcf
17a0 dd1 179f 179e
:2 0 17a1 dd3 :2 0
17a3 0 17a3 17a2
1750 17a1 :6 0 17a5
1 :3 0 dd6 17a6
173e 17a5 0 17a7
dd8 0 17a8 dda
17ad 8e :3 0 47
:2 0 17a9 17aa 0
17ac ddc 17ae 1735
17a8 0 17af 0
17ac 0 17af dde
0 17b0 de1 17b2
16c2 16cb 0 17b3
0 17b0 0 17b3
de4 0 1b81 8e
:3 0 c4 :2 0 4e
:2 0 de9 17b5 17b7
:3 0 a2 :3 0 1a7
:3 0 1a8 :3 0 63
:3 0 19a :3 0 99
:3 0 25 :3 0 a1
:3 0 49 :4 0 1a9
1 :8 0 17c8 21
:3 0 e9 :3 0 17c3
17c4 0 ea :3 0
17c5 17c6 0 17c8
dec 181b eb :3 0
21 :3 0 e9 :3 0
17ca 17cb 0 ea
:3 0 17cc 17cd 0
17cf def 17d1 df1
17d0 17cf :2 0 1819
ec :3 0 21 :3 0
e9 :3 0 17d4 17d5
0 ea :3 0 17d6
17d7 0 1811 ae
:3 0 af :3 0 17d9
17da 0 ae :3 0
be :3 0 17dc 17dd
0 ed :2 0 2
:4 0 1aa :2 0 c0
:2 0 47 :2 0 df3
17e2 17e4 :3 0 df6
17de 17e6 17db 17e8
17e7 :2 0 b1 :3 0
c1 :3 0 17ea 17eb
0 b3 :4 0 1ab
:4 0 b6 :2 0 b7
:3 0 dfa 17ef 17f1
:3 0 b6 :2 0 ca
:4 0 dfd 17f3 17f5
:3 0 b6 :2 0 f0
:4 0 e00 17f7 17f9
:3 0 b6 :2 0 ea
:3 0 e03 17fb 17fd
:3 0 b6 :2 0 f1
:4 0 e06 17ff 1801
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 e09
1804 1808 e0d 1803
180a :3 0 e10 17ec
180c :2 0 180e e13
180f 17e9 180e 0
1810 e15 0 1811
e17 1814 :3 0 1814
0 1814 1813 1811
1812 :6 0 1816 20
:3 0 e1a 1818 e1c
1817 1816 :2 0 1819
e1e :2 0 181b 0
181b 181a 17c8 1819
:6 0 19a4 1 :3 0
e5 :3 0 1ac :3 0
e5 :3 0 1ac :3 0
e5 :3 0 1ac :3 0
e5 :3 0 1ac :3 0
e5 :3 0 1ac :3 0
a0 :3 0 1ad :3 0
1ae :3 0 a0 :3 0
1af :3 0 1ae :3 0
a0 :3 0 bb :3 0
63 :3 0 4b :3 0
1b0 :3 0 1af :3 0
1b0 :3 0 1ad :3 0
1af :3 0 111 :3 0
49 :3 0 1ad :3 0
111 :3 0 1af :3 0
1b1 :4 0 1b2 1
:8 0 1842 21 :3 0
e9 :3 0 183d 183e
0 ea :3 0 183f
1840 0 1842 e21
1895 eb :3 0 21
:3 0 e9 :3 0 1844
1845 0 ea :3 0
1846 1847 0 1849
e24 184b e26 184a
1849 :2 0 1893 ec
:3 0 21 :3 0 e9
:3 0 184e 184f 0
ea :3 0 1850 1851
0 188b ae :3 0
af :3 0 1853 1854
0 ae :3 0 be
:3 0 1856 1857 0
ed :2 0 2 :4 0
1b3 :2 0 c0 :2 0
47 :2 0 e28 185c
185e :3 0 e2b 1858
1860 1855 1862 1861
:2 0 b1 :3 0 c1
:3 0 1864 1865 0
b3 :4 0 1b4 :4 0
b6 :2 0 b7 :3 0
e2f 1869 186b :3 0
b6 :2 0 ca :4 0
e32 186d 186f :3 0
b6 :2 0 f0 :4 0
e35 1871 1873 :3 0
b6 :2 0 ea :3 0
e38 1875 1877 :3 0
b6 :2 0 f1 :4 0
e3b 1879 187b :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 e3e 187e
1882 e42 187d 1884
:3 0 e45 1866 1886
:2 0 1888 e48 1889
1863 1888 0 188a
e4a 0 188b e4c
188e :3 0 188e 0
188e 188d 188b 188c
:6 0 1890 22 :3 0
e4f 1892 e51 1891
1890 :2 0 1893 e53
:2 0 1895 0 1895
1894 1842 1893 :6 0
19a4 1 :3 0 21
:3 0 e9 :3 0 1897
1898 0 21 :3 0
d3 :2 0 16b :3 0
189a 189c 0 e58
189b 189e :3 0 189f
:2 0 ae :3 0 af
:3 0 18a1 18a2 0
ae :3 0 be :3 0
18a4 18a5 0 24
:2 0 2 :4 0 1b5
:2 0 c0 :2 0 47
:2 0 e5b 18aa 18ac
:3 0 e5e 18a6 18ae
18a3 18b0 18af :2 0
b1 :3 0 c1 :3 0
18b2 18b3 0 b3
:4 0 1b6 :4 0 b6
:2 0 b7 :3 0 e62
18b7 18b9 :3 0 b6
:2 0 ca :4 0 e65
18bb 18bd :3 0 b6
:2 0 cb :4 0 e68
18bf 18c1 :3 0 b6
:2 0 a2 :3 0 bb
:3 0 c3 :3 0 146
:3 0 18c6 18c7 0
e6b 18c5 18c9 bc
:4 0 e6d 18c4 18cc
e70 18c3 18ce :3 0
b6 :2 0 11a :4 0
e73 18d0 18d2 :3 0
b6 :2 0 b9 :4 0
e76 18d4 18d6 :3 0
b6 :2 0 49 :3 0
e79 18d8 18da :3 0
b6 :2 0 b9 :4 0
e7c 18dc 18de :3 0
e7f 18b4 18e0 :2 0
18e2 e82 18e3 18b1
18e2 0 18e4 e84
0 190e ae :3 0
af :3 0 18e5 18e6
0 ae :3 0 be
:3 0 18e8 18e9 0
47 :2 0 2 :4 0
1b7 :2 0 c0 :2 0
47 :2 0 e86 18ee
18f0 :3 0 e89 18ea
18f2 18e7 18f4 18f3
:2 0 b1 :3 0 c1
:3 0 18f6 18f7 0
b3 :4 0 1b8 :4 0
b6 :2 0 b7 :3 0
e8d 18fb 18fd :3 0
e90 18f8 18ff :2 0
1901 e93 1902 18f5
1901 0 1903 e95
0 190e cf :3 0
11d :3 0 1904 1905
0 c3 :3 0 146
:3 0 1907 1908 0
49 :3 0 d1 :3 0
e97 1906 190c :2 0
190e e9b 190f 18a0
190e 0 1910 e9f
0 19a4 a2 :3 0
50 :3 0 4e :2 0
ea1 1911 1914 109
:2 0 4e :2 0 ea6
1916 1918 :3 0 82
:3 0 1b9 :4 0 191a
191b 0 191d ea9
1922 82 :3 0 1ba
:4 0 191e 191f 0
1921 eab 1923 1919
191d 0 1924 0
1921 0 1924 ead
0 19a4 19a :3 0
19b :3 0 99 :3 0
a1 :3 0 1a8 :3 0
1bb :3 0 10f :3 0
1bc :3 0 1bd :3 0
1be :3 0 39 :3 0
25 :3 0 49 :3 0
63 :3 0 4b :3 0
82 :3 0 14 :3 0
13 :3 0 12 :4 0
1bf 1 :8 0 194e
1c0 :4 0 1939 :3 0
d1 :3 0 d3 :2 0
eb2 193c 193d :3 0
21 :3 0 e9 :3 0
193f 1940 0 4e
:2 0 1941 1942 0
1944 eb5 194b 21
:3 0 e9 :3 0 1945
1946 0 18b :2 0
1947 1948 0 194a
eb7 194c 193e 1944
0 194d 0 194a
0 194d eb9 0
194e ebc 19a1 eb
:3 0 21 :3 0 e9
:3 0 1950 1951 0
ea :3 0 1952 1953
0 1955 ebf 1957
ec1 1956 1955 :2 0
199f ec :3 0 21
:3 0 e9 :3 0 195a
195b 0 ea :3 0
195c 195d 0 1997
ae :3 0 af :3 0
195f 1960 0 ae
:3 0 be :3 0 1962
1963 0 ed :2 0
2 :4 0 1c1 :2 0
c0 :2 0 47 :2 0
ec3 1968 196a :3 0
ec6 1964 196c 1961
196e 196d :2 0 b1
:3 0 c1 :3 0 1970
1971 0 b3 :4 0
1c2 :4 0 b6 :2 0
b7 :3 0 eca 1975
1977 :3 0 b6 :2 0
ca :4 0 ecd 1979
197b :3 0 b6 :2 0
f0 :4 0 ed0 197d
197f :3 0 b6 :2 0
ea :3 0 ed3 1981
1983 :3 0 b6 :2 0
f1 :4 0 ed6 1985
1987 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
ed9 198a 198e edd
1989 1990 :3 0 ee0
1972 1992 :2 0 1994
ee3 1995 196f 1994
0 1996 ee5 0
1997 ee7 199a :3 0
199a 0 199a 1999
1997 1998 :6 0 199c
24 :3 0 eea 199e
eec 199d 199c :2 0
199f eee :2 0 19a1
0 19a1 19a0 194e
199f :6 0 19a4 1
:3 0 d9 :3 0 ef1
1a26 f2 :3 0 4c
:3 0 47 :2 0 47
:2 0 ef7 19a5 19a9
d3 :2 0 1ba :4 0
efd 19ab 19ad :3 0
19a :3 0 10f :3 0
1bc :3 0 14 :3 0
1bd :3 0 13 :3 0
1be :3 0 12 :3 0
19b :3 0 39 :4 0
1c3 1 :8 0 19cf
1c0 :4 0 19ba :3 0
d1 :3 0 d3 :2 0
f02 19bd 19be :3 0
21 :3 0 e9 :3 0
19c0 19c1 0 4e
:2 0 19c2 19c3 0
19c5 f05 19cc 21
:3 0 e9 :3 0 19c6
19c7 0 18b :2 0
19c8 19c9 0 19cb
f07 19cd 19bf 19c5
0 19ce 0 19cb
0 19ce f09 0
19cf f0c 1a22 eb
:3 0 21 :3 0 e9
:3 0 19d1 19d2 0
ea :3 0 19d3 19d4
0 19d6 f0f 19d8
f11 19d7 19d6 :2 0
1a20 ec :3 0 21
:3 0 e9 :3 0 19db
19dc 0 ea :3 0
19dd 19de 0 1a18
ae :3 0 af :3 0
19e0 19e1 0 ae
:3 0 be :3 0 19e3
19e4 0 ed :2 0
2 :4 0 1c4 :2 0
c0 :2 0 47 :2 0
f13 19e9 19eb :3 0
f16 19e5 19ed 19e2
19ef 19ee :2 0 b1
:3 0 c1 :3 0 19f1
19f2 0 b3 :4 0
1c5 :4 0 b6 :2 0
b7 :3 0 f1a 19f6
19f8 :3 0 b6 :2 0
ca :4 0 f1d 19fa
19fc :3 0 b6 :2 0
f0 :4 0 f20 19fe
1a00 :3 0 b6 :2 0
ea :3 0 f23 1a02
1a04 :3 0 b6 :2 0
f1 :4 0 f26 1a06
1a08 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
f29 1a0b 1a0f f2d
1a0a 1a11 :3 0 f30
19f3 1a13 :2 0 1a15
f33 1a16 19f0 1a15
0 1a17 f35 0
1a18 f37 1a1b :3 0
1a1b 0 1a1b 1a1a
1a18 1a19 :6 0 1a1d
26 :3 0 f3a 1a1f
f3c 1a1e 1a1d :2 0
1a20 f3e :2 0 1a22
0 1a22 1a21 19cf
1a20 :6 0 1a24 1
:3 0 f41 1a25 19ae
1a24 0 1a27 17b8
19a4 0 1a27 f43
0 1b81 1c6 :3 0
19f :3 0 19b :3 0
19a :3 0 99 :3 0
25 :3 0 10f :3 0
19b :3 0 39 :4 0
1c7 1 :8 0 1a47
1c0 :4 0 1a32 :3 0
d1 :3 0 d3 :2 0
f48 1a35 1a36 :3 0
21 :3 0 e9 :3 0
1a38 1a39 0 4e
:2 0 1a3a 1a3b 0
1a3d f4b 1a44 21
:3 0 e9 :3 0 1a3e
1a3f 0 18b :2 0
1a40 1a41 0 1a43
f4d 1a45 1a37 1a3d
0 1a46 0 1a43
0 1a46 f4f 0
1a47 f52 1a9a eb
:3 0 21 :3 0 e9
:3 0 1a49 1a4a 0
ea :3 0 1a4b 1a4c
0 1a4e f55 1a50
f57 1a4f 1a4e :2 0
1a98 ec :3 0 21
:3 0 e9 :3 0 1a53
1a54 0 ea :3 0
1a55 1a56 0 1a90
ae :3 0 af :3 0
1a58 1a59 0 ae
:3 0 be :3 0 1a5b
1a5c 0 ed :2 0
2 :4 0 1c8 :2 0
c0 :2 0 47 :2 0
f59 1a61 1a63 :3 0
f5c 1a5d 1a65 1a5a
1a67 1a66 :2 0 b1
:3 0 c1 :3 0 1a69
1a6a 0 b3 :4 0
1c9 :4 0 b6 :2 0
b7 :3 0 f60 1a6e
1a70 :3 0 b6 :2 0
ca :4 0 f63 1a72
1a74 :3 0 b6 :2 0
f0 :4 0 f66 1a76
1a78 :3 0 b6 :2 0
ea :3 0 f69 1a7a
1a7c :3 0 b6 :2 0
f1 :4 0 f6c 1a7e
1a80 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
f6f 1a83 1a87 f73
1a82 1a89 :3 0 f76
1a6b 1a8b :2 0 1a8d
f79 1a8e 1a68 1a8d
0 1a8f f7b 0
1a90 f7d 1a93 :3 0
1a93 0 1a93 1a92
1a90 1a91 :6 0 1a95
28 :3 0 f80 1a97
f82 1a96 1a95 :2 0
1a98 f84 :2 0 1a9a
0 1a9a 1a99 1a47
1a98 :6 0 1b81 1
:3 0 1ca :3 0 19f
:3 0 19b :3 0 19a
:3 0 99 :3 0 25
:3 0 10f :3 0 19b
:3 0 39 :4 0 1cb
1 :8 0 1abb 1c0
:4 0 1aa6 :3 0 d1
:3 0 d3 :2 0 f89
1aa9 1aaa :3 0 21
:3 0 e9 :3 0 1aac
1aad 0 4e :2 0
1aae 1aaf 0 1ab1
f8c 1ab8 21 :3 0
e9 :3 0 1ab2 1ab3
0 18b :2 0 1ab4
1ab5 0 1ab7 f8e
1ab9 1aab 1ab1 0
1aba 0 1ab7 0
1aba f90 0 1abb
f93 1b0e eb :3 0
21 :3 0 e9 :3 0
1abd 1abe 0 ea
:3 0 1abf 1ac0 0
1ac2 f96 1ac4 f98
1ac3 1ac2 :2 0 1b0c
ec :3 0 21 :3 0
e9 :3 0 1ac7 1ac8
0 ea :3 0 1ac9
1aca 0 1b04 ae
:3 0 af :3 0 1acc
1acd 0 ae :3 0
be :3 0 1acf 1ad0
0 ed :2 0 2
:4 0 1cc :2 0 c0
:2 0 47 :2 0 f9a
1ad5 1ad7 :3 0 f9d
1ad1 1ad9 1ace 1adb
1ada :2 0 b1 :3 0
c1 :3 0 1add 1ade
0 b3 :4 0 1cd
:4 0 b6 :2 0 b7
:3 0 fa1 1ae2 1ae4
:3 0 b6 :2 0 ca
:4 0 fa4 1ae6 1ae8
:3 0 b6 :2 0 f0
:4 0 fa7 1aea 1aec
:3 0 b6 :2 0 ea
:3 0 faa 1aee 1af0
:3 0 b6 :2 0 f1
:4 0 fad 1af2 1af4
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 fb0
1af7 1afb fb4 1af6
1afd :3 0 fb7 1adf
1aff :2 0 1b01 fba
1b02 1adc 1b01 0
1b03 fbc 0 1b04
fbe 1b07 :3 0 1b07
0 1b07 1b06 1b04
1b05 :6 0 1b09 2a
:3 0 fc1 1b0b fc3
1b0a 1b09 :2 0 1b0c
fc5 :2 0 1b0e 0
1b0e 1b0d 1abb 1b0c
:6 0 1b81 1 :3 0
19a :3 0 99 :3 0
25 :3 0 10f :3 0
19b :3 0 39 :4 0
1ce 1 :8 0 1b2c
1c0 :4 0 1b17 :3 0
d1 :3 0 d3 :2 0
fca 1b1a 1b1b :3 0
21 :3 0 e9 :3 0
1b1d 1b1e 0 4e
:2 0 1b1f 1b20 0
1b22 fcd 1b29 21
:3 0 e9 :3 0 1b23
1b24 0 18b :2 0
1b25 1b26 0 1b28
fcf 1b2a 1b1c 1b22
0 1b2b 0 1b28
0 1b2b fd1 0
1b2c fd4 1b7f eb
:3 0 21 :3 0 e9
:3 0 1b2e 1b2f 0
ea :3 0 1b30 1b31
0 1b33 fd7 1b35
fd9 1b34 1b33 :2 0
1b7d ec :3 0 21
:3 0 e9 :3 0 1b38
1b39 0 ea :3 0
1b3a 1b3b 0 1b75
ae :3 0 af :3 0
1b3d 1b3e 0 ae
:3 0 be :3 0 1b40
1b41 0 ed :2 0
2 :4 0 1cf :2 0
c0 :2 0 47 :2 0
fdb 1b46 1b48 :3 0
fde 1b42 1b4a 1b3f
1b4c 1b4b :2 0 b1
:3 0 c1 :3 0 1b4e
1b4f 0 b3 :4 0
1d0 :4 0 b6 :2 0
b7 :3 0 fe2 1b53
1b55 :3 0 b6 :2 0
ca :4 0 fe5 1b57
1b59 :3 0 b6 :2 0
f0 :4 0 fe8 1b5b
1b5d :3 0 b6 :2 0
ea :3 0 feb 1b5f
1b61 :3 0 b6 :2 0
f1 :4 0 fee 1b63
1b65 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
ff1 1b68 1b6c ff5
1b67 1b6e :3 0 ff8
1b50 1b70 :2 0 1b72
ffb 1b73 1b4d 1b72
0 1b74 ffd 0
1b75 fff 1b78 :3 0
1b78 0 1b78 1b77
1b75 1b76 :6 0 1b7a
2c :3 0 1002 1b7c
1004 1b7b 1b7a :2 0
1b7d 1006 :2 0 1b7f
0 1b7f 1b7e 1b2c
1b7d :6 0 1b81 1
:3 0 1009 1b82 16a5
1b81 0 1b83 1014
0 3696 85 :3 0
1d1 :4 0 1b85 1b86
:3 0 1b84 1b87 0
3696 a2 :3 0 50
:3 0 4e :2 0 1016
1b89 1b8c d3 :2 0
4e :2 0 101b 1b8e
1b90 :3 0 a2 :3 0
5c :3 0 4e :2 0
101e 1b92 1b95 c3
:3 0 c4 :2 0 d4
:3 0 1b97 1b99 0
1023 1b98 1b9b :3 0
1b91 1b9d 1b9c :2 0
a2 :3 0 5c :3 0
4e :2 0 1026 1b9f
1ba2 c3 :3 0 c4
:2 0 d2 :3 0 1ba4
1ba6 0 102b 1ba5
1ba8 :3 0 1b9e 1baa
1ba9 :2 0 1e :3 0
e4 :2 0 102e 1bad
1bae :3 0 1baf :2 0
3a :3 0 1e :3 0
1bb1 1bb2 0 1bb4
1030 1bb5 1bb0 1bb4
0 1bb6 1032 0
1bb7 1034 1bb8 1bab
1bb7 0 1bb9 1036
0 3696 a2 :3 0
56 :3 0 4e :2 0
1038 1bba 1bbd d3
:2 0 4e :2 0 103d
1bbf 1bc1 :3 0 56
:3 0 c3 :3 0 1d2
:3 0 1bc4 1bc5 0
1bc3 1bc6 0 1bc8
1040 1bc9 1bc2 1bc8
0 1bca 1042 0
3696 16 :3 0 c6
:2 0 1044 1bcc 1bcd
:3 0 1bce :2 0 17
:3 0 c6 :2 0 1046
1bd1 1bd2 :3 0 1bd3
:2 0 1bcf 1bd5 1bd4
:2 0 18 :3 0 c6
:2 0 1048 1bd8 1bd9
:3 0 1bda :2 0 1bd6
1bdc 1bdb :2 0 19
:3 0 c6 :2 0 104a
1bdf 1be0 :3 0 1be1
:2 0 1be2 :2 0 1bdd
1be4 1be3 :2 0 8c
:3 0 47 :2 0 1be6
1be7 0 1be9 104c
1bea 1be5 1be9 0
1beb 104e 0 3696
75 :3 0 18d :4 0
1bec 1bed 0 3696
77 :3 0 18d :4 0
1bef 1bf0 0 3696
a2 :3 0 50 :3 0
4e :2 0 1050 1bf2
1bf5 109 :2 0 4e
:2 0 1055 1bf7 1bf9
:3 0 a2 :3 0 5c
:3 0 4e :2 0 1058
1bfb 1bfe c3 :3 0
d3 :2 0 d4 :3 0
1c00 1c02 0 105d
1c01 1c04 :3 0 75
:3 0 1d3 :4 0 b6
:2 0 39 :3 0 1060
1c08 1c0a :3 0 b6
:2 0 1d4 :4 0 1063
1c0c 1c0e :3 0 b6
:2 0 1d5 :4 0 1066
1c10 1c12 :3 0 b6
:2 0 1d6 :4 0 1069
1c14 1c16 :3 0 b6
:2 0 1d7 :4 0 106c
1c18 1c1a :3 0 b6
:2 0 49 :3 0 106f
1c1c 1c1e :3 0 b6
:2 0 b9 :4 0 1072
1c20 1c22 :3 0 1c06
1c23 0 1c26 d9
:3 0 1075 1c6d a2
:3 0 5c :3 0 4e
:2 0 1077 1c27 1c2a
d3 :2 0 2d :2 0
107c 1c2c 1c2e :3 0
75 :3 0 1d8 :4 0
b6 :2 0 1d9 :4 0
107f 1c32 1c34 :3 0
b6 :2 0 1da :4 0
1082 1c36 1c38 :3 0
b6 :2 0 25 :3 0
1085 1c3a 1c3c :3 0
b6 :2 0 1db :4 0
1088 1c3e 1c40 :3 0
b6 :2 0 1dc :4 0
108b 1c42 1c44 :3 0
b6 :2 0 39 :3 0
108e 1c46 1c48 :3 0
b6 :2 0 1db :4 0
1091 1c4a 1c4c :3 0
b6 :2 0 1dd :4 0
1094 1c4e 1c50 :3 0
1c30 1c51 0 1c53
1097 1c54 1c2f 1c53
0 1c6f 75 :3 0
1de :4 0 b6 :2 0
1df :4 0 1099 1c57
1c59 :3 0 b6 :2 0
1e0 :4 0 109c 1c5b
1c5d :3 0 b6 :2 0
1e1 :4 0 109f 1c5f
1c61 :3 0 b6 :2 0
39 :3 0 10a2 1c63
1c65 :3 0 b6 :2 0
1db :4 0 10a5 1c67
1c69 :3 0 1c55 1c6a
0 1c6c 10a8 1c6e
1c05 1c26 0 1c6f
0 1c6c 0 1c6f
10aa 0 1c70 10ae
25de a2 :3 0 5c
:3 0 4e :2 0 10b0
1c71 1c74 c3 :3 0
c4 :2 0 d4 :3 0
1c76 1c78 0 10b5
1c77 1c7a :3 0 a2
:3 0 5c :3 0 4e
:2 0 10b8 1c7c 1c7f
c3 :3 0 c4 :2 0
d2 :3 0 1c81 1c83
0 10bd 1c82 1c85
:3 0 1c7b 1c87 1c86
:2 0 a2 :3 0 a
:3 0 4e :2 0 10c0
1c89 1c8c c3 :3 0
c4 :2 0 c5 :3 0
1c8e 1c90 0 10c5
1c8f 1c92 :3 0 1c88
1c94 1c93 :2 0 1e2
:3 0 1e3 :3 0 1e4
:4 0 1c98 :4 0 1c99
:2 0 1db9 21 :3 0
e9 :3 0 1c9b 1c9c
0 4e :2 0 1c9d
1c9e 0 1db9 14
:3 0 c6 :2 0 10c8
1ca1 1ca2 :3 0 1ca3
:2 0 1e2 :3 0 1e3
:3 0 1e5 :4 0 1ca7
:4 0 1ca8 :2 0 1db1
21 :3 0 e9 :3 0
1caa 1cab 0 4e
:2 0 1cac 1cad 0
1db1 1e6 :3 0 111
:3 0 1e7 :3 0 183
:3 0 1e8 :3 0 1e9
:3 0 111 :3 0 1e9
:3 0 1e7 :3 0 183
:3 0 1e9 :3 0 1ea
:3 0 1a0 :3 0 1eb
:3 0 1e9 :3 0 111
:3 0 1eb :3 0 111
:3 0 1eb :3 0 1ec
:3 0 1eb :3 0 9b
:3 0 29 :4 0 1ed
1 :8 0 1cdc 1c0
:4 0 1cc7 :3 0 d1
:3 0 d3 :2 0 10cc
1cca 1ccb :3 0 21
:3 0 e9 :3 0 1ccd
1cce 0 4e :2 0
1ccf 1cd0 0 1cd2
10cf 1cd9 21 :3 0
e9 :3 0 1cd3 1cd4
0 18b :2 0 1cd5
1cd6 0 1cd8 10d1
1cda 1ccc 1cd2 0
1cdb 0 1cd8 0
1cdb 10d3 0 1cdc
10d6 1d2f eb :3 0
21 :3 0 e9 :3 0
1cde 1cdf 0 ea
:3 0 1ce0 1ce1 0
1ce3 10d9 1ce5 10db
1ce4 1ce3 :2 0 1d2d
ec :3 0 21 :3 0
e9 :3 0 1ce8 1ce9
0 ea :3 0 1cea
1ceb 0 1d25 ae
:3 0 af :3 0 1ced
1cee 0 ae :3 0
be :3 0 1cf0 1cf1
0 ed :2 0 2
:4 0 1ee :2 0 c0
:2 0 47 :2 0 10dd
1cf6 1cf8 :3 0 10e0
1cf2 1cfa 1cef 1cfc
1cfb :2 0 b1 :3 0
c1 :3 0 1cfe 1cff
0 b3 :4 0 1ef
:4 0 b6 :2 0 b7
:3 0 10e4 1d03 1d05
:3 0 b6 :2 0 ca
:4 0 10e7 1d07 1d09
:3 0 b6 :2 0 f0
:4 0 10ea 1d0b 1d0d
:3 0 b6 :2 0 ea
:3 0 10ed 1d0f 1d11
:3 0 b6 :2 0 f1
:4 0 10f0 1d13 1d15
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 10f3
1d18 1d1c 10f7 1d17
1d1e :3 0 10fa 1d00
1d20 :2 0 1d22 10fd
1d23 1cfd 1d22 0
1d24 10ff 0 1d25
1101 1d28 :3 0 1d28
0 1d28 1d27 1d25
1d26 :6 0 1d2a 2e
:3 0 1104 1d2c 1106
1d2b 1d2a :2 0 1d2d
1108 :2 0 1d2f 0
1d2f 1d2e 1cdc 1d2d
:6 0 1db1 1 :3 0
1f0 :3 0 1f1 :3 0
1e7 :3 0 1e6 :3 0
1f1 :3 0 13e :3 0
111 :3 0 1e6 :3 0
13e :3 0 13e :3 0
1e7 :3 0 1f1 :3 0
1e7 :3 0 f2 :3 0
1f1 :3 0 1e7 :3 0
1f2 :3 0 13e :3 0
1e7 :3 0 13e :3 0
1e7 :4 0 1f3 1
:8 0 1d5c 1c0 :4 0
1d47 :3 0 d1 :3 0
d3 :2 0 110d 1d4a
1d4b :3 0 21 :3 0
e9 :3 0 1d4d 1d4e
0 4e :2 0 1d4f
1d50 0 1d52 1110
1d59 21 :3 0 e9
:3 0 1d53 1d54 0
18b :2 0 1d55 1d56
0 1d58 1112 1d5a
1d4c 1d52 0 1d5b
0 1d58 0 1d5b
1114 0 1d5c 1117
1daf eb :3 0 21
:3 0 e9 :3 0 1d5e
1d5f 0 ea :3 0
1d60 1d61 0 1d63
111a 1d65 111c 1d64
1d63 :2 0 1dad ec
:3 0 21 :3 0 e9
:3 0 1d68 1d69 0
ea :3 0 1d6a 1d6b
0 1da5 ae :3 0
af :3 0 1d6d 1d6e
0 ae :3 0 be
:3 0 1d70 1d71 0
ed :2 0 2 :4 0
1f4 :2 0 c0 :2 0
47 :2 0 111e 1d76
1d78 :3 0 1121 1d72
1d7a 1d6f 1d7c 1d7b
:2 0 b1 :3 0 c1
:3 0 1d7e 1d7f 0
b3 :4 0 1f5 :4 0
b6 :2 0 b7 :3 0
1125 1d83 1d85 :3 0
b6 :2 0 ca :4 0
1128 1d87 1d89 :3 0
b6 :2 0 f0 :4 0
112b 1d8b 1d8d :3 0
b6 :2 0 ea :3 0
112e 1d8f 1d91 :3 0
b6 :2 0 f1 :4 0
1131 1d93 1d95 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 1134 1d98
1d9c 1138 1d97 1d9e
:3 0 113b 1d80 1da0
:2 0 1da2 113e 1da3
1d7d 1da2 0 1da4
1140 0 1da5 1142
1da8 :3 0 1da8 0
1da8 1da7 1da5 1da6
:6 0 1daa 30 :3 0
1145 1dac 1147 1dab
1daa :2 0 1dad 1149
:2 0 1daf 0 1daf
1dae 1d5c 1dad :6 0
1db1 1 :3 0 114c
1db6 39 :3 0 14
:3 0 1db2 1db3 0
1db5 1151 1db7 1ca4
1db1 0 1db8 0
1db5 0 1db8 1153
0 1db9 1156 1dba
1c95 1db9 0 1dbb
115a 0 25dd 10
:3 0 e4 :2 0 115c
1dbd 1dbe :3 0 1dbf
:2 0 8f :3 0 a2
:3 0 1f2 :3 0 10
:3 0 115e 1dc3 1dc5
4e :2 0 1160 1dc2
1dc8 109 :2 0 1f6
:2 0 1165 1dca 1dcc
:3 0 101 :3 0 a2
:3 0 1f2 :3 0 10
:3 0 1168 1dd0 1dd2
4e :2 0 116a 1dcf
1dd5 1f7 :2 0 116d
1dce 1dd8 1f8 :2 0
1f9 :2 0 1170 1dda
1ddc :3 0 1173 1dde
1ddd 101 :3 0 a2
:3 0 1f2 :3 0 10
:3 0 1175 1de2 1de4
4e :2 0 1177 1de1
1de7 1f7 :2 0 117a
1de0 1dea 0 1deb
0 117d :2 0 1dc1
1ded 0 1ef8 90
:3 0 4e :2 0 1def
1df0 0 1ef8 1fa
:3 0 90 :3 0 8f
:3 0 f6 :2 0 1fb
:3 0 1182 1df5 1df7
:3 0 1df8 1e34 a2
:3 0 1fc :3 0 f2
:3 0 2a :3 0 90
:3 0 c0 :2 0 47
:2 0 1185 1dff 1e01
:3 0 47 :2 0 1188
1dfc 1e04 118c 1dfb
1e06 4e :2 0 118e
1dfa 1e09 c4 :2 0
1fd :2 0 1193 1e0b
1e0d :3 0 a2 :3 0
1fc :3 0 f2 :3 0
2a :3 0 90 :3 0
c0 :2 0 47 :2 0
1196 1e14 1e16 :3 0
47 :2 0 1199 1e11
1e19 119d 1e10 1e1b
4e :2 0 119f 1e0f
1e1e c4 :2 0 1fe
:2 0 11a4 1e20 1e22
:3 0 1e0e 1e24 1e23
:2 0 1ff :8 0 1e28
11a7 1e29 1e25 1e28
0 1e2a 11a9 0
1e32 90 :3 0 90
:3 0 c0 :2 0 47
:2 0 11ab 1e2d 1e2f
:3 0 1e2b 1e30 0
1e32 11ae 1e34 1fb
:3 0 1df9 1e32 :4 0
1ef8 90 :3 0 8f
:3 0 d3 :2 0 11b3
1e37 1e38 :3 0 ae
:3 0 af :3 0 1e3a
1e3b 0 ae :3 0
be :3 0 1e3d 1e3e
0 c7 :2 0 2
:4 0 200 :2 0 c0
:2 0 47 :2 0 11b6
1e43 1e45 :3 0 11b9
1e3f 1e47 1e3c 1e49
1e48 :2 0 b1 :3 0
c1 :3 0 1e4b 1e4c
0 b3 :4 0 201
:4 0 b6 :2 0 b7
:3 0 11bd 1e50 1e52
:3 0 b6 :2 0 ca
:4 0 11c0 1e54 1e56
:3 0 b6 :2 0 cb
:4 0 11c3 1e58 1e5a
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 1e5f
1e60 0 11c6 1e5e
1e62 bc :4 0 11c8
1e5d 1e65 11cb 1e5c
1e67 :3 0 11ce 1e4d
1e69 :2 0 1e6b 11d1
1e6c 1e4a 1e6b 0
1e6d 11d3 0 1e96
ae :3 0 af :3 0
1e6e 1e6f 0 ae
:3 0 be :3 0 1e71
1e72 0 47 :2 0
2 :4 0 202 :2 0
c0 :2 0 47 :2 0
11d5 1e77 1e79 :3 0
11d8 1e73 1e7b 1e70
1e7d 1e7c :2 0 b1
:3 0 c1 :3 0 1e7f
1e80 0 b3 :4 0
203 :4 0 b6 :2 0
b7 :3 0 11dc 1e84
1e86 :3 0 11df 1e81
1e88 :2 0 1e8a 11e2
1e8b 1e7e 1e8a 0
1e8c 11e4 0 1e96
cf :3 0 d0 :3 0
1e8d 1e8e 0 c3
:3 0 d7 :3 0 1e90
1e91 0 d1 :3 0
11e6 1e8f 1e94 :2 0
1e96 11e9 1e97 1e39
1e96 0 1e98 11ed
0 1ef8 204 :3 0
2a :3 0 2a :3 0
e7 :4 0 205 1
:8 0 1ea3 21 :3 0
e9 :3 0 1e9e 1e9f
0 ea :3 0 1ea0
1ea1 0 1ea3 11ef
1ef6 eb :3 0 21
:3 0 e9 :3 0 1ea5
1ea6 0 ea :3 0
1ea7 1ea8 0 1eaa
11f2 1eac 11f4 1eab
1eaa :2 0 1ef4 ec
:3 0 21 :3 0 e9
:3 0 1eaf 1eb0 0
ea :3 0 1eb1 1eb2
0 1eec ae :3 0
af :3 0 1eb4 1eb5
0 ae :3 0 be
:3 0 1eb7 1eb8 0
ed :2 0 2 :4 0
206 :2 0 c0 :2 0
47 :2 0 11f6 1ebd
1ebf :3 0 11f9 1eb9
1ec1 1eb6 1ec3 1ec2
:2 0 b1 :3 0 c1
:3 0 1ec5 1ec6 0
b3 :4 0 207 :4 0
b6 :2 0 b7 :3 0
11fd 1eca 1ecc :3 0
b6 :2 0 ca :4 0
1200 1ece 1ed0 :3 0
b6 :2 0 f0 :4 0
1203 1ed2 1ed4 :3 0
b6 :2 0 ea :3 0
1206 1ed6 1ed8 :3 0
b6 :2 0 f1 :4 0
1209 1eda 1edc :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 120c 1edf
1ee3 1210 1ede 1ee5
:3 0 1213 1ec7 1ee7
:2 0 1ee9 1216 1eea
1ec4 1ee9 0 1eeb
1218 0 1eec 121a
1eef :3 0 1eef 0
1eef 1eee 1eec 1eed
:6 0 1ef1 33 :3 0
121d 1ef3 121f 1ef2
1ef1 :2 0 1ef4 1221
:2 0 1ef6 0 1ef6
1ef5 1ea3 1ef4 :6 0
1ef8 1 :3 0 1224
1ef9 1dc0 1ef8 0
1efa 122a 0 25dd
a2 :3 0 5c :3 0
4e :2 0 122c 1efb
1efe c3 :3 0 d3
:2 0 d4 :3 0 1f00
1f02 0 1231 1f01
1f04 :3 0 75 :3 0
208 :4 0 1f06 1f07
0 1f1b 77 :3 0
209 :4 0 1f09 1f0a
0 1f1b 77 :3 0
77 :3 0 b6 :2 0
39 :3 0 1234 1f0e
1f10 :3 0 1f0c 1f11
0 1f1b 77 :3 0
77 :3 0 b6 :2 0
b9 :4 0 1237 1f15
1f17 :3 0 1f13 1f18
0 1f1b d9 :3 0
123a 2006 a2 :3 0
5c :3 0 4e :2 0
123f 1f1c 1f1f c3
:3 0 d3 :2 0 d2
:3 0 1f21 1f23 0
1244 1f22 1f25 :3 0
75 :3 0 20a :4 0
1f27 1f28 0 1f3b
75 :3 0 75 :3 0
b6 :2 0 25 :3 0
1247 1f2c 1f2e :3 0
1f2a 1f2f 0 1f3b
75 :3 0 75 :3 0
b6 :2 0 20b :4 0
124a 1f33 1f35 :3 0
1f31 1f36 0 1f3b
77 :3 0 20c :4 0
1f38 1f39 0 1f3b
124d 1f3c 1f26 1f3b
0 2008 a2 :3 0
a :3 0 4e :2 0
1252 1f3d 1f40 c3
:3 0 d3 :2 0 c5
:3 0 1f42 1f44 0
1257 1f43 1f46 :3 0
75 :3 0 20d :4 0
1f48 1f49 0 1f8f
77 :3 0 20c :4 0
1f4b 1f4c 0 1f8f
1e :3 0 e4 :2 0
125a 1f4f 1f50 :3 0
1f51 :2 0 77 :3 0
77 :3 0 b6 :2 0
20e :4 0 125c 1f55
1f57 :3 0 1f53 1f58
0 1f68 77 :3 0
77 :3 0 b6 :2 0
3a :3 0 125f 1f5c
1f5e :3 0 1f5a 1f5f
0 1f68 77 :3 0
77 :3 0 b6 :2 0
1db :4 0 1262 1f63
1f65 :3 0 1f61 1f66
0 1f68 1265 1f69
1f52 1f68 0 1f6a
1269 0 1f8f 77
:3 0 77 :3 0 b6
:2 0 20f :4 0 126b
1f6d 1f6f :3 0 1f6b
1f70 0 1f8f 10
:3 0 e4 :2 0 126e
1f73 1f74 :3 0 1f75
:2 0 77 :3 0 77
:3 0 b6 :2 0 210
:4 0 1270 1f79 1f7b
:3 0 1f77 1f7c 0
1f8c 77 :3 0 77
:3 0 b6 :2 0 2a
:3 0 1273 1f80 1f82
:3 0 1f7e 1f83 0
1f8c 77 :3 0 77
:3 0 b6 :2 0 211
:4 0 1276 1f87 1f89
:3 0 1f85 1f8a 0
1f8c 1279 1f8d 1f76
1f8c 0 1f8e 127d
0 1f8f 127f 2002
14 :3 0 e4 :2 0
1285 1f91 1f92 :3 0
1f93 :2 0 75 :3 0
75 :3 0 b6 :2 0
212 :4 0 1287 1f97
1f99 :3 0 1f95 1f9a
0 1f9f 77 :3 0
20c :4 0 1f9c 1f9d
0 1f9f 128a 1fe7
75 :3 0 75 :3 0
b6 :2 0 213 :4 0
128d 1fa2 1fa4 :3 0
b6 :2 0 214 :4 0
1290 1fa6 1fa8 :3 0
1fa0 1fa9 0 1fe6
77 :3 0 20c :4 0
1fab 1fac 0 1fe6
1e :3 0 e4 :2 0
1293 1faf 1fb0 :3 0
1fb1 :2 0 77 :3 0
77 :3 0 b6 :2 0
20e :4 0 1295 1fb5
1fb7 :3 0 1fb3 1fb8
0 1fc8 77 :3 0
77 :3 0 b6 :2 0
3a :3 0 1298 1fbc
1fbe :3 0 1fba 1fbf
0 1fc8 77 :3 0
77 :3 0 b6 :2 0
1db :4 0 129b 1fc3
1fc5 :3 0 1fc1 1fc6
0 1fc8 129e 1fc9
1fb2 1fc8 0 1fca
12a2 0 1fe6 77
:3 0 77 :3 0 b6
:2 0 215 :4 0 12a4
1fcd 1fcf :3 0 b6
:2 0 216 :4 0 12a7
1fd1 1fd3 :3 0 b6
:2 0 217 :4 0 12aa
1fd5 1fd7 :3 0 b6
:2 0 218 :4 0 12ad
1fd9 1fdb :3 0 b6
:2 0 219 :4 0 12b0
1fdd 1fdf :3 0 b6
:2 0 21a :4 0 12b3
1fe1 1fe3 :3 0 1fcb
1fe4 0 1fe6 12b6
1fe8 1f94 1f9f 0
1fe9 0 1fe6 0
1fe9 12bb 0 2001
10 :3 0 e4 :2 0
12be 1feb 1fec :3 0
1fed :2 0 77 :3 0
77 :3 0 b6 :2 0
21b :4 0 12c0 1ff1
1ff3 :3 0 b6 :2 0
2a :3 0 12c3 1ff5
1ff7 :3 0 b6 :2 0
211 :4 0 12c6 1ff9
1ffb :3 0 1fef 1ffc
0 1ffe 12c9 1fff
1fee 1ffe 0 2000
12cb 0 2001 12cd
2003 1f47 1f8f 0
2004 0 2001 0
2004 12d0 0 2005
12d3 2007 1f05 1f1b
0 2008 0 2005
0 2008 12d5 0
25dd a2 :3 0 5c
:3 0 4e :2 0 12d9
2009 200c c3 :3 0
c4 :2 0 d4 :3 0
200e 2010 0 12de
200f 2012 :3 0 14
:3 0 e4 :2 0 12e1
2015 2016 :3 0 2017
:2 0 1e7 :3 0 3b
:3 0 183 :3 0 111
:3 0 14 :4 0 21c
1 :8 0 2024 21
:3 0 e9 :3 0 201f
2020 0 ea :3 0
2021 2022 0 2024
12e3 2077 eb :3 0
21 :3 0 e9 :3 0
2026 2027 0 ea
:3 0 2028 2029 0
202b 12e6 202d 12e8
202c 202b :2 0 2075
ec :3 0 21 :3 0
e9 :3 0 2030 2031
0 ea :3 0 2032
2033 0 206d ae
:3 0 af :3 0 2035
2036 0 ae :3 0
be :3 0 2038 2039
0 ed :2 0 2
:4 0 21d :2 0 c0
:2 0 47 :2 0 12ea
203e 2040 :3 0 12ed
203a 2042 2037 2044
2043 :2 0 b1 :3 0
c1 :3 0 2046 2047
0 b3 :4 0 21e
:4 0 b6 :2 0 b7
:3 0 12f1 204b 204d
:3 0 b6 :2 0 ca
:4 0 12f4 204f 2051
:3 0 b6 :2 0 f0
:4 0 12f7 2053 2055
:3 0 b6 :2 0 ea
:3 0 12fa 2057 2059
:3 0 b6 :2 0 f1
:4 0 12fd 205b 205d
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1300
2060 2064 1304 205f
2066 :3 0 1307 2048
2068 :2 0 206a 130a
206b 2045 206a 0
206c 130c 0 206d
130e 2070 :3 0 2070
0 2070 206f 206d
206e :6 0 2072 35
:3 0 1311 2074 1313
2073 2072 :2 0 2075
1315 :2 0 2077 0
2077 2076 2024 2075
:6 0 2119 1 :3 0
21 :3 0 e9 :3 0
2079 207a 0 21
:3 0 d3 :2 0 f5
:3 0 207c 207e 0
131a 207d 2080 :3 0
2081 :2 0 91 :3 0
a2 :3 0 1f2 :3 0
3b :3 0 131d 2085
2087 4e :2 0 131f
2084 208a 2083 208b
0 20a7 75 :3 0
75 :3 0 b6 :2 0
21f :4 0 1322 208f
2091 :3 0 208d 2092
0 20a7 77 :3 0
77 :3 0 b6 :2 0
220 :4 0 1325 2096
2098 :3 0 b6 :2 0
221 :4 0 1328 209a
209c :3 0 b6 :2 0
3b :3 0 132b 209e
20a0 :3 0 b6 :2 0
222 :4 0 132e 20a2
20a4 :3 0 2094 20a5
0 20a7 1331 2116
ae :3 0 af :3 0
20a8 20a9 0 ae
:3 0 be :3 0 20ab
20ac 0 24 :2 0
2 :4 0 223 :2 0
c0 :2 0 47 :2 0
1335 20b1 20b3 :3 0
1338 20ad 20b5 20aa
20b7 20b6 :2 0 b1
:3 0 c1 :3 0 20b9
20ba 0 b3 :4 0
224 :4 0 b6 :2 0
b7 :3 0 133c 20be
20c0 :3 0 b6 :2 0
ca :4 0 133f 20c2
20c4 :3 0 b6 :2 0
cb :4 0 1342 20c6
20c8 :3 0 b6 :2 0
a2 :3 0 bb :3 0
c3 :3 0 d7 :3 0
20cd 20ce 0 1345
20cc 20d0 bc :4 0
1347 20cb 20d3 134a
20ca 20d5 :3 0 b6
:2 0 11a :4 0 134d
20d7 20d9 :3 0 b6
:2 0 b9 :4 0 1350
20db 20dd :3 0 b6
:2 0 14 :3 0 1353
20df 20e1 :3 0 b6
:2 0 b9 :4 0 1356
20e3 20e5 :3 0 1359
20bb 20e7 :2 0 20e9
135c 20ea 20b8 20e9
0 20eb 135e 0
2115 ae :3 0 af
:3 0 20ec 20ed 0
ae :3 0 be :3 0
20ef 20f0 0 47
:2 0 2 :4 0 225
:2 0 c0 :2 0 47
:2 0 1360 20f5 20f7
:3 0 1363 20f1 20f9
20ee 20fb 20fa :2 0
b1 :3 0 c1 :3 0
20fd 20fe 0 b3
:4 0 226 :4 0 b6
:2 0 b7 :3 0 1367
2102 2104 :3 0 136a
20ff 2106 :2 0 2108
136d 2109 20fc 2108
0 210a 136f 0
2115 cf :3 0 11d
:3 0 210b 210c 0
c3 :3 0 d7 :3 0
210e 210f 0 14
:3 0 d1 :3 0 1371
210d 2113 :2 0 2115
1375 2117 2082 20a7
0 2118 0 2115
0 2118 1379 0
2119 137c 211a 2018
2119 0 211b 137f
0 2345 12 :3 0
e4 :2 0 1381 211d
211e :3 0 211f :2 0
1e7 :3 0 3b :3 0
227 :3 0 111 :3 0
12 :4 0 228 1
:8 0 212c 21 :3 0
e9 :3 0 2127 2128
0 ea :3 0 2129
212a 0 212c 1383
217f eb :3 0 21
:3 0 e9 :3 0 212e
212f 0 ea :3 0
2130 2131 0 2133
1386 2135 1388 2134
2133 :2 0 217d ec
:3 0 21 :3 0 e9
:3 0 2138 2139 0
ea :3 0 213a 213b
0 2175 ae :3 0
af :3 0 213d 213e
0 ae :3 0 be
:3 0 2140 2141 0
ed :2 0 2 :4 0
229 :2 0 c0 :2 0
47 :2 0 138a 2146
2148 :3 0 138d 2142
214a 213f 214c 214b
:2 0 b1 :3 0 c1
:3 0 214e 214f 0
b3 :4 0 22a :4 0
b6 :2 0 b7 :3 0
1391 2153 2155 :3 0
b6 :2 0 ca :4 0
1394 2157 2159 :3 0
b6 :2 0 f0 :4 0
1397 215b 215d :3 0
b6 :2 0 ea :3 0
139a 215f 2161 :3 0
b6 :2 0 f1 :4 0
139d 2163 2165 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 13a0 2168
216c 13a4 2167 216e
:3 0 13a7 2150 2170
:2 0 2172 13aa 2173
214d 2172 0 2174
13ac 0 2175 13ae
2178 :3 0 2178 0
2178 2177 2175 2176
:6 0 217a 37 :3 0
13b1 217c 13b3 217b
217a :2 0 217d 13b5
:2 0 217f 0 217f
217e 212c 217d :6 0
2217 1 :3 0 21
:3 0 e9 :3 0 2181
2182 0 21 :3 0
d3 :2 0 f5 :3 0
2184 2186 0 13ba
2185 2188 :3 0 2189
:2 0 75 :3 0 75
:3 0 b6 :2 0 22b
:4 0 13bd 218d 218f
:3 0 218b 2190 0
21a5 77 :3 0 77
:3 0 b6 :2 0 22c
:4 0 13c0 2194 2196
:3 0 b6 :2 0 22d
:4 0 13c3 2198 219a
:3 0 b6 :2 0 3b
:3 0 13c6 219c 219e
:3 0 b6 :2 0 222
:4 0 13c9 21a0 21a2
:3 0 2192 21a3 0
21a5 13cc 2214 ae
:3 0 af :3 0 21a6
21a7 0 ae :3 0
be :3 0 21a9 21aa
0 24 :2 0 2
:4 0 22e :2 0 c0
:2 0 47 :2 0 13cf
21af 21b1 :3 0 13d2
21ab 21b3 21a8 21b5
21b4 :2 0 b1 :3 0
c1 :3 0 21b7 21b8
0 b3 :4 0 22f
:4 0 b6 :2 0 b7
:3 0 13d6 21bc 21be
:3 0 b6 :2 0 ca
:4 0 13d9 21c0 21c2
:3 0 b6 :2 0 cb
:4 0 13dc 21c4 21c6
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 21cb
21cc 0 13df 21ca
21ce bc :4 0 13e1
21c9 21d1 13e4 21c8
21d3 :3 0 b6 :2 0
11a :4 0 13e7 21d5
21d7 :3 0 b6 :2 0
b9 :4 0 13ea 21d9
21db :3 0 b6 :2 0
12 :3 0 13ed 21dd
21df :3 0 b6 :2 0
b9 :4 0 13f0 21e1
21e3 :3 0 13f3 21b9
21e5 :2 0 21e7 13f6
21e8 21b6 21e7 0
21e9 13f8 0 2213
ae :3 0 af :3 0
21ea 21eb 0 ae
:3 0 be :3 0 21ed
21ee 0 47 :2 0
2 :4 0 230 :2 0
c0 :2 0 47 :2 0
13fa 21f3 21f5 :3 0
13fd 21ef 21f7 21ec
21f9 21f8 :2 0 b1
:3 0 c1 :3 0 21fb
21fc 0 b3 :4 0
231 :4 0 b6 :2 0
b7 :3 0 1401 2200
2202 :3 0 1404 21fd
2204 :2 0 2206 1407
2207 21fa 2206 0
2208 1409 0 2213
cf :3 0 11d :3 0
2209 220a 0 c3
:3 0 d7 :3 0 220c
220d 0 12 :3 0
d1 :3 0 140b 220b
2211 :2 0 2213 140f
2215 218a 21a5 0
2216 0 2213 0
2216 1413 0 2217
1416 2218 2120 2217
0 2219 1419 0
2345 13 :3 0 e4
:2 0 141b 221b 221c
:3 0 221d :2 0 1e7
:3 0 3b :3 0 232
:3 0 111 :3 0 13
:4 0 233 1 :8 0
222a 21 :3 0 e9
:3 0 2225 2226 0
ea :3 0 2227 2228
0 222a 141d 227d
eb :3 0 21 :3 0
e9 :3 0 222c 222d
0 ea :3 0 222e
222f 0 2231 1420
2233 1422 2232 2231
:2 0 227b ec :3 0
21 :3 0 e9 :3 0
2236 2237 0 ea
:3 0 2238 2239 0
2273 ae :3 0 af
:3 0 223b 223c 0
ae :3 0 be :3 0
223e 223f 0 ed
:2 0 2 :4 0 234
:2 0 c0 :2 0 47
:2 0 1424 2244 2246
:3 0 1427 2240 2248
223d 224a 2249 :2 0
b1 :3 0 c1 :3 0
224c 224d 0 b3
:4 0 235 :4 0 b6
:2 0 b7 :3 0 142b
2251 2253 :3 0 b6
:2 0 ca :4 0 142e
2255 2257 :3 0 b6
:2 0 f0 :4 0 1431
2259 225b :3 0 b6
:2 0 ea :3 0 1434
225d 225f :3 0 b6
:2 0 f1 :4 0 1437
2261 2263 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 143a 2266 226a
143e 2265 226c :3 0
1441 224e 226e :2 0
2270 1444 2271 224b
2270 0 2272 1446
0 2273 1448 2276
:3 0 2276 0 2276
2275 2273 2274 :6 0
2278 39 :3 0 144b
227a 144d 2279 2278
:2 0 227b 144f :2 0
227d 0 227d 227c
222a 227b :6 0 2315
1 :3 0 21 :3 0
e9 :3 0 227f 2280
0 21 :3 0 d3
:2 0 f5 :3 0 2282
2284 0 1454 2283
2286 :3 0 2287 :2 0
75 :3 0 75 :3 0
b6 :2 0 236 :4 0
1457 228b 228d :3 0
2289 228e 0 22a3
77 :3 0 77 :3 0
b6 :2 0 237 :4 0
145a 2292 2294 :3 0
b6 :2 0 238 :4 0
145d 2296 2298 :3 0
b6 :2 0 3b :3 0
1460 229a 229c :3 0
b6 :2 0 222 :4 0
1463 229e 22a0 :3 0
2290 22a1 0 22a3
1466 2312 ae :3 0
af :3 0 22a4 22a5
0 ae :3 0 be
:3 0 22a7 22a8 0
24 :2 0 2 :4 0
239 :2 0 c0 :2 0
47 :2 0 1469 22ad
22af :3 0 146c 22a9
22b1 22a6 22b3 22b2
:2 0 b1 :3 0 c1
:3 0 22b5 22b6 0
b3 :4 0 23a :4 0
b6 :2 0 b7 :3 0
1470 22ba 22bc :3 0
b6 :2 0 ca :4 0
1473 22be 22c0 :3 0
b6 :2 0 cb :4 0
1476 22c2 22c4 :3 0
b6 :2 0 a2 :3 0
bb :3 0 c3 :3 0
d7 :3 0 22c9 22ca
0 1479 22c8 22cc
bc :4 0 147b 22c7
22cf 147e 22c6 22d1
:3 0 b6 :2 0 11a
:4 0 1481 22d3 22d5
:3 0 b6 :2 0 b9
:4 0 1484 22d7 22d9
:3 0 b6 :2 0 13
:3 0 1487 22db 22dd
:3 0 b6 :2 0 b9
:4 0 148a 22df 22e1
:3 0 148d 22b7 22e3
:2 0 22e5 1490 22e6
22b4 22e5 0 22e7
1492 0 2311 ae
:3 0 af :3 0 22e8
22e9 0 ae :3 0
be :3 0 22eb 22ec
0 47 :2 0 2
:4 0 23b :2 0 c0
:2 0 47 :2 0 1494
22f1 22f3 :3 0 1497
22ed 22f5 22ea 22f7
22f6 :2 0 b1 :3 0
c1 :3 0 22f9 22fa
0 b3 :4 0 23c
:4 0 b6 :2 0 b7
:3 0 149b 22fe 2300
:3 0 149e 22fb 2302
:2 0 2304 14a1 2305
22f8 2304 0 2306
14a3 0 2311 cf
:3 0 11d :3 0 2307
2308 0 c3 :3 0
d7 :3 0 230a 230b
0 13 :3 0 d1
:3 0 14a5 2309 230f
:2 0 2311 14a9 2313
2288 22a3 0 2314
0 2311 0 2314
14ad 0 2315 14b0
2316 221e 2315 0
2317 14b3 0 2345
a2 :3 0 54 :3 0
4e :2 0 14b5 2318
231b 109 :2 0 4e
:2 0 14ba 231d 231f
:3 0 a2 :3 0 54
:3 0 4e :2 0 14bd
2321 2324 c4 :2 0
e3 :2 0 14c2 2326
2328 :3 0 2320 232a
2329 :2 0 77 :3 0
77 :3 0 b6 :2 0
23d :4 0 14c5 232e
2330 :3 0 b6 :2 0
bb :3 0 a2 :3 0
15 :3 0 4e :2 0
14c8 2334 2337 14cb
2333 2339 14cd 2332
233b :3 0 b6 :2 0
ca :4 0 14d0 233d
233f :3 0 232c 2340
0 2342 14d3 2343
232b 2342 0 2344
14d5 0 2345 14d7
2346 2013 2345 0
2347 14dc 0 25dd
16 :3 0 e4 :2 0
14de 2349 234a :3 0
234b :2 0 92 :3 0
a2 :3 0 1f2 :3 0
2e :3 0 14e0 234f
2351 4e :2 0 14e2
234e 2354 234d 2355
0 249e 86 :3 0
4e :2 0 2357 2358
0 249e 1fa :3 0
86 :3 0 92 :3 0
f6 :2 0 1fb :3 0
14e7 235d 235f :3 0
2360 249d 49 :3 0
23e :3 0 23f :3 0
2363 2364 0 24
:2 0 24 :2 0 86
:3 0 c0 :2 0 47
:2 0 14ea 2369 236b
:3 0 2e :3 0 14ed
2365 236e 2362 236f
0 249b 1e7 :3 0
3b :3 0 1b0 :3 0
111 :3 0 49 :4 0
240 1 :8 0 237c
21 :3 0 e9 :3 0
2377 2378 0 ea
:3 0 2379 237a 0
237c 14f2 23cf eb
:3 0 21 :3 0 e9
:3 0 237e 237f 0
ea :3 0 2380 2381
0 2383 14f5 2385
14f7 2384 2383 :2 0
23cd ec :3 0 21
:3 0 e9 :3 0 2388
2389 0 ea :3 0
238a 238b 0 23c5
ae :3 0 af :3 0
238d 238e 0 ae
:3 0 be :3 0 2390
2391 0 ed :2 0
2 :4 0 241 :2 0
c0 :2 0 47 :2 0
14f9 2396 2398 :3 0
14fc 2392 239a 238f
239c 239b :2 0 b1
:3 0 c1 :3 0 239e
239f 0 b3 :4 0
242 :4 0 b6 :2 0
b7 :3 0 1500 23a3
23a5 :3 0 b6 :2 0
ca :4 0 1503 23a7
23a9 :3 0 b6 :2 0
f0 :4 0 1506 23ab
23ad :3 0 b6 :2 0
ea :3 0 1509 23af
23b1 :3 0 b6 :2 0
f1 :4 0 150c 23b3
23b5 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
150f 23b8 23bc 1513
23b7 23be :3 0 1516
23a0 23c0 :2 0 23c2
1519 23c3 239d 23c2
0 23c4 151b 0
23c5 151d 23c8 :3 0
23c8 0 23c8 23c7
23c5 23c6 :6 0 23ca
3c :3 0 1520 23cc
1522 23cb 23ca :2 0
23cd 1524 :2 0 23cf
0 23cf 23ce 237c
23cd :6 0 249b 3b
:3 0 21 :3 0 e9
:3 0 23d1 23d2 0
21 :3 0 c4 :2 0
f5 :3 0 23d4 23d6
0 1529 23d5 23d8
:3 0 23d9 :2 0 ae
:3 0 af :3 0 23db
23dc 0 ae :3 0
be :3 0 23de 23df
0 24 :2 0 2
:4 0 243 :2 0 c0
:2 0 47 :2 0 152c
23e4 23e6 :3 0 152f
23e0 23e8 23dd 23ea
23e9 :2 0 b1 :3 0
c1 :3 0 23ec 23ed
0 b3 :4 0 244
:4 0 b6 :2 0 b7
:3 0 1533 23f1 23f3
:3 0 b6 :2 0 ca
:4 0 1536 23f5 23f7
:3 0 b6 :2 0 cb
:4 0 1539 23f9 23fb
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 2400
2401 0 153c 23ff
2403 bc :4 0 153e
23fe 2406 1541 23fd
2408 :3 0 b6 :2 0
11a :4 0 1544 240a
240c :3 0 b6 :2 0
b9 :4 0 1547 240e
2410 :3 0 b6 :2 0
49 :3 0 154a 2412
2414 :3 0 b6 :2 0
b9 :4 0 154d 2416
2418 :3 0 1550 23ee
241a :2 0 241c 1553
241d 23eb 241c 0
241e 1555 0 2448
ae :3 0 af :3 0
241f 2420 0 ae
:3 0 be :3 0 2422
2423 0 47 :2 0
2 :4 0 245 :2 0
c0 :2 0 47 :2 0
1557 2428 242a :3 0
155a 2424 242c 2421
242e 242d :2 0 b1
:3 0 c1 :3 0 2430
2431 0 b3 :4 0
246 :4 0 b6 :2 0
b7 :3 0 155e 2435
2437 :3 0 1561 2432
2439 :2 0 243b 1564
243c 242f 243b 0
243d 1566 0 2448
cf :3 0 11d :3 0
243e 243f 0 c3
:3 0 d7 :3 0 2441
2442 0 49 :3 0
d1 :3 0 1568 2440
2446 :2 0 2448 156c
2449 23da 2448 0
244a 1570 0 249b
77 :3 0 77 :3 0
b6 :2 0 247 :4 0
1572 244d 244f :3 0
b6 :2 0 248 :4 0
1575 2451 2453 :3 0
b6 :2 0 249 :4 0
1578 2455 2457 :3 0
b6 :2 0 24a :4 0
157b 2459 245b :3 0
b6 :2 0 3b :3 0
157e 245d 245f :3 0
b6 :2 0 24b :4 0
1581 2461 2463 :3 0
244b 2464 0 249b
a2 :3 0 5c :3 0
4e :2 0 1584 2466
2469 c3 :3 0 d3
:2 0 d4 :3 0 246b
246d 0 1589 246c
246f :3 0 77 :3 0
77 :3 0 b6 :2 0
24c :4 0 158c 2473
2475 :3 0 2471 2476
0 2478 158f 2481
77 :3 0 77 :3 0
b6 :2 0 24d :4 0
1591 247b 247d :3 0
2479 247e 0 2480
1594 2482 2470 2478
0 2483 0 2480
0 2483 1596 0
249b a2 :3 0 5c
:3 0 4e :2 0 1599
2484 2487 c3 :3 0
d3 :2 0 d4 :3 0
2489 248b 0 159e
248a 248d :3 0 1ff
:8 0 2491 15a1 2492
248e 2491 0 2493
15a3 0 249b 86
:3 0 86 :3 0 c0
:2 0 24 :2 0 15a5
2496 2498 :3 0 2494
2499 0 249b 15a8
249d 1fb :3 0 2361
249b :4 0 249e 15b0
249f 234c 249e 0
24a0 15b4 0 25dd
a2 :3 0 5c :3 0
4e :2 0 15b6 24a1
24a4 c3 :3 0 c4
:2 0 d4 :3 0 24a6
24a8 0 15bb 24a7
24aa :3 0 93 :3 0
a2 :3 0 1f2 :3 0
30 :3 0 15be 24ae
24b0 4e :2 0 15c0
24ad 24b3 24ac 24b4
0 25d3 86 :3 0
4e :2 0 24b6 24b7
0 25d3 1fa :3 0
86 :3 0 93 :3 0
f6 :2 0 1fb :3 0
15c5 24bc 24be :3 0
24bf 25d2 49 :3 0
23e :3 0 23f :3 0
24c2 24c3 0 24
:2 0 24 :2 0 86
:3 0 c0 :2 0 47
:2 0 15c8 24c8 24ca
:3 0 30 :3 0 15cb
24c4 24cd 24c1 24ce
0 25d0 1e7 :3 0
3b :3 0 1b0 :3 0
111 :3 0 49 :4 0
240 1 :8 0 24db
21 :3 0 e9 :3 0
24d6 24d7 0 ea
:3 0 24d8 24d9 0
24db 15d0 252e eb
:3 0 21 :3 0 e9
:3 0 24dd 24de 0
ea :3 0 24df 24e0
0 24e2 15d3 24e4
15d5 24e3 24e2 :2 0
252c ec :3 0 21
:3 0 e9 :3 0 24e7
24e8 0 ea :3 0
24e9 24ea 0 2524
ae :3 0 af :3 0
24ec 24ed 0 ae
:3 0 be :3 0 24ef
24f0 0 ed :2 0
2 :4 0 24e :2 0
c0 :2 0 47 :2 0
15d7 24f5 24f7 :3 0
15da 24f1 24f9 24ee
24fb 24fa :2 0 b1
:3 0 c1 :3 0 24fd
24fe 0 b3 :4 0
24f :4 0 b6 :2 0
b7 :3 0 15de 2502
2504 :3 0 b6 :2 0
ca :4 0 15e1 2506
2508 :3 0 b6 :2 0
f0 :4 0 15e4 250a
250c :3 0 b6 :2 0
ea :3 0 15e7 250e
2510 :3 0 b6 :2 0
f1 :4 0 15ea 2512
2514 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
15ed 2517 251b 15f1
2516 251d :3 0 15f4
24ff 251f :2 0 2521
15f7 2522 24fc 2521
0 2523 15f9 0
2524 15fb 2527 :3 0
2527 0 2527 2526
2524 2525 :6 0 2529
3f :3 0 15fe 252b
1600 252a 2529 :2 0
252c 1602 :2 0 252e
0 252e 252d 24db
252c :6 0 25d0 3e
:3 0 21 :3 0 e9
:3 0 2530 2531 0
21 :3 0 c4 :2 0
f5 :3 0 2533 2535
0 1607 2534 2537
:3 0 2538 :2 0 ae
:3 0 af :3 0 253a
253b 0 ae :3 0
be :3 0 253d 253e
0 24 :2 0 2
:4 0 250 :2 0 c0
:2 0 47 :2 0 160a
2543 2545 :3 0 160d
253f 2547 253c 2549
2548 :2 0 b1 :3 0
c1 :3 0 254b 254c
0 b3 :4 0 251
:4 0 b6 :2 0 b7
:3 0 1611 2550 2552
:3 0 b6 :2 0 ca
:4 0 1614 2554 2556
:3 0 b6 :2 0 cb
:4 0 1617 2558 255a
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 d7 :3 0 255f
2560 0 161a 255e
2562 bc :4 0 161c
255d 2565 161f 255c
2567 :3 0 b6 :2 0
11a :4 0 1622 2569
256b :3 0 b6 :2 0
b9 :4 0 1625 256d
256f :3 0 b6 :2 0
49 :3 0 1628 2571
2573 :3 0 b6 :2 0
b9 :4 0 162b 2575
2577 :3 0 162e 254d
2579 :2 0 257b 1631
257c 254a 257b 0
257d 1633 0 25a7
ae :3 0 af :3 0
257e 257f 0 ae
:3 0 be :3 0 2581
2582 0 47 :2 0
2 :4 0 252 :2 0
c0 :2 0 47 :2 0
1635 2587 2589 :3 0
1638 2583 258b 2580
258d 258c :2 0 b1
:3 0 c1 :3 0 258f
2590 0 b3 :4 0
253 :4 0 b6 :2 0
b7 :3 0 163c 2594
2596 :3 0 163f 2591
2598 :2 0 259a 1642
259b 258e 259a 0
259c 1644 0 25a7
cf :3 0 11d :3 0
259d 259e 0 c3
:3 0 d7 :3 0 25a0
25a1 0 49 :3 0
d1 :3 0 1646 259f
25a5 :2 0 25a7 164a
25a8 2539 25a7 0
25a9 164e 0 25d0
77 :3 0 77 :3 0
b6 :2 0 247 :4 0
1650 25ac 25ae :3 0
b6 :2 0 248 :4 0
1653 25b0 25b2 :3 0
b6 :2 0 249 :4 0
1656 25b4 25b6 :3 0
b6 :2 0 24a :4 0
1659 25b8 25ba :3 0
b6 :2 0 3b :3 0
165c 25bc 25be :3 0
b6 :2 0 24b :4 0
165f 25c0 25c2 :3 0
b6 :2 0 254 :4 0
1662 25c4 25c6 :3 0
25aa 25c7 0 25d0
86 :3 0 86 :3 0
c0 :2 0 24 :2 0
1665 25cb 25cd :3 0
25c9 25ce 0 25d0
1668 25d2 1fb :3 0
24c0 25d0 :4 0 25d3
166e 25d4 24ab 25d3
0 25d5 1672 0
25dd 75 :3 0 75
:3 0 b6 :2 0 77
:3 0 1674 25d8 25da
:3 0 25d6 25db 0
25dd 1677 25df 1bfa
1c70 0 25e0 0
25dd 0 25e0 167f
0 3696 75 :3 0
75 :3 0 b6 :2 0
255 :4 0 1682 25e3
25e5 :3 0 25e1 25e6
0 3696 256 :3 0
94 :3 0 75 :3 0
25e9 25ea 0 25eb
:2 0 3696 1fb :3 0
94 :3 0 39 :4 0
25f1 :2 0 2aa5 25ee
25ef :3 0 94 :3 0
1c0 :3 0 25f2 25f3
:3 0 21 :3 0 e9
:3 0 25f5 25f6 0
4e :2 0 25f7 25f8
0 25fa 1685 2601
21 :3 0 e9 :3 0
25fb 25fc 0 18b
:2 0 25fd 25fe 0
2600 1687 2602 25f4
25fa 0 2603 0
2600 0 2603 1689
0 2aa5 21 :3 0
e9 :3 0 2604 2605
0 21 :3 0 c4
:2 0 f5 :3 0 2607
2609 0 168e 2608
260b :3 0 260c :2 0
1ff :8 0 2610 1691
2611 260d 2610 0
2612 1693 0 2aa5
a2 :3 0 50 :3 0
4e :2 0 1695 2613
2616 d3 :2 0 4e
:2 0 169a 2618 261a
:3 0 a2 :3 0 5c
:3 0 4e :2 0 169d
261c 261f c3 :3 0
c4 :2 0 c5 :3 0
2621 2623 0 16a2
2622 2625 :3 0 261b
2627 2626 :2 0 a2
:3 0 5c :3 0 4e
:2 0 16a5 2629 262c
c3 :3 0 c4 :2 0
d2 :3 0 262e 2630
0 16aa 262f 2632
:3 0 2628 2634 2633
:2 0 a2 :3 0 5c
:3 0 4e :2 0 16ad
2636 2639 c3 :3 0
c4 :2 0 d4 :3 0
263b 263d 0 16b2
263c 263f :3 0 14
:3 0 c6 :2 0 16b5
2642 2643 :3 0 2644
:2 0 2640 2646 2645
:2 0 2647 :2 0 2635
2649 2648 :2 0 256
:3 0 96 :4 0 264e
:2 0 2733 264c 264f
:3 0 96 :3 0 28
:4 0 2653 :2 0 2733
2650 2651 :3 0 96
:3 0 1c0 :3 0 2654
2655 :3 0 21 :3 0
e9 :3 0 2657 2658
0 4e :2 0 2659
265a 0 265c 16b7
2663 21 :3 0 e9
:3 0 265d 265e 0
18b :2 0 265f 2660
0 2662 16b9 2664
2656 265c 0 2665
0 2662 0 2665
16bb 0 2733 21
:3 0 e9 :3 0 2666
2667 0 21 :3 0
d3 :2 0 f5 :3 0
2669 266b 0 16c0
266a 266d :3 0 266e
:2 0 257 :3 0 96
:4 0 2673 :2 0 2679
2671 0 21 :3 0
e9 :3 0 2674 2675
0 ea :3 0 2676
2677 0 2679 16c3
26cc eb :3 0 21
:3 0 e9 :3 0 267b
267c 0 ea :3 0
267d 267e 0 2680
16c6 2682 16c8 2681
2680 :2 0 26ca ec
:3 0 21 :3 0 e9
:3 0 2685 2686 0
ea :3 0 2687 2688
0 26c2 ae :3 0
af :3 0 268a 268b
0 ae :3 0 be
:3 0 268d 268e 0
ed :2 0 2 :4 0
258 :2 0 c0 :2 0
47 :2 0 16ca 2693
2695 :3 0 16cd 268f
2697 268c 2699 2698
:2 0 b1 :3 0 c1
:3 0 269b 269c 0
b3 :4 0 259 :4 0
b6 :2 0 b7 :3 0
16d1 26a0 26a2 :3 0
b6 :2 0 ca :4 0
16d4 26a4 26a6 :3 0
b6 :2 0 f0 :4 0
16d7 26a8 26aa :3 0
b6 :2 0 ea :3 0
16da 26ac 26ae :3 0
b6 :2 0 f1 :4 0
16dd 26b0 26b2 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 16e0 26b5
26b9 16e4 26b4 26bb
:3 0 16e7 269d 26bd
:2 0 26bf 16ea 26c0
269a 26bf 0 26c1
16ec 0 26c2 16ee
26c5 :3 0 26c5 0
26c5 26c4 26c2 26c3
:6 0 26c7 42 :3 0
16f1 26c9 16f3 26c8
26c7 :2 0 26ca 16f5
:2 0 26cc 0 26cc
26cb 2679 26ca :6 0
26d0 41 :3 0 25a
:3 0 26ce :4 0 26d0
16f8 2730 257 :3 0
96 :4 0 26d4 :2 0
26da 26d2 0 21
:3 0 e9 :3 0 26d5
26d6 0 ea :3 0
26d7 26d8 0 26da
16fb 272d eb :3 0
21 :3 0 e9 :3 0
26dc 26dd 0 ea
:3 0 26de 26df 0
26e1 16fe 26e3 1700
26e2 26e1 :2 0 272b
ec :3 0 21 :3 0
e9 :3 0 26e6 26e7
0 ea :3 0 26e8
26e9 0 2723 ae
:3 0 af :3 0 26eb
26ec 0 ae :3 0
be :3 0 26ee 26ef
0 ed :2 0 2
:4 0 25b :2 0 c0
:2 0 47 :2 0 1702
26f4 26f6 :3 0 1705
26f0 26f8 26ed 26fa
26f9 :2 0 b1 :3 0
c1 :3 0 26fc 26fd
0 b3 :4 0 25c
:4 0 b6 :2 0 b7
:3 0 1709 2701 2703
:3 0 b6 :2 0 ca
:4 0 170c 2705 2707
:3 0 b6 :2 0 f0
:4 0 170f 2709 270b
:3 0 b6 :2 0 ea
:3 0 1712 270d 270f
:3 0 b6 :2 0 f1
:4 0 1715 2711 2713
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1718
2716 271a 171c 2715
271c :3 0 171f 26fe
271e :2 0 2720 1722
2721 26fb 2720 0
2722 1724 0 2723
1726 2726 :3 0 2726
0 2726 2725 2723
2724 :6 0 2728 44
:3 0 1729 272a 172b
2729 2728 :2 0 272b
172d :2 0 272d 0
272d 272c 26da 272b
:6 0 272f 41 :3 0
1730 2731 266f 26d0
0 2732 0 272f
0 2732 1732 0
2733 1735 2734 264a
2733 0 2735 173a
0 2aa5 2e :3 0
16 :3 0 2736 2737
0 2aa5 30 :3 0
17 :3 0 2739 273a
0 2aa5 a2 :3 0
50 :3 0 4e :2 0
173c 273c 273f 109
:2 0 4e :2 0 1741
2741 2743 :3 0 f2
:3 0 46 :3 0 47
:2 0 47 :2 0 1744
2745 2749 d3 :2 0
47 :4 0 174a 274b
274d :3 0 48 :3 0
199 :4 0 2750 2751
:3 0 274f 2752 0
2757 4f :3 0 4e
:2 0 2754 2755 0
2757 174d 28a3 133
:3 0 a2 :3 0 50
:3 0 4e :2 0 1750
2759 275c 1753 2758
275e c4 :2 0 4e
:2 0 1757 2760 2762
:3 0 25d :3 0 25e
:3 0 83 :3 0 98
:3 0 99 :3 0 25
:3 0 9b :3 0 39
:3 0 1a1 :4 0 25f
1 :8 0 2773 21
:3 0 e9 :3 0 276e
276f 0 ea :3 0
2770 2771 0 2773
175a 27c6 eb :3 0
21 :3 0 e9 :3 0
2775 2776 0 ea
:3 0 2777 2778 0
277a 175d 277c 175f
277b 277a :2 0 27c4
ec :3 0 21 :3 0
e9 :3 0 277f 2780
0 ea :3 0 2781
2782 0 27bc ae
:3 0 af :3 0 2784
2785 0 ae :3 0
be :3 0 2787 2788
0 ed :2 0 2
:4 0 260 :2 0 c0
:2 0 47 :2 0 1761
278d 278f :3 0 1764
2789 2791 2786 2793
2792 :2 0 b1 :3 0
c1 :3 0 2795 2796
0 b3 :4 0 261
:4 0 b6 :2 0 b7
:3 0 1768 279a 279c
:3 0 b6 :2 0 ca
:4 0 176b 279e 27a0
:3 0 b6 :2 0 f0
:4 0 176e 27a2 27a4
:3 0 b6 :2 0 ea
:3 0 1771 27a6 27a8
:3 0 b6 :2 0 f1
:4 0 1774 27aa 27ac
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1777
27af 27b3 177b 27ae
27b5 :3 0 177e 2797
27b7 :2 0 27b9 1781
27ba 2794 27b9 0
27bb 1783 0 27bc
1785 27bf :3 0 27bf
0 27bf 27be 27bc
27bd :6 0 27c1 46
:3 0 1788 27c3 178a
27c2 27c1 :2 0 27c4
178c :2 0 27c6 0
27c6 27c5 2773 27c4
:6 0 289f 41 :3 0
a2 :3 0 83 :3 0
4e :2 0 178f 27c8
27cb 109 :2 0 4e
:2 0 1794 27cd 27cf
:3 0 257 :3 0 94
:4 0 27d4 :2 0 27da
27d2 0 21 :3 0
e9 :3 0 27d5 27d6
0 ea :3 0 27d7
27d8 0 27da 1797
282d eb :3 0 21
:3 0 e9 :3 0 27dc
27dd 0 ea :3 0
27de 27df 0 27e1
179a 27e3 179c 27e2
27e1 :2 0 282b ec
:3 0 21 :3 0 e9
:3 0 27e6 27e7 0
ea :3 0 27e8 27e9
0 2823 ae :3 0
af :3 0 27eb 27ec
0 ae :3 0 be
:3 0 27ee 27ef 0
ed :2 0 2 :4 0
262 :2 0 c0 :2 0
47 :2 0 179e 27f4
27f6 :3 0 17a1 27f0
27f8 27ed 27fa 27f9
:2 0 b1 :3 0 c1
:3 0 27fc 27fd 0
b3 :4 0 263 :4 0
b6 :2 0 b7 :3 0
17a5 2801 2803 :3 0
b6 :2 0 ca :4 0
17a8 2805 2807 :3 0
b6 :2 0 f0 :4 0
17ab 2809 280b :3 0
b6 :2 0 ea :3 0
17ae 280d 280f :3 0
b6 :2 0 f1 :4 0
17b1 2811 2813 :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 17b4 2816
281a 17b8 2815 281c
:3 0 17bb 27fe 281e
:2 0 2820 17be 2821
27fb 2820 0 2822
17c0 0 2823 17c2
2826 :3 0 2826 0
2826 2825 2823 2824
:6 0 2828 48 :3 0
17c5 282a 17c7 2829
2828 :2 0 282b 17c9
:2 0 282d 0 282d
282c 27da 282b :6 0
289c 41 :3 0 ae
:3 0 af :3 0 282f
2830 0 ae :3 0
be :3 0 2832 2833
0 24 :2 0 2
:4 0 264 :2 0 c0
:2 0 47 :2 0 17cc
2838 283a :3 0 17cf
2834 283c 2831 283e
283d :2 0 b1 :3 0
c1 :3 0 2840 2841
0 b3 :4 0 265
:4 0 b6 :2 0 b7
:3 0 17d3 2845 2847
:3 0 b6 :2 0 ca
:4 0 17d6 2849 284b
:3 0 b6 :2 0 cb
:4 0 17d9 284d 284f
:3 0 b6 :2 0 a2
:3 0 bb :3 0 c3
:3 0 266 :3 0 2854
2855 0 17dc 2853
2857 bc :4 0 17de
2852 285a 17e1 2851
285c :3 0 b6 :2 0
11a :4 0 17e4 285e
2860 :3 0 b6 :2 0
b9 :4 0 17e7 2862
2864 :3 0 b6 :2 0
39 :3 0 17ea 2866
2868 :3 0 b6 :2 0
b9 :4 0 17ed 286a
286c :3 0 17f0 2842
286e :2 0 2870 17f3
2871 283f 2870 0
2872 17f5 0 289c
ae :3 0 af :3 0
2873 2874 0 ae
:3 0 be :3 0 2876
2877 0 47 :2 0
2 :4 0 267 :2 0
c0 :2 0 47 :2 0
17f7 287c 287e :3 0
17fa 2878 2880 2875
2882 2881 :2 0 b1
:3 0 c1 :3 0 2884
2885 0 b3 :4 0
268 :4 0 b6 :2 0
b7 :3 0 17fe 2889
288b :3 0 1801 2886
288d :2 0 288f 1804
2890 2883 288f 0
2891 1806 0 289c
cf :3 0 11d :3 0
2892 2893 0 c3
:3 0 266 :3 0 2895
2896 0 39 :3 0
d1 :3 0 1808 2894
289a :2 0 289c 180c
289d 27d0 289c 0
289e 1811 0 289f
1813 28a0 2763 289f
0 28a1 1816 0
28a2 1818 28a4 274e
2757 0 28a5 0
28a2 0 28a5 181a
0 2a3b 89 :3 0
269 :3 0 48 :3 0
25 :3 0 26 :3 0
39 :3 0 66 :3 0
50 :3 0 2e :3 0
30 :3 0 31 :3 0
32 :3 0 41 :3 0
42 :3 0 61 :3 0
59 :3 0 57 :3 0
5a :3 0 5b :3 0
55 :3 0 5c :3 0
46 :3 0 53 :3 0
4d :3 0 5d :3 0
58 :3 0 52 :3 0
5f :3 0 64 :3 0
29 :3 0 a2 :3 0
5f :3 0 4e :2 0
181d 28c4 28c7 4e
:2 0 68 :2 0 68
:2 0 4e :2 0 1820
28a7 28cd 28a6 28ce
0 2a3b 89 :3 0
c4 :2 0 4e :2 0
1844 28d1 28d3 :3 0
257 :3 0 94 :4 0
28d8 :2 0 28de 28d6
0 21 :3 0 e9
:3 0 28d9 28da 0
ea :3 0 28db 28dc
0 28de 1847 2931
eb :3 0 21 :3 0
e9 :3 0 28e0 28e1
0 ea :3 0 28e2
28e3 0 28e5 184a
28e7 184c 28e6 28e5
:2 0 292f ec :3 0
21 :3 0 e9 :3 0
28ea 28eb 0 ea
:3 0 28ec 28ed 0
2927 ae :3 0 af
:3 0 28ef 28f0 0
ae :3 0 be :3 0
28f2 28f3 0 ed
:2 0 2 :4 0 26a
:2 0 c0 :2 0 47
:2 0 184e 28f8 28fa
:3 0 1851 28f4 28fc
28f1 28fe 28fd :2 0
b1 :3 0 c1 :3 0
2900 2901 0 b3
:4 0 26b :4 0 b6
:2 0 b7 :3 0 1855
2905 2907 :3 0 b6
:2 0 ca :4 0 1858
2909 290b :3 0 b6
:2 0 f0 :4 0 185b
290d 290f :3 0 b6
:2 0 ea :3 0 185e
2911 2913 :3 0 b6
:2 0 f1 :4 0 1861
2915 2917 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1864 291a 291e
1868 2919 2920 :3 0
186b 2902 2922 :2 0
2924 186e 2925 28ff
2924 0 2926 1870
0 2927 1872 292a
:3 0 292a 0 292a
2929 2927 2928 :6 0
292c 4a :3 0 1875
292e 1877 292d 292c
:2 0 292f 1879 :2 0
2931 0 2931 2930
28de 292f :6 0 29ac
41 :3 0 89 :3 0
c3 :3 0 f6 :2 0
26c :3 0 2934 2936
0 187e 2935 2938
:3 0 89 :3 0 c3
:3 0 26d :3 0 293b
293c 0 293a 293d
0 293f 1881 2940
2939 293f 0 2941
1883 0 29ac ae
:3 0 af :3 0 2942
2943 0 ae :3 0
be :3 0 2945 2946
0 24 :2 0 2
:4 0 26e :2 0 c0
:2 0 47 :2 0 1885
294b 294d :3 0 1888
2947 294f 2944 2951
2950 :2 0 b1 :3 0
c1 :3 0 2953 2954
0 b3 :4 0 26f
:4 0 b6 :2 0 b7
:3 0 188c 2958 295a
:3 0 b6 :2 0 ca
:4 0 188f 295c 295e
:3 0 b6 :2 0 cb
:4 0 1892 2960 2962
:3 0 b6 :2 0 a2
:3 0 bb :3 0 89
:3 0 1895 2966 2968
bc :4 0 1897 2965
296b 189a 2964 296d
:3 0 b6 :2 0 11a
:4 0 189d 296f 2971
:3 0 b6 :2 0 b9
:4 0 18a0 2973 2975
:3 0 b6 :2 0 48
:3 0 18a3 2977 2979
:3 0 b6 :2 0 b9
:4 0 18a6 297b 297d
:3 0 18a9 2955 297f
:2 0 2981 18ac 2982
2952 2981 0 2983
18ae 0 29ac ae
:3 0 af :3 0 2984
2985 0 ae :3 0
be :3 0 2987 2988
0 47 :2 0 2
:4 0 270 :2 0 c0
:2 0 47 :2 0 18b0
298d 298f :3 0 18b3
2989 2991 2986 2993
2992 :2 0 b1 :3 0
c1 :3 0 2995 2996
0 b3 :4 0 271
:4 0 b6 :2 0 b7
:3 0 18b7 299a 299c
:3 0 18ba 2997 299e
:2 0 29a0 18bd 29a1
2994 29a0 0 29a2
18bf 0 29ac cf
:3 0 11d :3 0 29a3
29a4 0 89 :3 0
48 :3 0 d1 :3 0
18c1 29a5 29a9 :2 0
29ac d9 :3 0 18c5
2a37 f2 :3 0 46
:3 0 47 :2 0 47
:2 0 18cb 29ad 29b1
d3 :2 0 47 :4 0
18d1 29b3 29b5 :3 0
29b6 :2 0 f2 :3 0
4c :3 0 47 :2 0
47 :2 0 18d4 29b8
29bc d3 :2 0 1ba
:4 0 18da 29be 29c0
:3 0 29c1 :2 0 29b7
29c3 29c2 :2 0 19a
:3 0 10f :3 0 19b
:3 0 39 :3 0 10f
:4 0 272 1 :8 0
29e0 1c0 :4 0 29cb
:3 0 d1 :3 0 d3
:2 0 18df 29ce 29cf
:3 0 21 :3 0 e9
:3 0 29d1 29d2 0
4e :2 0 29d3 29d4
0 29d6 18e2 29dd
21 :3 0 e9 :3 0
29d7 29d8 0 18b
:2 0 29d9 29da 0
29dc 18e4 29de 29d0
29d6 0 29df 0
29dc 0 29df 18e6
0 29e0 18e9 2a33
eb :3 0 21 :3 0
e9 :3 0 29e2 29e3
0 ea :3 0 29e4
29e5 0 29e7 18ec
29e9 18ee 29e8 29e7
:2 0 2a31 ec :3 0
21 :3 0 e9 :3 0
29ec 29ed 0 ea
:3 0 29ee 29ef 0
2a29 ae :3 0 af
:3 0 29f1 29f2 0
ae :3 0 be :3 0
29f4 29f5 0 ed
:2 0 2 :4 0 273
:2 0 c0 :2 0 47
:2 0 18f0 29fa 29fc
:3 0 18f3 29f6 29fe
29f3 2a00 29ff :2 0
b1 :3 0 c1 :3 0
2a02 2a03 0 b3
:4 0 274 :4 0 b6
:2 0 b7 :3 0 18f7
2a07 2a09 :3 0 b6
:2 0 ca :4 0 18fa
2a0b 2a0d :3 0 b6
:2 0 f0 :4 0 18fd
2a0f 2a11 :3 0 b6
:2 0 ea :3 0 1900
2a13 2a15 :3 0 b6
:2 0 f1 :4 0 1903
2a17 2a19 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1906 2a1c 2a20
190a 2a1b 2a22 :3 0
190d 2a04 2a24 :2 0
2a26 1910 2a27 2a01
2a26 0 2a28 1912
0 2a29 1914 2a2c
:3 0 2a2c 0 2a2c
2a2b 2a29 2a2a :6 0
2a2e 4c :3 0 1917
2a30 1919 2a2f 2a2e
:2 0 2a31 191b :2 0
2a33 0 2a33 2a32
29e0 2a31 :6 0 2a35
41 :3 0 191e 2a36
29c4 2a35 0 2a38
28d4 29ac 0 2a38
1920 0 2a3b 1ff
:8 0 2a3b 1923 2a9e
a2 :3 0 4d :3 0
4e :2 0 1928 2a3c
2a3f c3 :3 0 c4
:2 0 c5 :3 0 2a41
2a43 0 192d 2a42
2a45 :3 0 41 :3 0
5 :3 0 2a47 2a48
0 2a4d 42 :3 0
6 :3 0 2a4a 2a4b
0 2a4d 1930 2a4e
2a46 2a4d 0 2a4f
1933 0 2a9d 89
:3 0 269 :3 0 48
:3 0 25 :3 0 26
:3 0 39 :3 0 66
:3 0 50 :3 0 2e
:3 0 30 :3 0 31
:3 0 32 :3 0 41
:3 0 42 :3 0 61
:3 0 59 :3 0 57
:3 0 5a :3 0 5b
:3 0 55 :3 0 5c
:3 0 46 :3 0 53
:3 0 4d :3 0 5d
:3 0 58 :3 0 52
:3 0 5f :3 0 64
:3 0 29 :3 0 4e
:2 0 4e :2 0 68
:2 0 68 :2 0 4e
:2 0 1935 2a51 2a73
2a50 2a74 0 2a9d
89 :3 0 d3 :2 0
4e :2 0 1959 2a77
2a79 :3 0 88 :3 0
88 :3 0 c0 :2 0
47 :2 0 195c 2a7d
2a7f :3 0 2a7b 2a80
0 2a83 d9 :3 0
195f 2a8d 89 :3 0
f6 :2 0 4e :2 0
1963 2a85 2a87 :3 0
1ff :8 0 2a8b 1966
2a8c 2a88 2a8b 0
2a8e 2a7a 2a83 0
2a8e 1968 0 2a9d
88 :3 0 a2 :3 0
d3 :2 0 56 :3 0
4e :2 0 196b 2a90
2a94 1970 2a91 2a96
:3 0 1ff :8 0 2a9a
1973 2a9b 2a97 2a9a
0 2a9c 1975 0
2a9d 1977 2a9f 2744
2a3b 0 2aa0 0
2a9d 0 2aa0 197c
0 2aa5 25a :5 0
2aa3 4e 0 2aa4
197f 2aa3 2aa2 2aa5
1981 2aa7 1fb :4 0
2aa5 :4 0 3696 257
:3 0 94 :4 0 2aab
:2 0 2ab1 2aa9 0
21 :3 0 e9 :3 0
2aac 2aad 0 ea
:3 0 2aae 2aaf 0
2ab1 198a 2b04 eb
:3 0 21 :3 0 e9
:3 0 2ab3 2ab4 0
ea :3 0 2ab5 2ab6
0 2ab8 198d 2aba
198f 2ab9 2ab8 :2 0
2b02 ec :3 0 21
:3 0 e9 :3 0 2abd
2abe 0 ea :3 0
2abf 2ac0 0 2afa
ae :3 0 af :3 0
2ac2 2ac3 0 ae
:3 0 be :3 0 2ac5
2ac6 0 ed :2 0
2 :4 0 275 :2 0
c0 :2 0 47 :2 0
1991 2acb 2acd :3 0
1994 2ac7 2acf 2ac4
2ad1 2ad0 :2 0 b1
:3 0 c1 :3 0 2ad3
2ad4 0 b3 :4 0
276 :4 0 b6 :2 0
b7 :3 0 1998 2ad8
2ada :3 0 b6 :2 0
ca :4 0 199b 2adc
2ade :3 0 b6 :2 0
f0 :4 0 199e 2ae0
2ae2 :3 0 b6 :2 0
ea :3 0 19a1 2ae4
2ae6 :3 0 b6 :2 0
f1 :4 0 19a4 2ae8
2aea :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
19a7 2aed 2af1 19ab
2aec 2af3 :3 0 19ae
2ad5 2af5 :2 0 2af7
19b1 2af8 2ad2 2af7
0 2af9 19b3 0
2afa 19b5 2afd :3 0
2afd 0 2afd 2afc
2afa 2afb :6 0 2aff
4e :3 0 19b8 2b01
19ba 2b00 2aff :2 0
2b02 19bc :2 0 2b04
0 2b04 2b03 2ab1
2b02 :6 0 3696 1
:3 0 89 :3 0 c3
:3 0 d3 :2 0 277
:3 0 2b07 2b09 0
19c1 2b08 2b0b :3 0
2b0c :2 0 89 :3 0
f6 :2 0 4e :2 0
19c6 2b0f 2b11 :3 0
2b12 :2 0 2b0d 2b14
2b13 :2 0 89 :3 0
c4 :2 0 4e :2 0
19cb 2b17 2b19 :3 0
a2 :3 0 50 :3 0
4e :2 0 19ce 2b1b
2b1e 109 :2 0 4e
:2 0 19d3 2b20 2b22
:3 0 2b1a 2b24 2b23
:2 0 2b25 :2 0 2b15
2b27 2b26 :2 0 ae
:3 0 af :3 0 2b29
2b2a 0 ae :3 0
be :3 0 2b2c 2b2d
0 24 :2 0 2
:4 0 278 :2 0 c0
:2 0 47 :2 0 19d6
2b32 2b34 :3 0 19d9
2b2e 2b36 2b2b 2b38
2b37 :2 0 b1 :3 0
c1 :3 0 2b3a 2b3b
0 b3 :4 0 279
:4 0 b6 :2 0 b7
:3 0 19dd 2b3f 2b41
:3 0 b6 :2 0 ca
:4 0 19e0 2b43 2b45
:3 0 b6 :2 0 cb
:4 0 19e3 2b47 2b49
:3 0 b6 :2 0 a2
:3 0 bb :3 0 89
:3 0 19e6 2b4d 2b4f
bc :4 0 19e8 2b4c
2b52 19eb 2b4b 2b54
:3 0 b6 :2 0 11a
:4 0 19ee 2b56 2b58
:3 0 b6 :2 0 b9
:4 0 19f1 2b5a 2b5c
:3 0 b6 :2 0 48
:3 0 19f4 2b5e 2b60
:3 0 b6 :2 0 b9
:4 0 19f7 2b62 2b64
:3 0 19fa 2b3c 2b66
:2 0 2b68 19fd 2b69
2b39 2b68 0 2b6a
19ff 0 2b92 ae
:3 0 af :3 0 2b6b
2b6c 0 ae :3 0
be :3 0 2b6e 2b6f
0 47 :2 0 2
:4 0 27a :2 0 c0
:2 0 47 :2 0 1a01
2b74 2b76 :3 0 1a04
2b70 2b78 2b6d 2b7a
2b79 :2 0 b1 :3 0
c1 :3 0 2b7c 2b7d
0 b3 :4 0 27b
:4 0 b6 :2 0 b7
:3 0 1a08 2b81 2b83
:3 0 1a0b 2b7e 2b85
:2 0 2b87 1a0e 2b88
2b7b 2b87 0 2b89
1a10 0 2b92 cf
:3 0 11d :3 0 2b8a
2b8b 0 89 :3 0
48 :3 0 d1 :3 0
1a12 2b8c 2b90 :2 0
2b92 1a16 2b93 2b28
2b92 0 2b94 1a1a
0 3696 8c :3 0
c4 :2 0 47 :2 0
1a1e 2b96 2b98 :3 0
27 :3 0 27c :4 0
2b9a 2b9b 0 2edf
28 :3 0 18d :4 0
2b9d 2b9e 0 2edf
3a :3 0 18d :4 0
2ba0 2ba1 0 2edf
256 :3 0 9d :4 0
2ba6 :2 0 2edf 2ba4
2ba7 :3 0 86 :3 0
4e :2 0 2ba8 2ba9
0 2edf 1fb :3 0
9d :3 0 26 :3 0
39 :3 0 49 :3 0
33 :3 0 4a :3 0
34 :3 0 35 :3 0
36 :4 0 2bb6 :2 0
2dfc 2bac 2bb7 :3 0
1a21 :3 0 9d :3 0
1c0 :3 0 2bb8 2bb9
:3 0 21 :3 0 e9
:3 0 2bbb 2bbc 0
4e :2 0 2bbd 2bbe
0 2bc0 1a2a 2bc7
21 :3 0 e9 :3 0
2bc1 2bc2 0 18b
:2 0 2bc3 2bc4 0
2bc6 1a2c 2bc8 2bba
2bc0 0 2bc9 0
2bc6 0 2bc9 1a2e
0 2dfc 21 :3 0
e9 :3 0 2bca 2bcb
0 21 :3 0 c4
:2 0 f5 :3 0 2bcd
2bcf 0 1a33 2bce
2bd1 :3 0 2bd2 :2 0
1ff :8 0 2bd6 1a36
2bd7 2bd3 2bd6 0
2bd8 1a38 0 2dfc
49 :3 0 e4 :2 0
1a3a 2bda 2bdb :3 0
2bdc :2 0 e5 :3 0
115 :3 0 2bde 2bdf
0 49 :3 0 39
:3 0 1a3c 2be0 2be3
d3 :2 0 4e :2 0
1a41 2be5 2be7 :3 0
2bdd 2be9 2be8 :2 0
a2 :3 0 1f2 :3 0
27 :3 0 1a44 2bec
2bee 4e :2 0 1a46
2beb 2bf1 d3 :2 0
4e :2 0 1a4b 2bf3
2bf5 :3 0 2bea 2bf7
2bf6 :2 0 27 :3 0
26 :3 0 2bf9 2bfa
0 2bfc 1a4e 2bfd
2bf8 2bfc 0 2bfe
1a50 0 2dfc e5
:3 0 115 :3 0 2bff
2c00 0 28 :3 0
39 :3 0 1a52 2c01
2c04 c4 :2 0 4e
:2 0 1a57 2c06 2c08
:3 0 86 :3 0 c4
:2 0 4e :2 0 1a5c
2c0b 2c0d :3 0 a8
:3 0 a1 :3 0 37
:3 0 a3 :3 0 2e
:3 0 a4 :3 0 38
:3 0 a5 :3 0 30
:3 0 a6 :3 0 31
:3 0 a7 :3 0 32
:3 0 9e :3 0 3a
:4 0 27d 1 :8 0
2c34 1c0 :4 0 2c1f
:3 0 d1 :3 0 d3
:2 0 1a61 2c22 2c23
:3 0 21 :3 0 e9
:3 0 2c25 2c26 0
4e :2 0 2c27 2c28
0 2c2a 1a64 2c31
21 :3 0 e9 :3 0
2c2b 2c2c 0 18b
:2 0 2c2d 2c2e 0
2c30 1a66 2c32 2c24
2c2a 0 2c33 0
2c30 0 2c33 1a68
0 2c34 1a6b 2c87
eb :3 0 21 :3 0
e9 :3 0 2c36 2c37
0 ea :3 0 2c38
2c39 0 2c3b 1a6e
2c3d 1a70 2c3c 2c3b
:2 0 2c85 ec :3 0
21 :3 0 e9 :3 0
2c40 2c41 0 ea
:3 0 2c42 2c43 0
2c7d ae :3 0 af
:3 0 2c45 2c46 0
ae :3 0 be :3 0
2c48 2c49 0 ed
:2 0 2 :4 0 27e
:2 0 c0 :2 0 47
:2 0 1a72 2c4e 2c50
:3 0 1a75 2c4a 2c52
2c47 2c54 2c53 :2 0
b1 :3 0 c1 :3 0
2c56 2c57 0 b3
:4 0 27f :4 0 b6
:2 0 b7 :3 0 1a79
2c5b 2c5d :3 0 b6
:2 0 ca :4 0 1a7c
2c5f 2c61 :3 0 b6
:2 0 f0 :4 0 1a7f
2c63 2c65 :3 0 b6
:2 0 ea :3 0 1a82
2c67 2c69 :3 0 b6
:2 0 f1 :4 0 1a85
2c6b 2c6d :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1a88 2c70 2c74
1a8c 2c6f 2c76 :3 0
1a8f 2c58 2c78 :2 0
2c7a 1a92 2c7b 2c55
2c7a 0 2c7c 1a94
0 2c7d 1a96 2c80
:3 0 2c80 0 2c80
2c7f 2c7d 2c7e :6 0
2c82 51 :3 0 1a99
2c84 1a9b 2c83 2c82
:2 0 2c85 1a9d :2 0
2c87 0 2c87 2c86
2c34 2c85 :6 0 2c89
50 :3 0 1aa0 2c8a
2c0e 2c89 0 2c8b
1aa2 0 2ca4 2e
:3 0 18d :4 0 2c8c
2c8d 0 2ca4 30
:3 0 18d :4 0 2c8f
2c90 0 2ca4 31
:3 0 18d :4 0 2c92
2c93 0 2ca4 32
:3 0 18d :4 0 2c95
2c96 0 2ca4 37
:3 0 18d :4 0 2c98
2c99 0 2ca4 38
:3 0 18d :4 0 2c9b
2c9c 0 2ca4 28
:3 0 39 :3 0 2c9e
2c9f 0 2ca4 86
:3 0 4e :2 0 2ca1
2ca2 0 2ca4 1aa4
2ca5 2c09 2ca4 0
2ca6 1aae 0 2dfc
86 :3 0 c4 :2 0
4e :2 0 1ab2 2ca8
2caa :3 0 3a :3 0
e4 :2 0 1ab5 2cad
2cae :3 0 2caf :2 0
2cab 2cb1 2cb0 :2 0
a8 :3 0 a1 :3 0
a3 :3 0 a4 :3 0
a5 :3 0 a6 :3 0
a7 :3 0 9e :3 0
3a :4 0 280 1
:8 0 2cd2 1c0 :4 0
2cbd :3 0 d1 :3 0
d3 :2 0 1ab9 2cc0
2cc1 :3 0 21 :3 0
e9 :3 0 2cc3 2cc4
0 4e :2 0 2cc5
2cc6 0 2cc8 1abc
2ccf 21 :3 0 e9
:3 0 2cc9 2cca 0
18b :2 0 2ccb 2ccc
0 2cce 1abe 2cd0
2cc2 2cc8 0 2cd1
0 2cce 0 2cd1
1ac0 0 2cd2 1ac3
2d25 eb :3 0 21
:3 0 e9 :3 0 2cd4
2cd5 0 ea :3 0
2cd6 2cd7 0 2cd9
1ac6 2cdb 1ac8 2cda
2cd9 :2 0 2d23 ec
:3 0 21 :3 0 e9
:3 0 2cde 2cdf 0
ea :3 0 2ce0 2ce1
0 2d1b ae :3 0
af :3 0 2ce3 2ce4
0 ae :3 0 be
:3 0 2ce6 2ce7 0
ed :2 0 2 :4 0
281 :2 0 c0 :2 0
47 :2 0 1aca 2cec
2cee :3 0 1acd 2ce8
2cf0 2ce5 2cf2 2cf1
:2 0 b1 :3 0 c1
:3 0 2cf4 2cf5 0
b3 :4 0 282 :4 0
b6 :2 0 b7 :3 0
1ad1 2cf9 2cfb :3 0
b6 :2 0 ca :4 0
1ad4 2cfd 2cff :3 0
b6 :2 0 f0 :4 0
1ad7 2d01 2d03 :3 0
b6 :2 0 ea :3 0
1ada 2d05 2d07 :3 0
b6 :2 0 f1 :4 0
1add 2d09 2d0b :3 0
b6 :2 0 f2 :3 0
f3 :3 0 47 :2 0
f4 :2 0 1ae0 2d0e
2d12 1ae4 2d0d 2d14
:3 0 1ae7 2cf6 2d16
:2 0 2d18 1aea 2d19
2cf3 2d18 0 2d1a
1aec 0 2d1b 1aee
2d1e :3 0 2d1e 0
2d1e 2d1d 2d1b 2d1c
:6 0 2d20 53 :3 0
1af1 2d22 1af3 2d21
2d20 :2 0 2d23 1af5
:2 0 2d25 0 2d25
2d24 2cd2 2d23 :6 0
2d27 50 :3 0 1af8
2d28 2cb2 2d27 0
2d29 1afa 0 2dfc
33 :3 0 e4 :2 0
1afc 2d2b 2d2c :3 0
2d2d :2 0 2e :3 0
e4 :2 0 1afe 2d30
2d31 :3 0 2d32 :2 0
2e :3 0 f2 :3 0
2e :3 0 b6 :2 0
283 :4 0 1b00 2d37
2d39 :3 0 47 :2 0
2f :2 0 1b03 2d35
2d3d 2d34 2d3e 0
2d40 1b07 2d41 2d33
2d40 0 2d42 1b09
0 2d4f 2e :3 0
f2 :3 0 2e :3 0
b6 :2 0 33 :3 0
1b0b 2d46 2d48 :3 0
47 :2 0 2f :2 0
1b0e 2d44 2d4c 2d43
2d4d 0 2d4f 1b12
2d50 2d2e 2d4f 0
2d51 1b15 0 2dfc
49 :3 0 e4 :2 0
1b17 2d53 2d54 :3 0
2d55 :2 0 37 :3 0
f2 :3 0 37 :3 0
b6 :2 0 49 :3 0
1b19 2d5a 2d5c :3 0
47 :2 0 2f :2 0
1b1c 2d58 2d60 2d57
2d61 0 2d63 1b20
2d64 2d56 2d63 0
2d65 1b22 0 2dfc
34 :3 0 e4 :2 0
1b24 2d67 2d68 :3 0
2d69 :2 0 30 :3 0
e4 :2 0 1b26 2d6c
2d6d :3 0 2d6e :2 0
30 :3 0 f2 :3 0
30 :3 0 b6 :2 0
283 :4 0 1b28 2d73
2d75 :3 0 47 :2 0
2f :2 0 1b2b 2d71
2d79 2d70 2d7a 0
2d7c 1b2f 2d7d 2d6f
2d7c 0 2d7e 1b31
0 2d8b 30 :3 0
f2 :3 0 30 :3 0
b6 :2 0 34 :3 0
1b33 2d82 2d84 :3 0
47 :2 0 2f :2 0
1b36 2d80 2d88 2d7f
2d89 0 2d8b 1b3a
2d8c 2d6a 2d8b 0
2d8d 1b3d 0 2dfc
4a :3 0 e4 :2 0
1b3f 2d8f 2d90 :3 0
2d91 :2 0 38 :3 0
f2 :3 0 38 :3 0
b6 :2 0 4a :3 0
1b41 2d96 2d98 :3 0
47 :2 0 2f :2 0
1b44 2d94 2d9c 2d93
2d9d 0 2d9f 1b48
2da0 2d92 2d9f 0
2da1 1b4a 0 2dfc
35 :3 0 e4 :2 0
1b4c 2da3 2da4 :3 0
2da5 :2 0 31 :3 0
e4 :2 0 1b4e 2da8
2da9 :3 0 2daa :2 0
31 :3 0 f2 :3 0
31 :3 0 b6 :2 0
283 :4 0 1b50 2daf
2db1 :3 0 47 :2 0
2f :2 0 1b53 2dad
2db5 2dac 2db6 0
2db8 1b57 2db9 2dab
2db8 0 2dba 1b59
0 2dc7 31 :3 0
f2 :3 0 31 :3 0
b6 :2 0 35 :3 0
1b5b 2dbe 2dc0 :3 0
47 :2 0 2f :2 0
1b5e 2dbc 2dc4 2dbb
2dc5 0 2dc7 1b62
2dc8 2da6 2dc7 0
2dc9 1b65 0 2dfc
36 :3 0 e4 :2 0
1b67 2dcb 2dcc :3 0
2dcd :2 0 32 :3 0
e4 :2 0 1b69 2dd0
2dd1 :3 0 2dd2 :2 0
32 :3 0 f2 :3 0
32 :3 0 b6 :2 0
283 :4 0 1b6b 2dd7
2dd9 :3 0 47 :2 0
2f :2 0 1b6e 2dd5
2ddd 2dd4 2dde 0
2de0 1b72 2de1 2dd3
2de0 0 2de2 1b74
0 2def 32 :3 0
f2 :3 0 32 :3 0
b6 :2 0 36 :3 0
1b76 2de6 2de8 :3 0
47 :2 0 2f :2 0
1b79 2de4 2dec 2de3
2ded 0 2def 1b7d
2df0 2dce 2def 0
2df1 1b80 0 2dfc
86 :3 0 86 :3 0
c0 :2 0 47 :2 0
1b82 2df4 2df6 :3 0
2df2 2df7 0 2dfc
3a :3 0 26 :3 0
2df9 2dfa 0 2dfc
1b85 2dfe 1fb :4 0
2dfc :4 0 2edf 257
:3 0 9d :4 0 2e02
:2 0 2e08 2e00 0
21 :3 0 e9 :3 0
2e03 2e04 0 ea
:3 0 2e05 2e06 0
2e08 1b94 2e5b eb
:3 0 21 :3 0 e9
:3 0 2e0a 2e0b 0
ea :3 0 2e0c 2e0d
0 2e0f 1b97 2e11
1b99 2e10 2e0f :2 0
2e59 ec :3 0 21
:3 0 e9 :3 0 2e14
2e15 0 ea :3 0
2e16 2e17 0 2e51
ae :3 0 af :3 0
2e19 2e1a 0 ae
:3 0 be :3 0 2e1c
2e1d 0 ed :2 0
2 :4 0 284 :2 0
c0 :2 0 47 :2 0
1b9b 2e22 2e24 :3 0
1b9e 2e1e 2e26 2e1b
2e28 2e27 :2 0 b1
:3 0 c1 :3 0 2e2a
2e2b 0 b3 :4 0
285 :4 0 b6 :2 0
b7 :3 0 1ba2 2e2f
2e31 :3 0 b6 :2 0
ca :4 0 1ba5 2e33
2e35 :3 0 b6 :2 0
f0 :4 0 1ba8 2e37
2e39 :3 0 b6 :2 0
ea :3 0 1bab 2e3b
2e3d :3 0 b6 :2 0
f1 :4 0 1bae 2e3f
2e41 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1bb1 2e44 2e48 1bb5
2e43 2e4a :3 0 1bb8
2e2c 2e4c :2 0 2e4e
1bbb 2e4f 2e29 2e4e
0 2e50 1bbd 0
2e51 1bbf 2e54 :3 0
2e54 0 2e54 2e53
2e51 2e52 :6 0 2e56
55 :3 0 1bc2 2e58
1bc4 2e57 2e56 :2 0
2e59 1bc6 :2 0 2e5b
0 2e5b 2e5a 2e08
2e59 :6 0 2edf 1
:3 0 86 :3 0 c4
:2 0 4e :2 0 1bcb
2e5e 2e60 :3 0 a8
:3 0 a1 :3 0 37
:3 0 a3 :3 0 2e
:3 0 a4 :3 0 38
:3 0 a5 :3 0 30
:3 0 a6 :3 0 31
:3 0 a7 :3 0 32
:3 0 9e :3 0 3a
:4 0 286 1 :8 0
2e87 1c0 :4 0 2e72
:3 0 d1 :3 0 d3
:2 0 1bd0 2e75 2e76
:3 0 21 :3 0 e9
:3 0 2e78 2e79 0
4e :2 0 2e7a 2e7b
0 2e7d 1bd3 2e84
21 :3 0 e9 :3 0
2e7e 2e7f 0 18b
:2 0 2e80 2e81 0
2e83 1bd5 2e85 2e77
2e7d 0 2e86 0
2e83 0 2e86 1bd7
0 2e87 1bda 2eda
eb :3 0 21 :3 0
e9 :3 0 2e89 2e8a
0 ea :3 0 2e8b
2e8c 0 2e8e 1bdd
2e90 1bdf 2e8f 2e8e
:2 0 2ed8 ec :3 0
21 :3 0 e9 :3 0
2e93 2e94 0 ea
:3 0 2e95 2e96 0
2ed0 ae :3 0 af
:3 0 2e98 2e99 0
ae :3 0 be :3 0
2e9b 2e9c 0 ed
:2 0 2 :4 0 287
:2 0 c0 :2 0 47
:2 0 1be1 2ea1 2ea3
:3 0 1be4 2e9d 2ea5
2e9a 2ea7 2ea6 :2 0
b1 :3 0 c1 :3 0
2ea9 2eaa 0 b3
:4 0 288 :4 0 b6
:2 0 b7 :3 0 1be8
2eae 2eb0 :3 0 b6
:2 0 ca :4 0 1beb
2eb2 2eb4 :3 0 b6
:2 0 f0 :4 0 1bee
2eb6 2eb8 :3 0 b6
:2 0 ea :3 0 1bf1
2eba 2ebc :3 0 b6
:2 0 f1 :4 0 1bf4
2ebe 2ec0 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1bf7 2ec3 2ec7
1bfb 2ec2 2ec9 :3 0
1bfe 2eab 2ecb :2 0
2ecd 1c01 2ece 2ea8
2ecd 0 2ecf 1c03
0 2ed0 1c05 2ed3
:3 0 2ed3 0 2ed3
2ed2 2ed0 2ed1 :6 0
2ed5 57 :3 0 1c08
2ed7 1c0a 2ed6 2ed5
:2 0 2ed8 1c0c :2 0
2eda 0 2eda 2ed9
2e87 2ed8 :6 0 2edc
1 :3 0 1c0f 2edd
2e61 2edc 0 2ede
1c11 0 2edf 1c13
2ee0 2b99 2edf 0
2ee1 1c1c 0 3696
6 :3 0 e4 :2 0
1c1e 2ee3 2ee4 :3 0
2ee5 :2 0 a2 :3 0
57 :3 0 4e :2 0
1c20 2ee7 2eea d3
:2 0 4e :2 0 1c25
2eec 2eee :3 0 a2
:3 0 289 :3 0 28a
:3 0 59 :3 0 28b
:3 0 111 :3 0 25
:3 0 28c :3 0 176
:3 0 f2 :3 0 41
:3 0 176 :3 0 f2
:3 0 42 :4 0 28d
1 :8 0 2f04 21
:3 0 e9 :3 0 2eff
2f00 0 ea :3 0
2f01 2f02 0 2f04
1c28 2f57 eb :3 0
21 :3 0 e9 :3 0
2f06 2f07 0 ea
:3 0 2f08 2f09 0
2f0b 1c2b 2f0d 1c2d
2f0c 2f0b :2 0 2f55
ec :3 0 21 :3 0
e9 :3 0 2f10 2f11
0 ea :3 0 2f12
2f13 0 2f4d ae
:3 0 af :3 0 2f15
2f16 0 ae :3 0
be :3 0 2f18 2f19
0 ed :2 0 2
:4 0 28e :2 0 c0
:2 0 47 :2 0 1c2f
2f1e 2f20 :3 0 1c32
2f1a 2f22 2f17 2f24
2f23 :2 0 b1 :3 0
c1 :3 0 2f26 2f27
0 b3 :4 0 28f
:4 0 b6 :2 0 b7
:3 0 1c36 2f2b 2f2d
:3 0 b6 :2 0 ca
:4 0 1c39 2f2f 2f31
:3 0 b6 :2 0 f0
:4 0 1c3c 2f33 2f35
:3 0 b6 :2 0 ea
:3 0 1c3f 2f37 2f39
:3 0 b6 :2 0 f1
:4 0 1c42 2f3b 2f3d
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1c45
2f40 2f44 1c49 2f3f
2f46 :3 0 1c4c 2f28
2f48 :2 0 2f4a 1c4f
2f4b 2f25 2f4a 0
2f4c 1c51 0 2f4d
1c53 2f50 :3 0 2f50
0 2f50 2f4f 2f4d
2f4e :6 0 2f52 59
:3 0 1c56 2f54 1c58
2f53 2f52 :2 0 2f55
1c5a :2 0 2f57 0
2f57 2f56 2f04 2f55
:6 0 2f59 1 :3 0
1c5d 2f5f 61 :3 0
4e :2 0 2f5a 2f5b
0 2f5e 0 2f5e
1c5f 2f60 2eef 2f59
0 2f61 0 2f5e
0 2f61 1c62 0
2f62 1c65 2f63 2ee6
2f62 0 2f64 1c67
0 3696 290 :3 0
e5 :3 0 291 :3 0
292 :3 0 1ae :3 0
6c :3 0 69 :3 0
110 :3 0 293 :3 0
1ea :3 0 294 :3 0
292 :3 0 293 :3 0
290 :3 0 292 :3 0
111 :3 0 293 :3 0
111 :3 0 25 :4 0
295 1 :8 0 2f7e
21 :3 0 e9 :3 0
2f79 2f7a 0 ea
:3 0 2f7b 2f7c 0
2f7e 1c69 2fd1 eb
:3 0 21 :3 0 e9
:3 0 2f80 2f81 0
ea :3 0 2f82 2f83
0 2f85 1c6c 2f87
1c6e 2f86 2f85 :2 0
2fcf ec :3 0 21
:3 0 e9 :3 0 2f8a
2f8b 0 ea :3 0
2f8c 2f8d 0 2fc7
ae :3 0 af :3 0
2f8f 2f90 0 ae
:3 0 be :3 0 2f92
2f93 0 ed :2 0
2 :4 0 296 :2 0
c0 :2 0 47 :2 0
1c70 2f98 2f9a :3 0
1c73 2f94 2f9c 2f91
2f9e 2f9d :2 0 b1
:3 0 c1 :3 0 2fa0
2fa1 0 b3 :4 0
297 :4 0 b6 :2 0
b7 :3 0 1c77 2fa5
2fa7 :3 0 b6 :2 0
ca :4 0 1c7a 2fa9
2fab :3 0 b6 :2 0
f0 :4 0 1c7d 2fad
2faf :3 0 b6 :2 0
ea :3 0 1c80 2fb1
2fb3 :3 0 b6 :2 0
f1 :4 0 1c83 2fb5
2fb7 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1c86 2fba 2fbe 1c8a
2fb9 2fc0 :3 0 1c8d
2fa2 2fc2 :2 0 2fc4
1c90 2fc5 2f9f 2fc4
0 2fc6 1c92 0
2fc7 1c94 2fca :3 0
2fca 0 2fca 2fc9
2fc7 2fc8 :6 0 2fcc
5b :3 0 1c97 2fce
1c99 2fcd 2fcc :2 0
2fcf 1c9b :2 0 2fd1
0 2fd1 2fd0 2f7e
2fcf :6 0 3696 1
:3 0 a2 :3 0 5c
:3 0 4e :2 0 1c9e
2fd3 2fd6 c3 :3 0
d3 :2 0 d4 :3 0
2fd8 2fda 0 1ca3
2fd9 2fdc :3 0 1e2
:3 0 1e3 :3 0 298
:4 0 2fe0 :4 0 2fe1
:2 0 3258 21 :3 0
e9 :3 0 2fe3 2fe4
0 4e :2 0 2fe5
2fe6 0 3258 299
:3 0 9f :3 0 29a
:3 0 29b :3 0 29c
:3 0 29d :3 0 a8
:3 0 9e :3 0 27
:3 0 29a :3 0 29b
:4 0 29e 1 :8 0
3009 1c0 :4 0 2ff4
:3 0 d1 :3 0 d3
:2 0 1ca8 2ff7 2ff8
:3 0 21 :3 0 e9
:3 0 2ffa 2ffb 0
4e :2 0 2ffc 2ffd
0 2fff 1cab 3006
21 :3 0 e9 :3 0
3000 3001 0 18b
:2 0 3002 3003 0
3005 1cad 3007 2ff9
2fff 0 3008 0
3005 0 3008 1caf
0 3009 1cb2 305c
eb :3 0 21 :3 0
e9 :3 0 300b 300c
0 ea :3 0 300d
300e 0 3010 1cb5
3012 1cb7 3011 3010
:2 0 305a ec :3 0
21 :3 0 e9 :3 0
3015 3016 0 ea
:3 0 3017 3018 0
3052 ae :3 0 af
:3 0 301a 301b 0
ae :3 0 be :3 0
301d 301e 0 ed
:2 0 2 :4 0 29f
:2 0 c0 :2 0 47
:2 0 1cb9 3023 3025
:3 0 1cbc 301f 3027
301c 3029 3028 :2 0
b1 :3 0 c1 :3 0
302b 302c 0 b3
:4 0 2a0 :4 0 b6
:2 0 b7 :3 0 1cc0
3030 3032 :3 0 b6
:2 0 ca :4 0 1cc3
3034 3036 :3 0 b6
:2 0 f0 :4 0 1cc6
3038 303a :3 0 b6
:2 0 ea :3 0 1cc9
303c 303e :3 0 b6
:2 0 f1 :4 0 1ccc
3040 3042 :3 0 b6
:2 0 f2 :3 0 f3
:3 0 47 :2 0 f4
:2 0 1ccf 3045 3049
1cd3 3044 304b :3 0
1cd6 302d 304d :2 0
304f 1cd9 3050 302a
304f 0 3051 1cdb
0 3052 1cdd 3055
:3 0 3055 0 3055
3054 3052 3053 :6 0
3057 5d :3 0 1ce0
3059 1ce2 3058 3057
:2 0 305a 1ce4 :2 0
305c 0 305c 305b
3009 305a :6 0 3258
1 :3 0 21 :3 0
e9 :3 0 305e 305f
0 21 :3 0 d3
:2 0 16b :3 0 3061
3063 0 1ce9 3062
3065 :3 0 3066 :2 0
299 :3 0 9f :3 0
1a7 :3 0 29a :3 0
29a :3 0 1a7 :3 0
29b :3 0 29b :3 0
1a7 :3 0 29c :3 0
29c :3 0 1a7 :3 0
29d :3 0 29d :3 0
a8 :3 0 9e :3 0
27 :3 0 9f :4 0
2a1 1 :8 0 3090
1c0 :4 0 307b :3 0
d1 :3 0 d3 :2 0
1cee 307e 307f :3 0
21 :3 0 e9 :3 0
3081 3082 0 4e
:2 0 3083 3084 0
3086 1cf1 308d 21
:3 0 e9 :3 0 3087
3088 0 18b :2 0
3089 308a 0 308c
1cf3 308e 3080 3086
0 308f 0 308c
0 308f 1cf5 0
3090 1cf8 30e3 eb
:3 0 21 :3 0 e9
:3 0 3092 3093 0
ea :3 0 3094 3095
0 3097 1cfb 3099
1cfd 3098 3097 :2 0
30e1 ec :3 0 21
:3 0 e9 :3 0 309c
309d 0 ea :3 0
309e 309f 0 30d9
ae :3 0 af :3 0
30a1 30a2 0 ae
:3 0 be :3 0 30a4
30a5 0 ed :2 0
2 :4 0 2a2 :2 0
c0 :2 0 47 :2 0
1cff 30aa 30ac :3 0
1d02 30a6 30ae 30a3
30b0 30af :2 0 b1
:3 0 c1 :3 0 30b2
30b3 0 b3 :4 0
2a3 :4 0 b6 :2 0
b7 :3 0 1d06 30b7
30b9 :3 0 b6 :2 0
ca :4 0 1d09 30bb
30bd :3 0 b6 :2 0
f0 :4 0 1d0c 30bf
30c1 :3 0 b6 :2 0
ea :3 0 1d0f 30c3
30c5 :3 0 b6 :2 0
f1 :4 0 1d12 30c7
30c9 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1d15 30cc 30d0 1d19
30cb 30d2 :3 0 1d1c
30b4 30d4 :2 0 30d6
1d1f 30d7 30b1 30d6
0 30d8 1d21 0
30d9 1d23 30dc :3 0
30dc 0 30dc 30db
30d9 30da :6 0 30de
5f :3 0 1d26 30e0
1d28 30df 30de :2 0
30e1 1d2a :2 0 30e3
0 30e3 30e2 3090
30e1 :6 0 3163 1
:3 0 21 :3 0 e9
:3 0 30e5 30e6 0
21 :3 0 d3 :2 0
16b :3 0 30e8 30ea
0 1d2f 30e9 30ec
:3 0 30ed :2 0 299
:3 0 9f :3 0 a8
:3 0 9e :3 0 27
:3 0 9f :4 0 2a4
1 :8 0 310b 1c0
:4 0 30f6 :3 0 d1
:3 0 d3 :2 0 1d34
30f9 30fa :3 0 21
:3 0 e9 :3 0 30fc
30fd 0 4e :2 0
30fe 30ff 0 3101
1d37 3108 21 :3 0
e9 :3 0 3102 3103
0 18b :2 0 3104
3105 0 3107 1d39
3109 30fb 3101 0
310a 0 3107 0
310a 1d3b 0 310b
1d3e 315e eb :3 0
21 :3 0 e9 :3 0
310d 310e 0 ea
:3 0 310f 3110 0
3112 1d41 3114 1d43
3113 3112 :2 0 315c
ec :3 0 21 :3 0
e9 :3 0 3117 3118
0 ea :3 0 3119
311a 0 3154 ae
:3 0 af :3 0 311c
311d 0 ae :3 0
be :3 0 311f 3120
0 ed :2 0 2
:4 0 2a5 :2 0 c0
:2 0 47 :2 0 1d45
3125 3127 :3 0 1d48
3121 3129 311e 312b
312a :2 0 b1 :3 0
c1 :3 0 312d 312e
0 b3 :4 0 2a6
:4 0 b6 :2 0 b7
:3 0 1d4c 3132 3134
:3 0 b6 :2 0 ca
:4 0 1d4f 3136 3138
:3 0 b6 :2 0 f0
:4 0 1d52 313a 313c
:3 0 b6 :2 0 ea
:3 0 1d55 313e 3140
:3 0 b6 :2 0 f1
:4 0 1d58 3142 3144
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1d5b
3147 314b 1d5f 3146
314d :3 0 1d62 312f
314f :2 0 3151 1d65
3152 312c 3151 0
3153 1d67 0 3154
1d69 3157 :3 0 3157
0 3157 3156 3154
3155 :6 0 3159 61
:3 0 1d6c 315b 1d6e
315a 3159 :2 0 315c
1d70 :2 0 315e 0
315e 315d 310b 315c
:6 0 3160 1 :3 0
1d73 3161 30ee 3160
0 3162 1d75 0
3163 1d77 3164 3067
3163 0 3165 1d7a
0 3258 256 :3 0
aa :3 0 39 :3 0
111 :3 0 14a :3 0
1e9 :3 0 1bb :3 0
1ae :3 0 2a7 :3 0
a3 :3 0 2a7 :3 0
a5 :3 0 2a7 :3 0
a6 :3 0 2a7 :3 0
a7 :3 0 54 :3 0
2a8 :3 0 2a9 :3 0
1ae :3 0 2aa :3 0
2ab :3 0 1ae :3 0
2ac :3 0 2ad :3 0
2ae :3 0 29a :3 0
2ae :3 0 29a :3 0
2a7 :3 0 2af :3 0
2b0 :3 0 29a :3 0
69 :3 0 13e :3 0
29a :3 0 69 :3 0
29a :3 0 2ad :3 0
2ae :3 0 2b1 :3 0
2ae :3 0 2b1 :3 0
2a7 :3 0 2af :3 0
2b0 :3 0 29b :3 0
69 :3 0 13e :3 0
29b :3 0 69 :3 0
29b :3 0 2ad :3 0
2ae :3 0 29c :3 0
2ae :3 0 29c :3 0
2a7 :3 0 2af :3 0
2b0 :3 0 29c :3 0
69 :3 0 13e :3 0
29c :3 0 69 :3 0
29c :3 0 2ad :3 0
2ae :3 0 2b2 :3 0
2ae :3 0 2b2 :3 0
2a7 :3 0 2af :3 0
2b0 :3 0 29d :3 0
69 :3 0 13e :3 0
29d :3 0 69 :3 0
29d :3 0 2a7 :3 0
2b3 :3 0 2a7 :3 0
2b4 :3 0 2a7 :3 0
2b5 :3 0 2a7 :3 0
2b6 :3 0 2a7 :3 0
2b7 :3 0 2a7 :3 0
2b8 :3 0 2a7 :3 0
2b8 :3 0 59 :3 0
2b9 :3 0 5a :3 0
2ba :3 0 2a7 :3 0
2b5 :3 0 2a7 :3 0
2b6 :3 0 2a7 :3 0
2b7 :3 0 2bb :3 0
2bc :3 0 2bd :3 0
2be :3 0 2bf :3 0
1ae :3 0 2c0 :3 0
2c1 :3 0 2c2 :3 0
5f :3 0 134 :3 0
2a7 :3 0 2c3 :3 0
2c4 :3 0 2e :3 0
a1 :3 0 30 :3 0
a4 :3 0 2c5 :3 0
2c6 :3 0 155 :3 0
2c7 :3 0 2c8 :3 0
299 :3 0 2b0 :3 0
1ea :3 0 a8 :3 0
2a7 :3 0 2a7 :3 0
9f :3 0 2b0 :3 0
9f :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
2cb :3 0 2ae :3 0
2ae :3 0 99 :3 0
25 :3 0 2ae :3 0
9b :3 0 2a7 :3 0
9f :3 0 1ea :3 0
19a :3 0 1e9 :3 0
1e9 :3 0 19b :3 0
39 :3 0 1ea :3 0
1b0 :3 0 2cc :3 0
1e9 :3 0 a1 :3 0
2cc :3 0 111 :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 2cd :3 0
13e :3 0 2cc :3 0
2ce :3 0 13e :3 0
2ce :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
227 :3 0 2a9 :3 0
1e9 :3 0 1be :3 0
2a9 :3 0 111 :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 232 :3 0
2ab :3 0 1e9 :3 0
1bd :3 0 2ab :3 0
111 :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
183 :3 0 2bf :3 0
2bf :3 0 111 :3 0
1e9 :3 0 1bc :3 0
2a7 :3 0 a3 :3 0
2a7 :3 0 a5 :3 0
2a7 :3 0 a6 :3 0
2a7 :3 0 a7 :4 0
2cf 1 :a 0 3235
:2 0 3258 3167 3233
:2 0 ae :3 0 af
:3 0 3236 3237 0
ae :3 0 be :3 0
3239 323a 0 47
:2 0 2 :4 0 2d0
:2 0 c0 :2 0 47
:2 0 1d7c 323f 3241
:3 0 1d7f 323b 3243
3238 3245 3244 :2 0
b1 :3 0 c1 :3 0
3247 3248 0 b3
:4 0 2d1 :4 0 b6
:2 0 b7 :3 0 1d83
324c 324e :3 0 1d86
3249 3250 :2 0 3252
1d89 3253 3246 3252
0 3254 1d8b 0
3258 20 :3 0 aa
:3 0 3256 :2 0 3258
1d8d 3693 8c :3 0
d3 :2 0 47 :2 0
1d97 325a 325c :3 0
256 :3 0 ab :3 0
2a7 :3 0 9f :3 0
111 :3 0 14a :3 0
2cc :3 0 2be :3 0
1ae :3 0 2a7 :3 0
a3 :3 0 2a7 :3 0
a5 :3 0 2a7 :3 0
a6 :3 0 2a7 :3 0
a7 :3 0 2cc :3 0
2a8 :3 0 2d2 :3 0
1ae :3 0 2aa :3 0
2d3 :3 0 1ae :3 0
2ac :3 0 2ad :3 0
2a7 :3 0 2d4 :3 0
2a7 :3 0 29a :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2a7 :3 0
2d4 :3 0 2a7 :3 0
29a :3 0 2a7 :3 0
29a :3 0 69 :3 0
29a :3 0 2ad :3 0
2a7 :3 0 2d4 :3 0
2a7 :3 0 29b :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2a7 :3 0
2d4 :3 0 2a7 :3 0
29b :3 0 2a7 :3 0
29b :3 0 69 :3 0
29b :3 0 2ad :3 0
2a7 :3 0 2d4 :3 0
2a7 :3 0 29c :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2a7 :3 0
2d4 :3 0 2a7 :3 0
29c :3 0 2a7 :3 0
29c :3 0 69 :3 0
29c :3 0 2ad :3 0
2a7 :3 0 2d4 :3 0
2a7 :3 0 29d :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2a7 :3 0
2d4 :3 0 2a7 :3 0
29d :3 0 2a7 :3 0
29d :3 0 69 :3 0
29d :3 0 2a7 :3 0
2b3 :3 0 2a7 :3 0
2b4 :3 0 2a7 :3 0
2b5 :3 0 2a7 :3 0
2b6 :3 0 2a7 :3 0
2b7 :3 0 2a7 :3 0
2b8 :3 0 2a7 :3 0
2b8 :3 0 59 :3 0
2b9 :3 0 5a :3 0
2ba :3 0 2a7 :3 0
2b5 :3 0 2a7 :3 0
2b6 :3 0 2a7 :3 0
2b7 :3 0 2bb :3 0
2d5 :3 0 2be :3 0
2bc :3 0 2cc :3 0
2bd :3 0 2bf :3 0
1ae :3 0 2c0 :3 0
2d6 :3 0 2be :3 0
2d6 :3 0 2c1 :3 0
2c2 :3 0 5f :3 0
134 :3 0 2a7 :3 0
2c3 :3 0 2c4 :3 0
2a7 :3 0 a1 :3 0
2a7 :3 0 a4 :3 0
a2 :3 0 2ae :3 0
2d7 :3 0 2ae :3 0
2d8 :3 0 2c5 :3 0
2cc :3 0 2c6 :3 0
2cc :3 0 2d9 :3 0
2c7 :3 0 2cc :3 0
2c8 :3 0 a8 :3 0
2a7 :3 0 1ea :3 0
183 :3 0 1e9 :3 0
2a7 :3 0 9f :3 0
1e9 :3 0 111 :3 0
1ea :3 0 183 :3 0
2bf :3 0 2bf :3 0
111 :3 0 1e9 :3 0
1b1 :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
167 :3 0 2d6 :3 0
2bf :3 0 2da :3 0
2d6 :3 0 9b :3 0
1ea :3 0 167 :3 0
2cc :3 0 2a7 :3 0
9f :3 0 2cc :3 0
9b :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
167 :3 0 2d5 :3 0
2d5 :3 0 9b :3 0
2cc :3 0 2db :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 2cb :3 0
2ae :3 0 2ae :3 0
99 :3 0 25 :3 0
2ae :3 0 9b :3 0
2a7 :3 0 9f :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 227 :3 0
2a9 :3 0 2cc :3 0
9b :3 0 2a9 :3 0
111 :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
227 :3 0 2d2 :3 0
2a9 :3 0 1b1 :3 0
2d2 :3 0 111 :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 232 :3 0
2ab :3 0 2cc :3 0
9b :3 0 2ab :3 0
111 :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
232 :3 0 2d3 :3 0
2ab :3 0 1b1 :3 0
2d3 :3 0 111 :3 0
111 :4 0 2dc 1
:a 0 338f :2 0 33b2
325f 338d :2 0 ae
:3 0 af :3 0 3390
3391 0 ae :3 0
be :3 0 3393 3394
0 47 :2 0 2
:4 0 2dd :2 0 c0
:2 0 47 :2 0 1d9a
3399 339b :3 0 1d9d
3395 339d 3392 339f
339e :2 0 b1 :3 0
c1 :3 0 33a1 33a2
0 b3 :4 0 2de
:4 0 b6 :2 0 b7
:3 0 1da1 33a6 33a8
:3 0 1da4 33a3 33aa
:2 0 33ac 1da7 33ad
33a0 33ac 0 33ae
1da9 0 33b2 20
:3 0 ab :3 0 33b0
:2 0 33b2 1dab 368f
1e2 :3 0 1e3 :3 0
2df :4 0 33b5 :4 0
33b6 :2 0 368e 21
:3 0 e9 :3 0 33b8
33b9 0 4e :2 0
33ba 33bb 0 368e
2e0 :3 0 9f :3 0
29a :3 0 29b :3 0
29c :3 0 29d :3 0
a8 :3 0 2d4 :4 0
2e1 1 :8 0 33db
1c0 :4 0 33c6 :3 0
d1 :3 0 d3 :2 0
1db1 33c9 33ca :3 0
21 :3 0 e9 :3 0
33cc 33cd 0 4e
:2 0 33ce 33cf 0
33d1 1db4 33d8 21
:3 0 e9 :3 0 33d2
33d3 0 18b :2 0
33d4 33d5 0 33d7
1db6 33d9 33cb 33d1
0 33da 0 33d7
0 33da 1db8 0
33db 1dbb 342e eb
:3 0 21 :3 0 e9
:3 0 33dd 33de 0
ea :3 0 33df 33e0
0 33e2 1dbe 33e4
1dc0 33e3 33e2 :2 0
342c ec :3 0 21
:3 0 e9 :3 0 33e7
33e8 0 ea :3 0
33e9 33ea 0 3424
ae :3 0 af :3 0
33ec 33ed 0 ae
:3 0 be :3 0 33ef
33f0 0 ed :2 0
2 :4 0 2e2 :2 0
c0 :2 0 47 :2 0
1dc2 33f5 33f7 :3 0
1dc5 33f1 33f9 33ee
33fb 33fa :2 0 b1
:3 0 c1 :3 0 33fd
33fe 0 b3 :4 0
2e3 :4 0 b6 :2 0
b7 :3 0 1dc9 3402
3404 :3 0 b6 :2 0
ca :4 0 1dcc 3406
3408 :3 0 b6 :2 0
f0 :4 0 1dcf 340a
340c :3 0 b6 :2 0
ea :3 0 1dd2 340e
3410 :3 0 b6 :2 0
f1 :4 0 1dd5 3412
3414 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1dd8 3417 341b 1ddc
3416 341d :3 0 1ddf
33ff 341f :2 0 3421
1de2 3422 33fc 3421
0 3423 1de4 0
3424 1de6 3427 :3 0
3427 0 3427 3426
3424 3425 :6 0 3429
63 :3 0 1de9 342b
1deb 342a 3429 :2 0
342c 1ded :2 0 342e
0 342e 342d 33db
342c :6 0 368e 1
:3 0 2e0 :3 0 9f
:3 0 1a7 :3 0 29a
:3 0 29a :3 0 1a7
:3 0 29b :3 0 29b
:3 0 1a7 :3 0 29c
:3 0 29c :3 0 1a7
:3 0 29d :3 0 29d
:3 0 a8 :3 0 9f
:3 0 9f :3 0 a8
:3 0 2d4 :3 0 9f
:3 0 9f :4 0 2e4
1 :8 0 345b 1c0
:4 0 3446 :3 0 d1
:3 0 d3 :2 0 1df2
3449 344a :3 0 21
:3 0 e9 :3 0 344c
344d 0 4e :2 0
344e 344f 0 3451
1df5 3458 21 :3 0
e9 :3 0 3452 3453
0 18b :2 0 3454
3455 0 3457 1df7
3459 344b 3451 0
345a 0 3457 0
345a 1df9 0 345b
1dfc 34ae eb :3 0
21 :3 0 e9 :3 0
345d 345e 0 ea
:3 0 345f 3460 0
3462 1dff 3464 1e01
3463 3462 :2 0 34ac
ec :3 0 21 :3 0
e9 :3 0 3467 3468
0 ea :3 0 3469
346a 0 34a4 ae
:3 0 af :3 0 346c
346d 0 ae :3 0
be :3 0 346f 3470
0 ed :2 0 2
:4 0 2e5 :2 0 c0
:2 0 47 :2 0 1e03
3475 3477 :3 0 1e06
3471 3479 346e 347b
347a :2 0 b1 :3 0
c1 :3 0 347d 347e
0 b3 :4 0 2e6
:4 0 b6 :2 0 b7
:3 0 1e0a 3482 3484
:3 0 b6 :2 0 ca
:4 0 1e0d 3486 3488
:3 0 b6 :2 0 f0
:4 0 1e10 348a 348c
:3 0 b6 :2 0 ea
:3 0 1e13 348e 3490
:3 0 b6 :2 0 f1
:4 0 1e16 3492 3494
:3 0 b6 :2 0 f2
:3 0 f3 :3 0 47
:2 0 f4 :2 0 1e19
3497 349b 1e1d 3496
349d :3 0 1e20 347f
349f :2 0 34a1 1e23
34a2 347c 34a1 0
34a3 1e25 0 34a4
1e27 34a7 :3 0 34a7
0 34a7 34a6 34a4
34a5 :6 0 34a9 65
:3 0 1e2a 34ab 1e2c
34aa 34a9 :2 0 34ac
1e2e :2 0 34ae 0
34ae 34ad 345b 34ac
:6 0 368e 1 :3 0
256 :3 0 ac :3 0
2a7 :3 0 9f :3 0
111 :3 0 14a :3 0
2cc :3 0 2be :3 0
1ae :3 0 2a7 :3 0
a3 :3 0 2a7 :3 0
a5 :3 0 2a7 :3 0
a6 :3 0 2a7 :3 0
a7 :3 0 2cc :3 0
2a8 :3 0 2d2 :3 0
1ae :3 0 2aa :3 0
2d3 :3 0 1ae :3 0
2ac :3 0 2ad :3 0
2ae :3 0 29a :3 0
2ae :3 0 29a :3 0
13e :3 0 29a :3 0
13e :3 0 29a :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2e7 :3 0
29a :3 0 2e7 :3 0
29a :3 0 2cc :3 0
290 :3 0 6c :3 0
2cc :3 0 290 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
2cc :3 0 290 :3 0
2e8 :3 0 29a :3 0
69 :3 0 29a :3 0
2ad :3 0 2ae :3 0
29a :3 0 2ae :3 0
2b1 :3 0 13e :3 0
29a :3 0 13e :3 0
29b :3 0 2cc :3 0
290 :3 0 6c :3 0
2cc :3 0 290 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
2cc :3 0 290 :3 0
2e7 :3 0 29a :3 0
2e7 :3 0 29b :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2e8 :3 0
29b :3 0 69 :3 0
29b :3 0 2ad :3 0
2ae :3 0 29a :3 0
2ae :3 0 29c :3 0
13e :3 0 29a :3 0
13e :3 0 29c :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2e7 :3 0
29a :3 0 2e7 :3 0
29c :3 0 2cc :3 0
290 :3 0 6c :3 0
2cc :3 0 290 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
2cc :3 0 290 :3 0
2e8 :3 0 29c :3 0
69 :3 0 29c :3 0
2ad :3 0 2ae :3 0
2b1 :3 0 2ae :3 0
2b2 :3 0 13e :3 0
29b :3 0 13e :3 0
29d :3 0 2cc :3 0
290 :3 0 6c :3 0
2cc :3 0 290 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
6c :3 0 e5 :3 0
291 :3 0 1ae :3 0
294 :3 0 111 :3 0
2cc :3 0 290 :3 0
2e7 :3 0 29a :3 0
2e7 :3 0 29d :3 0
2cc :3 0 290 :3 0
6c :3 0 2cc :3 0
290 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 6c :3 0
e5 :3 0 291 :3 0
1ae :3 0 294 :3 0
111 :3 0 2cc :3 0
290 :3 0 2e8 :3 0
29d :3 0 69 :3 0
29d :3 0 2a7 :3 0
2b3 :3 0 2a7 :3 0
2b4 :3 0 2a7 :3 0
2b5 :3 0 2a7 :3 0
2b6 :3 0 2a7 :3 0
2b7 :3 0 2a7 :3 0
2b8 :3 0 2a7 :3 0
2b8 :3 0 59 :3 0
2b9 :3 0 5a :3 0
2ba :3 0 2a7 :3 0
2b5 :3 0 2a7 :3 0
2b6 :3 0 2a7 :3 0
2b7 :3 0 2bb :3 0
2d5 :3 0 2be :3 0
2bc :3 0 2cc :3 0
2bd :3 0 2bf :3 0
1ae :3 0 2c0 :3 0
2d6 :3 0 2be :3 0
2d6 :3 0 2c1 :3 0
2c2 :3 0 5f :3 0
134 :3 0 2a7 :3 0
2c3 :3 0 2c4 :3 0
2a7 :3 0 a1 :3 0
2a7 :3 0 a4 :3 0
a2 :3 0 2ae :3 0
2d7 :3 0 2ae :3 0
2d8 :3 0 2c5 :3 0
2cc :3 0 2c6 :3 0
2cc :3 0 2d9 :3 0
2c7 :3 0 2cc :3 0
2c8 :3 0 a8 :3 0
2a7 :3 0 2c9 :3 0
1ea :3 0 2e0 :3 0
2e7 :3 0 2a7 :3 0
9f :3 0 2e7 :3 0
9f :3 0 2e7 :3 0
2d4 :3 0 2c9 :3 0
1ea :3 0 2e0 :3 0
2e8 :3 0 2a7 :3 0
9f :3 0 2e8 :3 0
9f :3 0 2e8 :3 0
2d4 :3 0 1ea :3 0
183 :3 0 1e9 :3 0
2a7 :3 0 9f :3 0
1e9 :3 0 111 :3 0
1ea :3 0 183 :3 0
2bf :3 0 2bf :3 0
111 :3 0 1e9 :3 0
1b1 :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
167 :3 0 2d6 :3 0
2bf :3 0 2da :3 0
2d6 :3 0 9b :3 0
1ea :3 0 167 :3 0
2cc :3 0 2a7 :3 0
9f :3 0 2cc :3 0
9b :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
167 :3 0 2d5 :3 0
2d5 :3 0 9b :3 0
2cc :3 0 2db :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 2cb :3 0
2ae :3 0 2ae :3 0
99 :3 0 25 :3 0
2ae :3 0 9b :3 0
2a7 :3 0 9f :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 167 :3 0
2e9 :3 0 2cc :3 0
2db :3 0 2e9 :3 0
9b :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
227 :3 0 2a9 :3 0
2cc :3 0 9b :3 0
2a9 :3 0 111 :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 227 :3 0
2d2 :3 0 2a9 :3 0
1b1 :3 0 2d2 :3 0
111 :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
232 :3 0 2ab :3 0
2cc :3 0 9b :3 0
2ab :3 0 111 :3 0
2c9 :3 0 2ca :3 0
1ea :3 0 232 :3 0
2d3 :3 0 2ab :3 0
1b1 :3 0 2d3 :3 0
111 :3 0 2c9 :3 0
2ca :3 0 1ea :3 0
2cd :3 0 13e :3 0
2cc :3 0 2ce :3 0
13e :3 0 2ce :3 0
2a7 :3 0 a3 :3 0
2a7 :3 0 a5 :3 0
2a7 :3 0 a6 :3 0
2a7 :3 0 a7 :3 0
111 :4 0 2ea 1
:a 0 366b :2 0 368e
34b1 3669 :2 0 ae
:3 0 af :3 0 366c
366d 0 ae :3 0
be :3 0 366f 3670
0 47 :2 0 2
:4 0 2eb :2 0 c0
:2 0 47 :2 0 1e31
3675 3677 :3 0 1e34
3671 3679 366e 367b
367a :2 0 b1 :3 0
c1 :3 0 367d 367e
0 b3 :4 0 2ec
:4 0 b6 :2 0 b7
:3 0 1e38 3682 3684
:3 0 1e3b 367f 3686
:2 0 3688 1e3e 3689
367c 3688 0 368a
1e40 0 368e 20
:3 0 ac :3 0 368c
:2 0 368e 1e42 3690
325d 33b2 0 3691
0 368e 0 3691
1e4a 0 3692 1e4d
3694 2fdd 3258 0
3695 0 3692 0
3695 1e4f 0 3696
1e52 3737 21 :3 0
2ed :2 0 4 3697
3698 0 ae :3 0
af :3 0 369a 369b
0 ae :3 0 be
:3 0 369d 369e 0
ed :2 0 2 :4 0
2ee :2 0 c0 :2 0
47 :2 0 1e8e 36a3
36a5 :3 0 1e91 369f
36a7 369c 36a9 36a8
:2 0 b1 :3 0 c1
:3 0 36ab 36ac 0
b3 :4 0 2ef :4 0
b6 :2 0 b7 :3 0
1e95 36b0 36b2 :3 0
1e98 36ad 36b4 :2 0
36cd b1 :3 0 c1
:3 0 36b6 36b7 0
b3 :4 0 2f0 :4 0
b6 :2 0 21 :3 0
2f1 :3 0 36bc 36bd
0 1e9b 36bb 36bf
:3 0 b6 :2 0 11a
:4 0 1e9e 36c1 36c3
:3 0 b6 :2 0 21
:3 0 2f2 :3 0 36c6
36c7 0 1ea1 36c5
36c9 :3 0 1ea4 36b8
36cb :2 0 36cd 1ea7
36ce 36aa 36cd 0
36cf 1eaa 0 36df
256 :3 0 ad :3 0
21 :3 0 2f1 :3 0
2f3 :3 0 21 :3 0
2f2 :3 0 2f4 :3 0
e7 :4 0 2f5 1
:a 0 36db :2 0 36df
36d1 36d9 :2 0 20
:3 0 ad :3 0 36dd
:2 0 36df 1eac 36e1
1eb0 36e0 36df :2 0
3735 ec :3 0 21
:3 0 e9 :3 0 36e4
36e5 0 ea :3 0
36e6 36e7 0 372d
ae :3 0 af :3 0
36e9 36ea 0 ae
:3 0 be :3 0 36ec
36ed 0 ed :2 0
2 :4 0 2f6 :2 0
c0 :2 0 47 :2 0
1eb2 36f2 36f4 :3 0
1eb5 36ee 36f6 36eb
36f8 36f7 :2 0 b1
:3 0 c1 :3 0 36fa
36fb 0 b3 :4 0
2f7 :4 0 b6 :2 0
b7 :3 0 1eb9 36ff
3701 :3 0 1ebc 36fc
3703 :2 0 371d b1
:3 0 c1 :3 0 3705
3706 0 b3 :4 0
f0 :4 0 b6 :2 0
ea :3 0 1ebf 370a
370c :3 0 b6 :2 0
f1 :4 0 1ec2 370e
3710 :3 0 b6 :2 0
f2 :3 0 f3 :3 0
47 :2 0 f4 :2 0
1ec5 3713 3717 1ec9
3712 3719 :3 0 1ecc
3707 371b :2 0 371d
1ecf 371e 36f9 371d
0 371f 1ed2 0
372d 256 :3 0 ad
:3 0 2f3 :3 0 21
:3 0 2f2 :3 0 2f4
:3 0 e7 :4 0 2f8
1 :a 0 3729 :2 0
372d 3721 3727 :2 0
20 :3 0 ad :3 0
372b :2 0 372d 1ed4
3730 :3 0 3730 0
3730 372f 372d 372e
:6 0 3732 1 :3 0
1ed9 3734 1edb 3733
3732 :2 0 3735 1edd
:2 0 3737 1ee0 3737
3736 3696 3735 :6 0
3738 :2 0 2 74
3737 373b :3 0 373a
3738 373c :8 0 
1f4b
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
67 1 6b 1b
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 5a 5e 62
66 6a 6e 1
78 1 76 1
7f 1 7d 1
86 1 84 1
8d 1 8b 1
94 1 92 1
9b 1 99 1
a2 1 a0 1
a9 1 a7 1
b0 1 ae 1
b7 1 b5 1
be 1 bc 1
c5 1 c3 1
cc 1 ca 1
d3 1 d1 1
da 1 d8 1
e1 1 df 1
e8 1 e6 1
ef 1 ed 1
f6 1 f4 1
fd 1 fb 1
104 1 102 1
109 1 110 1
10e 1 117 1
115 1 11e 1
11c 1 125 1
123 1 12c 1
12a 1 131 1
138 1 136 1
13f 1 13d 1
146 1 144 1
14d 1 14b 1
154 1 152 1
15b 1 159 1
160 1 166 1
16c 1 172 1
178 1 17e 1
184 1 18a 1
190 1 196 1
19c 1 1a2 1
1a8 1 1ae 1
1b4 1 1ba 1
1c0 1 1c6 1
1cc 1 1d2 1
1d8 1 1de 1
1e4 1 1ea 1
1f0 1 1f6 1
1fc 1 202 1
208 1 20e 1
214 1 21a 1
220 1 228 1
226 1 22d 1
233 1 239 1
241 1 23f 1
248 1 246 1
24f 1 24d 1
254 1 25a 1
262 1 260 1
269 1 267 1
270 1 26e 1
277 1 275 1
27e 1 27c 1
285 1 283 1
28a 1 290 1
296 1 29c 1
2a2 1 2a8 1
2ae 1 2b4 1
2bc 1 2ba 1
2c1 1 2c7 1
2cc 1 2d1 1
2d6 1 2db 1
2e0 1 2e5 1
2ea 1 2fe 1
319 1 31f 1
326 1 32d 1
334 1 341 1
34d 2 350 352
2 355 357 2
359 35b 2 35d
35f 2 361 363
2 365 367 2
369 36b 2 36d
36f 2 371 373
2 375 377 2
379 37b 2 37d
37f 2 381 383
1 389 2 38b
38c 2 385 38e
2 390 392 1
398 2 39a 39b
2 394 39d 2
39f 3a1 1 3a7
2 3a9 3aa 2
3a3 3ac 2 3ae
3b0 1 3b6 2
3b8 3b9 2 3b2
3bb 2 3bd 3bf
1 3c5 2 3c7
3c8 2 3c1 3ca
2 3cc 3ce 1
3d4 2 3d6 3d7
2 3d0 3d9 2
3db 3dd 1 3e3
2 3e5 3e6 2
3df 3e8 2 3ea
3ec 1 3f2 2
3f4 3f5 2 3ee
3f7 2 3f9 3fb
2 3fd 3ff 2
401 403 2 405
407 2 409 40b
2 40d 40f 2
411 413 2 415
417 2 419 41b
2 41d 41f 2
421 423 2 425
427 2 429 42b
2 42d 42f 2
431 433 2 435
437 2 439 43b
2 43d 43f 2
441 443 2 445
447 2 449 44b
1 451 2 453
454 2 44d 456
2 458 45a 2
45c 45e 2 460
462 2 464 466
2 468 46a 2
46c 46e 2 470
472 2 474 476
2 478 47a 2
47c 47e 2 480
482 2 484 486
2 488 48a 2
48c 48e 2 490
492 2 494 496
2 498 49a 1
4a0 2 4a2 4a3
2 49c 4a5 2
4a7 4a9 1 4af
2 4b1 4b2 2
4ab 4b4 2 4b6
4b8 1 4be 2
4c0 4c1 2 4ba
4c3 2 4c5 4c7
1 4cd 2 4cf
4d0 2 4c9 4d2
2 4d4 4d6 2
4d8 4da 2 4dc
4de 2 4e0 4e2
2 4e4 4e6 2
4e8 4ea 2 4ec
4ee 2 4f0 4f2
2 4f4 4f6 4
349 34f 354 4f8
1 4fa 1 4fc
2 506 508 3
504 505 50a 2
513 515 2 512
517 1 519 1
51b 2 566 567
1 56d 2 569
56d 1 571 2
581 583 3 57f
580 585 2 58e
590 2 592 594
2 596 598 1
5a0 2 5a2 5a3
2 59a 5a5 2
58d 5a7 1 5a9
1 5ab 2 5b5
5b7 3 5b3 5b4
5b9 2 5c2 5c4
2 5c1 5c6 1
5c8 1 5ca 2
5d1 5d2 3 5ac
5cb 5d4 1 5d6
1 5d8 1 5de
1 5e6 1 5ee
2 5f7 5f8 1
5fe 2 5fa 5fe
1 604 2 60b
60c 1 612 2
60e 612 2 620
622 3 61e 61f
624 2 62d 62f
2 631 633 2
635 637 1 63f
2 641 642 2
639 644 2 62c
646 1 648 1
64a 2 654 656
3 652 653 658
2 661 663 2
660 665 1 667
1 669 2 670
671 3 64b 66a
673 1 676 1
67c 2 68c 68e
3 68a 68b 690
2 699 69b 2
69d 69f 2 6a1
6a3 1 6ab 2
6ad 6ae 2 6a5
6b0 2 698 6b2
1 6b4 1 6b6
2 6c0 6c2 3
6be 6bf 6c4 2
6cd 6cf 2 6cc
6d1 1 6d3 1
6d5 2 6dc 6dd
3 6b7 6d6 6df
2 6e2 6e1 1
6e3 1 6e5 2
6e8 6e9 1 6ed
2 6eb 6ed 2
6f1 6f2 1 6f6
2 6f4 6f6 2
6fc 6fd 1 701
2 6ff 701 2
70e 710 3 70c
70d 712 2 71b
71d 2 71f 721
2 723 725 1
72d 2 72f 730
2 727 732 2
71a 734 1 736
1 738 2 742
744 3 740 741
746 2 74f 751
2 74e 753 1
755 1 757 2
75e 75f 3 739
758 761 1 763
1 765 1 76d
1 771 2 773
774 2 777 778
1 77e 2 77a
77e 1 782 1
78a 2 79a 79f
1 7a6 1 7a1
2 7b9 7bb 3
7b7 7b8 7bd 2
7c6 7c8 2 7ca
7cc 2 7ce 7d0
2 7d2 7d4 2
7d6 7d8 3 7dd
7de 7df 2 7da
7e1 2 7c5 7e3
1 7e5 1 7e7
2 7b0 7e8 1
7ec 1 7ab 2
7a9 7f0 1 7fb
2 7f7 7fb 2
800 801 1 805
2 803 805 2
813 815 3 811
812 817 2 820
822 2 824 826
2 828 82a 1
832 2 834 835
2 82c 837 2
81f 839 1 83b
1 83d 2 847
849 3 845 846
84b 2 854 856
2 853 858 1
85a 1 85c 2
863 864 3 83e
85d 866 1 868
3 7f3 869 86c
1 86e 1 870
1 876 2 881
886 1 88d 1
888 2 8a0 8a2
3 89e 89f 8a4
2 8ad 8af 2
8b1 8b3 2 8b5
8b7 2 8b9 8bb
2 8bd 8bf 3
8c4 8c5 8c6 2
8c1 8c8 2 8ac
8ca 1 8cc 1
8ce 2 897 8cf
1 8d3 1 892
2 890 8d7 1
8da 1 8dd 2
8e8 8e9 2 8eb
8ee 2 8f1 8f2
2 8f9 8fa 2
8fc 8ff 2 909
90a 2 90c 90f
2 912 913 2
91a 91b 2 91d
920 2 925 926
1 92c 2 928
92c 1 931 2
935 936 1 93c
2 938 93c 1
941 2 945 946
1 94c 2 948
94c 1 951 1
955 2 957 958
1 959 3 95b
943 95c 2 95f
960 1 964 2
962 964 2 96f
974 1 97b 1
976 2 98e 990
3 98c 98d 992
2 99b 99d 2
99f 9a1 2 9a3
9a5 2 9a7 9a9
2 9ab 9ad 3
9b2 9b3 9b4 2
9af 9b6 2 99a
9b8 1 9ba 1
9bc 2 985 9bd
1 9c1 1 980
2 97e 9c5 2
9cb 9cc 1 9d0
2 9ce 9d0 2
9d8 9dd 1 9e4
1 9df 2 9f7
9f9 3 9f5 9f6
9fb 2 a04 a06
2 a08 a0a 2
a0c a0e 2 a10
a12 2 a14 a16
3 a1b a1c a1d
2 a18 a1f 2
a03 a21 1 a23
1 a25 2 9ee
a26 1 a2a 1
9e9 2 9e7 a2e
2 a36 a37 1
a3b 2 a39 a3b
2 a46 a48 3
a44 a45 a4a 2
a53 a55 2 a57
a59 2 a5b a5d
1 a65 2 a67
a68 2 a5f a6a
2 a6c a6e 2
a70 a72 2 a74
a76 2 a78 a7a
2 a52 a7c 1
a7e 1 a80 2
a8a a8c 3 a88
a89 a8e 2 a97
a99 2 a96 a9b
1 a9d 1 a9f
3 aa6 aa7 aa8
3 a81 aa0 aaa
1 aac 2 a31
aad 1 aaf 2
ab4 ab5 1 ab7
2 abc abd 1
ac1 2 abf ac1
2 ac7 ac8 1
aca 2 acf ad0
1 ad4 2 ad2
ad4 2 adf ae1
3 add ade ae3
2 aec aee 2
af0 af2 2 af4
af6 1 afe 2
b00 b01 2 af8
b03 2 aeb b05
1 b07 1 b09
2 b13 b15 3
b11 b12 b17 2
b20 b22 2 b1f
b24 1 b26 1
b28 2 b2f b30
3 b0a b29 b32
1 b34 3 acd
b35 b3a 1 b3c
2 b42 b43 1
b47 2 b45 b47
1 b4c 2 b56
b58 3 b54 b55
b5a 2 b63 b65
2 b67 b69 2
b6b b6d 1 b75
2 b77 b78 2
b6f b7a 2 b62
b7c 1 b7e 1
b80 2 b8a b8c
3 b88 b89 b8e
2 b97 b99 2
b96 b9b 1 b9d
1 b9f 2 ba6
ba7 3 b81 ba0
ba9 2 bab bac
6 bb0 bb1 bb2
bb3 bb4 bb5 2
bba bbb 1 bc1
2 bbd bc1 2
bc5 bc6 1 bca
2 bc8 bca 1
bd1 1 bd3 2
bdd bdf 3 bdb
bdc be1 2 bea
bec 2 bee bf0
2 bf2 bf4 1
bfa 2 bfc bfd
2 bf6 bff 2
c01 c03 2 c05
c07 2 c09 c0b
2 c0d c0f 2
be9 c11 1 c13
1 c15 2 c1f
c21 3 c1d c1e
c23 2 c2c c2e
2 c2b c30 1
c32 1 c34 2
c3a c3b 3 c3d
c3e c3f 4 bd4
c16 c35 c41 1
c43 2 c46 c47
1 c4b 2 c49
c4b 2 c4f c50
1 c54 2 c52
c54 2 c61 c63
3 c5f c60 c65
2 c6e c70 2
c72 c74 2 c76
c78 1 c7e 2
c80 c81 2 c7a
c83 2 c85 c87
2 c89 c8b 2
c8d c8f 2 c91
c93 2 c6d c95
1 c97 1 c99
2 ca3 ca5 3
ca1 ca2 ca7 2
cb0 cb2 2 caf
cb4 1 cb6 1
cb8 2 cbe cbf
3 cc1 cc2 cc3
3 c9a cb9 cc5
1 cc7 2 cca
ccb 1 cd1 2
ccd cd1 2 cd6
cd7 1 cd9 1
cdd 2 cdb cdd
2 ced cf2 1
cf9 1 cf4 2
d0c d0e 3 d0a
d0b d10 2 d19
d1b 2 d1d d1f
2 d21 d23 2
d25 d27 2 d29
d2b 3 d30 d31
d32 2 d2d d34
2 d18 d36 1
d38 1 d3a 2
d03 d3b 1 d3f
1 cfe 2 cfc
d43 1 d46 2
d70 d75 1 d7c
1 d77 2 d8f
d91 3 d8d d8e
d93 2 d9c d9e
2 da0 da2 2
da4 da6 2 da8
daa 2 dac dae
3 db3 db4 db5
2 db0 db7 2
d9b db9 1 dbb
1 dbd 2 d86
dbe 1 dc2 1
d81 2 d7f dc6
1 dc9 2 dcc
dcd 1 dd5 2
dd1 dd5 2 de1
de3 3 ddf de0
de5 2 dee df0
2 df2 df4 2
df6 df8 1 e00
2 e02 e03 2
dfa e05 2 e07
e09 2 e0b e0d
2 e0f e11 2
e13 e15 2 ded
e17 1 e19 1
e1b 2 e25 e27
3 e23 e24 e29
2 e32 e34 2
e31 e36 1 e38
1 e3a 3 e41
e42 e43 3 e1c
e3b e45 1 e47
2 dce e48 2
e4c e4d 1 e53
2 e4f e53 2
e5f e64 1 e6b
1 e66 2 e7e
e80 3 e7c e7d
e82 2 e8b e8d
2 e8f e91 2
e93 e95 2 e97
e99 2 e9b e9d
3 ea2 ea3 ea4
2 e9f ea6 2
e8a ea8 1 eaa
1 eac 2 e75
ead 1 eb1 1
e70 2 e6e eb5
1 ec0 2 ebc
ec0 2 ecc ece
3 eca ecb ed0
2 ed9 edb 2
edd edf 2 ee1
ee3 1 eeb 2
eed eee 2 ee5
ef0 2 ef2 ef4
2 ef6 ef8 2
efa efc 2 efe
f00 2 ed8 f02
1 f04 1 f06
2 f10 f12 3
f0e f0f f14 2
f1d f1f 2 f1c
f21 1 f23 1
f25 3 f2c f2d
f2e 3 f07 f26
f30 1 f32 2
f47 f4c 1 f53
1 f4e 2 f66
f68 3 f64 f65
f6a 2 f73 f75
2 f77 f79 2
f7b f7d 2 f7f
f81 2 f83 f85
3 f8a f8b f8c
2 f87 f8e 2
f72 f90 1 f92
1 f94 2 f5d
f95 1 f99 1
f58 2 f56 f9d
1 fa8 2 fa4
fa8 2 fb4 fb6
3 fb2 fb3 fb8
2 fc1 fc3 2
fc5 fc7 2 fc9
fcb 1 fd3 2
fd5 fd6 2 fcd
fd8 2 fda fdc
2 fde fe0 2
fe2 fe4 2 fe6
fe8 2 fc0 fea
1 fec 1 fee
2 ff8 ffa 3
ff6 ff7 ffc 2
1005 1007 2 1004
1009 1 100b 1
100d 3 1014 1015
1016 3 fef 100e
1018 1 101a 1
101c 1 1028 2
1025 102b 1 102d
5 eb8 f33 fa0
101b 102e 2 1039
103b 3 1037 1038
103d 2 1046 1048
2 104a 104c 2
104e 1050 1 1058
2 105a 105b 2
1052 105d 2 105f
1061 2 1063 1065
2 1067 1069 2
106b 106d 2 1045
106f 1 1071 1
1073 2 107d 107f
3 107b 107c 1081
2 108a 108c 2
1089 108e 1 1090
1 1092 3 1099
109a 109b 3 1074
1093 109d 3 109f
1030 10a0 2 10a3
10a4 1 10aa 2
10a6 10aa 2 10c4
10c9 1 10d0 1
10cb 2 10e3 10e5
3 10e1 10e2 10e7
2 10f0 10f2 2
10f4 10f6 2 10f8
10fa 2 10fc 10fe
2 1100 1102 3
1107 1108 1109 2
1104 110b 2 10ef
110d 1 110f 1
1111 2 10da 1112
1 1116 1 10d5
2 10d3 111a 1
1125 2 1121 1125
2 1131 1133 3
112f 1130 1135 2
113e 1140 2 1142
1144 2 1146 1148
1 1150 2 1152
1153 2 114a 1155
2 1157 1159 2
115b 115d 2 115f
1161 2 1163 1165
2 113d 1167 1
1169 1 116b 2
1175 1177 3 1173
1174 1179 2 1182
1184 2 1181 1186
1 1188 1 118a
3 1191 1192 1193
3 116c 118b 1195
1 119e 2 119a
119e 3 11a3 11a4
11a5 1 11a9 2
11a7 11a9 2 11ad
11ae 1 11b2 2
11b0 11b2 2 11b6
11b7 2 11bc 11bd
1 11bf 2 11b9
11bf 2 11cf 11d1
3 11cd 11ce 11d3
2 11dc 11de 2
11e0 11e2 2 11e4
11e6 1 11ee 2
11f0 11f1 2 11e8
11f3 2 11f5 11f7
2 11f9 11fb 2
11fd 11ff 2 1201
1203 2 11db 1205
1 1207 1 1209
2 1213 1215 3
1211 1212 1217 2
1220 1222 2 121f
1224 1 1226 1
1228 3 122f 1230
1231 3 120a 1229
1233 1 1235 2
1238 1239 2 123e
123f 1 1241 2
123b 1241 2 124d
1252 1 1259 1
1254 2 126c 126e
3 126a 126b 1270
2 1279 127b 2
127d 127f 2 1281
1283 2 1285 1287
2 1289 128b 3
1290 1291 1292 2
128d 1294 2 1278
1296 1 1298 1
129a 2 1263 129b
1 129f 1 125e
2 125c 12a3 1
12a6 1 12a9 2
1236 12aa 2 12ad
12ac 2 111d 12ae
1 12b0 c 969
9c8 ab0 aba b3d
b40 bad bb8 c44
cc8 10a1 12b1 1
12b3 2 12b6 12b7
1 12bb 2 12b9
12bb 2 12bf 12c0
1 12c6 2 12c2
12c6 1 12c9 2
12d1 12d2 1 12d6
2 12d4 12d6 2
12e3 12e5 3 12e1
12e2 12e7 2 12f0
12f2 2 12f4 12f6
2 12f8 12fa 1
1302 2 1304 1305
2 12fc 1307 2
1309 130b 2 130d
130f 2 1311 1313
2 1315 1317 2
12ef 1319 1 131b
1 131d 2 1327
1329 3 1325 1326
132b 2 1334 1336
2 1333 1338 1
133a 1 133c 3
1343 1344 1345 3
131e 133d 1347 1
1349 2 134c 134d
1 1353 2 134f
1353 2 1361 1366
1 136d 1 1368
2 1380 1382 3
137e 137f 1384 2
138d 138f 2 1391
1393 2 1395 1397
2 1399 139b 2
139d 139f 3 13a4
13a5 13a6 2 13a1
13a8 2 138c 13aa
1 13ac 1 13ae
2 1377 13af 1
13b3 1 1372 2
1370 13b7 1 13c2
2 13be 13c2 2
13cb 13d0 1 13d7
1 13d2 2 13ea
13ec 3 13e8 13e9
13ee 2 13f7 13f9
2 13fb 13fd 2
13ff 1401 2 1403
1405 2 1407 1409
3 140e 140f 1410
2 140b 1412 2
13f6 1414 1 1416
1 1418 2 13e1
1419 1 141d 1
13dc 2 13da 1421
1 142c 2 1428
142c 2 1438 143a
3 1436 1437 143c
2 1445 1447 2
1449 144b 2 144d
144f 1 1457 2
1459 145a 2 1451
145c 2 145e 1460
2 1462 1464 2
1466 1468 2 146a
146c 2 1444 146e
1 1470 1 1472
2 147c 147e 3
147a 147b 1480 2
1489 148b 2 1488
148d 1 148f 1
1491 3 1498 1499
149a 3 1473 1492
149c 1 149e 2
1424 149f 1 14a1
2 13ba 14a2 1
14a4 2 134a 14a5
1 14a7 2 14aa
14ab 1 14af 2
14ad 14af 2 14b3
14b4 1 14b8 2
14b6 14b8 1 14bf
1 14c1 2 14c4
14c5 1 14cb 2
14c7 14cb 1 14ce
2 14d5 14d8 2
14dc 14df 2 14e1
14e2 2 14e3 14e6
1 14ea 2 14e8
14ea 2 14f5 14f6
2 14fa 14fb 2
14ff 1500 2 1504
1505 2 1509 150a
2 150e 150f 2
1513 1514 2 1518
1519 d 14f2 14f3
14f8 14fd 1502 1507
150c 1511 1516 151b
151c 151d 151e 2
1523 1524 1 152a
2 1526 152a 2
1535 1537 3 1533
1534 1539 2 1542
1544 2 1546 1548
2 154a 154c 1
1554 2 1556 1557
2 154e 1559 2
1541 155b 1 155d
1 155f 2 1569
156b 3 1567 1568
156d 2 1576 1578
2 1575 157a 1
157c 1 157e 2
1585 1586 3 1560
157f 1588 2 158c
158d 1 1591 2
158f 1591 2 159c
159e 3 159a 159b
15a0 2 15a9 15ab
2 15ad 15af 2
15b1 15b3 1 15b9
2 15bb 15bc 2
15b5 15be 2 15c0
15c2 2 15c4 15c6
2 15c8 15ca 2
15cc 15ce 2 15a8
15d0 1 15d2 1
15d4 2 15de 15e0
3 15dc 15dd 15e2
2 15eb 15ed 2
15ea 15ef 1 15f1
1 15f3 2 15f9
15fa 3 15fc 15fd
15fe 3 15d5 15f4
1600 2 1603 1602
3 14ef 1521 1604
2 160a 160b 1
160f 2 160d 160f
2 1614 1615 2
161a 161b 2 1617
161d 1 1620 1
1622 2 1608 1623
2 1625 1626 2
1629 162a 1 162e
2 162c 162e 2
1633 1634 1 1638
2 1636 1638 2
163f 1640 1 1644
2 1642 1644 2
1649 164a 1 164e
2 164c 164e 1
1656 2 165a 165b
1 165f 2 165d
165f 1 1664 2
1669 166a 1 166e
2 166c 166e 2
1673 1674 1 1678
2 1676 1678 1
1680 2 1685 1686
1 168a 2 1688
168a 1 168f 4
1692 1667 1683 1691
1 1693 1 1695
2 1627 1696 2
1698 1699 2 169c
169d 1 16a3 2
169f 16a3 3 16b1
16b2 16b3 2 16bb
16bc 1 16c0 2
16be 16c0 2 16c7
16ca 2 16d1 16d6
1 16dd 1 16d8
2 16f0 16f2 3
16ee 16ef 16f4 2
16fd 16ff 2 1701
1703 2 1705 1707
2 1709 170b 2
170d 170f 3 1714
1715 1716 2 1711
1718 2 16fc 171a
1 171c 1 171e
2 16e7 171f 1
1723 1 16e2 2
16e0 1727 1 1732
2 172e 1732 2
1737 1738 1 173c
2 173a 173c 2
174a 174f 1 1756
1 1751 2 1769
176b 3 1767 1768
176d 2 1776 1778
2 177a 177c 2
177e 1780 2 1782
1784 2 1786 1788
3 178d 178e 178f
2 178a 1791 2
1775 1793 1 1795
1 1797 2 1760
1798 1 179c 1
175b 2 1759 17a0
1 17a3 1 17a6
1 17a7 1 17ab
2 17ad 17ae 2
172a 17af 2 17b1
17b2 1 17b6 2
17b4 17b6 2 17c2
17c7 1 17ce 1
17c9 2 17e1 17e3
3 17df 17e0 17e5
2 17ee 17f0 2
17f2 17f4 2 17f6
17f8 2 17fa 17fc
2 17fe 1800 3
1805 1806 1807 2
1802 1809 2 17ed
180b 1 180d 1
180f 2 17d8 1810
1 1814 1 17d3
2 17d1 1818 2
183c 1841 1 1848
1 1843 2 185b
185d 3 1859 185a
185f 2 1868 186a
2 186c 186e 2
1870 1872 2 1874
1876 2 1878 187a
3 187f 1880 1881
2 187c 1883 2
1867 1885 1 1887
1 1889 2 1852
188a 1 188e 1
184d 2 184b 1892
1 189d 2 1899
189d 2 18a9 18ab
3 18a7 18a8 18ad
2 18b6 18b8 2
18ba 18bc 2 18be
18c0 1 18c8 2
18ca 18cb 2 18c2
18cd 2 18cf 18d1
2 18d3 18d5 2
18d7 18d9 2 18db
18dd 2 18b5 18df
1 18e1 1 18e3
2 18ed 18ef 3
18eb 18ec 18f1 2
18fa 18fc 2 18f9
18fe 1 1900 1
1902 3 1909 190a
190b 3 18e4 1903
190d 1 190f 2
1912 1913 1 1917
2 1915 1917 1
191c 1 1920 2
1922 1923 1 193b
2 193a 193b 1
1943 1 1949 2
194b 194c 2 1938
194d 1 1954 1
194f 2 1967 1969
3 1965 1966 196b
2 1974 1976 2
1978 197a 2 197c
197e 2 1980 1982
2 1984 1986 3
198b 198c 198d 2
1988 198f 2 1973
1991 1 1993 1
1995 2 195e 1996
1 199a 1 1959
2 1957 199e 5
181b 1895 1910 1924
19a1 3 19a6 19a7
19a8 1 19ac 2
19aa 19ac 1 19bc
2 19bb 19bc 1
19c4 1 19ca 2
19cc 19cd 2 19b9
19ce 1 19d5 1
19d0 2 19e8 19ea
3 19e6 19e7 19ec
2 19f5 19f7 2
19f9 19fb 2 19fd
19ff 2 1a01 1a03
2 1a05 1a07 3
1a0c 1a0d 1a0e 2
1a09 1a10 2 19f4
1a12 1 1a14 1
1a16 2 19df 1a17
1 1a1b 1 19da
2 19d8 1a1f 1
1a22 2 1a26 1a25
1 1a34 2 1a33
1a34 1 1a3c 1
1a42 2 1a44 1a45
2 1a31 1a46 1
1a4d 1 1a48 2
1a60 1a62 3 1a5e
1a5f 1a64 2 1a6d
1a6f 2 1a71 1a73
2 1a75 1a77 2
1a79 1a7b 2 1a7d
1a7f 3 1a84 1a85
1a86 2 1a81 1a88
2 1a6c 1a8a 1
1a8c 1 1a8e 2
1a57 1a8f 1 1a93
1 1a52 2 1a50
1a97 1 1aa8 2
1aa7 1aa8 1 1ab0
1 1ab6 2 1ab8
1ab9 2 1aa5 1aba
1 1ac1 1 1abc
2 1ad4 1ad6 3
1ad2 1ad3 1ad8 2
1ae1 1ae3 2 1ae5
1ae7 2 1ae9 1aeb
2 1aed 1aef 2
1af1 1af3 3 1af8
1af9 1afa 2 1af5
1afc 2 1ae0 1afe
1 1b00 1 1b02
2 1acb 1b03 1
1b07 1 1ac6 2
1ac4 1b0b 1 1b19
2 1b18 1b19 1
1b21 1 1b27 2
1b29 1b2a 2 1b16
1b2b 1 1b32 1
1b2d 2 1b45 1b47
3 1b43 1b44 1b49
2 1b52 1b54 2
1b56 1b58 2 1b5a
1b5c 2 1b5e 1b60
2 1b62 1b64 3
1b69 1b6a 1b6b 2
1b66 1b6d 2 1b51
1b6f 1 1b71 1
1b73 2 1b3c 1b74
1 1b78 1 1b37
2 1b35 1b7c a
16a8 16ab 16ae 16b6
16b9 17b3 1a27 1a9a
1b0e 1b7f 1 1b82
2 1b8a 1b8b 1
1b8f 2 1b8d 1b8f
2 1b93 1b94 1
1b9a 2 1b96 1b9a
2 1ba0 1ba1 1
1ba7 2 1ba3 1ba7
1 1bac 1 1bb3
1 1bb5 1 1bb6
1 1bb8 2 1bbb
1bbc 1 1bc0 2
1bbe 1bc0 1 1bc7
1 1bc9 1 1bcb
1 1bd0 1 1bd7
1 1bde 1 1be8
1 1bea 2 1bf3
1bf4 1 1bf8 2
1bf6 1bf8 2 1bfc
1bfd 1 1c03 2
1bff 1c03 2 1c07
1c09 2 1c0b 1c0d
2 1c0f 1c11 2
1c13 1c15 2 1c17
1c19 2 1c1b 1c1d
2 1c1f 1c21 1
1c24 2 1c28 1c29
1 1c2d 2 1c2b
1c2d 2 1c31 1c33
2 1c35 1c37 2
1c39 1c3b 2 1c3d
1c3f 2 1c41 1c43
2 1c45 1c47 2
1c49 1c4b 2 1c4d
1c4f 1 1c52 2
1c56 1c58 2 1c5a
1c5c 2 1c5e 1c60
2 1c62 1c64 2
1c66 1c68 1 1c6b
3 1c6d 1c54 1c6e
1 1c6f 2 1c72
1c73 1 1c79 2
1c75 1c79 2 1c7d
1c7e 1 1c84 2
1c80 1c84 2 1c8a
1c8b 1 1c91 2
1c8d 1c91 1 1ca0
1 1cc9 2 1cc8
1cc9 1 1cd1 1
1cd7 2 1cd9 1cda
2 1cc6 1cdb 1
1ce2 1 1cdd 2
1cf5 1cf7 3 1cf3
1cf4 1cf9 2 1d02
1d04 2 1d06 1d08
2 1d0a 1d0c 2
1d0e 1d10 2 1d12
1d14 3 1d19 1d1a
1d1b 2 1d16 1d1d
2 1d01 1d1f 1
1d21 1 1d23 2
1cec 1d24 1 1d28
1 1ce7 2 1ce5
1d2c 1 1d49 2
1d48 1d49 1 1d51
1 1d57 2 1d59
1d5a 2 1d46 1d5b
1 1d62 1 1d5d
2 1d75 1d77 3
1d73 1d74 1d79 2
1d82 1d84 2 1d86
1d88 2 1d8a 1d8c
2 1d8e 1d90 2
1d92 1d94 3 1d99
1d9a 1d9b 2 1d96
1d9d 2 1d81 1d9f
1 1da1 1 1da3
2 1d6c 1da4 1
1da8 1 1d67 2
1d65 1dac 4 1ca9
1cae 1d2f 1daf 1
1db4 2 1db6 1db7
3 1c9a 1c9f 1db8
1 1dba 1 1dbc
1 1dc4 2 1dc6
1dc7 1 1dcb 2
1dc9 1dcb 1 1dd1
2 1dd3 1dd4 2
1dd6 1dd7 2 1dd9
1ddb 1 1dcd 1
1de3 2 1de5 1de6
2 1de8 1de9 2
1ddf 1dec 1 1df4
2 1df3 1df4 2
1dfe 1e00 3 1dfd
1e02 1e03 1 1e05
2 1e07 1e08 1
1e0c 2 1e0a 1e0c
2 1e13 1e15 3
1e12 1e17 1e18 1
1e1a 2 1e1c 1e1d
1 1e21 2 1e1f
1e21 1 1e27 1
1e29 2 1e2c 1e2e
2 1e2a 1e31 1
1e36 2 1e35 1e36
2 1e42 1e44 3
1e40 1e41 1e46 2
1e4f 1e51 2 1e53
1e55 2 1e57 1e59
1 1e61 2 1e63
1e64 2 1e5b 1e66
2 1e4e 1e68 1
1e6a 1 1e6c 2
1e76 1e78 3 1e74
1e75 1e7a 2 1e83
1e85 2 1e82 1e87
1 1e89 1 1e8b
2 1e92 1e93 3
1e6d 1e8c 1e95 1
1e97 2 1e9d 1ea2
1 1ea9 1 1ea4
2 1ebc 1ebe 3
1eba 1ebb 1ec0 2
1ec9 1ecb 2 1ecd
1ecf 2 1ed1 1ed3
2 1ed5 1ed7 2
1ed9 1edb 3 1ee0
1ee1 1ee2 2 1edd
1ee4 2 1ec8 1ee6
1 1ee8 1 1eea
2 1eb3 1eeb 1
1eef 1 1eae 2
1eac 1ef3 5 1dee
1df1 1e34 1e98 1ef6
1 1ef9 2 1efc
1efd 1 1f03 2
1eff 1f03 2 1f0d
1f0f 2 1f14 1f16
4 1f08 1f0b 1f12
1f19 2 1f1d 1f1e
1 1f24 2 1f20
1f24 2 1f2b 1f2d
2 1f32 1f34 4
1f29 1f30 1f37 1f3a
2 1f3e 1f3f 1
1f45 2 1f41 1f45
1 1f4e 2 1f54
1f56 2 1f5b 1f5d
2 1f62 1f64 3
1f59 1f60 1f67 1
1f69 2 1f6c 1f6e
1 1f72 2 1f78
1f7a 2 1f7f 1f81
2 1f86 1f88 3
1f7d 1f84 1f8b 1
1f8d 5 1f4a 1f4d
1f6a 1f71 1f8e 1
1f90 2 1f96 1f98
2 1f9b 1f9e 2
1fa1 1fa3 2 1fa5
1fa7 1 1fae 2
1fb4 1fb6 2 1fbb
1fbd 2 1fc2 1fc4
3 1fb9 1fc0 1fc7
1 1fc9 2 1fcc
1fce 2 1fd0 1fd2
2 1fd4 1fd6 2
1fd8 1fda 2 1fdc
1fde 2 1fe0 1fe2
4 1faa 1fad 1fca
1fe5 2 1fe7 1fe8
1 1fea 2 1ff0
1ff2 2 1ff4 1ff6
2 1ff8 1ffa 1
1ffd 1 1fff 2
1fe9 2000 2 2002
2003 1 2004 3
2006 1f3c 2007 2
200a 200b 1 2011
2 200d 2011 1
2014 2 201e 2023
1 202a 1 2025
2 203d 203f 3
203b 203c 2041 2
204a 204c 2 204e
2050 2 2052 2054
2 2056 2058 2
205a 205c 3 2061
2062 2063 2 205e
2065 2 2049 2067
1 2069 1 206b
2 2034 206c 1
2070 1 202f 2
202d 2074 1 207f
2 207b 207f 1
2086 2 2088 2089
2 208e 2090 2
2095 2097 2 2099
209b 2 209d 209f
2 20a1 20a3 3
208c 2093 20a6 2
20b0 20b2 3 20ae
20af 20b4 2 20bd
20bf 2 20c1 20c3
2 20c5 20c7 1
20cf 2 20d1 20d2
2 20c9 20d4 2
20d6 20d8 2 20da
20dc 2 20de 20e0
2 20e2 20e4 2
20bc 20e6 1 20e8
1 20ea 2 20f4
20f6 3 20f2 20f3
20f8 2 2101 2103
2 2100 2105 1
2107 1 2109 3
2110 2111 2112 3
20eb 210a 2114 2
2116 2117 2 2077
2118 1 211a 1
211c 2 2126 212b
1 2132 1 212d
2 2145 2147 3
2143 2144 2149 2
2152 2154 2 2156
2158 2 215a 215c
2 215e 2160 2
2162 2164 3 2169
216a 216b 2 2166
216d 2 2151 216f
1 2171 1 2173
2 213c 2174 1
2178 1 2137 2
2135 217c 1 2187
2 2183 2187 2
218c 218e 2 2193
2195 2 2197 2199
2 219b 219d 2
219f 21a1 2 2191
21a4 2 21ae 21b0
3 21ac 21ad 21b2
2 21bb 21bd 2
21bf 21c1 2 21c3
21c5 1 21cd 2
21cf 21d0 2 21c7
21d2 2 21d4 21d6
2 21d8 21da 2
21dc 21de 2 21e0
21e2 2 21ba 21e4
1 21e6 1 21e8
2 21f2 21f4 3
21f0 21f1 21f6 2
21ff 2201 2 21fe
2203 1 2205 1
2207 3 220e 220f
2210 3 21e9 2208
2212 2 2214 2215
2 217f 2216 1
2218 1 221a 2
2224 2229 1 2230
1 222b 2 2243
2245 3 2241 2242
2247 2 2250 2252
2 2254 2256 2
2258 225a 2 225c
225e 2 2260 2262
3 2267 2268 2269
2 2264 226b 2
224f 226d 1 226f
1 2271 2 223a
2272 1 2276 1
2235 2 2233 227a
1 2285 2 2281
2285 2 228a 228c
2 2291 2293 2
2295 2297 2 2299
229b 2 229d 229f
2 228f 22a2 2
22ac 22ae 3 22aa
22ab 22b0 2 22b9
22bb 2 22bd 22bf
2 22c1 22c3 1
22cb 2 22cd 22ce
2 22c5 22d0 2
22d2 22d4 2 22d6
22d8 2 22da 22dc
2 22de 22e0 2
22b8 22e2 1 22e4
1 22e6 2 22f0
22f2 3 22ee 22ef
22f4 2 22fd 22ff
2 22fc 2301 1
2303 1 2305 3
230c 230d 230e 3
22e7 2306 2310 2
2312 2313 2 227d
2314 1 2316 2
2319 231a 1 231e
2 231c 231e 2
2322 2323 1 2327
2 2325 2327 2
232d 232f 2 2335
2336 1 2338 2
2331 233a 2 233c
233e 1 2341 1
2343 4 211b 2219
2317 2344 1 2346
1 2348 1 2350
2 2352 2353 1
235c 2 235b 235c
2 2368 236a 4
2366 2367 236c 236d
2 2376 237b 1
2382 1 237d 2
2395 2397 3 2393
2394 2399 2 23a2
23a4 2 23a6 23a8
2 23aa 23ac 2
23ae 23b0 2 23b2
23b4 3 23b9 23ba
23bb 2 23b6 23bd
2 23a1 23bf 1
23c1 1 23c3 2
238c 23c4 1 23c8
1 2387 2 2385
23cc 1 23d7 2
23d3 23d7 2 23e3
23e5 3 23e1 23e2
23e7 2 23f0 23f2
2 23f4 23f6 2
23f8 23fa 1 2402
2 2404 2405 2
23fc 2407 2 2409
240b 2 240d 240f
2 2411 2413 2
2415 2417 2 23ef
2419 1 241b 1
241d 2 2427 2429
3 2425 2426 242b
2 2434 2436 2
2433 2438 1 243a
1 243c 3 2443
2444 2445 3 241e
243d 2447 1 2449
2 244c 244e 2
2450 2452 2 2454
2456 2 2458 245a
2 245c 245e 2
2460 2462 2 2467
2468 1 246e 2
246a 246e 2 2472
2474 1 2477 2
247a 247c 1 247f
2 2481 2482 2
2485 2486 1 248c
2 2488 248c 1
2490 1 2492 2
2495 2497 7 2370
23cf 244a 2465 2483
2493 249a 3 2356
2359 249d 1 249f
2 24a2 24a3 1
24a9 2 24a5 24a9
1 24af 2 24b1
24b2 1 24bb 2
24ba 24bb 2 24c7
24c9 4 24c5 24c6
24cb 24cc 2 24d5
24da 1 24e1 1
24dc 2 24f4 24f6
3 24f2 24f3 24f8
2 2501 2503 2
2505 2507 2 2509
250b 2 250d 250f
2 2511 2513 3
2518 2519 251a 2
2515 251c 2 2500
251e 1 2520 1
2522 2 24eb 2523
1 2527 1 24e6
2 24e4 252b 1
2536 2 2532 2536
2 2542 2544 3
2540 2541 2546 2
254f 2551 2 2553
2555 2 2557 2559
1 2561 2 2563
2564 2 255b 2566
2 2568 256a 2
256c 256e 2 2570
2572 2 2574 2576
2 254e 2578 1
257a 1 257c 2
2586 2588 3 2584
2585 258a 2 2593
2595 2 2592 2597
1 2599 1 259b
3 25a2 25a3 25a4
3 257d 259c 25a6
1 25a8 2 25ab
25ad 2 25af 25b1
2 25b3 25b5 2
25b7 25b9 2 25bb
25bd 2 25bf 25c1
2 25c3 25c5 2
25ca 25cc 5 24cf
252e 25a9 25c8 25cf
3 24b5 24b8 25d2
1 25d4 2 25d7
25d9 7 1dbb 1efa
2008 2347 24a0 25d5
25dc 2 25de 25df
2 25e2 25e4 1
25f9 1 25ff 2
2601 2602 1 260a
2 2606 260a 1
260f 1 2611 2
2614 2615 1 2619
2 2617 2619 2
261d 261e 1 2624
2 2620 2624 2
262a 262b 1 2631
2 262d 2631 2
2637 2638 1 263e
2 263a 263e 1
2641 1 265b 1
2661 2 2663 2664
1 266c 2 2668
266c 2 2672 2678
1 267f 1 267a
2 2692 2694 3
2690 2691 2696 2
269f 26a1 2 26a3
26a5 2 26a7 26a9
2 26ab 26ad 2
26af 26b1 3 26b6
26b7 26b8 2 26b3
26ba 2 269e 26bc
1 26be 1 26c0
2 2689 26c1 1
26c5 1 2684 2
2682 26c9 2 26cc
26cf 2 26d3 26d9
1 26e0 1 26db
2 26f3 26f5 3
26f1 26f2 26f7 2
2700 2702 2 2704
2706 2 2708 270a
2 270c 270e 2
2710 2712 3 2717
2718 2719 2 2714
271b 2 26ff 271d
1 271f 1 2721
2 26ea 2722 1
2726 1 26e5 2
26e3 272a 1 272d
2 2730 2731 4
264d 2652 2665 2732
1 2734 2 273d
273e 1 2742 2
2740 2742 3 2746
2747 2748 1 274c
2 274a 274c 2
2753 2756 2 275a
275b 1 275d 1
2761 2 275f 2761
2 276d 2772 1
2779 1 2774 2
278c 278e 3 278a
278b 2790 2 2799
279b 2 279d 279f
2 27a1 27a3 2
27a5 27a7 2 27a9
27ab 3 27b0 27b1
27b2 2 27ad 27b4
2 2798 27b6 1
27b8 1 27ba 2
2783 27bb 1 27bf
1 277e 2 277c
27c3 2 27c9 27ca
1 27ce 2 27cc
27ce 2 27d3 27d9
1 27e0 1 27db
2 27f3 27f5 3
27f1 27f2 27f7 2
2800 2802 2 2804
2806 2 2808 280a
2 280c 280e 2
2810 2812 3 2817
2818 2819 2 2814
281b 2 27ff 281d
1 281f 1 2821
2 27ea 2822 1
2826 1 27e5 2
27e3 282a 2 2837
2839 3 2835 2836
283b 2 2844 2846
2 2848 284a 2
284c 284e 1 2856
2 2858 2859 2
2850 285b 2 285d
285f 2 2861 2863
2 2865 2867 2
2869 286b 2 2843
286d 1 286f 1
2871 2 287b 287d
3 2879 287a 287f
2 2888 288a 2
2887 288c 1 288e
1 2890 3 2897
2898 2899 4 282d
2872 2891 289b 1
289d 2 27c6 289e
1 28a0 1 28a1
2 28a3 28a4 2
28c5 28c6 21 28a8
28a9 28aa 28ab 28ac
28ad 28ae 28af 28b0
28b1 28b2 28b3 28b4
28b5 28b6 28b7 28b8
28b9 28ba 28bb 28bc
28bd 28be 28bf 28c0
28c1 28c2 28c3 28c8
28c9 28ca 28cb 28cc
1 28d2 2 28d0
28d2 2 28d7 28dd
1 28e4 1 28df
2 28f7 28f9 3
28f5 28f6 28fb 2
2904 2906 2 2908
290a 2 290c 290e
2 2910 2912 2
2914 2916 3 291b
291c 291d 2 2918
291f 2 2903 2921
1 2923 1 2925
2 28ee 2926 1
292a 1 28e9 2
28e7 292e 1 2937
2 2933 2937 1
293e 1 2940 2
294a 294c 3 2948
2949 294e 2 2957
2959 2 295b 295d
2 295f 2961 1
2967 2 2969 296a
2 2963 296c 2
296e 2970 2 2972
2974 2 2976 2978
2 297a 297c 2
2956 297e 1 2980
1 2982 2 298c
298e 3 298a 298b
2990 2 2999 299b
2 2998 299d 1
299f 1 29a1 3
29a6 29a7 29a8 5
2931 2941 2983 29a2
29aa 3 29ae 29af
29b0 1 29b4 2
29b2 29b4 3 29b9
29ba 29bb 1 29bf
2 29bd 29bf 1
29cd 2 29cc 29cd
1 29d5 1 29db
2 29dd 29de 2
29ca 29df 1 29e6
1 29e1 2 29f9
29fb 3 29f7 29f8
29fd 2 2a06 2a08
2 2a0a 2a0c 2
2a0e 2a10 2 2a12
2a14 2 2a16 2a18
3 2a1d 2a1e 2a1f
2 2a1a 2a21 2
2a05 2a23 1 2a25
1 2a27 2 29f0
2a28 1 2a2c 1
29eb 2 29e9 2a30
1 2a33 2 2a37
2a36 4 28a5 28cf
2a38 2a3a 2 2a3d
2a3e 1 2a44 2
2a40 2a44 2 2a49
2a4c 1 2a4e 21
2a52 2a53 2a54 2a55
2a56 2a57 2a58 2a59
2a5a 2a5b 2a5c 2a5d
2a5e 2a5f 2a60 2a61
2a62 2a63 2a64 2a65
2a66 2a67 2a68 2a69
2a6a 2a6b 2a6c 2a6d
2a6e 2a6f 2a70 2a71
2a72 1 2a78 2
2a76 2a78 2 2a7c
2a7e 1 2a81 1
2a86 2 2a84 2a86
1 2a8a 2 2a8d
2a8c 2 2a92 2a93
1 2a95 2 2a8f
2a95 1 2a99 1
2a9b 4 2a4f 2a75
2a8e 2a9c 2 2a9e
2a9f 1 2aa1 8
25f0 2603 2612 2735
2738 273b 2aa0 2aa4
2 2aaa 2ab0 1
2ab7 1 2ab2 2
2aca 2acc 3 2ac8
2ac9 2ace 2 2ad7
2ad9 2 2adb 2add
2 2adf 2ae1 2
2ae3 2ae5 2 2ae7
2ae9 3 2aee 2aef
2af0 2 2aeb 2af2
2 2ad6 2af4 1
2af6 1 2af8 2
2ac1 2af9 1 2afd
1 2abc 2 2aba
2b01 1 2b0a 2
2b06 2b0a 1 2b10
2 2b0e 2b10 1
2b18 2 2b16 2b18
2 2b1c 2b1d 1
2b21 2 2b1f 2b21
2 2b31 2b33 3
2b2f 2b30 2b35 2
2b3e 2b40 2 2b42
2b44 2 2b46 2b48
1 2b4e 2 2b50
2b51 2 2b4a 2b53
2 2b55 2b57 2
2b59 2b5b 2 2b5d
2b5f 2 2b61 2b63
2 2b3d 2b65 1
2b67 1 2b69 2
2b73 2b75 3 2b71
2b72 2b77 2 2b80
2b82 2 2b7f 2b84
1 2b86 1 2b88
3 2b8d 2b8e 2b8f
3 2b6a 2b89 2b91
1 2b93 1 2b97
2 2b95 2b97 8
2bad 2bae 2baf 2bb0
2bb1 2bb2 2bb3 2bb4
1 2bbf 1 2bc5
2 2bc7 2bc8 1
2bd0 2 2bcc 2bd0
1 2bd5 1 2bd7
1 2bd9 2 2be1
2be2 1 2be6 2
2be4 2be6 1 2bed
2 2bef 2bf0 1
2bf4 2 2bf2 2bf4
1 2bfb 1 2bfd
2 2c02 2c03 1
2c07 2 2c05 2c07
1 2c0c 2 2c0a
2c0c 1 2c21 2
2c20 2c21 1 2c29
1 2c2f 2 2c31
2c32 2 2c1e 2c33
1 2c3a 1 2c35
2 2c4d 2c4f 3
2c4b 2c4c 2c51 2
2c5a 2c5c 2 2c5e
2c60 2 2c62 2c64
2 2c66 2c68 2
2c6a 2c6c 3 2c71
2c72 2c73 2 2c6e
2c75 2 2c59 2c77
1 2c79 1 2c7b
2 2c44 2c7c 1
2c80 1 2c3f 2
2c3d 2c84 1 2c87
1 2c8a 9 2c8b
2c8e 2c91 2c94 2c97
2c9a 2c9d 2ca0 2ca3
1 2ca5 1 2ca9
2 2ca7 2ca9 1
2cac 1 2cbf 2
2cbe 2cbf 1 2cc7
1 2ccd 2 2ccf
2cd0 2 2cbc 2cd1
1 2cd8 1 2cd3
2 2ceb 2ced 3
2ce9 2cea 2cef 2
2cf8 2cfa 2 2cfc
2cfe 2 2d00 2d02
2 2d04 2d06 2
2d08 2d0a 3 2d0f
2d10 2d11 2 2d0c
2d13 2 2cf7 2d15
1 2d17 1 2d19
2 2ce2 2d1a 1
2d1e 1 2cdd 2
2cdb 2d22 1 2d25
1 2d28 1 2d2a
1 2d2f 2 2d36
2d38 3 2d3a 2d3b
2d3c 1 2d3f 1
2d41 2 2d45 2d47
3 2d49 2d4a 2d4b
2 2d42 2d4e 1
2d50 1 2d52 2
2d59 2d5b 3 2d5d
2d5e 2d5f 1 2d62
1 2d64 1 2d66
1 2d6b 2 2d72
2d74 3 2d76 2d77
2d78 1 2d7b 1
2d7d 2 2d81 2d83
3 2d85 2d86 2d87
2 2d7e 2d8a 1
2d8c 1 2d8e 2
2d95 2d97 3 2d99
2d9a 2d9b 1 2d9e
1 2da0 1 2da2
1 2da7 2 2dae
2db0 3 2db2 2db3
2db4 1 2db7 1
2db9 2 2dbd 2dbf
3 2dc1 2dc2 2dc3
2 2dba 2dc6 1
2dc8 1 2dca 1
2dcf 2 2dd6 2dd8
3 2dda 2ddb 2ddc
1 2ddf 1 2de1
2 2de5 2de7 3
2de9 2dea 2deb 2
2de2 2dee 1 2df0
2 2df3 2df5 e
2bb5 2bc9 2bd8 2bfe
2ca6 2d29 2d51 2d65
2d8d 2da1 2dc9 2df1
2df8 2dfb 2 2e01
2e07 1 2e0e 1
2e09 2 2e21 2e23
3 2e1f 2e20 2e25
2 2e2e 2e30 2
2e32 2e34 2 2e36
2e38 2 2e3a 2e3c
2 2e3e 2e40 3
2e45 2e46 2e47 2
2e42 2e49 2 2e2d
2e4b 1 2e4d 1
2e4f 2 2e18 2e50
1 2e54 1 2e13
2 2e11 2e58 1
2e5f 2 2e5d 2e5f
1 2e74 2 2e73
2e74 1 2e7c 1
2e82 2 2e84 2e85
2 2e71 2e86 1
2e8d 1 2e88 2
2ea0 2ea2 3 2e9e
2e9f 2ea4 2 2ead
2eaf 2 2eb1 2eb3
2 2eb5 2eb7 2
2eb9 2ebb 2 2ebd
2ebf 3 2ec4 2ec5
2ec6 2 2ec1 2ec8
2 2eac 2eca 1
2ecc 1 2ece 2
2e97 2ecf 1 2ed3
1 2e92 2 2e90
2ed7 1 2eda 1
2edd 8 2b9c 2b9f
2ba2 2ba5 2baa 2dfe
2e5b 2ede 1 2ee0
1 2ee2 2 2ee8
2ee9 1 2eed 2
2eeb 2eed 2 2efe
2f03 1 2f0a 1
2f05 2 2f1d 2f1f
3 2f1b 2f1c 2f21
2 2f2a 2f2c 2
2f2e 2f30 2 2f32
2f34 2 2f36 2f38
2 2f3a 2f3c 3
2f41 2f42 2f43 2
2f3e 2f45 2 2f29
2f47 1 2f49 1
2f4b 2 2f14 2f4c
1 2f50 1 2f0f
2 2f0d 2f54 1
2f57 2 2f5c 2f5d
2 2f5f 2f60 1
2f61 1 2f63 2
2f78 2f7d 1 2f84
1 2f7f 2 2f97
2f99 3 2f95 2f96
2f9b 2 2fa4 2fa6
2 2fa8 2faa 2
2fac 2fae 2 2fb0
2fb2 2 2fb4 2fb6
3 2fbb 2fbc 2fbd
2 2fb8 2fbf 2
2fa3 2fc1 1 2fc3
1 2fc5 2 2f8e
2fc6 1 2fca 1
2f89 2 2f87 2fce
2 2fd4 2fd5 1
2fdb 2 2fd7 2fdb
1 2ff6 2 2ff5
2ff6 1 2ffe 1
3004 2 3006 3007
2 2ff3 3008 1
300f 1 300a 2
3022 3024 3 3020
3021 3026 2 302f
3031 2 3033 3035
2 3037 3039 2
303b 303d 2 303f
3041 3 3046 3047
3048 2 3043 304a
2 302e 304c 1
304e 1 3050 2
3019 3051 1 3055
1 3014 2 3012
3059 1 3064 2
3060 3064 1 307d
2 307c 307d 1
3085 1 308b 2
308d 308e 2 307a
308f 1 3096 1
3091 2 30a9 30ab
3 30a7 30a8 30ad
2 30b6 30b8 2
30ba 30bc 2 30be
30c0 2 30c2 30c4
2 30c6 30c8 3
30cd 30ce 30cf 2
30ca 30d1 2 30b5
30d3 1 30d5 1
30d7 2 30a0 30d8
1 30dc 1 309b
2 3099 30e0 1
30eb 2 30e7 30eb
1 30f8 2 30f7
30f8 1 3100 1
3106 2 3108 3109
2 30f5 310a 1
3111 1 310c 2
3124 3126 3 3122
3123 3128 2 3131
3133 2 3135 3137
2 3139 313b 2
313d 313f 2 3141
3143 3 3148 3149
314a 2 3145 314c
2 3130 314e 1
3150 1 3152 2
311b 3153 1 3157
1 3116 2 3114
315b 1 315e 1
3161 2 30e3 3162
1 3164 2 323e
3240 3 323c 323d
3242 2 324b 324d
2 324a 324f 1
3251 1 3253 7
2fe2 2fe7 305c 3165
3234 3254 3257 1
325b 2 3259 325b
2 3398 339a 3
3396 3397 339c 2
33a5 33a7 2 33a4
33a9 1 33ab 1
33ad 3 338e 33ae
33b1 1 33c8 2
33c7 33c8 1 33d0
1 33d6 2 33d8
33d9 2 33c5 33da
1 33e1 1 33dc
2 33f4 33f6 3
33f2 33f3 33f8 2
3401 3403 2 3405
3407 2 3409 340b
2 340d 340f 2
3411 3413 3 3418
3419 341a 2 3415
341c 2 3400 341e
1 3420 1 3422
2 33eb 3423 1
3427 1 33e6 2
33e4 342b 1 3448
2 3447 3448 1
3450 1 3456 2
3458 3459 2 3445
345a 1 3461 1
345c 2 3474 3476
3 3472 3473 3478
2 3481 3483 2
3485 3487 2 3489
348b 2 348d 348f
2 3491 3493 3
3498 3499 349a 2
3495 349c 2 3480
349e 1 34a0 1
34a2 2 346b 34a3
1 34a7 1 3466
2 3464 34ab 2
3674 3676 3 3672
3673 3678 2 3681
3683 2 3680 3685
1 3687 1 3689
7 33b7 33bc 342e
34ae 366a 368a 368d
2 368f 3690 1
3691 2 3693 3694
3b 4fd 51c 51f
522 525 528 52b
52e 531 534 537
53a 53d 540 543
546 549 54c 54f
552 555 558 55b
55e 561 564 5d7
6e6 764 775 86f
8de 8e1 8f5 902
916 923 95d 12b4
14a8 14c2 169a 1b83
1b88 1bb9 1bca 1beb
1bee 1bf1 25e0 25e7
25ec 2aa7 2b04 2b94
2ee1 2f64 2fd1 3695
2 36a2 36a4 3
36a0 36a1 36a6 2
36af 36b1 2 36ae
36b3 2 36ba 36be
2 36c0 36c2 2
36c4 36c8 2 36b9
36ca 2 36b5 36cc
1 36ce 3 36cf
36da 36de 1 3699
2 36f1 36f3 3
36ef 36f0 36f5 2
36fe 3700 2 36fd
3702 2 3709 370b
2 370d 370f 3
3714 3715 3716 2
3711 3718 2 3708
371a 2 3704 371c
1 371e 4 36e8
371f 3728 372c 1
3730 1 36e3 2
36e1 3734 6a 7b
82 89 90 97
9e a5 ac b3
ba c1 c8 cf
d6 dd e4 eb
f2 f9 100 107
10c 113 11a 121
128 12f 134 13b
142 149 150 157
15e 164 16a 170
176 17c 182 188
18e 194 19a 1a0
1a6 1ac 1b2 1b8
1be 1c4 1ca 1d0
1d6 1dc 1e2 1e8
1ee 1f4 1fa 200
206 20c 212 218
21e 224 22b 231
237 23d 244 24b
252 258 25e 265
26c 273 27a 281
288 28e 294 29a
2a0 2a6 2ac 2b2
2b8 2bf 2c5 2ca
2cf 2d4 2d9 2de
2e3 2e8 2ef 2ff
31a 324 32b 332
339 
1
4
0 
373b
0
1
a0
67
87
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 1 33 1 35 1 37
1 39 1 3b 3c 1 3e 3f
1 41 42 41 44 41 46 41
48 41 4a 41 4c 1 4e 1
50 51 50 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2a8 1 0
6b 1 0
2b 1 0
e6 1 0
25a 1 0
2ae 1 0
220 1 0
bc 1 0
5f 1 0
275 1 0
4b 1 0
28a 1 0
d8 1 0
2ea 1 0
2c1 1 0
1b4 1 0
21a 1 0
18a 1 0
8b 1 0
2a2 1 0
27 1 0
2d1 1 0
2f2 1 2
260 1 0
1f 1 0
53 1 0
202 1 0
a7 1 0
1b 1 0
1f6 1 0
2f 1 0
2b4 1 0
136 1 0
305 1 3
144 1 0
fb 1 0
2aa1 41 4e
172 1 0
d1 1 0
13d 1 0
178 1 0
63 1 0
43 1 0
23f 1 0
67 1 0
239 1 0
109 1 0
2c7 1 0
296 1 0
4f 1 0
2db 1 0
1d8 1 0
13 1 0
1ae 1 0
ed 1 0
b5 1 0
1a2 1 0
123 1 0
115 1 0
159 1 0
3f 1 0
24d 1 0
1de 1 0
226 1 0
10e 1 0
ae 1 0
3b 1 0
37 1 0
33 1 0
f 1 0
19c 1 0
31f 1 0
92 1 0
3 1 0
c3 1 0
283 1 0
160 1 0
5b 1 0
32d 1 0
14b 1 0
326 1 0
233 1 0
20e 1 0
12a 1 0
11c 1 0
290 1 0
190 1 0
1fc 1 0
2 0 1
1cc 1 0
1c0 1 0
23 1 0
84 1 0
102 1 0
29c 1 0
214 1 0
7 1 0
1f0 1 0
1a8 1 0
2d6 1 0
196 1 0
a0 1 0
246 1 0
1e4 1 0
17e 1 0
27c 1 0
26e 1 0
208 1 0
166 1 0
254 1 0
22d 1 0
16c 1 0
57 1 0
131 1 0
f4 1 0
7d 1 0
1c6 1 0
ca 1 0
47 1 0
184 1 0
df 1 0
2e0 1 0
1ea 1 0
17 1 0
2e5 1 0
152 1 0
2ba 1 0
1d2 1 0
99 1 0
2cc 1 0
76 1 0
1ba 1 0
b 1 0
334 1 0
267 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_2;
ALTER FUNCTION SP_SEARCH_2 COMPILE DEBUG;
/*#################################################################################################*/
/*#################################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_1
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_1 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_1 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2a9
2 :e:
1FUNCTION:
1SP_SEARCH_1:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_RES_ID:
1H_SECURITY_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_DAYS:
1H_DURATION:
1H_PARTICIPANT:
1H_PRIORITY:
1H_TOTAL:
1H_TOTPR:
1H_FROM_PRJ:
1H_SCHED_WORK:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_REC_STATUS:
1H_RES_COST:
1NUMBER:
1STMT:
17999:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_CRI_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_TASK_TYPE:
1H_TEMP_VAR:
1ID:
1I:
1II:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_1(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1109:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_1(110) :: cplan.sql(2655) :: :
1:
1GETTABLE:
10.00:
1IS NULL:
18:
1150:
1      RETURN_INVALID:: SP_SEARCH_1(151) :: cplan.sql(2696) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1153:
1                EXIT:: SP_SEARCH_1(154) :: cplan.sql(2699) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1160:
1      RETURN_INVALID:: SP_SEARCH_1(161) :: cplan.sql(2706) :: :
1163:
1                EXIT:: SP_SEARCH_1(164) :: cplan.sql(2709) :: :
1=:
15:
1170:
1      RETURN_INVALID:: SP_SEARCH_1(171) :: cplan.sql(2716) :: :
1INVALID_PARAMS:
1173:
1                EXIT:: SP_SEARCH_1(174) :: cplan.sql(2719) :: :
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1191:
1           EXCEPTION:: SP_SEARCH_1(192) :: cplan.sql(2737) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1198:
1      RETURN_INVALID:: SP_SEARCH_1(199) :: cplan.sql(2744) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1201:
1                EXIT:: SP_SEARCH_1(202) :: cplan.sql(2747) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1219:
1           EXCEPTION:: SP_SEARCH_1(220) :: cplan.sql(2765) :: :
1>:
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1!=:
1PROJECT_ID:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1252:
1           EXCEPTION:: SP_SEARCH_1(253) :: cplan.sql(2798) :: :
1B:
1TYPE_ID:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1SELECT B.TYPE_ID, B.TASK_TYPE, B.UNRESOLVED_START, B.UNRESOLVED_FINISH, B.PRO+
1JECT_ID,:n            COALESCE(A.MINUTE_PER_DAY, 480), COALESCE(A.MINUTE_PER_+
1WEEK, 2400), A.PRIORITY:n            INTO h_type, h_task_type, h_task_start_D+
1T, h_task_finish_DT, h_project_id,:n            h_per_day, h_per_week, h_prio+
1rity FROM TMT_WBS A, TMT_WBS B:n            WHERE B.ELEMENT_ID = h_task_id AN+
1D B.TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE+
12,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_+
1cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_+
1REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_c+
1nst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT+
1_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK) AND A.ELEMENT_ID = B.PROJECT_ID:
1271:
1           EXCEPTION:: SP_SEARCH_1(272) :: cplan.sql(2817) :: :
1SC_SQL_NO_DATA:
1WBS_ID:
1TMT_CRI:
1SELECT PROJECT_ID, WBS_ID INTO h_project_id, id:n            FROM TMT_CRI WHE+
1RE ELEMENT_ID = h_task_id:
1289:
1           EXCEPTION:: SP_SEARCH_1(290) :: cplan.sql(2835) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n               INTO h_per_day, h_per_week, h_priority:n               FRO+
1M TMT_WBS WHERE ELEMENT_ID = h_project_id:
1310:
1           EXCEPTION:: SP_SEARCH_1(311) :: cplan.sql(2856) :: :
1316:
1        RETURN_ERROR:: SP_SEARCH_1(317) :: cplan.sql(2862) :: :
1RECORD_NOT_FOUND:
1 ID:: :
1319:
1                EXIT:: SP_SEARCH_1(320) :: cplan.sql(2865) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1340:
1           EXCEPTION:: SP_SEARCH_1(341) :: cplan.sql(2886) :: :
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1358:
1           EXCEPTION:: SP_SEARCH_1(359) :: cplan.sql(2904) :: :
1STRCMP:
1L:
1365:
1        RETURN_ERROR:: SP_SEARCH_1(366) :: cplan.sql(2911) :: :
1LEV_LOCKED_BY_COPY:
1368:
1                EXIT:: SP_SEARCH_1(369) :: cplan.sql(2914) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1386:
1           EXCEPTION:: SP_SEARCH_1(387) :: cplan.sql(2932) :: :
1TMT_POOLS:
1SELECT 480, 2400 INTO h_per_day, h_per_week FROM TMT_POOLS WHERE ELEMENT_ID =+
1 h_project_id:
1401:
1           EXCEPTION:: SP_SEARCH_1(402) :: cplan.sql(2947) :: :
1407:
1        RETURN_ERROR:: SP_SEARCH_1(408) :: cplan.sql(2953) :: :
1410:
1                EXIT:: SP_SEARCH_1(411) :: cplan.sql(2956) :: :
1SC_FD_EFFORT_DRIVEN:
1SC_FIXED_DURATION:
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
17:
1FC_CALC_DURATION:
1437:
1      RETURN_INVALID:: SP_SEARCH_1(438) :: cplan.sql(2983) :: :
1440:
1                EXIT:: SP_SEARCH_1(441) :: cplan.sql(2986) :: :
1445:
1        RETURN_ERROR:: SP_SEARCH_1(446) :: cplan.sql(2991) :: :
1448:
1                EXIT:: SP_SEARCH_1(449) :: cplan.sql(2994) :: :
1*:
1100:
12:
13:
14:
1FC_DECLARE_PMO_TMP_SEARCH:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ASSIGNRESOURCE:
1SC_SRCH_PARTICIPANT:
1RECORD_ALREADY_ASSIGNED:
1496:
1        RETURN_ERROR:: SP_SEARCH_1(497) :: cplan.sql(3042) :: :
1499:
1                EXIT:: SP_SEARCH_1(500) :: cplan.sql(3045) :: :
1506:
1        RETURN_ERROR:: SP_SEARCH_1(507) :: cplan.sql(3052) :: :
1509:
1                EXIT:: SP_SEARCH_1(510) :: cplan.sql(3055) :: :
1MIN:
1BAK_START_DT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT MIN(BAK_START_DT), PMO_ORASTD.DAYS(h_start_date) - PMO_ORASTD.DAYS(MIN+
1(BAK_START_DT)):n         INTO h_start_DT, h_total :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE PROJECT_ID = h_project_id :n         AND TASK_ID = h_p+
1roject_id :n         AND RESOURCE_ID = h_res_id :n         AND RESOURCE_TYPE +
1= h_res_type:
1532:
1           EXCEPTION:: SP_SEARCH_1(533) :: cplan.sql(3078) :: :
1PROJECT_ASSIGNMENT_ID:
1SCHED_START:
1TO_DATE:
1SCHED_FINISH:
1SCHED_WORK:
1BIT_FLAG:
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, :n               CASE WHEN (TO_DAT+
1E(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AN+
1D TO_DATE(SubStr(SCHED_FINISH, 1, 10)) OR :n               TO_DATE(SubStr(h_f+
1inish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(Sub+
1Str(SCHED_FINISH, 1, 10))) AND :n               SCHED_WORK >= h_effort THEN 0+
1 ELSE 1 END,SCHED_WORK:n               INTO h_prj_assign_id, h_start_DT, h_to+
1tal, h_sched_work:n               FROM TASK_ASSIGNMENTS:n               WHERE+
1 TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_+
1FLAG = '2':
1564:
1           EXCEPTION:: SP_SEARCH_1(565) :: cplan.sql(3110) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_WORK:
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n                     CASE WHEN+
1 (TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, +
11, 10)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n                     +
1TO_DATE(SubStr(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, +
110)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n                     P+
1LANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                     INTO h_prj_as+
1sign_id, h_start_DT, h_total:n                     FROM TASK_ASSIGNMENTS:n   +
1                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RES+
1OURCE_TYPE='0' AND BIT_FLAG = '0':
1588:
1           EXCEPTION:: SP_SEARCH_1(589) :: cplan.sql(3134) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n                  CASE WHEN (T+
1O_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, +
110)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n                  TO_DAT+
1E(SubStr(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) A+
1ND TO_DATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n                  PLANNED_WO+
1RK >= h_effort THEN 0 ELSE 1 END:n                  INTO h_prj_assign_id, h_s+
1tart_DT, h_total:n                  FROM TASK_ASSIGNMENTS:n                  +
1WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND+
1 BIT_FLAG = '0':
1612:
1           EXCEPTION:: SP_SEARCH_1(613) :: cplan.sql(3158) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n               CASE WHEN(TO_DA+
1TE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10))+
1 AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n               TO_DATE(SubSt+
1r(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_D+
1ATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n               PLANNED_WORK >= h_ef+
1fort THEN 0 ELSE 1 END:n               INTO h_prj_assign_id, h_start_DT, h_to+
1tal:n               FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1634:
1           EXCEPTION:: SP_SEARCH_1(635) :: cplan.sql(3180) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n               INTO h_prj_assign_id, h_start_DT,h_total, h_sched_work :n   +
1            FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id +
1AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1654:
1           EXCEPTION:: SP_SEARCH_1(655) :: cplan.sql(3200) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                     INTO h_prj_assign_id, h_star+
1t_DT,h_total :n                     FROM TASK_ASSIGNMENTS:n                  +
1   WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' +
1AND BIT_FLAG = '0':
1675:
1           EXCEPTION:: SP_SEARCH_1(676) :: cplan.sql(3221) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1               INTO h_prj_assign_id, h_start_DT,h_total :n                  F+
1ROM TASK_ASSIGNMENTS:n                  WHERE TASK_ID=h_project_id AND RESOUR+
1CE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
1697:
1           EXCEPTION:: SP_SEARCH_1(698) :: cplan.sql(3243) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1            INTO h_prj_assign_id, h_start_DT,h_total :n               FROM TA+
1SK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_r+
1es_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1716:
1           EXCEPTION:: SP_SEARCH_1(717) :: cplan.sql(3262) :: :
1726:
1        RETURN_ERROR:: SP_SEARCH_1(727) :: cplan.sql(3272) :: :
1TASK_ASSIGNMENT_ERROR:
1729:
1                EXIT:: SP_SEARCH_1(730) :: cplan.sql(3275) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1DAY_YEAR:
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_+
1start_date, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1748:
1           EXCEPTION:: SP_SEARCH_1(749) :: cplan.sql(3294) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR >= TO_DATE(SubStr(h_start+
1_date, 1, 10)):
1767:
1           EXCEPTION:: SP_SEARCH_1(768) :: cplan.sql(3313) :: :
1775:
1        RETURN_ERROR:: SP_SEARCH_1(776) :: cplan.sql(3321) :: :
1778:
1                EXIT:: SP_SEARCH_1(779) :: cplan.sql(3324) :: :
1ISNOTPROJECTTYPE:
1786:
1        RETURN_ERROR:: SP_SEARCH_1(787) :: cplan.sql(3332) :: :
1789:
1                EXIT:: SP_SEARCH_1(790) :: cplan.sql(3335) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT NICK_NAME, PMO_ORASTD.JULIAN_DAY(h_start_DT), ACTIVE, COALESCE(PMO_ORA+
1STD.JULIAN_DAY(EFFECTIVE_DATE),0),COALESCE(PMO_ORASTD.JULIAN_DAY(DISCONTINUE_+
1DATE),0):n            INTO h_full_name, h_julian_day, h_active, h_j_efective_+
1date, h_j_disconti_date:n            FROM RESOURCES :n            WHERE RESOU+
1RCE_ID = h_res_id:
1810:
1           EXCEPTION:: SP_SEARCH_1(811) :: cplan.sql(3356) :: :
1817:
1        RETURN_ERROR:: SP_SEARCH_1(818) :: cplan.sql(3363) :: :
1820:
1                EXIT:: SP_SEARCH_1(821) :: cplan.sql(3366) :: :
1828:
1        RETURN_ERROR:: SP_SEARCH_1(829) :: cplan.sql(3374) :: :
1RESOURCE_NOT_ACTIVE:
1831:
1                EXIT:: SP_SEARCH_1(832) :: cplan.sql(3377) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1848:
1           EXCEPTION:: SP_SEARCH_1(849) :: cplan.sql(3394) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1865:
1           EXCEPTION:: SP_SEARCH_1(866) :: cplan.sql(3411) :: :
1872:
1        RETURN_ERROR:: SP_SEARCH_1(873) :: cplan.sql(3418) :: :
1875:
1                EXIT:: SP_SEARCH_1(876) :: cplan.sql(3421) :: :
1BAK_FINISH_DT:
1BAK_WORK:
1SELECT BAK_START_DT, CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN T+
1O_DATE(SubStr(BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10))+
1 AND BAK_WORK >= h_effort THEN 0 ELSE 1 END:n            INTO h_start_DT, h_t+
1otal :n            FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1':
1893:
1           EXCEPTION:: SP_SEARCH_1(894) :: cplan.sql(3439) :: :
1900:
1        RETURN_ERROR:: SP_SEARCH_1(901) :: cplan.sql(3446) :: :
1903:
1                EXIT:: SP_SEARCH_1(904) :: cplan.sql(3449) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1920:
1           EXCEPTION:: SP_SEARCH_1(921) :: cplan.sql(3466) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)) INTO h_start_DT:n            FROM DUAL:
1940:
1           EXCEPTION:: SP_SEARCH_1(941) :: cplan.sql(3486) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date:n            ELSE h_start_DT END:n           +
1 INTO h_start_DT:n            FROM DUAL:
1958:
1           EXCEPTION:: SP_SEARCH_1(959) :: cplan.sql(3504) :: :
110:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1FOUND:
1991:
1           EXCEPTION:: SP_SEARCH_1(992) :: cplan.sql(3537) :: :
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='1' WHERE RES_ID=h_res_id:
11010:
1           EXCEPTION:: SP_SEARCH_1(1011) :: cplan.sql(3556) :: :
11048:
1           EXCEPTION:: SP_SEARCH_1(1049) :: cplan.sql(3594) :: :
1LENGTH:
1TRUNC:
1/:
1WHILE:
1LOOP:
1COUNT:
1PROPOSED_START:
1SELECT COUNT(*), MIN(PROPOSED_START) INTO h_total, h_start_DT :n             +
1  FROM TASK_ASSIGNMENTS:n               WHERE PROJECT_ID = h_project_id AND T+
1ASK_ID = h_project_id:n               AND RESOURCE_ID = h_res_id AND RESOURCE+
1_TYPE = h_res_type:
11090:
1           EXCEPTION:: SP_SEARCH_1(1091) :: cplan.sql(3636) :: :
1',':
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, CASE WHEN TO_DATE(SubStr(h_start_d+
1ate, 1, 10)) >= TO_DATE(SubStr(SCHED_START, 1, 10)) AND:n                    +
1    TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(SCHED_FINISH, 1, 10+
1)) AND SCHED_WORK >= h_effort THEN 0 ELSE 1 END,SCHED_WORK:n                 +
1       INTO h_prj_assign_id, h_start_DT, h_total, h_sched_work:n             +
1           FROM TASK_ASSIGNMENTS:n                        WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '2':
11139:
1           EXCEPTION:: SP_SEARCH_1(1140) :: cplan.sql(3685) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1              TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_F+
1INISH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n              +
1                INTO h_prj_assign_id, h_start_DT, h_total :n                 +
1             FROM TASK_ASSIGNMENTS:n                              WHERE TASK_+
1ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG =+
1 '0':
11161:
1           EXCEPTION:: SP_SEARCH_1(1162) :: cplan.sql(3707) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1           TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINI+
1SH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                 +
1          INTO h_prj_assign_id, h_start_DT, h_total :n                       +
1    FROM TASK_ASSIGNMENTS:n                           WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11183:
1           EXCEPTION:: SP_SEARCH_1(1184) :: cplan.sql(3729) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1        TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH,+
1 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                    +
1    INTO h_prj_assign_id, h_start_DT, h_total FROM TASK_ASSIGNMENTS:n        +
1                WHERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n   +
1                     AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_F+
1LAG = '0':
11203:
1           EXCEPTION:: SP_SEARCH_1(1204) :: cplan.sql(3749) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n                        INTO h_prj_assign_id, h_start_DT,h_total, h_sched_w+
1ork FROM TASK_ASSIGNMENTS:n                        WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID=h_project_id:n                        AND RESOURCE_ID=h_res+
1_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
11223:
1           EXCEPTION:: SP_SEARCH_1(1224) :: cplan.sql(3769) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                              INTO h_prj_assign_i+
1d, h_start_DT,h_total FROM TASK_ASSIGNMENTS:n                              WH+
1ERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n                     +
1         AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11243:
1           EXCEPTION:: SP_SEARCH_1(1244) :: cplan.sql(3789) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n  +
1                         INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_A+
1SSIGNMENTS:n                           WHERE PROJECT_ID = h_project_id AND TA+
1SK_ID=h_project_id:n                           AND RESOURCE_ID=h_res_id AND R+
1ESOURCE_TYPE='0' AND BIT_FLAG = '0':
11265:
1           EXCEPTION:: SP_SEARCH_1(1266) :: cplan.sql(3811) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1                     INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_ASSIG+
1NMENTS:n                        WHERE PROJECT_ID = h_project_id AND TASK_ID=h+
1_project_id:n                        AND RESOURCE_ID=h_res_id AND RESOURCE_TY+
1PE='1' AND BIT_FLAG = '0':
11284:
1           EXCEPTION:: SP_SEARCH_1(1285) :: cplan.sql(3830) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_date, 1, 10)) AND TO_DATE(SubStr(h_+
1finish_DT, 1, 10)):
11311:
1           EXCEPTION:: SP_SEARCH_1(1312) :: cplan.sql(3857) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)):
11330:
1           EXCEPTION:: SP_SEARCH_1(1331) :: cplan.sql(3876) :: :
1CONTINUE0000:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)):n                  INTO h_start_DT:n                  FR+
1OM DUAL:
11362:
1           EXCEPTION:: SP_SEARCH_1(1363) :: cplan.sql(3908) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date ELSE h_start_DT END:n                  INTO h+
1_start_DT:n                  FROM DUAL:
11379:
1           EXCEPTION:: SP_SEARCH_1(1380) :: cplan.sql(3925) :: :
11412:
1           EXCEPTION:: SP_SEARCH_1(1413) :: cplan.sql(3958) :: :
11431:
1           EXCEPTION:: SP_SEARCH_1(1432) :: cplan.sql(3977) :: :
11467:
1           EXCEPTION:: SP_SEARCH_1(1468) :: cplan.sql(4013) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11497:
1           EXCEPTION:: SP_SEARCH_1(1498) :: cplan.sql(4043) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET SECURITY_ID = h_security_id, PARTICIPANT = h_+
1participant:n            WHERE RES_ASSIGNMENT_ID = h_assign_id:
11517:
1           EXCEPTION:: SP_SEARCH_1(1518) :: cplan.sql(4063) :: :
11525:
1        RETURN_ERROR:: SP_SEARCH_1(1526) :: cplan.sql(4071) :: :
11528:
1                EXIT:: SP_SEARCH_1(1529) :: cplan.sql(4074) :: :
1CANNOT_ASSIGN_TO_DEFAULT_CRI:
11533:
1        RETURN_ERROR:: SP_SEARCH_1(1534) :: cplan.sql(4079) :: :
11536:
1                EXIT:: SP_SEARCH_1(1537) :: cplan.sql(4082) :: :
1CANNOT_CHANGE_OBJECT_TYPE:
11542:
1        RETURN_ERROR:: SP_SEARCH_1(1543) :: cplan.sql(4088) :: :
11545:
1                EXIT:: SP_SEARCH_1(1546) :: cplan.sql(4091) :: :
11551:
1        RETURN_ERROR:: SP_SEARCH_1(1552) :: cplan.sql(4097) :: :
11554:
1                EXIT:: SP_SEARCH_1(1555) :: cplan.sql(4100) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0003:
1INSERT INTO PMO_TMP_CPLN_0003 SELECT RESOURCE_ID, RESOURCE_TYPE, :
1 MIN(PLANNED_START) AS PLANNED_START,  MAX(PLANNED_FINISH) AS PLANNED_FINISH,+
1 :
1 SUM(PLANNED_WORK) AS PLANNED_EFFORT,  MIN(SCHED_START) AS START_DATE,  :
1 MAX(SCHED_FINISH) AS FINISH_DATE,     SUM(SCHED_WORK) AS WORK,  :
1 SUM(ETC) AS REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=':
1' AND :
1      (RESOURCE_ID IN (':
1') OR RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID, RESOURCE_TYPE :
11588:
1           EXCEPTION:: SP_SEARCH_1(1589) :: cplan.sql(4134) :: :
1SQL :: :
1DELETE FROM PMO_TMP_CPLN_0002:
1INSERT INTO PMO_TMP_CPLN_0002 SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,MIN+
1(PLANNED_START) AS PRJ_PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,  SUM(PLANNED_WORK) AS PLANNED_REM+
1AINING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,        MAX(SCHED_FINISH) AS PRJ_SCHED_F+
1INISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING  :
1 FROM TASK_ASSIGNMENTS :
1 WHERE TASK_ID=':
1 (RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID :
11622:
1           EXCEPTION:: SP_SEARCH_1(1623) :: cplan.sql(4168) :: :
1FC_U_CREATETMPTABLE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME,RESOURCE_TYPE,TYPE_ID+
1,E_MAIL_ADDRESS,PLANNED_START,:
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,BEST_STAR+
1T,BEST_FINISH,:
1ASSIGNABLE,PLANNED,SCHED,WORK_EFFORT,PERIOD_AVAILABILITY,PROJECT_ASSIGNMENT_I+
1D,PRJ_PLANNED_START,:
1PRJ_PLANNED_FINISH,PLANNED_REMAINING,PRJ_SCHED_START,PRJ_SCHED_FINISH,SCHED_R+
1EMAINING,REGULAR_COST,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE, EXTERNAL_ID) :
1SELECT DISTINCT r.RESOURCE_ID,r.FULL_NAME AS ELEMENT_NAME,'0',:
1CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL THEN 185 ELSE 13 END AS TYPE_ID,:
1r.E_MAIL_ADDRESS, a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.STAR+
1T_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE, rs.FINISH_DATE, rs.ASSIGNABLE, rs.PLANNED, rs.SCHED, rs.PROPOS+
1ED, (rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PROJECT_ASSIGNMENT_ID,tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLAN+
1NED_REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, r.EXTERNAL_ID :
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='0' A+
1ND a.RESOURCE_ID=r.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=':
1' AND r.RESOURCE_ID = pa.RESOURCE_ID :
1LEFT OUTER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=':
1' AND r.RESOURCE_ID = ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON r.RESOURCE_ID = tb.PROJECT_ASSIGNMENT+
1_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON r.RESOURCE_ID=rs.RES_ID WHERE r.RESOURCE+
1_ID IN (':
1') :
1UNION ALL :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME AS ELEMENT_NAME, '1', 41 AS TYP+
1E_ID,:
1'', a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FINI+
1SH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE , rs.FINISH_DATE, rs.ASSIGNABLE ,rs.PLANNED,rs.SCHED, rs.PROPOS+
1ED,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, '' AS EXTERNAL_ID :
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='1' AN+
1D p.PROFILE_ID=a.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID= ':
1' AND p.PROFILE_ID = pa.RESOURCE_ID :
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID LEFT OUTER JOIN PMO_TMP_S+
1EARCH rs ON a.RESOURCE_ID=rs.RES_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON p.PROFILE_ID = tb.PROJECT_ASSIGNMENT_+
1ID :
1WHERE p.PROFILE_ID IN (':
1ORDER BY TYPE_ID,ELEMENT_NAME:
11679:
1           EXCEPTION:: SP_SEARCH_1(1680) :: cplan.sql(4225) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID AS TYPE_ID, :
1 T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STA+
1RT_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR,T.PLANNED AS PLANNED_W+
1ORK,:
1 T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT,T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T.R+
1EGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE, T.EXTERNAL_ID :
1 FROM PMO_TMP_CPLN01_TEMP T:
1 LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID WHERE T.RESOURCE+
1_TYPE IN ('0') :
1 UNION ALL :
1 SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1 '' AS E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T+
1.START_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR, :
1 T.PLANNED AS PLANNED_WORK,T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT, :
1 T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING,'' AS OBJECTIVES,'' AS RANK, :
1 T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1  T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T+
1.REGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE, T.EXTERNAL_ID :
1 FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID+
1=rs.RES_ID :
1 WHERE T.RESOURCE_TYPE = '1' ORDER BY TYPE_ID,ELEMENT_NAME:
1DELETE FROM PMO_TMP_CPLN_0001:
1INSERT INTO PMO_TMP_CPLN_0001 :
1SELECT  RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PLANNED_FINISH,   SUM(PLANNED_WORK) AS PLANNED_EFFORT+
1, :
1 MIN(SCHED_START) AS START_DATE,          MAX(SCHED_FINISH) AS FINISH_DATE, :
1 SUM(SCHED_WORK) AS WORK,                 SUM(ETC) AS REMAINING :
1 RESOURCE_ID IN (':
1') AND PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID:
11735:
1           EXCEPTION:: SP_SEARCH_1(1736) :: cplan.sql(4281) :: :
1INSERT INTO PMO_TMP_CPLN_0002 :
1SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,      MIN(PLANNED_START) AS PRJ_P+
1LANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH, SUM(PLANNED_WORK) AS PLANNED_REMA+
1INING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,       MAX(SCHED_FINISH) AS PRJ_SCHED_FI+
1NISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE TASK_ID=':
1' AND RESOURCE_ID IN (':
1') GROUP BY RESOURCE_ID:
11767:
1           EXCEPTION:: SP_SEARCH_1(1768) :: cplan.sql(4313) :: :
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,PROJECT_A+
1SSIGNMENT_ID,PRJ_PLANNED_START,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE, EXTERNAL_ID):
1SELECT DISTINCT r.RESOURCE_ID, r.FULL_NAME,'0',CASE WHEN ta.TSK_ASSIGNMENT_ID+
1 IS NuLL THEN 185 ELSE 13 END ,:
1tb.PROJECT_ASSIGNMENT_ID, tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLA+
1NNED_REMAINING,:
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON a.RESOURCE_ID=r.RESOU+
1RCE_ID :
1WHERE r.RESOURCE_ID IN (':
1'):
11805:
1           EXCEPTION:: SP_SEARCH_1(1806) :: cplan.sql(4351) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID, :
1T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STAR+
1T_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK, :
1rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID, T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID :
1ORDER BY ELEMENT_NAME:
1SELECT RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1       MAX(PLANNED_FINISH) AS PLANNED_FINISH,    SUM(PLANNED_WORK) AS PLANNED+
1_EFFORT, :
1       MIN(SCHED_START) AS START_DATE,           MAX(SCHED_FINISH) AS FINISH_+
1DATE, :
1       SUM(SCHED_WORK) AS WORK,                  SUM(ETC) AS REMAINING :
1 WHERE PROJECT_ID=':
1'        AND :
1       RESOURCE_ID IN (':
1')   AND :
1       PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID :
11852:
1           EXCEPTION:: SP_SEARCH_1(1853) :: cplan.sql(4398) :: :
1SELECT    RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,          MIN(PLANNED_START) A+
1S PRJ_PLANNED_START, :
1          MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,     SUM(PLANNED_WORK) AS+
1 PLANNED_REMAINING, :
1          MIN(SCHED_START) AS PRJ_SCHED_START,           MAX(SCHED_FINISH) AS+
1 PRJ_SCHED_FINISH, :
1          SUM(SCHED_WORK) AS SCHED_REMAINING  :
1') GROUP BY RESOURCE_ID :
11884:
1           EXCEPTION:: SP_SEARCH_1(1885) :: cplan.sql(4430) :: :
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE) :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME ,'1', 41 ,:
1'' , a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FIN+
1ISH_DATE, a.WORK, a.REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE :
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON p.PROFILE_ID=a.RESOURC+
1E_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID :
11922:
1           EXCEPTION:: SP_SEARCH_1(1923) :: cplan.sql(4468) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT+
1, :
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1  :
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=+
1rs.RES_ID :
11944:
1                EXIT:: SP_SEARCH_1(1945) :: cplan.sql(4490) :: :
11947:
1                EXIT:: SP_SEARCH_1(1948) :: cplan.sql(4493) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11955:
1           EXCEPTION:: SP_SEARCH_1(1956) :: cplan.sql(4501) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11967:
1           EXCEPTION:: SP_SEARCH_1(1968) :: cplan.sql(4513) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
330d
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d a0 6e d a0 4d d :4 a0
51 a5 b a5 b d a0 51
d a0 51 d a0 51 d a0
7e b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a a 10 :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c a0
51 d a0 b7 a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
:3 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 d a0
7e b4 2e 5a a0 6e d b7
19 3c :3 a0 :2 51 a5 b d :3 a0
:2 51 a5 b d :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e :4 a0 :2 51
a5 b :2 51 a5 b d :3 a0 6b
:3 51 a0 a5 b d :3 a0 51 a5
b a5 b 7e 51 b4 2e :d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :45 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
:7 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e 5a
a0 51 d b7 19 3c :b a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 a0 51 d b7
:2 19 3c a0 51 d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 6e a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 :b a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c b7 :2 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e 52 10 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 a0
51 d b7 19 3c a0 51 d
a0 51 d b7 a0 7e 51 b4
2e :2 a0 d :2 a0 d :6 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :3 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 19 3c :2 a0
d a0 7e b4 2e 5a a0 6e
d b7 19 3c b7 :2 a0 d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d b7 19 3c b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 51 d a0 b7 :2 a0 51
a5 b 7e 51 b4 2e a0 51
d a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
a0 51 d a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e a0 51
d b7 :2 19 3c b7 19 3c b7
:2 19 3c :2 a0 b4 2e d a0 6e
d a0 6e d :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :8 a0 a5 b d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 51 a5 b :2 a0 a5 57
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 19 3c
a0 4d d :14 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 d b7 19 3c b7 19 3c
a0 51 d a0 51 d a0 7e
51 b4 2e :2 a0 :2 51 a5 b 7e
6e b4 2e :22 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :20 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 51 d b7 :2 19 3c a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :20 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :20 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:2 a0 :2 51 a5 b 7e 6e b4 2e
:19 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 51 d :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 :14 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 51 d
4f b7 :2 19 3c a0 b7 :2 a0 6b
a0 7e a0 6b b4 2e 5a :17 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :17 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 a0
7e b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e a 10 a0 7e
51 b4 2e a0 51 d :f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
:2 19 3c a0 51 d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e 5a
:3 a0 51 a5 b a5 b 5a 7e
51 b4 2e a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e :3 a0
7e a0 b4 2e :2 51 a5 b d
:15 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 :2 51 a5
b 7e 6e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a a 10 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :c a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :3 a0 7e
a0 b4 2e :2 51 a5 b d :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :14 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e :a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :a a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
51 d :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c :1e a0 :5 51 a5 b d a0
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 19 3c b7 :2 a0 d :2 a0 d
:2 a0 :2 51 a5 b 7e 6e b4 2e
:3 a0 6b d b7 :4 a0 51 a5 b
:2 a0 6b a5 b d b7 :2 19 3c
:1e a0 :5 51 a5 b d a0 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :2 19 3c
b7 :3 a0 a5 b 51 a5 b 7e
51 b4 2e a0 51 d b7 :5 a0
a5 b 51 a5 b 7e 51 b4
2e 5a 7e 51 b4 2e a5 b
d b7 :2 19 3c a0 7e 51 b4
2e a0 51 d :3 a0 51 a5 b
a0 7e a0 b4 2e 82 a0 51
d :3 a0 6b :2 51 :2 a0 51 a5 b
7e 51 b4 2e 7e 51 b4 2e
a0 a5 b d :3 a0 6b :2 51 :2 a0
51 a5 b 7e 51 b4 2e 7e
51 b4 2e 7e 51 b4 2e a0
a5 b d :2 a0 d a0 51 d
a0 51 d :2 a0 d :e a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 a0
51 d :2 a0 6b :2 a0 a5 b 7e
51 b4 2e :2 a0 d b7 19 3c
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e :3 a0 6b d :3 a0 a5
b 51 a5 b 7e 51 b4 2e
:2 a0 d b7 :3 a0 7e 6e b4 2e
:2 51 a5 b d :3 a0 7e a0 b4
2e :2 51 a5 b d b7 :2 19 3c
b7 :3 a0 a5 b 51 a5 b 7e
51 b4 2e :2 a0 d b7 :3 a0 7e
6e b4 2e :2 51 a5 b d :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 :2 19 3c b7 :2 19 3c a0 51
d a0 51 d :2 a0 51 a5 b
7e 51 b4 2e a0 7e 51 b4
2e :2 a0 :2 51 a5 b 7e 6e b4
2e :1c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 51 d :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :1a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 51
d b7 :2 19 3c a0 b7 :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 :1a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:1c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :1b a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :16 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 51 d 4f b7 :2 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :19 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:19 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 a0 7e b4
2e 5a a0 7e 51 b4 2e a0
51 d :f a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 51 d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :3 a0 51 a5 b 7e 51 b4
2e d a0 3b b7 19 3c b7
19 3c a0 51 d b7 :2 19 3c
b7 :3 a0 51 a5 b 7e 51 b4
2e d a0 3b b7 :2 19 3c :2 a0
d a0 51 d :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 19 3c :1e a0 :5 51 a5 b d
a0 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :4 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 3c a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 d :2 a0 :2 51 a5 b 7e 6e
b4 2e :3 a0 6b d b7 :3 a0 51
a5 b d b7 :2 19 3c :1e a0 :5 51
a5 b d a0 7e 51 b4 2e
:4 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 19 3c :3 a0 51
a5 b 7e 51 b4 2e d 93
4f b0 46 b7 a0 47 b7 19
3c b7 :2 19 3c a0 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :7 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 :2 a0
7e a0 6b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 19 :2 a0
7e a0 6b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
b7 19 3c :3 a0 a5 b 51 a5
b 7e 51 b4 2e 5a :3 a0 a5
b 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 6e 11e 11d :2 a0
6b 51 d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6e 11e 11d :2 a0 6b 51 d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e d a0 b7 :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
6e 11e 11d :2 a0 6b 51 d a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d :3 a0 11e 11d a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6e 11e 11d
:2 a0 6b 51 d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
d b7 19 :2 a0 6e 11e 11d :2 a0
6b 51 d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6e 11e 11d :2 a0 6b 51 d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 b4 2e d a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d :3 a0 11e 11d a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
d b7 :2 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b a0 a5 b 65
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
330d
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 235
223 202 227 228 230 222 252 240
21f 244 245 24d 23f 26f 25d 23c
261 262 26a 25c 28b 27a 27e 286
259 2a3 292 296 29e 279 2c0 2ae
276 2b2 2b3 2bb 2ad 2dd 2cb 2aa
2cf 2d0 2d8 2ca 2fa 2e8 2c7 2ec
2ed 2f5 2e7 317 305 2e4 309 30a
312 304 334 322 301 326 327 32f
321 351 33f 31e 343 344 34c 33e
36d 35c 360 33b 368 35b 389 378
37c 358 384 377 3a5 394 398 374
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 431 420 424 400 42c 41f
44d 43c 440 41c 448 43b 469 458
45c 438 464 457 485 474 478 454
480 473 4a1 490 494 470 49c 48f
4bd 4ac 4b0 48c 4b8 4ab 4d9 4c8
4cc 4a8 4d4 4c7 4f5 4e4 4e8 4c4
4f0 4e3 511 500 504 4e0 50c 4ff
52d 51c 520 4fc 528 51b 549 538
53c 518 544 537 565 554 558 534
560 553 581 570 574 550 57c 56f
59d 58c 590 56c 598 58b 5b9 5a8
5ac 588 5b4 5a7 5d5 5c4 5c8 5a4
5d0 5c3 5f1 5e0 5e4 5c0 5ec 5df
60d 5fc 600 5dc 608 5fb 629 618
61c 5f8 624 617 645 634 638 614
640 633 661 650 654 630 65c 64f
67e 66c 64c 670 671 679 66b 69b
689 668 68d 68e 696 688 6b7 6a6
6aa 685 6b2 6a5 6d4 6c2 6a2 6c6
6c7 6cf 6c1 6f0 6df 6e3 6be 6eb
6de 70d 6fb 6db 6ff 700 708 6fa
72a 718 6f7 71c 71d 725 717 747
735 714 739 73a 742 734 763 752
756 731 75e 751 77f 76e 772 74e
77a 76d 79b 78a 78e 76a 796 789
7b8 7a6 786 7aa 7ab 7b3 7a5 7d5
7c3 7a2 7c7 7c8 7d0 7c2 7f1 7e0
7e4 7bf 7ec 7df 80d 7fc 800 7dc
808 7fb 82a 818 7f8 81c 81d 825
817 846 835 839 814 841 834 862
851 855 831 85d 850 87e 86d 871
84d 879 86c 89a 889 88d 869 895
888 8b6 8a5 8a9 8b1 885 8d5 8bd
8c1 8c5 8c8 8d0 8a4 8dc 8e0 8a1
8e4 8e8 8ec 8ef 8f4 8f5 1 8f7
8fc 900 904 907 90c 910 914 917
91c 91d 91f 924 927 92b 92c 931
936 939 93e 93f 944 947 94b 94c
951 954 959 95a 95f 962 967 968
96d 970 975 976 97b 97e 982 983
988 98b 990 991 996 999 99e 99f
9a4 9a7 9ac 9ad 9b2 9b5 9b9 9ba
9bf 9c2 9c7 9c8 9cd 9d0 9d5 9d6
9db 9de 9e2 9e6 9ea 9eb 9ed 9f2
9f3 9f5 9f6 9fb 9fe a03 a04 a09
a0c a10 a14 a18 a19 a1b a20 a21
a23 a24 a29 a2c a31 a32 a37 a3a
a3e a42 a46 a47 a49 a4e a4f a51
a52 a57 a5a a5f a60 a65 a68 a6c
a70 a74 a75 a77 a7c a7d a7f a80
a85 a88 a8d a8e a93 a96 a9a a9e
aa2 aa3 aa5 aaa aab aad aae ab3
ab6 abb abc ac1 ac4 ac8 acc ad0
ad1 ad3 ad8 ad9 adb adc ae1 ae4
ae9 aea aef af2 af6 afa afe aff
b01 b06 b07 b09 b0a b0f b12 b17
b18 b1d b20 b24 b28 b2c b2d b2f
b34 b35 b37 b38 b3d b40 b45 b46
b4b b4e b52 b56 b5a b5b b5d b62
b63 b65 b66 b6b b6e b73 b74 b79
b7c b80 b84 b88 b89 b8b b90 b91
b93 b94 b99 b9c ba1 ba2 ba7 baa
baf bb0 bb5 bb8 bbc bbd bc2 bc5
bca bcb bd0 bd3 bd8 bd9 bde be1
be6 be7 bec bef bf3 bf4 bf9 bfc
c01 c02 c07 c0a c0f c10 c15 c16
c1b c1d c21 c24 c28 c2c c2f c33
c37 c3a c3d c42 c45 c48 c4b c4c
c51 c52 1 c54 c59 c5d c61 c64
c69 c6e c71 c75 c76 c7b c7c c81
c83 c87 c8a c8e c92 c96 c9a c9e
ca2 ca6 caa cae cb2 cb6 cba cbe
cc2 cc6 cca cce cd2 cd6 cda cde
ce2 ce6 cea cee cf2 cf6 cfa cfe
d02 d06 d0a d0e d12 d16 d1a d1e
d22 d26 d2a d2e d32 d36 d3a d3e
d42 d47 d4b d4f d50 d54 d58 d5c
d60 d64 d67 d68 d6a d6b d6d d71
d75 d78 d7c d80 d83 d87 d8b d8e
d92 d96 d99 d9a d9f da2 da6 daa
dad db1 db5 db8 dbb dc0 dc3 dc6
dc9 dca dcf dd0 1 dd2 dd7 ddb
ddf de2 de7 dec def df3 df4 df9
dfc e01 e02 e07 e0a e0f e10 e15
e18 e1c e20 e24 e28 e2b e2c e2e
e33 e34 e36 e37 e3c e3d e42 e44
e48 e4b e4f e53 e56 e5a e5e e61
e64 e69 e6c e6f e72 e73 e78 e79
1 e7b e80 e84 e88 e8b e90 e95
e98 e9c e9d ea2 ea3 ea8 eaa eae
eb1 eb5 eb9 ebc ec0 ec4 ec7 ecb
ecc ed1 ed3 ed7 eda ede ee1 ee2
ee7 eea eee ef2 ef5 ef9 efd f00
f03 f08 f0b f0e f11 f12 f17 f18
1 f1a f1f f23 f27 f2a f2f f34
f37 f3b f3c f41 f44 f49 f4a f4f
f52 f57 f58 f5d f60 f64 f68 f6c
f70 f73 f74 f76 f7b f7c f7e f7f
f84 f85 f8a f8c f90 f93 f97 f9b
f9e fa2 fa6 fa9 fac fb1 fb4 fb7
fba fbb fc0 fc1 1 fc3 fc8 fcc
fd0 fd3 fd8 fdd fe0 fe4 fe5 fea
feb ff0 ff2 ff6 ff9 ffd 1001 1004
1008 100c 100f 1013 1014 1019 101b 101f
1022 1026 102a 102d 102e 1030 1033 1036
1037 103c 1040 1044 1047 1048 104a 104d
1050 1051 1 1056 105b 105f 1063 1066
1067 1069 106c 106f 1070 1 1075 107a
107e 1082 1085 1089 108d 1090 1093 1098
109b 109e 10a1 10a2 10a7 10a8 1 10aa
10af 10b3 10b7 10ba 10bf 10c4 10c7 10cb
10cc 10d1 10d4 10d9 10da 10df 10e2 10e7
10e8 10ed 10f0 10f4 10f8 10fc 1100 1103
1104 1106 110b 110c 110e 110f 1114 1115
111a 111c 1120 1123 1127 112b 112e 1132
1136 1139 113c 1141 1144 1147 114a 114b
1150 1151 1 1153 1158 115c 1160 1163
1168 116d 1170 1174 1175 117a 117b 1180
1182 1186 1189 118d 1191 1194 1198 119c
119f 11a3 11a4 11a9 11ab 11af 11b2 11b6
11b9 11ba 11bf 11c2 11c5 11c9 11cc 11cd
11d2 11d5 1 11d8 11dd 11e1 11e5 11e9
11ed 11f1 11f5 11f9 11fd 1209 120d 1211
1214 1218 121c 121e 1222 1226 122a 122d
1231 1235 1237 1238 123d 1 1241 1245
1249 124c 1250 1254 1258 125c 125f 1263
1267 126a 126d 1272 1275 1278 127b 127c
1281 1282 1 1284 1289 128d 1291 1294
1299 129e 12a1 12a5 12a6 12ab 12ae 12b3
12b4 12b9 12bc 12c1 12c2 12c7 12ca 12ce
12cf 12d4 12d7 12dc 12dd 12e2 12e5 12e9
12ed 12f0 12f3 12f4 12f6 12f7 12fc 12fd
1302 1304 1308 130b 130d 1311 1313 131f
1321 1323 1324 1329 132d 132f 133b 133d
1341 1345 1348 134c 134f 1353 1356 1357
135c 135f 1363 1367 136a 136b 136d 1370
1373 1374 1379 1 137c 1381 1385 1389
138c 1390 1394 1397 139a 139f 13a2 13a5
13a8 13a9 13ae 13af 1 13b1 13b6 13ba
13be 13c1 13c6 13cb 13ce 13d2 13d3 13d8
13db 13e0 13e1 13e6 13e9 13ee 13ef 13f4
13f7 13fb 13ff 1403 1407 140a 140b 140d
1412 1413 1415 1416 141b 141c 1421 1423
1427 142a 142e 1432 1435 1439 143d 1440
1443 1448 144b 144e 1451 1452 1457 1458
1 145a 145f 1463 1467 146a 146f 1474
1477 147b 147c 1481 1482 1487 1489 148d
1490 1494 1498 149b 149f 14a3 14a6 14aa
14ab 14b0 14b2 14b6 14b9 14bd 14c0 14c4
14c8 14ca 14ce 14d1 14d2 14d7 14da 14dd
14e1 14e4 14e5 14ea 14ed 1 14f0 14f5
14f9 14fd 1501 150d 1511 1515 1518 151c
1520 1522 1526 152a 152e 1531 1535 1539
153b 153c 1541 1 1545 1549 154d 1550
1554 1558 155c 1560 1563 1567 156b 156e
1571 1576 1579 157c 157f 1580 1585 1586
1 1588 158d 1591 1595 1598 159d 15a2
15a5 15a9 15aa 15af 15b2 15b7 15b8 15bd
15c0 15c5 15c6 15cb 15ce 15d2 15d3 15d8
15db 15e0 15e1 15e6 15e9 15ed 15f1 15f4
15f7 15f8 15fa 15fb 1600 1601 1606 1608
160c 160f 1611 1615 1617 1623 1625 1627
1628 162d 1631 1633 163f 1641 1643 1647
164b 164e 1652 1656 165a 165e 1661 1662
1667 166a 166e 1673 1677 1679 167d 1680
1684 1688 168c 168f 1692 1693 1695 1699
169d 16a1 16a5 16a8 16ab 16ac 16ae 16b2
16b6 16ba 16be 16c2 16c6 16c9 16ca 16cc
16cf 16d2 16d3 16d8 16dc 16e0 16e4 16e8
16eb 16ee 16ef 16f1 16f4 16f7 16f8 16fa
16fe 1702 1706 170a 170d 1710 1713 1716
171a 171b 171d 1721 1725 1729 172d 1730
1731 1733 1734 1736 1739 173c 173d 1742
1746 174a 174e 1752 1756 175a 175e 1762
1766 176a 176e 1772 1776 1782 1786 178a
178d 1791 1795 1797 179b 179f 17a3 17a6
17aa 17ae 17b0 17b1 17b6 1 17ba 17be
17c2 17c5 17c9 17cd 17d1 17d5 17d8 17dc
17e0 17e3 17e6 17eb 17ee 17f1 17f4 17f5
17fa 17fb 1 17fd 1802 1806 180a 180d
1812 1817 181a 181e 181f 1824 1827 182c
182d 1832 1835 183a 183b 1840 1843 1847
1848 184d 1850 1855 1856 185b 185e 1862
1866 1869 186c 186d 186f 1870 1875 1876
187b 187d 1881 1884 1886 188a 188c 1898
189a 189c 189d 18a2 18a6 18a8 18b4 18b6
18b8 18bc 18c0 18c4 18c8 18cc 18d0 18d4
18d8 18dc 18e0 18e4 18e8 18ec 18f0 18f4
18f8 18fc 1900 1904 1908 190c 1910 1914
1918 191c 1920 1924 1928 192c 1930 1934
1938 193c 1940 1944 1948 194c 1950 1954
1958 195c 1960 1964 1968 196c 1970 1974
1978 197c 1980 1984 1988 198c 1990 1994
1998 199c 19a0 19a4 19a8 19ac 19b0 19b4
19b8 19bc 19c0 19c4 19c8 19cc 19d8 19dc
19e0 19e3 19e7 19eb 19ed 19f1 19f5 19f9
19fc 1a00 1a04 1a06 1a07 1a0c 1 1a10
1a14 1a18 1a1b 1a1f 1a23 1a27 1a2b 1a2e
1a32 1a36 1a39 1a3c 1a41 1a44 1a47 1a4a
1a4b 1a50 1a51 1 1a53 1a58 1a5c 1a60
1a63 1a68 1a6d 1a70 1a74 1a75 1a7a 1a7d
1a82 1a83 1a88 1a8b 1a90 1a91 1a96 1a99
1a9d 1a9e 1aa3 1aa6 1aab 1aac 1ab1 1ab4
1ab8 1abc 1abf 1ac2 1ac3 1ac5 1ac6 1acb
1acc 1ad1 1ad3 1ad7 1ada 1adc 1ae0 1ae2
1aee 1af0 1af2 1af3 1af8 1afc 1afe 1b0a
1b0c 1b0e 1b12 1b16 1b19 1b1d 1b21 1b24
1b28 1b2b 1b2f 1b32 1b33 1b38 1b3b 1b3f
1b43 1b47 1b4b 1b4f 1b53 1b57 1b63 1b67
1b6b 1b6e 1b72 1b76 1b78 1b7c 1b80 1b84
1b87 1b8b 1b8f 1b91 1b92 1b97 1 1b9b
1b9f 1ba3 1ba6 1baa 1bae 1bb2 1bb6 1bb9
1bbd 1bc1 1bc4 1bc7 1bcc 1bcf 1bd2 1bd5
1bd6 1bdb 1bdc 1 1bde 1be3 1be7 1beb
1bee 1bf3 1bf8 1bfb 1bff 1c00 1c05 1c08
1c0d 1c0e 1c13 1c16 1c1b 1c1c 1c21 1c24
1c28 1c29 1c2e 1c31 1c36 1c37 1c3c 1c3f
1c43 1c47 1c4a 1c4d 1c4e 1c50 1c51 1c56
1c57 1c5c 1c5e 1c62 1c65 1c67 1c6b 1c6d
1c79 1c7b 1c7d 1c7e 1c83 1c87 1c89 1c95
1c97 1c9b 1c9f 1ca2 1ca6 1ca9 1cad 1cb0
1cb1 1cb6 1cb9 1cbd 1cc0 1cc1 1cc6 1cc9
1ccd 1cd0 1cd4 1cd6 1cda 1cdd 1ce1 1ce5
1ce9 1ced 1cf1 1cf5 1cf9 1cfd 1d01 1d05
1d09 1d15 1d19 1d1d 1d20 1d24 1d28 1d2a
1d2e 1d32 1d36 1d39 1d3d 1d41 1d43 1d44
1d49 1 1d4d 1d51 1d55 1d58 1d5c 1d60
1d64 1d68 1d6b 1d6f 1d73 1d76 1d79 1d7e
1d81 1d84 1d87 1d88 1d8d 1d8e 1 1d90
1d95 1d99 1d9d 1da0 1da5 1daa 1dad 1db1
1db2 1db7 1dba 1dbf 1dc0 1dc5 1dc8 1dcd
1dce 1dd3 1dd6 1dda 1ddb 1de0 1de3 1de8
1de9 1dee 1df1 1df5 1df9 1dfc 1dff 1e00
1e02 1e03 1e08 1e09 1e0e 1e10 1e14 1e17
1e19 1e1d 1e1f 1e2b 1e2d 1e2f 1e30 1e35
1e39 1e3b 1e47 1e49 1e4b 1e4f 1e53 1e56
1e5a 1e5e 1e61 1e64 1e69 1e6c 1e6f 1e72
1e73 1e78 1e79 1 1e7b 1e80 1e84 1e88
1e8b 1e90 1e95 1e98 1e9c 1e9d 1ea2 1ea5
1eaa 1eab 1eb0 1eb3 1eb8 1eb9 1ebe 1ec1
1ec5 1ec9 1ecd 1ed1 1ed4 1ed5 1ed7 1edc
1edd 1edf 1ee0 1ee5 1ee8 1eed 1eee 1ef3
1ef6 1efb 1efc 1f01 1f04 1f08 1f09 1f0e
1f11 1f16 1f17 1f1c 1f1d 1f22 1f24 1f28
1f2b 1f2f 1f33 1f36 1f3a 1f3e 1f41 1f44
1f49 1f4c 1f4f 1f52 1f53 1f58 1f59 1
1f5b 1f60 1f64 1f68 1f6b 1f70 1f75 1f78
1f7c 1f7d 1f82 1f83 1f88 1f8a 1f8e 1f91
1f95 1f99 1f9c 1fa0 1fa4 1fa7 1fab 1faf
1fb0 1fb5 1fb7 1fbb 1fbf 1fc2 1fc4 1fc8
1fcb 1fcf 1fd1 1fd5 1fd9 1fdc 1fe0 1fe3
1fe7 1feb 1fef 1ff3 1ff7 1ffb 2007 200b
200f 2012 2016 201a 201c 2020 2024 2028
202b 202f 2033 2035 2036 203b 1 203f
2043 2047 204a 204e 2052 2056 205a 205d
2061 2065 2068 206b 2070 2073 2076 2079
207a 207f 2080 1 2082 2087 208b 208f
2092 2097 209c 209f 20a3 20a4 20a9 20ac
20b1 20b2 20b7 20ba 20bf 20c0 20c5 20c8
20cc 20cd 20d2 20d5 20da 20db 20e0 20e3
20e7 20eb 20ee 20f1 20f2 20f4 20f5 20fa
20fb 2100 2102 2106 2109 210b 210f 2111
211d 211f 2121 2122 2127 212b 212d 2139
213b 213f 2143 2146 2147 2149 214c 214f
2150 2155 2159 215d 2161 2165 2169 2175
2179 217d 2180 2184 2188 218a 218e 2192
2196 2199 219d 21a1 21a3 21a4 21a9 1
21ad 21b1 21b5 21b8 21bc 21c0 21c4 21c8
21cb 21cf 21d3 21d6 21d9 21de 21e1 21e4
21e7 21e8 21ed 21ee 1 21f0 21f5 21f9
21fd 2200 2205 220a 220d 2211 2212 2217
221a 221f 2220 2225 2228 222d 222e 2233
2236 223a 223b 2240 2243 2248 2249 224e
2251 2255 2259 225c 225f 2260 2262 2263
2268 2269 226e 2270 2274 2277 2279 227d
227f 228b 228d 228f 2290 2295 2299 229b
22a7 22a9 22ad 22b1 22b4 22b8 22bd 22be
22c0 22c3 22c6 22c7 22cc 22d0 22d4 22d7
22db 22df 22e2 22e5 22ea 22ed 22f0 22f3
22f4 22f9 22fa 1 22fc 2301 2305 2309
230c 2311 2316 2319 231d 231e 2323 2326
232b 232c 2331 2334 2339 233a 233f 2342
2346 234a 234e 2352 2355 2356 2358 235d
235e 2360 2361 2366 2369 236e 236f 2374
2377 237c 237d 2382 2385 2389 238a 238f
2392 2397 2398 239d 239e 23a3 23a5 23a9
23ac 23b0 23b4 23b7 23bb 23bf 23c2 23c5
23ca 23cd 23d0 23d3 23d4 23d9 23da 1
23dc 23e1 23e5 23e9 23ec 23f1 23f6 23f9
23fd 23fe 2403 2404 2409 240b 240f 2412
2416 241a 241d 2421 2425 2428 242c 2430
2431 2436 2438 243c 243f 2441 2445 2448
244a 244e 2452 2456 245a 245e 2462 2466
246a 246e 2472 2476 2482 2486 248a 248d
2491 2495 2497 249b 249f 24a3 24a6 24aa
24ae 24b0 24b1 24b6 1 24ba 24be 24c2
24c5 24c9 24cd 24d1 24d5 24d8 24dc 24e0
24e3 24e6 24eb 24ee 24f1 24f4 24f5 24fa
24fb 1 24fd 2502 2506 250a 250d 2512
2517 251a 251e 251f 2524 2527 252c 252d
2532 2535 253a 253b 2540 2543 2547 2548
254d 2550 2555 2556 255b 255e 2562 2566
2569 256c 256d 256f 2570 2575 2576 257b
257d 2581 2584 2586 258a 258c 2598 259a
259c 259d 25a2 25a6 25a8 25b4 25b6 25ba
25be 25c1 25c5 25c8 25cc 25cf 25d0 25d5
25d8 25dc 25e0 25e4 25e8 25ec 25f8 25fc
2600 2603 2607 260b 260d 2611 2615 2619
261c 2620 2624 2626 2627 262c 1 2630
2634 2638 263b 263f 2643 2647 264b 264e
2652 2656 2659 265c 2661 2664 2667 266a
266b 2670 2671 1 2673 2678 267c 2680
2683 2688 268d 2690 2694 2695 269a 269d
26a2 26a3 26a8 26ab 26b0 26b1 26b6 26b9
26bd 26be 26c3 26c6 26cb 26cc 26d1 26d4
26d8 26dc 26df 26e2 26e3 26e5 26e6 26eb
26ec 26f1 26f3 26f7 26fa 26fc 2700 2702
270e 2710 2712 2713 2718 271c 271e 272a
272c 2730 2734 2737 273b 273e 2742 2745
2746 274b 274e 2752 2756 2759 275d 2761
2764 2767 276c 276f 2772 2775 2776 277b
277c 1 277e 2783 2787 278b 278e 2793
2798 279b 279f 27a0 27a5 27a8 27ad 27ae
27b3 27b6 27bb 27bc 27c1 27c4 27c8 27cc
27d0 27d4 27d7 27d8 27da 27df 27e0 27e2
27e3 27e8 27eb 27f0 27f1 27f6 27f9 27fe
27ff 2804 2807 280b 280c 2811 2814 2819
281a 281f 2820 2825 2827 282b 282e 2832
2836 2839 283d 2841 2844 2847 284c 284f
2852 2855 2856 285b 285c 1 285e 2863
2867 286b 286e 2873 2878 287b 287f 2880
2885 2886 288b 288d 2891 2894 2898 289c
289f 28a3 28a7 28aa 28ae 28b2 28b3 28b8
28ba 28be 28c1 28c3 28c7 28ca 28cc 28d0
28d4 28d7 28db 28df 28e2 28e3 28e5 28e9
28ec 28f0 28f3 28f4 28f9 28fd 2901 2904
2905 2907 290b 290e 2912 2915 2916 1
291b 2920 2923 2927 292b 292e 292f 2931
2934 2937 2938 293d 1 2940 2945 2949
294d 2950 2951 2953 2957 295a 295e 2961
2962 2967 296b 296f 2972 2973 2975 2979
297c 2980 2983 2984 1 2989 298e 2992
2995 2999 299b 299f 29a2 29a6 29a9 29ad
29b1 29b4 29b8 29ba 29be 29c1 29c4 29c5
29ca 29ce 29d2 29d6 29da 29de 29e2 29e6
29ea 29ee 29f2 29f6 29fa 29fd 29fe 2a00
2a04 2a08 2a0b 2a0c 2a0e 2a12 2a16 2a19
2a1a 2a1c 2a20 2a24 2a27 2a28 2a2a 2a2e
2a32 2a35 2a36 2a38 2a3c 2a40 2a43 2a44
2a46 2a4a 2a4e 2a51 2a52 2a54 2a58 2a5c
2a5f 2a60 2a62 2a66 2a6a 2a6e 2a6f 2a71
2a75 2a79 2a7d 2a80 2a81 2a83 2a87 2a8a
2a8e 2a91 2a92 2a97 2a9b 2a9f 2aa2 2aa6
2aaa 2aad 2ab0 2ab5 2ab8 2abb 2abe 2abf
2ac4 2ac5 1 2ac7 2acc 2ad0 2ad4 2ad7
2adc 2ae1 2ae4 2ae8 2ae9 2aee 2af1 2af6
2af7 2afc 2aff 2b04 2b05 2b0a 2b0d 2b11
2b15 2b19 2b1d 2b20 2b21 2b23 2b28 2b29
2b2b 2b2c 2b31 2b32 2b37 2b39 2b3d 2b40
2b44 2b48 2b4b 2b4f 2b53 2b56 2b59 2b5e
2b61 2b64 2b67 2b68 2b6d 2b6e 1 2b70
2b75 2b79 2b7d 2b80 2b85 2b8a 2b8d 2b91
2b92 2b97 2b98 2b9d 2b9f 2ba3 2ba6 2baa
2bae 2bb1 2bb5 2bb9 2bbc 2bc0 2bc1 2bc6
2bca 2bcc 2bd0 2bd4 2bd7 2bd8 2bda 2bdd
2be0 2be1 2be6 2bea 2bee 2bf1 2bf5 2bf9
2bfc 2bff 2c04 2c07 2c0a 2c0d 2c0e 2c13
2c14 1 2c16 2c1b 2c1f 2c23 2c26 2c2b
2c30 2c33 2c37 2c38 2c3d 2c40 2c45 2c46
2c4b 2c4e 2c53 2c54 2c59 2c5c 2c60 2c64
2c68 2c69 2c6b 2c70 2c71 2c73 2c74 2c79
2c7c 2c81 2c82 2c87 2c8a 2c8f 2c90 2c95
2c98 2c9c 2c9d 2ca2 2ca5 2caa 2cab 2cb0
2cb1 2cb6 2cb8 2cbc 2cbf 2cc3 2cc7 2cca
2cce 2cd2 2cd5 2cd8 2cdd 2ce0 2ce3 2ce6
2ce7 2cec 2ced 1 2cef 2cf4 2cf8 2cfc
2cff 2d04 2d09 2d0c 2d10 2d11 2d16 2d17
2d1c 2d1e 2d22 2d25 2d29 2d2d 2d30 2d34
2d38 2d3b 2d3c 2d3e 2d42 2d46 2d47 2d4c
2d4e 2d52 2d56 2d59 2d5d 2d61 2d65 2d69
2d6c 2d6d 2d72 2d75 2d79 2d7e 2d82 2d84
2d88 2d8b 2d8d 2d91 2d95 2d99 2d9d 2da1
2da4 2da5 2da7 2daa 2dad 2dae 2db3 2db7
2dbb 2dbf 2dc2 2dc3 2dc5 2dc8 2dcc 2dd0
2dd3 2dd4 2dd6 2dd7 2ddc 2de0 2de2 2de6
2de9 2deb 2def 2df3 2df6 2dfa 2dfe 2e01
2e02 2e04 2e07 2e0a 2e0b 2e10 2e13 2e17
2e1b 2e1e 2e1f 2e21 2e24 2e27 2e28 2e2d
1 2e30 2e35 2e39 2e3d 2e40 2e41 2e43
2e46 2e49 2e4a 2e4f 2e52 2e56 2e5a 2e5d
2e5e 2e60 2e63 2e66 2e67 2e6c 1 2e6f
2e74 2e78 2e7b 2e7f 2e83 2e85 2e89 2e8d
2e90 2e91 2e93 2e96 2e99 2e9a 2e9f 2ea3
2ea6 2eaa 2eae 2eb0 2eb4 2eb8 2ebc 2ebf
2ec0 2ec2 2ec5 2ec8 2ec9 2ece 2ed1 2ed5
2ed9 2edc 2edd 2edf 2ee2 2ee5 2ee6 2eeb
1 2eee 2ef3 2ef7 2efa 2efe 2f02 2f04
2f08 2f0c 2f10 2f13 2f14 2f16 2f19 2f1c
2f1d 2f22 2f26 2f29 2f2d 2f2f 2f33 2f37
2f3a 2f3c 2f40 2f43 2f45 2f49 2f4d 2f50
2f54 2f58 2f59 2f5e 2f62 2f66 2f6b 2f6f
2f73 2f78 2f7c 2f80 2f84 2f88 2f8b 2f8f
2f93 2f97 2f9a 2f9b 2f9d 2fa1 2fa5 2fa8
2fa9 2fab 2fae 2fb1 2fb2 2fb4 2fb8 2fbc
2fc0 2fc4 2fc8 2fcb 2fcc 2fce 2fd2 2fd6
2fd9 2fda 2fdc 2fe0 2fe4 2fe8 2feb 2fec
2fee 2ff1 2ff4 2ff5 2ffa 2ffe 3002 3006
300a 300e 3012 3016 301a 301b 301d 3021
3025 3029 302c 302d 302f 3033 3036 303a
303d 303e 3043 3047 304b 304e 304f 3051
3054 3057 3058 305d 3061 3065 3069 306c
3070 3072 3076 3079 307d 3081 3084 3088
308c 308f 3092 3097 309a 309d 30a0 30a1
30a6 30a7 1 30a9 30ae 30b2 30b6 30b9
30be 30c3 30c6 30ca 30cb 30d0 30d3 30d8
30d9 30de 30e1 30e6 30e7 30ec 30ef 30f3
30f7 30fb 30fc 30fe 3103 3104 3106 3107
310c 310f 3114 3115 311a 311d 3122 3123
3128 312b 312f 3130 3135 3138 313d 313e
3143 3144 3149 314b 314f 3152 3156 315a
315d 3161 3165 3168 316b 3170 3173 3176
3179 317a 317f 3180 1 3182 3187 318b
318f 3192 3197 319c 319f 31a3 31a4 31a9
31aa 31af 31b1 31b5 31b8 31bc 31c0 31c3
31c7 31cb 31ce 31cf 31d1 31d5 31d9 31da
31df 31e1 31e5 31e8 31ec 31f0 31f3 31f4
31f6 31f9 31fc 31fd 3202 3206 320a 320d
320e 3210 3213 3216 3217 1 321c 3221
3225 3229 322c 3230 3234 3237 323a 323f
3242 3245 3248 3249 324e 324f 1 3251
3256 325a 325e 3261 3266 326b 326e 3272
3273 3278 327b 3280 3281 3286 3289 328e
328f 3294 3297 329b 329f 32a3 32a4 32a6
32ab 32ac 32ae 32af 32b4 32b7 32bc 32bd
32c2 32c5 32ca 32cb 32d0 32d3 32d7 32d8
32dd 32e0 32e5 32e6 32eb 32ec 32f1 32f3
32f7 32fa 32fe 3302 3305 3309 330d 3310
3313 3318 331b 331e 3321 3322 3327 3328
1 332a 332f 3333 3337 333a 333f 3344
3347 334b 334c 3351 3352 3357 3359 335d
3360 3364 3368 336b 336f 3373 3376 3377
3379 337d 3381 3382 3387 3389 338d 3390
3394 3395 3399 339d 33a1 33a5 33a9 33ad
33b1 33b5 33b9 33bd 33c1 33c5 33c9 33cd
33d1 33d5 33d9 33dd 33e1 33e5 33e9 33f5
33f9 33fd 3400 3404 3408 340a 340e 3412
3416 3419 341d 3421 3423 3424 3429 1
342d 3431 3435 3438 343c 3440 3444 3448
344b 344f 3453 3456 3459 345e 3461 3464
3467 3468 346d 346e 1 3470 3475 3479
347d 3480 3485 348a 348d 3491 3492 3497
349a 349f 34a0 34a5 34a8 34ad 34ae 34b3
34b6 34ba 34bb 34c0 34c3 34c8 34c9 34ce
34d1 34d5 34d9 34dc 34df 34e0 34e2 34e3
34e8 34e9 34ee 34f0 34f4 34f7 34f9 34fd
34ff 350b 350d 350f 3510 3515 3519 351b
3527 3529 352d 3531 3534 3538 353b 353f
3542 3543 3548 354b 354f 3552 3553 3558
355b 1 355e 3563 3567 356a 356e 3572
3576 3579 357a 357c 357f 3582 3583 3588
358c 3590 3594 3596 359a 359d 359f 35a3
35a6 35aa 35ad 35b1 35b5 35b8 35bc 35c0
35c3 35c6 35c7 35cc 35d0 35d4 35d7 35da
35db 35dd 35e0 35e5 35e6 35eb 35ef 35f3
35f7 35fb 35ff 3603 3607 360b 360f 3613
3617 361b 361f 3623 3627 362b 362f 3633
3637 363b 363f 3643 3647 364b 364f 3653
3657 365b 365f 3663 3667 366b 366f 3673
367f 3683 3687 368a 368e 3692 3694 3698
369c 36a0 36a3 36a7 36ab 36ad 36ae 36b3
1 36b7 36bb 36bf 36c2 36c6 36ca 36ce
36d2 36d5 36d9 36dd 36e0 36e3 36e8 36eb
36ee 36f1 36f2 36f7 36f8 1 36fa 36ff
3703 3707 370a 370f 3714 3717 371b 371c
3721 3724 3729 372a 372f 3732 3737 3738
373d 3740 3744 3745 374a 374d 3752 3753
3758 375b 375f 3763 3766 3769 376a 376c
376d 3772 3773 3778 377a 377e 3781 3783
3787 3789 3795 3797 3799 379a 379f 37a3
37a5 37b1 37b3 37b7 37bb 37be 37c2 37c5
37c9 37cc 37cd 37d2 37d5 37d9 37dc 37e0
37e4 37e8 37eb 37ec 37ee 37f1 37f4 37f5
37fa 37fd 3801 3805 3808 3809 380b 380e
3811 3812 3817 1 381a 381f 3823 3827
382b 382f 3833 3837 383b 383f 3843 3847
384b 384f 3853 3857 385b 385f 3863 3867
386b 386f 3873 3877 387b 387f 3883 3887
388b 388f 3893 3897 389b 389f 38ab 38af
38b3 38b6 38ba 38be 38c0 38c4 38c8 38cc
38cf 38d3 38d7 38d9 38da 38df 1 38e3
38e7 38eb 38ee 38f2 38f6 38fa 38fe 3901
3905 3909 390c 390f 3914 3917 391a 391d
391e 3923 3924 1 3926 392b 392f 3933
3936 393b 3940 3943 3947 3948 394d 3950
3955 3956 395b 395e 3963 3964 3969 396c
3970 3971 3976 3979 397e 397f 3984 3987
398b 398f 3992 3995 3996 3998 3999 399e
399f 39a4 39a6 39aa 39ad 39af 39b3 39b5
39c1 39c3 39c5 39c6 39cb 39cf 39d1 39dd
39df 39e1 39e5 39e8 39ec 39ee 39f2 39f6
39f9 39fd 39ff 3a03 3a07 3a0a 3a0e 3a11
3a15 3a18 3a19 3a1e 3a21 3a25 3a29 3a2c
3a2d 3a2f 3a32 3a35 3a36 3a3b 1 3a3e
3a43 3a47 3a4b 3a4f 3a53 3a57 3a5b 3a5f
3a63 3a67 3a6b 3a6f 3a73 3a77 3a7b 3a7f
3a83 3a87 3a8b 3a8f 3a93 3a97 3a9b 3a9f
3aa3 3aa7 3aab 3aaf 3ab3 3ab7 3abb 3abf
3ac3 3acf 3ad3 3ad7 3ada 3ade 3ae2 3ae4
3ae8 3aec 3af0 3af3 3af7 3afb 3afd 3afe
3b03 1 3b07 3b0b 3b0f 3b12 3b16 3b1a
3b1e 3b22 3b25 3b29 3b2d 3b30 3b33 3b38
3b3b 3b3e 3b41 3b42 3b47 3b48 1 3b4a
3b4f 3b53 3b57 3b5a 3b5f 3b64 3b67 3b6b
3b6c 3b71 3b74 3b79 3b7a 3b7f 3b82 3b87
3b88 3b8d 3b90 3b94 3b95 3b9a 3b9d 3ba2
3ba3 3ba8 3bab 3baf 3bb3 3bb6 3bb9 3bba
3bbc 3bbd 3bc2 3bc3 3bc8 3bca 3bce 3bd1
3bd3 3bd7 3bd9 3be5 3be7 3be9 3bea 3bef
3bf3 3bf5 3c01 3c03 3c05 3c09 3c0d 3c10
3c12 3c16 3c1a 3c1e 3c22 3c26 3c2a 3c2e
3c32 3c36 3c3a 3c3e 3c42 3c46 3c4a 3c4e
3c52 3c56 3c5a 3c5e 3c62 3c66 3c6a 3c6e
3c72 3c76 3c7a 3c7e 3c82 3c86 3c8a 3c8e
3c92 3c9e 3ca2 3ca6 3ca9 3cad 3cb1 3cb3
3cb7 3cbb 3cbf 3cc2 3cc6 3cca 3ccc 3ccd
3cd2 1 3cd6 3cda 3cde 3ce1 3ce5 3ce9
3ced 3cf1 3cf4 3cf8 3cfc 3cff 3d02 3d07
3d0a 3d0d 3d10 3d11 3d16 3d17 1 3d19
3d1e 3d22 3d26 3d29 3d2e 3d33 3d36 3d3a
3d3b 3d40 3d43 3d48 3d49 3d4e 3d51 3d56
3d57 3d5c 3d5f 3d63 3d64 3d69 3d6c 3d71
3d72 3d77 3d7a 3d7e 3d82 3d85 3d88 3d89
3d8b 3d8c 3d91 3d92 3d97 3d99 3d9d 3da0
3da2 3da6 3da8 3db4 3db6 3db8 3db9 3dbe
3dc2 3dc4 3dd0 3dd2 3dd4 3dd8 3ddc 3ddf
3de1 3de5 3de9 3dec 3def 3df0 3df2 3df5
3dfa 3dfb 3e00 3e04 3e08 3e0c 3e10 3e14
3e18 3e1c 3e20 3e24 3e28 3e2c 3e30 3e34
3e38 3e3c 3e40 3e44 3e48 3e4c 3e50 3e54
3e58 3e5c 3e60 3e64 3e70 3e74 3e78 3e7b
3e7f 3e83 3e85 3e89 3e8d 3e91 3e94 3e98
3e9c 3e9e 3e9f 3ea4 1 3ea8 3eac 3eb0
3eb3 3eb7 3ebb 3ebf 3ec3 3ec6 3eca 3ece
3ed1 3ed4 3ed9 3edc 3edf 3ee2 3ee3 3ee8
3ee9 1 3eeb 3ef0 3ef4 3ef8 3efb 3f00
3f05 3f08 3f0c 3f0d 3f12 3f15 3f1a 3f1b
3f20 3f23 3f28 3f29 3f2e 3f31 3f35 3f36
3f3b 3f3e 3f43 3f44 3f49 3f4c 3f50 3f54
3f57 3f5a 3f5b 3f5d 3f5e 3f63 3f64 3f69
3f6b 3f6f 3f72 3f74 3f78 3f7a 3f86 3f88
3f8a 3f8b 3f90 3f94 3f96 3fa2 3fa4 3fa8
3fac 3faf 3fb3 3fb6 3fba 3fbd 3fbe 3fc3
3fc6 3fca 3fcd 3fd1 3fd5 3fd9 3fdc 3fdd
3fdf 3fe2 3fe5 3fe6 3feb 3fee 3ff2 3ff6
3ff9 3ffa 3ffc 3fff 4002 4003 4008 1
400b 4010 4014 4018 401c 4020 4024 4028
402c 4030 4034 4038 403c 4040 4044 4048
404c 4050 4054 4058 405c 4060 406c 4070
4074 4077 407b 407f 4081 4085 4089 408d
4090 4094 4098 409a 409b 40a0 1 40a4
40a8 40ac 40af 40b3 40b7 40bb 40bf 40c2
40c6 40ca 40cd 40d0 40d5 40d8 40db 40de
40df 40e4 40e5 1 40e7 40ec 40f0 40f4
40f7 40fc 4101 4104 4108 4109 410e 4111
4116 4117 411c 411f 4124 4125 412a 412d
4131 4132 4137 413a 413f 4140 4145 4148
414c 4150 4153 4156 4157 4159 415a 415f
4160 4165 4167 416b 416e 4170 4174 4176
4182 4184 4186 4187 418c 4190 4192 419e
41a0 41a2 41a6 41a9 41ad 41af 41b1 41b5
41b9 41bc 41c0 41c2 41c6 41ca 41cd 41d1
41d4 41d8 41db 41dc 41e1 41e4 41e8 41ec
41f0 41f4 41f8 41fc 4200 4204 4208 420c
4210 4214 4218 421c 4220 4224 4228 422c
4230 4234 4238 423c 4240 424c 4250 4254
4257 425b 425f 4261 4265 4269 426d 4270
4274 4278 427a 427b 4280 1 4284 4288
428c 428f 4293 4297 429b 429f 42a2 42a6
42aa 42ad 42b0 42b5 42b8 42bb 42be 42bf
42c4 42c5 1 42c7 42cc 42d0 42d4 42d7
42dc 42e1 42e4 42e8 42e9 42ee 42f1 42f6
42f7 42fc 42ff 4304 4305 430a 430d 4311
4312 4317 431a 431f 4320 4325 4328 432c
4330 4333 4336 4337 4339 433a 433f 4340
4345 4347 434b 434e 4350 4354 4356 4362
4364 4366 4367 436c 4370 4372 437e 4380
4382 4386 438a 438d 438f 4393 4397 439b
439f 43a3 43a7 43ab 43af 43b3 43b7 43bb
43bf 43c3 43c7 43cb 43cf 43d3 43d7 43db
43df 43e3 43e7 43eb 43f7 43fb 43ff 4402
4406 440a 440c 4410 4414 4418 441b 441f
4423 4425 4426 442b 1 442f 4433 4437
443a 443e 4442 4446 444a 444d 4451 4455
4458 445b 4460 4463 4466 4469 446a 446f
4470 1 4472 4477 447b 447f 4482 4487
448c 448f 4493 4494 4499 449c 44a1 44a2
44a7 44aa 44af 44b0 44b5 44b8 44bc 44bd
44c2 44c5 44ca 44cb 44d0 44d3 44d7 44db
44de 44e1 44e2 44e4 44e5 44ea 44eb 44f0
44f2 44f6 44f9 44fb 44ff 4501 450d 450f
4511 4512 4517 451b 451d 4529 452b 452d
4531 4535 4538 453a 453e 4542 4545 4549
454d 4550 4554 4557 455b 455e 455f 4564
4567 456b 456f 4572 4573 4575 4578 457b
457c 4581 4585 4589 458c 4590 4594 4597
459a 459f 45a2 45a5 45a8 45a9 45ae 45af
1 45b1 45b6 45ba 45be 45c1 45c6 45cb
45ce 45d2 45d3 45d8 45db 45e0 45e1 45e6
45e9 45ee 45ef 45f4 45f7 45fb 45ff 4603
4607 460a 460b 460d 4612 4613 4615 4616
461b 461e 4623 4624 4629 462c 4631 4632
4637 463a 463e 463f 4644 4647 464c 464d
4652 4653 4658 465a 465e 4661 4665 4669
466c 4670 4674 4677 467a 467f 4682 4685
4688 4689 468e 468f 1 4691 4696 469a
469e 46a1 46a6 46ab 46ae 46b2 46b3 46b8
46b9 46be 46c0 46c4 46c7 46cb 46cf 46d2
46d6 46da 46dd 46e1 46e5 46e6 46eb 46ef
46f1 46f5 46f8 46f9 46fe 4701 4705 4709
470c 470d 470f 4712 4715 4716 1 471b
4720 4724 4727 472a 472b 4730 4734 4737
473b 473f 4743 4747 474b 474f 4753 4757
475b 475f 4763 4767 476b 476f 4773 4777
4783 4787 478b 478e 4792 4796 4798 479c
47a0 47a4 47a7 47ab 47af 47b1 47b2 47b7
1 47bb 47bf 47c3 47c6 47ca 47ce 47d2
47d6 47d9 47dd 47e1 47e4 47e7 47ec 47ef
47f2 47f5 47f6 47fb 47fc 1 47fe 4803
4807 480b 480e 4813 4818 481b 481f 4820
4825 4828 482d 482e 4833 4836 483b 483c
4841 4844 4848 4849 484e 4851 4856 4857
485c 485f 4863 4867 486a 486d 486e 4870
4871 4876 4877 487c 487e 4882 4885 4887
488b 488d 4899 489b 489d 489e 48a3 48a7
48a9 48b5 48b7 48b9 48bd 48c0 48c4 48c8
48cc 48d0 48d4 48d8 48dc 48e0 48e4 48e8
48ec 48f0 48f4 4900 4904 4908 490b 490f
4913 4915 4919 491d 4921 4924 4928 492c
492e 492f 4934 1 4938 493c 4940 4943
4947 494b 494f 4953 4956 495a 495e 4961
4964 4969 496c 496f 4972 4973 4978 4979
1 497b 4980 4984 4988 498b 4990 4995
4998 499c 499d 49a2 49a5 49aa 49ab 49b0
49b3 49b8 49b9 49be 49c1 49c5 49c6 49cb
49ce 49d3 49d4 49d9 49dc 49e0 49e4 49e7
49ea 49eb 49ed 49ee 49f3 49f4 49f9 49fb
49ff 4a02 4a04 4a08 4a0a 4a16 4a18 4a1a
4a1b 4a20 4a24 4a26 4a32 4a34 4a36 4a3a
4a3e 4a41 4a45 4a49 4a4c 4a4d 4a4f 4a53
4a56 4a5a 4a5d 4a5e 4a60 4a61 4a66 4a6a
4a6e 4a71 4a75 4a79 4a7c 4a7f 4a84 4a87
4a8a 4a8d 4a8e 4a93 4a94 1 4a96 4a9b
4a9f 4aa3 4aa6 4aab 4ab0 4ab3 4ab7 4ab8
4abd 4ac0 4ac5 4ac6 4acb 4ace 4ad3 4ad4
4ad9 4adc 4ae0 4ae4 4ae8 4aec 4aef 4af0
4af2 4af7 4af8 4afa 4afb 4b00 4b03 4b08
4b09 4b0e 4b11 4b16 4b17 4b1c 4b1f 4b23
4b24 4b29 4b2c 4b31 4b32 4b37 4b38 4b3d
4b3f 4b43 4b46 4b4a 4b4e 4b51 4b55 4b59
4b5c 4b5f 4b64 4b67 4b6a 4b6d 4b6e 4b73
4b74 1 4b76 4b7b 4b7f 4b83 4b86 4b8b
4b90 4b93 4b97 4b98 4b9d 4b9e 4ba3 4ba5
4ba9 4bac 4bb0 4bb4 4bb7 4bbb 4bbf 4bc2
4bc6 4bca 4bcb 4bd0 4bd2 4bd6 4bd9 4bdb
4bdf 4be3 4be6 4bea 4bed 4bf1 4bf5 4bf7
4bfb 4bff 4c02 4c03 4c05 4c08 4c0b 4c0c
4c11 4c14 4c18 4c1c 4c20 4c23 4c24 4c26
4c27 4c29 4c2c 4c2f 4c32 4c33 1 4c38
4c3d 4c41 4c45 4c48 4c4c 4c50 4c53 4c56
4c5b 4c5e 4c61 4c64 4c65 4c6a 4c6b 1
4c6d 4c72 4c76 4c7a 4c7d 4c82 4c87 4c8a
4c8e 4c8f 4c94 4c97 4c9c 4c9d 4ca2 4ca5
4caa 4cab 4cb0 4cb3 4cb7 4cbb 4cbf 4cc3
4cc6 4cc7 4cc9 4cce 4ccf 4cd1 4cd2 4cd7
4cda 4cdf 4ce0 4ce5 4ce8 4ced 4cee 4cf3
4cf6 4cfa 4cfb 4d00 4d03 4d08 4d09 4d0e
4d0f 4d14 4d16 4d1a 4d1d 4d21 4d25 4d28
4d2c 4d30 4d33 4d36 4d3b 4d3e 4d41 4d44
4d45 4d4a 4d4b 1 4d4d 4d52 4d56 4d5a
4d5d 4d62 4d67 4d6a 4d6e 4d6f 4d74 4d75
4d7a 4d7c 4d80 4d83 4d87 4d8b 4d8e 4d92
4d96 4d99 4d9d 4da1 4da2 4da7 4da9 4dad
4db1 4db4 4db8 4dbc 4dbf 4dc2 4dc3 4dc5
4dc8 4dcd 4dce 4dd3 4dd7 4ddb 4ddf 4de2
4de6 4de7 4dec 4def 4df2 4df3 4df5 4df9
4dfd 4e01 4e05 4e09 4e0d 4e11 4e15 4e19
4e1d 4e21 4e25 4e29 4e2d 4e31 4e35 4e39
4e3d 4e41 4e45 4e49 4e4d 4e59 4e5d 4e61
4e64 4e68 4e6c 4e6e 4e72 4e76 4e7a 4e7d
4e81 4e85 4e87 4e88 4e8d 1 4e91 4e95
4e99 4e9c 4ea0 4ea4 4ea8 4eac 4eaf 4eb3
4eb7 4eba 4ebd 4ec2 4ec5 4ec8 4ecb 4ecc
4ed1 4ed2 1 4ed4 4ed9 4edd 4ee1 4ee4
4ee9 4eee 4ef1 4ef5 4ef6 4efb 4efe 4f03
4f04 4f09 4f0c 4f11 4f12 4f17 4f1a 4f1e
4f1f 4f24 4f27 4f2c 4f2d 4f32 4f35 4f39
4f3d 4f40 4f43 4f44 4f46 4f47 4f4c 4f4d
4f52 4f54 4f58 4f5b 4f5d 4f61 4f63 4f6f
4f71 4f73 4f74 4f79 4f7d 4f7f 4f8b 4f8d
4f91 4f95 4f98 4f9c 4f9f 4fa3 4fa6 4fa7
4fac 4faf 4fb3 4fb7 4fba 4fbe 4fc2 4fc5
4fc8 4fcd 4fd0 4fd3 4fd6 4fd7 4fdc 4fdd
1 4fdf 4fe4 4fe8 4fec 4fef 4ff4 4ff9
4ffc 5000 5001 5006 5009 500e 500f 5014
5017 501c 501d 5022 5025 5029 502d 5031
5035 5038 5039 503b 5040 5041 5043 5044
5049 504c 5051 5052 5057 505a 505f 5060
5065 5068 506c 506d 5072 5075 507a 507b
5080 5081 5086 5088 508c 508f 5093 5097
509a 509e 50a2 50a5 50a8 50ad 50b0 50b3
50b6 50b7 50bc 50bd 1 50bf 50c4 50c8
50cc 50cf 50d4 50d9 50dc 50e0 50e1 50e6
50e7 50ec 50ee 50f2 50f5 50f9 50fd 5100
5104 5108 510b 510f 5113 5114 5119 511b
511f 5122 5126 512a 512d 5130 5131 5133
5136 513b 513c 5141 5144 5148 514c 514f
5150 5152 5155 5158 5159 515e 5161 5165
5169 516c 516d 516f 5173 5176 517a 517d
517e 5180 5181 5186 1 5189 518e 1
5191 5196 519a 519e 51a1 51a5 51a9 51ac
51af 51b4 51b7 51ba 51bd 51be 51c3 51c4
1 51c6 51cb 51cf 51d3 51d6 51db 51e0
51e3 51e7 51e8 51ed 51f0 51f5 51f6 51fb
51fe 5203 5204 5209 520c 5210 5214 5218
521c 521f 5220 5222 5227 5228 522a 522b
5230 5233 5238 5239 523e 5241 5246 5247
524c 524f 5253 5254 5259 525c 5261 5262
5267 5268 526d 526f 5273 5276 527a 527e
5281 5285 5289 528c 528f 5294 5297 529a
529d 529e 52a3 52a4 1 52a6 52ab 52af
52b3 52b6 52bb 52c0 52c3 52c7 52c8 52cd
52ce 52d3 52d5 52d9 52dc 52e0 52e4 52e7
52eb 52ef 52f2 52f6 52fa 52fb 5300 5302
5306 5309 530d 5311 5315 5319 531d 5321
5325 5329 532d 5331 5335 5339 5345 5349
534d 5350 5354 5358 535a 535e 5362 5366
5369 536d 5371 5373 5374 5379 1 537d
5381 5385 5388 538c 5390 5394 5398 539b
539f 53a3 53a6 53a9 53ae 53b1 53b4 53b7
53b8 53bd 53be 1 53c0 53c5 53c9 53cd
53d0 53d5 53da 53dd 53e1 53e2 53e7 53ea
53ef 53f0 53f5 53f8 53fd 53fe 5403 5406
540a 540b 5410 5413 5418 5419 541e 5421
5425 5429 542c 542f 5430 5432 5433 5438
5439 543e 5440 5444 5447 5449 544d 544f
545b 545d 545f 5460 5465 5469 546b 5477
5479 547b 547f 5483 5487 548a 548e 548f
5494 5497 549a 549b 549d 54a1 54a5 54a9
54ad 54b1 54b5 54c1 54c5 54c9 54cc 54d0
54d4 54d6 54da 54de 54e2 54e5 54e9 54ed
54ef 54f0 54f5 1 54f9 54fd 5501 5504
5508 550c 5510 5514 5517 551b 551f 5522
5525 552a 552d 5530 5533 5534 5539 553a
1 553c 5541 5545 5549 554c 5551 5556
5559 555d 555e 5563 5566 556b 556c 5571
5574 5579 557a 557f 5582 5586 5587 558c
558f 5594 5595 559a 559d 55a1 55a5 55a8
55ab 55ac 55ae 55af 55b4 55b5 55ba 55bc
55c0 55c3 55c5 55c9 55cb 55d7 55d9 55db
55dc 55e1 55e5 55e7 55f3 55f5 55f9 55fd
5600 5604 5607 560b 560e 560f 5614 5617
561b 561f 5622 5626 562a 562d 5630 5635
5638 563b 563e 563f 5644 5645 1 5647
564c 5650 5654 5657 565c 5661 5664 5668
5669 566e 5671 5676 5677 567c 567f 5684
5685 568a 568d 5691 5695 5699 569d 56a0
56a1 56a3 56a8 56a9 56ab 56ac 56b1 56b4
56b9 56ba 56bf 56c2 56c7 56c8 56cd 56d0
56d4 56d5 56da 56dd 56e2 56e3 56e8 56e9
56ee 56f0 56f4 56f7 56fb 56ff 5702 5706
570a 570d 5710 5715 5718 571b 571e 571f
5724 5725 1 5727 572c 5730 5734 5737
573c 5741 5744 5748 5749 574e 574f 5754
5756 575a 575d 5761 5765 5768 576c 5770
5773 5777 577b 577c 5781 5783 5787 578a
578e 5792 5796 579a 579e 57a2 57a6 57aa
57ae 57b2 57b6 57ba 57be 57c2 57c6 57ca
57ce 57d2 57d6 57da 57e6 57ea 57ee 57f1
57f5 57f9 57fb 57ff 5803 5807 580a 580e
5812 5814 5815 581a 1 581e 5822 5826
5829 582d 5831 5835 5839 583c 5840 5844
5847 584a 584f 5852 5855 5858 5859 585e
585f 1 5861 5866 586a 586e 5871 5876
587b 587e 5882 5883 5888 588b 5890 5891
5896 5899 589e 589f 58a4 58a7 58ab 58ac
58b1 58b4 58b9 58ba 58bf 58c2 58c6 58ca
58cd 58d0 58d1 58d3 58d4 58d9 58da 58df
58e1 58e5 58e8 58ea 58ee 58f0 58fc 58fe
5900 5901 5906 590a 590c 5918 591a 591e
5922 5925 5929 592c 5930 5933 5934 5939
593c 5940 5944 5947 5948 594a 594d 5950
5951 5956 1 5959 595e 5962 5966 5969
596d 5971 5974 5977 597c 597f 5982 5985
5986 598b 598c 1 598e 5993 5997 599b
599e 59a3 59a8 59ab 59af 59b0 59b5 59b8
59bd 59be 59c3 59c6 59cb 59cc 59d1 59d4
59d8 59dc 59e0 59e4 59e7 59e8 59ea 59ef
59f0 59f2 59f3 59f8 59fb 5a00 5a01 5a06
5a09 5a0e 5a0f 5a14 5a17 5a1b 5a1c 5a21
5a24 5a29 5a2a 5a2f 5a30 5a35 5a37 5a3b
5a3e 5a42 5a46 5a49 5a4d 5a51 5a54 5a57
5a5c 5a5f 5a62 5a65 5a66 5a6b 5a6c 1
5a6e 5a73 5a77 5a7b 5a7e 5a83 5a88 5a8b
5a8f 5a90 5a95 5a96 5a9b 5a9d 5aa1 5aa4
5aa8 5aac 5aaf 5ab3 5ab7 5aba 5abe 5ac2
5ac3 5ac8 5aca 5ace 5ad1 5ad5 5ad9 5add
5ae1 5ae5 5ae9 5aed 5af1 5af5 5af9 5afd
5b01 5b0d 5b11 5b15 5b18 5b1c 5b20 5b22
5b26 5b2a 5b2e 5b31 5b35 5b39 5b3b 5b3c
5b41 1 5b45 5b49 5b4d 5b50 5b54 5b58
5b5c 5b60 5b63 5b67 5b6b 5b6e 5b71 5b76
5b79 5b7c 5b7f 5b80 5b85 5b86 1 5b88
5b8d 5b91 5b95 5b98 5b9d 5ba2 5ba5 5ba9
5baa 5baf 5bb2 5bb7 5bb8 5bbd 5bc0 5bc5
5bc6 5bcb 5bce 5bd2 5bd3 5bd8 5bdb 5be0
5be1 5be6 5be9 5bed 5bf1 5bf4 5bf7 5bf8
5bfa 5bfb 5c00 5c01 5c06 5c08 5c0c 5c0f
5c11 5c15 5c17 5c23 5c25 5c27 5c28 5c2d
5c31 5c33 5c3f 5c41 5c43 5c47 5c4b 5c4e
5c52 5c56 5c5a 5c5e 5c62 5c65 5c66 5c68
5c6b 5c6e 5c6f 5c74 5c78 5c7c 5c80 5c84
5c88 5c8c 5c90 5c94 5c98 5c9c 5ca8 5cac
5cb0 5cb3 5cb7 5cbb 5cbd 5cc1 5cc5 5cc9
5ccc 5cd0 5cd4 5cd6 5cd7 5cdc 1 5ce0
5ce4 5ce8 5ceb 5cef 5cf3 5cf7 5cfb 5cfe
5d02 5d06 5d09 5d0c 5d11 5d14 5d17 5d1a
5d1b 5d20 5d21 1 5d23 5d28 5d2c 5d30
5d33 5d38 5d3d 5d40 5d44 5d45 5d4a 5d4d
5d52 5d53 5d58 5d5b 5d60 5d61 5d66 5d69
5d6d 5d6e 5d73 5d76 5d7b 5d7c 5d81 5d84
5d88 5d8c 5d8f 5d92 5d93 5d95 5d96 5d9b
5d9c 5da1 5da3 5da7 5daa 5dac 5db0 5db2
5dbe 5dc0 5dc2 5dc3 5dc8 5dcc 5dce 5dda
5ddc 5de0 5de4 5de8 5dec 5df0 5df4 5df8
5dfc 5e00 5e04 5e10 5e14 5e18 5e1b 5e1f
5e23 5e25 5e29 5e2d 5e31 5e34 5e38 5e3c
5e3e 5e3f 5e44 1 5e48 5e4c 5e50 5e53
5e57 5e5b 5e5f 5e63 5e66 5e6a 5e6e 5e71
5e74 5e79 5e7c 5e7f 5e82 5e83 5e88 5e89
1 5e8b 5e90 5e94 5e98 5e9b 5ea0 5ea5
5ea8 5eac 5ead 5eb2 5eb5 5eba 5ebb 5ec0
5ec3 5ec8 5ec9 5ece 5ed1 5ed5 5ed6 5edb
5ede 5ee3 5ee4 5ee9 5eec 5ef0 5ef4 5ef7
5efa 5efb 5efd 5efe 5f03 5f04 5f09 5f0b
5f0f 5f12 5f14 5f18 5f1a 5f26 5f28 5f2a
5f2b 5f30 5f34 5f36 5f42 5f44 5f48 5f4b
5f4f 5f53 5f57 5f5b 5f5f 5f63 5f66 5f67
5f69 5f6c 5f6f 5f70 5f75 5f79 5f7c 5f80
5f82 5f86 5f89 5f8d 5f91 5f95 5f99 5f9d
5fa1 5fa5 5fa9 5fad 5fb1 5fb5 5fb9 5fbd
5fc1 5fc5 5fc9 5fcd 5fd1 5fd5 5fd9 5fdd
5fe1 5fe5 5fe9 5fed 5ff1 5ff5 5ff9 5ffd
6001 6004 6007 600a 600d 6010 6011 6013
6017 601b 601e 6021 6022 6027 602b 602f
6032 6033 6035 6038 603b 603c 6041 6045
6049 604d 6051 605d 6061 6066 606a 606d
606e 6073 6077 607b 607e 6081 6085 6087
608b 608f 6092 6095 6099 609b 609f 60a3
60a6 60a8 60ac 60b0 60b4 60b7 60bb 60bf
60c1 60c2 60c7 1 60cb 60cf 60d3 60d6
60da 60de 60e2 60e6 60e9 60ed 60f1 60f4
60f7 60fc 60ff 6102 6105 6106 610b 610c
1 610e 6113 6117 611b 611e 6123 6128
612b 612f 6130 6135 6138 613d 613e 6143
6146 614b 614c 6151 6154 6158 6159 615e
6161 6166 6167 616c 616f 6173 6177 617a
617d 617e 6180 6181 6186 6187 618c 618e
6192 6195 6197 619b 619d 61a9 61ab 61ad
61ae 61b3 61b7 61b9 61c5 61c7 61c9 61cd
61d1 61d5 61d9 61e5 61e9 61ee 61f2 61f5
61f6 61fb 61ff 6203 6206 6209 620d 620f
6213 6217 621a 621d 6221 6223 6227 622b
622e 6230 6234 6238 623c 623f 6243 6247
6249 624a 624f 1 6253 6257 625b 625e
6262 6266 626a 626e 6271 6275 6279 627c
627f 6284 6287 628a 628d 628e 6293 6294
1 6296 629b 629f 62a3 62a6 62ab 62b0
62b3 62b7 62b8 62bd 62c0 62c5 62c6 62cb
62ce 62d3 62d4 62d9 62dc 62e0 62e1 62e6
62e9 62ee 62ef 62f4 62f7 62fb 62ff 6302
6305 6306 6308 6309 630e 630f 6314 6316
631a 631d 631f 6323 6325 6331 6333 6335
6336 633b 633f 6341 634d 634f 6351 6355
6359 635c 635e 6362 6365 6367 636b 636f
6373 6377 637b 637f 6383 6387 638a 638d
638e 6390 6393 6398 6399 639e 63a2 63a6
63aa 63ad 63b1 63b3 63b7 63bb 63bf 63c3
63c6 63c7 63c9 63cd 63d1 63d4 63d5 63d7
63db 63dd 63e1 63e5 63e8 63ec 63f0 63f4
63f8 63fc 6400 6404 6408 640c 6410 6414
6418 641c 6420 6424 6428 642c 6430 6434
6438 643c 6440 6444 6448 644c 6450 6454
6458 645c 6460 6463 6466 6469 646c 646f
6470 6472 6476 647a 647d 6480 6481 6486
648a 648e 6492 6496 64a2 64a6 64ab 64af
64b2 64b3 64b8 64bc 64c0 64c3 64c6 64ca
64cc 64d0 64d4 64d7 64da 64de 64e0 64e4
64e8 64eb 64ed 64f1 64f5 64f9 64fc 6500
6504 6506 6507 650c 1 6510 6514 6518
651b 651f 6523 6527 652b 652e 6532 6536
6539 653c 6541 6544 6547 654a 654b 6550
6551 1 6553 6558 655c 6560 6563 6568
656d 6570 6574 6575 657a 657d 6582 6583
6588 658b 6590 6591 6596 6599 659d 659e
65a3 65a6 65ab 65ac 65b1 65b4 65b8 65bc
65bf 65c2 65c3 65c5 65c6 65cb 65cc 65d1
65d3 65d7 65da 65dc 65e0 65e2 65ee 65f0
65f2 65f3 65f8 65fc 65fe 660a 660c 660e
6612 6615 6617 661b 661f 6622 6624 6628
662c 6630 6631 6633 6636 6637 6639 663c
663f 6640 6645 6649 664c 6650 6652 6656
665a 665e 6662 6666 6667 6669 666c 666d
666f 6672 6675 6676 667b 667e 6681 6684
6685 668a 668b 668d 6691 6693 6697 669b
669e 66a2 66a5 66a8 66a9 66ae 66b2 66b5
66b9 66bd 66c1 66c5 66c8 66c9 66cb 66cf
66d2 66d6 66d7 66dc 66de 66e2 66e5 66e9
66ed 66f1 66f5 66f8 66fb 66fe 6702 6706
6709 670a 670c 670f 6712 6713 6718 671b
671e 671f 6724 6728 6729 672b 672f 6733
6737 673b 673e 6741 6744 6748 674c 674f
6750 6752 6755 6758 6759 675e 6761 6764
6765 676a 676d 6770 6771 6776 677a 677b
677d 6781 6785 6789 678d 6791 6794 6798
679c 679f 67a3 67a7 67ab 67af 67b3 67b7
67bb 67bf 67c3 67c7 67cb 67cf 67d3 67d7
67db 67df 67e3 67e7 67f3 67f7 67fb 67fe
6802 6806 6808 680c 6810 6814 6817 681b
681f 6821 6822 6827 1 682b 682f 6833
6836 683a 683e 6842 6846 6849 684d 6851
6854 6857 685c 685f 6862 6865 6866 686b
686c 1 686e 6873 6877 687b 687e 6883
6888 688b 688f 6890 6895 6898 689d 689e
68a3 68a6 68ab 68ac 68b1 68b4 68b8 68b9
68be 68c1 68c6 68c7 68cc 68cf 68d3 68d7
68da 68dd 68de 68e0 68e1 68e6 68e7 68ec
68ee 68f2 68f5 68f7 68fb 68fd 6909 690b
690d 690e 6913 6917 6919 6925 6927 692b
692f 6932 6933 6935 6938 693b 693c 6941
6944 6948 694b 694c 6951 6954 1 6957
695c 6960 6963 6967 696b 696f 6972 6976
697a 697b 697d 6980 6983 6984 6989 698d
6991 6995 6997 699b 699e 69a0 69a4 69a7
69ab 69af 69b2 69b5 69b6 69b8 69bb 69c0
69c1 69c6 69ca 69ce 69d2 69d5 69d9 69dd
69e1 69e5 69e6 69e8 69eb 69ec 69ee 69f1
69f4 69f5 69fa 69fe 6a02 6a06 6a08 6a0c
6a10 6a14 6a17 6a1c 6a1d 6a22 6a25 6a28
6a29 6a2b 6a2f 6a33 6a37 6a3b 6a3e 6a42
6a43 6a48 6a4b 6a4e 6a4f 6a51 6a55 6a57
6a5b 6a5f 6a62 6a64 6a68 6a6c 6a70 6a71
6a73 6a76 6a77 6a79 6a7c 6a7f 6a80 6a85
6a89 6a8d 6a91 6a93 6a97 6a9b 6a9f 6aa2
6aa7 6aa8 6aad 6ab0 6ab3 6ab4 6ab6 6aba
6abe 6ac2 6ac6 6ac9 6acd 6ace 6ad3 6ad6
6ad9 6ada 6adc 6ae0 6ae2 6ae6 6aea 6aed
6aef 6af3 6af7 6afa 6afe 6b01 6b05 6b09
6b0c 6b10 6b14 6b18 6b1b 6b1c 6b1e 6b21
6b24 6b25 6b2a 6b2e 6b31 6b34 6b35 6b3a
6b3e 6b42 6b45 6b48 6b49 6b4b 6b4e 6b53
6b54 6b59 6b5d 6b61 6b65 6b69 6b6d 6b71
6b75 6b79 6b7d 6b81 6b85 6b89 6b8d 6b91
6b95 6b99 6b9d 6ba1 6ba5 6ba9 6bad 6bb1
6bb5 6bb9 6bbd 6bc1 6bc5 6bc9 6bd5 6bd9
6bdd 6be0 6be4 6be8 6bea 6bee 6bf2 6bf6
6bf9 6bfd 6c01 6c03 6c04 6c09 1 6c0d
6c11 6c15 6c18 6c1c 6c20 6c24 6c28 6c2b
6c2f 6c33 6c36 6c39 6c3e 6c41 6c44 6c47
6c48 6c4d 6c4e 1 6c50 6c55 6c59 6c5d
6c60 6c65 6c6a 6c6d 6c71 6c72 6c77 6c7a
6c7f 6c80 6c85 6c88 6c8d 6c8e 6c93 6c96
6c9a 6c9b 6ca0 6ca3 6ca8 6ca9 6cae 6cb1
6cb5 6cb9 6cbc 6cbf 6cc0 6cc2 6cc3 6cc8
6cc9 6cce 6cd0 6cd4 6cd7 6cd9 6cdd 6cdf
6ceb 6ced 6cef 6cf0 6cf5 6cf9 6cfb 6d07
6d09 6d0d 6d11 6d14 6d18 6d1b 6d1f 6d22
6d23 6d28 6d2b 6d2f 6d32 6d36 6d3a 6d3e
6d41 6d42 6d44 6d47 6d4a 6d4b 6d50 6d53
6d57 6d5b 6d5e 6d5f 6d61 6d64 6d67 6d68
6d6d 1 6d70 6d75 6d79 6d7d 6d81 6d85
6d89 6d8d 6d91 6d95 6d99 6d9d 6da1 6da5
6da9 6dad 6db1 6db5 6db9 6dbd 6dc1 6dc5
6dc9 6dcd 6dd1 6dd5 6dd9 6ddd 6de9 6ded
6df1 6df4 6df8 6dfc 6dfe 6e02 6e06 6e0a
6e0d 6e11 6e15 6e17 6e18 6e1d 1 6e21
6e25 6e29 6e2c 6e30 6e34 6e38 6e3c 6e3f
6e43 6e47 6e4a 6e4d 6e52 6e55 6e58 6e5b
6e5c 6e61 6e62 1 6e64 6e69 6e6d 6e71
6e74 6e79 6e7e 6e81 6e85 6e86 6e8b 6e8e
6e93 6e94 6e99 6e9c 6ea1 6ea2 6ea7 6eaa
6eae 6eaf 6eb4 6eb7 6ebc 6ebd 6ec2 6ec5
6ec9 6ecd 6ed0 6ed3 6ed4 6ed6 6ed7 6edc
6edd 6ee2 6ee4 6ee8 6eeb 6eed 6ef1 6ef3
6eff 6f01 6f03 6f04 6f09 6f0d 6f0f 6f1b
6f1d 6f1f 6f23 6f26 6f2a 6f2c 6f30 6f34
6f37 6f3b 6f3d 6f41 6f45 6f48 6f4c 6f4f
6f53 6f56 6f57 6f5c 6f5f 6f63 6f67 6f6a
6f6b 6f6d 6f70 6f73 6f74 6f79 1 6f7c
6f81 6f85 6f89 6f8d 6f91 6f95 6f99 6f9d
6fa1 6fa5 6fa9 6fad 6fb1 6fb5 6fb9 6fbd
6fc1 6fc5 6fc9 6fcd 6fd1 6fd5 6fd9 6fdd
6fe1 6fe5 6fe9 6ff5 6ff9 6ffd 7000 7004
7008 700a 700e 7012 7016 7019 701d 7021
7023 7024 7029 1 702d 7031 7035 7038
703c 7040 7044 7048 704b 704f 7053 7056
7059 705e 7061 7064 7067 7068 706d 706e
1 7070 7075 7079 707d 7080 7085 708a
708d 7091 7092 7097 709a 709f 70a0 70a5
70a8 70ad 70ae 70b3 70b6 70ba 70bb 70c0
70c3 70c8 70c9 70ce 70d1 70d5 70d9 70dc
70df 70e0 70e2 70e3 70e8 70e9 70ee 70f0
70f4 70f7 70f9 70fd 70ff 710b 710d 710f
7110 7115 7119 711b 7127 7129 712b 712f
7133 7136 7138 713c 7140 7144 7148 714c
7150 7154 7158 715c 7160 7164 7168 716c
7170 7174 7178 717c 7180 7184 7188 718c
7190 7194 7198 719c 71a0 71a4 71a8 71b4
71b8 71bc 71bf 71c3 71c7 71c9 71cd 71d1
71d5 71d8 71dc 71e0 71e2 71e3 71e8 1
71ec 71f0 71f4 71f7 71fb 71ff 7203 7207
720a 720e 7212 7215 7218 721d 7220 7223
7226 7227 722c 722d 1 722f 7234 7238
723c 723f 7244 7249 724c 7250 7251 7256
7259 725e 725f 7264 7267 726c 726d 7272
7275 7279 727a 727f 7282 7287 7288 728d
7290 7294 7298 729b 729e 729f 72a1 72a2
72a7 72a8 72ad 72af 72b3 72b6 72b8 72bc
72be 72ca 72cc 72ce 72cf 72d4 72d8 72da
72e6 72e8 72ea 72ee 72f2 72f5 72f7 72fb
72ff 7302 7305 7306 7308 730b 7310 7311
7316 731a 731e 7322 7326 732a 732e 7332
7336 733a 733e 7342 7346 734a 734e 7352
7356 735a 735e 7362 7366 736a 736e 7372
7376 737a 737e 7382 738e 7392 7396 7399
739d 73a1 73a3 73a7 73ab 73af 73b2 73b6
73ba 73bc 73bd 73c2 1 73c6 73ca 73ce
73d1 73d5 73d9 73dd 73e1 73e4 73e8 73ec
73ef 73f2 73f7 73fa 73fd 7400 7401 7406
7407 1 7409 740e 7412 7416 7419 741e
7423 7426 742a 742b 7430 7433 7438 7439
743e 7441 7446 7447 744c 744f 7453 7454
7459 745c 7461 7462 7467 746a 746e 7472
7475 7478 7479 747b 747c 7481 7482 7487
7489 748d 7490 7492 7496 7498 74a4 74a6
74a8 74a9 74ae 74b2 74b4 74c0 74c2 74c6
74ca 74cd 74d1 74d4 74d8 74db 74dc 74e1
74e4 74e8 74ec 74ef 74f0 74f2 74f5 74f8
74f9 74fe 7501 7505 7509 750c 750d 750f
7512 7515 7516 751b 1 751e 7523 7527
752b 752f 7533 7537 753b 753f 7543 7547
754b 754f 7553 7557 755b 755f 7563 7567
756b 756f 7573 7577 757b 7587 758b 758f
7592 7596 759a 759c 75a0 75a4 75a8 75ab
75af 75b3 75b5 75b6 75bb 1 75bf 75c3
75c7 75ca 75ce 75d2 75d6 75da 75dd 75e1
75e5 75e8 75eb 75f0 75f3 75f6 75f9 75fa
75ff 7600 1 7602 7607 760b 760f 7612
7617 761c 761f 7623 7624 7629 762c 7631
7632 7637 763a 763f 7640 7645 7648 764c
764d 7652 7655 765a 765b 7660 7663 7667
766b 766e 7671 7672 7674 7675 767a 767b
7680 7682 7686 7689 768b 768f 7691 769d
769f 76a1 76a2 76a7 76ab 76ad 76b9 76bb
76bd 76c1 76c4 76c8 76ca 76cc 76d0 76d4
76d7 76db 76dd 76e1 76e5 76e8 76ec 76ef
76f3 76f6 76f7 76fc 76ff 7703 7707 770b
770f 7713 7717 771b 771f 7723 7727 772b
772f 7733 7737 773b 773f 7743 7747 774b
774f 7753 7757 775b 775f 7763 776f 7773
7777 777a 777e 7782 7784 7788 778c 7790
7793 7797 779b 779d 779e 77a3 1 77a7
77ab 77af 77b2 77b6 77ba 77be 77c2 77c5
77c9 77cd 77d0 77d3 77d8 77db 77de 77e1
77e2 77e7 77e8 1 77ea 77ef 77f3 77f7
77fa 77ff 7804 7807 780b 780c 7811 7814
7819 781a 781f 7822 7827 7828 782d 7830
7834 7835 783a 783d 7842 7843 7848 784b
784f 7853 7856 7859 785a 785c 785d 7862
7863 7868 786a 786e 7871 7873 7877 7879
7885 7887 7889 788a 788f 7893 7895 78a1
78a3 78a5 78a9 78ad 78b0 78b2 78b6 78ba
78be 78c2 78c6 78ca 78ce 78d2 78d6 78da
78de 78e2 78e6 78ea 78ee 78f2 78f6 78fa
78fe 7902 7906 790a 790e 7912 7916 7922
7926 792a 792d 7931 7935 7937 793b 793f
7943 7946 794a 794e 7950 7951 7956 1
795a 795e 7962 7965 7969 796d 7971 7975
7978 797c 7980 7983 7986 798b 798e 7991
7994 7995 799a 799b 1 799d 79a2 79a6
79aa 79ad 79b2 79b7 79ba 79be 79bf 79c4
79c7 79cc 79cd 79d2 79d5 79da 79db 79e0
79e3 79e7 79e8 79ed 79f0 79f5 79f6 79fb
79fe 7a02 7a06 7a09 7a0c 7a0d 7a0f 7a10
7a15 7a16 7a1b 7a1d 7a21 7a24 7a26 7a2a
7a2c 7a38 7a3a 7a3c 7a3d 7a42 7a46 7a48
7a54 7a56 7a58 7a5c 7a60 7a63 7a65 7a69
7a6d 7a70 7a74 7a78 7a7b 7a7f 7a82 7a86
7a89 7a8a 7a8f 7a92 7a96 7a9a 7a9d 7a9e
7aa0 7aa3 7aa6 7aa7 7aac 7ab0 7ab3 7ab7
7ab9 7abd 7ac0 7ac1 7ac6 7ac9 7acd 7ad0
7ad3 7ad4 7ad9 7add 7ae0 7ae4 7ae8 7aec
7af0 7af4 7af8 7afc 7b00 7b04 7b08 7b0c
7b10 7b14 7b18 7b1c 7b20 7b2c 7b30 7b34
7b37 7b3b 7b3f 7b41 7b45 7b49 7b4d 7b50
7b54 7b58 7b5a 7b5b 7b60 1 7b64 7b68
7b6c 7b6f 7b73 7b77 7b7b 7b7f 7b82 7b86
7b8a 7b8d 7b90 7b95 7b98 7b9b 7b9e 7b9f
7ba4 7ba5 1 7ba7 7bac 7bb0 7bb4 7bb7
7bbc 7bc1 7bc4 7bc8 7bc9 7bce 7bd1 7bd6
7bd7 7bdc 7bdf 7be4 7be5 7bea 7bed 7bf1
7bf2 7bf7 7bfa 7bff 7c00 7c05 7c08 7c0c
7c10 7c13 7c16 7c17 7c19 7c1a 7c1f 7c20
7c25 7c27 7c2b 7c2e 7c30 7c34 7c36 7c42
7c44 7c46 7c47 7c4c 7c50 7c52 7c5e 7c60
7c62 7c66 7c69 7c6d 7c71 7c75 7c79 7c7d
7c81 7c85 7c89 7c8d 7c91 7c95 7c99 7c9d
7ca9 7cad 7cb1 7cb4 7cb8 7cbc 7cbe 7cc2
7cc6 7cca 7ccd 7cd1 7cd5 7cd7 7cd8 7cdd
1 7ce1 7ce5 7ce9 7cec 7cf0 7cf4 7cf8
7cfc 7cff 7d03 7d07 7d0a 7d0d 7d12 7d15
7d18 7d1b 7d1c 7d21 7d22 1 7d24 7d29
7d2d 7d31 7d34 7d39 7d3e 7d41 7d45 7d46
7d4b 7d4e 7d53 7d54 7d59 7d5c 7d61 7d62
7d67 7d6a 7d6e 7d6f 7d74 7d77 7d7c 7d7d
7d82 7d85 7d89 7d8d 7d90 7d93 7d94 7d96
7d97 7d9c 7d9d 7da2 7da4 7da8 7dab 7dad
7db1 7db3 7dbf 7dc1 7dc3 7dc4 7dc9 7dcd
7dcf 7ddb 7ddd 7ddf 7de3 7de7 7dea 7dee
7df2 7df5 7df6 7df8 7dfc 7dff 7e03 7e06
7e07 7e09 7e0a 7e0f 7e13 7e17 7e1b 7e1e
7e1f 7e21 7e24 7e27 7e28 7e2d 7e31 7e35
7e3b 7e3d 7e41 7e44 7e46 7e4a 7e4d 7e51
7e54 7e58 7e5a 7e5e 7e62 7e65 7e67 7e6b
7e6f 7e73 7e76 7e77 7e79 7e7c 7e7f 7e80
7e85 7e89 7e8d 7e93 7e95 7e99 7e9d 7ea0
7ea4 7ea8 7eac 7eb0 7eb3 7eb7 7ebb 7ebf
7ec3 7ec7 7ecb 7ecf 7ed3 7ed7 7edb 7edf
7eeb 7eef 7ef3 7ef6 7efa 7efe 7f00 7f04
7f08 7f0c 7f0f 7f13 7f17 7f19 7f1a 7f1f
1 7f23 7f27 7f2b 7f2e 7f32 7f36 7f3a
7f3e 7f41 7f45 7f49 7f4c 7f4f 7f54 7f57
7f5a 7f5d 7f5e 7f63 7f64 1 7f66 7f6b
7f6f 7f73 7f76 7f7b 7f80 7f83 7f87 7f88
7f8d 7f90 7f95 7f96 7f9b 7f9e 7fa3 7fa4
7fa9 7fac 7fb0 7fb1 7fb6 7fb9 7fbe 7fbf
7fc4 7fc7 7fcb 7fcf 7fd2 7fd5 7fd6 7fd8
7fd9 7fde 7fdf 7fe4 7fe6 7fea 7fed 7fef
7ff3 7ff5 8001 8003 8005 8006 800b 800f
8011 801d 801f 8023 8027 802b 802f 8033
8037 803b 803f 8043 8047 8053 8057 805b
805e 8062 8066 8068 806c 8070 8074 8077
807b 807f 8081 8082 8087 1 808b 808f
8093 8096 809a 809e 80a2 80a6 80a9 80ad
80b1 80b4 80b7 80bc 80bf 80c2 80c5 80c6
80cb 80cc 1 80ce 80d3 80d7 80db 80de
80e3 80e8 80eb 80ef 80f0 80f5 80f8 80fd
80fe 8103 8106 810b 810c 8111 8114 8118
8119 811e 8121 8126 8127 812c 812f 8133
8137 813a 813d 813e 8140 8141 8146 8147
814c 814e 8152 8155 8157 815b 815d 8169
816b 816d 816e 8173 8177 8179 8185 8187
818b 818e 8192 8196 819a 819e 81a2 81a6
81a9 81aa 81ac 81af 81b2 81b3 81b8 81bc
81bf 81c3 81c5 81c9 81cc 81d0 81d4 81d8
81dc 81e0 81e4 81e8 81ec 81f0 81f4 81f8
81fc 8200 8204 8208 820c 8210 8214 8218
821c 8220 8224 8228 822c 8230 8234 8238
823c 8240 8244 8247 824a 824d 8250 8253
8254 8256 825a 825e 8261 8264 8265 826a
826e 8272 8275 8276 8278 827b 827e 827f
8284 8288 828c 8290 8294 82a0 82a4 82a9
82ad 82b0 82b1 82b6 82ba 82be 82c1 82c4
82c8 82ca 82ce 82d2 82d5 82d8 82dc 82de
82e2 82e6 82e9 82eb 82ef 82f3 82f7 82fa
82fe 8302 8304 8305 830a 1 830e 8312
8316 8319 831d 8321 8325 8329 832c 8330
8334 8337 833a 833f 8342 8345 8348 8349
834e 834f 1 8351 8356 835a 835e 8361
8366 836b 836e 8372 8373 8378 837b 8380
8381 8386 8389 838e 838f 8394 8397 839b
839c 83a1 83a4 83a9 83aa 83af 83b2 83b6
83ba 83bd 83c0 83c1 83c3 83c4 83c9 83ca
83cf 83d1 83d5 83d8 83da 83de 83e0 83ec
83ee 83f0 83f1 83f6 83fa 83fc 8408 840a
840c 8410 8414 8418 841c 8428 842c 8431
8435 8438 8439 843e 8442 8446 8449 844c
8450 8452 8456 845a 845d 8460 8464 8466
846a 846e 8471 8473 8477 847b 847f 8482
8486 848a 848c 848d 8492 1 8496 849a
849e 84a1 84a5 84a9 84ad 84b1 84b4 84b8
84bc 84bf 84c2 84c7 84ca 84cd 84d0 84d1
84d6 84d7 1 84d9 84de 84e2 84e6 84e9
84ee 84f3 84f6 84fa 84fb 8500 8503 8508
8509 850e 8511 8516 8517 851c 851f 8523
8524 8529 852c 8531 8532 8537 853a 853e
8542 8545 8548 8549 854b 854c 8551 8552
8557 8559 855d 8560 8562 8566 8568 8574
8576 8578 8579 857e 8582 8584 8590 8592
8594 8598 859c 859f 85a1 85a5 85a8 85ac
85ae 85b2 85b6 85b9 85ba 85bc 85bf 85c2
85c3 85c8 85cc 85d0 85d4 85d8 85dc 85e0
85e4 85e8 85eb 85ee 85ef 85f1 85f4 85f9
85fa 85ff 8603 8607 860b 860e 8612 8614
8618 861c 8620 8623 8624 8626 862a 862c
8630 8634 8637 863b 863f 8643 8647 864b
864f 8653 8657 865b 865f 8663 8667 866b
866f 8673 8677 867b 867f 8683 8687 868b
868f 8693 8697 869b 869f 86a3 86a7 86ab
86af 86b2 86b5 86b8 86bb 86be 86bf 86c1
86c5 86c9 86cc 86cf 86d0 86d5 86d9 86dd
86e1 86e5 86f1 86f5 86fa 86fe 8701 8702
8707 870b 870f 8712 8715 8719 871b 871f
8723 8726 8729 872d 872f 8733 8737 873a
873c 8740 8744 8748 874b 874f 8753 8755
8756 875b 1 875f 8763 8767 876a 876e
8772 8776 877a 877d 8781 8785 8788 878b
8790 8793 8796 8799 879a 879f 87a0 1
87a2 87a7 87ab 87af 87b2 87b7 87bc 87bf
87c3 87c4 87c9 87cc 87d1 87d2 87d7 87da
87df 87e0 87e5 87e8 87ec 87ed 87f2 87f5
87fa 87fb 8800 8803 8807 880b 880e 8811
8812 8814 8815 881a 881b 8820 8822 8826
8829 882b 882f 8831 883d 883f 8841 8842
8847 884b 884d 8859 885b 885d 8861 8864
8866 886a 886e 8871 8875 8879 887d 8880
8881 8883 8886 8889 888a 888f 8893 889b
889d 889e 88a1 88a3 88a7 88ae 88b0 88b4
88b7 88b9 88bd 88c1 88c4 88c8 88cb 88ce
88cf 88d4 88d7 88db 88df 88e2 88e3 88e5
88e8 88eb 88ec 88f1 1 88f4 88f9 88fd
8901 8904 8905 8907 890a 890d 890e 8913
8917 891b 891f 892b 892f 8934 8938 893b
893c 8941 8945 8949 894c 894f 8953 8955
8959 895d 8960 8963 8967 8969 896d 8971
8974 8976 897a 897e 8982 8985 8989 898d
898f 8990 8995 1 8999 899d 89a1 89a4
89a8 89ac 89b0 89b4 89b7 89bb 89bf 89c2
89c5 89ca 89cd 89d0 89d3 89d4 89d9 89da
1 89dc 89e1 89e5 89e9 89ec 89f1 89f6
89f9 89fd 89fe 8a03 8a06 8a0b 8a0c 8a11
8a14 8a19 8a1a 8a1f 8a22 8a26 8a27 8a2c
8a2f 8a34 8a35 8a3a 8a3d 8a41 8a45 8a48
8a4b 8a4c 8a4e 8a4f 8a54 8a55 8a5a 8a5c
8a60 8a63 8a65 8a69 8a6b 8a77 8a79 8a7b
8a7c 8a81 8a85 8a87 8a93 8a95 8a97 8a9b
8a9f 8aa3 8aa7 8aab 8aaf 8ab3 8abf 8ac3
8ac8 8acc 8acf 8ad0 8ad5 8ad9 8add 8ae0
8ae3 8ae7 8ae9 8aed 8af1 8af4 8af7 8afb
8afd 8b01 8b05 8b08 8b0a 8b0e 8b12 8b16
8b19 8b1d 8b21 8b23 8b24 8b29 1 8b2d
8b31 8b35 8b38 8b3c 8b40 8b44 8b48 8b4b
8b4f 8b53 8b56 8b59 8b5e 8b61 8b64 8b67
8b68 8b6d 8b6e 1 8b70 8b75 8b79 8b7d
8b80 8b85 8b8a 8b8d 8b91 8b92 8b97 8b9a
8b9f 8ba0 8ba5 8ba8 8bad 8bae 8bb3 8bb6
8bba 8bbb 8bc0 8bc3 8bc8 8bc9 8bce 8bd1
8bd5 8bd9 8bdc 8bdf 8be0 8be2 8be3 8be8
8be9 8bee 8bf0 8bf4 8bf7 8bf9 8bfd 8bff
8c0b 8c0d 8c0f 8c10 8c15 8c19 8c1b 8c27
8c29 8c2b 8c2f 8c33 8c36 8c3a 8c3d 8c40
8c41 8c46 8c4a 8c4e 8c51 8c55 8c59 8c5c
8c5f 8c64 8c67 8c6a 8c6d 8c6e 8c73 8c74
1 8c76 8c7b 8c7f 8c83 8c86 8c8b 8c90
8c93 8c97 8c98 8c9d 8ca0 8ca5 8ca6 8cab
8cae 8cb3 8cb4 8cb9 8cbc 8cc0 8cc4 8cc8
8ccc 8ccf 8cd0 8cd2 8cd7 8cd8 8cda 8cdb
8ce0 8ce3 8ce8 8ce9 8cee 8cf1 8cf6 8cf7
8cfc 8cff 8d03 8d04 8d09 8d0c 8d11 8d12
8d17 8d18 8d1d 8d1f 8d23 8d26 8d2a 8d2e
8d31 8d35 8d39 8d3c 8d3f 8d44 8d47 8d4a
8d4d 8d4e 8d53 8d54 1 8d56 8d5b 8d5f
8d63 8d66 8d6b 8d70 8d73 8d77 8d78 8d7d
8d7e 8d83 8d85 8d89 8d8c 8d90 8d94 8d97
8d9b 8d9f 8da2 8da6 8daa 8dab 8db0 8db4
8db6 8dba 8dbe 8dc1 8dc5 8dc8 8dc9 8dce
8dd2 8dd6 8dd9 8ddd 8de1 8de4 8de7 8dec
8def 8df2 8df5 8df6 8dfb 8dfc 1 8dfe
8e03 8e07 8e0b 8e0e 8e13 8e18 8e1b 8e1f
8e20 8e25 8e28 8e2d 8e2e 8e33 8e36 8e3b
8e3c 8e41 8e44 8e48 8e4c 8e50 8e54 8e57
8e58 8e5a 8e5f 8e60 8e62 8e63 8e68 8e6b
8e70 8e71 8e76 8e79 8e7e 8e7f 8e84 8e87
8e8b 8e8c 8e91 8e94 8e99 8e9a 8e9f 8ea0
8ea5 8ea7 8eab 8eae 8eb2 8eb6 8eb9 8ebd
8ec1 8ec4 8ec7 8ecc 8ecf 8ed2 8ed5 8ed6
8edb 8edc 1 8ede 8ee3 8ee7 8eeb 8eee
8ef3 8ef8 8efb 8eff 8f00 8f05 8f06 8f0b
8f0d 8f11 8f14 8f18 8f1c 8f1f 8f23 8f27
8f2a 8f2e 8f32 8f33 8f38 8f3c 8f3e 8f42
8f46 8f4a 8f4d 8f51 8f54 8f55 8f5a 8f5e
8f62 8f65 8f69 8f6d 8f70 8f73 8f78 8f7b
8f7e 8f81 8f82 8f87 8f88 1 8f8a 8f8f
8f93 8f97 8f9a 8f9f 8fa4 8fa7 8fab 8fac
8fb1 8fb4 8fb9 8fba 8fbf 8fc2 8fc7 8fc8
8fcd 8fd0 8fd4 8fd8 8fdc 8fe0 8fe3 8fe4
8fe6 8feb 8fec 8fee 8fef 8ff4 8ff7 8ffc
8ffd 9002 9005 900a 900b 9010 9013 9017
9018 901d 9020 9025 9026 902b 902c 9031
9033 9037 903a 903e 9042 9045 9049 904d
9050 9053 9058 905b 905e 9061 9062 9067
9068 1 906a 906f 9073 9077 907a 907f
9084 9087 908b 908c 9091 9092 9097 9099
909d 90a0 90a4 90a8 90ab 90af 90b3 90b6
90ba 90be 90bf 90c4 90c6 90ca 90ce 90d2
90d5 90d9 90dd 90e0 90e3 90e8 90eb 90ee
90f1 90f2 90f7 90f8 1 90fa 90ff 9103
9107 910a 910f 9114 9117 911b 911c 9121
9124 9129 912a 912f 9132 9137 9138 913d
9140 9144 9148 914c 9150 9153 9154 9156
915b 915c 915e 915f 9164 9167 916c 916d
9172 9175 917a 917b 9180 9183 9187 9188
918d 9190 9195 9196 919b 919c 91a1 91a3
91a7 91aa 91ae 91b2 91b5 91b9 91bd 91c0
91c3 91c8 91cb 91ce 91d1 91d2 91d7 91d8
1 91da 91df 91e3 91e7 91ea 91ef 91f4
91f7 91fb 91fc 9201 9202 9207 9209 920d
9210 9214 9218 921b 921f 9223 9226 922a
922e 922f 9234 9236 923a 923e 9241 9243
9247 924a 924e 9252 9256 9257 9259 925c
925d 925f 9262 9265 9266 926b 926e 9272
9276 927a 927b 927d 9280 9281 9283 9286
9289 928a 928f 1 9292 9297 929b 929f
92a4 92a9 92ad 92b1 92b5 92b8 92bb 92bf
92c3 92c8 92cb 92d0 92d1 92d6 92d9 92de
92df 92e4 92e7 92ec 92ed 92f2 92f5 92fa
92fb 9300 9303 9308 9309 930e 9311 9315
9316 931b 931e 9323 9324 9329 932c 9331
9332 9337 933a 933e 933f 9344 9347 934c
934d 9352 9355 9359 935a 935f 9362 9367
9368 936d 9371 9375 9379 937d 9382 9386
938a 938f 9393 9396 9397 939c 93a0 93a4
93a7 93aa 93ae 93b0 93b4 93b8 93bb 93be
93c2 93c4 93c8 93cc 93cf 93d1 93d5 93d9
93dd 93e0 93e4 93e8 93ea 93eb 93f0 1
93f4 93f8 93fc 93ff 9403 9407 940b 940f
9412 9416 941a 941d 9420 9425 9428 942b
942e 942f 9434 9435 1 9437 943c 9440
9444 9447 944c 9451 9454 9458 9459 945e
9461 9466 9467 946c 946f 9474 9475 947a
947d 9481 9482 9487 948a 948f 9490 9495
9498 949c 94a0 94a3 94a6 94a7 94a9 94aa
94af 94b0 94b5 94b9 94bd 94c0 94c5 94ca
94cd 94d1 94d2 94d7 94d8 94dd 94df 94e3
94e6 94e8 94ec 94ee 94fa 94fc 94fe 94ff
9504 9508 950a 9516 9518 951c 9520 9525
952a 952e 9532 9536 9539 953c 9540 9544
9549 954c 9551 9552 9557 955a 955f 9560
9565 9568 956d 956e 9573 9576 957b 957c
9581 9584 9589 958a 958f 9592 9596 9597
959c 959f 95a4 95a5 95aa 95ad 95b2 95b3
95b8 95bb 95bf 95c0 95c5 95c8 95cd 95ce
95d3 95d6 95da 95db 95e0 95e3 95e8 95e9
95ee 95f2 95f6 95fa 95fe 9603 9607 960b
9610 9614 9617 9618 961d 9621 9625 9628
962b 962f 9631 9635 9639 963c 963f 9643
9645 9649 964d 9650 9652 9656 965a 965e
9661 9665 9669 966b 966c 9671 1 9675
9679 967d 9680 9684 9688 968c 9690 9693
9697 969b 969e 96a1 96a6 96a9 96ac 96af
96b0 96b5 96b6 1 96b8 96bd 96c1 96c5
96c8 96cd 96d2 96d5 96d9 96da 96df 96e2
96e7 96e8 96ed 96f0 96f5 96f6 96fb 96fe
9702 9703 9708 970b 9710 9711 9716 9719
971d 9721 9724 9727 9728 972a 972b 9730
9731 9736 973a 973e 9741 9746 974b 974e
9752 9753 9758 9759 975e 9760 9764 9767
9769 976d 976f 977b 977d 977f 9780 9785
9789 978b 9797 9799 979d 97a1 97a4 97a8
97a9 97ae 97b2 97b6 97bb 97be 97c3 97c4
97c9 97cc 97d1 97d2 97d7 97da 97df 97e0
97e5 97e8 97ed 97ee 97f3 97f6 97fb 97fc
9801 9804 9809 980a 980f 9812 9817 9818
981d 9820 9825 9826 982b 982e 9833 9834
9839 983c 9841 9842 9847 984a 984f 9850
9855 9858 985d 985e 9863 9866 986a 986b
9870 9873 9878 9879 987e 9881 9886 9887
988c 988f 9893 9894 9899 989c 98a1 98a2
98a7 98aa 98af 98b0 98b5 98b8 98bd 98be
98c3 98c6 98ca 98cb 98d0 98d3 98d8 98d9
98de 98e1 98e6 98e7 98ec 98ef 98f4 98f5
98fa 98fd 9902 9903 9908 990b 9910 9911
9916 9919 991e 991f 9924 9927 992c 992d
9932 9935 993a 993b 9940 9943 9948 9949
994e 9951 9955 9956 995b 995e 9963 9964
9969 996c 9971 9972 9977 997a 997f 9980
9985 9988 998d 998e 9993 9996 999b 999c
99a1 99a4 99a8 99a9 99ae 99b1 99b6 99b7
99bc 99bf 99c4 99c5 99ca 99ce 99d2 99d6
99da 99df 99e3 99e7 99ec 99f0 99f3 99f4
99f9 99fd 9a01 9a04 9a07 9a0b 9a0d 9a11
9a15 9a18 9a1b 9a1f 9a21 9a25 9a29 9a2c
9a2e 9a32 9a36 9a3a 9a3d 9a41 9a45 9a47
9a48 9a4d 1 9a51 9a55 9a59 9a5c 9a60
9a64 9a68 9a6c 9a6f 9a73 9a77 9a7a 9a7d
9a82 9a85 9a88 9a8b 9a8c 9a91 9a92 1
9a94 9a99 9a9d 9aa1 9aa4 9aa9 9aae 9ab1
9ab5 9ab6 9abb 9abe 9ac3 9ac4 9ac9 9acc
9ad1 9ad2 9ad7 9ada 9ade 9adf 9ae4 9ae7
9aec 9aed 9af2 9af5 9af9 9afd 9b00 9b03
9b04 9b06 9b07 9b0c 9b0d 9b12 9b16 9b1a
9b1d 9b22 9b27 9b2a 9b2e 9b2f 9b34 9b35
9b3a 9b3c 9b40 9b43 9b45 9b49 9b4b 9b57
9b59 9b5b 9b5c 9b61 9b65 9b67 9b73 9b75
9b79 9b7e 9b81 9b86 9b87 9b8c 9b8f 9b94
9b95 9b9a 9b9d 9ba2 9ba3 9ba8 9bab 9baf
9bb3 9bb7 9bba 9bbb 9bbd 9bbe 9bc0 9bc1
9bc6 9bc9 9bce 9bcf 9bd4 9bd7 9bdc 9bdd
9be2 9be5 9be9 9bed 9bf1 9bf4 9bf5 9bf7
9bf8 9bfa 9bfb 9c00 9c03 9c08 9c09 9c0e
9c11 9c16 9c17 9c1c 9c1f 9c24 9c25 9c2a
9c2d 9c32 9c33 9c38 9c3b 9c40 9c41 9c46
9c49 9c4e 9c4f 9c54 9c57 9c5c 9c5d 9c62
9c65 9c6a 9c6b 9c70 9c73 9c78 9c79 9c7e
9c81 9c85 9c89 9c8d 9c90 9c91 9c93 9c94
9c96 9c97 9c9c 9c9f 9ca4 9ca5 9caa 9cad
9cb2 9cb3 9cb8 9cbb 9cbf 9cc3 9cc7 9cca
9ccb 9ccd 9cce 9cd0 9cd1 9cd6 9cd9 9cde
9cdf 9ce4 9ce7 9cec 9ced 9cf2 9cf5 9cfa
9cfb 9d00 9d03 9d08 9d09 9d0e 9d11 9d16
9d17 9d1c 9d20 9d24 9d26 9d2a 9d2e 9d32
9d33 9d35 9d38 9d39 9d3b 9d3e 9d41 9d42
9d47 9d4b 9d4f 9d54 9d59 9d5d 9d61 9d65
9d68 9d6b 9d6f 9d73 9d78 9d7b 9d80 9d81
9d86 9d89 9d8e 9d8f 9d94 9d97 9d9c 9d9d
9da2 9da5 9daa 9dab 9db0 9db3 9db8 9db9
9dbe 9dc1 9dc5 9dc6 9dcb 9dce 9dd3 9dd4
9dd9 9ddc 9de1 9de2 9de7 9dea 9dee 9def
9df4 9df7 9dfc 9dfd 9e02 9e06 9e0a 9e0e
9e12 9e17 9e1b 9e1f 9e24 9e28 9e2b 9e2c
9e31 9e35 9e39 9e3c 9e3f 9e43 9e45 9e49
9e4d 9e50 9e53 9e57 9e59 9e5d 9e61 9e64
9e66 9e6a 9e6e 9e72 9e75 9e79 9e7d 9e7f
9e80 9e85 1 9e89 9e8d 9e91 9e94 9e98
9e9c 9ea0 9ea4 9ea7 9eab 9eaf 9eb2 9eb5
9eba 9ebd 9ec0 9ec3 9ec4 9ec9 9eca 1
9ecc 9ed1 9ed5 9ed9 9edc 9ee1 9ee6 9ee9
9eed 9eee 9ef3 9ef6 9efb 9efc 9f01 9f04
9f09 9f0a 9f0f 9f12 9f16 9f17 9f1c 9f1f
9f24 9f25 9f2a 9f2d 9f31 9f35 9f38 9f3b
9f3c 9f3e 9f3f 9f44 9f45 9f4a 9f4e 9f52
9f55 9f5a 9f5f 9f62 9f66 9f67 9f6c 9f6d
9f72 9f74 9f78 9f7b 9f7d 9f81 9f83 9f8f
9f91 9f93 9f94 9f99 9f9d 9f9f 9fab 9fad
9fb1 9fb5 9fba 9fbf 9fc3 9fc7 9fcb 9fce
9fd1 9fd5 9fd9 9fde 9fe1 9fe6 9fe7 9fec
9fef 9ff4 9ff5 9ffa 9ffd a002 a003 a008
a00b a010 a011 a016 a019 a01e a01f a024
a027 a02b a02c a031 a034 a039 a03a a03f
a042 a046 a047 a04c a04f a054 a055 a05a
a05e a062 a066 a06a a06f a073 a077 a07c
a080 a083 a084 a089 a08d a091 a094 a097
a09b a09d a0a1 a0a5 a0a8 a0ab a0af a0b1
a0b5 a0b9 a0bc a0be a0c2 a0c6 a0ca a0cd
a0d1 a0d5 a0d7 a0d8 a0dd 1 a0e1 a0e5
a0e9 a0ec a0f0 a0f4 a0f8 a0fc a0ff a103
a107 a10a a10d a112 a115 a118 a11b a11c
a121 a122 1 a124 a129 a12d a131 a134
a139 a13e a141 a145 a146 a14b a14e a153
a154 a159 a15c a161 a162 a167 a16a a16e
a16f a174 a177 a17c a17d a182 a185 a189
a18d a190 a193 a194 a196 a197 a19c a19d
a1a2 a1a6 a1aa a1ad a1b2 a1b7 a1ba a1be
a1bf a1c4 a1c5 a1ca a1cc a1d0 a1d3 a1d5
a1d9 a1db a1e7 a1e9 a1eb a1ec a1f1 a1f5
a1f7 a203 a205 a209 a20d a210 a214 a215
a21a a21e a222 a227 a22a a22f a230 a235
a238 a23d a23e a243 a246 a24b a24c a251
a254 a259 a25a a25f a262 a267 a268 a26d
a270 a275 a276 a27b a27e a283 a284 a289
a28c a291 a292 a297 a29a a29f a2a0 a2a5
a2a8 a2ac a2ad a2b2 a2b5 a2ba a2bb a2c0
a2c3 a2c8 a2c9 a2ce a2d1 a2d5 a2d6 a2db
a2de a2e3 a2e4 a2e9 a2ec a2f1 a2f2 a2f7
a2fa a2ff a300 a305 a308 a30c a30d a312
a315 a31a a31b a320 a324 a328 a32c a330
a335 a339 a33d a342 a346 a349 a34a a34f
a353 a357 a35a a35d a361 a363 a367 a36b
a36e a371 a375 a377 a37b a37f a382 a384
a388 a38c a390 a393 a397 a39b a39d a39e
a3a3 1 a3a7 a3ab a3af a3b2 a3b6 a3ba
a3be a3c2 a3c5 a3c9 a3cd a3d0 a3d3 a3d8
a3db a3de a3e1 a3e2 a3e7 a3e8 1 a3ea
a3ef a3f3 a3f7 a3fa a3ff a404 a407 a40b
a40c a411 a414 a419 a41a a41f a422 a427
a428 a42d a430 a434 a435 a43a a43d a442
a443 a448 a44b a44f a453 a456 a459 a45a
a45c a45d a462 a463 a468 a46c a470 a473
a478 a47d a480 a484 a485 a48a a48b a490
a492 a496 a499 a49b a49f a4a1 a4ad a4af
a4b1 a4b2 a4b7 a4bb a4bd a4c9 a4cb a4cf
a4d4 a4d7 a4dc a4dd a4e2 a4e5 a4ea a4eb
a4f0 a4f3 a4f8 a4f9 a4fe a501 a505 a509
a50d a510 a511 a513 a514 a516 a517 a51c
a51f a524 a525 a52a a52d a531 a535 a539
a53c a53d a53f a540 a542 a543 a548 a54b
a550 a551 a556 a559 a55e a55f a564 a567
a56c a56d a572 a575 a57a a57b a580 a583
a588 a589 a58e a592 a594 a598 a59c a5a0
a5a5 a5aa a5ae a5b2 a5b6 a5b9 a5bc a5c0
a5c4 a5c9 a5cc a5d1 a5d2 a5d7 a5da a5df
a5e0 a5e5 a5e8 a5ed a5ee a5f3 a5f6 a5fb
a5fc a601 a604 a609 a60a a60f a612 a617
a618 a61d a620 a624 a625 a62a a62d a632
a633 a638 a63b a640 a641 a646 a649 a64d
a64e a653 a656 a65b a65c a661 a664 a669
a66a a66f a673 a677 a67b a67f a684 a688
a68c a691 a695 a698 a699 a69e a6a2 a6a6
a6a9 a6ac a6b0 a6b2 a6b6 a6ba a6bd a6c0
a6c4 a6c6 a6ca a6ce a6d1 a6d3 a6d7 a6db
a6df a6e2 a6e6 a6ea a6ec a6ed a6f2 1
a6f6 a6fa a6fe a701 a705 a709 a70d a711
a714 a718 a71c a71f a722 a727 a72a a72d
a730 a731 a736 a737 1 a739 a73e a742
a746 a749 a74e a753 a756 a75a a75b a760
a763 a768 a769 a76e a771 a776 a777 a77c
a77f a783 a784 a789 a78c a791 a792 a797
a79a a79e a7a2 a7a5 a7a8 a7a9 a7ab a7ac
a7b1 a7b2 a7b7 a7bb a7bf a7c2 a7c7 a7cc
a7cf a7d3 a7d4 a7d9 a7da a7df a7e1 a7e5
a7e8 a7ea a7ee a7f0 a7fc a7fe a800 a801
a806 a80a a80c a818 a81a a81e a822 a827
a82c a830 a834 a838 a83b a83e a842 a846
a84b a84e a853 a854 a859 a85c a861 a862
a867 a86a a86f a870 a875 a878 a87d a87e
a883 a886 a88b a88c a891 a894 a898 a899
a89e a8a1 a8a6 a8a7 a8ac a8af a8b3 a8b4
a8b9 a8bc a8c1 a8c2 a8c7 a8cb a8cf a8d3
a8d7 a8dc a8e0 a8e4 a8e9 a8ed a8f0 a8f1
a8f6 a8fa a8fe a901 a904 a908 a90a a90e
a912 a915 a918 a91c a91e a922 a926 a929
a92b a92f a933 a937 a93a a93e a942 a944
a945 a94a 1 a94e a952 a956 a959 a95d
a961 a965 a969 a96c a970 a974 a977 a97a
a97f a982 a985 a988 a989 a98e a98f 1
a991 a996 a99a a99e a9a1 a9a6 a9ab a9ae
a9b2 a9b3 a9b8 a9bb a9c0 a9c1 a9c6 a9c9
a9ce a9cf a9d4 a9d7 a9db a9dc a9e1 a9e4
a9e9 a9ea a9ef a9f2 a9f6 a9fa a9fd aa00
aa01 aa03 aa04 aa09 aa0a aa0f aa13 aa17
aa1a aa1f aa24 aa27 aa2b aa2c aa31 aa32
aa37 aa39 aa3d aa40 aa42 aa46 aa48 aa54
aa56 aa58 aa59 aa5e aa62 aa64 aa70 aa72
aa76 aa7a aa7d aa81 aa82 aa87 aa8b aa8f
aa94 aa97 aa9c aa9d aaa2 aaa5 aaaa aaab
aab0 aab3 aab8 aab9 aabe aac1 aac6 aac7
aacc aacf aad4 aad5 aada aadd aae2 aae3
aae8 aaeb aaf0 aaf1 aaf6 aaf9 aafe aaff
ab04 ab07 ab0c ab0d ab12 ab15 ab19 ab1a
ab1f ab22 ab27 ab28 ab2d ab30 ab35 ab36
ab3b ab3e ab43 ab44 ab49 ab4c ab51 ab52
ab57 ab5a ab5e ab5f ab64 ab67 ab6c ab6d
ab72 ab76 ab7a ab7e ab82 ab87 ab8b ab8f
ab94 ab98 ab9b ab9c aba1 aba5 aba9 abac
abaf abb3 abb5 abb9 abbd abc0 abc3 abc7
abc9 abcd abd1 abd4 abd6 abda abde abe2
abe5 abe9 abed abef abf0 abf5 1 abf9
abfd ac01 ac04 ac08 ac0c ac10 ac14 ac17
ac1b ac1f ac22 ac25 ac2a ac2d ac30 ac33
ac34 ac39 ac3a 1 ac3c ac41 ac45 ac49
ac4c ac51 ac56 ac59 ac5d ac5e ac63 ac66
ac6b ac6c ac71 ac74 ac79 ac7a ac7f ac82
ac86 ac87 ac8c ac8f ac94 ac95 ac9a ac9d
aca1 aca5 aca8 acab acac acae acaf acb4
acb5 acba acbe acc2 acc5 acca accf acd2
acd6 acd7 acdc acdd ace2 ace4 ace8 aceb
aced acf1 acf3 acff ad01 ad03 ad04 ad09
ad0d ad0f ad1b ad1d ad21 ad26 ad29 ad2e
ad2f ad34 ad37 ad3c ad3d ad42 ad45 ad4a
ad4b ad50 ad53 ad57 ad5b ad5f ad62 ad63
ad65 ad66 ad68 ad69 ad6e ad71 ad76 ad77
ad7c ad7f ad84 ad85 ad8a ad8d ad91 ad95
ad99 ad9c ad9d ad9f ada0 ada2 ada3 ada8
adab adb0 adb1 adb6 adb9 adbe adbf adc4
adc7 adcc adcd add2 add5 adda addb ade0
ade3 ade8 ade9 adee adf2 adf4 adf8 adfc
adff ae03 ae07 ae0a ae0e ae12 ae15 ae18
ae1d ae20 ae23 ae26 ae27 ae2c ae2d 1
ae2f ae34 ae38 ae3c ae3f ae44 ae49 ae4c
ae50 ae51 ae56 ae57 ae5c ae5e ae62 ae65
ae69 ae6d ae70 ae74 ae78 ae7b ae7e ae83
ae86 ae89 ae8c ae8d ae92 ae93 1 ae95
ae9a ae9e aea2 aea5 aeaa aeaf aeb2 aeb6
aeb7 aebc aebd aec2 aec4 aec8 aecb aecf
aed3 aed7 aeda aede aedf aee1 aee5 aee7
aeeb aeef aef2 aef6 aefa aefd af01 af05
af08 af0b af10 af13 af16 af19 af1a af1f
af20 1 af22 af27 af2b af2f af32 af37
af3c af3f af43 af44 af49 af4a af4f af53
af57 af5a af5f af64 af67 af6b af6f af72
af73 af78 af7b af80 af81 af86 af89 af8d
af91 af94 af95 af9a af9b afa0 afa2 afa6
afa9 afad afb1 afb5 afb9 afbd afc1 afc5
afc9 afcd afd9 afde afe2 afe6 afea afee
aff0 aff1 aff6 1 affa affe b002 b005
b009 b00d b011 b015 b018 b01c b020 b023
b026 b02b b02e b031 b034 b035 b03a b03b
1 b03d b042 b046 b04a b04d b052 b057
b05a b05e b05f b064 b065 b06a b06e b072
b075 b07a b07f b082 b086 b087 b08c b08f
b094 b095 b09a b09d b0a1 b0a5 b0a8 b0ab
b0ac b0ae b0af b0b4 b0b5 b0ba b0bc b0c0
b0c3 b0c7 b0cb b0cf b0d3 b0d7 b0db b0df
b0eb b0f0 b0f4 b0f8 b0fc b100 b102 b106
b108 b114 b116 b118 b119 b11e b122 b124
b130 b134 b136 b137 b140 
330d
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 14 1d
1c :2 14 :2 4 e 17 16 :2 e :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 d 16 15 :2 d :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 :3 10 :2 4 :3 f :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 10 19 18 :2 10 :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 b 1a b
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 11 20 11 :2 4 :2 11 20 11
:2 4 :2 16 25 16 :2 4 :2 16 25 16
:2 4 :2 b 1a b :2 4 d 16 15
:2 d :2 4 11 1a 19 :2 11 :2 4 :2 f
19 f :2 4 9 12 11 :2 9 :2 4
:2 17 26 17 :2 4 17 1c 1b :2 17
:2 4 18 1d 1c :2 18 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 14
1d 1c :2 14 :2 4 15 1e 1d :2 15
:2 4 :2 10 1f 10 :2 4 :2 f 1e f
:2 4 7 10 f :2 7 :2 4 :2 6 1e
6 :2 4 :2 7 1f 7 :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 13 :2 4
17 :2 4 14 1d 26 2e :2 1d :2 14
:2 4 13 :2 4 12 :2 4 10 4 :4 8
7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b6
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 46 :2 7 18
:2 4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 1b :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 :4 9 8 7 :4 2b 2a 29
:2 7 11 1c 21 33 3e 43 :2 f
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 48 b :2 14
1f 1d :2 28 :2 1d a 3d 46 4f
:2 3d 52 54 :2 52 3c :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
72 75 :2 24 79 7c :2 24 86 89
92 9a :2 a3 :2 92 c0 :2 89 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
2b :2 34 50 :2 a 57 :3 7 e 7
4 48 :4 c b a :4 2a 29 28
:2 a 11 23 f :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :4 43 48 :3 4 12 4 :4 8 :2 7
16 7 20 :3 4 10 17 21 24
:2 10 :2 4 12 19 25 28 :2 12 :2 4
13 4 7 10 18 :2 7 1b 1d
:2 1b 7 13 1a 21 2e 31 :2 1a
36 39 :2 13 :2 7 15 :2 1e 27 2a
2d 31 :2 15 7 a 18 21 29
:2 18 :2 a 2d 30 :2 2d 14 20 29
3f 48 60 12 20 2b 37 12
20 2d :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :4 32
14 16 1f 21 2c 2e 40 42
55 57 d 16 18 2e 37 39
51 53 12 1a 27 38 4a d
18 24 34 3c 3f 47 13 15
22 30 32 3e 47 4f 58 66
6f 7d 86 94 9d aa b3 c4
cd e0 e9 fe 107 122 12b 143
14c 15d 166 178 181 199 1a2 1b5
1be 1df 1e1 1ee 1f0 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :7 7 b :2 14 1f 1d :2 28
:2 1d a 14 20 2c 3a 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 38 e
:2 17 22 20 :2 2b :2 20 d :4 11 :2 10
20 10 21 :2 d 17 20 36 3f
57 15 20 2c 15 23 30 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :4 3b 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 27 c1 c4
:2 27 cc cf :2 27 d4 d7 :2 27 e1
e4 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 47 52 :2 d
:4 a 38 a 1a a :5 7 15 7
11 21 f 10 1d :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f a 13 1f :2 a 22
24 :2 22 14 24 12 13 20 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 26 d :2 18 1f
2d :2 d 32 34 :2 32 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 bb :2 8c :2 27 c3 c6
:2 27 ce d1 :2 27 d6 d9 :2 27 e6
e9 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 49 57 :2 d
36 :2 a 26 :2 7 1f 11 1a 30
39 51 f 1a 26 f 1d 2a
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 4 b :2 14
1f 1d :2 28 :2 1d a 23 2e 3e
4e 5b :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 38
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b7 :2 8c :2 27
bf c2 :2 27 ca cd :2 27 d2 d5
:2 27 e2 e5 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 45
53 :2 d 3b :2 a 38 :2 7 :4 4 8
11 1e :2 8 23 21 :2 2c :2 21 43
e 1b :2 43 20 1e :2 29 :2 1e :2 8
7 41 4a 52 :2 41 55 57 :2 55
40 :2 7 a 13 1f :2 a 25 22
:2 2e :2 22 42 d 19 :2 42 1f 1c
:2 28 :2 1c :3 a 18 a 3d :3 7 e
:2 7 11 7 5a a e 10 :2 e
a 18 :2 a 19 :2 a 18 29 35
42 4b 54 :2 42 58 61 69 :2 58
22 2b 37 :2 22 3b 44 4f :2 3b
53 20 2b :2 53 2f 38 46 :2 2f
4a 53 5e :2 4a 22 2b 37 :2 22
3b 43 4d :2 18 a d 16 22
:2 d 27 25 :2 30 :2 25 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 27 :2 10 5b
:2 d 10 :2 1a 2c :2 36 42 45 54
57 58 :2 54 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 :2 10 5b :3 d :2 18 2e
:2 37 47 :2 d a 3f 10 19 25
:2 10 28 2b :2 28 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 95 aa :2 8c :2 27 b2 b5 :2 27 bd
c0 :2 27 c5 c8 :2 27 d5 d8 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c 35 41 :2 2c 45 53 :2 d
2d 3f :3 a 19 a :4 e :2 d 1c
d 23 :2 a 12 a 19 a d
16 1e :2 d 21 23 :2 21 d 17
20 28 :2 17 2b 2d 36 42 :2 2d
:2 17 d 25 :2 a :4 7 b 14 1c
:2 b 1f 21 :2 1f a 29 32 3a
:2 29 3d 40 :2 3d 28 :2 a e 17
1f :2 e 22 24 :2 22 d 2b 34
3c :2 2b 3f 41 :2 3f 2a :3 d 18
d a 44 10 19 21 :2 10 24
26 :2 24 d 18 d a 28 44
11 1a 22 :2 11 25 27 :2 25 10
2e 37 3f :2 2e 42 44 :2 42 2d
:2 10 d 18 d a 47 44 10
19 21 :2 10 24 26 :2 24 d 18
d 28 44 :2 a 45 :2 7 :5 4 :3 17
:2 4 12 :2 4 13 :2 4 d :2 16 22
29 32 3e :2 29 42 :2 4b :2 22 21
5a :2 d :2 4 12 19 22 2e :2 19
32 :2 3b :2 12 4 7 10 18 :2 7
1b 1d :2 1b 7 1a 29 37 3f
4a 54 25 :2 1a 7 a 13 1e
:2 a 23 21 :2 2c :2 21 d 16 27
:2 d 2a 2c :2 2a d 20 :2 29 d
2e :2 a d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 86 89 92 9a :2 92 ac
:2 89 :2 24 b4 b7 :2 24 bf c2 :2 24
c7 ca :2 24 d6 d9 :2 24 :2 d 59
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 29
32 43 :2 29 47 54 :2 a 40 :2 7
a 13 24 :2 a 27 2a :2 27 30
39 4a :2 30 4d 50 :2 4d :2 a d
:2 17 29 :2 33 3f 43 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 92 ac :2 89 :2 24 b4
b7 :2 24 bf c2 :2 24 c7 ca :2 24
d6 d9 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 32 43 :2 29
47 54 :2 a 52 :3 7 15 7 11
15 24 2f 34 44 4f 54 58
f 1b f 10 1d e 18 e
1c e 1e :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 1f b :2 14 1f 1d :2 28 :2 1d a
:4 3e 3d 3c :3 a 18 a d 16
1f :2 d 22 24 :2 22 d 1d d
26 :2 a 57 :3 7 16 :2 7 12 7
a e 10 :2 e d 14 20 23
:2 d 26 28 :2 26 17 2e 1b 23
2a 48 50 57 70 78 7f 10
18 1f 3c 44 4b 64 6c 73
10 1e 39 15 26 32 3b 15
16 1e 2f 3b 48 5e :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5e 5f
:2 5b :2 32 :3 16 :2 1c 21 2d 6b 6e
:2 2d 7b 7e :2 2d 82 85 :2 2d 91
94 :2 2d 9c 9f :2 2d ab ae b5
be c1 :2 ae :2 2d :2 16 62 :2 13 :2 10
:4 1c :2 10 d :3 2c 11 :2 1a 25 23
:2 2e :2 23 :2 10 1e 10 14 1d 2b
:2 14 2e 30 :2 2e 13 37 40 49
:2 37 4c 4e :2 4c 36 :2 13 1d 34
21 29 30 4e 56 5d 78 80
87 16 1e 25 42 4a 51 6c
74 7b 16 26 1b 2c 38 1b
1c 24 35 41 4e 64 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 61 64 65
:2 61 :2 38 :3 1c :2 22 27 33 71 74
:2 33 81 84 :2 33 88 8b :2 33 97
9a :2 33 a2 a5 :2 33 b1 b4 bb
c4 c7 :2 b4 :2 33 :2 1c 68 :2 19 :2 16
:4 22 :2 16 13 :4 51 13 22 13 :4 10
d 3e 14 :2 1d 28 26 :2 31 :2 26
13 45 4e 57 :2 45 5a 5c :2 5a
44 :2 13 1a 31 1e 26 2d 4b
53 5a 75 7d 84 13 1b 22
3f 47 4e 69 71 78 13 23
18 29 35 18 19 21 32 3e
4b 61 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 94 97 :2 30 9f a2
:2 30 ae b1 b8 c1 c4 :2 b1 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :4 5f
3e :2 d 2c 17 2e 1a 22 29
47 4f 56 71 79 80 10 18
1f 3c 44 4b 66 6e 75 10
20 15 26 32 15 16 1e 2f
3b 48 5e :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6b 6e :2 2d 7b 7e
:2 2d 82 85 :2 2d 91 94 :2 2d 9c
9f :2 2d ab ae b5 be c1 :2 ae
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:7 a 12 d 14 20 23 :2 d 26
28 :2 26 17 2e 44 4c 53 71
79 80 99 a1 a8 c2 ce ec
15 26 31 3a 15 16 1e 2f
3b 48 5e :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6b 6e :2 2d 7b 7e
:2 2d 82 85 :2 2d 91 94 :2 2d 9c
9f :2 2d ab ae b5 be c1 :2 ae
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:3 2c 11 :2 1a 25 23 :2 2e :2 23 :2 10
1e 10 14 1d 2b :2 14 2e 30
:2 2e 13 37 40 49 :2 37 4c 4e
:2 4c 36 :2 13 1d 34 4d 55 5c
75 7d 84 a0 ac 1b 2c 37
1b 1c 24 35 41 4e 64 :2 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 61 64
65 :2 61 :2 38 :3 1c :2 22 27 33 71
74 :2 33 81 84 :2 33 88 8b :2 33
97 9a :2 33 a2 a5 :2 33 b1 b4
bb c4 c7 :2 b4 :2 33 :2 1c 68 :2 19
:2 16 :4 22 :2 16 13 :4 51 13 22 :2 13
:4 10 d 3e 14 :2 1d 28 26 :2 31
:2 26 13 1a 31 49 51 58 76
7e 85 a0 a8 af cb d7 18
29 34 18 19 21 32 3e 4b
61 :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5e 61 62 :2 5e :2 35 :3 19 :2 1f 24
30 6e 71 :2 30 7e 81 :2 30 85
88 :2 30 94 97 :2 30 9f a2 :2 30
ae b1 b8 c1 c4 :2 b1 :2 30 :2 19
65 :2 16 :2 13 :4 1f :2 13 10 :4 41 3e
:2 d 2c 17 2e 46 4e 55 73
7b 82 9d a5 ac c8 d4 15
26 31 15 16 1e 2f 3b 48
5e :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5e 5f :2 5b :2 32 :3 16 :2 1c 21
2d 6b 6e :2 2d 7b 7e :2 2d 82
85 :2 2d 91 94 :2 2d 9c 9f :2 2d
ab ae b5 be c1 :2 ae :2 2d :2 16
62 :2 13 :2 10 :4 1c :2 10 d :7 a :4 7
b :2 14 1f 1d :2 28 :2 1d a d
16 1f :2 d 22 24 :2 22 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 89 8c
95 9d :2 a6 :2 95 be :2 8c :2 27 c6
c9 :2 27 d1 d4 :2 27 d9 dc :2 27
e5 e8 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
:2 10 5b :3 d :2 18 2c :2 35 4c 56
:2 d a 26 :4 11 10 32 3b 45
:2 32 48 4a :2 48 :3 10 14 16 :2 14
10 20 10 1a 1e 2e 18 19
26 37 4b 17 28 30 37 51
59 60 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 94 97 :2 30 9f a2
:2 30 ae b1 b8 c1 c4 :2 b1 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :4 18
10 20 10 1a 1e 2e 18 19
26 37 4b 17 23 2b 32 :2 13
:2 1c 28 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 61
62 :2 5e :2 35 :3 19 :2 1f 24 30 6e
71 :2 30 7e 81 :2 30 85 88 :2 30
94 97 :2 30 9f a2 :2 30 ae b1
b8 c1 c4 :2 b1 :2 30 :2 19 65 :2 16
:2 13 :4 1f :2 13 10 :7 d 10 19 27
:2 10 2c 2a 35 3f :2 2c :2 2a 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8c
8f 98 a0 :2 a9 :2 98 c1 :2 8f :2 2a
c9 cc :2 2a d4 d7 :2 2a dc df
:2 2a e8 eb :2 2a :2 13 5f :2 10 13
:2 1d 2f :2 39 45 48 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a :2 13 5e :3 10 :2 1b 2f :2 38 4f
59 :2 10 42 :2 d 4c 26 :3 a 18
a 7 38 e 17 23 :2 e 26
28 :2 26 d 30 41 4a 52 :2 41
:2 30 2f 57 5a :2 57 :3 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 bb :2 89 :2 24 c3 c6
:2 24 ce d1 :2 24 d6 d9 :2 24 e2
e5 :2 24 :2 d 59 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 29 :2 32 49 53 :2 a
5c 38 :2 7 a 11 1d 20 :2 a
23 25 :2 23 a 18 1f 2a 2d
:2 1f 37 3a :2 18 a 14 1f 2a
35 42 4a 53 5e 69 7c 85
90 9b 12 1f 2d 37 4a 12
13 21 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 29
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e0 e3 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
51 :2 d 3b :2 a e 15 1f 22
:2 e 25 27 :2 25 d 31 3a 4d
:2 31 50 52 :2 50 30 5a 10 1e
:2 5a 23 21 2c 3f :2 23 :2 21 59
:2 30 2f :2 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 bc :2 8c :2 27 c4 c7 :2 27 cf
d2 :2 27 d7 da :2 27 e3 e6 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 4a 54 :2 d 44 :2 a
14 27 34 45 52 61 12 13
20 2e 46 54 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :4 29 a 19 20 2c 2f :2 20
39 3c :2 19 a 14 26 37 46
53 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 7 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 89 8c
95 9d :2 a6 :2 95 b9 :2 8c :2 27 c1
c4 :2 27 cc cf :2 27 d4 d7 :2 27
e0 e3 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
:2 10 5b :3 d :2 18 2c :2 35 47 51
:2 d 3b :2 a 14 2c 34 3b 59
61 68 82 8a 91 ac b8 12
1e 12 13 1b 2c 38 45 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 7 e :2 17 22
20 :2 2b :2 20 d 40 49 52 :2 40
55 57 :2 55 3f :2 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 be :2 8c :2 27 c6 c9
:2 27 d1 d4 :2 27 d9 dc :2 27 e5
e8 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 4c 56 :2 d
5a :2 a 14 27 34 45 52 61
12 13 20 2e 46 54 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :8 7 15 7 a 13
1f :2 a 22 24 :2 22 14 1f 2c
34 3b 50 5b 60 74 12 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 26 1e 26 2d
45 4d 54 6d :3 12 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 26 a 15 :2 a 19 a
d 16 23 :2 d 26 28 :2 26 d
19 d 2a :3 a 16 22 2f 3d
48 52 5e 1b 28 35 42 4f
1b 28 34 3e 46 4f 57 5e
1b 27 34 3f 4a 58 1b 26
32 3e 41 44 4a 50 :2 16 a
d 16 18 :2 16 10 19 26 :2 10
29 2b :2 29 1a 2d 4a 51 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 94 97 :2 30 9f a2
:2 30 ae b1 b8 c1 c4 :2 b1 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :4 2d
1a 2d 4a 51 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 62
63 :2 5e :2 35 :3 19 :2 1f 24 30 6f
72 :2 30 7f 82 :2 30 86 89 :2 30
95 98 :2 30 a0 a3 :2 30 af b2
b9 c2 c5 :2 b2 :2 30 :2 19 66 :2 16
:2 13 :4 1f :2 13 10 :7 d 1a :2 a 26
a 18 :2 a 19 a d 14 20
23 :2 d 26 28 :2 26 d 18 :2 21
d 2c d 18 1f 28 34 :2 1f
38 :2 41 :2 18 d :5 a 16 22 2f
3d 48 52 5e 1b 28 35 42
4f 1b 28 34 3e 46 4f 57
5e 1b 27 34 3f 4a 58 1b
26 32 3e 41 44 4a 50 :2 16
a d 16 18 :2 16 17 2a 47
4e 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5b 5f 60 :2 5b :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 92 95 :2 2d
9d a0 :2 2d ac af b6 bf c2
:2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10
d :4 1a :2 a :4 7 1f a 13 1a
:2 13 28 :2 a 2b 2d :2 2b a 16
a 30 a 16 1d 26 2d :2 26
3b :2 1d 3e 40 :2 1d 1c 43 45
:2 1c :2 16 a :4 7 a 13 15 :2 13
a 15 :2 a 10 19 22 :2 10 27
25 30 :2 25 a d 1b :2 d 19
:2 22 2b 2f 33 3c 45 :2 33 48
4a :2 33 4c 4d :2 33 50 :2 19 :2 d
1b :2 24 2d 30 33 3c 45 :2 33
48 4a :2 33 4d 4f :2 33 51 52
:2 33 55 :2 1b :2 d 1d :2 d 1b :2 d
18 :2 d 1b d 17 21 25 3a
43 15 16 23 34 3e 14 22
2f 3f :2 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 30
11 1a 23 :2 11 26 28 :2 26 10
:4 31 30 2f :3 10 1e 10 13 :2 1e
25 33 :2 13 3f 41 :2 3f 13 23
13 43 :2 10 4a :2 d 10 17 23
26 :2 10 29 2b :2 29 10 1e :2 27
10 13 1c 23 :2 1c 31 :2 13 34
36 :2 34 13 22 13 38 13 22
29 35 38 :2 29 41 44 :2 22 :2 13
22 29 35 38 :2 29 42 45 :2 22
13 :4 10 2f 13 1c 23 :2 1c 30
:2 13 33 35 :2 33 13 21 13 37
13 21 28 33 36 :2 28 3f 42
:2 21 :2 13 21 28 33 36 :2 28 40
43 :2 21 13 :4 10 :5 d 1c :2 d 18
d 10 19 25 :2 10 28 2a :2 28
13 17 19 :2 17 16 1d 29 2c
:2 16 2f 31 :2 2f 20 37 4e 56
5d 76 7e 85 19 21 28 40
48 4f 69 77 92 1e 2f 3b
44 1e 1f 27 38 44 51 67
:2 19 :2 22 2e 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 64
68 69 :2 64 :2 3b :3 1f :2 25 2a 36
75 78 :2 36 85 88 :2 36 8c 8f
:2 36 9b 9e :2 36 a6 a9 :2 36 b5
b8 bf c8 cb :2 b8 :2 36 :2 1f 6c
:2 1c :2 19 :4 25 :2 19 16 :3 35 1a :2 23
2e 2c :2 37 :2 2c :2 19 27 19 1d
26 34 :2 1d 37 39 :2 37 1c 40
49 52 :2 40 55 57 :2 55 3f :2 1c
26 3d 56 5e 65 7e 86 8d
1f 27 2e 46 4e 55 71 81
24 35 41 24 25 2d 3e 4a
57 6d :2 1f :2 28 34 1f 1c 24
22 :2 2b 37 22 32 :2 1f :2 24 22
:2 2b 37 22 25 :2 2f 41 :2 4b 57
5b 6a 6e 6f :2 6a :2 41 :3 25 :2 2b
30 3c 7b 7e :2 3c 8b 8e :2 3c
92 95 :2 3c a1 a4 :2 3c ac af
:2 3c bb be c5 ce d1 :2 be :2 3c
:2 25 72 :2 22 :2 1f :4 2b :2 1f 1c :4 5a
1c 2b 1c :4 19 16 47 1d :2 26
31 2f :2 3a :2 2f 1c 4e 57 60
:2 4e 63 65 :2 63 4d :2 1c 23 3a
53 5b 62 7b 83 8a 1c 24
2b 43 4b 52 6e 7e 21 32
3e 21 22 2a 3b 47 54 6a
:2 1c :2 25 31 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 67
6b 6c :2 67 :2 3e :3 22 :2 28 2d 39
78 7b :2 39 88 8b :2 39 8f 92
:2 39 9e a1 :2 39 a9 ac :2 39 b8
bb c2 cb ce :2 bb :2 39 :2 22 6f
:2 1f :2 1c :4 28 :2 1c 19 :4 68 47 :2 16
35 20 37 50 58 5f 78 80
87 19 21 28 40 48 4f 6b
7b 1e 2f 3b 48 1f 2c 3d
45 1d 29 36 4c :2 19 :2 22 2e
19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 64 68 69 :2 64
:2 3b :3 1f :2 25 2a 36 75 78 :2 36
85 88 :2 36 8c 8f :2 36 9b 9e
:2 36 a6 a9 :2 36 b5 b8 bf c8
cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25
:2 19 16 :7 13 1b 16 1d 29 2c
:2 16 2f 31 :2 2f 20 37 4d 55
5c 7a 82 89 a2 aa b1 cb
d7 f5 1e 2f 3a 43 55 1f
2c 3d 45 1d 29 36 4c :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 64 68
69 :2 64 :2 3b :3 1f :2 25 2a 36 75
78 :2 36 85 88 :2 36 8c 8f :2 36
9b 9e :2 36 a6 a9 :2 36 b5 b8
bf c8 cb :2 b8 :2 36 :2 1f 6c :2 1c
:2 19 :4 25 :2 19 16 :3 35 1a :2 23 2e
2c :2 37 :2 2c 19 1d 26 34 :2 1d
37 39 :2 37 1c 40 49 52 :2 40
55 57 :2 55 3f :2 1c 26 3d 56
5e 65 7e 86 8d a9 b5 24
35 40 4d 25 32 43 4b 23
2f 3c 52 :2 1f :2 28 34 1f 1c
24 22 :2 2b 37 22 32 :2 1f :2 24
22 :2 2b 37 22 25 :2 2f 41 :2 4b
57 5b 6a 6e 6f :2 6a :2 41 :3 25
:2 2b 30 3c 7b 7e :2 3c 8b 8e
:2 3c 92 95 :2 3c a1 a4 :2 3c ac
af :2 3c bb be c5 ce d1 :2 be
:2 3c :2 25 72 :2 22 :2 1f :4 2b :2 1f 1c
:4 5a 1c 2b :2 1c :4 19 16 47 1d
:2 26 31 2f :2 3a :2 2f 1c 23 3a
53 5b 62 80 88 8f aa b2
b9 d5 e1 21 32 3d 4a 22
2f 40 48 20 2c 39 4f :2 1c
:2 25 31 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 67 6b
6c :2 67 :2 3e :3 22 :2 28 2d 39 78
7b :2 39 88 8b :2 39 8f 92 :2 39
9e a1 :2 39 a9 ac :2 39 b8 bb
c2 cb ce :2 bb :2 39 :2 22 6f :2 1f
:2 1c :4 28 :2 1c 19 :4 4a 47 :2 16 35
20 37 4f 57 5e 7c 84 8b
a6 ae b5 d1 dd 1e 2f 3a
47 1f 2c 3d 45 1d 29 36
4c :2 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
64 68 69 :2 64 :2 3b :3 1f :2 25 2a
36 75 78 :2 36 85 88 :2 36 8c
8f :2 36 9b 9e :2 36 a6 a9 :2 36
b5 b8 bf c8 cb :2 b8 :2 36 :2 1f
6c :2 1c :2 19 :4 25 :2 19 16 :7 13 :4 10
14 :2 1d 28 26 :2 31 :2 26 13 16
1f 28 :2 16 2b 2d :2 2b 16 24
16 2f :4 1a 19 1c 20 22 :2 20
1c 2c 1c 26 2a 3a 24 25
32 43 57 23 34 3c 43 5d
65 6c :2 1f :2 28 34 1f 1c 24
22 :2 2b 37 22 32 :2 1f :2 24 22
:2 2b 37 22 25 :2 2f 41 :2 4b 57
5b 6a 6e 6f :2 6a :2 41 :3 25 :2 2b
30 3c 7b 7e :2 3c 8b 8e :2 3c
92 95 :2 3c a1 a4 :2 3c ac af
:2 3c bb be c5 ce d1 :2 be :2 3c
:2 25 72 :2 22 :2 1f :4 2b :2 1f 1c :4 24
1c 2c 1c 26 2a 3a 24 25
32 43 57 23 2f 37 3e :2 1f
:2 28 34 1f 1c 24 22 :2 2b 37
22 32 :2 1f :2 24 22 :2 2b 37 22
25 :2 2f 41 :2 4b 57 5b 6a 6e
6f :2 6a :2 41 :3 25 :2 2b 30 3c 7b
7e :2 3c 8b 8e :2 3c 92 95 :2 3c
a1 a4 :2 3c ac af :2 3c bb be
c5 ce d1 :2 be :2 3c :2 25 72 :2 22
:2 1f :4 2b :2 1f 1c :7 19 1c 25 33
:2 1c 38 36 41 4b :2 38 :2 36 1c
27 30 39 :2 27 3c 3e :2 27 1c
21 1c 4e :2 19 37 :3 16 24 16
:4 13 41 13 1e 27 30 :2 1e 33
35 :2 1e 13 18 13 :5 10 1e :2 10
1c 10 1a 25 32 3a 41 56
61 66 :2 18 :2 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 62 63 :2 5e :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:3 2c 24 2c 33 4b 53 5a 73
85 :2 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 62 63 :2 5e :2 35 :3 19 :2 1f
24 30 6f 72 :2 30 7f 82 :2 30
86 89 :2 30 95 98 :2 30 a0 a3
:2 30 af b2 b9 c2 c5 :2 b2 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :3 2c
10 1b :2 10 1f 10 13 1c 29
:2 13 2c 2e :2 2c 13 1f 13 30
:3 10 1c 28 39 47 52 5c 68
1b 28 35 42 4f 1b 28 34
3e 46 4f 57 5e 1b 27 34
3f 4a 58 1b 26 32 3e 41
44 4a 50 :2 1c 10 13 1c 1e
:2 1c 16 1f 2c :2 16 2f 31 :2 2f
20 33 50 57 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 64 68
69 :2 64 :2 3b :3 1f :2 25 2a 36 75
78 :2 36 85 88 :2 36 8c 8f :2 36
9b 9e :2 36 a6 a9 :2 36 b5 b8
bf c8 cb :2 b8 :2 36 :2 1f 6c :2 1c
:2 19 :4 25 :2 19 16 :4 33 20 33 50
57 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 64 68 69 :2 64 :2 3b
:3 1f :2 25 2a 36 75 78 :2 36 85
88 :2 36 8c 8f :2 36 9b 9e :2 36
a6 a9 :2 36 b5 b8 bf c8 cb
:2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25 :2 19
16 :7 13 20 :2 10 d 2c 13 1c
28 :2 13 2b 2d :2 2b 10 1e :2 10
1f 10 13 1a 26 29 :2 13 2c
2e :2 2c 13 1e :2 27 13 32 13
1e 27 33 :2 1e 13 :5 10 1c 28
35 43 4e 58 64 1b 28 35
42 4f 1b 28 34 3e 46 4f
57 5e 1b 27 34 3f 4a 58
1b 26 32 3e 41 44 4a 50
:2 1c 10 13 1c 1e :2 1c 1d 30
4d 54 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 61 65 66 :2 61
:2 38 :3 1c :2 22 27 33 72 75 :2 33
82 85 :2 33 89 8c :2 33 98 9b
:2 33 a3 a6 :2 33 b2 b5 bc c5
c8 :2 b5 :2 33 :2 1c 69 :2 19 :2 16 :4 22
:2 16 13 :4 20 :2 10 2f 2c :3 d 18
21 2a :2 18 2d 2f :2 18 d f
d :3 30 e a 17 :2 7 :4 4 8
11 14 :2 11 7 1c 25 2d :2 1c
30 32 :2 30 1b :2 7 a 13 22
:2 a 25 27 :2 25 19 34 48 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :4 29
14 2d 3b 4a 58 13 27 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5c 5d :2 58 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :7 7
a 13 15 :2 13 d :2 17 29 :2 33
3f 43 52 56 57 :2 52 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 87 8a 93 9b
:2 a4 :2 93 ba :2 8a :2 24 c2 c5 :2 24
cd d0 :2 24 d5 d8 :2 24 e1 e4
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 51 55 56 :2 51 :2 29 :3 d
:2 13 18 24 63 66 :2 24 :2 d 59
:3 a :2 15 29 :2 32 47 51 :2 a 7
19 d 18 16 :2 21 :2 16 d :2 17
29 :2 33 3f 43 52 56 57 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 c3 :2 8a :2 24 cb
ce :2 24 d6 d9 :2 24 de e1 :2 24
ea ed :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 51 55 56 :2 51
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 50 12
:2 a 7 3e 19 d 18 16 :2 21
:2 16 d :2 17 29 :2 33 3f 43 52
56 57 :2 52 :2 29 :3 d :2 13 18 24
63 66 :2 24 73 76 :2 24 7a 7d
:2 24 87 8a 93 9b :2 a4 :2 93 c0
:2 8a :2 24 c8 cb :2 24 d3 d6 :2 24
db de :2 24 e7 ea :2 24 :2 d 5a
:2 a d :2 17 29 :2 33 3f 42 51
55 56 :2 51 :2 29 :3 d :2 13 18 24
63 66 :2 24 :2 d 59 :3 a :2 15 29
:2 32 4d 12 :2 a 3b 19 d :2 17
29 :2 33 3f 43 52 56 57 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 bc :2 8a :2 24 c4
c7 :2 24 cf d2 :2 24 d7 da :2 24
e6 e9 :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 51 55 56 :2 51
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 49 56
:2 a :4 7 35 :2 4 8 11 18 :2 11
25 :2 8 28 2a :2 28 7 32 3b
42 :2 3b 50 :2 32 53 55 :2 53 31
:3 7 f 19 :3 7 :2 10 1c :2 7 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f 3e
41 :2 f 4e 51 :2 f e 11 :2 f
2d 30 :2 f 3b 3e :2 f 5a 5d
:2 f 13 16 :2 f 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :3 10 :2 16 1b 3f 48 4b :2 3f
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 58
7 f 19 :3 7 :2 10 1c :2 7 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 25
28 :2 d 35 38 :2 d e 11 :2 d
28 2b :2 d 36 39 :2 d 55 58
:2 d 13 16 :2 d 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :3 10 :2 16 1b 3f 48 4b :2 3f
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 58
7 :2 10 :3 1c :2 7 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d 4e 51 :2 d 13 16 :2 d e
11 :2 d 4b 4e :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d 13 16
:2 d 21 24 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d 4f 52 :2 d 13
16 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 2d 30
:2 d 3c 3f :2 d e 11 :2 d 7
a 12 1c :2 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :3 10 :2 16 1b 3f
48 4b :2 3f :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 58 7 d e 11 :2 d
e 11 :2 d e 11 :2 d 3b 3e
46 4f 58 :2 46 :2 3e :2 d 13 16
:2 d e 11 :2 d 15 18 20 29
34 :2 20 :2 18 :2 d 13 16 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 55
58 60 13 1c :2 60 :2 58 :2 d 20
23 :2 d e 11 :2 d 2c 2f 37
40 4b :2 37 :2 2f :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d 7 4 58 a
13 1a :2 13 28 :2 a 2b 2d :2 2b
7 f 19 :3 7 :2 10 1c :2 7 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f 3e
41 :2 f 4e 51 :2 f e 11 :2 f
27 2a :2 f 35 38 :2 f 7 a
12 1c :2 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :3 10 :2 16 1b 3f 48
4b :2 3f :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 2f 7 f 19 :3 7 :2 10 1c
:2 7 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f e 11
:2 f 3b 3e :2 f 4b 4e :2 f 13
16 :2 f 21 24 :2 f 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :3 10 :2 16 1b 3f 48 4b
:2 3f :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 2f 7 :2 10 :3 1c :2 7 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d 4e 51 :2 d 13 16 :2 d e
11 :2 d 4b 4e :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d 2e 31
:2 d 3c 3f :2 d 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :3 10 :2 16 1b 3f 48 4b :2 3f
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 2f
7 d e 11 :2 d e 11 :2 d
e 11 :2 d 48 4b 53 5c 65
:2 53 :2 4b :2 d 13 16 :2 d e 11
19 22 2d :2 19 :2 11 :2 d 13 16
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 7 2f 58
7 f 19 :3 7 :2 10 1c :2 7 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f e
11 :2 f 28 2b :2 f 38 3b :2 f
e 11 :2 f 2d 30 :2 f 3c 3f
:2 f e 11 :2 f 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :3 10 :2 16 1b 3f 48 4b :2 3f
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 4
7 f 19 :3 7 :2 10 1c :2 7 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f 3b
3e :2 f 4b 4e :2 f 13 16 :2 f
22 25 :2 f 7 a 12 1c :2 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:3 10 :2 16 1b 3f 48 4b :2 3f :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 4 7
:2 10 :3 1c :2 7 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 4e
51 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 2d 30
:2 d 3c 3f :2 d 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :3 10 :2 16 1b 3f 48 4b :2 3f
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 4
7 f e 11 :2 f e 11 :2 f
e 11 :2 f 13 16 1e 27 30
:2 1e :2 16 :2 f 34 37 :2 f e 11
:2 f 54 57 5f 13 1e :2 5f :2 57
:2 f 13 16 :2 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
7 :4 4 7 :2 11 23 :2 2d 39 3c
4b 4f 50 :2 4b :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e :2 7 53 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4f 50
:2 4b :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :2 7 53 :3 4 b :2 16 26 :2 b
4 1 9 12 9 a :2 14 26
:2 30 3c 40 4f 53 54 :2 4f :2 26
:3 a :2 10 15 21 60 63 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 57
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4c 50 51 :2 4c :2 23
:3 7 :2 d 12 1e 5d 60 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 54 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
330d
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :5 1e :5 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :7 42 :7 43
:6 44 :7 45 :6 46 :7 47
:7 48 :7 49 :6 4a :6 4b
:6 4c :7 4d :7 4e :6 4f
:6 50 :7 51 :6 52 :6 53
:6 54 :6 55 :5 56 :7 58
:b 5a :11 5b 5c :2 5b
:2 5c :2 5b :2 5c :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5f :2 5b :9 5f :2 5b
:2 60 :2 5b :9 60 :2 5b
:2 61 :2 5b :9 61 :2 5b
:2 62 :2 5b :9 62 :2 5b
:2 63 :2 5b :9 63 :2 5b
:2 64 :2 5b :9 64 :2 5b
:2 65 :2 5b :9 65 :2 5b
:2 66 :2 5b :9 66 :2 5b
:2 67 :2 5b :9 67 :2 5b
:2 68 :2 5b :9 68 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :4 5b :3 5a :11 6d
:b 6e :3 6d :3 76 :3 77
:3 78 :3 79 :3 7b :3 7d
:3 7f :3 81 :3 82 :3 83
:3 84 :3 85 :3 86 :3 87
:3 89 :3 8a :3 8b :a 8c
:3 8d :3 92 :3 93 :5 95
:11 96 :20 97 :3 96 :11 99
:b 9a :3 99 :9 9c :3 95
:5 9f :11 a0 :20 a1 :3 a0
:11 a3 :b a4 :3 a3 :9 a6
:3 9f :1f a9 :11 aa :20 ab
:3 aa :11 ad :b ae :3 ad
:9 b0 :3 a9 :e b3 :6 b5
b6 b7 b5 :5 b8
b4 ba :5 bb :3 ba
:2 bc :5 be :11 bf :24 c0
:3 bf :2 bd :6 bc b9
:3 b3 :16 c5 :11 c6 :20 c7
:3 c6 :11 c9 :b ca :3 c9
:9 cc :3 c5 :3 cf d0
b3 :e d0 :2 d2 d3
d2 :5 d4 d1 d6
:5 d7 :3 d6 :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d5 :4 d0 :3 b3
:3 e2 :5 e3 :3 e4 :3 e3
:8 e7 :8 e8 :3 e9 :9 eb
:d ed :b ee :c f0 :6 f2
:4 f3 :3 f4 f2 :5 f5
f1 f7 :5 f8 :3 f7
:2 f9 :5 fb :11 fc :24 fd
:3 fc :2 fa :6 f9 f6
:4 f0 :a 103 :8 104 :5 105
:7 106 :27 107 103 :5 108
102 10a :5 10b :3 10a
:2 10c :5 10e :11 10f :24 110
:3 10f :2 10d :6 10c 109
:4 101 :3 f0 :a 116 :4 118
:3 119 118 :5 11a 117
11c :5 11d :3 11c :2 11e
:5 120 :11 121 :24 122 :3 121
:2 11f :6 11e 11b :3 116
:a 127 :5 128 :3 129 :3 128
:5 12c :3 12d :3 12e 12c
:5 12f 12b 131 :5 132
:3 131 :2 133 :5 135 :11 136
:24 137 :3 136 :2 134 :6 133
130 :4 127 :11 13c :30 13d
:3 13c :11 13f :b 140 :3 13f
:a 142 13b :3 127 116
:3 145 144 :3 116 :3 148
:2 14a 14b :2 14c 14a
:5 14d 149 14f :5 150
:3 14f :2 151 :5 153 :11 154
:24 155 :3 154 :2 152 :6 151
14e :3 eb :9 15a :2 15c
15d :2 15e 15c :5 15f
15b 161 :5 162 :3 161
:2 163 :5 165 :11 166 :24 167
:3 166 :2 164 :6 163 160
:3 15a :b 16c :11 16d :30 16e
:3 16d :11 170 :b 171 :3 170
:a 173 :3 16c :3 15a eb
:5 178 :3 179 :3 17a 178
:5 17b 177 17d :5 17e
:3 17d :2 17f :5 181 :11 182
:24 183 :3 182 :2 180 :6 17f
17c :3 176 :a 187 :6 189
:5 18a 188 18c :5 18d
:3 18c :2 18e :5 190 :11 191
:24 192 :3 191 :2 18f :6 18e
18b :3 187 :a 196 :11 197
:30 198 :3 197 :11 19a :b 19b
:3 19a :a 19d :3 196 :3 187
176 :3 eb :c 1a2 :2 1a3
:2 1a2 :6 1a3 :3 1a2 :a 1a3
:2 1a2 :c 1a4 :2 1a5 :2 1a4
:6 1a5 :2 1a4 :3 1a6 1a5
:2 1a4 :3 1a9 :3 1aa 1a3
:5 1ac :3 1ad :3 1ae :e 1af
:b 1b0 :2 1b1 :2 1b0 :a 1b1
:8 1b2 :3 1af :b 1b4 :11 1b5
:20 1b6 :3 1b5 :11 1b8 :b 1b9
:3 1b8 :9 1bb 1bc 1b4
:9 1bc :11 1bd :2e 1be :3 1bd
:11 1c0 :b 1c1 :3 1c0 :c 1c3
1bc :3 1b4 :3 1c6 :5 1c7
:3 1c8 :3 1c7 1ac :3 1cb
:9 1cd :f 1ce :3 1cd 1ca
:3 1ac :16 1d1 :16 1d2 :3 1d3
1d4 1d2 :9 1d4 :3 1d5
1d6 1d4 1d2 :16 1d6
:3 1d7 1d8 1d6 1d2
:9 1d8 :3 1d9 1d8 :3 1d2
:3 1d1 1ab :3 1a2 :5 1de
:3 1e0 :3 1e1 :14 1e3 :d 1e5
:9 1e7 :7 1e8 1e9 :3 1e8
:b 1eb :9 1ec :5 1ed :3 1ec
:11 1f0 :2e 1f1 :3 1f0 :11 1f3
:b 1f4 :3 1f3 :c 1f6 :3 1eb
:14 1f9 :11 1fa :2e 1fb :3 1fa
:11 1fd :b 1fe :3 1fd :c 200
:3 1f9 :3 203 :9 206 :2 207
208 :2 209 :2 20a :2 20b
:2 20c 206 :5 20d 205
20f :5 210 :3 20f :2 211
:5 213 :11 214 :24 215 :3 214
:2 212 :6 211 20e :3 1e7
:12 21a :3 21b :9 21c :3 21d
:3 21c :3 21a :3 221 :3 222
:5 223 :a 224 :2 226 :9 227
:9 228 :3 229 :4 22a 22b
:6 22c 226 :5 22d 225
22f :5 230 :3 22f :2 231
:5 233 :11 234 :24 235 :3 234
:2 232 :6 231 22e :3 224
:a 23a :3 23b :16 23c :2 23e
:9 23f :9 240 :2 241 :3 242
243 :6 244 23e :5 245
23d 247 :5 248 :3 247
:2 249 :5 24b :11 24c :24 24d
:3 24c :2 24a :6 249 246
:4 23c :3 252 251 :3 23c
254 23a :16 254 :2 256
:9 257 :9 258 :2 259 :3 25a
25b :6 25c 256 :5 25d
255 25f :5 260 :3 25f
:2 261 :5 263 :11 264 :24 265
:3 264 :2 262 :6 261 25e
:4 254 :3 23a 224 :2 26c
:9 26d :9 26e :2 26f :3 270
271 :6 272 26c :5 273
26b 275 :5 276 :3 275
:2 277 :5 279 :11 27a :24 27b
:3 27a :2 278 :6 277 274
:4 26a :3 224 223 :a 281
:e 283 :4 284 285 :6 286
283 :5 287 282 289
:5 28a :3 289 :2 28b :5 28d
:11 28e :24 28f :3 28e :2 28c
:6 28b 288 :3 281 :a 294
:3 295 :16 296 :a 298 :3 299
29a :6 29b 298 :5 29c
297 29e :5 29f :3 29e
:2 2a0 :5 2a2 :11 2a3 :24 2a4
:3 2a3 :2 2a1 :6 2a0 29d
:4 296 :3 2a9 2aa 2a8
:3 296 2ac 294 :a 2ac
:d 2ae :3 2af 2b0 :6 2b1
2ae :5 2b2 2ad 2b4
:5 2b5 :3 2b4 :2 2b6 :5 2b8
:11 2b9 :24 2ba :3 2b9 :2 2b7
:6 2b6 2b3 :4 2ac :3 294
281 :d 2c1 :3 2c2 2c3
:6 2c4 2c1 :5 2c5 2c0
2c7 :5 2c8 :3 2c7 :2 2c9
:5 2cb :11 2cc :24 2cd :3 2cc
:2 2ca :6 2c9 2c6 :4 2bf
:3 281 280 :3 223 :a 2d4
:9 2d5 :11 2d6 :30 2d7 :3 2d6
:11 2d9 :b 2da :3 2d9 :a 2dc
2dd 2d5 :10 2dd :5 2de
:3 2df :3 2e1 2e2 :4 2e3
:7 2e4 2e1 :5 2e5 2e0
2e7 :5 2e8 :3 2e7 :2 2e9
:5 2eb :11 2ec :24 2ed :3 2ec
:2 2ea :6 2e9 2e6 :4 2de
:3 2f2 :3 2f4 2f5 :4 2f6
:4 2f7 2f4 :5 2f8 2f3
2fa :5 2fb :3 2fa :2 2fc
:5 2fe :11 2ff :24 300 :3 2ff
:2 2fd :6 2fc 2f9 :4 2f1
:3 2de :d 306 :11 307 :30 308
:3 307 :11 30a :b 30b :3 30a
:a 30d :3 306 2dd :3 2d5
:3 310 311 2d4 :19 311
:11 312 :30 313 :3 312 :11 315
:b 316 :3 315 :a 318 311
:3 2d4 :a 31b :c 31c :d 31f
:5 320 321 :2 322 31f
:5 323 31e 325 :5 326
:3 325 :2 327 :5 329 :11 32a
:24 32b :3 32a :2 328 :6 327
324 :3 31b :a 330 :11 331
:30 332 :3 331 :11 334 :b 335
:3 334 :a 337 :3 330 :16 33a
:2 33b :2 33a :8 33b :6 33a
:11 33c :30 33d :3 33c :11 33f
:b 340 :3 33f :a 342 33b
:2 33a :6 346 347 :5 348
346 :5 349 345 34b
:5 34c :3 34b :2 34d :5 34f
:11 350 :24 351 :3 350 :2 34e
:6 34d 34a :4 31b :c 356
:6 359 :5 35a 358 35c
:5 35d :3 35c :2 35e :5 360
:11 361 :24 362 :3 361 :2 35f
:6 35e 35b :3 355 :a 367
:11 368 :30 369 :3 368 :11 36b
:b 36c :3 36b :a 36e :3 367
:c 372 :2 373 374 :5 375
372 :5 376 371 378
:5 379 :3 378 :2 37a :5 37c
:11 37d :24 37e :3 37d :2 37b
:6 37a 377 :3 355 :16 383
:11 384 :30 385 :3 384 :11 387
:b 388 :3 387 :a 38a :3 383
:6 38e 38f :5 390 38e
:5 391 38d 393 :5 394
:3 393 :2 395 :5 397 :11 398
:24 399 :3 398 :2 396 :6 395
392 :4 355 :3 31b :3 39f
:9 3a1 :9 3a3 3a4 3a3
:5 3a5 3a2 3a7 :5 3a8
:3 3a7 :2 3a9 :5 3ab :11 3ac
:24 3ad :3 3ac :2 3aa :6 3a9
3a6 :3 3a1 :7 3b3 3b4
3b5 3b6 3b3 :5 3b7
3b2 3b9 :5 3ba :3 3b9
:2 3bb :5 3bd :11 3be :24 3bf
:3 3be :2 3bc :6 3bb 3b8
:3 3a1 :3 3c4 :3 3c5 :9 3c6
:3 3c7 :3 3c6 :8 3ca :5 3cb
:8 3cc :6 3cd :8 3ce :3 3ca
:5 3d0 :9 3d1 :5 3d3 :6 3d4
:5 3d5 3d4 :5 3d7 3d6
:3 3d4 3d2 3da :5 3db
:3 3da :2 3dc :5 3de :11 3df
:24 3e0 :3 3df :2 3dd :6 3dc
3d9 :4 3d1 :5 3e6 :6 3e7
:5 3e8 3e7 :5 3ea 3e9
:3 3e7 3e5 3ed :5 3ee
:3 3ed :2 3ef :5 3f1 :11 3f2
:24 3f3 :3 3f2 :2 3f0 :6 3ef
3ec :4 3e4 :3 3d1 :3 3d0
3a1 :3 3fb :3 3fc :a 3fe
:5 3ff 3fe :d 401 400
:3 3fe :8 404 :5 405 :8 406
:6 407 :8 408 :3 404 :5 40a
:5 40c :6 40d :5 40e 40d
:5 410 40f :3 40d 40b
413 :5 414 :3 413 :2 415
:5 417 :11 418 :24 419 :3 418
:2 416 :6 415 412 :6 40a
3f9 :3 3a1 1e7 :c 422
:3 423 422 :16 425 424
:3 422 :5 427 :3 428 :c 429
:3 42a :17 42d :1b 42f :3 431
:3 432 :3 433 :3 434 :5 437
438 :4 439 :4 43a 437
:5 43b 436 43d :5 43e
:3 43d :2 43f :5 441 :11 442
:24 443 :3 442 :2 440 :6 43f
43c :3 429 :12 448 :3 449
:b 44a :3 44b :3 44a :3 448
:a 44f :5 450 :c 451 :3 452
451 :c 454 :c 455 453
:3 451 44f :c 458 :3 459
458 :c 45b :c 45c 45a
:3 458 457 :3 44f :3 460
:3 461 :9 463 :5 464 :a 465
:8 467 :9 468 :4 469 46a
:6 46b 467 :5 46c 466
46e :5 46f :3 46e :2 470
:5 472 :11 473 :24 474 :3 473
:2 471 :6 470 46d :3 465
:a 479 :3 47a :16 47b :8 47d
:8 47e :3 47f 480 :6 481
47d :5 482 47c 484
:5 485 :3 484 :2 486 :5 488
:11 489 :24 48a :3 489 :2 487
:6 486 483 :4 47b :3 48f
48e :3 47b 491 479
:16 491 :8 493 :8 494 :3 495
496 :6 497 493 :5 498
492 49a :5 49b :3 49a
:2 49c :5 49e :11 49f :24 4a0
:3 49f :2 49d :6 49c 499
:4 491 :3 479 465 :8 4a7
:8 4a8 :4 4a9 :4 4aa :4 4ab
4a7 :5 4ac 4a6 4ae
:5 4af :3 4ae :2 4b0 :5 4b2
:11 4b3 :24 4b4 :3 4b3 :2 4b1
:6 4b0 4ad :4 4a5 :3 465
464 :a 4ba :e 4bc :5 4bd
:4 4be :4 4bf 4bc :5 4c0
4bb 4c2 :5 4c3 :3 4c2
:2 4c4 :5 4c6 :11 4c7 :24 4c8
:3 4c7 :2 4c5 :6 4c4 4c1
:3 4ba :a 4cd :16 4ce :a 4d0
:4 4d1 :4 4d2 :4 4d3 4d0
:5 4d4 4cf 4d6 :5 4d7
:3 4d6 :2 4d8 :5 4da :11 4db
:24 4dc :3 4db :2 4d9 :6 4d8
4d5 :4 4ce :3 4e1 4e2
4e0 :3 4ce 4e4 4cd
:a 4e4 :d 4e6 :4 4e7 :4 4e8
:4 4e9 4e6 :5 4ea 4e5
4ec :5 4ed :3 4ec :2 4ee
:5 4f0 :11 4f1 :24 4f2 :3 4f1
:2 4ef :6 4ee 4eb :4 4e4
:3 4cd 4ba :d 4f9 :4 4fa
:4 4fb :4 4fc 4f9 :5 4fd
4f8 4ff :5 500 :3 4ff
:2 501 :5 503 :11 504 :24 505
:3 504 :2 502 :6 501 4fe
:4 4f7 :3 4ba 4b9 :3 464
:a 50c :9 50d :3 50e 50d
:5 510 :5 511 :3 512 :3 514
515 :4 516 :7 517 514
:5 518 513 51a :5 51b
:3 51a :2 51c :5 51e :11 51f
:24 520 :3 51f :2 51d :6 51c
519 :4 511 :3 525 :3 527
528 :4 529 :4 52a 527
:5 52b 526 52d :5 52e
:3 52d :2 52f :5 531 :11 532
:24 533 :3 532 :2 530 :6 52f
52c :4 524 :3 511 :d 538
:b 539 :2 53a :3 538 :3 510
:3 53d 50f :3 50d 50c
:b 540 :2 541 53f :3 50c
:3 544 :3 545 :8 548 549
54a 548 :5 54b 547
54d :5 54e :3 54d :2 54f
:5 551 :11 552 :24 553 :3 552
:2 550 :6 54f 54c :3 463
:8 559 55a 55b 559
:5 55c 558 55e :5 55f
:3 55e :2 560 :5 562 :11 563
:24 564 :3 563 :2 561 :6 560
55d :3 463 :3 569 :3 56a
:9 56b :3 56c :3 56b :8 56f
:5 570 :8 571 :6 572 :8 573
:3 56f :5 575 :9 576 :5 578
:6 579 :5 57a 579 :5 57c
57b :3 579 577 57f
:5 580 :3 57f :2 581 :5 583
:11 584 :24 585 :3 584 :2 582
:6 581 57e :4 576 :5 58b
:6 58c :5 58d 58c :5 58f
58e :3 58c 58a 592
:5 593 :3 592 :2 594 :5 596
:11 597 :24 598 :3 597 :2 595
:6 594 591 :4 589 :3 576
:3 575 59e 463 :9 59e
:3 59f :3 5a0 :a 5a2 :5 5a3
5a2 :7 5a5 5a4 :3 5a2
:8 5a8 :5 5a9 :8 5aa :6 5ab
:8 5ac :3 5a8 :5 5ad :5 5af
:6 5b0 :5 5b1 5b0 :5 5b3
5b2 :3 5b0 5ae 5b6
:5 5b7 :3 5b6 :2 5b8 :5 5ba
:11 5bb :24 5bc :3 5bb :2 5b9
:6 5b8 5b5 :6 5ad 59e
:3 463 :b 5c2 5c3 5c4
:3 429 5c5 429 :3 427
41f :3 1e7 :12 5ca :9 5cb
:4 5cd :6 5ce :5 5cf 5ce
:5 5d1 5d0 :3 5ce 5cc
5d4 :5 5d5 :3 5d4 :2 5d6
:5 5d8 :11 5d9 :24 5da :3 5d9
:2 5d7 :6 5d6 5d3 :4 5cb
:5 5e0 :2 5e1 5e0 :6 5e2
:5 5e3 5e2 :5 5e5 5e4
:3 5e2 5df 5e8 :5 5e9
:3 5e8 :2 5ea :5 5ec :11 5ed
:24 5ee :3 5ed :2 5eb :6 5ea
5e7 :4 5de :3 5cb :5 5f4
:11 5f5 :30 5f6 :3 5f5 :11 5f8
:b 5f9 :3 5f8 :a 5fb 5fc
5f4 :7 5fc :11 5fd :30 5fe
:3 5fd :11 600 :b 601 :3 600
:7 603 604 :2 603 605
5fc 5f4 :7 605 :11 606
:30 607 :3 606 :11 609 :b 60a
:3 609 :7 60c 60d :2 60c
605 5f4 :11 60f :30 610
:3 60f :11 612 :b 613 :3 612
:a 615 60e :3 5f4 :3 5ca
:1c 619 :5 61b :5 61c :2 61e
:2 61f :2 61e :2 620 :2 61e
:2 621 :2 61e :2 622 :2 61e
:2 623 :2 61e :2 623 :2 61e
:2 623 :2 61e :2 624 :2 61e
:2 624 :2 61e :2 624 :2 61e
:2 624 :2 61e :2 625 :3 61e
:5 628 :6 629 :5 62a 629
:5 62c 62b :3 629 627
62f :5 630 :3 62f :2 631
:5 633 :11 634 :24 635 :b 636
:3 634 :2 632 :6 631 62e
:3 619 :5 63c :5 63d 63f
640 :2 641 :2 640 :2 642
:2 640 :2 643 :2 640 :2 644
:2 640 :2 645 :2 640 :2 645
:2 640 :2 645 :2 640 :2 646
:2 640 :2 646 :2 640 :2 646
:2 640 :2 646 :2 640 :2 647
:2 640 63f :5 64a :6 64b
:5 64c 64b :5 64e 64d
:3 64b 649 651 :5 652
:3 651 :2 653 :5 655 :11 656
:24 657 :b 658 :3 656 :2 654
:6 653 650 :3 619 :7 65d
65f 660 :2 661 :2 660
:2 662 :2 660 :2 663 :2 660
:2 664 :2 660 :2 665 :2 660
:2 666 :2 660 :2 667 :2 660
:2 668 :2 660 :2 669 :2 660
:2 66a :2 660 :2 66b :2 660
:2 66c :2 660 :2 66c :2 660
:2 66d :2 660 :2 66e :2 660
:2 66e :2 660 :2 66f :2 660
:2 670 :2 660 :2 671 :2 660
:2 672 :2 660 :2 672 :2 660
:2 673 :2 660 :2 674 :2 660
:2 675 :2 660 :2 676 :2 660
:2 677 :2 660 :2 678 :2 660
:2 679 :2 660 :2 67a :2 660
:2 67a :2 660 :2 67b :2 660
:2 67c :2 660 :2 67d :2 660
:2 67e :2 660 :2 67f :2 660
:2 67f :2 660 :2 67f :2 660
:2 680 :2 660 65f :5 683
:6 684 :5 685 684 :5 687
686 :3 684 682 68a
:5 68b :3 68a :2 68c :5 68e
:11 68f :24 690 :b 691 :3 68f
:2 68d :6 68c 689 :3 619
696 697 :2 698 :2 697
:2 699 :2 697 :2 69a :2 697
:9 69a :2 697 :2 69b :2 697
:2 69c :2 697 :9 69c :2 697
:2 69d :2 697 :2 69e :2 697
:2 69f :2 697 :2 6a0 :2 697
:2 6a1 :2 697 :2 6a2 :2 697
:2 6a3 :2 697 :2 6a4 :2 697
:2 6a5 :2 697 :3 6a5 :2 6a6
:4 6a5 :2 697 :2 6a6 :2 697
:2 6a7 :2 697 :9 6a7 :2 697
:2 6a8 :2 697 :2 6a9 :2 697
:2 6aa :2 697 :2 6ab :2 697
:2 6ac :2 697 696 6ad
619 :c 6ad :5 6af :5 6b0
:2 6b2 :2 6b3 :2 6b2 :2 6b4
:2 6b2 :2 6b5 :2 6b2 :2 6b6
:2 6b2 :2 6b7 :2 6b2 :2 6b7
:2 6b2 :2 6b7 :2 6b2 :2 6b8
:2 6b2 :2 6b8 :2 6b2 :2 6b8
:3 6b2 :5 6bb :6 6bc :5 6bd
6bc :5 6bf 6be :3 6bc
6ba 6c2 :5 6c3 :3 6c2
:2 6c4 :5 6c6 :11 6c7 :24 6c8
:b 6c9 :3 6c7 :2 6c5 :6 6c4
6c1 :3 6ad :5 6cf :5 6d0
:2 6d2 :2 6d3 :2 6d2 :2 6d4
:2 6d2 :2 6d5 :2 6d2 :2 6d6
:2 6d2 :2 6d7 :2 6d2 :2 6d7
:2 6d2 :2 6d7 :2 6d2 :2 6d8
:2 6d2 :2 6d8 :3 6d2 :5 6db
:6 6dc :5 6dd 6dc :5 6df
6de :3 6dc 6da 6e2
:5 6e3 :3 6e2 :2 6e4 :5 6e6
:11 6e7 :24 6e8 :b 6e9 :3 6e7
:2 6e5 :6 6e4 6e1 :3 6ad
:7 6ee 6ef 6f0 :2 6f1
:2 6f0 :2 6f2 :2 6f0 :2 6f3
:2 6f0 :2 6f4 :2 6f0 :2 6f5
:2 6f0 :2 6f6 :2 6f0 :2 6f7
:2 6f0 :2 6f8 :2 6f0 :2 6f9
:2 6f0 :2 6f9 :2 6f0 :2 6fa
:2 6f0 :2 6fb :2 6f0 :2 6fb
:2 6f0 :2 6fc :2 6f0 :2 6fd
:2 6f0 :2 6fe :2 6f0 :2 6fe
:2 6f0 :2 6fe :2 6f0 6ef
:5 701 :6 702 :5 703 702
:5 705 704 :3 702 700
708 :5 709 :3 708 :2 70a
:5 70c :11 70d :24 70e :b 70f
:3 70d :2 70b :6 70a 707
:3 6ad 714 715 :2 716
:2 715 :2 717 :2 715 :2 718
:2 715 :9 718 :2 715 :2 719
:2 715 :9 71a :2 715 :2 71b
:2 715 :2 71c :2 715 :2 71d
:2 715 :2 71e :2 715 :2 71f
:2 715 714 6ad 619
:5 722 :5 723 :2 725 :2 726
:2 725 :2 727 :2 725 :2 728
:2 725 :2 729 :2 725 :2 72a
:2 725 :2 72b :2 725 :2 72b
:2 725 :2 72b :2 725 :2 72c
:2 725 :2 72c :2 725 :2 72c
:2 725 :2 72d :3 725 :5 730
:6 731 :5 732 731 :5 734
733 :3 731 72f 737
:5 738 :3 737 :2 739 :5 73b
:11 73c :24 73d :b 73e :3 73c
:2 73a :6 739 736 :3 720
:5 744 :5 745 :2 747 :2 748
:2 747 :2 749 :2 747 :2 74a
:2 747 :2 74b :2 747 :2 74c
:2 747 :2 74c :2 747 :2 74c
:2 747 :2 74d :2 747 :2 74d
:3 747 :5 750 :6 751 :5 752
751 :5 754 753 :3 751
74f 757 :5 758 :3 757
:2 759 :5 75b :11 75c :24 75d
:b 75e :3 75c :2 75a :6 759
756 :3 720 :7 763 765
766 :2 767 :2 766 :2 768
:2 766 :2 769 :2 766 :2 76a
:2 766 :2 76b :2 766 :2 76c
:2 766 :2 76d :2 766 :2 76e
:2 766 :2 76f :2 766 :2 76f
:2 766 :2 770 :2 766 :2 771
:2 766 :2 772 :2 766 :2 773
:2 766 :2 773 :2 766 :2 773
:2 766 765 :5 776 :6 777
:5 778 777 :5 77a 779
:3 777 775 77d :5 77e
:3 77d :2 77f :5 781 :11 782
:24 783 :b 784 :3 782 :2 780
:6 77f 77c :3 720 :2 789
:2 78a :2 789 :2 78b :2 789
:2 78c :2 789 :9 78d :2 789
:2 78d :2 789 :2 78e :2 789
:3 78e :2 78f :4 78e :2 789
:2 790 :2 789 :2 791 :2 789
:2 792 :2 789 :2 793 :2 789
:2 794 :3 789 720 :3 619
:11 798 :b 799 :3 798 :11 79b
:b 79c :3 79b :8 79e 59
:3 7a2 :11 7a3 :b 7a4 :17 7a5
:3 7a3 :2 7a7 :3 7a8 :3 7a9
7aa 7a8 7a7 7a8
:3 7ab :3 7a2 :2 7ac :5 7ae
:11 7af :b 7b0 :18 7b1 :3 7af
:2 7b3 7b4 :3 7b5 7b6
7b4 7b3 7b4 :3 7b7
:2 7ad :6 7ac 7a1 :7 1

b142
4
:3 0 1 :3 0 2
:a 0 3308 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 3308 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 3306
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 3306
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 3306
0 1a :6 0 18
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 3306
0 1b :6 0 18
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 3306
0 1c :6 0 18
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 3306
0 1d :6 0 20
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 3306
0 1e :6 0 20
:2 0 4f 4 :3 0
4d 78 7a :6 0
7d 7b 0 3306
0 1f :6 0 20
:2 0 53 4 :3 0
51 7f 81 :6 0
84 82 0 3306
0 21 :6 0 59
276 0 57 4
:3 0 55 86 88
:6 0 8b 89 0
3306 0 22 :6 0
27 :2 0 5b 24
:3 0 8d :7 0 90
8e 0 3306 0
23 :6 0 24 :3 0
92 :7 0 95 93
0 3306 0 25
:6 0 18 :2 0 5f
4 :3 0 5d 97
99 :6 0 9c 9a
0 3306 0 26
:6 0 2a :2 0 63
4 :3 0 61 9e
a0 :6 0 a3 a1
0 3306 0 28
:6 0 2a :2 0 67
4 :3 0 65 a5
a7 :6 0 aa a8
0 3306 0 29
:6 0 2a :2 0 6b
4 :3 0 69 ac
ae :6 0 b1 af
0 3306 0 2b
:6 0 2e :2 0 6f
4 :3 0 6d b3
b5 :6 0 b8 b6
0 3306 0 2c
:6 0 30 :2 0 73
4 :3 0 71 ba
bc :6 0 bf bd
0 3306 0 2d
:6 0 30 :2 0 75
8 :3 0 c1 :7 0
c5 c2 c3 3306
0 2f :6 0 30
:2 0 77 8 :3 0
c7 :7 0 cb c8
c9 3306 0 31
:6 0 30 :2 0 79
8 :3 0 cd :7 0
d1 ce cf 3306
0 32 :6 0 30
:2 0 7b 8 :3 0
d3 :7 0 d7 d4
d5 3306 0 33
:6 0 30 :2 0 7d
8 :3 0 d9 :7 0
dd da db 3306
0 34 :6 0 30
:2 0 7f 8 :3 0
df :7 0 e3 e0
e1 3306 0 35
:6 0 30 :2 0 81
8 :3 0 e5 :7 0
e9 e6 e7 3306
0 36 :6 0 30
:2 0 83 8 :3 0
eb :7 0 ef ec
ed 3306 0 37
:6 0 30 :2 0 85
8 :3 0 f1 :7 0
f5 f2 f3 3306
0 38 :6 0 30
:2 0 87 8 :3 0
f7 :7 0 fb f8
f9 3306 0 39
:6 0 30 :2 0 89
8 :3 0 fd :7 0
101 fe ff 3306
0 3a :6 0 30
:2 0 8b 8 :3 0
103 :7 0 107 104
105 3306 0 3b
:6 0 30 :2 0 8d
8 :3 0 109 :7 0
10d 10a 10b 3306
0 3c :6 0 30
:2 0 8f 8 :3 0
10f :7 0 113 110
111 3306 0 3d
:6 0 30 :2 0 91
8 :3 0 115 :7 0
119 116 117 3306
0 3e :6 0 30
:2 0 93 8 :3 0
11b :7 0 11f 11c
11d 3306 0 3f
:6 0 30 :2 0 95
8 :3 0 121 :7 0
125 122 123 3306
0 40 :6 0 30
:2 0 97 8 :3 0
127 :7 0 12b 128
129 3306 0 41
:6 0 30 :2 0 99
8 :3 0 12d :7 0
131 12e 12f 3306
0 42 :6 0 30
:2 0 9b 8 :3 0
133 :7 0 137 134
135 3306 0 43
:6 0 30 :2 0 9d
8 :3 0 139 :7 0
13d 13a 13b 3306
0 44 :6 0 30
:2 0 9f 8 :3 0
13f :7 0 143 140
141 3306 0 45
:6 0 30 :2 0 a1
8 :3 0 145 :7 0
149 146 147 3306
0 46 :6 0 30
:2 0 a3 8 :3 0
14b :7 0 14f 14c
14d 3306 0 47
:6 0 30 :2 0 a5
8 :3 0 151 :7 0
155 152 153 3306
0 48 :6 0 30
:2 0 a7 8 :3 0
157 :7 0 15b 158
159 3306 0 49
:6 0 30 :2 0 a9
8 :3 0 15d :7 0
161 15e 15f 3306
0 4a :6 0 27
:2 0 ab 8 :3 0
163 :7 0 167 164
165 3306 0 4b
:6 0 27 :2 0 af
4 :3 0 ad 169
16b :6 0 16e 16c
0 3306 0 4c
:6 0 30 :2 0 b3
4 :3 0 b1 170
172 :6 0 175 173
0 3306 0 4d
:6 0 51 :2 0 b5
4f :3 0 177 :7 0
17b 178 179 3306
0 4e :6 0 30
:2 0 b9 4 :3 0
b7 17d 17f :6 0
182 180 0 3306
0 50 :6 0 18
:2 0 bb 8 :3 0
184 :7 0 188 185
186 3306 0 52
:6 0 18 :2 0 bf
54 :3 0 bd 18a
18c :6 0 18f 18d
0 3306 0 53
:6 0 18 :2 0 c3
54 :3 0 c1 191
193 :6 0 196 194
0 3306 0 55
:6 0 30 :2 0 c7
4 :3 0 c5 198
19a :6 0 19d 19b
0 3306 0 56
:6 0 30 :2 0 c9
8 :3 0 19f :7 0
1a3 1a0 1a1 3306
0 57 :6 0 30
:2 0 cb 8 :3 0
1a5 :7 0 1a9 1a6
1a7 3306 0 58
:6 0 20 :2 0 cd
8 :3 0 1ab :7 0
1af 1ac 1ad 3306
0 59 :6 0 20
:2 0 d1 4 :3 0
cf 1b1 1b3 :6 0
1b6 1b4 0 3306
0 5a :6 0 30
:2 0 d5 4 :3 0
d3 1b8 1ba :6 0
1bd 1bb 0 3306
0 5b :6 0 30
:2 0 d7 8 :3 0
1bf :7 0 1c3 1c0
1c1 3306 0 5c
:6 0 18 :2 0 d9
8 :3 0 1c5 :7 0
1c9 1c6 1c7 3306
0 5d :6 0 27
:2 0 dd 4 :3 0
db 1cb 1cd :6 0
1d0 1ce 0 3306
0 5e :6 0 27
:2 0 df 8 :3 0
1d2 0 2 :5 0
1d6 1d3 1d4 3306
0 5f :6 0 30
:2 0 e1 8 :3 0
1d8 0 2 :5 0
1dc 1d9 1da 3306
0 60 :6 0 30
:2 0 e3 8 :3 0
1de 0 2 :5 0
1e2 1df 1e0 3306
0 61 :6 0 e7
8a1 0 e5 8
:3 0 1e4 0 2
:5 0 1e8 1e5 1e6
3306 0 62 :6 0
1f5 1f6 0 e9
8 :3 0 1ea :7 0
1ed 1eb 0 3306
0 63 :6 0 15
:3 0 16 :2 0 4
1ef 1f0 0 1f1
:7 0 1f4 1f2 0
3306 0 64 :6 0
65 :3 0 66 :3 0
65 :3 0 67 :3 0
1f8 1f9 0 2
:4 0 eb 1fa 1fc
1f7 1fe 1fd :2 0
68 :3 0 69 :3 0
200 201 0 6a
:4 0 65 :3 0 6b
:3 0 204 205 0
2 :4 0 ed 206
208 6c :4 0 6d
:2 0 6e :3 0 ef
20b 20d :3 0 6f
:4 0 6d :2 0 70
:4 0 f2 210 212
:3 0 6d :2 0 3
:3 0 f5 214 216
:3 0 6d :2 0 70
:4 0 f8 218 21a
:3 0 6d :2 0 71
:4 0 fb 21c 21e
:3 0 6d :2 0 70
:4 0 fe 220 222
:3 0 6d :2 0 5
:3 0 101 224 226
:3 0 6d :2 0 70
:4 0 104 228 22a
:3 0 6d :2 0 71
:4 0 107 22c 22e
:3 0 6d :2 0 70
:4 0 10a 230 232
:3 0 6d :2 0 6
:3 0 10d 234 236
:3 0 6d :2 0 70
:4 0 110 238 23a
:3 0 6d :2 0 71
:4 0 113 23c 23e
:3 0 6d :2 0 72
:3 0 73 :3 0 7
:3 0 116 242 244
74 :4 0 118 241
247 11b 240 249
:3 0 6d :2 0 71
:4 0 11e 24b 24d
:3 0 6d :2 0 72
:3 0 73 :3 0 9
:3 0 121 251 253
74 :4 0 123 250
256 126 24f 258
:3 0 6d :2 0 71
:4 0 129 25a 25c
:3 0 6d :2 0 72
:3 0 73 :3 0 a
:3 0 12c 260 262
74 :4 0 12e 25f
265 131 25e 267
:3 0 6d :2 0 71
:4 0 134 269 26b
:3 0 6d :2 0 72
:3 0 73 :3 0 b
:3 0 137 26f 271
74 :4 0 139 26e
274 13c 26d 276
:3 0 6d :2 0 71
:4 0 13f 278 27a
:3 0 6d :2 0 72
:3 0 73 :3 0 c
:3 0 142 27e 280
74 :4 0 144 27d
283 147 27c 285
:3 0 6d :2 0 71
:4 0 14a 287 289
:3 0 6d :2 0 72
:3 0 73 :3 0 d
:3 0 14d 28d 28f
74 :4 0 14f 28c
292 152 28b 294
:3 0 6d :2 0 71
:4 0 155 296 298
:3 0 6d :2 0 72
:3 0 73 :3 0 e
:3 0 158 29c 29e
74 :4 0 15a 29b
2a1 15d 29a 2a3
:3 0 6d :2 0 71
:4 0 160 2a5 2a7
:3 0 6d :2 0 72
:3 0 73 :3 0 f
:3 0 163 2ab 2ad
74 :4 0 165 2aa
2b0 168 2a9 2b2
:3 0 6d :2 0 71
:4 0 16b 2b4 2b6
:3 0 6d :2 0 72
:3 0 73 :3 0 10
:3 0 16e 2ba 2bc
74 :4 0 170 2b9
2bf 173 2b8 2c1
:3 0 6d :2 0 71
:4 0 176 2c3 2c5
:3 0 6d :2 0 72
:3 0 73 :3 0 11
:3 0 179 2c9 2cb
74 :4 0 17b 2c8
2ce 17e 2c7 2d0
:3 0 6d :2 0 71
:4 0 181 2d2 2d4
:3 0 6d :2 0 70
:4 0 184 2d6 2d8
:3 0 6d :2 0 12
:3 0 187 2da 2dc
:3 0 6d :2 0 70
:4 0 18a 2de 2e0
:3 0 6d :2 0 71
:4 0 18d 2e2 2e4
:3 0 6d :2 0 70
:4 0 190 2e6 2e8
:3 0 6d :2 0 13
:3 0 193 2ea 2ec
:3 0 6d :2 0 70
:4 0 196 2ee 2f0
:3 0 6d :2 0 75
:4 0 199 2f2 2f4
:3 0 19c 202 2f6
:2 0 2f8 1a1 2f9
1ff 2f8 0 2fa
1a3 0 3266 65
:3 0 66 :3 0 2fb
2fc 0 65 :3 0
76 :3 0 2fe 2ff
0 27 :2 0 2
:4 0 77 :2 0 78
:2 0 27 :2 0 1a5
304 306 :3 0 1a8
300 308 2fd 30a
309 :2 0 68 :3 0
79 :3 0 30c 30d
0 6a :4 0 7a
:4 0 6d :2 0 6e
:3 0 1ac 311 313
:3 0 1af 30e 315
:2 0 317 1b2 318
30b 317 0 319
1b4 0 3266 17
:3 0 3 :3 0 31a
31b 0 3266 1f
:3 0 5 :3 0 31d
31e 0 3266 22
:3 0 6 :3 0 320
321 0 3266 1c
:3 0 13 :3 0 323
324 0 3266 37
:3 0 7 :3 0 326
327 0 3266 35
:3 0 9 :3 0 329
32a 0 3266 36
:3 0 e :3 0 32c
32d 0 3266 38
:3 0 b :3 0 32f
330 0 3266 3a
:3 0 f :3 0 332
333 0 3266 39
:3 0 c :3 0 335
336 0 3266 32
:3 0 11 :3 0 338
339 0 3266 31
:3 0 a :3 0 33b
33c 0 3266 3b
:3 0 d :3 0 33e
33f 0 3266 33
:3 0 10 :3 0 341
342 0 3266 1a
:3 0 17 :3 0 344
345 0 3266 23
:3 0 7b :4 0 347
348 0 3266 19
:4 0 34a 34b 0
3266 59 :3 0 7c
:3 0 72 :3 0 32
:3 0 30 :2 0 1b6
34f 352 1b9 34e
354 34d 355 0
3266 5c :3 0 30
:2 0 357 358 0
3266 4e :3 0 7d
:2 0 35a 35b 0
3266 3f :3 0 30
:2 0 35d 35e 0
3266 3 :3 0 7e
:2 0 1bb 361 362
:3 0 363 :2 0 65
:3 0 66 :3 0 365
366 0 65 :3 0
76 :3 0 368 369
0 7f :2 0 2
:4 0 80 :2 0 78
:2 0 27 :2 0 1bd
36e 370 :3 0 1c0
36a 372 367 374
373 :2 0 68 :3 0
79 :3 0 376 377
0 6a :4 0 81
:4 0 6d :2 0 6e
:3 0 1c4 37b 37d
:3 0 6d :2 0 82
:4 0 1c7 37f 381
:3 0 6d :2 0 83
:4 0 1ca 383 385
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 85 :3 0 38a
38b 0 1cd 389
38d 74 :4 0 1cf
388 390 1d2 387
392 :3 0 1d5 378
394 :2 0 396 1d8
397 375 396 0
398 1da 0 3c1
65 :3 0 66 :3 0
399 39a 0 65
:3 0 76 :3 0 39c
39d 0 27 :2 0
2 :4 0 86 :2 0
78 :2 0 27 :2 0
1dc 3a2 3a4 :3 0
1df 39e 3a6 39b
3a8 3a7 :2 0 68
:3 0 79 :3 0 3aa
3ab 0 6a :4 0
87 :4 0 6d :2 0
6e :3 0 1e3 3af
3b1 :3 0 1e6 3ac
3b3 :2 0 3b5 1e9
3b6 3a9 3b5 0
3b7 1eb 0 3c1
88 :3 0 89 :3 0
3b8 3b9 0 84
:3 0 85 :3 0 3bb
3bc 0 8a :3 0
1ed 3ba 3bf :2 0
3c1 1f0 3c2 364
3c1 0 3c3 1f4
0 3266 12 :3 0
7e :2 0 1f6 3c5
3c6 :3 0 3c7 :2 0
65 :3 0 66 :3 0
3c9 3ca 0 65
:3 0 76 :3 0 3cc
3cd 0 7f :2 0
2 :4 0 8b :2 0
78 :2 0 27 :2 0
1f8 3d2 3d4 :3 0
1fb 3ce 3d6 3cb
3d8 3d7 :2 0 68
:3 0 79 :3 0 3da
3db 0 6a :4 0
8c :4 0 6d :2 0
6e :3 0 1ff 3df
3e1 :3 0 6d :2 0
82 :4 0 202 3e3
3e5 :3 0 6d :2 0
83 :4 0 205 3e7
3e9 :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 85 :3 0
3ee 3ef 0 208
3ed 3f1 74 :4 0
20a 3ec 3f4 20d
3eb 3f6 :3 0 210
3dc 3f8 :2 0 3fa
213 3fb 3d9 3fa
0 3fc 215 0
425 65 :3 0 66
:3 0 3fd 3fe 0
65 :3 0 76 :3 0
400 401 0 27
:2 0 2 :4 0 8d
:2 0 78 :2 0 27
:2 0 217 406 408
:3 0 21a 402 40a
3ff 40c 40b :2 0
68 :3 0 79 :3 0
40e 40f 0 6a
:4 0 8e :4 0 6d
:2 0 6e :3 0 21e
413 415 :3 0 221
410 417 :2 0 419
224 41a 40d 419
0 41b 226 0
425 88 :3 0 89
:3 0 41c 41d 0
84 :3 0 85 :3 0
41f 420 0 8a
:3 0 228 41e 423
:2 0 425 22b 426
3c8 425 0 427
22f 0 3266 72
:3 0 31 :3 0 30
:2 0 231 428 42b
8f :2 0 90 :2 0
236 42d 42f :3 0
72 :3 0 39 :3 0
30 :2 0 239 431
434 8f :2 0 90
:2 0 23e 436 438
:3 0 430 43a 439
:2 0 72 :3 0 35
:3 0 30 :2 0 241
43c 43f 8f :2 0
90 :2 0 246 441
443 :3 0 43b 445
444 :2 0 65 :3 0
66 :3 0 447 448
0 65 :3 0 76
:3 0 44a 44b 0
7f :2 0 2 :4 0
91 :2 0 78 :2 0
27 :2 0 249 450
452 :3 0 24c 44c
454 449 456 455
:2 0 68 :3 0 79
:3 0 458 459 0
6a :4 0 92 :4 0
6d :2 0 6e :3 0
250 45d 45f :3 0
6d :2 0 82 :4 0
253 461 463 :3 0
6d :2 0 83 :4 0
256 465 467 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
93 :3 0 46c 46d
0 259 46b 46f
74 :4 0 25b 46a
472 25e 469 474
:3 0 261 45a 476
:2 0 478 264 479
457 478 0 47a
266 0 4a3 65
:3 0 66 :3 0 47b
47c 0 65 :3 0
76 :3 0 47e 47f
0 27 :2 0 2
:4 0 94 :2 0 78
:2 0 27 :2 0 268
484 486 :3 0 26b
480 488 47d 48a
489 :2 0 68 :3 0
79 :3 0 48c 48d
0 6a :4 0 95
:4 0 6d :2 0 6e
:3 0 26f 491 493
:3 0 272 48e 495
:2 0 497 275 498
48b 497 0 499
277 0 4a3 88
:3 0 89 :3 0 49a
49b 0 84 :3 0
93 :3 0 49d 49e
0 8a :3 0 279
49c 4a1 :2 0 4a3
27c 4a4 446 4a3
0 4a5 280 0
3266 5 :3 0 96
:2 0 282 4a7 4a8
:3 0 4a9 :2 0 4aa
:2 0 6 :3 0 96
:2 0 284 4ad 4ae
:3 0 4af :2 0 4b0
:2 0 4ab 4b2 4b1
:2 0 97 :3 0 98
:3 0 6 :3 0 97
:3 0 98 :3 0 5
:3 0 44 :3 0 99
:4 0 9a 1 :8 0
4c2 15 :3 0 9b
:3 0 4bd 4be 0
9c :3 0 4bf 4c0
0 4c2 286 515
9d :3 0 15 :3 0
9b :3 0 4c4 4c5
0 9c :3 0 4c6
4c7 0 4c9 289
4cb 28b 4ca 4c9
:2 0 513 9e :3 0
15 :3 0 9b :3 0
4ce 4cf 0 9c
:3 0 4d0 4d1 0
50b 65 :3 0 66
:3 0 4d3 4d4 0
65 :3 0 76 :3 0
4d6 4d7 0 9f
:2 0 2 :4 0 a0
:2 0 78 :2 0 27
:2 0 28d 4dc 4de
:3 0 290 4d8 4e0
4d5 4e2 4e1 :2 0
68 :3 0 79 :3 0
4e4 4e5 0 6a
:4 0 a1 :4 0 6d
:2 0 6e :3 0 294
4e9 4eb :3 0 6d
:2 0 82 :4 0 297
4ed 4ef :3 0 6d
:2 0 a2 :4 0 29a
4f1 4f3 :3 0 6d
:2 0 9c :3 0 29d
4f5 4f7 :3 0 6d
:2 0 a3 :4 0 2a0
4f9 4fb :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 2a3 4fe 502
2a7 4fd 504 :3 0
2aa 4e6 506 :2 0
508 2ad 509 4e3
508 0 50a 2af
0 50b 2b1 50e
:3 0 50e 0 50e
50d 50b 50c :6 0
510 2 :3 0 2b4
512 2b6 511 510
:2 0 513 2b8 :2 0
515 0 515 514
4c2 513 :6 0 590
1 :3 0 15 :3 0
9b :3 0 517 518
0 15 :3 0 8f
:2 0 a7 :3 0 51a
51c 0 2bd 51b
51e :3 0 51f :2 0
72 :3 0 44 :3 0
30 :2 0 2c0 521
524 a8 :2 0 30
:2 0 2c5 526 528
:3 0 529 :2 0 520
52b 52a :2 0 65
:3 0 66 :3 0 52d
52e 0 65 :3 0
76 :3 0 530 531
0 7f :2 0 2
:4 0 a9 :2 0 78
:2 0 27 :2 0 2c8
536 538 :3 0 2cb
532 53a 52f 53c
53b :2 0 68 :3 0
79 :3 0 53e 53f
0 6a :4 0 aa
:4 0 6d :2 0 6e
:3 0 2cf 543 545
:3 0 6d :2 0 82
:4 0 2d2 547 549
:3 0 6d :2 0 83
:4 0 2d5 54b 54d
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 ab :3 0 552
553 0 2d8 551
555 74 :4 0 2da
550 558 2dd 54f
55a :3 0 2e0 540
55c :2 0 55e 2e3
55f 53d 55e 0
560 2e5 0 589
65 :3 0 66 :3 0
561 562 0 65
:3 0 76 :3 0 564
565 0 27 :2 0
2 :4 0 ac :2 0
78 :2 0 27 :2 0
2e7 56a 56c :3 0
2ea 566 56e 563
570 56f :2 0 68
:3 0 79 :3 0 572
573 0 6a :4 0
ad :4 0 6d :2 0
6e :3 0 2ee 577
579 :3 0 2f1 574
57b :2 0 57d 2f4
57e 571 57d 0
57f 2f6 0 589
88 :3 0 89 :3 0
580 581 0 84
:3 0 ab :3 0 583
584 0 8a :3 0
2f8 582 587 :2 0
589 2fb 58a 52c
589 0 58b 2ff
0 590 62 :3 0
27 :2 0 58c 58d
0 590 ae :3 0
301 5ff 5 :3 0
7e :2 0 305 592
593 :3 0 594 :2 0
595 :2 0 6 :3 0
7e :2 0 307 598
599 :3 0 59a :2 0
59b :2 0 596 59d
59c :2 0 6e :3 0
1f :3 0 99 :4 0
af 1 :8 0 5a8
15 :3 0 9b :3 0
5a3 5a4 0 9c
:3 0 5a5 5a6 0
5a8 309 5fb 9d
:3 0 15 :3 0 9b
:3 0 5aa 5ab 0
9c :3 0 5ac 5ad
0 5af 30c 5b1
30e 5b0 5af :2 0
5f9 9e :3 0 15
:3 0 9b :3 0 5b4
5b5 0 9c :3 0
5b6 5b7 0 5f1
65 :3 0 66 :3 0
5b9 5ba 0 65
:3 0 76 :3 0 5bc
5bd 0 9f :2 0
2 :4 0 b0 :2 0
78 :2 0 27 :2 0
310 5c2 5c4 :3 0
313 5be 5c6 5bb
5c8 5c7 :2 0 68
:3 0 79 :3 0 5ca
5cb 0 6a :4 0
b1 :4 0 6d :2 0
6e :3 0 317 5cf
5d1 :3 0 6d :2 0
82 :4 0 31a 5d3
5d5 :3 0 6d :2 0
a2 :4 0 31d 5d7
5d9 :3 0 6d :2 0
9c :3 0 320 5db
5dd :3 0 6d :2 0
a3 :4 0 323 5df
5e1 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
326 5e4 5e8 32a
5e3 5ea :3 0 32d
5cc 5ec :2 0 5ee
330 5ef 5c9 5ee
0 5f0 332 0
5f1 334 5f4 :3 0
5f4 0 5f4 5f3
5f1 5f2 :6 0 5f6
4 :3 0 337 5f8
339 5f7 5f6 :2 0
5f9 33b :2 0 5fb
0 5fb 5fa 5a8
5f9 :6 0 5fd 1
:3 0 33e 5fe 59e
5fd 0 600 4b3
590 0 600 340
0 3266 21 :3 0
1f :3 0 601 602
0 3266 6 :3 0
7e :2 0 343 605
606 :3 0 607 :2 0
22 :3 0 7b :4 0
609 60a 0 60c
345 60d 608 60c
0 60e 347 0
3266 1d :3 0 a4
:3 0 1d :3 0 27
:2 0 18 :2 0 349
610 614 60f 615
0 3266 26 :3 0
a4 :3 0 26 :3 0
27 :2 0 27 :2 0
34d 618 61c 617
61d 0 3266 29
:3 0 12 :3 0 61f
620 0 3266 72
:3 0 32 :3 0 30
:2 0 351 622 625
b2 :2 0 30 :2 0
356 627 629 :3 0
1d :3 0 a4 :3 0
a4 :3 0 29 :3 0
27 :2 0 18 :2 0
359 62d 631 27
:2 0 18 :2 0 35d
62c 635 62b 636
0 a07 26 :3 0
b3 :3 0 b4 :3 0
639 63a 0 27
:2 0 27 :2 0 b5
:2 0 29 :3 0 361
63b 640 638 641
0 a07 b6 :3 0
72 :3 0 32 :3 0
30 :2 0 366 644
647 369 643 649
b7 :2 0 30 :2 0
36d 64b 64d :3 0
b8 :3 0 72 :3 0
b9 :3 0 72 :3 0
ba :3 0 bb :3 0
17 :3 0 3d :3 0
3e :3 0 43 :3 0
bc :3 0 bd :3 0
1a :4 0 be 1
:8 0 662 15 :3 0
9b :3 0 65d 65e
0 9c :3 0 65f
660 0 662 370
6b5 9d :3 0 15
:3 0 9b :3 0 664
665 0 9c :3 0
666 667 0 669
373 66b 375 66a
669 :2 0 6b3 9e
:3 0 15 :3 0 9b
:3 0 66e 66f 0
9c :3 0 670 671
0 6ab 65 :3 0
66 :3 0 673 674
0 65 :3 0 76
:3 0 676 677 0
9f :2 0 2 :4 0
bf :2 0 78 :2 0
27 :2 0 377 67c
67e :3 0 37a 678
680 675 682 681
:2 0 68 :3 0 79
:3 0 684 685 0
6a :4 0 c0 :4 0
6d :2 0 6e :3 0
37e 689 68b :3 0
6d :2 0 82 :4 0
381 68d 68f :3 0
6d :2 0 a2 :4 0
384 691 693 :3 0
6d :2 0 9c :3 0
387 695 697 :3 0
6d :2 0 a3 :4 0
38a 699 69b :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 38d 69e
6a2 391 69d 6a4
:3 0 394 686 6a6
:2 0 6a8 397 6a9
683 6a8 0 6aa
399 0 6ab 39b
6ae :3 0 6ae 0
6ae 6ad 6ab 6ac
:6 0 6b0 6 :3 0
39e 6b2 3a0 6b1
6b0 :2 0 6b3 3a2
:2 0 6b5 0 6b5
6b4 662 6b3 :6 0
6b7 1 :3 0 3a5
759 c1 :3 0 c2
:3 0 c1 :3 0 c3
:3 0 c1 :3 0 c4
:3 0 c1 :3 0 c5
:3 0 c1 :3 0 b8
:3 0 72 :3 0 c6
:3 0 b9 :3 0 72
:3 0 c6 :3 0 ba
:3 0 c6 :3 0 bb
:3 0 32 :3 0 5c
:3 0 5a :3 0 5b
:3 0 17 :3 0 3d
:3 0 3e :3 0 43
:3 0 bc :3 0 c6
:3 0 bc :3 0 c1
:3 0 c1 :3 0 bd
:3 0 1a :3 0 c1
:3 0 c2 :3 0 84
:3 0 c7 :3 0 84
:3 0 c8 :3 0 84
:3 0 c9 :3 0 84
:3 0 ca :3 0 84
:3 0 cb :3 0 84
:3 0 cc :3 0 84
:3 0 cd :3 0 84
:3 0 ce :3 0 84
:3 0 cf :3 0 84
:3 0 d0 :3 0 84
:3 0 d1 :3 0 84
:3 0 d2 :3 0 84
:3 0 d3 :3 0 84
:3 0 d4 :3 0 84
:3 0 d5 :3 0 c6
:3 0 bd :3 0 c1
:3 0 b8 :4 0 d6
1 :8 0 703 15
:3 0 9b :3 0 6fe
6ff 0 9c :3 0
700 701 0 703
3a7 756 9d :3 0
15 :3 0 9b :3 0
705 706 0 9c
:3 0 707 708 0
70a 3aa 70c 3ac
70b 70a :2 0 754
9e :3 0 15 :3 0
9b :3 0 70f 710
0 9c :3 0 711
712 0 74c 65
:3 0 66 :3 0 714
715 0 65 :3 0
76 :3 0 717 718
0 9f :2 0 2
:4 0 d7 :2 0 78
:2 0 27 :2 0 3ae
71d 71f :3 0 3b1
719 721 716 723
722 :2 0 68 :3 0
79 :3 0 725 726
0 6a :4 0 d8
:4 0 6d :2 0 6e
:3 0 3b5 72a 72c
:3 0 6d :2 0 82
:4 0 3b8 72e 730
:3 0 6d :2 0 a2
:4 0 3bb 732 734
:3 0 6d :2 0 9c
:3 0 3be 736 738
:3 0 6d :2 0 a3
:4 0 3c1 73a 73c
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 3c4
73f 743 3c8 73e
745 :3 0 3cb 727
747 :2 0 749 3ce
74a 724 749 0
74b 3d0 0 74c
3d2 74f :3 0 74f
0 74f 74e 74c
74d :6 0 751 8
:3 0 3d5 753 3d7
752 751 :2 0 754
3d9 :2 0 756 0
756 755 703 754
:6 0 758 1 :3 0
3dc 75a 64e 6b7
0 75b 0 758
0 75b 3de 0
a07 15 :3 0 9b
:3 0 75c 75d 0
15 :3 0 8f :2 0
d9 :3 0 75f 761
0 3e3 760 763
:3 0 764 :2 0 b8
:3 0 da :3 0 17
:3 0 5e :3 0 db
:3 0 bd :3 0 1a
:4 0 dc 1 :8 0
773 15 :3 0 9b
:3 0 76e 76f 0
9c :3 0 770 771
0 773 3e6 7c6
9d :3 0 15 :3 0
9b :3 0 775 776
0 9c :3 0 777
778 0 77a 3e9
77c 3eb 77b 77a
:2 0 7c4 9e :3 0
15 :3 0 9b :3 0
77f 780 0 9c
:3 0 781 782 0
7bc 65 :3 0 66
:3 0 784 785 0
65 :3 0 76 :3 0
787 788 0 9f
:2 0 2 :4 0 dd
:2 0 78 :2 0 27
:2 0 3ed 78d 78f
:3 0 3f0 789 791
786 793 792 :2 0
68 :3 0 79 :3 0
795 796 0 6a
:4 0 de :4 0 6d
:2 0 6e :3 0 3f4
79a 79c :3 0 6d
:2 0 82 :4 0 3f7
79e 7a0 :3 0 6d
:2 0 a2 :4 0 3fa
7a2 7a4 :3 0 6d
:2 0 9c :3 0 3fd
7a6 7a8 :3 0 6d
:2 0 a3 :4 0 400
7aa 7ac :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 403 7af 7b3
407 7ae 7b5 :3 0
40a 797 7b7 :2 0
7b9 40d 7ba 794
7b9 0 7bb 40f
0 7bc 411 7bf
:3 0 7bf 0 7bf
7be 7bc 7bd :6 0
7c1 a :3 0 414
7c3 416 7c2 7c1
:2 0 7c4 418 :2 0
7c6 0 7c6 7c5
773 7c4 :6 0 8b5
1 :3 0 15 :3 0
9b :3 0 7c8 7c9
0 15 :3 0 8f
:2 0 a7 :3 0 7cb
7cd 0 41d 7cc
7cf :3 0 7d0 :2 0
5e :3 0 96 :2 0
420 7d3 7d4 :3 0
7d5 :2 0 59 :3 0
27 :2 0 7d7 7d8
0 7da 422 7db
7d6 7da 0 7dc
424 0 843 72
:3 0 b9 :3 0 72
:3 0 ba :3 0 bb
:3 0 3d :3 0 3e
:3 0 43 :3 0 bc
:3 0 bd :3 0 17
:4 0 df 1 :8 0
7ee 15 :3 0 9b
:3 0 7e9 7ea 0
9c :3 0 7eb 7ec
0 7ee 426 841
9d :3 0 15 :3 0
9b :3 0 7f0 7f1
0 9c :3 0 7f2
7f3 0 7f5 429
7f7 42b 7f6 7f5
:2 0 83f 9e :3 0
15 :3 0 9b :3 0
7fa 7fb 0 9c
:3 0 7fc 7fd 0
837 65 :3 0 66
:3 0 7ff 800 0
65 :3 0 76 :3 0
802 803 0 9f
:2 0 2 :4 0 e0
:2 0 78 :2 0 27
:2 0 42d 808 80a
:3 0 430 804 80c
801 80e 80d :2 0
68 :3 0 79 :3 0
810 811 0 6a
:4 0 e1 :4 0 6d
:2 0 6e :3 0 434
815 817 :3 0 6d
:2 0 82 :4 0 437
819 81b :3 0 6d
:2 0 a2 :4 0 43a
81d 81f :3 0 6d
:2 0 9c :3 0 43d
821 823 :3 0 6d
:2 0 a3 :4 0 440
825 827 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 443 82a 82e
447 829 830 :3 0
44a 812 832 :2 0
834 44d 835 80f
834 0 836 44f
0 837 451 83a
:3 0 83a 0 83a
839 837 838 :6 0
83c c :3 0 454
83e 456 83d 83c
:2 0 83f 458 :2 0
841 0 841 840
7ee 83f :6 0 843
1 :3 0 45b 8b2
65 :3 0 66 :3 0
844 845 0 65
:3 0 76 :3 0 847
848 0 18 :2 0
2 :4 0 e2 :2 0
78 :2 0 27 :2 0
45e 84d 84f :3 0
461 849 851 846
853 852 :2 0 68
:3 0 79 :3 0 855
856 0 6a :4 0
e3 :4 0 6d :2 0
6e :3 0 465 85a
85c :3 0 6d :2 0
82 :4 0 468 85e
860 :3 0 6d :2 0
83 :4 0 46b 862
864 :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 e4 :3 0
869 86a 0 46e
868 86c 74 :4 0
470 867 86f 473
866 871 :3 0 6d
:2 0 e5 :4 0 476
873 875 :3 0 6d
:2 0 70 :4 0 479
877 879 :3 0 6d
:2 0 1a :3 0 47c
87b 87d :3 0 6d
:2 0 70 :4 0 47f
87f 881 :3 0 482
857 883 :2 0 885
485 886 854 885
0 887 487 0
8b1 65 :3 0 66
:3 0 888 889 0
65 :3 0 76 :3 0
88b 88c 0 27
:2 0 2 :4 0 e6
:2 0 78 :2 0 27
:2 0 489 891 893
:3 0 48c 88d 895
88a 897 896 :2 0
68 :3 0 79 :3 0
899 89a 0 6a
:4 0 e7 :4 0 6d
:2 0 6e :3 0 490
89e 8a0 :3 0 493
89b 8a2 :2 0 8a4
496 8a5 898 8a4
0 8a6 498 0
8b1 88 :3 0 e8
:3 0 8a7 8a8 0
84 :3 0 e4 :3 0
8aa 8ab 0 1a
:3 0 8a :3 0 49a
8a9 8af :2 0 8b1
49e 8b3 7d1 843
0 8b4 0 8b1
0 8b4 4a2 0
8b5 4a5 8ba 59
:3 0 27 :2 0 8b6
8b7 0 8b9 4a8
8bb 765 8b5 0
8bc 0 8b9 0
8bc 4aa 0 a07
5d :3 0 30 :2 0
8bd 8be 0 a07
e9 :3 0 5d :3 0
ea :3 0 b8 :3 0
17 :4 0 eb 1
:8 0 8cb 15 :3 0
9b :3 0 8c6 8c7
0 9c :3 0 8c8
8c9 0 8cb 4ad
91e 9d :3 0 15
:3 0 9b :3 0 8cd
8ce 0 9c :3 0
8cf 8d0 0 8d2
4b0 8d4 4b2 8d3
8d2 :2 0 91c 9e
:3 0 15 :3 0 9b
:3 0 8d7 8d8 0
9c :3 0 8d9 8da
0 914 65 :3 0
66 :3 0 8dc 8dd
0 65 :3 0 76
:3 0 8df 8e0 0
9f :2 0 2 :4 0
ec :2 0 78 :2 0
27 :2 0 4b4 8e5
8e7 :3 0 4b7 8e1
8e9 8de 8eb 8ea
:2 0 68 :3 0 79
:3 0 8ed 8ee 0
6a :4 0 ed :4 0
6d :2 0 6e :3 0
4bb 8f2 8f4 :3 0
6d :2 0 82 :4 0
4be 8f6 8f8 :3 0
6d :2 0 a2 :4 0
4c1 8fa 8fc :3 0
6d :2 0 9c :3 0
4c4 8fe 900 :3 0
6d :2 0 a3 :4 0
4c7 902 904 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 4ca 907
90b 4ce 906 90d
:3 0 4d1 8ef 90f
:2 0 911 4d4 912
8ec 911 0 913
4d6 0 914 4d8
917 :3 0 917 0
917 916 914 915
:6 0 919 e :3 0
4db 91b 4dd 91a
919 :2 0 91c 4df
:2 0 91e 0 91e
91d 8cb 91c :6 0
a07 1 :3 0 72
:3 0 5d :3 0 30
:2 0 4e2 920 923
b2 :2 0 30 :2 0
4e7 925 927 :3 0
ee :3 0 4d :3 0
bc :3 0 bd :3 0
17 :4 0 ef 1
:8 0 934 15 :3 0
9b :3 0 92f 930
0 9c :3 0 931
932 0 934 4ea
987 9d :3 0 15
:3 0 9b :3 0 936
937 0 9c :3 0
938 939 0 93b
4ed 93d 4ef 93c
93b :2 0 985 9e
:3 0 15 :3 0 9b
:3 0 940 941 0
9c :3 0 942 943
0 97d 65 :3 0
66 :3 0 945 946
0 65 :3 0 76
:3 0 948 949 0
9f :2 0 2 :4 0
f0 :2 0 78 :2 0
27 :2 0 4f1 94e
950 :3 0 4f4 94a
952 947 954 953
:2 0 68 :3 0 79
:3 0 956 957 0
6a :4 0 f1 :4 0
6d :2 0 6e :3 0
4f8 95b 95d :3 0
6d :2 0 82 :4 0
4fb 95f 961 :3 0
6d :2 0 a2 :4 0
4fe 963 965 :3 0
6d :2 0 9c :3 0
501 967 969 :3 0
6d :2 0 a3 :4 0
504 96b 96d :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 507 970
974 50b 96f 976
:3 0 50e 958 978
:2 0 97a 511 97b
955 97a 0 97c
513 0 97d 515
980 :3 0 980 0
980 97f 97d 97e
:6 0 982 10 :3 0
518 984 51a 983
982 :2 0 985 51c
:2 0 987 0 987
986 934 985 :6 0
a04 1 :3 0 97
:3 0 f2 :3 0 989
98a 0 4d :3 0
f3 :4 0 51f 98b
98e 8f :2 0 30
:2 0 524 990 992
:3 0 65 :3 0 66
:3 0 994 995 0
65 :3 0 76 :3 0
997 998 0 18
:2 0 2 :4 0 f4
:2 0 78 :2 0 27
:2 0 527 99d 99f
:3 0 52a 999 9a1
996 9a3 9a2 :2 0
68 :3 0 79 :3 0
9a5 9a6 0 6a
:4 0 f5 :4 0 6d
:2 0 6e :3 0 52e
9aa 9ac :3 0 6d
:2 0 82 :4 0 531
9ae 9b0 :3 0 6d
:2 0 83 :4 0 534
9b2 9b4 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 f6
:3 0 9b9 9ba 0
537 9b8 9bc 74
:4 0 539 9b7 9bf
53c 9b6 9c1 :3 0
6d :2 0 e5 :4 0
53f 9c3 9c5 :3 0
6d :2 0 70 :4 0
542 9c7 9c9 :3 0
6d :2 0 17 :3 0
545 9cb 9cd :3 0
6d :2 0 70 :4 0
548 9cf 9d1 :3 0
54b 9a7 9d3 :2 0
9d5 54e 9d6 9a4
9d5 0 9d7 550
0 a01 65 :3 0
66 :3 0 9d8 9d9
0 65 :3 0 76
:3 0 9db 9dc 0
27 :2 0 2 :4 0
f7 :2 0 78 :2 0
27 :2 0 552 9e1
9e3 :3 0 555 9dd
9e5 9da 9e7 9e6
:2 0 68 :3 0 79
:3 0 9e9 9ea 0
6a :4 0 f8 :4 0
6d :2 0 6e :3 0
559 9ee 9f0 :3 0
55c 9eb 9f2 :2 0
9f4 55f 9f5 9e8
9f4 0 9f6 561
0 a01 88 :3 0
e8 :3 0 9f7 9f8
0 84 :3 0 f6
:3 0 9fa 9fb 0
17 :3 0 8a :3 0
563 9f9 9ff :2 0
a01 567 a02 993
a01 0 a03 56b
0 a04 56d a05
928 a04 0 a06
570 0 a07 572
b56 72 :3 0 b9
:3 0 72 :3 0 ba
:3 0 bb :3 0 3d
:3 0 3e :3 0 43
:3 0 bc :3 0 bd
:3 0 17 :4 0 f9
1 :8 0 a19 15
:3 0 9b :3 0 a14
a15 0 9c :3 0
a16 a17 0 a19
57a a6c 9d :3 0
15 :3 0 9b :3 0
a1b a1c 0 9c
:3 0 a1d a1e 0
a20 57d a22 57f
a21 a20 :2 0 a6a
9e :3 0 15 :3 0
9b :3 0 a25 a26
0 9c :3 0 a27
a28 0 a62 65
:3 0 66 :3 0 a2a
a2b 0 65 :3 0
76 :3 0 a2d a2e
0 9f :2 0 2
:4 0 fa :2 0 78
:2 0 27 :2 0 581
a33 a35 :3 0 584
a2f a37 a2c a39
a38 :2 0 68 :3 0
79 :3 0 a3b a3c
0 6a :4 0 fb
:4 0 6d :2 0 6e
:3 0 588 a40 a42
:3 0 6d :2 0 82
:4 0 58b a44 a46
:3 0 6d :2 0 a2
:4 0 58e a48 a4a
:3 0 6d :2 0 9c
:3 0 591 a4c a4e
:3 0 6d :2 0 a3
:4 0 594 a50 a52
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 597
a55 a59 59b a54
a5b :3 0 59e a3d
a5d :2 0 a5f 5a1
a60 a3a a5f 0
a61 5a3 0 a62
5a5 a65 :3 0 a65
0 a65 a64 a62
a63 :6 0 a67 12
:3 0 5a8 a69 5aa
a68 a67 :2 0 a6a
5ac :2 0 a6c 0
a6c a6b a19 a6a
:6 0 b55 1 :3 0
15 :3 0 9b :3 0
a6e a6f 0 15
:3 0 8f :2 0 d9
:3 0 a71 a73 0
5b1 a72 a75 :3 0
a76 :2 0 3d :3 0
3e :3 0 fc :3 0
bd :3 0 17 :4 0
fd 1 :8 0 a83
15 :3 0 9b :3 0
a7e a7f 0 9c
:3 0 a80 a81 0
a83 5b4 ad6 9d
:3 0 15 :3 0 9b
:3 0 a85 a86 0
9c :3 0 a87 a88
0 a8a 5b7 a8c
5b9 a8b a8a :2 0
ad4 9e :3 0 15
:3 0 9b :3 0 a8f
a90 0 9c :3 0
a91 a92 0 acc
65 :3 0 66 :3 0
a94 a95 0 65
:3 0 76 :3 0 a97
a98 0 9f :2 0
2 :4 0 fe :2 0
78 :2 0 27 :2 0
5bb a9d a9f :3 0
5be a99 aa1 a96
aa3 aa2 :2 0 68
:3 0 79 :3 0 aa5
aa6 0 6a :4 0
ff :4 0 6d :2 0
6e :3 0 5c2 aaa
aac :3 0 6d :2 0
82 :4 0 5c5 aae
ab0 :3 0 6d :2 0
a2 :4 0 5c8 ab2
ab4 :3 0 6d :2 0
9c :3 0 5cb ab6
ab8 :3 0 6d :2 0
a3 :4 0 5ce aba
abc :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
5d1 abf ac3 5d5
abe ac5 :3 0 5d8
aa7 ac7 :2 0 ac9
5db aca aa4 ac9
0 acb 5dd 0
acc 5df acf :3 0
acf 0 acf ace
acc acd :6 0 ad1
14 :3 0 5e2 ad3
5e4 ad2 ad1 :2 0
ad4 5e6 :2 0 ad6
0 ad6 ad5 a83
ad4 :6 0 b52 1
:3 0 15 :3 0 9b
:3 0 ad8 ad9 0
15 :3 0 8f :2 0
d9 :3 0 adb add
0 5eb adc adf
:3 0 ae0 :2 0 65
:3 0 66 :3 0 ae2
ae3 0 65 :3 0
76 :3 0 ae5 ae6
0 18 :2 0 2
:4 0 100 :2 0 78
:2 0 27 :2 0 5ee
aeb aed :3 0 5f1
ae7 aef ae4 af1
af0 :2 0 68 :3 0
79 :3 0 af3 af4
0 6a :4 0 101
:4 0 6d :2 0 6e
:3 0 5f5 af8 afa
:3 0 6d :2 0 82
:4 0 5f8 afc afe
:3 0 6d :2 0 83
:4 0 5fb b00 b02
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 93 :3 0 b07
b08 0 5fe b06
b0a 74 :4 0 600
b05 b0d 603 b04
b0f :3 0 6d :2 0
e5 :4 0 606 b11
b13 :3 0 6d :2 0
70 :4 0 609 b15
b17 :3 0 6d :2 0
17 :3 0 60c b19
b1b :3 0 6d :2 0
70 :4 0 60f b1d
b1f :3 0 612 af5
b21 :2 0 b23 615
b24 af2 b23 0
b25 617 0 b4f
65 :3 0 66 :3 0
b26 b27 0 65
:3 0 76 :3 0 b29
b2a 0 27 :2 0
2 :4 0 102 :2 0
78 :2 0 27 :2 0
619 b2f b31 :3 0
61c b2b b33 b28
b35 b34 :2 0 68
:3 0 79 :3 0 b37
b38 0 6a :4 0
103 :4 0 6d :2 0
6e :3 0 620 b3c
b3e :3 0 623 b39
b40 :2 0 b42 626
b43 b36 b42 0
b44 628 0 b4f
88 :3 0 e8 :3 0
b45 b46 0 84
:3 0 93 :3 0 b48
b49 0 17 :3 0
8a :3 0 62a b47
b4d :2 0 b4f 62e
b50 ae1 b4f 0
b51 632 0 b52
634 b53 a77 b52
0 b54 637 0
b55 639 b57 62a
a07 0 b58 0
b55 0 b58 63c
0 3266 72 :3 0
5c :3 0 30 :2 0
63f b59 b5c 84
:3 0 8f :2 0 104
:3 0 b5e b60 0
644 b5f b62 :3 0
72 :3 0 5c :3 0
30 :2 0 647 b64
b67 84 :3 0 8f
:2 0 105 :3 0 b69
b6b 0 64c b6a
b6d :3 0 b63 b6f
b6e :2 0 b70 :2 0
72 :3 0 32 :3 0
30 :2 0 64f b72
b75 b2 :2 0 30
:2 0 654 b77 b79
:3 0 b7a :2 0 b71
b7c b7b :2 0 72
:3 0 3a :3 0 30
:2 0 657 b7e b81
84 :3 0 b7 :2 0
106 :3 0 b83 b85
0 65c b84 b87
:3 0 72 :3 0 3a
:3 0 30 :2 0 65f
b89 b8c 84 :3 0
b7 :2 0 107 :3 0
b8e b90 0 664
b8f b92 :3 0 b88
b94 b93 :2 0 3a
:3 0 108 :2 0 b96
b97 0 b99 667
b9a b95 b99 0
b9b 669 0 ba2
62 :3 0 27 :2 0
b9c b9d 0 ba2
35 :3 0 30 :2 0
b9f ba0 0 ba2
66b d64 62 :3 0
8f :2 0 30 :2 0
671 ba4 ba6 :3 0
21 :3 0 5 :3 0
ba8 ba9 0 cd1
22 :3 0 6 :3 0
bab bac 0 cd1
5d :3 0 109 :3 0
21 :3 0 22 :3 0
72 :3 0 38 :3 0
30 :2 0 674 bb2
bb5 72 :3 0 39
:3 0 30 :2 0 677
bb7 bba 72 :3 0
3a :3 0 30 :2 0
67a bbc bbf 72
:3 0 31 :3 0 30
:2 0 67d bc1 bc4
72 :3 0 3b :3 0
30 :2 0 680 bc6
bc9 72 :3 0 36
:3 0 30 :2 0 683
bcb bce 72 :3 0
3d :3 0 30 :2 0
686 bd0 bd3 72
:3 0 3e :3 0 30
:2 0 689 bd5 bd8
35 :3 0 37 :3 0
41 :3 0 68c baf
bdd bae bde 0
cd1 72 :3 0 5d
:3 0 30 :2 0 69a
be0 be3 84 :3 0
8f :2 0 93 :3 0
be5 be7 0 69f
be6 be9 :3 0 65
:3 0 66 :3 0 beb
bec 0 65 :3 0
76 :3 0 bee bef
0 7f :2 0 2
:4 0 10a :2 0 78
:2 0 27 :2 0 6a2
bf4 bf6 :3 0 6a5
bf0 bf8 bed bfa
bf9 :2 0 68 :3 0
79 :3 0 bfc bfd
0 6a :4 0 10b
:4 0 6d :2 0 6e
:3 0 6a9 c01 c03
:3 0 6d :2 0 82
:4 0 6ac c05 c07
:3 0 6d :2 0 83
:4 0 6af c09 c0b
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 93 :3 0 c10
c11 0 6b2 c0f
c13 74 :4 0 6b4
c0e c16 6b7 c0d
c18 :3 0 6ba bfe
c1a :2 0 c1c 6bd
c1d bfb c1c 0
c1e 6bf 0 c48
65 :3 0 66 :3 0
c1f c20 0 65
:3 0 76 :3 0 c22
c23 0 27 :2 0
2 :4 0 10c :2 0
78 :2 0 27 :2 0
6c1 c28 c2a :3 0
6c4 c24 c2c c21
c2e c2d :2 0 68
:3 0 79 :3 0 c30
c31 0 6a :4 0
10d :4 0 6d :2 0
6e :3 0 6c8 c35
c37 :3 0 6cb c32
c39 :2 0 c3b 6ce
c3c c2f c3b 0
c3d 6d0 0 c48
88 :3 0 89 :3 0
c3e c3f 0 84
:3 0 93 :3 0 c41
c42 0 8a :3 0
6d2 c40 c45 :2 0
c48 ae :3 0 6d5
cc1 72 :3 0 5d
:3 0 30 :2 0 6d9
c49 c4c b7 :2 0
30 :2 0 6de c4e
c50 :3 0 65 :3 0
66 :3 0 c52 c53
0 65 :3 0 76
:3 0 c55 c56 0
18 :2 0 2 :4 0
10e :2 0 78 :2 0
27 :2 0 6e1 c5b
c5d :3 0 6e4 c57
c5f c54 c61 c60
:2 0 68 :3 0 79
:3 0 c63 c64 0
6a :4 0 10f :4 0
6d :2 0 6e :3 0
6e8 c68 c6a :3 0
6d :2 0 82 :4 0
6eb c6c c6e :3 0
6d :2 0 83 :4 0
6ee c70 c72 :3 0
6d :2 0 72 :3 0
73 :3 0 5d :3 0
6f1 c76 c78 74
:4 0 6f3 c75 c7b
6f6 c74 c7d :3 0
6d :2 0 e5 :4 0
6f9 c7f c81 :3 0
6d :2 0 70 :4 0
6fc c83 c85 :3 0
6d :2 0 17 :3 0
6ff c87 c89 :3 0
6d :2 0 70 :4 0
702 c8b c8d :3 0
705 c65 c8f :2 0
c91 708 c92 c62
c91 0 c93 70a
0 cbf 65 :3 0
66 :3 0 c94 c95
0 65 :3 0 76
:3 0 c97 c98 0
27 :2 0 2 :4 0
110 :2 0 78 :2 0
27 :2 0 70c c9d
c9f :3 0 70f c99
ca1 c96 ca3 ca2
:2 0 68 :3 0 79
:3 0 ca5 ca6 0
6a :4 0 111 :4 0
6d :2 0 6e :3 0
713 caa cac :3 0
716 ca7 cae :2 0
cb0 719 cb1 ca4
cb0 0 cb2 71b
0 cbf 88 :3 0
e8 :3 0 cb3 cb4
0 72 :3 0 5d
:3 0 30 :2 0 71d
cb6 cb9 17 :3 0
8a :3 0 720 cb5
cbd :2 0 cbf 724
cc0 c51 cbf 0
cc2 bea c48 0
cc2 728 0 cd1
22 :3 0 22 :3 0
cc3 cc4 0 cd1
22 :3 0 7e :2 0
72b cc7 cc8 :3 0
cc9 :2 0 22 :3 0
7b :4 0 ccb ccc
0 cce 72d ccf
cca cce 0 cd0
72f 0 cd1 731
cf1 22 :3 0 6
:3 0 cd2 cd3 0
cf0 72 :3 0 39
:3 0 30 :2 0 738
cd5 cd8 8f :2 0
90 :2 0 73d cda
cdc :3 0 35 :3 0
72 :3 0 35 :3 0
30 :2 0 740 cdf
ce2 112 :2 0 72
:3 0 3e :3 0 30
:2 0 743 ce5 ce8
746 ce4 cea :3 0
cde ceb 0 ced
749 cee cdd ced
0 cef 74b 0
cf0 74d cf2 ba7
cd1 0 cf3 0
cf0 0 cf3 750
0 d63 72 :3 0
35 :3 0 30 :2 0
753 cf4 cf7 b2
:2 0 30 :2 0 758
cf9 cfb :3 0 cfc
:2 0 72 :3 0 39
:3 0 30 :2 0 75b
cfe d01 b7 :2 0
113 :2 0 760 d03
d05 :3 0 d06 :2 0
cfd d08 d07 :2 0
72 :3 0 39 :3 0
30 :2 0 763 d0a
d0d 8f :2 0 27
:2 0 768 d0f d11
:3 0 d12 :2 0 72
:3 0 39 :3 0 30
:2 0 76b d14 d17
8f :2 0 114 :2 0
770 d19 d1b :3 0
d1c :2 0 d13 d1e
d1d :2 0 38 :3 0
114 :2 0 d20 d21
0 d24 ae :3 0
773 d5e 72 :3 0
39 :3 0 30 :2 0
775 d25 d28 8f
:2 0 30 :2 0 77a
d2a d2c :3 0 38
:3 0 27 :2 0 d2e
d2f 0 d32 ae
:3 0 77d d33 d2d
d32 0 d5f 72
:3 0 39 :3 0 30
:2 0 77f d34 d37
8f :2 0 115 :2 0
784 d39 d3b :3 0
d3c :2 0 72 :3 0
39 :3 0 30 :2 0
787 d3e d41 8f
:2 0 116 :2 0 78c
d43 d45 :3 0 d46
:2 0 d3d d48 d47
:2 0 38 :3 0 27
:2 0 d4a d4b 0
d4e ae :3 0 78f
d4f d49 d4e 0
d5f 72 :3 0 39
:3 0 30 :2 0 791
d50 d53 8f :2 0
90 :2 0 796 d55
d57 :3 0 38 :3 0
115 :2 0 d59 d5a
0 d5c 799 d5d
d58 d5c 0 d5f
d1f d24 0 d5f
79b 0 d60 7a0
d61 d09 d60 0
d62 7a2 0 d63
7a4 d65 b7d ba2
0 d66 0 d63
0 d66 7a7 0
3266 58 :3 0 117
:4 0 d68 d69 :3 0
d67 d6a 0 3266
2b :3 0 7b :4 0
d6c d6d 0 3266
2c :3 0 7b :4 0
d6f d70 0 3266
34 :3 0 118 :3 0
119 :3 0 d73 d74
0 11a :3 0 72
:3 0 3a :3 0 30
:2 0 7aa d77 d7a
84 :3 0 11b :3 0
d7c d7d 0 7ad
d76 d7f d80 :2 0
11c :2 0 7b0 d75
d83 d72 d84 0
3266 3a :3 0 11a
:3 0 72 :3 0 3a
:3 0 30 :2 0 7b3
d88 d8b 84 :3 0
11d :3 0 d8d d8e
0 7b6 d87 d90
d86 d91 0 3266
72 :3 0 32 :3 0
30 :2 0 7b9 d93
d96 b2 :2 0 30
:2 0 7be d98 d9a
:3 0 58 :3 0 11e
:3 0 59 :3 0 32
:3 0 1a :3 0 1d
:3 0 1c :3 0 28
:3 0 7c1 d9d da4
d9c da5 0 1d4d
72 :3 0 31 :3 0
30 :2 0 7c8 da7
daa 84 :3 0 8f
:2 0 11f :3 0 dac
dae 0 7cd dad
db0 :3 0 72 :3 0
58 :3 0 30 :2 0
7d0 db2 db5 8f
:2 0 27 :2 0 7d5
db7 db9 :3 0 58
:3 0 84 :3 0 120
:3 0 dbc dbd 0
dbb dbe 0 dc0
7d8 dc1 dba dc0
0 dc2 7da 0
e30 65 :3 0 66
:3 0 dc3 dc4 0
65 :3 0 76 :3 0
dc6 dc7 0 18
:2 0 2 :4 0 121
:2 0 78 :2 0 27
:2 0 7dc dcc dce
:3 0 7df dc8 dd0
dc5 dd2 dd1 :2 0
68 :3 0 79 :3 0
dd4 dd5 0 6a
:4 0 122 :4 0 6d
:2 0 6e :3 0 7e3
dd9 ddb :3 0 6d
:2 0 82 :4 0 7e6
ddd ddf :3 0 6d
:2 0 83 :4 0 7e9
de1 de3 :3 0 6d
:2 0 72 :3 0 73
:3 0 58 :3 0 7ec
de7 de9 74 :4 0
7ee de6 dec 7f1
de5 dee :3 0 6d
:2 0 e5 :4 0 7f4
df0 df2 :3 0 6d
:2 0 70 :4 0 7f7
df4 df6 :3 0 6d
:2 0 28 :3 0 7fa
df8 dfa :3 0 6d
:2 0 70 :4 0 7fd
dfc dfe :3 0 800
dd6 e00 :2 0 e02
803 e03 dd3 e02
0 e04 805 0
e30 65 :3 0 66
:3 0 e05 e06 0
65 :3 0 76 :3 0
e08 e09 0 27
:2 0 2 :4 0 123
:2 0 78 :2 0 27
:2 0 807 e0e e10
:3 0 80a e0a e12
e07 e14 e13 :2 0
68 :3 0 79 :3 0
e16 e17 0 6a
:4 0 124 :4 0 6d
:2 0 6e :3 0 80e
e1b e1d :3 0 811
e18 e1f :2 0 e21
814 e22 e15 e21
0 e23 816 0
e30 88 :3 0 e8
:3 0 e24 e25 0
72 :3 0 58 :3 0
30 :2 0 818 e27
e2a 28 :3 0 8a
:3 0 81b e26 e2e
:2 0 e30 81f e31
db1 e30 0 e32
824 0 1d4d 72
:3 0 58 :3 0 30
:2 0 826 e33 e36
b7 :2 0 30 :2 0
82b e38 e3a :3 0
72 :3 0 58 :3 0
30 :2 0 82e e3c
e3f b7 :2 0 27
:2 0 833 e41 e43
:3 0 e3b e45 e44
:2 0 65 :3 0 66
:3 0 e47 e48 0
65 :3 0 76 :3 0
e4a e4b 0 18
:2 0 2 :4 0 125
:2 0 78 :2 0 27
:2 0 836 e50 e52
:3 0 839 e4c e54
e49 e56 e55 :2 0
68 :3 0 79 :3 0
e58 e59 0 6a
:4 0 126 :4 0 6d
:2 0 6e :3 0 83d
e5d e5f :3 0 6d
:2 0 82 :4 0 840
e61 e63 :3 0 6d
:2 0 83 :4 0 843
e65 e67 :3 0 6d
:2 0 72 :3 0 73
:3 0 58 :3 0 846
e6b e6d 74 :4 0
848 e6a e70 84b
e69 e72 :3 0 6d
:2 0 e5 :4 0 84e
e74 e76 :3 0 6d
:2 0 70 :4 0 851
e78 e7a :3 0 6d
:2 0 28 :3 0 854
e7c e7e :3 0 6d
:2 0 70 :4 0 857
e80 e82 :3 0 85a
e5a e84 :2 0 e86
85d e87 e57 e86
0 e88 85f 0
eb4 65 :3 0 66
:3 0 e89 e8a 0
65 :3 0 76 :3 0
e8c e8d 0 27
:2 0 2 :4 0 127
:2 0 78 :2 0 27
:2 0 861 e92 e94
:3 0 864 e8e e96
e8b e98 e97 :2 0
68 :3 0 79 :3 0
e9a e9b 0 6a
:4 0 128 :4 0 6d
:2 0 6e :3 0 868
e9f ea1 :3 0 86b
e9c ea3 :2 0 ea5
86e ea6 e99 ea5
0 ea7 870 0
eb4 88 :3 0 e8
:3 0 ea8 ea9 0
72 :3 0 58 :3 0
30 :2 0 872 eab
eae 28 :3 0 8a
:3 0 875 eaa eb2
:2 0 eb4 879 eb5
e46 eb4 0 eb6
87d 0 1d4d 21
:4 0 eb7 eb8 0
1d4d 129 :3 0 12a
:3 0 97 :3 0 98
:3 0 1f :3 0 97
:3 0 98 :3 0 129
:3 0 12a :3 0 21
:3 0 44 :3 0 12b
:3 0 b8 :3 0 17
:3 0 12c :3 0 17
:3 0 12d :3 0 1d
:3 0 12e :3 0 26
:4 0 12f 1 :8 0
ed4 15 :3 0 9b
:3 0 ecf ed0 0
9c :3 0 ed1 ed2
0 ed4 87f f27
9d :3 0 15 :3 0
9b :3 0 ed6 ed7
0 9c :3 0 ed8
ed9 0 edb 882
edd 884 edc edb
:2 0 f25 9e :3 0
15 :3 0 9b :3 0
ee0 ee1 0 9c
:3 0 ee2 ee3 0
f1d 65 :3 0 66
:3 0 ee5 ee6 0
65 :3 0 76 :3 0
ee8 ee9 0 9f
:2 0 2 :4 0 130
:2 0 78 :2 0 27
:2 0 886 eee ef0
:3 0 889 eea ef2
ee7 ef4 ef3 :2 0
68 :3 0 79 :3 0
ef6 ef7 0 6a
:4 0 131 :4 0 6d
:2 0 6e :3 0 88d
efb efd :3 0 6d
:2 0 82 :4 0 890
eff f01 :3 0 6d
:2 0 a2 :4 0 893
f03 f05 :3 0 6d
:2 0 9c :3 0 896
f07 f09 :3 0 6d
:2 0 a3 :4 0 899
f0b f0d :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 89c f10 f14
8a0 f0f f16 :3 0
8a3 ef8 f18 :2 0
f1a 8a6 f1b ef5
f1a 0 f1c 8a8
0 f1d 8aa f20
:3 0 f20 0 f20
f1f f1d f1e :6 0
f22 16 :3 0 8ad
f24 8af f23 f22
:2 0 f25 8b1 :2 0
f27 0 f27 f26
ed4 f25 :6 0 1d4d
1 :3 0 15 :3 0
9b :3 0 f29 f2a
0 15 :3 0 8f
:2 0 a7 :3 0 f2c
f2e 0 8b6 f2d
f30 :3 0 f31 :2 0
21 :3 0 96 :2 0
8b9 f34 f35 :3 0
f36 :2 0 f37 :2 0
f32 f39 f38 :2 0
46 :3 0 27 :2 0
f3b f3c 0 f4d
72 :3 0 44 :3 0
30 :2 0 8bb f3e
f41 a8 :2 0 30
:2 0 8c0 f43 f45
:3 0 1f :3 0 21
:3 0 f47 f48 0
f4a 8c3 f4b f46
f4a 0 f4c 8c5
0 f4d 8c7 f4e
f3a f4d 0 f4f
8ca 0 1d4d 33
:3 0 30 :2 0 f50
f51 0 1d4d 44
:3 0 30 :2 0 f53
f54 0 1d4d 62
:3 0 8f :2 0 27
:2 0 8ce f57 f59
:3 0 a4 :3 0 26
:3 0 27 :2 0 27
:2 0 8d1 f5b f5f
8f :2 0 30 :4 0
8d7 f61 f63 :3 0
132 :3 0 133 :3 0
134 :3 0 a4 :3 0
1f :3 0 134 :3 0
a4 :3 0 133 :3 0
134 :3 0 a4 :3 0
135 :3 0 134 :3 0
a4 :3 0 22 :3 0
134 :3 0 a4 :3 0
133 :3 0 134 :3 0
a4 :3 0 135 :3 0
136 :3 0 37 :3 0
136 :3 0 19 :3 0
21 :3 0 44 :3 0
47 :3 0 12b :3 0
12c :3 0 17 :3 0
12d :3 0 1d :3 0
12e :3 0 137 :4 0
138 1 :8 0 f8d
15 :3 0 9b :3 0
f88 f89 0 9c
:3 0 f8a f8b 0
f8d 8da fe0 9d
:3 0 15 :3 0 9b
:3 0 f8f f90 0
9c :3 0 f91 f92
0 f94 8dd f96
8df f95 f94 :2 0
fde 9e :3 0 15
:3 0 9b :3 0 f99
f9a 0 9c :3 0
f9b f9c 0 fd6
65 :3 0 66 :3 0
f9e f9f 0 65
:3 0 76 :3 0 fa1
fa2 0 9f :2 0
2 :4 0 139 :2 0
78 :2 0 27 :2 0
8e1 fa7 fa9 :3 0
8e4 fa3 fab fa0
fad fac :2 0 68
:3 0 79 :3 0 faf
fb0 0 6a :4 0
13a :4 0 6d :2 0
6e :3 0 8e8 fb4
fb6 :3 0 6d :2 0
82 :4 0 8eb fb8
fba :3 0 6d :2 0
a2 :4 0 8ee fbc
fbe :3 0 6d :2 0
9c :3 0 8f1 fc0
fc2 :3 0 6d :2 0
a3 :4 0 8f4 fc4
fc6 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
8f7 fc9 fcd 8fb
fc8 fcf :3 0 8fe
fb1 fd1 :2 0 fd3
901 fd4 fae fd3
0 fd5 903 0
fd6 905 fd9 :3 0
fd9 0 fd9 fd8
fd6 fd7 :6 0 fdb
18 :3 0 908 fdd
90a fdc fdb :2 0
fde 90c :2 0 fe0
0 fe0 fdf f8d
fde :6 0 111f 1
:3 0 15 :3 0 9b
:3 0 fe2 fe3 0
15 :3 0 8f :2 0
a7 :3 0 fe5 fe7
0 911 fe6 fe9
:3 0 fea :2 0 46
:3 0 27 :2 0 fec
fed 0 1089 72
:3 0 47 :3 0 30
:2 0 914 fef ff2
8f :2 0 30 :2 0
919 ff4 ff6 :3 0
ff7 :2 0 72 :3 0
44 :3 0 30 :2 0
91c ff9 ffc 8f
:2 0 27 :2 0 921
ffe 1000 :3 0 1001
:2 0 ff8 1003 1002
:2 0 132 :3 0 13b
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 13b
:3 0 134 :3 0 a4
:3 0 13c :3 0 134
:3 0 a4 :3 0 22
:3 0 134 :3 0 a4
:3 0 13b :3 0 134
:3 0 a4 :3 0 13c
:3 0 13d :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 12b
:3 0 12c :3 0 17
:3 0 12d :3 0 1d
:3 0 12e :3 0 137
:4 0 13e 1 :8 0
102b 15 :3 0 9b
:3 0 1026 1027 0
9c :3 0 1028 1029
0 102b 924 107e
9d :3 0 15 :3 0
9b :3 0 102d 102e
0 9c :3 0 102f
1030 0 1032 927
1034 929 1033 1032
:2 0 107c 9e :3 0
15 :3 0 9b :3 0
1037 1038 0 9c
:3 0 1039 103a 0
1074 65 :3 0 66
:3 0 103c 103d 0
65 :3 0 76 :3 0
103f 1040 0 9f
:2 0 2 :4 0 13f
:2 0 78 :2 0 27
:2 0 92b 1045 1047
:3 0 92e 1041 1049
103e 104b 104a :2 0
68 :3 0 79 :3 0
104d 104e 0 6a
:4 0 140 :4 0 6d
:2 0 6e :3 0 932
1052 1054 :3 0 6d
:2 0 82 :4 0 935
1056 1058 :3 0 6d
:2 0 a2 :4 0 938
105a 105c :3 0 6d
:2 0 9c :3 0 93b
105e 1060 :3 0 6d
:2 0 a3 :4 0 93e
1062 1064 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 941 1067 106b
945 1066 106d :3 0
948 104f 106f :2 0
1071 94b 1072 104c
1071 0 1073 94d
0 1074 94f 1077
:3 0 1077 0 1077
1076 1074 1075 :6 0
1079 1a :3 0 952
107b 954 107a 1079
:2 0 107c 956 :2 0
107e 0 107e 107d
102b 107c :6 0 1080
1 :3 0 959 1085
33 :3 0 114 :2 0
1081 1082 0 1084
95b 1086 1004 1080
0 1087 0 1084
0 1087 95d 0
1089 ae :3 0 960
111d 15 :3 0 9b
:3 0 108a 108b 0
15 :3 0 8f :2 0
d9 :3 0 108d 108f
0 965 108e 1091
:3 0 1092 :2 0 72
:3 0 44 :3 0 30
:2 0 968 1094 1097
8f :2 0 27 :2 0
96d 1099 109b :3 0
109c :2 0 1093 109e
109d :2 0 132 :3 0
13b :3 0 134 :3 0
a4 :3 0 1f :3 0
134 :3 0 a4 :3 0
13b :3 0 134 :3 0
a4 :3 0 13c :3 0
134 :3 0 a4 :3 0
22 :3 0 134 :3 0
a4 :3 0 13b :3 0
134 :3 0 a4 :3 0
13c :3 0 13d :3 0
37 :3 0 19 :3 0
21 :3 0 44 :3 0
12b :3 0 12c :3 0
17 :3 0 12d :3 0
1d :3 0 12e :3 0
137 :4 0 141 1
:8 0 10c6 15 :3 0
9b :3 0 10c1 10c2
0 9c :3 0 10c3
10c4 0 10c6 970
1119 9d :3 0 15
:3 0 9b :3 0 10c8
10c9 0 9c :3 0
10ca 10cb 0 10cd
973 10cf 975 10ce
10cd :2 0 1117 9e
:3 0 15 :3 0 9b
:3 0 10d2 10d3 0
9c :3 0 10d4 10d5
0 110f 65 :3 0
66 :3 0 10d7 10d8
0 65 :3 0 76
:3 0 10da 10db 0
9f :2 0 2 :4 0
142 :2 0 78 :2 0
27 :2 0 977 10e0
10e2 :3 0 97a 10dc
10e4 10d9 10e6 10e5
:2 0 68 :3 0 79
:3 0 10e8 10e9 0
6a :4 0 143 :4 0
6d :2 0 6e :3 0
97e 10ed 10ef :3 0
6d :2 0 82 :4 0
981 10f1 10f3 :3 0
6d :2 0 a2 :4 0
984 10f5 10f7 :3 0
6d :2 0 9c :3 0
987 10f9 10fb :3 0
6d :2 0 a3 :4 0
98a 10fd 10ff :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 98d 1102
1106 991 1101 1108
:3 0 994 10ea 110a
:2 0 110c 997 110d
10e7 110c 0 110e
999 0 110f 99b
1112 :3 0 1112 0
1112 1111 110f 1110
:6 0 1114 1c :3 0
99e 1116 9a0 1115
1114 :2 0 1117 9a2
:2 0 1119 0 1119
1118 10c6 1117 :6 0
111b 1 :3 0 9a5
111c 109f 111b 0
111e feb 1089 0
111e 9a7 0 111f
9aa 119c 132 :3 0
13b :3 0 134 :3 0
a4 :3 0 1f :3 0
134 :3 0 a4 :3 0
13b :3 0 134 :3 0
a4 :3 0 13c :3 0
134 :3 0 a4 :3 0
22 :3 0 134 :3 0
a4 :3 0 13b :3 0
134 :3 0 a4 :3 0
13c :3 0 13d :3 0
37 :3 0 19 :3 0
21 :3 0 44 :3 0
12b :3 0 12c :3 0
17 :3 0 12d :3 0
1d :3 0 12e :3 0
137 :4 0 144 1
:8 0 1146 15 :3 0
9b :3 0 1141 1142
0 9c :3 0 1143
1144 0 1146 9ad
1199 9d :3 0 15
:3 0 9b :3 0 1148
1149 0 9c :3 0
114a 114b 0 114d
9b0 114f 9b2 114e
114d :2 0 1197 9e
:3 0 15 :3 0 9b
:3 0 1152 1153 0
9c :3 0 1154 1155
0 118f 65 :3 0
66 :3 0 1157 1158
0 65 :3 0 76
:3 0 115a 115b 0
9f :2 0 2 :4 0
145 :2 0 78 :2 0
27 :2 0 9b4 1160
1162 :3 0 9b7 115c
1164 1159 1166 1165
:2 0 68 :3 0 79
:3 0 1168 1169 0
6a :4 0 146 :4 0
6d :2 0 6e :3 0
9bb 116d 116f :3 0
6d :2 0 82 :4 0
9be 1171 1173 :3 0
6d :2 0 a2 :4 0
9c1 1175 1177 :3 0
6d :2 0 9c :3 0
9c4 1179 117b :3 0
6d :2 0 a3 :4 0
9c7 117d 117f :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 9ca 1182
1186 9ce 1181 1188
:3 0 9d1 116a 118a
:2 0 118c 9d4 118d
1167 118c 0 118e
9d6 0 118f 9d8
1192 :3 0 1192 0
1192 1191 118f 1190
:6 0 1194 1e :3 0
9db 1196 9dd 1195
1194 :2 0 1197 9df
:2 0 1199 0 1199
1198 1146 1197 :6 0
119b 1 :3 0 9e2
119d f64 111f 0
119e 0 119b 0
119e 9e4 0 119f
9e7 13b3 a4 :3 0
26 :3 0 27 :2 0
27 :2 0 9e9 11a0
11a4 8f :2 0 30
:4 0 9ef 11a6 11a8
:3 0 132 :3 0 133
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 133
:3 0 134 :3 0 a4
:3 0 135 :3 0 37
:3 0 136 :3 0 136
:3 0 19 :3 0 21
:3 0 44 :3 0 47
:3 0 12b :3 0 12c
:3 0 17 :3 0 12d
:3 0 1d :3 0 12e
:3 0 137 :4 0 147
1 :8 0 11c9 15
:3 0 9b :3 0 11c4
11c5 0 9c :3 0
11c6 11c7 0 11c9
9f2 121c 9d :3 0
15 :3 0 9b :3 0
11cb 11cc 0 9c
:3 0 11cd 11ce 0
11d0 9f5 11d2 9f7
11d1 11d0 :2 0 121a
9e :3 0 15 :3 0
9b :3 0 11d5 11d6
0 9c :3 0 11d7
11d8 0 1212 65
:3 0 66 :3 0 11da
11db 0 65 :3 0
76 :3 0 11dd 11de
0 9f :2 0 2
:4 0 148 :2 0 78
:2 0 27 :2 0 9f9
11e3 11e5 :3 0 9fc
11df 11e7 11dc 11e9
11e8 :2 0 68 :3 0
79 :3 0 11eb 11ec
0 6a :4 0 149
:4 0 6d :2 0 6e
:3 0 a00 11f0 11f2
:3 0 6d :2 0 82
:4 0 a03 11f4 11f6
:3 0 6d :2 0 a2
:4 0 a06 11f8 11fa
:3 0 6d :2 0 9c
:3 0 a09 11fc 11fe
:3 0 6d :2 0 a3
:4 0 a0c 1200 1202
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 a0f
1205 1209 a13 1204
120b :3 0 a16 11ed
120d :2 0 120f a19
1210 11ea 120f 0
1211 a1b 0 1212
a1d 1215 :3 0 1215
0 1215 1214 1212
1213 :6 0 1217 20
:3 0 a20 1219 a22
1218 1217 :2 0 121a
a24 :2 0 121c 0
121c 121b 11c9 121a
:6 0 133b 1 :3 0
15 :3 0 9b :3 0
121e 121f 0 15
:3 0 8f :2 0 a7
:3 0 1221 1223 0
a29 1222 1225 :3 0
1226 :2 0 46 :3 0
27 :2 0 1228 1229
0 12ba 72 :3 0
47 :3 0 30 :2 0
a2c 122b 122e 8f
:2 0 30 :2 0 a31
1230 1232 :3 0 1233
:2 0 72 :3 0 44
:3 0 30 :2 0 a34
1235 1238 8f :2 0
27 :2 0 a39 123a
123c :3 0 123d :2 0
1234 123f 123e :2 0
132 :3 0 13b :3 0
134 :3 0 a4 :3 0
1f :3 0 134 :3 0
a4 :3 0 13c :3 0
37 :3 0 13d :3 0
19 :3 0 21 :3 0
44 :3 0 12b :3 0
12c :3 0 17 :3 0
12d :3 0 1d :3 0
12e :3 0 137 :4 0
14a 1 :8 0 125b
15 :3 0 9b :3 0
1256 1257 0 9c
:3 0 1258 1259 0
125b a3c 12ae 9d
:3 0 15 :3 0 9b
:3 0 125d 125e 0
9c :3 0 125f 1260
0 1262 a3f 1264
a41 1263 1262 :2 0
12ac 9e :3 0 15
:3 0 9b :3 0 1267
1268 0 9c :3 0
1269 126a 0 12a4
65 :3 0 66 :3 0
126c 126d 0 65
:3 0 76 :3 0 126f
1270 0 9f :2 0
2 :4 0 14b :2 0
78 :2 0 27 :2 0
a43 1275 1277 :3 0
a46 1271 1279 126e
127b 127a :2 0 68
:3 0 79 :3 0 127d
127e 0 6a :4 0
14c :4 0 6d :2 0
6e :3 0 a4a 1282
1284 :3 0 6d :2 0
82 :4 0 a4d 1286
1288 :3 0 6d :2 0
a2 :4 0 a50 128a
128c :3 0 6d :2 0
9c :3 0 a53 128e
1290 :3 0 6d :2 0
a3 :4 0 a56 1292
1294 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
a59 1297 129b a5d
1296 129d :3 0 a60
127f 129f :2 0 12a1
a63 12a2 127c 12a1
0 12a3 a65 0
12a4 a67 12a7 :3 0
12a7 0 12a7 12a6
12a4 12a5 :6 0 12a9
22 :3 0 a6a 12ab
a6c 12aa 12a9 :2 0
12ac a6e :2 0 12ae
0 12ae 12ad 125b
12ac :6 0 12b0 1
:3 0 a71 12b6 33
:3 0 114 :2 0 12b1
12b2 0 12b5 0
12b5 a73 12b7 1240
12b0 0 12b8 0
12b5 0 12b8 a76
0 12ba ae :3 0
a79 1339 15 :3 0
9b :3 0 12bb 12bc
0 15 :3 0 8f
:2 0 d9 :3 0 12be
12c0 0 a7e 12bf
12c2 :3 0 12c3 :2 0
132 :3 0 13b :3 0
134 :3 0 a4 :3 0
1f :3 0 134 :3 0
a4 :3 0 13b :3 0
134 :3 0 a4 :3 0
13c :3 0 37 :3 0
13d :3 0 19 :3 0
21 :3 0 44 :3 0
12b :3 0 12c :3 0
17 :3 0 12d :3 0
1d :3 0 12e :3 0
137 :4 0 14d 1
:8 0 12e2 15 :3 0
9b :3 0 12dd 12de
0 9c :3 0 12df
12e0 0 12e2 a81
1335 9d :3 0 15
:3 0 9b :3 0 12e4
12e5 0 9c :3 0
12e6 12e7 0 12e9
a84 12eb a86 12ea
12e9 :2 0 1333 9e
:3 0 15 :3 0 9b
:3 0 12ee 12ef 0
9c :3 0 12f0 12f1
0 132b 65 :3 0
66 :3 0 12f3 12f4
0 65 :3 0 76
:3 0 12f6 12f7 0
9f :2 0 2 :4 0
14e :2 0 78 :2 0
27 :2 0 a88 12fc
12fe :3 0 a8b 12f8
1300 12f5 1302 1301
:2 0 68 :3 0 79
:3 0 1304 1305 0
6a :4 0 14f :4 0
6d :2 0 6e :3 0
a8f 1309 130b :3 0
6d :2 0 82 :4 0
a92 130d 130f :3 0
6d :2 0 a2 :4 0
a95 1311 1313 :3 0
6d :2 0 9c :3 0
a98 1315 1317 :3 0
6d :2 0 a3 :4 0
a9b 1319 131b :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 a9e 131e
1322 aa2 131d 1324
:3 0 aa5 1306 1326
:2 0 1328 aa8 1329
1303 1328 0 132a
aaa 0 132b aac
132e :3 0 132e 0
132e 132d 132b 132c
:6 0 1330 24 :3 0
aaf 1332 ab1 1331
1330 :2 0 1333 ab3
:2 0 1335 0 1335
1334 12e2 1333 :6 0
1337 1 :3 0 ab6
1338 12c4 1337 0
133a 1227 12ba 0
133a ab8 0 133b
abb 13af 132 :3 0
13b :3 0 134 :3 0
a4 :3 0 1f :3 0
134 :3 0 a4 :3 0
13b :3 0 134 :3 0
a4 :3 0 13c :3 0
37 :3 0 13d :3 0
19 :3 0 21 :3 0
44 :3 0 12b :3 0
12c :3 0 17 :3 0
12d :3 0 1d :3 0
12e :3 0 137 :4 0
150 1 :8 0 1359
15 :3 0 9b :3 0
1354 1355 0 9c
:3 0 1356 1357 0
1359 abe 13ac 9d
:3 0 15 :3 0 9b
:3 0 135b 135c 0
9c :3 0 135d 135e
0 1360 ac1 1362
ac3 1361 1360 :2 0
13aa 9e :3 0 15
:3 0 9b :3 0 1365
1366 0 9c :3 0
1367 1368 0 13a2
65 :3 0 66 :3 0
136a 136b 0 65
:3 0 76 :3 0 136d
136e 0 9f :2 0
2 :4 0 151 :2 0
78 :2 0 27 :2 0
ac5 1373 1375 :3 0
ac8 136f 1377 136c
1379 1378 :2 0 68
:3 0 79 :3 0 137b
137c 0 6a :4 0
152 :4 0 6d :2 0
6e :3 0 acc 1380
1382 :3 0 6d :2 0
82 :4 0 acf 1384
1386 :3 0 6d :2 0
a2 :4 0 ad2 1388
138a :3 0 6d :2 0
9c :3 0 ad5 138c
138e :3 0 6d :2 0
a3 :4 0 ad8 1390
1392 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
adb 1395 1399 adf
1394 139b :3 0 ae2
137d 139d :2 0 139f
ae5 13a0 137a 139f
0 13a1 ae7 0
13a2 ae9 13a5 :3 0
13a5 0 13a5 13a4
13a2 13a3 :6 0 13a7
26 :3 0 aec 13a9
aee 13a8 13a7 :2 0
13aa af0 :2 0 13ac
0 13ac 13ab 1359
13aa :6 0 13ae 1
:3 0 af3 13b0 11a9
133b 0 13b1 0
13ae 0 13b1 af5
0 13b2 af8 13b4
f5a 119f 0 13b5
0 13b2 0 13b5
afa 0 1d4d 15
:3 0 9b :3 0 13b6
13b7 0 15 :3 0
8f :2 0 a7 :3 0
13b9 13bb 0 aff
13ba 13bd :3 0 13be
:2 0 72 :3 0 44
:3 0 30 :2 0 b02
13c0 13c3 8f :2 0
27 :2 0 b07 13c5
13c7 :3 0 65 :3 0
66 :3 0 13c9 13ca
0 65 :3 0 76
:3 0 13cc 13cd 0
18 :2 0 2 :4 0
153 :2 0 78 :2 0
27 :2 0 b0a 13d2
13d4 :3 0 b0d 13ce
13d6 13cb 13d8 13d7
:2 0 68 :3 0 79
:3 0 13da 13db 0
6a :4 0 154 :4 0
6d :2 0 6e :3 0
b11 13df 13e1 :3 0
6d :2 0 82 :4 0
b14 13e3 13e5 :3 0
6d :2 0 83 :4 0
b17 13e7 13e9 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
155 :3 0 13ee 13ef
0 b1a 13ed 13f1
74 :4 0 b1c 13ec
13f4 b1f 13eb 13f6
:3 0 6d :2 0 e5
:4 0 b22 13f8 13fa
:3 0 6d :2 0 70
:4 0 b25 13fc 13fe
:3 0 6d :2 0 1d
:3 0 b28 1400 1402
:3 0 6d :2 0 70
:4 0 b2b 1404 1406
:3 0 b2e 13dc 1408
:2 0 140a b31 140b
13d9 140a 0 140c
b33 0 1437 65
:3 0 66 :3 0 140d
140e 0 65 :3 0
76 :3 0 1410 1411
0 27 :2 0 2
:4 0 156 :2 0 78
:2 0 27 :2 0 b35
1416 1418 :3 0 b38
1412 141a 140f 141c
141b :2 0 68 :3 0
79 :3 0 141e 141f
0 6a :4 0 157
:4 0 6d :2 0 6e
:3 0 b3c 1423 1425
:3 0 b3f 1420 1427
:2 0 1429 b42 142a
141d 1429 0 142b
b44 0 1437 88
:3 0 e8 :3 0 142c
142d 0 84 :3 0
155 :3 0 142f 1430
0 1d :3 0 8a
:3 0 b46 142e 1434
:2 0 1437 ae :3 0
b4a 15a8 19 :3 0
96 :2 0 b4e 1439
143a :3 0 143b :2 0
72 :3 0 37 :3 0
30 :2 0 b50 143d
1440 b2 :2 0 30
:2 0 b55 1442 1444
:3 0 143c 1446 1445
:2 0 62 :3 0 8f
:2 0 27 :2 0 b5a
1449 144b :3 0 47
:3 0 30 :2 0 144d
144e 0 14ba 158
:3 0 159 :3 0 47
:3 0 15a :3 0 b8
:3 0 17 :3 0 15b
:3 0 19 :3 0 15c
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 22
:4 0 15d 1 :8 0
1465 15 :3 0 9b
:3 0 1460 1461 0
9c :3 0 1462 1463
0 1465 b5d 14b8
9d :3 0 15 :3 0
9b :3 0 1467 1468
0 9c :3 0 1469
146a 0 146c b60
146e b62 146d 146c
:2 0 14b6 9e :3 0
15 :3 0 9b :3 0
1471 1472 0 9c
:3 0 1473 1474 0
14ae 65 :3 0 66
:3 0 1476 1477 0
65 :3 0 76 :3 0
1479 147a 0 9f
:2 0 2 :4 0 15e
:2 0 78 :2 0 27
:2 0 b64 147f 1481
:3 0 b67 147b 1483
1478 1485 1484 :2 0
68 :3 0 79 :3 0
1487 1488 0 6a
:4 0 15f :4 0 6d
:2 0 6e :3 0 b6b
148c 148e :3 0 6d
:2 0 82 :4 0 b6e
1490 1492 :3 0 6d
:2 0 a2 :4 0 b71
1494 1496 :3 0 6d
:2 0 9c :3 0 b74
1498 149a :3 0 6d
:2 0 a3 :4 0 b77
149c 149e :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 b7a 14a1 14a5
b7e 14a0 14a7 :3 0
b81 1489 14a9 :2 0
14ab b84 14ac 1486
14ab 0 14ad b86
0 14ae b88 14b1
:3 0 14b1 0 14b1
14b0 14ae 14af :6 0
14b3 28 :3 0 b8b
14b5 b8d 14b4 14b3
:2 0 14b6 b8f :2 0
14b8 0 14b8 14b7
1465 14b6 :6 0 14ba
1 :3 0 b92 1526
47 :3 0 30 :2 0
14bb 14bc 0 1525
158 :3 0 159 :3 0
47 :3 0 15a :3 0
b8 :3 0 17 :3 0
15b :3 0 19 :3 0
15c :3 0 134 :3 0
a4 :3 0 1f :4 0
160 1 :8 0 14d0
15 :3 0 9b :3 0
14cb 14cc 0 9c
:3 0 14cd 14ce 0
14d0 b95 1523 9d
:3 0 15 :3 0 9b
:3 0 14d2 14d3 0
9c :3 0 14d4 14d5
0 14d7 b98 14d9
b9a 14d8 14d7 :2 0
1521 9e :3 0 15
:3 0 9b :3 0 14dc
14dd 0 9c :3 0
14de 14df 0 1519
65 :3 0 66 :3 0
14e1 14e2 0 65
:3 0 76 :3 0 14e4
14e5 0 9f :2 0
2 :4 0 161 :2 0
78 :2 0 27 :2 0
b9c 14ea 14ec :3 0
b9f 14e6 14ee 14e3
14f0 14ef :2 0 68
:3 0 79 :3 0 14f2
14f3 0 6a :4 0
162 :4 0 6d :2 0
6e :3 0 ba3 14f7
14f9 :3 0 6d :2 0
82 :4 0 ba6 14fb
14fd :3 0 6d :2 0
a2 :4 0 ba9 14ff
1501 :3 0 6d :2 0
9c :3 0 bac 1503
1505 :3 0 6d :2 0
a3 :4 0 baf 1507
1509 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
bb2 150c 1510 bb6
150b 1512 :3 0 bb9
14f4 1514 :2 0 1516
bbc 1517 14f1 1516
0 1518 bbe 0
1519 bc0 151c :3 0
151c 0 151c 151b
1519 151a :6 0 151e
2a :3 0 bc3 1520
bc5 151f 151e :2 0
1521 bc7 :2 0 1523
0 1523 1522 14d0
1521 :6 0 1525 1
:3 0 bca 1527 144c
14ba 0 1528 0
1525 0 1528 bcd
0 15a6 72 :3 0
47 :3 0 30 :2 0
bd0 1529 152c 72
:3 0 a8 :2 0 37
:3 0 30 :2 0 bd3
152e 1532 bd8 152f
1534 :3 0 65 :3 0
66 :3 0 1536 1537
0 65 :3 0 76
:3 0 1539 153a 0
18 :2 0 2 :4 0
163 :2 0 78 :2 0
27 :2 0 bdb 153f
1541 :3 0 bde 153b
1543 1538 1545 1544
:2 0 68 :3 0 79
:3 0 1547 1548 0
6a :4 0 164 :4 0
6d :2 0 6e :3 0
be2 154c 154e :3 0
6d :2 0 82 :4 0
be5 1550 1552 :3 0
6d :2 0 83 :4 0
be8 1554 1556 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
155 :3 0 155b 155c
0 beb 155a 155e
74 :4 0 bed 1559
1561 bf0 1558 1563
:3 0 6d :2 0 e5
:4 0 bf3 1565 1567
:3 0 6d :2 0 70
:4 0 bf6 1569 156b
:3 0 6d :2 0 1d
:3 0 bf9 156d 156f
:3 0 6d :2 0 70
:4 0 bfc 1571 1573
:3 0 bff 1549 1575
:2 0 1577 c02 1578
1546 1577 0 1579
c04 0 15a3 65
:3 0 66 :3 0 157a
157b 0 65 :3 0
76 :3 0 157d 157e
0 27 :2 0 2
:4 0 165 :2 0 78
:2 0 27 :2 0 c06
1583 1585 :3 0 c09
157f 1587 157c 1589
1588 :2 0 68 :3 0
79 :3 0 158b 158c
0 6a :4 0 166
:4 0 6d :2 0 6e
:3 0 c0d 1590 1592
:3 0 c10 158d 1594
:2 0 1596 c13 1597
158a 1596 0 1598
c15 0 15a3 88
:3 0 e8 :3 0 1599
159a 0 84 :3 0
155 :3 0 159c 159d
0 1d :3 0 8a
:3 0 c17 159b 15a1
:2 0 15a3 c1b 15a4
1535 15a3 0 15a5
c1f 0 15a6 c21
15a7 1447 15a6 0
15a9 13c8 1437 0
15a9 c24 0 15ae
46 :3 0 27 :2 0
15aa 15ab 0 15ae
ae :3 0 c27 1637
72 :3 0 46 :3 0
30 :2 0 c2a 15af
15b2 8f :2 0 27
:2 0 c2f 15b4 15b6
:3 0 15b7 :2 0 167
:3 0 72 :3 0 32
:3 0 30 :2 0 c32
15ba 15bd c35 15b9
15bf 15c0 :2 0 b7
:2 0 30 :2 0 c39
15c2 15c4 :3 0 15b8
15c6 15c5 :2 0 65
:3 0 66 :3 0 15c8
15c9 0 65 :3 0
76 :3 0 15cb 15cc
0 18 :2 0 2
:4 0 168 :2 0 78
:2 0 27 :2 0 c3c
15d1 15d3 :3 0 c3f
15cd 15d5 15ca 15d7
15d6 :2 0 68 :3 0
79 :3 0 15d9 15da
0 6a :4 0 169
:4 0 6d :2 0 6e
:3 0 c43 15de 15e0
:3 0 6d :2 0 82
:4 0 c46 15e2 15e4
:3 0 6d :2 0 83
:4 0 c49 15e6 15e8
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 155 :3 0 15ed
15ee 0 c4c 15ec
15f0 74 :4 0 c4e
15eb 15f3 c51 15ea
15f5 :3 0 6d :2 0
e5 :4 0 c54 15f7
15f9 :3 0 6d :2 0
70 :4 0 c57 15fb
15fd :3 0 6d :2 0
1d :3 0 c5a 15ff
1601 :3 0 6d :2 0
70 :4 0 c5d 1603
1605 :3 0 c60 15db
1607 :2 0 1609 c63
160a 15d8 1609 0
160b c65 0 1635
65 :3 0 66 :3 0
160c 160d 0 65
:3 0 76 :3 0 160f
1610 0 27 :2 0
2 :4 0 16a :2 0
78 :2 0 27 :2 0
c67 1615 1617 :3 0
c6a 1611 1619 160e
161b 161a :2 0 68
:3 0 79 :3 0 161d
161e 0 6a :4 0
16b :4 0 6d :2 0
6e :3 0 c6e 1622
1624 :3 0 c71 161f
1626 :2 0 1628 c74
1629 161c 1628 0
162a c76 0 1635
88 :3 0 e8 :3 0
162b 162c 0 84
:3 0 155 :3 0 162e
162f 0 1d :3 0
8a :3 0 c78 162d
1633 :2 0 1635 c7c
1636 15c7 1635 0
1638 13bf 15ae 0
1638 c80 0 1d4d
a4 :3 0 26 :3 0
27 :2 0 27 :2 0
c83 1639 163d 8f
:2 0 30 :4 0 c89
163f 1641 :3 0 2b
:3 0 a4 :3 0 2b
:3 0 6d :2 0 1d
:3 0 c8c 1646 1648
:3 0 27 :2 0 2a
:2 0 c8f 1644 164c
1643 164d 0 1838
16c :3 0 97 :3 0
16d :3 0 21 :3 0
16e :3 0 72 :3 0
97 :3 0 16d :3 0
16f :3 0 72 :3 0
97 :3 0 16d :3 0
170 :3 0 2d :3 0
48 :3 0 4c :3 0
49 :3 0 4a :3 0
171 :3 0 12d :3 0
1d :4 0 172 1
:8 0 166a 15 :3 0
9b :3 0 1665 1666
0 9c :3 0 1667
1668 0 166a c93
16bd 9d :3 0 15
:3 0 9b :3 0 166c
166d 0 9c :3 0
166e 166f 0 1671
c96 1673 c98 1672
1671 :2 0 16bb 9e
:3 0 15 :3 0 9b
:3 0 1676 1677 0
9c :3 0 1678 1679
0 16b3 65 :3 0
66 :3 0 167b 167c
0 65 :3 0 76
:3 0 167e 167f 0
9f :2 0 2 :4 0
173 :2 0 78 :2 0
27 :2 0 c9a 1684
1686 :3 0 c9d 1680
1688 167d 168a 1689
:2 0 68 :3 0 79
:3 0 168c 168d 0
6a :4 0 174 :4 0
6d :2 0 6e :3 0
ca1 1691 1693 :3 0
6d :2 0 82 :4 0
ca4 1695 1697 :3 0
6d :2 0 a2 :4 0
ca7 1699 169b :3 0
6d :2 0 9c :3 0
caa 169d 169f :3 0
6d :2 0 a3 :4 0
cad 16a1 16a3 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 cb0 16a6
16aa cb4 16a5 16ac
:3 0 cb7 168e 16ae
:2 0 16b0 cba 16b1
168b 16b0 0 16b2
cbc 0 16b3 cbe
16b6 :3 0 16b6 0
16b6 16b5 16b3 16b4
:6 0 16b8 2c :3 0
cc1 16ba cc3 16b9
16b8 :2 0 16bb cc5
:2 0 16bd 0 16bd
16bc 166a 16bb :6 0
1838 1 :3 0 15
:3 0 9b :3 0 16bf
16c0 0 15 :3 0
8f :2 0 d9 :3 0
16c2 16c4 0 cca
16c3 16c6 :3 0 16c7
:2 0 65 :3 0 66
:3 0 16c9 16ca 0
65 :3 0 76 :3 0
16cc 16cd 0 18
:2 0 2 :4 0 175
:2 0 78 :2 0 27
:2 0 ccd 16d2 16d4
:3 0 cd0 16ce 16d6
16cb 16d8 16d7 :2 0
68 :3 0 79 :3 0
16da 16db 0 6a
:4 0 176 :4 0 6d
:2 0 6e :3 0 cd4
16df 16e1 :3 0 6d
:2 0 82 :4 0 cd7
16e3 16e5 :3 0 6d
:2 0 83 :4 0 cda
16e7 16e9 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 e4
:3 0 16ee 16ef 0
cdd 16ed 16f1 74
:4 0 cdf 16ec 16f4
ce2 16eb 16f6 :3 0
6d :2 0 e5 :4 0
ce5 16f8 16fa :3 0
6d :2 0 70 :4 0
ce8 16fc 16fe :3 0
6d :2 0 1d :3 0
ceb 1700 1702 :3 0
6d :2 0 70 :4 0
cee 1704 1706 :3 0
cf1 16dc 1708 :2 0
170a cf4 170b 16d9
170a 0 170c cf6
0 1736 65 :3 0
66 :3 0 170d 170e
0 65 :3 0 76
:3 0 1710 1711 0
27 :2 0 2 :4 0
177 :2 0 78 :2 0
27 :2 0 cf8 1716
1718 :3 0 cfb 1712
171a 170f 171c 171b
:2 0 68 :3 0 79
:3 0 171e 171f 0
6a :4 0 178 :4 0
6d :2 0 6e :3 0
cff 1723 1725 :3 0
d02 1720 1727 :2 0
1729 d05 172a 171d
1729 0 172b d07
0 1736 88 :3 0
e8 :3 0 172c 172d
0 84 :3 0 e4
:3 0 172f 1730 0
1d :3 0 8a :3 0
d09 172e 1734 :2 0
1736 d0d 1737 16c8
1736 0 1738 d11
0 1838 a4 :3 0
4c :3 0 27 :2 0
27 :2 0 d13 1739
173d 8f :2 0 30
:4 0 d19 173f 1741
:3 0 1742 :2 0 72
:3 0 4a :3 0 30
:2 0 d1c 1744 1747
b2 :2 0 30 :2 0
d21 1749 174b :3 0
174c :2 0 72 :3 0
48 :3 0 30 :2 0
d24 174e 1751 72
:3 0 b2 :2 0 4a
:3 0 30 :2 0 d27
1753 1757 d2c 1754
1759 :3 0 175a :2 0
174d 175c 175b :2 0
175d :2 0 1743 175f
175e :2 0 65 :3 0
66 :3 0 1761 1762
0 65 :3 0 76
:3 0 1764 1765 0
18 :2 0 2 :4 0
179 :2 0 78 :2 0
27 :2 0 d2f 176a
176c :3 0 d32 1766
176e 1763 1770 176f
:2 0 68 :3 0 79
:3 0 1772 1773 0
6a :4 0 17a :4 0
6d :2 0 6e :3 0
d36 1777 1779 :3 0
6d :2 0 82 :4 0
d39 177b 177d :3 0
6d :2 0 83 :4 0
d3c 177f 1781 :3 0
6d :2 0 72 :3 0
73 :3 0 84 :3 0
17b :3 0 1786 1787
0 d3f 1785 1789
74 :4 0 d41 1784
178c d44 1783 178e
:3 0 6d :2 0 e5
:4 0 d47 1790 1792
:3 0 6d :2 0 70
:4 0 d4a 1794 1796
:3 0 6d :2 0 1d
:3 0 d4d 1798 179a
:3 0 6d :2 0 70
:4 0 d50 179c 179e
:3 0 d53 1774 17a0
:2 0 17a2 d56 17a3
1771 17a2 0 17a4
d58 0 17ce 65
:3 0 66 :3 0 17a5
17a6 0 65 :3 0
76 :3 0 17a8 17a9
0 27 :2 0 2
:4 0 17c :2 0 78
:2 0 27 :2 0 d5a
17ae 17b0 :3 0 d5d
17aa 17b2 17a7 17b4
17b3 :2 0 68 :3 0
79 :3 0 17b6 17b7
0 6a :4 0 17d
:4 0 6d :2 0 6e
:3 0 d61 17bb 17bd
:3 0 d64 17b8 17bf
:2 0 17c1 d67 17c2
17b5 17c1 0 17c3
d69 0 17ce 88
:3 0 e8 :3 0 17c4
17c5 0 84 :3 0
17b :3 0 17c7 17c8
0 1d :3 0 8a
:3 0 d6b 17c6 17cc
:2 0 17ce d6f 17cf
1760 17ce 0 17d0
d73 0 1838 17e
:3 0 17f :3 0 180
:3 0 28 :3 0 42
:3 0 1e :3 0 181
:3 0 bd :3 0 1a
:3 0 12e :3 0 12d
:3 0 1d :4 0 182
1 :8 0 17e3 15
:3 0 9b :3 0 17de
17df 0 9c :3 0
17e0 17e1 0 17e3
d75 1836 9d :3 0
15 :3 0 9b :3 0
17e5 17e6 0 9c
:3 0 17e7 17e8 0
17ea d78 17ec d7a
17eb 17ea :2 0 1834
9e :3 0 15 :3 0
9b :3 0 17ef 17f0
0 9c :3 0 17f1
17f2 0 182c 65
:3 0 66 :3 0 17f4
17f5 0 65 :3 0
76 :3 0 17f7 17f8
0 9f :2 0 2
:4 0 183 :2 0 78
:2 0 27 :2 0 d7c
17fd 17ff :3 0 d7f
17f9 1801 17f6 1803
1802 :2 0 68 :3 0
79 :3 0 1805 1806
0 6a :4 0 184
:4 0 6d :2 0 6e
:3 0 d83 180a 180c
:3 0 6d :2 0 82
:4 0 d86 180e 1810
:3 0 6d :2 0 a2
:4 0 d89 1812 1814
:3 0 6d :2 0 9c
:3 0 d8c 1816 1818
:3 0 6d :2 0 a3
:4 0 d8f 181a 181c
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 d92
181f 1823 d96 181e
1825 :3 0 d99 1807
1827 :2 0 1829 d9c
182a 1804 1829 0
182b d9e 0 182c
da0 182f :3 0 182f
0 182f 182e 182c
182d :6 0 1831 2e
:3 0 da3 1833 da5
1832 1831 :2 0 1834
da7 :2 0 1836 0
1836 1835 17e3 1834
:6 0 1838 1 :3 0
daa 1a7c 2c :3 0
a4 :3 0 2c :3 0
6d :2 0 1d :3 0
db0 183c 183e :3 0
27 :2 0 2a :2 0
db3 183a 1842 1839
1843 0 1a7b 185
:3 0 2d :3 0 186
:3 0 187 :3 0 1d
:4 0 188 1 :8 0
1850 15 :3 0 9b
:3 0 184b 184c 0
9c :3 0 184d 184e
0 1850 db7 18a3
9d :3 0 15 :3 0
9b :3 0 1852 1853
0 9c :3 0 1854
1855 0 1857 dba
1859 dbc 1858 1857
:2 0 18a1 9e :3 0
15 :3 0 9b :3 0
185c 185d 0 9c
:3 0 185e 185f 0
1899 65 :3 0 66
:3 0 1861 1862 0
65 :3 0 76 :3 0
1864 1865 0 9f
:2 0 2 :4 0 189
:2 0 78 :2 0 27
:2 0 dbe 186a 186c
:3 0 dc1 1866 186e
1863 1870 186f :2 0
68 :3 0 79 :3 0
1872 1873 0 6a
:4 0 18a :4 0 6d
:2 0 6e :3 0 dc5
1877 1879 :3 0 6d
:2 0 82 :4 0 dc8
187b 187d :3 0 6d
:2 0 a2 :4 0 dcb
187f 1881 :3 0 6d
:2 0 9c :3 0 dce
1883 1885 :3 0 6d
:2 0 a3 :4 0 dd1
1887 1889 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 dd4 188c 1890
dd8 188b 1892 :3 0
ddb 1874 1894 :2 0
1896 dde 1897 1871
1896 0 1898 de0
0 1899 de2 189c
:3 0 189c 0 189c
189b 1899 189a :6 0
189e 30 :3 0 de5
18a0 de7 189f 189e
:2 0 18a1 de9 :2 0
18a3 0 18a3 18a2
1850 18a1 :6 0 1a7b
1 :3 0 15 :3 0
9b :3 0 18a5 18a6
0 15 :3 0 8f
:2 0 d9 :3 0 18a8
18aa 0 dee 18a9
18ac :3 0 18ad :2 0
65 :3 0 66 :3 0
18af 18b0 0 65
:3 0 76 :3 0 18b2
18b3 0 18 :2 0
2 :4 0 18b :2 0
78 :2 0 27 :2 0
df1 18b8 18ba :3 0
df4 18b4 18bc 18b1
18be 18bd :2 0 68
:3 0 79 :3 0 18c0
18c1 0 6a :4 0
18c :4 0 6d :2 0
6e :3 0 df8 18c5
18c7 :3 0 6d :2 0
82 :4 0 dfb 18c9
18cb :3 0 6d :2 0
83 :4 0 dfe 18cd
18cf :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 e4 :3 0
18d4 18d5 0 e01
18d3 18d7 74 :4 0
e03 18d2 18da e06
18d1 18dc :3 0 6d
:2 0 e5 :4 0 e09
18de 18e0 :3 0 6d
:2 0 70 :4 0 e0c
18e2 18e4 :3 0 6d
:2 0 1d :3 0 e0f
18e6 18e8 :3 0 6d
:2 0 70 :4 0 e12
18ea 18ec :3 0 e15
18c2 18ee :2 0 18f0
e18 18f1 18bf 18f0
0 18f2 e1a 0
191c 65 :3 0 66
:3 0 18f3 18f4 0
65 :3 0 76 :3 0
18f6 18f7 0 27
:2 0 2 :4 0 18d
:2 0 78 :2 0 27
:2 0 e1c 18fc 18fe
:3 0 e1f 18f8 1900
18f5 1902 1901 :2 0
68 :3 0 79 :3 0
1904 1905 0 6a
:4 0 18e :4 0 6d
:2 0 6e :3 0 e23
1909 190b :3 0 e26
1906 190d :2 0 190f
e29 1910 1903 190f
0 1911 e2b 0
191c 88 :3 0 e8
:3 0 1912 1913 0
84 :3 0 e4 :3 0
1915 1916 0 1d
:3 0 8a :3 0 e2d
1914 191a :2 0 191c
e31 191d 18ae 191c
0 191e e35 0
1a7b 12a :3 0 134
:3 0 a4 :3 0 1f
:3 0 134 :3 0 a4
:3 0 12a :3 0 134
:3 0 a4 :3 0 18f
:3 0 190 :3 0 37
:3 0 21 :3 0 44
:3 0 12b :3 0 12c
:3 0 17 :3 0 12d
:3 0 1d :3 0 12e
:4 0 191 1 :8 0
1939 15 :3 0 9b
:3 0 1934 1935 0
9c :3 0 1936 1937
0 1939 e37 198c
9d :3 0 15 :3 0
9b :3 0 193b 193c
0 9c :3 0 193d
193e 0 1940 e3a
1942 e3c 1941 1940
:2 0 198a 9e :3 0
15 :3 0 9b :3 0
1945 1946 0 9c
:3 0 1947 1948 0
1982 65 :3 0 66
:3 0 194a 194b 0
65 :3 0 76 :3 0
194d 194e 0 9f
:2 0 2 :4 0 192
:2 0 78 :2 0 27
:2 0 e3e 1953 1955
:3 0 e41 194f 1957
194c 1959 1958 :2 0
68 :3 0 79 :3 0
195b 195c 0 6a
:4 0 193 :4 0 6d
:2 0 6e :3 0 e45
1960 1962 :3 0 6d
:2 0 82 :4 0 e48
1964 1966 :3 0 6d
:2 0 a2 :4 0 e4b
1968 196a :3 0 6d
:2 0 9c :3 0 e4e
196c 196e :3 0 6d
:2 0 a3 :4 0 e51
1970 1972 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 e54 1975 1979
e58 1974 197b :3 0
e5b 195d 197d :2 0
197f e5e 1980 195a
197f 0 1981 e60
0 1982 e62 1985
:3 0 1985 0 1985
1984 1982 1983 :6 0
1987 32 :3 0 e65
1989 e67 1988 1987
:2 0 198a e69 :2 0
198c 0 198c 198b
1939 198a :6 0 1a7b
1 :3 0 15 :3 0
9b :3 0 198e 198f
0 15 :3 0 8f
:2 0 a7 :3 0 1991
1993 0 e6e 1992
1995 :3 0 1996 :2 0
72 :3 0 44 :3 0
30 :2 0 e71 1998
199b 8f :2 0 27
:2 0 e76 199d 199f
:3 0 19a0 :2 0 1997
19a2 19a1 :2 0 65
:3 0 66 :3 0 19a4
19a5 0 65 :3 0
76 :3 0 19a7 19a8
0 18 :2 0 2
:4 0 194 :2 0 78
:2 0 27 :2 0 e79
19ad 19af :3 0 e7c
19a9 19b1 19a6 19b3
19b2 :2 0 68 :3 0
79 :3 0 19b5 19b6
0 6a :4 0 195
:4 0 6d :2 0 6e
:3 0 e80 19ba 19bc
:3 0 6d :2 0 82
:4 0 e83 19be 19c0
:3 0 6d :2 0 83
:4 0 e86 19c2 19c4
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 155 :3 0 19c9
19ca 0 e89 19c8
19cc 74 :4 0 e8b
19c7 19cf e8e 19c6
19d1 :3 0 6d :2 0
e5 :4 0 e91 19d3
19d5 :3 0 6d :2 0
70 :4 0 e94 19d7
19d9 :3 0 6d :2 0
1d :3 0 e97 19db
19dd :3 0 6d :2 0
70 :4 0 e9a 19df
19e1 :3 0 e9d 19b7
19e3 :2 0 19e5 ea0
19e6 19b4 19e5 0
19e7 ea2 0 1a11
65 :3 0 66 :3 0
19e8 19e9 0 65
:3 0 76 :3 0 19eb
19ec 0 27 :2 0
2 :4 0 196 :2 0
78 :2 0 27 :2 0
ea4 19f1 19f3 :3 0
ea7 19ed 19f5 19ea
19f7 19f6 :2 0 68
:3 0 79 :3 0 19f9
19fa 0 6a :4 0
197 :4 0 6d :2 0
6e :3 0 eab 19fe
1a00 :3 0 eae 19fb
1a02 :2 0 1a04 eb1
1a05 19f8 1a04 0
1a06 eb3 0 1a11
88 :3 0 e8 :3 0
1a07 1a08 0 84
:3 0 155 :3 0 1a0a
1a0b 0 1d :3 0
8a :3 0 eb5 1a09
1a0f :2 0 1a11 eb9
1a12 19a3 1a11 0
1a13 ebd 0 1a7b
17e :3 0 17f :3 0
180 :3 0 28 :3 0
42 :3 0 1e :3 0
181 :3 0 bd :3 0
1a :3 0 12e :3 0
12d :3 0 1d :4 0
198 1 :8 0 1a26
15 :3 0 9b :3 0
1a21 1a22 0 9c
:3 0 1a23 1a24 0
1a26 ebf 1a79 9d
:3 0 15 :3 0 9b
:3 0 1a28 1a29 0
9c :3 0 1a2a 1a2b
0 1a2d ec2 1a2f
ec4 1a2e 1a2d :2 0
1a77 9e :3 0 15
:3 0 9b :3 0 1a32
1a33 0 9c :3 0
1a34 1a35 0 1a6f
65 :3 0 66 :3 0
1a37 1a38 0 65
:3 0 76 :3 0 1a3a
1a3b 0 9f :2 0
2 :4 0 199 :2 0
78 :2 0 27 :2 0
ec6 1a40 1a42 :3 0
ec9 1a3c 1a44 1a39
1a46 1a45 :2 0 68
:3 0 79 :3 0 1a48
1a49 0 6a :4 0
19a :4 0 6d :2 0
6e :3 0 ecd 1a4d
1a4f :3 0 6d :2 0
82 :4 0 ed0 1a51
1a53 :3 0 6d :2 0
a2 :4 0 ed3 1a55
1a57 :3 0 6d :2 0
9c :3 0 ed6 1a59
1a5b :3 0 6d :2 0
a3 :4 0 ed9 1a5d
1a5f :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
edc 1a62 1a66 ee0
1a61 1a68 :3 0 ee3
1a4a 1a6a :2 0 1a6c
ee6 1a6d 1a47 1a6c
0 1a6e ee8 0
1a6f eea 1a72 :3 0
1a72 0 1a72 1a71
1a6f 1a70 :6 0 1a74
34 :3 0 eed 1a76
eef 1a75 1a74 :2 0
1a77 ef1 :2 0 1a79
0 1a79 1a78 1a26
1a77 :6 0 1a7b 1
:3 0 ef4 1a7d 1642
1838 0 1a7e 0
1a7b 0 1a7e efb
0 1d4d 21 :3 0
21 :3 0 1a7f 1a80
0 1d4d 72 :3 0
46 :3 0 30 :2 0
efe 1a82 1a85 8f
:2 0 27 :2 0 f03
1a87 1a89 :3 0 97
:3 0 19b :3 0 134
:3 0 a4 :3 0 21
:3 0 97 :3 0 19c
:3 0 1f :3 0 21
:3 0 99 :4 0 19d
1 :8 0 1a9b 15
:3 0 9b :3 0 1a96
1a97 0 9c :3 0
1a98 1a99 0 1a9b
f06 1aee 9d :3 0
15 :3 0 9b :3 0
1a9d 1a9e 0 9c
:3 0 1a9f 1aa0 0
1aa2 f09 1aa4 f0b
1aa3 1aa2 :2 0 1aec
9e :3 0 15 :3 0
9b :3 0 1aa7 1aa8
0 9c :3 0 1aa9
1aaa 0 1ae4 65
:3 0 66 :3 0 1aac
1aad 0 65 :3 0
76 :3 0 1aaf 1ab0
0 9f :2 0 2
:4 0 19e :2 0 78
:2 0 27 :2 0 f0d
1ab5 1ab7 :3 0 f10
1ab1 1ab9 1aae 1abb
1aba :2 0 68 :3 0
79 :3 0 1abd 1abe
0 6a :4 0 19f
:4 0 6d :2 0 6e
:3 0 f14 1ac2 1ac4
:3 0 6d :2 0 82
:4 0 f17 1ac6 1ac8
:3 0 6d :2 0 a2
:4 0 f1a 1aca 1acc
:3 0 6d :2 0 9c
:3 0 f1d 1ace 1ad0
:3 0 6d :2 0 a3
:4 0 f20 1ad2 1ad4
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 f23
1ad7 1adb f27 1ad6
1add :3 0 f2a 1abf
1adf :2 0 1ae1 f2d
1ae2 1abc 1ae1 0
1ae3 f2f 0 1ae4
f31 1ae7 :3 0 1ae7
0 1ae7 1ae6 1ae4
1ae5 :6 0 1ae9 36
:3 0 f34 1aeb f36
1aea 1ae9 :2 0 1aec
f38 :2 0 1aee 0
1aee 1aed 1a9b 1aec
:6 0 1c84 1 :3 0
134 :3 0 a4 :3 0
1f :3 0 134 :3 0
a4 :3 0 21 :3 0
1f :3 0 21 :3 0
21 :3 0 99 :4 0
1a0 1 :8 0 1b00
15 :3 0 9b :3 0
1afb 1afc 0 9c
:3 0 1afd 1afe 0
1b00 f3b 1b53 9d
:3 0 15 :3 0 9b
:3 0 1b02 1b03 0
9c :3 0 1b04 1b05
0 1b07 f3e 1b09
f40 1b08 1b07 :2 0
1b51 9e :3 0 15
:3 0 9b :3 0 1b0c
1b0d 0 9c :3 0
1b0e 1b0f 0 1b49
65 :3 0 66 :3 0
1b11 1b12 0 65
:3 0 76 :3 0 1b14
1b15 0 9f :2 0
2 :4 0 1a1 :2 0
78 :2 0 27 :2 0
f42 1b1a 1b1c :3 0
f45 1b16 1b1e 1b13
1b20 1b1f :2 0 68
:3 0 79 :3 0 1b22
1b23 0 6a :4 0
1a2 :4 0 6d :2 0
6e :3 0 f49 1b27
1b29 :3 0 6d :2 0
82 :4 0 f4c 1b2b
1b2d :3 0 6d :2 0
a2 :4 0 f4f 1b2f
1b31 :3 0 6d :2 0
9c :3 0 f52 1b33
1b35 :3 0 6d :2 0
a3 :4 0 f55 1b37
1b39 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
f58 1b3c 1b40 f5c
1b3b 1b42 :3 0 f5f
1b24 1b44 :2 0 1b46
f62 1b47 1b21 1b46
0 1b48 f64 0
1b49 f66 1b4c :3 0
1b4c 0 1b4c 1b4b
1b49 1b4a :6 0 1b4e
38 :3 0 f69 1b50
f6b 1b4f 1b4e :2 0
1b51 f6d :2 0 1b53
0 1b53 1b52 1b00
1b51 :6 0 1c84 1
:3 0 45 :3 0 1a3
:2 0 1b55 1b56 0
1c84 22 :3 0 6
:3 0 1b58 1b59 0
1c84 72 :3 0 33
:3 0 30 :2 0 f70
1b5b 1b5e 8f :2 0
30 :2 0 f75 1b60
1b62 :3 0 3f :3 0
115 :2 0 1b64 1b65
0 1b67 f78 1b68
1b63 1b67 0 1b69
f7a 0 1c84 61
:3 0 1a4 :3 0 28
:3 0 17 :3 0 1a
:3 0 1d :3 0 4e
:3 0 32 :3 0 23
:3 0 23 :3 0 23
:3 0 23 :3 0 21
:3 0 22 :3 0 41
:3 0 37 :3 0 35
:3 0 38 :3 0 39
:3 0 34 :3 0 45
:3 0 26 :3 0 33
:3 0 31 :3 0 3b
:3 0 36 :3 0 3f
:3 0 3d :3 0 43
:3 0 1c :3 0 30
:2 0 30 :2 0 7d
:2 0 7d :2 0 30
:2 0 f7c 1b6b 1b8d
1b6a 1b8e 0 1c84
61 :3 0 8f :2 0
30 :2 0 fa0 1b91
1b93 :3 0 72 :3 0
33 :3 0 30 :2 0
fa3 1b95 1b98 8f
:2 0 30 :2 0 fa8
1b9a 1b9c :3 0 1a5
:3 0 1a6 :3 0 1a7
:3 0 1d :4 0 1a8
1 :8 0 1bb8 1a9
:4 0 1ba3 :3 0 8a
:3 0 8f :2 0 fad
1ba6 1ba7 :3 0 15
:3 0 9b :3 0 1ba9
1baa 0 30 :2 0
1bab 1bac 0 1bae
fb0 1bb5 15 :3 0
9b :3 0 1baf 1bb0
0 113 :2 0 1bb1
1bb2 0 1bb4 fb2
1bb6 1ba8 1bae 0
1bb7 0 1bb4 0
1bb7 fb4 0 1bb8
fb7 1c0b 9d :3 0
15 :3 0 9b :3 0
1bba 1bbb 0 9c
:3 0 1bbc 1bbd 0
1bbf fba 1bc1 fbc
1bc0 1bbf :2 0 1c09
9e :3 0 15 :3 0
9b :3 0 1bc4 1bc5
0 9c :3 0 1bc6
1bc7 0 1c01 65
:3 0 66 :3 0 1bc9
1bca 0 65 :3 0
76 :3 0 1bcc 1bcd
0 9f :2 0 2
:4 0 1aa :2 0 78
:2 0 27 :2 0 fbe
1bd2 1bd4 :3 0 fc1
1bce 1bd6 1bcb 1bd8
1bd7 :2 0 68 :3 0
79 :3 0 1bda 1bdb
0 6a :4 0 1ab
:4 0 6d :2 0 6e
:3 0 fc5 1bdf 1be1
:3 0 6d :2 0 82
:4 0 fc8 1be3 1be5
:3 0 6d :2 0 a2
:4 0 fcb 1be7 1be9
:3 0 6d :2 0 9c
:3 0 fce 1beb 1bed
:3 0 6d :2 0 a3
:4 0 fd1 1bef 1bf1
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 fd4
1bf4 1bf8 fd8 1bf3
1bfa :3 0 fdb 1bdc
1bfc :2 0 1bfe fde
1bff 1bd9 1bfe 0
1c00 fe0 0 1c01
fe2 1c04 :3 0 1c04
0 1c04 1c03 1c01
1c02 :6 0 1c06 3a
:3 0 fe5 1c08 fe7
1c07 1c06 :2 0 1c09
fe9 :2 0 1c0b 0
1c0b 1c0a 1bb8 1c09
:6 0 1c0d 1 :3 0
fec 1c7e 1a5 :3 0
1a6 :3 0 1a7 :3 0
1d :4 0 1ac 1
:8 0 1c28 1a9 :4 0
1c13 :3 0 8a :3 0
8f :2 0 ff0 1c16
1c17 :3 0 15 :3 0
9b :3 0 1c19 1c1a
0 30 :2 0 1c1b
1c1c 0 1c1e ff3
1c25 15 :3 0 9b
:3 0 1c1f 1c20 0
113 :2 0 1c21 1c22
0 1c24 ff5 1c26
1c18 1c1e 0 1c27
0 1c24 0 1c27
ff7 0 1c28 ffa
1c7b 9d :3 0 15
:3 0 9b :3 0 1c2a
1c2b 0 9c :3 0
1c2c 1c2d 0 1c2f
ffd 1c31 fff 1c30
1c2f :2 0 1c79 9e
:3 0 15 :3 0 9b
:3 0 1c34 1c35 0
9c :3 0 1c36 1c37
0 1c71 65 :3 0
66 :3 0 1c39 1c3a
0 65 :3 0 76
:3 0 1c3c 1c3d 0
9f :2 0 2 :4 0
1ad :2 0 78 :2 0
27 :2 0 1001 1c42
1c44 :3 0 1004 1c3e
1c46 1c3b 1c48 1c47
:2 0 68 :3 0 79
:3 0 1c4a 1c4b 0
6a :4 0 1ae :4 0
6d :2 0 6e :3 0
1008 1c4f 1c51 :3 0
6d :2 0 82 :4 0
100b 1c53 1c55 :3 0
6d :2 0 a2 :4 0
100e 1c57 1c59 :3 0
6d :2 0 9c :3 0
1011 1c5b 1c5d :3 0
6d :2 0 a3 :4 0
1014 1c5f 1c61 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 1017 1c64
1c68 101b 1c63 1c6a
:3 0 101e 1c4c 1c6c
:2 0 1c6e 1021 1c6f
1c49 1c6e 0 1c70
1023 0 1c71 1025
1c74 :3 0 1c74 0
1c74 1c73 1c71 1c72
:6 0 1c76 3c :3 0
1028 1c78 102a 1c77
1c76 :2 0 1c79 102c
:2 0 1c7b 0 1c7b
1c7a 1c28 1c79 :6 0
1c7d 1 :3 0 102f
1c7f 1b9d 1c0d 0
1c80 0 1c7d 0
1c80 1031 0 1c81
1034 1c82 1b94 1c81
0 1c83 1036 0
1c84 1038 1d4a 21
:3 0 1f :3 0 1c85
1c86 0 1d49 22
:3 0 6 :3 0 1c88
1c89 0 1d49 a4
:3 0 26 :3 0 27
:2 0 27 :2 0 1040
1c8b 1c8f 8f :2 0
27 :4 0 1046 1c91
1c93 :3 0 45 :3 0
84 :3 0 106 :3 0
1c96 1c97 0 1c95
1c98 0 1c9a 1049
1ca9 45 :3 0 11a
:3 0 72 :3 0 3a
:3 0 30 :2 0 104b
1c9d 1ca0 84 :3 0
11d :3 0 1ca2 1ca3
0 104e 1c9c 1ca5
1c9b 1ca6 0 1ca8
1051 1caa 1c94 1c9a
0 1cab 0 1ca8
0 1cab 1053 0
1d49 61 :3 0 1a4
:3 0 28 :3 0 17
:3 0 1a :3 0 1d
:3 0 4e :3 0 32
:3 0 23 :3 0 23
:3 0 23 :3 0 23
:3 0 21 :3 0 22
:3 0 41 :3 0 37
:3 0 35 :3 0 38
:3 0 39 :3 0 34
:3 0 45 :3 0 26
:3 0 33 :3 0 31
:3 0 3b :3 0 36
:3 0 3f :3 0 3d
:3 0 43 :3 0 1c
:3 0 30 :2 0 30
:2 0 7d :2 0 7d
:2 0 30 :2 0 1056
1cad 1ccf 1cac 1cd0
0 1d49 61 :3 0
8f :2 0 30 :2 0
107a 1cd3 1cd5 :3 0
1a5 :3 0 1a6 :3 0
1a7 :3 0 1d :4 0
1a8 1 :8 0 1cf1
1a9 :4 0 1cdc :3 0
8a :3 0 8f :2 0
107f 1cdf 1ce0 :3 0
15 :3 0 9b :3 0
1ce2 1ce3 0 30
:2 0 1ce4 1ce5 0
1ce7 1082 1cee 15
:3 0 9b :3 0 1ce8
1ce9 0 113 :2 0
1cea 1ceb 0 1ced
1084 1cef 1ce1 1ce7
0 1cf0 0 1ced
0 1cf0 1086 0
1cf1 1089 1d44 9d
:3 0 15 :3 0 9b
:3 0 1cf3 1cf4 0
9c :3 0 1cf5 1cf6
0 1cf8 108c 1cfa
108e 1cf9 1cf8 :2 0
1d42 9e :3 0 15
:3 0 9b :3 0 1cfd
1cfe 0 9c :3 0
1cff 1d00 0 1d3a
65 :3 0 66 :3 0
1d02 1d03 0 65
:3 0 76 :3 0 1d05
1d06 0 9f :2 0
2 :4 0 1af :2 0
78 :2 0 27 :2 0
1090 1d0b 1d0d :3 0
1093 1d07 1d0f 1d04
1d11 1d10 :2 0 68
:3 0 79 :3 0 1d13
1d14 0 6a :4 0
1b0 :4 0 6d :2 0
6e :3 0 1097 1d18
1d1a :3 0 6d :2 0
82 :4 0 109a 1d1c
1d1e :3 0 6d :2 0
a2 :4 0 109d 1d20
1d22 :3 0 6d :2 0
9c :3 0 10a0 1d24
1d26 :3 0 6d :2 0
a3 :4 0 10a3 1d28
1d2a :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
10a6 1d2d 1d31 10aa
1d2c 1d33 :3 0 10ad
1d15 1d35 :2 0 1d37
10b0 1d38 1d12 1d37
0 1d39 10b2 0
1d3a 10b4 1d3d :3 0
1d3d 0 1d3d 1d3c
1d3a 1d3b :6 0 1d3f
3e :3 0 10b7 1d41
10b9 1d40 1d3f :2 0
1d42 10bb :2 0 1d44
0 1d44 1d43 1cf1
1d42 :6 0 1d46 1
:3 0 10be 1d47 1cd6
1d46 0 1d48 10c0
0 1d49 10c2 1d4b
1a8a 1c84 0 1d4c
0 1d49 0 1d4c
10c8 0 1d4d 10cb
2741 72 :3 0 1b1
:3 0 29 :3 0 10d9
1d4f 1d51 30 :2 0
10db 1d4e 1d54 a8
:2 0 18 :2 0 10e0
1d56 1d58 :3 0 63
:3 0 30 :2 0 1d5a
1d5b 0 1d5d 10e3
1d75 63 :3 0 1b2
:3 0 72 :3 0 1b1
:3 0 29 :3 0 10e5
1d61 1d63 30 :2 0
10e7 1d60 1d66 78
:2 0 27 :2 0 10ea
1d68 1d6a :3 0 1d6b
:2 0 1b3 :2 0 b5
:2 0 10ed 1d6d 1d6f
:3 0 10f0 1d5f 1d71
1d5e 1d72 0 1d74
10f2 1d76 1d59 1d5d
0 1d77 0 1d74
0 1d77 10f4 0
2740 63 :3 0 b2
:2 0 30 :2 0 10f9
1d79 1d7b :3 0 2f
:3 0 30 :2 0 1d7d
1d7e 0 273d 1b4
:3 0 72 :3 0 2f
:3 0 30 :2 0 10fc
1d81 1d84 63 :3 0
a8 :2 0 1b5 :3 0
1101 1d87 1d89 :3 0
1d8a 273c 46 :3 0
30 :2 0 1d8c 1d8d
0 273a 1d :3 0
b3 :3 0 b4 :3 0
1d90 1d91 0 18
:2 0 18 :2 0 72
:3 0 2f :3 0 30
:2 0 1104 1d95 1d98
112 :2 0 b5 :2 0
1107 1d9a 1d9c :3 0
78 :2 0 27 :2 0
110a 1d9e 1da0 :3 0
29 :3 0 110d 1d92
1da3 1d8f 1da4 0
273a 26 :3 0 b3
:3 0 b4 :3 0 1da7
1da8 0 27 :2 0
27 :2 0 72 :3 0
2f :3 0 30 :2 0
1112 1dac 1daf 112
:2 0 b5 :2 0 1115
1db1 1db3 :3 0 78
:2 0 18 :2 0 1118
1db5 1db7 :3 0 78
:2 0 27 :2 0 111b
1db9 1dbb :3 0 29
:3 0 111e 1da9 1dbe
1da6 1dbf 0 273a
1f :3 0 5 :3 0
1dc1 1dc2 0 273a
46 :3 0 30 :2 0
1dc4 1dc5 0 273a
44 :3 0 30 :2 0
1dc7 1dc8 0 273a
21 :3 0 1f :3 0
1dca 1dcb 0 273a
1b6 :3 0 129 :3 0
1b7 :3 0 44 :3 0
21 :3 0 12b :3 0
b8 :3 0 17 :3 0
12c :3 0 17 :3 0
12d :3 0 1d :3 0
12e :3 0 26 :4 0
1b8 1 :8 0 1de1
15 :3 0 9b :3 0
1ddc 1ddd 0 9c
:3 0 1dde 1ddf 0
1de1 1123 1e34 9d
:3 0 15 :3 0 9b
:3 0 1de3 1de4 0
9c :3 0 1de5 1de6
0 1de8 1126 1dea
1128 1de9 1de8 :2 0
1e32 9e :3 0 15
:3 0 9b :3 0 1ded
1dee 0 9c :3 0
1def 1df0 0 1e2a
65 :3 0 66 :3 0
1df2 1df3 0 65
:3 0 76 :3 0 1df5
1df6 0 9f :2 0
2 :4 0 1b9 :2 0
78 :2 0 27 :2 0
112a 1dfb 1dfd :3 0
112d 1df7 1dff 1df4
1e01 1e00 :2 0 68
:3 0 79 :3 0 1e03
1e04 0 6a :4 0
1ba :4 0 6d :2 0
6e :3 0 1131 1e08
1e0a :3 0 6d :2 0
82 :4 0 1134 1e0c
1e0e :3 0 6d :2 0
a2 :4 0 1137 1e10
1e12 :3 0 6d :2 0
9c :3 0 113a 1e14
1e16 :3 0 6d :2 0
a3 :4 0 113d 1e18
1e1a :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1140 1e1d 1e21 1144
1e1c 1e23 :3 0 1147
1e05 1e25 :2 0 1e27
114a 1e28 1e02 1e27
0 1e29 114c 0
1e2a 114e 1e2d :3 0
1e2d 0 1e2d 1e2c
1e2a 1e2b :6 0 1e2f
41 :3 0 1151 1e31
1153 1e30 1e2f :2 0
1e32 1155 :2 0 1e34
0 1e34 1e33 1de1
1e32 :6 0 273a 40
:3 0 72 :3 0 44
:3 0 30 :2 0 1158
1e36 1e39 b2 :2 0
30 :2 0 115d 1e3b
1e3d :3 0 1e3e :2 0
21 :3 0 96 :2 0
1160 1e41 1e42 :3 0
1e43 :2 0 1e44 :2 0
1e3f 1e46 1e45 :2 0
46 :3 0 27 :2 0
1e48 1e49 0 1e5c
97 :3 0 f2 :3 0
1e4b 1e4c 0 1f
:3 0 21 :3 0 1162
1e4d 1e50 a8 :2 0
30 :2 0 1167 1e52
1e54 :3 0 1f :3 0
21 :3 0 1e56 1e57
0 1e59 116a 1e5a
1e55 1e59 0 1e5b
116c 0 1e5c 116e
1e5d 1e47 1e5c 0
1e5e 1171 0 273a
a4 :3 0 26 :3 0
27 :2 0 27 :2 0
1173 1e5f 1e63 8f
:2 0 27 :4 0 1179
1e65 1e67 :3 0 3a
:3 0 84 :3 0 106
:3 0 1e6a 1e6b 0
1e69 1e6c 0 1e9a
72 :3 0 1b1 :3 0
2c :3 0 117c 1e6f
1e71 30 :2 0 117e
1e6e 1e74 8f :2 0
30 :2 0 1183 1e76
1e78 :3 0 2c :3 0
1d :3 0 1e7a 1e7b
0 1e7d 1186 1e97
2c :3 0 a4 :3 0
2c :3 0 6d :2 0
1bb :4 0 1188 1e81
1e83 :3 0 27 :2 0
2a :2 0 118b 1e7f
1e87 1e7e 1e88 0
1e96 2c :3 0 a4
:3 0 2c :3 0 6d
:2 0 1d :3 0 118f
1e8d 1e8f :3 0 27
:2 0 2a :2 0 1192
1e8b 1e93 1e8a 1e94
0 1e96 1196 1e98
1e79 1e7d 0 1e99
0 1e96 0 1e99
1199 0 1e9a 119c
1ec8 72 :3 0 1b1
:3 0 2b :3 0 119f
1e9c 1e9e 30 :2 0
11a1 1e9b 1ea1 8f
:2 0 30 :2 0 11a6
1ea3 1ea5 :3 0 2b
:3 0 1d :3 0 1ea7
1ea8 0 1eaa 11a9
1ec4 2b :3 0 a4
:3 0 2b :3 0 6d
:2 0 1bb :4 0 11ab
1eae 1eb0 :3 0 27
:2 0 2a :2 0 11ae
1eac 1eb4 1eab 1eb5
0 1ec3 2b :3 0
a4 :3 0 2b :3 0
6d :2 0 1d :3 0
11b2 1eba 1ebc :3 0
27 :2 0 2a :2 0
11b5 1eb8 1ec0 1eb7
1ec1 0 1ec3 11b9
1ec5 1ea6 1eaa 0
1ec6 0 1ec3 0
1ec6 11bc 0 1ec7
11bf 1ec9 1e68 1e9a
0 1eca 0 1ec7
0 1eca 11c1 0
273a 33 :3 0 30
:2 0 1ecb 1ecc 0
273a 44 :3 0 30
:2 0 1ece 1ecf 0
273a 72 :3 0 46
:3 0 30 :2 0 11c4
1ed1 1ed4 8f :2 0
27 :2 0 11c9 1ed6
1ed8 :3 0 62 :3 0
8f :2 0 27 :2 0
11ce 1edb 1edd :3 0
a4 :3 0 26 :3 0
27 :2 0 27 :2 0
11d1 1edf 1ee3 8f
:2 0 30 :4 0 11d7
1ee5 1ee7 :3 0 132
:3 0 133 :3 0 134
:3 0 a4 :3 0 1f
:3 0 134 :3 0 a4
:3 0 133 :3 0 134
:3 0 a4 :3 0 22
:3 0 134 :3 0 a4
:3 0 135 :3 0 136
:3 0 37 :3 0 136
:3 0 19 :3 0 21
:3 0 44 :3 0 47
:3 0 12b :3 0 12c
:3 0 17 :3 0 12d
:3 0 1d :3 0 12e
:3 0 137 :4 0 1bc
1 :8 0 1f0b 15
:3 0 9b :3 0 1f06
1f07 0 9c :3 0
1f08 1f09 0 1f0b
11da 1f5e 9d :3 0
15 :3 0 9b :3 0
1f0d 1f0e 0 9c
:3 0 1f0f 1f10 0
1f12 11dd 1f14 11df
1f13 1f12 :2 0 1f5c
9e :3 0 15 :3 0
9b :3 0 1f17 1f18
0 9c :3 0 1f19
1f1a 0 1f54 65
:3 0 66 :3 0 1f1c
1f1d 0 65 :3 0
76 :3 0 1f1f 1f20
0 9f :2 0 2
:4 0 1bd :2 0 78
:2 0 27 :2 0 11e1
1f25 1f27 :3 0 11e4
1f21 1f29 1f1e 1f2b
1f2a :2 0 68 :3 0
79 :3 0 1f2d 1f2e
0 6a :4 0 1be
:4 0 6d :2 0 6e
:3 0 11e8 1f32 1f34
:3 0 6d :2 0 82
:4 0 11eb 1f36 1f38
:3 0 6d :2 0 a2
:4 0 11ee 1f3a 1f3c
:3 0 6d :2 0 9c
:3 0 11f1 1f3e 1f40
:3 0 6d :2 0 a3
:4 0 11f4 1f42 1f44
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 11f7
1f47 1f4b 11fb 1f46
1f4d :3 0 11fe 1f2f
1f4f :2 0 1f51 1201
1f52 1f2c 1f51 0
1f53 1203 0 1f54
1205 1f57 :3 0 1f57
0 1f57 1f56 1f54
1f55 :6 0 1f59 43
:3 0 1208 1f5b 120a
1f5a 1f59 :2 0 1f5c
120c :2 0 1f5e 0
1f5e 1f5d 1f0b 1f5c
:6 0 2091 40 :3 0
15 :3 0 9b :3 0
1f60 1f61 0 15
:3 0 8f :2 0 a7
:3 0 1f63 1f65 0
1211 1f64 1f67 :3 0
1f68 :2 0 46 :3 0
27 :2 0 1f6a 1f6b
0 2001 72 :3 0
47 :3 0 30 :2 0
1214 1f6d 1f70 8f
:2 0 30 :2 0 1219
1f72 1f74 :3 0 1f75
:2 0 72 :3 0 44
:3 0 30 :2 0 121c
1f77 1f7a 8f :2 0
27 :2 0 1221 1f7c
1f7e :3 0 1f7f :2 0
1f76 1f81 1f80 :2 0
132 :3 0 13b :3 0
134 :3 0 a4 :3 0
1f :3 0 134 :3 0
a4 :3 0 13b :3 0
134 :3 0 a4 :3 0
22 :3 0 134 :3 0
a4 :3 0 13c :3 0
13d :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 12b :3 0
12c :3 0 17 :3 0
12d :3 0 1d :3 0
12e :3 0 137 :4 0
1bf 1 :8 0 1fa3
15 :3 0 9b :3 0
1f9e 1f9f 0 9c
:3 0 1fa0 1fa1 0
1fa3 1224 1ff6 9d
:3 0 15 :3 0 9b
:3 0 1fa5 1fa6 0
9c :3 0 1fa7 1fa8
0 1faa 1227 1fac
1229 1fab 1faa :2 0
1ff4 9e :3 0 15
:3 0 9b :3 0 1faf
1fb0 0 9c :3 0
1fb1 1fb2 0 1fec
65 :3 0 66 :3 0
1fb4 1fb5 0 65
:3 0 76 :3 0 1fb7
1fb8 0 9f :2 0
2 :4 0 1c0 :2 0
78 :2 0 27 :2 0
122b 1fbd 1fbf :3 0
122e 1fb9 1fc1 1fb6
1fc3 1fc2 :2 0 68
:3 0 79 :3 0 1fc5
1fc6 0 6a :4 0
1c1 :4 0 6d :2 0
6e :3 0 1232 1fca
1fcc :3 0 6d :2 0
82 :4 0 1235 1fce
1fd0 :3 0 6d :2 0
a2 :4 0 1238 1fd2
1fd4 :3 0 6d :2 0
9c :3 0 123b 1fd6
1fd8 :3 0 6d :2 0
a3 :4 0 123e 1fda
1fdc :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1241 1fdf 1fe3 1245
1fde 1fe5 :3 0 1248
1fc7 1fe7 :2 0 1fe9
124b 1fea 1fc4 1fe9
0 1feb 124d 0
1fec 124f 1fef :3 0
1fef 0 1fef 1fee
1fec 1fed :6 0 1ff1
45 :3 0 1252 1ff3
1254 1ff2 1ff1 :2 0
1ff4 1256 :2 0 1ff6
0 1ff6 1ff5 1fa3
1ff4 :6 0 1ff8 40
:3 0 1259 1ffd 33
:3 0 114 :2 0 1ff9
1ffa 0 1ffc 125b
1ffe 1f82 1ff8 0
1fff 0 1ffc 0
1fff 125d 0 2001
ae :3 0 1260 208f
15 :3 0 9b :3 0
2002 2003 0 15
:3 0 8f :2 0 d9
:3 0 2005 2007 0
1265 2006 2009 :3 0
200a :2 0 72 :3 0
44 :3 0 30 :2 0
1268 200c 200f 8f
:2 0 27 :2 0 126d
2011 2013 :3 0 2014
:2 0 200b 2016 2015
:2 0 132 :3 0 13b
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 13b
:3 0 134 :3 0 a4
:3 0 22 :3 0 134
:3 0 a4 :3 0 13c
:3 0 13d :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 12b
:3 0 12c :3 0 17
:3 0 12d :3 0 1d
:3 0 12e :3 0 137
:4 0 1c2 1 :8 0
2038 15 :3 0 9b
:3 0 2033 2034 0
9c :3 0 2035 2036
0 2038 1270 208b
9d :3 0 15 :3 0
9b :3 0 203a 203b
0 9c :3 0 203c
203d 0 203f 1273
2041 1275 2040 203f
:2 0 2089 9e :3 0
15 :3 0 9b :3 0
2044 2045 0 9c
:3 0 2046 2047 0
2081 65 :3 0 66
:3 0 2049 204a 0
65 :3 0 76 :3 0
204c 204d 0 9f
:2 0 2 :4 0 1c3
:2 0 78 :2 0 27
:2 0 1277 2052 2054
:3 0 127a 204e 2056
204b 2058 2057 :2 0
68 :3 0 79 :3 0
205a 205b 0 6a
:4 0 1c4 :4 0 6d
:2 0 6e :3 0 127e
205f 2061 :3 0 6d
:2 0 82 :4 0 1281
2063 2065 :3 0 6d
:2 0 a2 :4 0 1284
2067 2069 :3 0 6d
:2 0 9c :3 0 1287
206b 206d :3 0 6d
:2 0 a3 :4 0 128a
206f 2071 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 128d 2074 2078
1291 2073 207a :3 0
1294 205c 207c :2 0
207e 1297 207f 2059
207e 0 2080 1299
0 2081 129b 2084
:3 0 2084 0 2084
2083 2081 2082 :6 0
2086 47 :3 0 129e
2088 12a0 2087 2086
:2 0 2089 12a2 :2 0
208b 0 208b 208a
2038 2089 :6 0 208d
40 :3 0 12a5 208e
2017 208d 0 2090
1f69 2001 0 2090
12a7 0 2091 12aa
210a 132 :3 0 13b
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 13b
:3 0 134 :3 0 a4
:3 0 22 :3 0 134
:3 0 a4 :3 0 13c
:3 0 13d :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 12b
:3 0 b8 :3 0 17
:3 0 12c :3 0 17
:3 0 12d :3 0 1d
:3 0 12e :3 0 137
:4 0 1c5 1 :8 0
20b4 15 :3 0 9b
:3 0 20af 20b0 0
9c :3 0 20b1 20b2
0 20b4 12ad 2107
9d :3 0 15 :3 0
9b :3 0 20b6 20b7
0 9c :3 0 20b8
20b9 0 20bb 12b0
20bd 12b2 20bc 20bb
:2 0 2105 9e :3 0
15 :3 0 9b :3 0
20c0 20c1 0 9c
:3 0 20c2 20c3 0
20fd 65 :3 0 66
:3 0 20c5 20c6 0
65 :3 0 76 :3 0
20c8 20c9 0 9f
:2 0 2 :4 0 1c6
:2 0 78 :2 0 27
:2 0 12b4 20ce 20d0
:3 0 12b7 20ca 20d2
20c7 20d4 20d3 :2 0
68 :3 0 79 :3 0
20d6 20d7 0 6a
:4 0 1c7 :4 0 6d
:2 0 6e :3 0 12bb
20db 20dd :3 0 6d
:2 0 82 :4 0 12be
20df 20e1 :3 0 6d
:2 0 a2 :4 0 12c1
20e3 20e5 :3 0 6d
:2 0 9c :3 0 12c4
20e7 20e9 :3 0 6d
:2 0 a3 :4 0 12c7
20eb 20ed :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 12ca 20f0 20f4
12ce 20ef 20f6 :3 0
12d1 20d8 20f8 :2 0
20fa 12d4 20fb 20d5
20fa 0 20fc 12d6
0 20fd 12d8 2100
:3 0 2100 0 2100
20ff 20fd 20fe :6 0
2102 49 :3 0 12db
2104 12dd 2103 2102
:2 0 2105 12df :2 0
2107 0 2107 2106
20b4 2105 :6 0 2109
40 :3 0 12e2 210b
1ee8 2091 0 210c
0 2109 0 210c
12e4 0 210d 12e7
2326 a4 :3 0 26
:3 0 27 :2 0 27
:2 0 12e9 210e 2112
8f :2 0 30 :4 0
12ef 2114 2116 :3 0
132 :3 0 133 :3 0
134 :3 0 a4 :3 0
1f :3 0 134 :3 0
a4 :3 0 133 :3 0
134 :3 0 a4 :3 0
135 :3 0 37 :3 0
136 :3 0 136 :3 0
19 :3 0 21 :3 0
44 :3 0 47 :3 0
12b :3 0 b8 :3 0
17 :3 0 12c :3 0
17 :3 0 12d :3 0
1d :3 0 12e :3 0
137 :4 0 1c8 1
:8 0 2139 15 :3 0
9b :3 0 2134 2135
0 9c :3 0 2136
2137 0 2139 12f2
218c 9d :3 0 15
:3 0 9b :3 0 213b
213c 0 9c :3 0
213d 213e 0 2140
12f5 2142 12f7 2141
2140 :2 0 218a 9e
:3 0 15 :3 0 9b
:3 0 2145 2146 0
9c :3 0 2147 2148
0 2182 65 :3 0
66 :3 0 214a 214b
0 65 :3 0 76
:3 0 214d 214e 0
9f :2 0 2 :4 0
1c9 :2 0 78 :2 0
27 :2 0 12f9 2153
2155 :3 0 12fc 214f
2157 214c 2159 2158
:2 0 68 :3 0 79
:3 0 215b 215c 0
6a :4 0 1ca :4 0
6d :2 0 6e :3 0
1300 2160 2162 :3 0
6d :2 0 82 :4 0
1303 2164 2166 :3 0
6d :2 0 a2 :4 0
1306 2168 216a :3 0
6d :2 0 9c :3 0
1309 216c 216e :3 0
6d :2 0 a3 :4 0
130c 2170 2172 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 130f 2175
2179 1313 2174 217b
:3 0 1316 215d 217d
:2 0 217f 1319 2180
215a 217f 0 2181
131b 0 2182 131d
2185 :3 0 2185 0
2185 2184 2182 2183
:6 0 2187 4b :3 0
1320 2189 1322 2188
2187 :2 0 218a 1324
:2 0 218c 0 218c
218b 2139 218a :6 0
22ac 40 :3 0 15
:3 0 9b :3 0 218e
218f 0 15 :3 0
8f :2 0 a7 :3 0
2191 2193 0 1329
2192 2195 :3 0 2196
:2 0 72 :3 0 47
:3 0 30 :2 0 132c
2198 219b 8f :2 0
30 :2 0 1331 219d
219f :3 0 21a0 :2 0
72 :3 0 44 :3 0
30 :2 0 1334 21a2
21a5 8f :2 0 27
:2 0 1339 21a7 21a9
:3 0 21aa :2 0 21a1
21ac 21ab :2 0 132
:3 0 13b :3 0 134
:3 0 a4 :3 0 1f
:3 0 134 :3 0 a4
:3 0 13c :3 0 37
:3 0 13d :3 0 19
:3 0 21 :3 0 44
:3 0 12b :3 0 b8
:3 0 17 :3 0 12c
:3 0 17 :3 0 12d
:3 0 1d :3 0 12e
:3 0 137 :4 0 1cb
1 :8 0 21ca 15
:3 0 9b :3 0 21c5
21c6 0 9c :3 0
21c7 21c8 0 21ca
133c 221d 9d :3 0
15 :3 0 9b :3 0
21cc 21cd 0 9c
:3 0 21ce 21cf 0
21d1 133f 21d3 1341
21d2 21d1 :2 0 221b
9e :3 0 15 :3 0
9b :3 0 21d6 21d7
0 9c :3 0 21d8
21d9 0 2213 65
:3 0 66 :3 0 21db
21dc 0 65 :3 0
76 :3 0 21de 21df
0 9f :2 0 2
:4 0 1cc :2 0 78
:2 0 27 :2 0 1343
21e4 21e6 :3 0 1346
21e0 21e8 21dd 21ea
21e9 :2 0 68 :3 0
79 :3 0 21ec 21ed
0 6a :4 0 1cd
:4 0 6d :2 0 6e
:3 0 134a 21f1 21f3
:3 0 6d :2 0 82
:4 0 134d 21f5 21f7
:3 0 6d :2 0 a2
:4 0 1350 21f9 21fb
:3 0 6d :2 0 9c
:3 0 1353 21fd 21ff
:3 0 6d :2 0 a3
:4 0 1356 2201 2203
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 1359
2206 220a 135d 2205
220c :3 0 1360 21ee
220e :2 0 2210 1363
2211 21eb 2210 0
2212 1365 0 2213
1367 2216 :3 0 2216
0 2216 2215 2213
2214 :6 0 2218 4d
:3 0 136a 221a 136c
2219 2218 :2 0 221b
136e :2 0 221d 0
221d 221c 21ca 221b
:6 0 221f 40 :3 0
1371 2225 33 :3 0
114 :2 0 2220 2221
0 2224 0 2224
1373 2226 21ad 221f
0 2227 0 2224
0 2227 1376 0
2229 ae :3 0 1379
22aa 15 :3 0 9b
:3 0 222a 222b 0
15 :3 0 8f :2 0
d9 :3 0 222d 222f
0 137d 222e 2231
:3 0 2232 :2 0 132
:3 0 13b :3 0 134
:3 0 a4 :3 0 1f
:3 0 134 :3 0 a4
:3 0 13b :3 0 134
:3 0 a4 :3 0 13c
:3 0 37 :3 0 13d
:3 0 19 :3 0 21
:3 0 44 :3 0 12b
:3 0 b8 :3 0 17
:3 0 12c :3 0 17
:3 0 12d :3 0 1d
:3 0 12e :3 0 137
:4 0 1ce 1 :8 0
2253 15 :3 0 9b
:3 0 224e 224f 0
9c :3 0 2250 2251
0 2253 1380 22a6
9d :3 0 15 :3 0
9b :3 0 2255 2256
0 9c :3 0 2257
2258 0 225a 1383
225c 1385 225b 225a
:2 0 22a4 9e :3 0
15 :3 0 9b :3 0
225f 2260 0 9c
:3 0 2261 2262 0
229c 65 :3 0 66
:3 0 2264 2265 0
65 :3 0 76 :3 0
2267 2268 0 9f
:2 0 2 :4 0 1cf
:2 0 78 :2 0 27
:2 0 1387 226d 226f
:3 0 138a 2269 2271
2266 2273 2272 :2 0
68 :3 0 79 :3 0
2275 2276 0 6a
:4 0 1d0 :4 0 6d
:2 0 6e :3 0 138e
227a 227c :3 0 6d
:2 0 82 :4 0 1391
227e 2280 :3 0 6d
:2 0 a2 :4 0 1394
2282 2284 :3 0 6d
:2 0 9c :3 0 1397
2286 2288 :3 0 6d
:2 0 a3 :4 0 139a
228a 228c :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 139d 228f 2293
13a1 228e 2295 :3 0
13a4 2277 2297 :2 0
2299 13a7 229a 2274
2299 0 229b 13a9
0 229c 13ab 229f
:3 0 229f 0 229f
229e 229c 229d :6 0
22a1 4f :3 0 13ae
22a3 13b0 22a2 22a1
:2 0 22a4 13b2 :2 0
22a6 0 22a6 22a5
2253 22a4 :6 0 22a8
40 :3 0 13b5 22a9
2233 22a8 0 22ab
2197 2229 0 22ab
13b7 0 22ac 13ba
2322 132 :3 0 13b
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 13b
:3 0 134 :3 0 a4
:3 0 13c :3 0 37
:3 0 13d :3 0 19
:3 0 21 :3 0 44
:3 0 12b :3 0 b8
:3 0 17 :3 0 12c
:3 0 17 :3 0 12d
:3 0 1d :3 0 12e
:3 0 137 :4 0 1d1
1 :8 0 22cc 15
:3 0 9b :3 0 22c7
22c8 0 9c :3 0
22c9 22ca 0 22cc
13bd 231f 9d :3 0
15 :3 0 9b :3 0
22ce 22cf 0 9c
:3 0 22d0 22d1 0
22d3 13c0 22d5 13c2
22d4 22d3 :2 0 231d
9e :3 0 15 :3 0
9b :3 0 22d8 22d9
0 9c :3 0 22da
22db 0 2315 65
:3 0 66 :3 0 22dd
22de 0 65 :3 0
76 :3 0 22e0 22e1
0 9f :2 0 2
:4 0 1d2 :2 0 78
:2 0 27 :2 0 13c4
22e6 22e8 :3 0 13c7
22e2 22ea 22df 22ec
22eb :2 0 68 :3 0
79 :3 0 22ee 22ef
0 6a :4 0 1d3
:4 0 6d :2 0 6e
:3 0 13cb 22f3 22f5
:3 0 6d :2 0 82
:4 0 13ce 22f7 22f9
:3 0 6d :2 0 a2
:4 0 13d1 22fb 22fd
:3 0 6d :2 0 9c
:3 0 13d4 22ff 2301
:3 0 6d :2 0 a3
:4 0 13d7 2303 2305
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 13da
2308 230c 13de 2307
230e :3 0 13e1 22f0
2310 :2 0 2312 13e4
2313 22ed 2312 0
2314 13e6 0 2315
13e8 2318 :3 0 2318
0 2318 2317 2315
2316 :6 0 231a 51
:3 0 13eb 231c 13ed
231b 231a :2 0 231d
13ef :2 0 231f 0
231f 231e 22cc 231d
:6 0 2321 40 :3 0
13f2 2323 2117 22ac
0 2324 0 2321
0 2324 13f4 0
2325 13f7 2327 1ede
210d 0 2328 0
2325 0 2328 13f9
0 265f 15 :3 0
9b :3 0 2329 232a
0 15 :3 0 8f
:2 0 a7 :3 0 232c
232e 0 13fe 232d
2330 :3 0 2331 :2 0
72 :3 0 44 :3 0
30 :2 0 1401 2333
2336 8f :2 0 27
:2 0 1406 2338 233a
:3 0 46 :3 0 114
:2 0 233c 233d 0
233f 1409 244a 19
:3 0 96 :2 0 140b
2341 2342 :3 0 2343
:2 0 62 :3 0 8f
:2 0 27 :2 0 140f
2346 2348 :3 0 47
:3 0 30 :2 0 234a
234b 0 23b7 158
:3 0 159 :3 0 47
:3 0 15a :3 0 b8
:3 0 17 :3 0 15b
:3 0 19 :3 0 15c
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 22
:4 0 1d4 1 :8 0
2362 15 :3 0 9b
:3 0 235d 235e 0
9c :3 0 235f 2360
0 2362 1412 23b5
9d :3 0 15 :3 0
9b :3 0 2364 2365
0 9c :3 0 2366
2367 0 2369 1415
236b 1417 236a 2369
:2 0 23b3 9e :3 0
15 :3 0 9b :3 0
236e 236f 0 9c
:3 0 2370 2371 0
23ab 65 :3 0 66
:3 0 2373 2374 0
65 :3 0 76 :3 0
2376 2377 0 9f
:2 0 2 :4 0 1d5
:2 0 78 :2 0 27
:2 0 1419 237c 237e
:3 0 141c 2378 2380
2375 2382 2381 :2 0
68 :3 0 79 :3 0
2384 2385 0 6a
:4 0 1d6 :4 0 6d
:2 0 6e :3 0 1420
2389 238b :3 0 6d
:2 0 82 :4 0 1423
238d 238f :3 0 6d
:2 0 a2 :4 0 1426
2391 2393 :3 0 6d
:2 0 9c :3 0 1429
2395 2397 :3 0 6d
:2 0 a3 :4 0 142c
2399 239b :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 142f 239e 23a2
1433 239d 23a4 :3 0
1436 2386 23a6 :2 0
23a8 1439 23a9 2383
23a8 0 23aa 143b
0 23ab 143d 23ae
:3 0 23ae 0 23ae
23ad 23ab 23ac :6 0
23b0 53 :3 0 1440
23b2 1442 23b1 23b0
:2 0 23b3 1444 :2 0
23b5 0 23b5 23b4
2362 23b3 :6 0 23b7
40 :3 0 1447 2423
47 :3 0 30 :2 0
23b8 23b9 0 2422
158 :3 0 159 :3 0
47 :3 0 15a :3 0
b8 :3 0 17 :3 0
15b :3 0 19 :3 0
15c :3 0 134 :3 0
a4 :3 0 1f :4 0
1d7 1 :8 0 23cd
15 :3 0 9b :3 0
23c8 23c9 0 9c
:3 0 23ca 23cb 0
23cd 144a 2420 9d
:3 0 15 :3 0 9b
:3 0 23cf 23d0 0
9c :3 0 23d1 23d2
0 23d4 144d 23d6
144f 23d5 23d4 :2 0
241e 9e :3 0 15
:3 0 9b :3 0 23d9
23da 0 9c :3 0
23db 23dc 0 2416
65 :3 0 66 :3 0
23de 23df 0 65
:3 0 76 :3 0 23e1
23e2 0 9f :2 0
2 :4 0 1d8 :2 0
78 :2 0 27 :2 0
1451 23e7 23e9 :3 0
1454 23e3 23eb 23e0
23ed 23ec :2 0 68
:3 0 79 :3 0 23ef
23f0 0 6a :4 0
1d9 :4 0 6d :2 0
6e :3 0 1458 23f4
23f6 :3 0 6d :2 0
82 :4 0 145b 23f8
23fa :3 0 6d :2 0
a2 :4 0 145e 23fc
23fe :3 0 6d :2 0
9c :3 0 1461 2400
2402 :3 0 6d :2 0
a3 :4 0 1464 2404
2406 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1467 2409 240d 146b
2408 240f :3 0 146e
23f1 2411 :2 0 2413
1471 2414 23ee 2413
0 2415 1473 0
2416 1475 2419 :3 0
2419 0 2419 2418
2416 2417 :6 0 241b
55 :3 0 1478 241d
147a 241c 241b :2 0
241e 147c :2 0 2420
0 2420 241f 23cd
241e :6 0 2422 40
:3 0 147f 2424 2349
23b7 0 2425 0
2422 0 2425 1482
0 2443 72 :3 0
47 :3 0 30 :2 0
1485 2426 2429 72
:3 0 a8 :2 0 37
:3 0 30 :2 0 1488
242b 242f 148d 242c
2431 :3 0 2f :3 0
72 :3 0 2f :3 0
30 :2 0 1490 2434
2437 78 :2 0 27
:2 0 1493 2439 243b
:3 0 2433 243c 0
2440 1da :3 0 243e
:4 0 2440 1496 2441
2432 2440 0 2442
1499 0 2443 149b
2444 2344 2443 0
2445 149e 0 2449
46 :3 0 27 :2 0
2446 2447 0 2449
14a0 244b 233b 233f
0 244c 0 2449
0 244c 14a3 0
244d 14a6 245c 2f
:3 0 72 :3 0 2f
:3 0 30 :2 0 14a8
244f 2452 78 :2 0
27 :2 0 14ab 2454
2456 :3 0 244e 2457
0 245b 1da :3 0
2459 :4 0 245b 14ae
245d 2332 244d 0
245e 0 245b 0
245e 14b1 0 265f
21 :3 0 21 :3 0
245f 2460 0 265f
3f :3 0 30 :2 0
2462 2463 0 265f
97 :3 0 19b :3 0
134 :3 0 a4 :3 0
21 :3 0 97 :3 0
19c :3 0 1f :3 0
21 :3 0 99 :4 0
1db 1 :8 0 2475
15 :3 0 9b :3 0
2470 2471 0 9c
:3 0 2472 2473 0
2475 14b4 24c8 9d
:3 0 15 :3 0 9b
:3 0 2477 2478 0
9c :3 0 2479 247a
0 247c 14b7 247e
14b9 247d 247c :2 0
24c6 9e :3 0 15
:3 0 9b :3 0 2481
2482 0 9c :3 0
2483 2484 0 24be
65 :3 0 66 :3 0
2486 2487 0 65
:3 0 76 :3 0 2489
248a 0 9f :2 0
2 :4 0 1dc :2 0
78 :2 0 27 :2 0
14bb 248f 2491 :3 0
14be 248b 2493 2488
2495 2494 :2 0 68
:3 0 79 :3 0 2497
2498 0 6a :4 0
1dd :4 0 6d :2 0
6e :3 0 14c2 249c
249e :3 0 6d :2 0
82 :4 0 14c5 24a0
24a2 :3 0 6d :2 0
a2 :4 0 14c8 24a4
24a6 :3 0 6d :2 0
9c :3 0 14cb 24a8
24aa :3 0 6d :2 0
a3 :4 0 14ce 24ac
24ae :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
14d1 24b1 24b5 14d5
24b0 24b7 :3 0 14d8
2499 24b9 :2 0 24bb
14db 24bc 2496 24bb
0 24bd 14dd 0
24be 14df 24c1 :3 0
24c1 0 24c1 24c0
24be 24bf :6 0 24c3
57 :3 0 14e2 24c5
14e4 24c4 24c3 :2 0
24c6 14e6 :2 0 24c8
0 24c8 24c7 2475
24c6 :6 0 265f 40
:3 0 134 :3 0 a4
:3 0 1f :3 0 134
:3 0 a4 :3 0 21
:3 0 1f :3 0 21
:3 0 21 :3 0 99
:4 0 1de 1 :8 0
24da 15 :3 0 9b
:3 0 24d5 24d6 0
9c :3 0 24d7 24d8
0 24da 14e9 252d
9d :3 0 15 :3 0
9b :3 0 24dc 24dd
0 9c :3 0 24de
24df 0 24e1 14ec
24e3 14ee 24e2 24e1
:2 0 252b 9e :3 0
15 :3 0 9b :3 0
24e6 24e7 0 9c
:3 0 24e8 24e9 0
2523 65 :3 0 66
:3 0 24eb 24ec 0
65 :3 0 76 :3 0
24ee 24ef 0 9f
:2 0 2 :4 0 1df
:2 0 78 :2 0 27
:2 0 14f0 24f4 24f6
:3 0 14f3 24f0 24f8
24ed 24fa 24f9 :2 0
68 :3 0 79 :3 0
24fc 24fd 0 6a
:4 0 1e0 :4 0 6d
:2 0 6e :3 0 14f7
2501 2503 :3 0 6d
:2 0 82 :4 0 14fa
2505 2507 :3 0 6d
:2 0 a2 :4 0 14fd
2509 250b :3 0 6d
:2 0 9c :3 0 1500
250d 250f :3 0 6d
:2 0 a3 :4 0 1503
2511 2513 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1506 2516 251a
150a 2515 251c :3 0
150d 24fe 251e :2 0
2520 1510 2521 24fb
2520 0 2522 1512
0 2523 1514 2526
:3 0 2526 0 2526
2525 2523 2524 :6 0
2528 59 :3 0 1517
252a 1519 2529 2528
:2 0 252b 151b :2 0
252d 0 252d 252c
24da 252b :6 0 265f
40 :3 0 45 :3 0
1a3 :2 0 252f 2530
0 265f 22 :3 0
6 :3 0 2532 2533
0 265f 72 :3 0
33 :3 0 30 :2 0
151e 2535 2538 8f
:2 0 30 :2 0 1523
253a 253c :3 0 3f
:3 0 115 :2 0 253e
253f 0 2541 1526
2542 253d 2541 0
2543 1528 0 265f
61 :3 0 1a4 :3 0
19 :3 0 17 :3 0
1a :3 0 1d :3 0
4e :3 0 32 :3 0
23 :3 0 23 :3 0
23 :3 0 23 :3 0
21 :3 0 22 :3 0
41 :3 0 37 :3 0
35 :3 0 38 :3 0
39 :3 0 34 :3 0
45 :3 0 26 :3 0
33 :3 0 31 :3 0
3b :3 0 36 :3 0
3f :3 0 3d :3 0
43 :3 0 1c :3 0
30 :2 0 30 :2 0
7d :2 0 7d :2 0
30 :2 0 152a 2545
2567 2544 2568 0
265f 61 :3 0 8f
:2 0 30 :2 0 154e
256b 256d :3 0 72
:3 0 33 :3 0 30
:2 0 1551 256f 2572
8f :2 0 30 :2 0
1556 2574 2576 :3 0
1a5 :3 0 1a6 :3 0
1a7 :3 0 1d :4 0
1a8 1 :8 0 2592
1a9 :4 0 257d :3 0
8a :3 0 8f :2 0
155b 2580 2581 :3 0
15 :3 0 9b :3 0
2583 2584 0 30
:2 0 2585 2586 0
2588 155e 258f 15
:3 0 9b :3 0 2589
258a 0 113 :2 0
258b 258c 0 258e
1560 2590 2582 2588
0 2591 0 258e
0 2591 1562 0
2592 1565 25e5 9d
:3 0 15 :3 0 9b
:3 0 2594 2595 0
9c :3 0 2596 2597
0 2599 1568 259b
156a 259a 2599 :2 0
25e3 9e :3 0 15
:3 0 9b :3 0 259e
259f 0 9c :3 0
25a0 25a1 0 25db
65 :3 0 66 :3 0
25a3 25a4 0 65
:3 0 76 :3 0 25a6
25a7 0 9f :2 0
2 :4 0 1e1 :2 0
78 :2 0 27 :2 0
156c 25ac 25ae :3 0
156f 25a8 25b0 25a5
25b2 25b1 :2 0 68
:3 0 79 :3 0 25b4
25b5 0 6a :4 0
1e2 :4 0 6d :2 0
6e :3 0 1573 25b9
25bb :3 0 6d :2 0
82 :4 0 1576 25bd
25bf :3 0 6d :2 0
a2 :4 0 1579 25c1
25c3 :3 0 6d :2 0
9c :3 0 157c 25c5
25c7 :3 0 6d :2 0
a3 :4 0 157f 25c9
25cb :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1582 25ce 25d2 1586
25cd 25d4 :3 0 1589
25b6 25d6 :2 0 25d8
158c 25d9 25b3 25d8
0 25da 158e 0
25db 1590 25de :3 0
25de 0 25de 25dd
25db 25dc :6 0 25e0
5b :3 0 1593 25e2
1595 25e1 25e0 :2 0
25e3 1597 :2 0 25e5
0 25e5 25e4 2592
25e3 :6 0 25e7 40
:3 0 159a 2658 1a5
:3 0 1a6 :3 0 1a7
:3 0 1d :4 0 1ac
1 :8 0 2602 1a9
:4 0 25ed :3 0 8a
:3 0 8f :2 0 159e
25f0 25f1 :3 0 15
:3 0 9b :3 0 25f3
25f4 0 30 :2 0
25f5 25f6 0 25f8
15a1 25ff 15 :3 0
9b :3 0 25f9 25fa
0 113 :2 0 25fb
25fc 0 25fe 15a3
2600 25f2 25f8 0
2601 0 25fe 0
2601 15a5 0 2602
15a8 2655 9d :3 0
15 :3 0 9b :3 0
2604 2605 0 9c
:3 0 2606 2607 0
2609 15ab 260b 15ad
260a 2609 :2 0 2653
9e :3 0 15 :3 0
9b :3 0 260e 260f
0 9c :3 0 2610
2611 0 264b 65
:3 0 66 :3 0 2613
2614 0 65 :3 0
76 :3 0 2616 2617
0 9f :2 0 2
:4 0 1e3 :2 0 78
:2 0 27 :2 0 15af
261c 261e :3 0 15b2
2618 2620 2615 2622
2621 :2 0 68 :3 0
79 :3 0 2624 2625
0 6a :4 0 1e4
:4 0 6d :2 0 6e
:3 0 15b6 2629 262b
:3 0 6d :2 0 82
:4 0 15b9 262d 262f
:3 0 6d :2 0 a2
:4 0 15bc 2631 2633
:3 0 6d :2 0 9c
:3 0 15bf 2635 2637
:3 0 6d :2 0 a3
:4 0 15c2 2639 263b
:3 0 6d :2 0 a4
:3 0 a5 :3 0 27
:2 0 a6 :2 0 15c5
263e 2642 15c9 263d
2644 :3 0 15cc 2626
2646 :2 0 2648 15cf
2649 2623 2648 0
264a 15d1 0 264b
15d3 264e :3 0 264e
0 264e 264d 264b
264c :6 0 2650 5d
:3 0 15d6 2652 15d8
2651 2650 :2 0 2653
15da :2 0 2655 0
2655 2654 2602 2653
:6 0 2657 40 :3 0
15dd 2659 2577 25e7
0 265a 0 2657
0 265a 15df 0
265b 15e2 265c 256e
265b 0 265d 15e4
0 265f ae :3 0
15e6 2729 72 :3 0
46 :3 0 30 :2 0
15f2 2660 2663 8f
:2 0 30 :2 0 15f7
2665 2667 :3 0 21
:3 0 1f :3 0 2669
266a 0 2727 22
:3 0 6 :3 0 266c
266d 0 2727 a4
:3 0 26 :3 0 27
:2 0 27 :2 0 15fa
266f 2673 8f :2 0
27 :4 0 1600 2675
2677 :3 0 45 :3 0
84 :3 0 106 :3 0
267a 267b 0 2679
267c 0 267e 1603
2687 45 :3 0 72
:3 0 3a :3 0 30
:2 0 1605 2680 2683
267f 2684 0 2686
1608 2688 2678 267e
0 2689 0 2686
0 2689 160a 0
2727 61 :3 0 1a4
:3 0 28 :3 0 17
:3 0 1a :3 0 1d
:3 0 4e :3 0 32
:3 0 23 :3 0 23
:3 0 23 :3 0 23
:3 0 21 :3 0 22
:3 0 41 :3 0 37
:3 0 35 :3 0 38
:3 0 39 :3 0 34
:3 0 45 :3 0 26
:3 0 33 :3 0 31
:3 0 3b :3 0 36
:3 0 3f :3 0 3d
:3 0 43 :3 0 1c
:3 0 30 :2 0 30
:2 0 7d :2 0 7d
:2 0 30 :2 0 160d
268b 26ad 268a 26ae
0 2727 61 :3 0
8f :2 0 30 :2 0
1631 26b1 26b3 :3 0
1a5 :3 0 1a6 :3 0
1a7 :3 0 1d :4 0
1a8 1 :8 0 26cf
1a9 :4 0 26ba :3 0
8a :3 0 8f :2 0
1636 26bd 26be :3 0
15 :3 0 9b :3 0
26c0 26c1 0 30
:2 0 26c2 26c3 0
26c5 1639 26cc 15
:3 0 9b :3 0 26c6
26c7 0 113 :2 0
26c8 26c9 0 26cb
163b 26cd 26bf 26c5
0 26ce 0 26cb
0 26ce 163d 0
26cf 1640 2722 9d
:3 0 15 :3 0 9b
:3 0 26d1 26d2 0
9c :3 0 26d3 26d4
0 26d6 1643 26d8
1645 26d7 26d6 :2 0
2720 9e :3 0 15
:3 0 9b :3 0 26db
26dc 0 9c :3 0
26dd 26de 0 2718
65 :3 0 66 :3 0
26e0 26e1 0 65
:3 0 76 :3 0 26e3
26e4 0 9f :2 0
2 :4 0 1e5 :2 0
78 :2 0 27 :2 0
1647 26e9 26eb :3 0
164a 26e5 26ed 26e2
26ef 26ee :2 0 68
:3 0 79 :3 0 26f1
26f2 0 6a :4 0
1e6 :4 0 6d :2 0
6e :3 0 164e 26f6
26f8 :3 0 6d :2 0
82 :4 0 1651 26fa
26fc :3 0 6d :2 0
a2 :4 0 1654 26fe
2700 :3 0 6d :2 0
9c :3 0 1657 2702
2704 :3 0 6d :2 0
a3 :4 0 165a 2706
2708 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
165d 270b 270f 1661
270a 2711 :3 0 1664
26f3 2713 :2 0 2715
1667 2716 26f0 2715
0 2717 1669 0
2718 166b 271b :3 0
271b 0 271b 271a
2718 2719 :6 0 271d
5f :3 0 166e 271f
1670 271e 271d :2 0
2720 1672 :2 0 2722
0 2722 2721 26cf
2720 :6 0 2724 40
:3 0 1675 2725 26b4
2724 0 2726 1677
0 2727 1679 2728
2668 2727 0 272a
1ed9 265f 0 272a
167f 0 273a 2f
:3 0 72 :3 0 2f
:3 0 30 :2 0 1682
272c 272f 78 :2 0
27 :2 0 1685 2731
2733 :3 0 272b 2734
0 273a 1da :5 0
2738 61 0 2739
1688 2738 2737 273a
168a 273c 1b5 :3 0
1d8b 273a :4 0 273d
169a 273e 1d7c 273d
0 273f 169d 0
2740 169f 2742 d9b
1d4d 0 2743 0
2740 0 2743 16a2
0 3266 61 :3 0
b7 :2 0 30 :2 0
16a7 2745 2747 :3 0
2748 :2 0 72 :3 0
32 :3 0 30 :2 0
16aa 274a 274d b2
:2 0 30 :2 0 16af
274f 2751 :3 0 2752
:2 0 2749 2754 2753
:2 0 72 :3 0 42
:3 0 30 :2 0 16b2
2756 2759 8f :2 0
30 :2 0 16b7 275b
275d :3 0 181 :3 0
17e :3 0 28 :4 0
1e7 1 :8 0 2778
1a9 :4 0 2763 :3 0
8a :3 0 8f :2 0
16bc 2766 2767 :3 0
15 :3 0 9b :3 0
2769 276a 0 30
:2 0 276b 276c 0
276e 16bf 2775 15
:3 0 9b :3 0 276f
2770 0 113 :2 0
2771 2772 0 2774
16c1 2776 2768 276e
0 2777 0 2774
0 2777 16c3 0
2778 16c6 27cb 9d
:3 0 15 :3 0 9b
:3 0 277a 277b 0
9c :3 0 277c 277d
0 277f 16c9 2781
16cb 2780 277f :2 0
27c9 9e :3 0 15
:3 0 9b :3 0 2784
2785 0 9c :3 0
2786 2787 0 27c1
65 :3 0 66 :3 0
2789 278a 0 65
:3 0 76 :3 0 278c
278d 0 9f :2 0
2 :4 0 1e8 :2 0
78 :2 0 27 :2 0
16cd 2792 2794 :3 0
16d0 278e 2796 278b
2798 2797 :2 0 68
:3 0 79 :3 0 279a
279b 0 6a :4 0
1e9 :4 0 6d :2 0
6e :3 0 16d4 279f
27a1 :3 0 6d :2 0
82 :4 0 16d7 27a3
27a5 :3 0 6d :2 0
a2 :4 0 16da 27a7
27a9 :3 0 6d :2 0
9c :3 0 16dd 27ab
27ad :3 0 6d :2 0
a3 :4 0 16e0 27af
27b1 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
16e3 27b4 27b8 16e7
27b3 27ba :3 0 16ea
279c 27bc :2 0 27be
16ed 27bf 2799 27be
0 27c0 16ef 0
27c1 16f1 27c4 :3 0
27c4 0 27c4 27c3
27c1 27c2 :6 0 27c6
61 :3 0 16f4 27c8
16f6 27c7 27c6 :2 0
27c9 16f8 :2 0 27cb
0 27cb 27ca 2778
27c9 :6 0 27cd 1
:3 0 16fb 2841 181
:3 0 180 :3 0 1e
:3 0 17f :3 0 42
:3 0 17e :3 0 28
:4 0 1ea 1 :8 0
27eb 1a9 :4 0 27d6
:3 0 8a :3 0 8f
:2 0 16ff 27d9 27da
:3 0 15 :3 0 9b
:3 0 27dc 27dd 0
30 :2 0 27de 27df
0 27e1 1702 27e8
15 :3 0 9b :3 0
27e2 27e3 0 113
:2 0 27e4 27e5 0
27e7 1704 27e9 27db
27e1 0 27ea 0
27e7 0 27ea 1706
0 27eb 1709 283e
9d :3 0 15 :3 0
9b :3 0 27ed 27ee
0 9c :3 0 27ef
27f0 0 27f2 170c
27f4 170e 27f3 27f2
:2 0 283c 9e :3 0
15 :3 0 9b :3 0
27f7 27f8 0 9c
:3 0 27f9 27fa 0
2834 65 :3 0 66
:3 0 27fc 27fd 0
65 :3 0 76 :3 0
27ff 2800 0 9f
:2 0 2 :4 0 1eb
:2 0 78 :2 0 27
:2 0 1710 2805 2807
:3 0 1713 2801 2809
27fe 280b 280a :2 0
68 :3 0 79 :3 0
280d 280e 0 6a
:4 0 1ec :4 0 6d
:2 0 6e :3 0 1717
2812 2814 :3 0 6d
:2 0 82 :4 0 171a
2816 2818 :3 0 6d
:2 0 a2 :4 0 171d
281a 281c :3 0 6d
:2 0 9c :3 0 1720
281e 2820 :3 0 6d
:2 0 a3 :4 0 1723
2822 2824 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1726 2827 282b
172a 2826 282d :3 0
172d 280f 282f :2 0
2831 1730 2832 280c
2831 0 2833 1732
0 2834 1734 2837
:3 0 2837 0 2837
2836 2834 2835 :6 0
2839 63 :3 0 1737
283b 1739 283a 2839
:2 0 283c 173b :2 0
283e 0 283e 283d
27eb 283c :6 0 2840
1 :3 0 173e 2842
275e 27cd 0 2843
0 2840 0 2843
1740 0 2a16 61
:3 0 8f :2 0 113
:2 0 1745 2845 2847
:3 0 65 :3 0 66
:3 0 2849 284a 0
65 :3 0 76 :3 0
284c 284d 0 18
:2 0 2 :4 0 1ed
:2 0 78 :2 0 27
:2 0 1748 2852 2854
:3 0 174b 284e 2856
284b 2858 2857 :2 0
68 :3 0 79 :3 0
285a 285b 0 6a
:4 0 1ee :4 0 6d
:2 0 6e :3 0 174f
285f 2861 :3 0 6d
:2 0 82 :4 0 1752
2863 2865 :3 0 6d
:2 0 83 :4 0 1755
2867 2869 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 17b
:3 0 286e 286f 0
1758 286d 2871 74
:4 0 175a 286c 2874
175d 286b 2876 :3 0
6d :2 0 e5 :4 0
1760 2878 287a :3 0
6d :2 0 70 :4 0
1763 287c 287e :3 0
6d :2 0 1d :3 0
1766 2880 2882 :3 0
6d :2 0 70 :4 0
1769 2884 2886 :3 0
176c 285c 2888 :2 0
288a 176f 288b 2859
288a 0 288c 1771
0 28b7 65 :3 0
66 :3 0 288d 288e
0 65 :3 0 76
:3 0 2890 2891 0
27 :2 0 2 :4 0
1ef :2 0 78 :2 0
27 :2 0 1773 2896
2898 :3 0 1776 2892
289a 288f 289c 289b
:2 0 68 :3 0 79
:3 0 289e 289f 0
6a :4 0 1f0 :4 0
6d :2 0 6e :3 0
177a 28a3 28a5 :3 0
177d 28a0 28a7 :2 0
28a9 1780 28aa 289d
28a9 0 28ab 1782
0 28b7 88 :3 0
e8 :3 0 28ac 28ad
0 84 :3 0 17b
:3 0 28af 28b0 0
1d :3 0 8a :3 0
1784 28ae 28b4 :2 0
28b7 ae :3 0 1788
2a13 61 :3 0 84
:3 0 8f :2 0 1f1
:3 0 28b9 28bb 0
178e 28ba 28bd :3 0
65 :3 0 66 :3 0
28bf 28c0 0 65
:3 0 76 :3 0 28c2
28c3 0 18 :2 0
2 :4 0 1f2 :2 0
78 :2 0 27 :2 0
1791 28c8 28ca :3 0
1794 28c4 28cc 28c1
28ce 28cd :2 0 68
:3 0 79 :3 0 28d0
28d1 0 6a :4 0
1f3 :4 0 6d :2 0
6e :3 0 1798 28d5
28d7 :3 0 6d :2 0
82 :4 0 179b 28d9
28db :3 0 6d :2 0
83 :4 0 179e 28dd
28df :3 0 6d :2 0
72 :3 0 73 :3 0
84 :3 0 1f1 :3 0
28e4 28e5 0 17a1
28e3 28e7 74 :4 0
17a3 28e2 28ea 17a6
28e1 28ec :3 0 6d
:2 0 e5 :4 0 17a9
28ee 28f0 :3 0 6d
:2 0 70 :4 0 17ac
28f2 28f4 :3 0 6d
:2 0 1d :3 0 17af
28f6 28f8 :3 0 6d
:2 0 70 :4 0 17b2
28fa 28fc :3 0 17b5
28d2 28fe :2 0 2900
17b8 2901 28cf 2900
0 2902 17ba 0
292d 65 :3 0 66
:3 0 2903 2904 0
65 :3 0 76 :3 0
2906 2907 0 27
:2 0 2 :4 0 1f4
:2 0 78 :2 0 27
:2 0 17bc 290c 290e
:3 0 17bf 2908 2910
2905 2912 2911 :2 0
68 :3 0 79 :3 0
2914 2915 0 6a
:4 0 1f5 :4 0 6d
:2 0 6e :3 0 17c3
2919 291b :3 0 17c6
2916 291d :2 0 291f
17c9 2920 2913 291f
0 2921 17cb 0
292d 88 :3 0 e8
:3 0 2922 2923 0
84 :3 0 1f1 :3 0
2925 2926 0 1d
:3 0 8a :3 0 17cd
2924 292a :2 0 292d
ae :3 0 17d1 292e
28be 292d 0 2a15
61 :3 0 84 :3 0
8f :2 0 1f6 :3 0
2930 2932 0 17d7
2931 2934 :3 0 65
:3 0 66 :3 0 2936
2937 0 65 :3 0
76 :3 0 2939 293a
0 18 :2 0 2
:4 0 1f7 :2 0 78
:2 0 27 :2 0 17da
293f 2941 :3 0 17dd
293b 2943 2938 2945
2944 :2 0 68 :3 0
79 :3 0 2947 2948
0 6a :4 0 1f8
:4 0 6d :2 0 6e
:3 0 17e1 294c 294e
:3 0 6d :2 0 82
:4 0 17e4 2950 2952
:3 0 6d :2 0 83
:4 0 17e7 2954 2956
:3 0 6d :2 0 72
:3 0 73 :3 0 84
:3 0 1f6 :3 0 295b
295c 0 17ea 295a
295e 74 :4 0 17ec
2959 2961 17ef 2958
2963 :3 0 6d :2 0
e5 :4 0 17f2 2965
2967 :3 0 6d :2 0
70 :4 0 17f5 2969
296b :3 0 6d :2 0
1d :3 0 17f8 296d
296f :3 0 6d :2 0
70 :4 0 17fb 2971
2973 :3 0 17fe 2949
2975 :2 0 2977 1801
2978 2946 2977 0
2979 1803 0 29a3
65 :3 0 66 :3 0
297a 297b 0 65
:3 0 76 :3 0 297d
297e 0 27 :2 0
2 :4 0 1f9 :2 0
78 :2 0 27 :2 0
1805 2983 2985 :3 0
1808 297f 2987 297c
2989 2988 :2 0 68
:3 0 79 :3 0 298b
298c 0 6a :4 0
1fa :4 0 6d :2 0
6e :3 0 180c 2990
2992 :3 0 180f 298d
2994 :2 0 2996 1812
2997 298a 2996 0
2998 1814 0 29a3
88 :3 0 e8 :3 0
2999 299a 0 84
:3 0 1f6 :3 0 299c
299d 0 1d :3 0
8a :3 0 1816 299b
29a1 :2 0 29a3 181a
29a4 2935 29a3 0
2a15 65 :3 0 66
:3 0 29a5 29a6 0
65 :3 0 76 :3 0
29a8 29a9 0 18
:2 0 2 :4 0 1fb
:2 0 78 :2 0 27
:2 0 181e 29ae 29b0
:3 0 1821 29aa 29b2
29a7 29b4 29b3 :2 0
68 :3 0 79 :3 0
29b6 29b7 0 6a
:4 0 1fc :4 0 6d
:2 0 6e :3 0 1825
29bb 29bd :3 0 6d
:2 0 82 :4 0 1828
29bf 29c1 :3 0 6d
:2 0 83 :4 0 182b
29c3 29c5 :3 0 6d
:2 0 72 :3 0 73
:3 0 84 :3 0 155
:3 0 29ca 29cb 0
182e 29c9 29cd 74
:4 0 1830 29c8 29d0
1833 29c7 29d2 :3 0
6d :2 0 e5 :4 0
1836 29d4 29d6 :3 0
6d :2 0 70 :4 0
1839 29d8 29da :3 0
6d :2 0 28 :3 0
183c 29dc 29de :3 0
6d :2 0 70 :4 0
183f 29e0 29e2 :3 0
1842 29b8 29e4 :2 0
29e6 1845 29e7 29b5
29e6 0 29e8 1847
0 2a12 65 :3 0
66 :3 0 29e9 29ea
0 65 :3 0 76
:3 0 29ec 29ed 0
27 :2 0 2 :4 0
1fd :2 0 78 :2 0
27 :2 0 1849 29f2
29f4 :3 0 184c 29ee
29f6 29eb 29f8 29f7
:2 0 68 :3 0 79
:3 0 29fa 29fb 0
6a :4 0 1fe :4 0
6d :2 0 6e :3 0
1850 29ff 2a01 :3 0
1853 29fc 2a03 :2 0
2a05 1856 2a06 29f9
2a05 0 2a07 1858
0 2a12 88 :3 0
e8 :3 0 2a08 2a09
0 84 :3 0 155
:3 0 2a0b 2a0c 0
28 :3 0 8a :3 0
185a 2a0a 2a10 :2 0
2a12 185e 2a14 2848
28b7 0 2a15 0
2a12 0 2a15 1862
0 2a16 1867 2a17
2755 2a16 0 2a18
186a 0 3266 72
:3 0 1b1 :3 0 2b
:3 0 186c 2a1a 2a1c
30 :2 0 186e 2a19
2a1f b2 :2 0 30
:2 0 1873 2a21 2a23
:3 0 2a24 :2 0 72
:3 0 1b1 :3 0 2c
:3 0 1876 2a27 2a29
30 :2 0 1878 2a26
2a2c b2 :2 0 30
:2 0 187d 2a2e 2a30
:3 0 2a31 :2 0 2a25
2a33 2a32 :2 0 1ff
:3 0 200 :3 0 201
:4 0 2a37 :4 0 2a38
:2 0 2d43 15 :3 0
9b :3 0 2a3a 2a3b
0 30 :2 0 2a3c
2a3d 0 2d43 50
:3 0 202 :4 0 6d
:2 0 203 :4 0 1880
2a41 2a43 :3 0 6d
:2 0 204 :4 0 1883
2a45 2a47 :3 0 6d
:2 0 205 :4 0 1886
2a49 2a4b :3 0 6d
:2 0 206 :4 0 1889
2a4d 2a4f :3 0 6d
:2 0 207 :4 0 188c
2a51 2a53 :3 0 6d
:2 0 17 :3 0 188f
2a55 2a57 :3 0 6d
:2 0 208 :4 0 1892
2a59 2a5b :3 0 6d
:2 0 209 :4 0 1895
2a5d 2a5f :3 0 6d
:2 0 2b :3 0 1898
2a61 2a63 :3 0 6d
:2 0 20a :4 0 189b
2a65 2a67 :3 0 6d
:2 0 2c :3 0 189e
2a69 2a6b :3 0 6d
:2 0 20b :4 0 18a1
2a6d 2a6f :3 0 2a3f
2a70 0 2d43 1ff
:3 0 200 :3 0 50
:3 0 2a74 :4 0 2a75
:2 0 2a8c 1a9 :4 0
2a77 :3 0 8a :3 0
8f :2 0 18a6 2a7a
2a7b :3 0 15 :3 0
9b :3 0 2a7d 2a7e
0 30 :2 0 2a7f
2a80 0 2a82 18a9
2a89 15 :3 0 9b
:3 0 2a83 2a84 0
113 :2 0 2a85 2a86
0 2a88 18ab 2a8a
2a7c 2a82 0 2a8b
0 2a88 0 2a8b
18ad 0 2a8c 18b0
2aea 9d :3 0 15
:3 0 9b :3 0 2a8e
2a8f 0 9c :3 0
2a90 2a91 0 2a93
18b3 2a95 18b5 2a94
2a93 :2 0 2ae8 9e
:3 0 15 :3 0 9b
:3 0 2a98 2a99 0
9c :3 0 2a9a 2a9b
0 2ae0 65 :3 0
66 :3 0 2a9d 2a9e
0 65 :3 0 76
:3 0 2aa0 2aa1 0
9f :2 0 2 :4 0
20c :2 0 78 :2 0
27 :2 0 18b7 2aa6
2aa8 :3 0 18ba 2aa2
2aaa 2a9f 2aac 2aab
:2 0 68 :3 0 79
:3 0 2aae 2aaf 0
6a :4 0 20d :4 0
6d :2 0 6e :3 0
18be 2ab3 2ab5 :3 0
6d :2 0 82 :4 0
18c1 2ab7 2ab9 :3 0
6d :2 0 a2 :4 0
18c4 2abb 2abd :3 0
6d :2 0 9c :3 0
18c7 2abf 2ac1 :3 0
6d :2 0 a3 :4 0
18ca 2ac3 2ac5 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 18cd 2ac8
2acc 18d1 2ac7 2ace
:3 0 18d4 2ab0 2ad0
:2 0 2add 68 :3 0
79 :3 0 2ad2 2ad3
0 6a :4 0 20e
:4 0 6d :2 0 50
:3 0 18d7 2ad7 2ad9
:3 0 18da 2ad4 2adb
:2 0 2add 18dd 2ade
2aad 2add 0 2adf
18e0 0 2ae0 18e2
2ae3 :3 0 2ae3 0
2ae3 2ae2 2ae0 2ae1
:6 0 2ae5 65 :3 0
18e5 2ae7 18e7 2ae6
2ae5 :2 0 2ae8 18e9
:2 0 2aea 0 2aea
2ae9 2a8c 2ae8 :6 0
2d43 1 :3 0 1ff
:3 0 200 :3 0 20f
:4 0 2aee :4 0 2aef
:2 0 2d43 15 :3 0
9b :3 0 2af1 2af2
0 30 :2 0 2af3
2af4 0 2d43 50
:3 0 210 :4 0 6d
:2 0 211 :4 0 18ec
2af8 2afa :3 0 6d
:2 0 212 :4 0 18ef
2afc 2afe :3 0 6d
:2 0 213 :4 0 18f2
2b00 2b02 :3 0 6d
:2 0 214 :4 0 18f5
2b04 2b06 :3 0 6d
:2 0 215 :4 0 18f8
2b08 2b0a :3 0 6d
:2 0 17 :3 0 18fb
2b0c 2b0e :3 0 6d
:2 0 208 :4 0 18fe
2b10 2b12 :3 0 6d
:2 0 216 :4 0 1901
2b14 2b16 :3 0 6d
:2 0 2b :3 0 1904
2b18 2b1a :3 0 6d
:2 0 20a :4 0 1907
2b1c 2b1e :3 0 6d
:2 0 2c :3 0 190a
2b20 2b22 :3 0 6d
:2 0 217 :4 0 190d
2b24 2b26 :3 0 2af6
2b27 0 2d43 1ff
:3 0 200 :3 0 50
:3 0 2b2b :4 0 2b2c
:2 0 2b43 1a9 :4 0
2b2e :3 0 8a :3 0
8f :2 0 1912 2b31
2b32 :3 0 15 :3 0
9b :3 0 2b34 2b35
0 30 :2 0 2b36
2b37 0 2b39 1915
2b40 15 :3 0 9b
:3 0 2b3a 2b3b 0
113 :2 0 2b3c 2b3d
0 2b3f 1917 2b41
2b33 2b39 0 2b42
0 2b3f 0 2b42
1919 0 2b43 191c
2ba1 9d :3 0 15
:3 0 9b :3 0 2b45
2b46 0 9c :3 0
2b47 2b48 0 2b4a
191f 2b4c 1921 2b4b
2b4a :2 0 2b9f 9e
:3 0 15 :3 0 9b
:3 0 2b4f 2b50 0
9c :3 0 2b51 2b52
0 2b97 65 :3 0
66 :3 0 2b54 2b55
0 65 :3 0 76
:3 0 2b57 2b58 0
9f :2 0 2 :4 0
218 :2 0 78 :2 0
27 :2 0 1923 2b5d
2b5f :3 0 1926 2b59
2b61 2b56 2b63 2b62
:2 0 68 :3 0 79
:3 0 2b65 2b66 0
6a :4 0 219 :4 0
6d :2 0 6e :3 0
192a 2b6a 2b6c :3 0
6d :2 0 82 :4 0
192d 2b6e 2b70 :3 0
6d :2 0 a2 :4 0
1930 2b72 2b74 :3 0
6d :2 0 9c :3 0
1933 2b76 2b78 :3 0
6d :2 0 a3 :4 0
1936 2b7a 2b7c :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 1939 2b7f
2b83 193d 2b7e 2b85
:3 0 1940 2b67 2b87
:2 0 2b94 68 :3 0
79 :3 0 2b89 2b8a
0 6a :4 0 20e
:4 0 6d :2 0 50
:3 0 1943 2b8e 2b90
:3 0 1946 2b8b 2b92
:2 0 2b94 1949 2b95
2b64 2b94 0 2b96
194c 0 2b97 194e
2b9a :3 0 2b9a 0
2b9a 2b99 2b97 2b98
:6 0 2b9c 67 :3 0
1951 2b9e 1953 2b9d
2b9c :2 0 2b9f 1955
:2 0 2ba1 0 2ba1
2ba0 2b43 2b9f :6 0
2d43 1 :3 0 15
:3 0 9b :3 0 2ba3
2ba4 0 21a :4 0
2ba6 2ba7 :3 0 2ba5
2ba8 0 2d43 50
:3 0 21b :4 0 6d
:2 0 21c :4 0 1958
2bac 2bae :3 0 6d
:2 0 21d :4 0 195b
2bb0 2bb2 :3 0 6d
:2 0 21e :4 0 195e
2bb4 2bb6 :3 0 6d
:2 0 21f :4 0 1961
2bb8 2bba :3 0 6d
:2 0 220 :4 0 1964
2bbc 2bbe :3 0 6d
:2 0 221 :4 0 1967
2bc0 2bc2 :3 0 6d
:2 0 222 :4 0 196a
2bc4 2bc6 :3 0 6d
:2 0 223 :4 0 196d
2bc8 2bca :3 0 6d
:2 0 224 :4 0 1970
2bcc 2bce :3 0 6d
:2 0 225 :4 0 1973
2bd0 2bd2 :3 0 6d
:2 0 226 :4 0 1976
2bd4 2bd6 :3 0 6d
:2 0 227 :4 0 1979
2bd8 2bda :3 0 6d
:2 0 17 :3 0 197c
2bdc 2bde :3 0 6d
:2 0 228 :4 0 197f
2be0 2be2 :3 0 6d
:2 0 229 :4 0 1982
2be4 2be6 :3 0 6d
:2 0 17 :3 0 1985
2be8 2bea :3 0 6d
:2 0 22a :4 0 1988
2bec 2bee :3 0 6d
:2 0 22b :4 0 198b
2bf0 2bf2 :3 0 6d
:2 0 22c :4 0 198e
2bf4 2bf6 :3 0 6d
:2 0 2b :3 0 1991
2bf8 2bfa :3 0 6d
:2 0 22d :4 0 1994
2bfc 2bfe :3 0 6d
:2 0 22e :4 0 1997
2c00 2c02 :3 0 6d
:2 0 22f :4 0 199a
2c04 2c06 :3 0 6d
:2 0 230 :4 0 199d
2c08 2c0a :3 0 6d
:2 0 231 :4 0 19a0
2c0c 2c0e :3 0 6d
:2 0 224 :4 0 19a3
2c10 2c12 :3 0 6d
:2 0 232 :4 0 19a6
2c14 2c16 :3 0 6d
:2 0 233 :4 0 19a9
2c18 2c1a :3 0 6d
:2 0 234 :4 0 19ac
2c1c 2c1e :3 0 6d
:2 0 17 :3 0 19af
2c20 2c22 :3 0 6d
:2 0 235 :4 0 19b2
2c24 2c26 :3 0 6d
:2 0 236 :4 0 19b5
2c28 2c2a :3 0 6d
:2 0 237 :4 0 19b8
2c2c 2c2e :3 0 6d
:2 0 238 :4 0 19bb
2c30 2c32 :3 0 6d
:2 0 239 :4 0 19be
2c34 2c36 :3 0 6d
:2 0 2c :3 0 19c1
2c38 2c3a :3 0 6d
:2 0 22d :4 0 19c4
2c3c 2c3e :3 0 6d
:2 0 23a :4 0 19c7
2c40 2c42 :3 0 2baa
2c43 0 2d43 1ff
:3 0 200 :3 0 50
:3 0 2c47 :4 0 2c48
:2 0 2c5f 1a9 :4 0
2c4a :3 0 8a :3 0
8f :2 0 19cc 2c4d
2c4e :3 0 15 :3 0
9b :3 0 2c50 2c51
0 30 :2 0 2c52
2c53 0 2c55 19cf
2c5c 15 :3 0 9b
:3 0 2c56 2c57 0
113 :2 0 2c58 2c59
0 2c5b 19d1 2c5d
2c4f 2c55 0 2c5e
0 2c5b 0 2c5e
19d3 0 2c5f 19d6
2cbd 9d :3 0 15
:3 0 9b :3 0 2c61
2c62 0 9c :3 0
2c63 2c64 0 2c66
19d9 2c68 19db 2c67
2c66 :2 0 2cbb 9e
:3 0 15 :3 0 9b
:3 0 2c6b 2c6c 0
9c :3 0 2c6d 2c6e
0 2cb3 65 :3 0
66 :3 0 2c70 2c71
0 65 :3 0 76
:3 0 2c73 2c74 0
9f :2 0 2 :4 0
23b :2 0 78 :2 0
27 :2 0 19dd 2c79
2c7b :3 0 19e0 2c75
2c7d 2c72 2c7f 2c7e
:2 0 68 :3 0 79
:3 0 2c81 2c82 0
6a :4 0 23c :4 0
6d :2 0 6e :3 0
19e4 2c86 2c88 :3 0
6d :2 0 82 :4 0
19e7 2c8a 2c8c :3 0
6d :2 0 a2 :4 0
19ea 2c8e 2c90 :3 0
6d :2 0 9c :3 0
19ed 2c92 2c94 :3 0
6d :2 0 a3 :4 0
19f0 2c96 2c98 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 19f3 2c9b
2c9f 19f7 2c9a 2ca1
:3 0 19fa 2c83 2ca3
:2 0 2cb0 68 :3 0
79 :3 0 2ca5 2ca6
0 6a :4 0 20e
:4 0 6d :2 0 50
:3 0 19fd 2caa 2cac
:3 0 1a00 2ca7 2cae
:2 0 2cb0 1a03 2cb1
2c80 2cb0 0 2cb2
1a06 0 2cb3 1a08
2cb6 :3 0 2cb6 0
2cb6 2cb5 2cb3 2cb4
:6 0 2cb8 69 :3 0
1a0b 2cba 1a0d 2cb9
2cb8 :2 0 2cbb 1a0f
:2 0 2cbd 0 2cbd
2cbc 2c5f 2cbb :6 0
2d43 1 :3 0 50
:3 0 23d :4 0 6d
:2 0 23e :4 0 1a12
2cc1 2cc3 :3 0 6d
:2 0 23f :4 0 1a15
2cc5 2cc7 :3 0 6d
:2 0 240 :4 0 1a18
2cc9 2ccb :3 0 6d
:2 0 73 :3 0 72
:3 0 38 :3 0 30
:2 0 1a1b 2ccf 2cd2
1a1e 2cce 2cd4 1a20
2ccd 2cd6 :3 0 6d
:2 0 241 :4 0 1a23
2cd8 2cda :3 0 6d
:2 0 82 :4 0 1a26
2cdc 2cde :3 0 6d
:2 0 73 :3 0 72
:3 0 3d :3 0 30
:2 0 1a29 2ce2 2ce5
1a2c 2ce1 2ce7 1a2e
2ce0 2ce9 :3 0 6d
:2 0 242 :4 0 1a31
2ceb 2ced :3 0 6d
:2 0 243 :4 0 1a34
2cef 2cf1 :3 0 6d
:2 0 244 :4 0 1a37
2cf3 2cf5 :3 0 6d
:2 0 245 :4 0 1a3a
2cf7 2cf9 :3 0 6d
:2 0 246 :4 0 1a3d
2cfb 2cfd :3 0 6d
:2 0 247 :4 0 1a40
2cff 2d01 :3 0 6d
:2 0 248 :4 0 1a43
2d03 2d05 :3 0 6d
:2 0 249 :4 0 1a46
2d07 2d09 :3 0 6d
:2 0 24a :4 0 1a49
2d0b 2d0d :3 0 6d
:2 0 73 :3 0 72
:3 0 38 :3 0 30
:2 0 1a4c 2d11 2d14
1a4f 2d10 2d16 1a51
2d0f 2d18 :3 0 6d
:2 0 24b :4 0 1a54
2d1a 2d1c :3 0 6d
:2 0 24c :4 0 1a57
2d1e 2d20 :3 0 6d
:2 0 73 :3 0 72
:3 0 3d :3 0 30
:2 0 1a5a 2d24 2d27
1a5d 2d23 2d29 1a5f
2d22 2d2b :3 0 6d
:2 0 24d :4 0 1a62
2d2d 2d2f :3 0 6d
:2 0 24e :4 0 1a65
2d31 2d33 :3 0 6d
:2 0 24f :4 0 1a68
2d35 2d37 :3 0 6d
:2 0 250 :4 0 1a6b
2d39 2d3b :3 0 6d
:2 0 251 :4 0 1a6e
2d3d 2d3f :3 0 2cbf
2d40 0 2d43 ae
:3 0 1a71 321d 72
:3 0 1b1 :3 0 2c
:3 0 1a7e 2d45 2d47
30 :2 0 1a80 2d44
2d4a 8f :2 0 30
:2 0 1a85 2d4c 2d4e
:3 0 1ff :3 0 200
:3 0 252 :4 0 2d52
:4 0 2d53 :2 0 2fb3
15 :3 0 9b :3 0
2d55 2d56 0 30
:2 0 2d57 2d58 0
2fb3 50 :3 0 253
:4 0 6d :2 0 254
:4 0 1a88 2d5c 2d5e
:3 0 6d :2 0 255
:4 0 1a8b 2d60 2d62
:3 0 6d :2 0 256
:4 0 1a8e 2d64 2d66
:3 0 6d :2 0 257
:4 0 1a91 2d68 2d6a
:3 0 6d :2 0 207
:4 0 1a94 2d6c 2d6e
:3 0 6d :2 0 17
:3 0 1a97 2d70 2d72
:3 0 6d :2 0 208
:4 0 1a9a 2d74 2d76
:3 0 6d :2 0 258
:4 0 1a9d 2d78 2d7a
:3 0 6d :2 0 2b
:3 0 1aa0 2d7c 2d7e
:3 0 6d :2 0 259
:4 0 1aa3 2d80 2d82
:3 0 2d5a 2d83 0
2fb3 1ff :3 0 200
:3 0 50 :3 0 2d87
:4 0 2d88 :2 0 2d9f
1a9 :4 0 2d8a :3 0
8a :3 0 8f :2 0
1aa8 2d8d 2d8e :3 0
15 :3 0 9b :3 0
2d90 2d91 0 30
:2 0 2d92 2d93 0
2d95 1aab 2d9c 15
:3 0 9b :3 0 2d96
2d97 0 113 :2 0
2d98 2d99 0 2d9b
1aad 2d9d 2d8f 2d95
0 2d9e 0 2d9b
0 2d9e 1aaf 0
2d9f 1ab2 2dfd 9d
:3 0 15 :3 0 9b
:3 0 2da1 2da2 0
9c :3 0 2da3 2da4
0 2da6 1ab5 2da8
1ab7 2da7 2da6 :2 0
2dfb 9e :3 0 15
:3 0 9b :3 0 2dab
2dac 0 9c :3 0
2dad 2dae 0 2df3
65 :3 0 66 :3 0
2db0 2db1 0 65
:3 0 76 :3 0 2db3
2db4 0 9f :2 0
2 :4 0 25a :2 0
78 :2 0 27 :2 0
1ab9 2db9 2dbb :3 0
1abc 2db5 2dbd 2db2
2dbf 2dbe :2 0 68
:3 0 79 :3 0 2dc1
2dc2 0 6a :4 0
25b :4 0 6d :2 0
6e :3 0 1ac0 2dc6
2dc8 :3 0 6d :2 0
82 :4 0 1ac3 2dca
2dcc :3 0 6d :2 0
a2 :4 0 1ac6 2dce
2dd0 :3 0 6d :2 0
9c :3 0 1ac9 2dd2
2dd4 :3 0 6d :2 0
a3 :4 0 1acc 2dd6
2dd8 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1acf 2ddb 2ddf 1ad3
2dda 2de1 :3 0 1ad6
2dc3 2de3 :2 0 2df0
68 :3 0 79 :3 0
2de5 2de6 0 6a
:4 0 20e :4 0 6d
:2 0 50 :3 0 1ad9
2dea 2dec :3 0 1adc
2de7 2dee :2 0 2df0
1adf 2df1 2dc0 2df0
0 2df2 1ae2 0
2df3 1ae4 2df6 :3 0
2df6 0 2df6 2df5
2df3 2df4 :6 0 2df8
6b :3 0 1ae7 2dfa
1ae9 2df9 2df8 :2 0
2dfb 1aeb :2 0 2dfd
0 2dfd 2dfc 2d9f
2dfb :6 0 2fb3 1
:3 0 1ff :3 0 200
:3 0 20f :4 0 2e01
:4 0 2e02 :2 0 2fb3
15 :3 0 9b :3 0
2e04 2e05 0 30
:2 0 2e06 2e07 0
2fb3 50 :3 0 25c
:4 0 6d :2 0 25d
:4 0 1aee 2e0b 2e0d
:3 0 6d :2 0 25e
:4 0 1af1 2e0f 2e11
:3 0 6d :2 0 25f
:4 0 1af4 2e13 2e15
:3 0 6d :2 0 260
:4 0 1af7 2e17 2e19
:3 0 6d :2 0 261
:4 0 1afa 2e1b 2e1d
:3 0 6d :2 0 17
:3 0 1afd 2e1f 2e21
:3 0 6d :2 0 262
:4 0 1b00 2e23 2e25
:3 0 6d :2 0 2b
:3 0 1b03 2e27 2e29
:3 0 6d :2 0 263
:4 0 1b06 2e2b 2e2d
:3 0 2e09 2e2e 0
2fb3 1ff :3 0 200
:3 0 50 :3 0 2e32
:4 0 2e33 :2 0 2e4a
1a9 :4 0 2e35 :3 0
8a :3 0 8f :2 0
1b0b 2e38 2e39 :3 0
15 :3 0 9b :3 0
2e3b 2e3c 0 30
:2 0 2e3d 2e3e 0
2e40 1b0e 2e47 15
:3 0 9b :3 0 2e41
2e42 0 113 :2 0
2e43 2e44 0 2e46
1b10 2e48 2e3a 2e40
0 2e49 0 2e46
0 2e49 1b12 0
2e4a 1b15 2ea8 9d
:3 0 15 :3 0 9b
:3 0 2e4c 2e4d 0
9c :3 0 2e4e 2e4f
0 2e51 1b18 2e53
1b1a 2e52 2e51 :2 0
2ea6 9e :3 0 15
:3 0 9b :3 0 2e56
2e57 0 9c :3 0
2e58 2e59 0 2e9e
65 :3 0 66 :3 0
2e5b 2e5c 0 65
:3 0 76 :3 0 2e5e
2e5f 0 9f :2 0
2 :4 0 264 :2 0
78 :2 0 27 :2 0
1b1c 2e64 2e66 :3 0
1b1f 2e60 2e68 2e5d
2e6a 2e69 :2 0 68
:3 0 79 :3 0 2e6c
2e6d 0 6a :4 0
265 :4 0 6d :2 0
6e :3 0 1b23 2e71
2e73 :3 0 6d :2 0
82 :4 0 1b26 2e75
2e77 :3 0 6d :2 0
a2 :4 0 1b29 2e79
2e7b :3 0 6d :2 0
9c :3 0 1b2c 2e7d
2e7f :3 0 6d :2 0
a3 :4 0 1b2f 2e81
2e83 :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1b32 2e86 2e8a 1b36
2e85 2e8c :3 0 1b39
2e6e 2e8e :2 0 2e9b
68 :3 0 79 :3 0
2e90 2e91 0 6a
:4 0 20e :4 0 6d
:2 0 50 :3 0 1b3c
2e95 2e97 :3 0 1b3f
2e92 2e99 :2 0 2e9b
1b42 2e9c 2e6b 2e9b
0 2e9d 1b45 0
2e9e 1b47 2ea1 :3 0
2ea1 0 2ea1 2ea0
2e9e 2e9f :6 0 2ea3
6d :3 0 1b4a 2ea5
1b4c 2ea4 2ea3 :2 0
2ea6 1b4e :2 0 2ea8
0 2ea8 2ea7 2e4a
2ea6 :6 0 2fb3 1
:3 0 15 :3 0 9b
:3 0 2eaa 2eab 0
21a :4 0 2ead 2eae
:3 0 2eac 2eaf 0
2fb3 50 :3 0 21b
:4 0 6d :2 0 266
:4 0 1b51 2eb3 2eb5
:3 0 6d :2 0 21e
:4 0 1b54 2eb7 2eb9
:3 0 6d :2 0 267
:4 0 1b57 2ebb 2ebd
:3 0 6d :2 0 268
:4 0 1b5a 2ebf 2ec1
:3 0 6d :2 0 222
:4 0 1b5d 2ec3 2ec5
:3 0 6d :2 0 269
:4 0 1b60 2ec7 2ec9
:3 0 6d :2 0 225
:4 0 1b63 2ecb 2ecd
:3 0 6d :2 0 26a
:4 0 1b66 2ecf 2ed1
:3 0 6d :2 0 227
:4 0 1b69 2ed3 2ed5
:3 0 6d :2 0 17
:3 0 1b6c 2ed7 2ed9
:3 0 6d :2 0 228
:4 0 1b6f 2edb 2edd
:3 0 6d :2 0 229
:4 0 1b72 2edf 2ee1
:3 0 6d :2 0 17
:3 0 1b75 2ee3 2ee5
:3 0 6d :2 0 22a
:4 0 1b78 2ee7 2ee9
:3 0 6d :2 0 22b
:4 0 1b7b 2eeb 2eed
:3 0 6d :2 0 26b
:4 0 1b7e 2eef 2ef1
:3 0 6d :2 0 2b
:3 0 1b81 2ef3 2ef5
:3 0 6d :2 0 26c
:4 0 1b84 2ef7 2ef9
:3 0 2eb1 2efa 0
2fb3 1ff :3 0 200
:3 0 50 :3 0 2efe
:4 0 2eff :2 0 2f16
1a9 :4 0 2f01 :3 0
8a :3 0 8f :2 0
1b89 2f04 2f05 :3 0
15 :3 0 9b :3 0
2f07 2f08 0 30
:2 0 2f09 2f0a 0
2f0c 1b8c 2f13 15
:3 0 9b :3 0 2f0d
2f0e 0 113 :2 0
2f0f 2f10 0 2f12
1b8e 2f14 2f06 2f0c
0 2f15 0 2f12
0 2f15 1b90 0
2f16 1b93 2f74 9d
:3 0 15 :3 0 9b
:3 0 2f18 2f19 0
9c :3 0 2f1a 2f1b
0 2f1d 1b96 2f1f
1b98 2f1e 2f1d :2 0
2f72 9e :3 0 15
:3 0 9b :3 0 2f22
2f23 0 9c :3 0
2f24 2f25 0 2f6a
65 :3 0 66 :3 0
2f27 2f28 0 65
:3 0 76 :3 0 2f2a
2f2b 0 9f :2 0
2 :4 0 26d :2 0
78 :2 0 27 :2 0
1b9a 2f30 2f32 :3 0
1b9d 2f2c 2f34 2f29
2f36 2f35 :2 0 68
:3 0 79 :3 0 2f38
2f39 0 6a :4 0
26e :4 0 6d :2 0
6e :3 0 1ba1 2f3d
2f3f :3 0 6d :2 0
82 :4 0 1ba4 2f41
2f43 :3 0 6d :2 0
a2 :4 0 1ba7 2f45
2f47 :3 0 6d :2 0
9c :3 0 1baa 2f49
2f4b :3 0 6d :2 0
a3 :4 0 1bad 2f4d
2f4f :3 0 6d :2 0
a4 :3 0 a5 :3 0
27 :2 0 a6 :2 0
1bb0 2f52 2f56 1bb4
2f51 2f58 :3 0 1bb7
2f3a 2f5a :2 0 2f67
68 :3 0 79 :3 0
2f5c 2f5d 0 6a
:4 0 20e :4 0 6d
:2 0 50 :3 0 1bba
2f61 2f63 :3 0 1bbd
2f5e 2f65 :2 0 2f67
1bc0 2f68 2f37 2f67
0 2f69 1bc3 0
2f6a 1bc5 2f6d :3 0
2f6d 0 2f6d 2f6c
2f6a 2f6b :6 0 2f6f
6f :3 0 1bc8 2f71
1bca 2f70 2f6f :2 0
2f72 1bcc :2 0 2f74
0 2f74 2f73 2f16
2f72 :6 0 2fb3 1
:3 0 50 :3 0 26f
:4 0 6d :2 0 270
:4 0 1bcf 2f78 2f7a
:3 0 6d :2 0 271
:4 0 1bd2 2f7c 2f7e
:3 0 6d :2 0 272
:4 0 1bd5 2f80 2f82
:3 0 6d :2 0 73
:3 0 72 :3 0 38
:3 0 30 :2 0 1bd8
2f86 2f89 1bdb 2f85
2f8b 1bdd 2f84 2f8d
:3 0 6d :2 0 273
:4 0 1be0 2f8f 2f91
:3 0 6d :2 0 73
:3 0 72 :3 0 3d
:3 0 30 :2 0 1be3
2f95 2f98 1be6 2f94
2f9a 1be8 2f93 2f9c
:3 0 6d :2 0 274
:4 0 1beb 2f9e 2fa0
:3 0 6d :2 0 243
:4 0 1bee 2fa2 2fa4
:3 0 6d :2 0 275
:4 0 1bf1 2fa6 2fa8
:3 0 6d :2 0 276
:4 0 1bf4 2faa 2fac
:3 0 6d :2 0 277
:4 0 1bf7 2fae 2fb0
:3 0 2f76 2fb1 0
2fb3 1bfa 2fb4 2d4f
2fb3 0 321f 1ff
:3 0 200 :3 0 252
:4 0 2fb7 :4 0 2fb8
:2 0 321c 15 :3 0
9b :3 0 2fba 2fbb
0 30 :2 0 2fbc
2fbd 0 321c 50
:3 0 253 :4 0 6d
:2 0 278 :4 0 1c07
2fc1 2fc3 :3 0 6d
:2 0 279 :4 0 1c0a
2fc5 2fc7 :3 0 6d
:2 0 27a :4 0 1c0d
2fc9 2fcb :3 0 6d
:2 0 27b :4 0 1c10
2fcd 2fcf :3 0 6d
:2 0 214 :4 0 1c13
2fd1 2fd3 :3 0 6d
:2 0 27c :4 0 1c16
2fd5 2fd7 :3 0 6d
:2 0 17 :3 0 1c19
2fd9 2fdb :3 0 6d
:2 0 27d :4 0 1c1c
2fdd 2fdf :3 0 6d
:2 0 27e :4 0 1c1f
2fe1 2fe3 :3 0 6d
:2 0 2c :3 0 1c22
2fe5 2fe7 :3 0 6d
:2 0 27f :4 0 1c25
2fe9 2feb :3 0 6d
:2 0 280 :4 0 1c28
2fed 2fef :3 0 2fbf
2ff0 0 321c 1ff
:3 0 200 :3 0 50
:3 0 2ff4 :4 0 2ff5
:2 0 300c 1a9 :4 0
2ff7 :3 0 8a :3 0
8f :2 0 1c2d 2ffa
2ffb :3 0 15 :3 0
9b :3 0 2ffd 2ffe
0 30 :2 0 2fff
3000 0 3002 1c30
3009 15 :3 0 9b
:3 0 3003 3004 0
113 :2 0 3005 3006
0 3008 1c32 300a
2ffc 3002 0 300b
0 3008 0 300b
1c34 0 300c 1c37
306a 9d :3 0 15
:3 0 9b :3 0 300e
300f 0 9c :3 0
3010 3011 0 3013
1c3a 3015 1c3c 3014
3013 :2 0 3068 9e
:3 0 15 :3 0 9b
:3 0 3018 3019 0
9c :3 0 301a 301b
0 3060 65 :3 0
66 :3 0 301d 301e
0 65 :3 0 76
:3 0 3020 3021 0
9f :2 0 2 :4 0
281 :2 0 78 :2 0
27 :2 0 1c3e 3026
3028 :3 0 1c41 3022
302a 301f 302c 302b
:2 0 68 :3 0 79
:3 0 302e 302f 0
6a :4 0 282 :4 0
6d :2 0 6e :3 0
1c45 3033 3035 :3 0
6d :2 0 82 :4 0
1c48 3037 3039 :3 0
6d :2 0 a2 :4 0
1c4b 303b 303d :3 0
6d :2 0 9c :3 0
1c4e 303f 3041 :3 0
6d :2 0 a3 :4 0
1c51 3043 3045 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 1c54 3048
304c 1c58 3047 304e
:3 0 1c5b 3030 3050
:2 0 305d 68 :3 0
79 :3 0 3052 3053
0 6a :4 0 20e
:4 0 6d :2 0 50
:3 0 1c5e 3057 3059
:3 0 1c61 3054 305b
:2 0 305d 1c64 305e
302d 305d 0 305f
1c67 0 3060 1c69
3063 :3 0 3063 0
3063 3062 3060 3061
:6 0 3065 71 :3 0
1c6c 3067 1c6e 3066
3065 :2 0 3068 1c70
:2 0 306a 0 306a
3069 300c 3068 :6 0
321c 1 :3 0 1ff
:3 0 200 :3 0 20f
:4 0 306e :4 0 306f
:2 0 321c 15 :3 0
9b :3 0 3071 3072
0 30 :2 0 3073
3074 0 321c 50
:3 0 25c :4 0 6d
:2 0 283 :4 0 1c73
3078 307a :3 0 6d
:2 0 284 :4 0 1c76
307c 307e :3 0 6d
:2 0 285 :4 0 1c79
3080 3082 :3 0 6d
:2 0 286 :4 0 1c7c
3084 3086 :3 0 6d
:2 0 261 :4 0 1c7f
3088 308a :3 0 6d
:2 0 17 :3 0 1c82
308c 308e :3 0 6d
:2 0 262 :4 0 1c85
3090 3092 :3 0 6d
:2 0 2c :3 0 1c88
3094 3096 :3 0 6d
:2 0 287 :4 0 1c8b
3098 309a :3 0 3076
309b 0 321c 1ff
:3 0 200 :3 0 50
:3 0 309f :4 0 30a0
:2 0 30b7 1a9 :4 0
30a2 :3 0 8a :3 0
8f :2 0 1c90 30a5
30a6 :3 0 15 :3 0
9b :3 0 30a8 30a9
0 30 :2 0 30aa
30ab 0 30ad 1c93
30b4 15 :3 0 9b
:3 0 30ae 30af 0
113 :2 0 30b0 30b1
0 30b3 1c95 30b5
30a7 30ad 0 30b6
0 30b3 0 30b6
1c97 0 30b7 1c9a
3115 9d :3 0 15
:3 0 9b :3 0 30b9
30ba 0 9c :3 0
30bb 30bc 0 30be
1c9d 30c0 1c9f 30bf
30be :2 0 3113 9e
:3 0 15 :3 0 9b
:3 0 30c3 30c4 0
9c :3 0 30c5 30c6
0 310b 65 :3 0
66 :3 0 30c8 30c9
0 65 :3 0 76
:3 0 30cb 30cc 0
9f :2 0 2 :4 0
288 :2 0 78 :2 0
27 :2 0 1ca1 30d1
30d3 :3 0 1ca4 30cd
30d5 30ca 30d7 30d6
:2 0 68 :3 0 79
:3 0 30d9 30da 0
6a :4 0 289 :4 0
6d :2 0 6e :3 0
1ca8 30de 30e0 :3 0
6d :2 0 82 :4 0
1cab 30e2 30e4 :3 0
6d :2 0 a2 :4 0
1cae 30e6 30e8 :3 0
6d :2 0 9c :3 0
1cb1 30ea 30ec :3 0
6d :2 0 a3 :4 0
1cb4 30ee 30f0 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 1cb7 30f3
30f7 1cbb 30f2 30f9
:3 0 1cbe 30db 30fb
:2 0 3108 68 :3 0
79 :3 0 30fd 30fe
0 6a :4 0 20e
:4 0 6d :2 0 50
:3 0 1cc1 3102 3104
:3 0 1cc4 30ff 3106
:2 0 3108 1cc7 3109
30d8 3108 0 310a
1cca 0 310b 1ccc
310e :3 0 310e 0
310e 310d 310b 310c
:6 0 3110 73 :3 0
1ccf 3112 1cd1 3111
3110 :2 0 3113 1cd3
:2 0 3115 0 3115
3114 30b7 3113 :6 0
321c 1 :3 0 15
:3 0 9b :3 0 3117
3118 0 21a :4 0
311a 311b :3 0 3119
311c 0 321c 50
:3 0 21b :4 0 6d
:2 0 266 :4 0 1cd6
3120 3122 :3 0 6d
:2 0 21e :4 0 1cd9
3124 3126 :3 0 6d
:2 0 28a :4 0 1cdc
3128 312a :3 0 6d
:2 0 28b :4 0 1cdf
312c 312e :3 0 6d
:2 0 28c :4 0 1ce2
3130 3132 :3 0 6d
:2 0 224 :4 0 1ce5
3134 3136 :3 0 6d
:2 0 28d :4 0 1ce8
3138 313a :3 0 6d
:2 0 28e :4 0 1ceb
313c 313e :3 0 6d
:2 0 227 :4 0 1cee
3140 3142 :3 0 6d
:2 0 17 :3 0 1cf1
3144 3146 :3 0 6d
:2 0 235 :4 0 1cf4
3148 314a :3 0 6d
:2 0 28f :4 0 1cf7
314c 314e :3 0 6d
:2 0 238 :4 0 1cfa
3150 3152 :3 0 6d
:2 0 239 :4 0 1cfd
3154 3156 :3 0 6d
:2 0 2c :3 0 1d00
3158 315a :3 0 6d
:2 0 26c :4 0 1d03
315c 315e :3 0 311e
315f 0 321c 1ff
:3 0 200 :3 0 50
:3 0 3163 :4 0 3164
:2 0 317b 1a9 :4 0
3166 :3 0 8a :3 0
8f :2 0 1d08 3169
316a :3 0 15 :3 0
9b :3 0 316c 316d
0 30 :2 0 316e
316f 0 3171 1d0b
3178 15 :3 0 9b
:3 0 3172 3173 0
113 :2 0 3174 3175
0 3177 1d0d 3179
316b 3171 0 317a
0 3177 0 317a
1d0f 0 317b 1d12
31d9 9d :3 0 15
:3 0 9b :3 0 317d
317e 0 9c :3 0
317f 3180 0 3182
1d15 3184 1d17 3183
3182 :2 0 31d7 9e
:3 0 15 :3 0 9b
:3 0 3187 3188 0
9c :3 0 3189 318a
0 31cf 65 :3 0
66 :3 0 318c 318d
0 65 :3 0 76
:3 0 318f 3190 0
9f :2 0 2 :4 0
290 :2 0 78 :2 0
27 :2 0 1d19 3195
3197 :3 0 1d1c 3191
3199 318e 319b 319a
:2 0 68 :3 0 79
:3 0 319d 319e 0
6a :4 0 291 :4 0
6d :2 0 6e :3 0
1d20 31a2 31a4 :3 0
6d :2 0 82 :4 0
1d23 31a6 31a8 :3 0
6d :2 0 a2 :4 0
1d26 31aa 31ac :3 0
6d :2 0 9c :3 0
1d29 31ae 31b0 :3 0
6d :2 0 a3 :4 0
1d2c 31b2 31b4 :3 0
6d :2 0 a4 :3 0
a5 :3 0 27 :2 0
a6 :2 0 1d2f 31b7
31bb 1d33 31b6 31bd
:3 0 1d36 319f 31bf
:2 0 31cc 68 :3 0
79 :3 0 31c1 31c2
0 6a :4 0 20e
:4 0 6d :2 0 50
:3 0 1d39 31c6 31c8
:3 0 1d3c 31c3 31ca
:2 0 31cc 1d3f 31cd
319c 31cc 0 31ce
1d42 0 31cf 1d44
31d2 :3 0 31d2 0
31d2 31d1 31cf 31d0
:6 0 31d4 75 :3 0
1d47 31d6 1d49 31d5
31d4 :2 0 31d7 1d4b
:2 0 31d9 0 31d9
31d8 317b 31d7 :6 0
321c 1 :3 0 50
:3 0 292 :4 0 6d
:2 0 270 :4 0 1d4e
31dd 31df :3 0 6d
:2 0 293 :4 0 1d51
31e1 31e3 :3 0 6d
:2 0 294 :4 0 1d54
31e5 31e7 :3 0 6d
:2 0 73 :3 0 72
:3 0 38 :3 0 30
:2 0 1d57 31eb 31ee
1d5a 31ea 31f0 1d5c
31e9 31f2 :3 0 6d
:2 0 24b :4 0 1d5f
31f4 31f6 :3 0 6d
:2 0 295 :4 0 1d62
31f8 31fa :3 0 6d
:2 0 73 :3 0 72
:3 0 3d :3 0 30
:2 0 1d65 31fe 3201
1d68 31fd 3203 1d6a
31fc 3205 :3 0 6d
:2 0 296 :4 0 1d6d
3207 3209 :3 0 6d
:2 0 297 :4 0 1d70
320b 320d :3 0 6d
:2 0 243 :4 0 1d73
320f 3211 :3 0 6d
:2 0 298 :4 0 1d76
3213 3215 :3 0 6d
:2 0 277 :4 0 1d79
3217 3219 :3 0 31db
321a 0 321c 1d7c
321e 2a34 2d43 0
321f 0 321c 0
321f 1d89 0 3266
65 :3 0 66 :3 0
3220 3221 0 65
:3 0 76 :3 0 3223
3224 0 27 :2 0
2 :4 0 299 :2 0
78 :2 0 27 :2 0
1d8d 3229 322b :3 0
1d90 3225 322d 3222
322f 322e :2 0 68
:3 0 79 :3 0 3231
3232 0 6a :4 0
29a :4 0 6d :2 0
6e :3 0 1d94 3236
3238 :3 0 1d97 3233
323a :2 0 323c 1d9a
323d 3230 323c 0
323e 1d9c 0 3266
65 :3 0 66 :3 0
323f 3240 0 65
:3 0 76 :3 0 3242
3243 0 27 :2 0
2 :4 0 29b :2 0
78 :2 0 27 :2 0
1d9e 3248 324a :3 0
1da1 3244 324c 3241
324e 324d :2 0 68
:3 0 79 :3 0 3250
3251 0 6a :4 0
29c :4 0 6d :2 0
6e :3 0 1da5 3255
3257 :3 0 1da8 3252
3259 :2 0 325b 1dab
325c 324f 325b 0
325d 1dad 0 3266
14 :3 0 88 :3 0
29d :3 0 325f 3260
0 50 :3 0 1daf
3261 3263 3264 :2 0
3266 1db1 3307 15
:3 0 29e :2 0 4
3267 3268 0 65
:3 0 66 :3 0 326a
326b 0 65 :3 0
76 :3 0 326d 326e
0 9f :2 0 2
:4 0 29f :2 0 78
:2 0 27 :2 0 1ddf
3273 3275 :3 0 1de2
326f 3277 326c 3279
3278 :2 0 68 :3 0
79 :3 0 327b 327c
0 6a :4 0 2a0
:4 0 6d :2 0 6e
:3 0 1de6 3280 3282
:3 0 1de9 327d 3284
:2 0 329d 68 :3 0
79 :3 0 3286 3287
0 6a :4 0 2a1
:4 0 6d :2 0 15
:3 0 2a2 :3 0 328c
328d 0 1dec 328b
328f :3 0 6d :2 0
e5 :4 0 1def 3291
3293 :3 0 6d :2 0
15 :3 0 2a3 :3 0
3296 3297 0 1df2
3295 3299 :3 0 1df5
3288 329b :2 0 329d
1df8 329e 327a 329d
0 329f 1dfb 0
32af 2a4 :3 0 64
:3 0 15 :3 0 2a2
:3 0 2a5 :3 0 15
:3 0 2a3 :3 0 5e
:3 0 99 :4 0 2a6
1 :a 0 32ab :2 0
32af 32a1 32a9 :2 0
14 :3 0 64 :3 0
32ad :2 0 32af 1dfd
32b1 1e01 32b0 32af
:2 0 3305 9e :3 0
15 :3 0 9b :3 0
32b4 32b5 0 9c
:3 0 32b6 32b7 0
32fd 65 :3 0 66
:3 0 32b9 32ba 0
65 :3 0 76 :3 0
32bc 32bd 0 9f
:2 0 2 :4 0 2a7
:2 0 78 :2 0 27
:2 0 1e03 32c2 32c4
:3 0 1e06 32be 32c6
32bb 32c8 32c7 :2 0
68 :3 0 79 :3 0
32ca 32cb 0 6a
:4 0 2a8 :4 0 6d
:2 0 6e :3 0 1e0a
32cf 32d1 :3 0 1e0d
32cc 32d3 :2 0 32ed
68 :3 0 79 :3 0
32d5 32d6 0 6a
:4 0 a2 :4 0 6d
:2 0 9c :3 0 1e10
32da 32dc :3 0 6d
:2 0 a3 :4 0 1e13
32de 32e0 :3 0 6d
:2 0 a4 :3 0 a5
:3 0 27 :2 0 a6
:2 0 1e16 32e3 32e7
1e1a 32e2 32e9 :3 0
1e1d 32d7 32eb :2 0
32ed 1e20 32ee 32c9
32ed 0 32ef 1e23
0 32fd 2a4 :3 0
64 :3 0 2a5 :3 0
15 :3 0 2a3 :3 0
5e :3 0 99 :4 0
2a9 1 :a 0 32f9
:2 0 32fd 32f1 32f7
:2 0 14 :3 0 64
:3 0 32fb :2 0 32fd
1e25 3300 :3 0 3300
0 3300 32ff 32fd
32fe :6 0 3302 1
:3 0 1e2a 3304 1e2c
3303 3302 :2 0 3305
1e2e :2 0 3307 1e31
3307 3306 3266 3305
:6 0 3308 :2 0 2
44 3307 330b :3 0
330a 3308 330c :8 0

1e76
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
79 1 77 1
80 1 7e 1
87 1 85 1
8c 1 91 1
98 1 96 1
9f 1 9d 1
a6 1 a4 1
ad 1 ab 1
b4 1 b2 1
bb 1 b9 1
c0 1 c6 1
cc 1 d2 1
d8 1 de 1
e4 1 ea 1
f0 1 f6 1
fc 1 102 1
108 1 10e 1
114 1 11a 1
120 1 126 1
12c 1 132 1
138 1 13e 1
144 1 14a 1
150 1 156 1
15c 1 162 1
16a 1 168 1
171 1 16f 1
176 1 17e 1
17c 1 183 1
18b 1 189 1
192 1 190 1
199 1 197 1
19e 1 1a4 1
1aa 1 1b2 1
1b0 1 1b9 1
1b7 1 1be 1
1c4 1 1cc 1
1ca 1 1d1 1
1d7 1 1dd 1
1e3 1 1e9 1
1ee 1 1fb 1
207 2 20a 20c
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 2 227
229 2 22b 22d
2 22f 231 2
233 235 2 237
239 2 23b 23d
1 243 2 245
246 2 23f 248
2 24a 24c 1
252 2 254 255
2 24e 257 2
259 25b 1 261
2 263 264 2
25d 266 2 268
26a 1 270 2
272 273 2 26c
275 2 277 279
1 27f 2 281
282 2 27b 284
2 286 288 1
28e 2 290 291
2 28a 293 2
295 297 1 29d
2 29f 2a0 2
299 2a2 2 2a4
2a6 1 2ac 2
2ae 2af 2 2a8
2b1 2 2b3 2b5
1 2bb 2 2bd
2be 2 2b7 2c0
2 2c2 2c4 1
2ca 2 2cc 2cd
2 2c6 2cf 2
2d1 2d3 2 2d5
2d7 2 2d9 2db
2 2dd 2df 2
2e1 2e3 2 2e5
2e7 2 2e9 2eb
2 2ed 2ef 2
2f1 2f3 4 203
209 20e 2f5 1
2f7 1 2f9 2
303 305 3 301
302 307 2 310
312 2 30f 314
1 316 1 318
2 350 351 1
353 1 360 2
36d 36f 3 36b
36c 371 2 37a
37c 2 37e 380
2 382 384 1
38c 2 38e 38f
2 386 391 2
379 393 1 395
1 397 2 3a1
3a3 3 39f 3a0
3a5 2 3ae 3b0
2 3ad 3b2 1
3b4 1 3b6 2
3bd 3be 3 398
3b7 3c0 1 3c2
1 3c4 2 3d1
3d3 3 3cf 3d0
3d5 2 3de 3e0
2 3e2 3e4 2
3e6 3e8 1 3f0
2 3f2 3f3 2
3ea 3f5 2 3dd
3f7 1 3f9 1
3fb 2 405 407
3 403 404 409
2 412 414 2
411 416 1 418
1 41a 2 421
422 3 3fc 41b
424 1 426 2
429 42a 1 42e
2 42c 42e 2
432 433 1 437
2 435 437 2
43d 43e 1 442
2 440 442 2
44f 451 3 44d
44e 453 2 45c
45e 2 460 462
2 464 466 1
46e 2 470 471
2 468 473 2
45b 475 1 477
1 479 2 483
485 3 481 482
487 2 490 492
2 48f 494 1
496 1 498 2
49f 4a0 3 47a
499 4a2 1 4a4
1 4a6 1 4ac
2 4bc 4c1 1
4c8 1 4c3 2
4db 4dd 3 4d9
4da 4df 2 4e8
4ea 2 4ec 4ee
2 4f0 4f2 2
4f4 4f6 2 4f8
4fa 3 4ff 500
501 2 4fc 503
2 4e7 505 1
507 1 509 2
4d2 50a 1 50e
1 4cd 2 4cb
512 1 51d 2
519 51d 2 522
523 1 527 2
525 527 2 535
537 3 533 534
539 2 542 544
2 546 548 2
54a 54c 1 554
2 556 557 2
54e 559 2 541
55b 1 55d 1
55f 2 569 56b
3 567 568 56d
2 576 578 2
575 57a 1 57c
1 57e 2 585
586 3 560 57f
588 1 58a 3
515 58b 58e 1
591 1 597 2
5a2 5a7 1 5ae
1 5a9 2 5c1
5c3 3 5bf 5c0
5c5 2 5ce 5d0
2 5d2 5d4 2
5d6 5d8 2 5da
5dc 2 5de 5e0
3 5e5 5e6 5e7
2 5e2 5e9 2
5cd 5eb 1 5ed
1 5ef 2 5b8
5f0 1 5f4 1
5b3 2 5b1 5f8
1 5fb 2 5ff
5fe 1 604 1
60b 1 60d 3
611 612 613 3
619 61a 61b 2
623 624 1 628
2 626 628 3
62e 62f 630 3
632 633 634 4
63c 63d 63e 63f
2 645 646 1
648 1 64c 2
64a 64c 2 65c
661 1 668 1
663 2 67b 67d
3 679 67a 67f
2 688 68a 2
68c 68e 2 690
692 2 694 696
2 698 69a 3
69f 6a0 6a1 2
69c 6a3 2 687
6a5 1 6a7 1
6a9 2 672 6aa
1 6ae 1 66d
2 66b 6b2 1
6b5 2 6fd 702
1 709 1 704
2 71c 71e 3
71a 71b 720 2
729 72b 2 72d
72f 2 731 733
2 735 737 2
739 73b 3 740
741 742 2 73d
744 2 728 746
1 748 1 74a
2 713 74b 1
74f 1 70e 2
70c 753 1 756
2 759 75a 1
762 2 75e 762
2 76d 772 1
779 1 774 2
78c 78e 3 78a
78b 790 2 799
79b 2 79d 79f
2 7a1 7a3 2
7a5 7a7 2 7a9
7ab 3 7b0 7b1
7b2 2 7ad 7b4
2 798 7b6 1
7b8 1 7ba 2
783 7bb 1 7bf
1 77e 2 77c
7c3 1 7ce 2
7ca 7ce 1 7d2
1 7d9 1 7db
2 7e8 7ed 1
7f4 1 7ef 2
807 809 3 805
806 80b 2 814
816 2 818 81a
2 81c 81e 2
820 822 2 824
826 3 82b 82c
82d 2 828 82f
2 813 831 1
833 1 835 2
7fe 836 1 83a
1 7f9 2 7f7
83e 2 7dc 841
2 84c 84e 3
84a 84b 850 2
859 85b 2 85d
85f 2 861 863
1 86b 2 86d
86e 2 865 870
2 872 874 2
876 878 2 87a
87c 2 87e 880
2 858 882 1
884 1 886 2
890 892 3 88e
88f 894 2 89d
89f 2 89c 8a1
1 8a3 1 8a5
3 8ac 8ad 8ae
3 887 8a6 8b0
2 8b2 8b3 2
7c6 8b4 1 8b8
2 8ba 8bb 2
8c5 8ca 1 8d1
1 8cc 2 8e4
8e6 3 8e2 8e3
8e8 2 8f1 8f3
2 8f5 8f7 2
8f9 8fb 2 8fd
8ff 2 901 903
3 908 909 90a
2 905 90c 2
8f0 90e 1 910
1 912 2 8db
913 1 917 1
8d6 2 8d4 91b
2 921 922 1
926 2 924 926
2 92e 933 1
93a 1 935 2
94d 94f 3 94b
94c 951 2 95a
95c 2 95e 960
2 962 964 2
966 968 2 96a
96c 3 971 972
973 2 96e 975
2 959 977 1
979 1 97b 2
944 97c 1 980
1 93f 2 93d
984 2 98c 98d
1 991 2 98f
991 2 99c 99e
3 99a 99b 9a0
2 9a9 9ab 2
9ad 9af 2 9b1
9b3 1 9bb 2
9bd 9be 2 9b5
9c0 2 9c2 9c4
2 9c6 9c8 2
9ca 9cc 2 9ce
9d0 2 9a8 9d2
1 9d4 1 9d6
2 9e0 9e2 3
9de 9df 9e4 2
9ed 9ef 2 9ec
9f1 1 9f3 1
9f5 3 9fc 9fd
9fe 3 9d7 9f6
a00 1 a02 2
987 a03 1 a05
7 637 642 75b
8bc 8bf 91e a06
2 a13 a18 1
a1f 1 a1a 2
a32 a34 3 a30
a31 a36 2 a3f
a41 2 a43 a45
2 a47 a49 2
a4b a4d 2 a4f
a51 3 a56 a57
a58 2 a53 a5a
2 a3e a5c 1
a5e 1 a60 2
a29 a61 1 a65
1 a24 2 a22
a69 1 a74 2
a70 a74 2 a7d
a82 1 a89 1
a84 2 a9c a9e
3 a9a a9b aa0
2 aa9 aab 2
aad aaf 2 ab1
ab3 2 ab5 ab7
2 ab9 abb 3
ac0 ac1 ac2 2
abd ac4 2 aa8
ac6 1 ac8 1
aca 2 a93 acb
1 acf 1 a8e
2 a8c ad3 1
ade 2 ada ade
2 aea aec 3
ae8 ae9 aee 2
af7 af9 2 afb
afd 2 aff b01
1 b09 2 b0b
b0c 2 b03 b0e
2 b10 b12 2
b14 b16 2 b18
b1a 2 b1c b1e
2 af6 b20 1
b22 1 b24 2
b2e b30 3 b2c
b2d b32 2 b3b
b3d 2 b3a b3f
1 b41 1 b43
3 b4a b4b b4c
3 b25 b44 b4e
1 b50 2 ad6
b51 1 b53 2
a6c b54 2 b56
b57 2 b5a b5b
1 b61 2 b5d
b61 2 b65 b66
1 b6c 2 b68
b6c 2 b73 b74
1 b78 2 b76
b78 2 b7f b80
1 b86 2 b82
b86 2 b8a b8b
1 b91 2 b8d
b91 1 b98 1
b9a 3 b9b b9e
ba1 1 ba5 2
ba3 ba5 2 bb3
bb4 2 bb8 bb9
2 bbd bbe 2
bc2 bc3 2 bc7
bc8 2 bcc bcd
2 bd1 bd2 2
bd6 bd7 d bb0
bb1 bb6 bbb bc0
bc5 bca bcf bd4
bd9 bda bdb bdc
2 be1 be2 1
be8 2 be4 be8
2 bf3 bf5 3
bf1 bf2 bf7 2
c00 c02 2 c04
c06 2 c08 c0a
1 c12 2 c14
c15 2 c0c c17
2 bff c19 1
c1b 1 c1d 2
c27 c29 3 c25
c26 c2b 2 c34
c36 2 c33 c38
1 c3a 1 c3c
2 c43 c44 3
c1e c3d c46 2
c4a c4b 1 c4f
2 c4d c4f 2
c5a c5c 3 c58
c59 c5e 2 c67
c69 2 c6b c6d
2 c6f c71 1
c77 2 c79 c7a
2 c73 c7c 2
c7e c80 2 c82
c84 2 c86 c88
2 c8a c8c 2
c66 c8e 1 c90
1 c92 2 c9c
c9e 3 c9a c9b
ca0 2 ca9 cab
2 ca8 cad 1
caf 1 cb1 2
cb7 cb8 3 cba
cbb cbc 3 c93
cb2 cbe 2 cc1
cc0 1 cc6 1
ccd 1 ccf 6
baa bad bdf cc2
cc5 cd0 2 cd6
cd7 1 cdb 2
cd9 cdb 2 ce0
ce1 2 ce6 ce7
2 ce3 ce9 1
cec 1 cee 2
cd4 cef 2 cf1
cf2 2 cf5 cf6
1 cfa 2 cf8
cfa 2 cff d00
1 d04 2 d02
d04 2 d0b d0c
1 d10 2 d0e
d10 2 d15 d16
1 d1a 2 d18
d1a 1 d22 2
d26 d27 1 d2b
2 d29 d2b 1
d30 2 d35 d36
1 d3a 2 d38
d3a 2 d3f d40
1 d44 2 d42
d44 1 d4c 2
d51 d52 1 d56
2 d54 d56 1
d5b 4 d5e d33
d4f d5d 1 d5f
1 d61 2 cf3
d62 2 d64 d65
2 d78 d79 2
d7b d7e 2 d81
d82 2 d89 d8a
2 d8c d8f 2
d94 d95 1 d99
2 d97 d99 6
d9e d9f da0 da1
da2 da3 2 da8
da9 1 daf 2
dab daf 2 db3
db4 1 db8 2
db6 db8 1 dbf
1 dc1 2 dcb
dcd 3 dc9 dca
dcf 2 dd8 dda
2 ddc dde 2
de0 de2 1 de8
2 dea deb 2
de4 ded 2 def
df1 2 df3 df5
2 df7 df9 2
dfb dfd 2 dd7
dff 1 e01 1
e03 2 e0d e0f
3 e0b e0c e11
2 e1a e1c 2
e19 e1e 1 e20
1 e22 2 e28
e29 3 e2b e2c
e2d 4 dc2 e04
e23 e2f 1 e31
2 e34 e35 1
e39 2 e37 e39
2 e3d e3e 1
e42 2 e40 e42
2 e4f e51 3
e4d e4e e53 2
e5c e5e 2 e60
e62 2 e64 e66
1 e6c 2 e6e
e6f 2 e68 e71
2 e73 e75 2
e77 e79 2 e7b
e7d 2 e7f e81
2 e5b e83 1
e85 1 e87 2
e91 e93 3 e8f
e90 e95 2 e9e
ea0 2 e9d ea2
1 ea4 1 ea6
2 eac ead 3
eaf eb0 eb1 3
e88 ea7 eb3 1
eb5 2 ece ed3
1 eda 1 ed5
2 eed eef 3
eeb eec ef1 2
efa efc 2 efe
f00 2 f02 f04
2 f06 f08 2
f0a f0c 3 f11
f12 f13 2 f0e
f15 2 ef9 f17
1 f19 1 f1b
2 ee4 f1c 1
f20 1 edf 2
edd f24 1 f2f
2 f2b f2f 1
f33 2 f3f f40
1 f44 2 f42
f44 1 f49 1
f4b 2 f3d f4c
1 f4e 1 f58
2 f56 f58 3
f5c f5d f5e 1
f62 2 f60 f62
2 f87 f8c 1
f93 1 f8e 2
fa6 fa8 3 fa4
fa5 faa 2 fb3
fb5 2 fb7 fb9
2 fbb fbd 2
fbf fc1 2 fc3
fc5 3 fca fcb
fcc 2 fc7 fce
2 fb2 fd0 1
fd2 1 fd4 2
f9d fd5 1 fd9
1 f98 2 f96
fdd 1 fe8 2
fe4 fe8 2 ff0
ff1 1 ff5 2
ff3 ff5 2 ffa
ffb 1 fff 2
ffd fff 2 1025
102a 1 1031 1
102c 2 1044 1046
3 1042 1043 1048
2 1051 1053 2
1055 1057 2 1059
105b 2 105d 105f
2 1061 1063 3
1068 1069 106a 2
1065 106c 2 1050
106e 1 1070 1
1072 2 103b 1073
1 1077 1 1036
2 1034 107b 1
107e 1 1083 2
1085 1086 2 fee
1087 1 1090 2
108c 1090 2 1095
1096 1 109a 2
1098 109a 2 10c0
10c5 1 10cc 1
10c7 2 10df 10e1
3 10dd 10de 10e3
2 10ec 10ee 2
10f0 10f2 2 10f4
10f6 2 10f8 10fa
2 10fc 10fe 3
1103 1104 1105 2
1100 1107 2 10eb
1109 1 110b 1
110d 2 10d6 110e
1 1112 1 10d1
2 10cf 1116 1
1119 2 111d 111c
2 fe0 111e 2
1140 1145 1 114c
1 1147 2 115f
1161 3 115d 115e
1163 2 116c 116e
2 1170 1172 2
1174 1176 2 1178
117a 2 117c 117e
3 1183 1184 1185
2 1180 1187 2
116b 1189 1 118b
1 118d 2 1156
118e 1 1192 1
1151 2 114f 1196
1 1199 2 119c
119d 1 119e 3
11a1 11a2 11a3 1
11a7 2 11a5 11a7
2 11c3 11c8 1
11cf 1 11ca 2
11e2 11e4 3 11e0
11e1 11e6 2 11ef
11f1 2 11f3 11f5
2 11f7 11f9 2
11fb 11fd 2 11ff
1201 3 1206 1207
1208 2 1203 120a
2 11ee 120c 1
120e 1 1210 2
11d9 1211 1 1215
1 11d4 2 11d2
1219 1 1224 2
1220 1224 2 122c
122d 1 1231 2
122f 1231 2 1236
1237 1 123b 2
1239 123b 2 1255
125a 1 1261 1
125c 2 1274 1276
3 1272 1273 1278
2 1281 1283 2
1285 1287 2 1289
128b 2 128d 128f
2 1291 1293 3
1298 1299 129a 2
1295 129c 2 1280
129e 1 12a0 1
12a2 2 126b 12a3
1 12a7 1 1266
2 1264 12ab 1
12ae 2 12b3 12b4
2 12b6 12b7 2
122a 12b8 1 12c1
2 12bd 12c1 2
12dc 12e1 1 12e8
1 12e3 2 12fb
12fd 3 12f9 12fa
12ff 2 1308 130a
2 130c 130e 2
1310 1312 2 1314
1316 2 1318 131a
3 131f 1320 1321
2 131c 1323 2
1307 1325 1 1327
1 1329 2 12f2
132a 1 132e 1
12ed 2 12eb 1332
1 1335 2 1339
1338 2 121c 133a
2 1353 1358 1
135f 1 135a 2
1372 1374 3 1370
1371 1376 2 137f
1381 2 1383 1385
2 1387 1389 2
138b 138d 2 138f
1391 3 1396 1397
1398 2 1393 139a
2 137e 139c 1
139e 1 13a0 2
1369 13a1 1 13a5
1 1364 2 1362
13a9 1 13ac 2
13af 13b0 1 13b1
2 13b3 13b4 1
13bc 2 13b8 13bc
2 13c1 13c2 1
13c6 2 13c4 13c6
2 13d1 13d3 3
13cf 13d0 13d5 2
13de 13e0 2 13e2
13e4 2 13e6 13e8
1 13f0 2 13f2
13f3 2 13ea 13f5
2 13f7 13f9 2
13fb 13fd 2 13ff
1401 2 1403 1405
2 13dd 1407 1
1409 1 140b 2
1415 1417 3 1413
1414 1419 2 1422
1424 2 1421 1426
1 1428 1 142a
3 1431 1432 1433
3 140c 142b 1435
1 1438 2 143e
143f 1 1443 2
1441 1443 1 144a
2 1448 144a 2
145f 1464 1 146b
1 1466 2 147e
1480 3 147c 147d
1482 2 148b 148d
2 148f 1491 2
1493 1495 2 1497
1499 2 149b 149d
3 14a2 14a3 14a4
2 149f 14a6 2
148a 14a8 1 14aa
1 14ac 2 1475
14ad 1 14b1 1
1470 2 146e 14b5
2 144f 14b8 2
14ca 14cf 1 14d6
1 14d1 2 14e9
14eb 3 14e7 14e8
14ed 2 14f6 14f8
2 14fa 14fc 2
14fe 1500 2 1502
1504 2 1506 1508
3 150d 150e 150f
2 150a 1511 2
14f5 1513 1 1515
1 1517 2 14e0
1518 1 151c 1
14db 2 14d9 1520
2 14bd 1523 2
1526 1527 2 152a
152b 2 1530 1531
1 1533 2 152d
1533 2 153e 1540
3 153c 153d 1542
2 154b 154d 2
154f 1551 2 1553
1555 1 155d 2
155f 1560 2 1557
1562 2 1564 1566
2 1568 156a 2
156c 156e 2 1570
1572 2 154a 1574
1 1576 1 1578
2 1582 1584 3
1580 1581 1586 2
158f 1591 2 158e
1593 1 1595 1
1597 3 159e 159f
15a0 3 1579 1598
15a2 1 15a4 2
1528 15a5 2 15a8
15a7 2 15a9 15ac
2 15b0 15b1 1
15b5 2 15b3 15b5
2 15bb 15bc 1
15be 1 15c3 2
15c1 15c3 2 15d0
15d2 3 15ce 15cf
15d4 2 15dd 15df
2 15e1 15e3 2
15e5 15e7 1 15ef
2 15f1 15f2 2
15e9 15f4 2 15f6
15f8 2 15fa 15fc
2 15fe 1600 2
1602 1604 2 15dc
1606 1 1608 1
160a 2 1614 1616
3 1612 1613 1618
2 1621 1623 2
1620 1625 1 1627
1 1629 3 1630
1631 1632 3 160b
162a 1634 2 1637
1636 3 163a 163b
163c 1 1640 2
163e 1640 2 1645
1647 3 1649 164a
164b 2 1664 1669
1 1670 1 166b
2 1683 1685 3
1681 1682 1687 2
1690 1692 2 1694
1696 2 1698 169a
2 169c 169e 2
16a0 16a2 3 16a7
16a8 16a9 2 16a4
16ab 2 168f 16ad
1 16af 1 16b1
2 167a 16b2 1
16b6 1 1675 2
1673 16ba 1 16c5
2 16c1 16c5 2
16d1 16d3 3 16cf
16d0 16d5 2 16de
16e0 2 16e2 16e4
2 16e6 16e8 1
16f0 2 16f2 16f3
2 16ea 16f5 2
16f7 16f9 2 16fb
16fd 2 16ff 1701
2 1703 1705 2
16dd 1707 1 1709
1 170b 2 1715
1717 3 1713 1714
1719 2 1722 1724
2 1721 1726 1
1728 1 172a 3
1731 1732 1733 3
170c 172b 1735 1
1737 3 173a 173b
173c 1 1740 2
173e 1740 2 1745
1746 1 174a 2
1748 174a 2 174f
1750 2 1755 1756
1 1758 2 1752
1758 2 1769 176b
3 1767 1768 176d
2 1776 1778 2
177a 177c 2 177e
1780 1 1788 2
178a 178b 2 1782
178d 2 178f 1791
2 1793 1795 2
1797 1799 2 179b
179d 2 1775 179f
1 17a1 1 17a3
2 17ad 17af 3
17ab 17ac 17b1 2
17ba 17bc 2 17b9
17be 1 17c0 1
17c2 3 17c9 17ca
17cb 3 17a4 17c3
17cd 1 17cf 2
17dd 17e2 1 17e9
1 17e4 2 17fc
17fe 3 17fa 17fb
1800 2 1809 180b
2 180d 180f 2
1811 1813 2 1815
1817 2 1819 181b
3 1820 1821 1822
2 181d 1824 2
1808 1826 1 1828
1 182a 2 17f3
182b 1 182f 1
17ee 2 17ec 1833
5 164e 16bd 1738
17d0 1836 2 183b
183d 3 183f 1840
1841 2 184a 184f
1 1856 1 1851
2 1869 186b 3
1867 1868 186d 2
1876 1878 2 187a
187c 2 187e 1880
2 1882 1884 2
1886 1888 3 188d
188e 188f 2 188a
1891 2 1875 1893
1 1895 1 1897
2 1860 1898 1
189c 1 185b 2
1859 18a0 1 18ab
2 18a7 18ab 2
18b7 18b9 3 18b5
18b6 18bb 2 18c4
18c6 2 18c8 18ca
2 18cc 18ce 1
18d6 2 18d8 18d9
2 18d0 18db 2
18dd 18df 2 18e1
18e3 2 18e5 18e7
2 18e9 18eb 2
18c3 18ed 1 18ef
1 18f1 2 18fb
18fd 3 18f9 18fa
18ff 2 1908 190a
2 1907 190c 1
190e 1 1910 3
1917 1918 1919 3
18f2 1911 191b 1
191d 2 1933 1938
1 193f 1 193a
2 1952 1954 3
1950 1951 1956 2
195f 1961 2 1963
1965 2 1967 1969
2 196b 196d 2
196f 1971 3 1976
1977 1978 2 1973
197a 2 195e 197c
1 197e 1 1980
2 1949 1981 1
1985 1 1944 2
1942 1989 1 1994
2 1990 1994 2
1999 199a 1 199e
2 199c 199e 2
19ac 19ae 3 19aa
19ab 19b0 2 19b9
19bb 2 19bd 19bf
2 19c1 19c3 1
19cb 2 19cd 19ce
2 19c5 19d0 2
19d2 19d4 2 19d6
19d8 2 19da 19dc
2 19de 19e0 2
19b8 19e2 1 19e4
1 19e6 2 19f0
19f2 3 19ee 19ef
19f4 2 19fd 19ff
2 19fc 1a01 1
1a03 1 1a05 3
1a0c 1a0d 1a0e 3
19e7 1a06 1a10 1
1a12 2 1a20 1a25
1 1a2c 1 1a27
2 1a3f 1a41 3
1a3d 1a3e 1a43 2
1a4c 1a4e 2 1a50
1a52 2 1a54 1a56
2 1a58 1a5a 2
1a5c 1a5e 3 1a63
1a64 1a65 2 1a60
1a67 2 1a4b 1a69
1 1a6b 1 1a6d
2 1a36 1a6e 1
1a72 1 1a31 2
1a2f 1a76 6 1844
18a3 191e 198c 1a13
1a79 2 1a7c 1a7d
2 1a83 1a84 1
1a88 2 1a86 1a88
2 1a95 1a9a 1
1aa1 1 1a9c 2
1ab4 1ab6 3 1ab2
1ab3 1ab8 2 1ac1
1ac3 2 1ac5 1ac7
2 1ac9 1acb 2
1acd 1acf 2 1ad1
1ad3 3 1ad8 1ad9
1ada 2 1ad5 1adc
2 1ac0 1ade 1
1ae0 1 1ae2 2
1aab 1ae3 1 1ae7
1 1aa6 2 1aa4
1aeb 2 1afa 1aff
1 1b06 1 1b01
2 1b19 1b1b 3
1b17 1b18 1b1d 2
1b26 1b28 2 1b2a
1b2c 2 1b2e 1b30
2 1b32 1b34 2
1b36 1b38 3 1b3d
1b3e 1b3f 2 1b3a
1b41 2 1b25 1b43
1 1b45 1 1b47
2 1b10 1b48 1
1b4c 1 1b0b 2
1b09 1b50 2 1b5c
1b5d 1 1b61 2
1b5f 1b61 1 1b66
1 1b68 21 1b6c
1b6d 1b6e 1b6f 1b70
1b71 1b72 1b73 1b74
1b75 1b76 1b77 1b78
1b79 1b7a 1b7b 1b7c
1b7d 1b7e 1b7f 1b80
1b81 1b82 1b83 1b84
1b85 1b86 1b87 1b88
1b89 1b8a 1b8b 1b8c
1 1b92 2 1b90
1b92 2 1b96 1b97
1 1b9b 2 1b99
1b9b 1 1ba5 2
1ba4 1ba5 1 1bad
1 1bb3 2 1bb5
1bb6 2 1ba2 1bb7
1 1bbe 1 1bb9
2 1bd1 1bd3 3
1bcf 1bd0 1bd5 2
1bde 1be0 2 1be2
1be4 2 1be6 1be8
2 1bea 1bec 2
1bee 1bf0 3 1bf5
1bf6 1bf7 2 1bf2
1bf9 2 1bdd 1bfb
1 1bfd 1 1bff
2 1bc8 1c00 1
1c04 1 1bc3 2
1bc1 1c08 1 1c0b
1 1c15 2 1c14
1c15 1 1c1d 1
1c23 2 1c25 1c26
2 1c12 1c27 1
1c2e 1 1c29 2
1c41 1c43 3 1c3f
1c40 1c45 2 1c4e
1c50 2 1c52 1c54
2 1c56 1c58 2
1c5a 1c5c 2 1c5e
1c60 3 1c65 1c66
1c67 2 1c62 1c69
2 1c4d 1c6b 1
1c6d 1 1c6f 2
1c38 1c70 1 1c74
1 1c33 2 1c31
1c78 1 1c7b 2
1c7e 1c7f 1 1c80
1 1c82 7 1aee
1b53 1b57 1b5a 1b69
1b8f 1c83 3 1c8c
1c8d 1c8e 1 1c92
2 1c90 1c92 1
1c99 2 1c9e 1c9f
2 1ca1 1ca4 1
1ca7 2 1ca9 1caa
21 1cae 1caf 1cb0
1cb1 1cb2 1cb3 1cb4
1cb5 1cb6 1cb7 1cb8
1cb9 1cba 1cbb 1cbc
1cbd 1cbe 1cbf 1cc0
1cc1 1cc2 1cc3 1cc4
1cc5 1cc6 1cc7 1cc8
1cc9 1cca 1ccb 1ccc
1ccd 1cce 1 1cd4
2 1cd2 1cd4 1
1cde 2 1cdd 1cde
1 1ce6 1 1cec
2 1cee 1cef 2
1cdb 1cf0 1 1cf7
1 1cf2 2 1d0a
1d0c 3 1d08 1d09
1d0e 2 1d17 1d19
2 1d1b 1d1d 2
1d1f 1d21 2 1d23
1d25 2 1d27 1d29
3 1d2e 1d2f 1d30
2 1d2b 1d32 2
1d16 1d34 1 1d36
1 1d38 2 1d01
1d39 1 1d3d 1
1cfc 2 1cfa 1d41
1 1d44 1 1d47
5 1c87 1c8a 1cab
1cd1 1d48 2 1d4a
1d4b d da6 e32
eb6 eb9 f27 f4f
f52 f55 13b5 1638
1a7e 1a81 1d4c 1
1d50 2 1d52 1d53
1 1d57 2 1d55
1d57 1 1d5c 1
1d62 2 1d64 1d65
2 1d67 1d69 2
1d6c 1d6e 1 1d70
1 1d73 2 1d75
1d76 1 1d7a 2
1d78 1d7a 2 1d82
1d83 1 1d86 2
1d85 1d86 2 1d96
1d97 2 1d99 1d9b
2 1d9d 1d9f 4
1d93 1d94 1da1 1da2
2 1dad 1dae 2
1db0 1db2 2 1db4
1db6 2 1db8 1dba
4 1daa 1dab 1dbc
1dbd 2 1ddb 1de0
1 1de7 1 1de2
2 1dfa 1dfc 3
1df8 1df9 1dfe 2
1e07 1e09 2 1e0b
1e0d 2 1e0f 1e11
2 1e13 1e15 2
1e17 1e19 3 1e1e
1e1f 1e20 2 1e1b
1e22 2 1e06 1e24
1 1e26 1 1e28
2 1df1 1e29 1
1e2d 1 1dec 2
1dea 1e31 2 1e37
1e38 1 1e3c 2
1e3a 1e3c 1 1e40
2 1e4e 1e4f 1
1e53 2 1e51 1e53
1 1e58 1 1e5a
2 1e4a 1e5b 1
1e5d 3 1e60 1e61
1e62 1 1e66 2
1e64 1e66 1 1e70
2 1e72 1e73 1
1e77 2 1e75 1e77
1 1e7c 2 1e80
1e82 3 1e84 1e85
1e86 2 1e8c 1e8e
3 1e90 1e91 1e92
2 1e89 1e95 2
1e97 1e98 2 1e6d
1e99 1 1e9d 2
1e9f 1ea0 1 1ea4
2 1ea2 1ea4 1
1ea9 2 1ead 1eaf
3 1eb1 1eb2 1eb3
2 1eb9 1ebb 3
1ebd 1ebe 1ebf 2
1eb6 1ec2 2 1ec4
1ec5 1 1ec6 2
1ec8 1ec9 2 1ed2
1ed3 1 1ed7 2
1ed5 1ed7 1 1edc
2 1eda 1edc 3
1ee0 1ee1 1ee2 1
1ee6 2 1ee4 1ee6
2 1f05 1f0a 1
1f11 1 1f0c 2
1f24 1f26 3 1f22
1f23 1f28 2 1f31
1f33 2 1f35 1f37
2 1f39 1f3b 2
1f3d 1f3f 2 1f41
1f43 3 1f48 1f49
1f4a 2 1f45 1f4c
2 1f30 1f4e 1
1f50 1 1f52 2
1f1b 1f53 1 1f57
1 1f16 2 1f14
1f5b 1 1f66 2
1f62 1f66 2 1f6e
1f6f 1 1f73 2
1f71 1f73 2 1f78
1f79 1 1f7d 2
1f7b 1f7d 2 1f9d
1fa2 1 1fa9 1
1fa4 2 1fbc 1fbe
3 1fba 1fbb 1fc0
2 1fc9 1fcb 2
1fcd 1fcf 2 1fd1
1fd3 2 1fd5 1fd7
2 1fd9 1fdb 3
1fe0 1fe1 1fe2 2
1fdd 1fe4 2 1fc8
1fe6 1 1fe8 1
1fea 2 1fb3 1feb
1 1fef 1 1fae
2 1fac 1ff3 1
1ff6 1 1ffb 2
1ffd 1ffe 2 1f6c
1fff 1 2008 2
2004 2008 2 200d
200e 1 2012 2
2010 2012 2 2032
2037 1 203e 1
2039 2 2051 2053
3 204f 2050 2055
2 205e 2060 2
2062 2064 2 2066
2068 2 206a 206c
2 206e 2070 3
2075 2076 2077 2
2072 2079 2 205d
207b 1 207d 1
207f 2 2048 2080
1 2084 1 2043
2 2041 2088 1
208b 2 208f 208e
2 1f5e 2090 2
20ae 20b3 1 20ba
1 20b5 2 20cd
20cf 3 20cb 20cc
20d1 2 20da 20dc
2 20de 20e0 2
20e2 20e4 2 20e6
20e8 2 20ea 20ec
3 20f1 20f2 20f3
2 20ee 20f5 2
20d9 20f7 1 20f9
1 20fb 2 20c4
20fc 1 2100 1
20bf 2 20bd 2104
1 2107 2 210a
210b 1 210c 3
210f 2110 2111 1
2115 2 2113 2115
2 2133 2138 1
213f 1 213a 2
2152 2154 3 2150
2151 2156 2 215f
2161 2 2163 2165
2 2167 2169 2
216b 216d 2 216f
2171 3 2176 2177
2178 2 2173 217a
2 215e 217c 1
217e 1 2180 2
2149 2181 1 2185
1 2144 2 2142
2189 1 2194 2
2190 2194 2 2199
219a 1 219e 2
219c 219e 2 21a3
21a4 1 21a8 2
21a6 21a8 2 21c4
21c9 1 21d0 1
21cb 2 21e3 21e5
3 21e1 21e2 21e7
2 21f0 21f2 2
21f4 21f6 2 21f8
21fa 2 21fc 21fe
2 2200 2202 3
2207 2208 2209 2
2204 220b 2 21ef
220d 1 220f 1
2211 2 21da 2212
1 2216 1 21d5
2 21d3 221a 1
221d 2 2222 2223
2 2225 2226 1
2227 1 2230 2
222c 2230 2 224d
2252 1 2259 1
2254 2 226c 226e
3 226a 226b 2270
2 2279 227b 2
227d 227f 2 2281
2283 2 2285 2287
2 2289 228b 3
2290 2291 2292 2
228d 2294 2 2278
2296 1 2298 1
229a 2 2263 229b
1 229f 1 225e
2 225c 22a3 1
22a6 2 22aa 22a9
2 218c 22ab 2
22c6 22cb 1 22d2
1 22cd 2 22e5
22e7 3 22e3 22e4
22e9 2 22f2 22f4
2 22f6 22f8 2
22fa 22fc 2 22fe
2300 2 2302 2304
3 2309 230a 230b
2 2306 230d 2
22f1 230f 1 2311
1 2313 2 22dc
2314 1 2318 1
22d7 2 22d5 231c
1 231f 2 2322
2323 1 2324 2
2326 2327 1 232f
2 232b 232f 2
2334 2335 1 2339
2 2337 2339 1
233e 1 2340 1
2347 2 2345 2347
2 235c 2361 1
2368 1 2363 2
237b 237d 3 2379
237a 237f 2 2388
238a 2 238c 238e
2 2390 2392 2
2394 2396 2 2398
239a 3 239f 23a0
23a1 2 239c 23a3
2 2387 23a5 1
23a7 1 23a9 2
2372 23aa 1 23ae
1 236d 2 236b
23b2 2 234c 23b5
2 23c7 23cc 1
23d3 1 23ce 2
23e6 23e8 3 23e4
23e5 23ea 2 23f3
23f5 2 23f7 23f9
2 23fb 23fd 2
23ff 2401 2 2403
2405 3 240a 240b
240c 2 2407 240e
2 23f2 2410 1
2412 1 2414 2
23dd 2415 1 2419
1 23d8 2 23d6
241d 2 23ba 2420
2 2423 2424 2
2427 2428 2 242d
242e 1 2430 2
242a 2430 2 2435
2436 2 2438 243a
2 243d 243f 1
2441 2 2425 2442
1 2444 2 2445
2448 2 244a 244b
1 244c 2 2450
2451 2 2453 2455
2 2458 245a 2
245c 245d 2 246f
2474 1 247b 1
2476 2 248e 2490
3 248c 248d 2492
2 249b 249d 2
249f 24a1 2 24a3
24a5 2 24a7 24a9
2 24ab 24ad 3
24b2 24b3 24b4 2
24af 24b6 2 249a
24b8 1 24ba 1
24bc 2 2485 24bd
1 24c1 1 2480
2 247e 24c5 2
24d4 24d9 1 24e0
1 24db 2 24f3
24f5 3 24f1 24f2
24f7 2 2500 2502
2 2504 2506 2
2508 250a 2 250c
250e 2 2510 2512
3 2517 2518 2519
2 2514 251b 2
24ff 251d 1 251f
1 2521 2 24ea
2522 1 2526 1
24e5 2 24e3 252a
2 2536 2537 1
253b 2 2539 253b
1 2540 1 2542
21 2546 2547 2548
2549 254a 254b 254c
254d 254e 254f 2550
2551 2552 2553 2554
2555 2556 2557 2558
2559 255a 255b 255c
255d 255e 255f 2560
2561 2562 2563 2564
2565 2566 1 256c
2 256a 256c 2
2570 2571 1 2575
2 2573 2575 1
257f 2 257e 257f
1 2587 1 258d
2 258f 2590 2
257c 2591 1 2598
1 2593 2 25ab
25ad 3 25a9 25aa
25af 2 25b8 25ba
2 25bc 25be 2
25c0 25c2 2 25c4
25c6 2 25c8 25ca
3 25cf 25d0 25d1
2 25cc 25d3 2
25b7 25d5 1 25d7
1 25d9 2 25a2
25da 1 25de 1
259d 2 259b 25e2
1 25e5 1 25ef
2 25ee 25ef 1
25f7 1 25fd 2
25ff 2600 2 25ec
2601 1 2608 1
2603 2 261b 261d
3 2619 261a 261f
2 2628 262a 2
262c 262e 2 2630
2632 2 2634 2636
2 2638 263a 3
263f 2640 2641 2
263c 2643 2 2627
2645 1 2647 1
2649 2 2612 264a
1 264e 1 260d
2 260b 2652 1
2655 2 2658 2659
1 265a 1 265c
b 2328 245e 2461
2464 24c8 252d 2531
2534 2543 2569 265d
2 2661 2662 1
2666 2 2664 2666
3 2670 2671 2672
1 2676 2 2674
2676 1 267d 2
2681 2682 1 2685
2 2687 2688 21
268c 268d 268e 268f
2690 2691 2692 2693
2694 2695 2696 2697
2698 2699 269a 269b
269c 269d 269e 269f
26a0 26a1 26a2 26a3
26a4 26a5 26a6 26a7
26a8 26a9 26aa 26ab
26ac 1 26b2 2
26b0 26b2 1 26bc
2 26bb 26bc 1
26c4 1 26ca 2
26cc 26cd 2 26b9
26ce 1 26d5 1
26d0 2 26e8 26ea
3 26e6 26e7 26ec
2 26f5 26f7 2
26f9 26fb 2 26fd
26ff 2 2701 2703
2 2705 2707 3
270c 270d 270e 2
2709 2710 2 26f4
2712 1 2714 1
2716 2 26df 2717
1 271b 1 26da
2 26d8 271f 1
2722 1 2725 5
266b 266e 2689 26af
2726 2 2729 2728
2 272d 272e 2
2730 2732 1 2736
f 1d8e 1da5 1dc0
1dc3 1dc6 1dc9 1dcc
1e34 1e5e 1eca 1ecd
1ed0 272a 2735 2739
2 1d7f 273c 1
273e 2 1d77 273f
2 2741 2742 1
2746 2 2744 2746
2 274b 274c 1
2750 2 274e 2750
2 2757 2758 1
275c 2 275a 275c
1 2765 2 2764
2765 1 276d 1
2773 2 2775 2776
2 2762 2777 1
277e 1 2779 2
2791 2793 3 278f
2790 2795 2 279e
27a0 2 27a2 27a4
2 27a6 27a8 2
27aa 27ac 2 27ae
27b0 3 27b5 27b6
27b7 2 27b2 27b9
2 279d 27bb 1
27bd 1 27bf 2
2788 27c0 1 27c4
1 2783 2 2781
27c8 1 27cb 1
27d8 2 27d7 27d8
1 27e0 1 27e6
2 27e8 27e9 2
27d5 27ea 1 27f1
1 27ec 2 2804
2806 3 2802 2803
2808 2 2811 2813
2 2815 2817 2
2819 281b 2 281d
281f 2 2821 2823
3 2828 2829 282a
2 2825 282c 2
2810 282e 1 2830
1 2832 2 27fb
2833 1 2837 1
27f6 2 27f4 283b
1 283e 2 2841
2842 1 2846 2
2844 2846 2 2851
2853 3 284f 2850
2855 2 285e 2860
2 2862 2864 2
2866 2868 1 2870
2 2872 2873 2
286a 2875 2 2877
2879 2 287b 287d
2 287f 2881 2
2883 2885 2 285d
2887 1 2889 1
288b 2 2895 2897
3 2893 2894 2899
2 28a2 28a4 2
28a1 28a6 1 28a8
1 28aa 3 28b1
28b2 28b3 3 288c
28ab 28b5 1 28bc
2 28b8 28bc 2
28c7 28c9 3 28c5
28c6 28cb 2 28d4
28d6 2 28d8 28da
2 28dc 28de 1
28e6 2 28e8 28e9
2 28e0 28eb 2
28ed 28ef 2 28f1
28f3 2 28f5 28f7
2 28f9 28fb 2
28d3 28fd 1 28ff
1 2901 2 290b
290d 3 2909 290a
290f 2 2918 291a
2 2917 291c 1
291e 1 2920 3
2927 2928 2929 3
2902 2921 292b 1
2933 2 292f 2933
2 293e 2940 3
293c 293d 2942 2
294b 294d 2 294f
2951 2 2953 2955
1 295d 2 295f
2960 2 2957 2962
2 2964 2966 2
2968 296a 2 296c
296e 2 2970 2972
2 294a 2974 1
2976 1 2978 2
2982 2984 3 2980
2981 2986 2 298f
2991 2 298e 2993
1 2995 1 2997
3 299e 299f 29a0
3 2979 2998 29a2
2 29ad 29af 3
29ab 29ac 29b1 2
29ba 29bc 2 29be
29c0 2 29c2 29c4
1 29cc 2 29ce
29cf 2 29c6 29d1
2 29d3 29d5 2
29d7 29d9 2 29db
29dd 2 29df 29e1
2 29b9 29e3 1
29e5 1 29e7 2
29f1 29f3 3 29ef
29f0 29f5 2 29fe
2a00 2 29fd 2a02
1 2a04 1 2a06
3 2a0d 2a0e 2a0f
3 29e8 2a07 2a11
4 2a13 292e 29a4
2a14 2 2843 2a15
1 2a17 1 2a1b
2 2a1d 2a1e 1
2a22 2 2a20 2a22
1 2a28 2 2a2a
2a2b 1 2a2f 2
2a2d 2a2f 2 2a40
2a42 2 2a44 2a46
2 2a48 2a4a 2
2a4c 2a4e 2 2a50
2a52 2 2a54 2a56
2 2a58 2a5a 2
2a5c 2a5e 2 2a60
2a62 2 2a64 2a66
2 2a68 2a6a 2
2a6c 2a6e 1 2a79
2 2a78 2a79 1
2a81 1 2a87 2
2a89 2a8a 2 2a76
2a8b 1 2a92 1
2a8d 2 2aa5 2aa7
3 2aa3 2aa4 2aa9
2 2ab2 2ab4 2
2ab6 2ab8 2 2aba
2abc 2 2abe 2ac0
2 2ac2 2ac4 3
2ac9 2aca 2acb 2
2ac6 2acd 2 2ab1
2acf 2 2ad6 2ad8
2 2ad5 2ada 2
2ad1 2adc 1 2ade
2 2a9c 2adf 1
2ae3 1 2a97 2
2a95 2ae7 2 2af7
2af9 2 2afb 2afd
2 2aff 2b01 2
2b03 2b05 2 2b07
2b09 2 2b0b 2b0d
2 2b0f 2b11 2
2b13 2b15 2 2b17
2b19 2 2b1b 2b1d
2 2b1f 2b21 2
2b23 2b25 1 2b30
2 2b2f 2b30 1
2b38 1 2b3e 2
2b40 2b41 2 2b2d
2b42 1 2b49 1
2b44 2 2b5c 2b5e
3 2b5a 2b5b 2b60
2 2b69 2b6b 2
2b6d 2b6f 2 2b71
2b73 2 2b75 2b77
2 2b79 2b7b 3
2b80 2b81 2b82 2
2b7d 2b84 2 2b68
2b86 2 2b8d 2b8f
2 2b8c 2b91 2
2b88 2b93 1 2b95
2 2b53 2b96 1
2b9a 1 2b4e 2
2b4c 2b9e 2 2bab
2bad 2 2baf 2bb1
2 2bb3 2bb5 2
2bb7 2bb9 2 2bbb
2bbd 2 2bbf 2bc1
2 2bc3 2bc5 2
2bc7 2bc9 2 2bcb
2bcd 2 2bcf 2bd1
2 2bd3 2bd5 2
2bd7 2bd9 2 2bdb
2bdd 2 2bdf 2be1
2 2be3 2be5 2
2be7 2be9 2 2beb
2bed 2 2bef 2bf1
2 2bf3 2bf5 2
2bf7 2bf9 2 2bfb
2bfd 2 2bff 2c01
2 2c03 2c05 2
2c07 2c09 2 2c0b
2c0d 2 2c0f 2c11
2 2c13 2c15 2
2c17 2c19 2 2c1b
2c1d 2 2c1f 2c21
2 2c23 2c25 2
2c27 2c29 2 2c2b
2c2d 2 2c2f 2c31
2 2c33 2c35 2
2c37 2c39 2 2c3b
2c3d 2 2c3f 2c41
1 2c4c 2 2c4b
2c4c 1 2c54 1
2c5a 2 2c5c 2c5d
2 2c49 2c5e 1
2c65 1 2c60 2
2c78 2c7a 3 2c76
2c77 2c7c 2 2c85
2c87 2 2c89 2c8b
2 2c8d 2c8f 2
2c91 2c93 2 2c95
2c97 3 2c9c 2c9d
2c9e 2 2c99 2ca0
2 2c84 2ca2 2
2ca9 2cab 2 2ca8
2cad 2 2ca4 2caf
1 2cb1 2 2c6f
2cb2 1 2cb6 1
2c6a 2 2c68 2cba
2 2cc0 2cc2 2
2cc4 2cc6 2 2cc8
2cca 2 2cd0 2cd1
1 2cd3 2 2ccc
2cd5 2 2cd7 2cd9
2 2cdb 2cdd 2
2ce3 2ce4 1 2ce6
2 2cdf 2ce8 2
2cea 2cec 2 2cee
2cf0 2 2cf2 2cf4
2 2cf6 2cf8 2
2cfa 2cfc 2 2cfe
2d00 2 2d02 2d04
2 2d06 2d08 2
2d0a 2d0c 2 2d12
2d13 1 2d15 2
2d0e 2d17 2 2d19
2d1b 2 2d1d 2d1f
2 2d25 2d26 1
2d28 2 2d21 2d2a
2 2d2c 2d2e 2
2d30 2d32 2 2d34
2d36 2 2d38 2d3a
2 2d3c 2d3e c
2a39 2a3e 2a71 2aea
2af0 2af5 2b28 2ba1
2ba9 2c44 2cbd 2d41
1 2d46 2 2d48
2d49 1 2d4d 2
2d4b 2d4d 2 2d5b
2d5d 2 2d5f 2d61
2 2d63 2d65 2
2d67 2d69 2 2d6b
2d6d 2 2d6f 2d71
2 2d73 2d75 2
2d77 2d79 2 2d7b
2d7d 2 2d7f 2d81
1 2d8c 2 2d8b
2d8c 1 2d94 1
2d9a 2 2d9c 2d9d
2 2d89 2d9e 1
2da5 1 2da0 2
2db8 2dba 3 2db6
2db7 2dbc 2 2dc5
2dc7 2 2dc9 2dcb
2 2dcd 2dcf 2
2dd1 2dd3 2 2dd5
2dd7 3 2ddc 2ddd
2dde 2 2dd9 2de0
2 2dc4 2de2 2
2de9 2deb 2 2de8
2ded 2 2de4 2def
1 2df1 2 2daf
2df2 1 2df6 1
2daa 2 2da8 2dfa
2 2e0a 2e0c 2
2e0e 2e10 2 2e12
2e14 2 2e16 2e18
2 2e1a 2e1c 2
2e1e 2e20 2 2e22
2e24 2 2e26 2e28
2 2e2a 2e2c 1
2e37 2 2e36 2e37
1 2e3f 1 2e45
2 2e47 2e48 2
2e34 2e49 1 2e50
1 2e4b 2 2e63
2e65 3 2e61 2e62
2e67 2 2e70 2e72
2 2e74 2e76 2
2e78 2e7a 2 2e7c
2e7e 2 2e80 2e82
3 2e87 2e88 2e89
2 2e84 2e8b 2
2e6f 2e8d 2 2e94
2e96 2 2e93 2e98
2 2e8f 2e9a 1
2e9c 2 2e5a 2e9d
1 2ea1 1 2e55
2 2e53 2ea5 2
2eb2 2eb4 2 2eb6
2eb8 2 2eba 2ebc
2 2ebe 2ec0 2
2ec2 2ec4 2 2ec6
2ec8 2 2eca 2ecc
2 2ece 2ed0 2
2ed2 2ed4 2 2ed6
2ed8 2 2eda 2edc
2 2ede 2ee0 2
2ee2 2ee4 2 2ee6
2ee8 2 2eea 2eec
2 2eee 2ef0 2
2ef2 2ef4 2 2ef6
2ef8 1 2f03 2
2f02 2f03 1 2f0b
1 2f11 2 2f13
2f14 2 2f00 2f15
1 2f1c 1 2f17
2 2f2f 2f31 3
2f2d 2f2e 2f33 2
2f3c 2f3e 2 2f40
2f42 2 2f44 2f46
2 2f48 2f4a 2
2f4c 2f4e 3 2f53
2f54 2f55 2 2f50
2f57 2 2f3b 2f59
2 2f60 2f62 2
2f5f 2f64 2 2f5b
2f66 1 2f68 2
2f26 2f69 1 2f6d
1 2f21 2 2f1f
2f71 2 2f77 2f79
2 2f7b 2f7d 2
2f7f 2f81 2 2f87
2f88 1 2f8a 2
2f83 2f8c 2 2f8e
2f90 2 2f96 2f97
1 2f99 2 2f92
2f9b 2 2f9d 2f9f
2 2fa1 2fa3 2
2fa5 2fa7 2 2fa9
2fab 2 2fad 2faf
c 2d54 2d59 2d84
2dfd 2e03 2e08 2e2f
2ea8 2eb0 2efb 2f74
2fb2 2 2fc0 2fc2
2 2fc4 2fc6 2
2fc8 2fca 2 2fcc
2fce 2 2fd0 2fd2
2 2fd4 2fd6 2
2fd8 2fda 2 2fdc
2fde 2 2fe0 2fe2
2 2fe4 2fe6 2
2fe8 2fea 2 2fec
2fee 1 2ff9 2
2ff8 2ff9 1 3001
1 3007 2 3009
300a 2 2ff6 300b
1 3012 1 300d
2 3025 3027 3
3023 3024 3029 2
3032 3034 2 3036
3038 2 303a 303c
2 303e 3040 2
3042 3044 3 3049
304a 304b 2 3046
304d 2 3031 304f
2 3056 3058 2
3055 305a 2 3051
305c 1 305e 2
301c 305f 1 3063
1 3017 2 3015
3067 2 3077 3079
2 307b 307d 2
307f 3081 2 3083
3085 2 3087 3089
2 308b 308d 2
308f 3091 2 3093
3095 2 3097 3099
1 30a4 2 30a3
30a4 1 30ac 1
30b2 2 30b4 30b5
2 30a1 30b6 1
30bd 1 30b8 2
30d0 30d2 3 30ce
30cf 30d4 2 30dd
30df 2 30e1 30e3
2 30e5 30e7 2
30e9 30eb 2 30ed
30ef 3 30f4 30f5
30f6 2 30f1 30f8
2 30dc 30fa 2
3101 3103 2 3100
3105 2 30fc 3107
1 3109 2 30c7
310a 1 310e 1
30c2 2 30c0 3112
2 311f 3121 2
3123 3125 2 3127
3129 2 312b 312d
2 312f 3131 2
3133 3135 2 3137
3139 2 313b 313d
2 313f 3141 2
3143 3145 2 3147
3149 2 314b 314d
2 314f 3151 2
3153 3155 2 3157
3159 2 315b 315d
1 3168 2 3167
3168 1 3170 1
3176 2 3178 3179
2 3165 317a 1
3181 1 317c 2
3194 3196 3 3192
3193 3198 2 31a1
31a3 2 31a5 31a7
2 31a9 31ab 2
31ad 31af 2 31b1
31b3 3 31b8 31b9
31ba 2 31b5 31bc
2 31a0 31be 2
31c5 31c7 2 31c4
31c9 2 31c0 31cb
1 31cd 2 318b
31ce 1 31d2 1
3186 2 3184 31d6
2 31dc 31de 2
31e0 31e2 2 31e4
31e6 2 31ec 31ed
1 31ef 2 31e8
31f1 2 31f3 31f5
2 31f7 31f9 2
31ff 3200 1 3202
2 31fb 3204 2
3206 3208 2 320a
320c 2 320e 3210
2 3212 3214 2
3216 3218 c 2fb9
2fbe 2ff1 306a 3070
3075 309c 3115 311d
3160 31d9 321b 3
321d 2fb4 321e 2
3228 322a 3 3226
3227 322c 2 3235
3237 2 3234 3239
1 323b 1 323d
2 3247 3249 3
3245 3246 324b 2
3254 3256 2 3253
3258 1 325a 1
325c 1 3262 2d
2fa 319 31c 31f
322 325 328 32b
32e 331 334 337
33a 33d 340 343
346 349 34c 356
359 35c 35f 3c3
427 4a5 600 603
60e 616 61e 621
b58 d66 d6b d6e
d71 d85 d92 2743
2a18 321f 323e 325d
3265 2 3272 3274
3 3270 3271 3276
2 327f 3281 2
327e 3283 2 328a
328e 2 3290 3292
2 3294 3298 2
3289 329a 2 3285
329c 1 329e 3
329f 32aa 32ae 1
3269 2 32c1 32c3
3 32bf 32c0 32c5
2 32ce 32d0 2
32cd 32d2 2 32d9
32db 2 32dd 32df
3 32e4 32e5 32e6
2 32e1 32e8 2
32d8 32ea 2 32d4
32ec 1 32ee 4
32b8 32ef 32f8 32fc
1 3300 1 32b3
2 32b1 3304 44
4b 52 59 60
67 6e 75 7c
83 8a 8f 94
9b a2 a9 b0
b7 be c4 ca
d0 d6 dc e2
e8 ee f4 fa
100 106 10c 112
118 11e 124 12a
130 136 13c 142
148 14e 154 15a
160 166 16d 174
17a 181 187 18e
195 19c 1a2 1a8
1ae 1b5 1bc 1c2
1c8 1cf 1d5 1db
1e1 1e7 1ec 1f3

1
4
0 
330b
0
1
a0
77
55
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 41 40 43 40 45 40 47
40 49 40 4b 40 4d 40 4f
40 51 40 53 40 55 40 57
40 59 40 5b 40 5d 40 5f
1 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
1 71 1 73 1 75 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
13e 1 0
2b 1 0
183 1 0
1dd 1 0
162 1 0
2f 1 0
1c4 1 0
ab 1 0
1ca 1 0
fc 1 0
15c 1 0
d8 1 0
1d7 1 0
27 1 0
189 1 0
1f 1 0
1b 1 0
1e3 1 0
96 1 0
2736 40 61
c0 1 0
9d 1 0
11a 1 0
17c 1 0
12c 1 0
8c 1 0
1e9 1 0
1a4 1 0
13 1 0
f6 1 0
1b0 1 0
ea 1 0
7e 1 0
16f 1 0
168 1 0
a4 1 0
77 1 0
f 1 0
e4 1 0
70 1 0
5b 1 0
3 1 0
c6 1 0
150 1 0
14a 1 0
1b7 1 0
85 1 0
19e 1 0
138 1 0
2 0 1
114 1 0
108 1 0
23 1 0
144 1 0
54 1 0
1d1 1 0
156 1 0
7 1 0
176 1 0
f0 1 0
de 1 0
132 1 0
d2 1 0
197 1 0
1be 1 0
1aa 1 0
cc 1 0
69 1 0
46 1 0
10e 1 0
37 1 0
4d 1 0
b2 1 0
120 1 0
17 1 0
91 1 0
b9 1 0
126 1 0
62 1 0
33 1 0
102 1 0
b 1 0
1ee 1 0
190 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_1;
ALTER FUNCTION SP_SEARCH_1 COMPILE DEBUG;
/*######################################################################################*/
/*######################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_3
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_3 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_3 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1e0
2 :e:
1FUNCTION:
1SP_SEARCH_3:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_REC_USER:
1H_RES_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_REC_STATUS:
11:
1H_RES_TYPE:
1H_PA_TIMEPHASE:
1H_ASSIGN_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SD:
1H_FD:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_UPDATE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_FROM_PRJ:
1H_DAYS:
1H_DURATION:
1H_NUMBER:
1H_TOTAL:
1H_TOTPR:
1H_PRIORITY:
1H_WEEK:
1H_RES_COST:
1NUMBER:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_AVAILABLE:
1H_ASSIGNED_WORK:
1H_REG_COST:
10.00:
1H_REG_SALE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1STMT:
17999:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1I:
1II:
1I_PA_SCHED:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_3(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1107:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_3(108) :: cplan.sql(4651) :: :
1GETTABLE:
1IS NULL:
18:
1143:
1      RETURN_INVALID:: SP_SEARCH_3(144) :: cplan.sql(4687) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1146:
1                EXIT:: SP_SEARCH_3(147) :: cplan.sql(4690) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
15:
1153:
1      RETURN_INVALID:: SP_SEARCH_3(154) :: cplan.sql(4697) :: :
1INVALID_PARAMS:
1156:
1                EXIT:: SP_SEARCH_3(157) :: cplan.sql(4700) :: :
1!=:
1SC_SRCH_PARTICIPANT:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1175:
1           EXCEPTION:: SP_SEARCH_3(176) :: cplan.sql(4719) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1182:
1      RETURN_INVALID:: SP_SEARCH_3(183) :: cplan.sql(4726) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1185:
1                EXIT:: SP_SEARCH_3(186) :: cplan.sql(4729) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1203:
1           EXCEPTION:: SP_SEARCH_3(204) :: cplan.sql(4747) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1SC_SRCH_OVERALLOCATE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1233:
1           EXCEPTION:: SP_SEARCH_3(234) :: cplan.sql(4777) :: :
1SC_SQL_NO_DATA:
1TMT_POOLS:
1SELECT 480, 2400, 0 INTO h_per_day, h_per_week, h_priority FROM TMT_POOLS WHE+
1RE ELEMENT_ID = h_project_id:
1249:
1           EXCEPTION:: SP_SEARCH_3(250) :: cplan.sql(4793) :: :
1        RETURN_ERROR:: SP_SEARCH_3(256) :: cplan.sql(4799) :: :
1 ID:: :
1258:
1                EXIT:: SP_SEARCH_3(259) :: cplan.sql(4802) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1PROJECT_ID:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1277:
1           EXCEPTION:: SP_SEARCH_3(278) :: cplan.sql(4821) :: :
1>:
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1295:
1           EXCEPTION:: SP_SEARCH_3(296) :: cplan.sql(4839) :: :
1STRCMP:
1L:
1302:
1        RETURN_ERROR:: SP_SEARCH_3(303) :: cplan.sql(4846) :: :
1LEV_LOCKED_BY_COPY:
1305:
1                EXIT:: SP_SEARCH_3(306) :: cplan.sql(4849) :: :
1313:
1      RETURN_INVALID:: SP_SEARCH_3(314) :: cplan.sql(4857) :: :
1316:
1                EXIT:: SP_SEARCH_3(317) :: cplan.sql(4860) :: :
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1TYPE_ID:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id AND TYPE_ID IN (pm+
1o_cnst.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PRO+
1J_TYPE2,pmo_cnst.SC_PROJ_TYPE3):
1344:
1           EXCEPTION:: SP_SEARCH_3(345) :: cplan.sql(4888) :: :
1351:
1        RETURN_ERROR:: SP_SEARCH_3(352) :: cplan.sql(4895) :: :
1RECORD_NOT_FOUND:
1354:
1                EXIT:: SP_SEARCH_3(355) :: cplan.sql(4898) :: :
1360:
1        RETURN_ERROR:: SP_SEARCH_3(361) :: cplan.sql(4904) :: :
1363:
1                EXIT:: SP_SEARCH_3(364) :: cplan.sql(4907) :: :
1100:
1:
1FC_CALC_DURATION:
1386:
1      RETURN_INVALID:: SP_SEARCH_3(387) :: cplan.sql(4930) :: :
1389:
1                EXIT:: SP_SEARCH_3(390) :: cplan.sql(4933) :: :
1394:
1        RETURN_ERROR:: SP_SEARCH_3(395) :: cplan.sql(4938) :: :
1397:
1                EXIT:: SP_SEARCH_3(398) :: cplan.sql(4941) :: :
1*:
12:
13:
14:
1FC_DECLARE_PMO_TMP_SEARCH:
1TSK_ASSIGNMENT_ID:
1TO_DATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG='0':
1454:
1           EXCEPTION:: SP_SEARCH_3(455) :: cplan.sql(4998) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1469:
1           EXCEPTION:: SP_SEARCH_3(470) :: cplan.sql(5013) :: :
1476:
1        RETURN_ERROR:: SP_SEARCH_3(477) :: cplan.sql(5020) :: :
1479:
1                EXIT:: SP_SEARCH_3(480) :: cplan.sql(5023) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1498:
1           EXCEPTION:: SP_SEARCH_3(499) :: cplan.sql(5042) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME INTO h_full_name FROM RESOURCES WHERE RESOURCE_ID = h_res_id:
1513:
1           EXCEPTION:: SP_SEARCH_3(514) :: cplan.sql(5057) :: :
1520:
1        RETURN_ERROR:: SP_SEARCH_3(521) :: cplan.sql(5064) :: :
1523:
1                EXIT:: SP_SEARCH_3(524) :: cplan.sql(5067) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='0':
1545:
1           EXCEPTION:: SP_SEARCH_3(546) :: cplan.sql(5089) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n               +
1REGULAR_COST, REGULAR_RATE :n               INTO h_prj_assignment_id, h_SD, h+
1_FD, h_billable, h_capital_expense,:n               h_reg_cost, h_reg_sale:n +
1              FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_i+
1d AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1568:
1           EXCEPTION:: SP_SEARCH_3(569) :: cplan.sql(5112) :: :
1-:
1COUNT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n                     WHERE PROJECT_ID = h_project_id AND TAS+
1K_ID <> PROJECT_ID AND RESOURCE_ID = h_res_id):
1589:
1           EXCEPTION:: SP_SEARCH_3(590) :: cplan.sql(5133) :: :
1595:
1        RETURN_ERROR:: SP_SEARCH_3(596) :: cplan.sql(5139) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1598:
1                EXIT:: SP_SEARCH_3(599) :: cplan.sql(5142) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1619:
1           EXCEPTION:: SP_SEARCH_3(620) :: cplan.sql(5163) :: :
1625:
1      RETURN_INVALID:: SP_SEARCH_3(626) :: cplan.sql(5169) :: :
1628:
1                EXIT:: SP_SEARCH_3(629) :: cplan.sql(5172) :: :
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1SC_PARTICIPANT_GROUP:
1SECURITY_ID:
1ELEMENT_TYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT =:n            CASE:n            +
1WHEN SECURITY_ID = h_temp2_security_id AND ELEMENT_TYPE IN (pmo_cnst.SC_PROJE+
1CT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cns+
1t.SC_PROJ_TYPE3) THEN pmo_cnst.SC_AFFECTED:n            WHEN SECURITY_ID = h_+
1temp2_security_id THEN pmo_cnst.SC_TEAMMEMBER:n            WHEN SECURITY_ID =+
1 h_temp_security_id THEN pmo_cnst.SC_AFFECTED:n            ELSE PMO_STPU.BIT_+
1OR( PARTICIPANT, pmo_cnst.SC_TEAMMEMBER):n            END, SECURITY_ID =:n   +
1         CASE:n            WHEN SECURITY_ID = h_temp2_security_id THEN  h_tem+
1p_security_id:n            ELSE SECURITY_ID:n            END:n            WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1665:
1           EXCEPTION:: SP_SEARCH_3(666) :: cplan.sql(5209) :: :
1FC_AFTER_U_RES_ASSIGN:
1SYS_GUID:
1FC_BEFORE_I_RES_ASSIGN:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE, TABLE_TYPE,:n            RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT+
1, SECURITY_ID, REC_USER, REC_DATETIME):n            VALUES (h_assign_id, h_pr+
1oject_id, h_task_id, h_type, h_table_type,:n            h_res_type, h_res_id,+
1 pmo_cnst.SC_AFFECTED, h_temp_security_id, rec_user001, SYSTIMESTAMP):
1701:
1           EXCEPTION:: SP_SEARCH_3(702) :: cplan.sql(5245) :: :
1TRUNC:
1TO_NUMBER:
1/:
110000.0:
10.5:
1MIN:
1TDY:
1DAY_YEAR:
1CALENDAR_DAY_OF_YEAR:
1CDY:
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1AVAILABLE_MIN:
1SCHED_MIN:
1SELECT MIN(tdy.DAY_YEAR) INTO h_SD :n               FROM CALENDAR_DAY_OF_YEAR+
1 cdy, TASK_DAY_OF_YEAR tdy :n               WHERE tdy.PROJECT_ID = h_project_+
1id :n               AND tdy.TSK_ASSIGNMENT_ID = h_prj_assignment_id:n        +
1       AND tdy.DAY_YEAR >= TO_DATE(SubStr(h_start_DT, 1, 10)) :n             +
1  AND tdy.ACTUAL_FLAG = 0:n               AND cdy.ELEMENT_ID = h_res_id :n   +
1            AND cdy.DAY_YEAR = tdy.DAY_YEAR:n               AND (cdy.AVAILABL+
1E_MIN - tdy.SCHED_MIN) >= h_temp_var:
1735:
1           EXCEPTION:: SP_SEARCH_3(736) :: cplan.sql(5279) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT  PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_FD, 1, 10)) + 1     , PMO_OR+
1ASTD.TIME('00::00'))  INTO  h_start_DT FROM DUAL:
1751:
1           EXCEPTION:: SP_SEARCH_3(752) :: cplan.sql(5295) :: :
1LAST_AVAIL_TIME:
1BIT_SCHED:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_STPU.LAST_AVAIL_TIME(BIT_SCHED))+
1 INTO h_start_DT:n                  FROM TASK_DAY_OF_YEAR :n                 +
1 WHERE PROJECT_ID = h_project_id :n                  AND TSK_ASSIGNMENT_ID = +
1h_prj_assignment_id :n                  AND DAY_YEAR = h_SD:
1770:
1           EXCEPTION:: SP_SEARCH_3(771) :: cplan.sql(5314) :: :
1STRNCMP:
110:
1778:
1        RETURN_ERROR:: SP_SEARCH_3(779) :: cplan.sql(5322) :: :
1TASK_ASSIGNMENT_ERROR:
1781:
1                EXIT:: SP_SEARCH_3(782) :: cplan.sql(5325) :: :
1SUM:
1SELECT SUM(SCHED_MIN) INTO h_assigned_work:n               FROM TASK_DAY_OF_Y+
1EAR:n               WHERE PROJECT_ID = h_project_id :n               AND TSK_+
1ASSIGNMENT_ID = h_prj_assignment_id :n               AND DAY_YEAR BETWEEN TO_+
1DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1801:
1           EXCEPTION:: SP_SEARCH_3(802) :: cplan.sql(5345) :: :
1SELECT SUM(AVAILABLE_MIN) INTO h_available:n               FROM CALENDAR_DAY_+
1OF_YEAR:n               WHERE ELEMENT_ID = h_res_id AND DAY_YEAR BETWEEN TO_D+
1ATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1819:
1           EXCEPTION:: SP_SEARCH_3(820) :: cplan.sql(5363) :: :
1826:
1        RETURN_ERROR:: SP_SEARCH_3(827) :: cplan.sql(5370) :: :
1829:
1                EXIT:: SP_SEARCH_3(830) :: cplan.sql(5373) :: :
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT TIMEPHASE_PROJECT_ASSIGNMENT INTO h_pa_timephase FROM PROJECT_DETAILS +
1WHERE PROJECT_ID = h_project_id:
1845:
1           EXCEPTION:: SP_SEARCH_3(846) :: cplan.sql(5389) :: :
1Y:
1FC_TPHASE_SCHED_ASSIGN:
1SC_SRCH_PROFILE:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1892:
1           EXCEPTION:: SP_SEARCH_3(893) :: cplan.sql(5436) :: :
1LENGTH:
1WHILE:
1LOOP:
1',':
1START_DT:
1FINISH_DT:
1SELECT TSK_ASSIGNMENT_ID, START_DT, FINISH_DT :n               INTO h_prj_ass+
1ignment_id, h_start_DT, h_finish_DT :n               FROM TASK_ASSIGNMENTS :n+
1               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND BIT_FL+
1AG='0':
1958:
1           EXCEPTION:: SP_SEARCH_3(959) :: cplan.sql(5502) :: :
1SELECT TSK_ASSIGNMENT_ID, START_DT, FINISH_DT :n                  INTO h_prj_+
1assignment_id, h_start_DT, h_finish_DT :n                  FROM TASK_ASSIGNME+
1NTS :n                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id A+
1ND BIT_FLAG='2':
1977:
1           EXCEPTION:: SP_SEARCH_3(978) :: cplan.sql(5521) :: :
1SELECT MIN(tdy.DAY_YEAR) INTO h_SD :n                     FROM CALENDAR_DAY_O+
1F_YEAR cdy, TASK_DAY_OF_YEAR tdy :n                     WHERE tdy.PROJECT_ID +
1= h_project_id :n                     AND tdy.TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id:n                     AND tdy.DAY_YEAR >= TO_DATE(SubStr(h_start_dat+
1e, 1, 10)) :n                     AND tdy.ACTUAL_FLAG = 0:n                  +
1   AND cdy.ELEMENT_ID = h_res_id :n                     AND cdy.DAY_YEAR = td+
1y.DAY_YEAR:n                     AND (cdy.AVAILABLE_MIN - tdy.SCHED_MIN) >= h+
1_temp_var:
11015:
1           EXCEPTION:: SP_SEARCH_3(1016) :: cplan.sql(5559) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_STPU.LAST_AVAIL_TIME(BIT_SCHED))+
1 INTO h_start_DT:n                        FROM TASK_DAY_OF_YEAR :n           +
1             WHERE PROJECT_ID = h_project_id :n                        AND TS+
1K_ASSIGNMENT_ID = h_prj_assignment_id :n                        AND DAY_YEAR +
1= h_SD:
11035:
1           EXCEPTION:: SP_SEARCH_3(1036) :: cplan.sql(5579) :: :
1<=:
1>=:
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)) + 1     ,+
1 PMO_ORASTD.TIME('00::00'))) :n                      INTO  h_start_DT FROM DU+
1AL:
11053:
1           EXCEPTION:: SP_SEARCH_3(1054) :: cplan.sql(5597) :: :
11099:
1           EXCEPTION:: SP_SEARCH_3(1100) :: cplan.sql(5643) :: :
11113:
1        RETURN_ERROR:: SP_SEARCH_3(1114) :: cplan.sql(5657) :: :
1CANNOT_ASSIGN_FROM_PROJECT_AFF:
11116:
1                EXIT:: SP_SEARCH_3(1117) :: cplan.sql(5660) :: :
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID, :
1p.E_MAIL_ADDRESS,b.PLANNED_START,b.PLANNED_FINISH,b.BEST AS PLANNED_EFFORT, :
1a.SCHED_START AS START_DATE, a.SCHED_FINISH AS FINISH_DATE, a.BEST AS WORK, a+
1.SCHED_WORK AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK,:
1rs.SCHED AS SCHED_WORK, :
1 AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y,:
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' AS+
1 OBJECTIVES,'' AS RANK, p.EXTERNAL_ID :
1FROM RESOURCE_ASSIGNMENTS t LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNMENT_+
1ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2' :
1LEFT JOIN TASK_ASSIGNMENTS b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b+
1.BIT_FLAG='0' :
1JOIN RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON t.RESOURCE_ID=rs.RES_ID :
1WHERE t.ELEMENT_ID=':
1' AND t.RESOURCE_TYPE='0' AND t.RESOURCE_ID IN (':
1') AND BITAND(t.PARTICIPANT, 4112) > 0 :
1UNION ALL :
1SELECT r.PROFILE_ID AS ELEMENT_ID, ta.RES_ASSIGNMENT_ID, r.PROFILE_NAME AS EL+
1EMENT_NAME, 41 AS TYPE_ID, :
1'' AS E_MAIL_ADDRESS,ta.PLANNED_START,ta.PLANNED_FINISH,ta.BEST AS PLANNED_EF+
1FORT,:
1STR_1899_12_31_00_00_00:
1 AS START_DATE, :
1 AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, :
1 AS UNIT_EFFORT,:
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY , rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' A+
1S OBJECTIVES,'' AS RANK, '' AS EXTERNAL_ID :
1FROM TASK_ASSIGNMENTS ta JOIN PROFILES r ON ta.TASK_ID=':
1' AND ta.RESOURCE_TYPE='1' AND ta.RESOURCE_ID IN (':
1') AND r.PROFILE_ID=ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON ta.RESOURCE_ID=rs.RES_ID :
1ORDER BY TYPE_ID:
11202:
1                EXIT:: SP_SEARCH_3(1203) :: cplan.sql(5746) :: :
11205:
1                EXIT:: SP_SEARCH_3(1206) :: cplan.sql(5749) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11213:
1           EXCEPTION:: SP_SEARCH_3(1214) :: cplan.sql(5757) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11225:
1           EXCEPTION:: SP_SEARCH_3(1226) :: cplan.sql(5769) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2013
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :4 a0 51
a5 b a5 b d a0 51 d
a0 51 d a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 a0 7e b4 2e :2 5a a
10 :8 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 51 d a0 b7 a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
a 10 :3 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :3 a0
6b :3 a0 51 a5 b :2 a0 6b a5
b 5a 51 a5 b d :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a0 51 d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:b a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 6e a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 19
3c b7 a0 7e b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :2 a0 d :4 a0 :2 51 a5 b :2 51
a5 b d :3 a0 6b :3 51 a0 a5
b d :3 a0 51 a5 b a5 b
7e 51 b4 2e :18 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 19 3c b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 51 d b7 19
3c a0 7e 51 b4 2e :2 a0 d
a0 6e d :6 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :3 a0 a5 b d :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 b7 :2 19 3c b7 :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 a0 51 d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e a0
51 d a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 51 d a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 :2 19 3c b7 19 3c
:2 a0 b4 2e d a0 6e d a0
6e d a0 6e d a0 6e d
:3 a0 :2 51 a5 b d :3 a0 :2 51 a5
b d :2 a0 51 a5 b 7e 51
b4 2e a0 4d d :2 a0 d :2 a0
:2 51 a5 b 7e 6e b4 2e :19 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 d
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 d :19 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 7e 51 b4
2e d :3 a0 51 a5 b a5 b
7e 51 b4 2e a0 51 d :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 19 3c b7 19
3c b7 19 3c :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 :2 a0 51 a5
b :2 a0 6b a0 a5 b d :2 a0
51 :2 a0 51 a5 b :2 a0 6b a0
a5 b d :25 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 a5 b d b7
:2 a0 b4 2e d :2 a0 51 :2 a0 51
a5 b :2 a0 6b a0 a5 b d
:3 a0 6b d a0 51 d :9 a0 a5
b d :18 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a a0 7e
b4 2e 5a a 10 a0 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 :5 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e 5a a5
b 7e 51 b4 2e 7e 51 b4
2e a5 b d b7 :2 19 3c a0
4d d :21 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 7e b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :e a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 7e 51 b4 2e :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 b7 a0 7e
51 b4 2e a0 51 d :f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :d a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e :2 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 :2 19 3c :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
:2 51 a5 b 7e 6e b4 2e a0
7e 51 b4 2e d :2 a0 6b :b a0
a5 b d b7 19 3c b7 19
3c :2 a0 :2 51 a5 b 7e 6e b4
2e :3 a0 6b d b7 :3 a0 51 a5
b d b7 :2 19 3c :1e a0 :5 51 a5
b d a0 7e 51 b4 2e :4 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c b7 a0 6e d a0 6e
d :2 a0 d :3 a0 a5 b 51 a5
b 7e 51 b4 2e a0 51 d
b7 :5 a0 a5 b 51 a5 b 7e
51 b4 2e 5a 7e 51 b4 2e
a5 b d b7 :2 19 3c a0 7e
51 b4 2e a0 51 d :3 a0 51
a5 b a0 7e a0 b4 2e 82
:3 a0 6b :2 51 :2 a0 51 a5 b 7e
51 b4 2e 7e 51 b4 2e a0
a5 b d :3 a0 6b :2 51 :2 a0 51
a5 b 7e 51 b4 2e 7e 51
b4 2e 7e 51 b4 2e a0 a5
b d :2 a0 :2 51 a5 b 7e 6e
b4 2e :3 a0 6b d :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
d b7 :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 :2 19 3c b7
:3 a0 51 a5 b d :3 a0 a5 b
51 a5 b 7e 51 b4 2e :2 a0
d b7 :3 a0 7e 6e b4 2e :2 51
a5 b d :3 a0 7e a0 b4 2e
:2 51 a5 b d b7 :2 19 3c b7
:2 19 3c :2 a0 :2 51 a5 b 7e 6e
b4 2e a0 51 d b7 19 3c
a0 51 d a0 51 d :c a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 51 d b7
:2 a0 d b7 :2 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b d b7 :5 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e 5a a5 b 7e 51 b4 2e
7e 51 b4 2e a5 b d b7
:2 19 3c a0 4d d :21 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
7e b4 2e 5a :e a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c a0 b7 :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e a
10 :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 :2 a0 d :2 a0
d b7 :2 19 3c b7 :2 a0 d :2 a0
d b7 :2 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 :2 51 a5 b
7e 6e b4 2e a0 51 d b7
19 3c a0 b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :3 a0 6b d b7
19 :3 a0 51 a5 b d b7 :2 19
3c :1e a0 :5 51 a5 b d a0 7e
51 b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c :3 a0 51
a5 b 7e 51 b4 2e d b7
a0 47 b7 19 3c b7 :2 19 3c
a0 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 d b7 19 3c
:3 a0 a5 b 51 a5 b 7e 51
b4 2e 5a :3 a0 a5 b 51 a5
b 7e 51 b4 2e 5a a 10
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e d a0 b7 :3 a0 a5 b
51 a5 b 7e 51 b4 2e a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
d a0 b7 19 :3 a0 a5 b 51
a5 b 7e 51 b4 2e a0 6e
7e 6e b4 2e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e d b7 :2 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b a0 a5 b 65 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
2013
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 234
223 227 22f 202 250 23b 23f 242
243 24b 222 26d 25b 21f 25f 260
268 25a 28a 278 257 27c 27d 285
277 2a7 295 274 299 29a 2a2 294
2c4 2b2 291 2b6 2b7 2bf 2b1 2e1
2cf 2ae 2d3 2d4 2dc 2ce 2fe 2ec
2cb 2f0 2f1 2f9 2eb 31b 309 2e8
30d 30e 316 308 337 326 32a 332
305 34f 33e 342 34a 325 36c 35a
322 35e 35f 367 359 388 377 37b
356 383 376 3a4 393 397 373 39f
392 3c0 3af 3b3 38f 3bb 3ae 3dc
3cb 3cf 3ab 3d7 3ca 3f8 3e7 3eb
3c7 3f3 3e6 414 403 407 3e3 40f
402 430 41f 423 3ff 42b 41e 44c
43b 43f 41b 447 43a 468 457 45b
437 463 456 484 473 477 453 47f
472 4a0 48f 493 46f 49b 48e 4bc
4ab 4af 48b 4b7 4aa 4d8 4c7 4cb
4a7 4d3 4c6 4f4 4e3 4e7 4c3 4ef
4e2 510 4ff 503 4df 50b 4fe 52c
51b 51f 4fb 527 51a 548 537 53b
517 543 536 564 553 557 533 55f
552 580 56f 573 54f 57b 56e 59c
58b 58f 56b 597 58a 5b8 5a7 5ab
587 5b3 5a6 5d4 5c3 5c7 5a3 5cf
5c2 5f0 5df 5e3 5bf 5eb 5de 60c
5fb 5ff 5db 607 5fa 628 617 61b
5f7 623 616 644 633 637 613 63f
632 660 64f 653 62f 65b 64e 67c
66b 66f 64b 677 66a 698 687 68b
667 693 686 6b4 6a3 6a7 683 6af
6a2 6d0 6bf 6c3 69f 6cb 6be 6ec
6db 6df 6bb 6e7 6da 708 6f7 6fb
6d7 703 6f6 725 713 6f3 717 718
720 712 742 730 70f 734 735 73d
72f 75e 74d 751 72c 759 74c 77a
769 76d 749 775 768 797 785 765
789 78a 792 784 7b3 7a2 7a6 781
7ae 7a1 7cf 7be 7c2 79e 7ca 7bd
7eb 7da 7de 7ba 7e6 7d9 807 7f6
7fa 7d6 802 7f5 823 812 816 7f2
81e 811 83f 82e 832 80e 83a 82d
85b 84a 84e 82a 856 849 877 866
86a 872 846 896 87e 882 886 889
891 865 89d 8a1 862 8a5 8a9 8ad
8b0 8b5 8b6 1 8b8 8bd 8c1 8c5
8c8 8cd 8d1 8d5 8d8 8dd 8de 8e0
8e5 8e8 8ec 8ed 8f2 8f7 8fa 8ff
900 905 908 90c 90d 912 915 91a
91b 920 923 928 929 92e 931 936
937 93c 93f 943 944 949 94c 951
952 957 95a 95f 960 965 968 96d
96e 973 976 97a 97b 980 983 988
989 98e 991 996 997 99c 99f 9a3
9a7 9ab 9ac 9ae 9b3 9b4 9b6 9b7
9bc 9bf 9c4 9c5 9ca 9cd 9d1 9d5
9d9 9da 9dc 9e1 9e2 9e4 9e5 9ea
9ed 9f2 9f3 9f8 9fb 9ff a03 a07
a08 a0a a0f a10 a12 a13 a18 a1b
a20 a21 a26 a29 a2d a31 a35 a36
a38 a3d a3e a40 a41 a46 a49 a4e
a4f a54 a57 a5b a5f a63 a64 a66
a6b a6c a6e a6f a74 a77 a7c a7d
a82 a85 a89 a8d a91 a92 a94 a99
a9a a9c a9d aa2 aa5 aaa aab ab0
ab3 ab7 abb abf ac0 ac2 ac7 ac8
aca acb ad0 ad3 ad8 ad9 ade ae1
ae5 ae9 aed aee af0 af5 af6 af8
af9 afe b01 b06 b07 b0c b0f b13
b17 b1b b1c b1e b23 b24 b26 b27
b2c b2f b34 b35 b3a b3d b41 b45
b49 b4a b4c b51 b52 b54 b55 b5a
b5d b62 b63 b68 b6b b70 b71 b76
b79 b7d b7e b83 b86 b8b b8c b91
b94 b99 b9a b9f ba2 ba7 ba8 bad
bb0 bb4 bb5 bba bbd bc2 bc3 bc8
bcb bd0 bd1 bd6 bd7 bdc bde be2
be5 be9 bed bf0 bf4 bf8 bfb bfe
c03 c06 c09 c0c c0d c12 c13 1
c15 c1a c1e c22 c25 c2a c2f c32
c36 c37 c3c c3d c42 c44 c48 c4b
c4f c53 c57 c5b c5f c63 c67 c6b
c6f c73 c77 c7b c7f c83 c87 c8b
c8f c93 c97 c9b c9f ca3 ca7 cab
caf cb3 cb7 cbb cbf cc3 cc7 ccb
ccf cd3 cd7 cdb cdf ce3 ce7 ceb
cef cf3 cf7 cfb cff d03 d07 d0b
d0f d12 d13 d15 d16 d18 d1c d20
d23 d27 d2b d2e d32 d36 d39 d3a
d3f d42 d46 d4a d4d d51 d55 d58
d5b d60 d63 d66 d69 d6a d6f d70
1 d72 d77 d7b d7f d82 d87 d8c
d8f d93 d94 d99 d9c da1 da2 da7
daa daf db0 db5 db8 dbc dc0 dc4
dc8 dcb dcc dce dd3 dd4 dd6 dd7
ddc ddd de2 de4 de8 deb def df3
df6 dfa dfe e01 e04 e09 e0c e0f
e12 e13 e18 e19 1 e1b e20 e24
e28 e2b e30 e35 e38 e3c e3d e42
e43 e48 e4a e4e e51 e55 e59 e5c
e60 e64 e67 e6b e6c e71 e73 e77
e7a e7e e82 e85 e86 e88 e8b e8e
e8f e94 e98 e9c e9f ea0 ea2 ea5
ea8 ea9 1 eae eb3 eb7 ebb ebe
ebf ec1 ec4 ec7 ec8 1 ecd ed2
ed6 eda edd ee1 ee5 ee8 eeb ef0
ef3 ef6 ef9 efa eff f00 1 f02
f07 f0b f0f f12 f17 f1c f1f f23
f24 f29 f2c f31 f32 f37 f3a f3f
f40 f45 f48 f4c f50 f54 f58 f5b
f5c f5e f63 f64 f66 f67 f6c f6d
f72 f74 f78 f7b f7f f83 f86 f8a
f8e f91 f94 f99 f9c f9f fa2 fa3
fa8 fa9 1 fab fb0 fb4 fb8 fbb
fc0 fc5 fc8 fcc fcd fd2 fd3 fd8
fda fde fe1 fe5 fe9 fec ff0 ff4
ff7 ffb ffc 1001 1003 1007 100a 100e
1012 1015 1016 1018 101c 101f 1023 1026
1027 102c 102f 1033 1036 1037 103c 103f
1 1042 1047 104b 104e 104f 1054 1057
1 105a 105f 1063 1067 106b 106f 1073
1077 107b 107f 108b 108f 1093 1096 109a
109e 10a0 10a4 10a8 10ac 10af 10b3 10b7
10b9 10ba 10bf 1 10c3 10c7 10cb 10ce
10d2 10d6 10da 10de 10e1 10e5 10e9 10ec
10ef 10f4 10f7 10fa 10fd 10fe 1103 1104
1 1106 110b 110f 1113 1116 111b 1120
1123 1127 1128 112d 1130 1135 1136 113b
113e 1143 1144 1149 114c 1150 1151 1156
1159 115e 115f 1164 1167 116b 116f 1172
1175 1176 1178 1179 117e 117f 1184 1186
118a 118d 118f 1193 1195 11a1 11a3 11a5
11a6 11ab 11af 11b1 11bd 11bf 11c3 11c7
11ca 11ce 11d1 11d5 11d8 11d9 11de 11e1
11e5 11e9 11ec 11ed 11ef 11f2 11f5 11f6
11fb 1 11fe 1203 1207 120b 120e 1212
1216 1219 121c 1221 1224 1227 122a 122b
1230 1231 1 1233 1238 123c 1240 1243
1248 124d 1250 1254 1255 125a 125d 1262
1263 1268 126b 1270 1271 1276 1279 127d
1281 1285 1289 128c 128d 128f 1294 1295
1297 1298 129d 129e 12a3 12a5 12a9 12ac
12b0 12b4 12b7 12bb 12bf 12c2 12c5 12ca
12cd 12d0 12d3 12d4 12d9 12da 1 12dc
12e1 12e5 12e9 12ec 12f1 12f6 12f9 12fd
12fe 1303 1304 1309 130b 130f 1312 1316
131a 131d 1321 1325 1328 132c 132d 1332
1334 1338 133b 133f 1342 1346 134a 134c
1350 1353 1354 1359 135c 135f 1363 1366
1367 136c 136f 1 1372 1377 137b 137f
1383 138f 1393 1397 139a 139e 13a2 13a4
13a8 13ac 13b0 13b3 13b7 13bb 13bd 13be
13c3 1 13c7 13cb 13cf 13d2 13d6 13da
13de 13e2 13e5 13e9 13ed 13f0 13f3 13f8
13fb 13fe 1401 1402 1407 1408 1 140a
140f 1413 1417 141a 141f 1424 1427 142b
142c 1431 1434 1439 143a 143f 1442 1447
1448 144d 1450 1454 1455 145a 145d 1462
1463 1468 146b 146f 1473 1476 1479 147a
147c 147d 1482 1483 1488 148a 148e 1491
1493 1497 1499 14a5 14a7 14a9 14aa 14af
14b3 14b5 14c1 14c3 14c5 14c9 14cd 14d0
14d4 14d8 14dc 14df 14e3 14e7 14eb 14ee
14ef 14f1 14f5 14f9 14fc 14fd 14ff 1502
1505 1506 1508 150c 1510 1514 1518 151c
151f 1520 1522 1526 152a 152d 152e 1530
1533 1537 153b 153f 1542 1543 1545 1549
154c 1550 1553 1554 1559 155d 1560 1564
1566 156a 156d 1571 1575 1578 1579 157b
157e 1581 1582 1587 158b 158f 1593 1597
159b 159f 15a3 15a7 15ab 15af 15b3 15bf
15c3 15c7 15ca 15ce 15d2 15d4 15d8 15dc
15e0 15e3 15e7 15eb 15ed 15ee 15f3 1
15f7 15fb 15ff 1602 1606 160a 160e 1612
1615 1619 161d 1620 1623 1628 162b 162e
1631 1632 1637 1638 1 163a 163f 1643
1647 164a 164f 1654 1657 165b 165c 1661
1664 1669 166a 166f 1672 1677 1678 167d
1680 1684 1685 168a 168d 1692 1693 1698
169b 169f 16a3 16a6 16a9 16aa 16ac 16ad
16b2 16b3 16b8 16ba 16be 16c1 16c3 16c7
16c9 16d5 16d7 16d9 16da 16df 16e3 16e5
16f1 16f3 16f7 16fb 16fe 1702 1705 1709
170c 170d 1712 1715 1719 171d 1721 1725
1729 172d 1739 173d 1741 1744 1748 174c
174e 1752 1756 175a 175d 1761 1765 1767
1768 176d 1 1771 1775 1779 177c 1780
1784 1788 178c 178f 1793 1797 179a 179d
17a2 17a5 17a8 17ab 17ac 17b1 17b2 1
17b4 17b9 17bd 17c1 17c4 17c9 17ce 17d1
17d5 17d6 17db 17de 17e3 17e4 17e9 17ec
17f1 17f2 17f7 17fa 17fe 17ff 1804 1807
180c 180d 1812 1815 1819 181d 1820 1823
1824 1826 1827 182c 182d 1832 1834 1838
183b 183d 1841 1843 184f 1851 1853 1854
1859 185d 185f 186b 186d 1871 1875 1878
187c 187f 1883 1886 1887 188c 188f 1893
1897 189a 189e 18a2 18a5 18a8 18ad 18b0
18b3 18b6 18b7 18bc 18bd 1 18bf 18c4
18c8 18cc 18cf 18d4 18d9 18dc 18e0 18e1
18e6 18e9 18ee 18ef 18f4 18f7 18fc 18fd
1902 1905 1909 190d 1911 1915 1918 1919
191b 1920 1921 1923 1924 1929 192c 1931
1932 1937 193a 193f 1940 1945 1948 194c
194d 1952 1955 195a 195b 1960 1961 1966
1968 196c 196f 1973 1977 197a 197e 1982
1985 1988 198d 1990 1993 1996 1997 199c
199d 1 199f 19a4 19a8 19ac 19af 19b4
19b9 19bc 19c0 19c1 19c6 19c7 19cc 19ce
19d2 19d5 19d9 19dd 19e0 19e4 19e8 19eb
19ef 19f3 19f4 19f9 19fb 19ff 1a02 1a04
1a08 1a0b 1a0f 1a12 1a16 1a1a 1a1e 1a22
1a26 1a2a 1a36 1a3a 1a3e 1a41 1a45 1a49
1a4b 1a4f 1a53 1a57 1a5a 1a5e 1a62 1a64
1a65 1a6a 1 1a6e 1a72 1a76 1a79 1a7d
1a81 1a85 1a89 1a8c 1a90 1a94 1a97 1a9a
1a9f 1aa2 1aa5 1aa8 1aa9 1aae 1aaf 1
1ab1 1ab6 1aba 1abe 1ac1 1ac6 1acb 1ace
1ad2 1ad3 1ad8 1adb 1ae0 1ae1 1ae6 1ae9
1aee 1aef 1af4 1af7 1afb 1afc 1b01 1b04
1b09 1b0a 1b0f 1b12 1b16 1b1a 1b1d 1b20
1b21 1b23 1b24 1b29 1b2a 1b2f 1b31 1b35
1b38 1b3a 1b3e 1b40 1b4c 1b4e 1b50 1b51
1b56 1b5a 1b5c 1b68 1b6a 1b6e 1b72 1b75
1b76 1b78 1b7b 1b7e 1b7f 1b84 1b88 1b8c
1b90 1b94 1b98 1ba4 1ba8 1bac 1baf 1bb3
1bb7 1bb9 1bbd 1bc1 1bc5 1bc8 1bcc 1bd0
1bd2 1bd3 1bd8 1 1bdc 1be0 1be4 1be7
1beb 1bef 1bf3 1bf7 1bfa 1bfe 1c02 1c05
1c08 1c0d 1c10 1c13 1c16 1c17 1c1c 1c1d
1 1c1f 1c24 1c28 1c2c 1c2f 1c34 1c39
1c3c 1c40 1c41 1c46 1c49 1c4e 1c4f 1c54
1c57 1c5c 1c5d 1c62 1c65 1c69 1c6a 1c6f
1c72 1c77 1c78 1c7d 1c80 1c84 1c88 1c8b
1c8e 1c8f 1c91 1c92 1c97 1c98 1c9d 1c9f
1ca3 1ca6 1ca8 1cac 1cae 1cba 1cbc 1cbe
1cbf 1cc4 1cc8 1cca 1cd6 1cd8 1cdc 1ce0
1ce3 1ce7 1cec 1ced 1cef 1cf2 1cf5 1cf6
1cfb 1cff 1d03 1d06 1d0a 1d0e 1d11 1d14
1d19 1d1c 1d1f 1d22 1d23 1d28 1d29 1
1d2b 1d30 1d34 1d38 1d3b 1d40 1d45 1d48
1d4c 1d4d 1d52 1d55 1d5a 1d5b 1d60 1d63
1d68 1d69 1d6e 1d71 1d75 1d79 1d7d 1d81
1d84 1d85 1d87 1d8c 1d8d 1d8f 1d90 1d95
1d98 1d9d 1d9e 1da3 1da6 1dab 1dac 1db1
1db4 1db8 1db9 1dbe 1dc1 1dc6 1dc7 1dcc
1dcd 1dd2 1dd4 1dd8 1ddb 1ddf 1de3 1de6
1dea 1dee 1df1 1df4 1df9 1dfc 1dff 1e02
1e03 1e08 1e09 1 1e0b 1e10 1e14 1e18
1e1b 1e20 1e25 1e28 1e2c 1e2d 1e32 1e33
1e38 1e3a 1e3e 1e41 1e45 1e49 1e4c 1e50
1e54 1e57 1e5b 1e5f 1e60 1e65 1e67 1e6b
1e6e 1e70 1e74 1e77 1e79 1e7d 1e80 1e81
1e86 1e89 1e8d 1e91 1e94 1e98 1e9c 1e9f
1ea2 1ea7 1eaa 1ead 1eb0 1eb1 1eb6 1eb7
1 1eb9 1ebe 1ec2 1ec6 1ec9 1ece 1ed3
1ed6 1eda 1edb 1ee0 1ee3 1ee8 1ee9 1eee
1ef1 1ef6 1ef7 1efc 1eff 1f03 1f07 1f0b
1f0f 1f12 1f13 1f15 1f1a 1f1b 1f1d 1f1e
1f23 1f24 1f29 1f2b 1f2f 1f32 1f36 1f3a
1f3d 1f41 1f45 1f48 1f4b 1f50 1f53 1f56
1f59 1f5a 1f5f 1f60 1 1f62 1f67 1f6b
1f6f 1f72 1f77 1f7c 1f7f 1f83 1f84 1f89
1f8a 1f8f 1f91 1f95 1f98 1f9c 1fa0 1fa3
1fa7 1fab 1fae 1fb2 1fb3 1fb8 1fba 1fbe
1fc1 1fc5 1fc9 1fcd 1fd1 1fd5 1fd9 1fdd
1fe0 1fe3 1fe4 1fe6 1fe9 1fec 1fed 1fef
1ff3 1ff7 1ffb 1fff 2002 2005 2008 200b
200f 2010 2012 2016 201a 201e 2022 2025
2026 2028 2029 202b 202e 2031 2032 2037
203b 203f 2043 2047 204b 204f 2053 2057
205b 205f 2063 2067 206b 206f 2073 2077
207b 207f 2083 2087 208b 208f 2093 2097
20a3 20a7 20ab 20ae 20b2 20b6 20b8 20bc
20c0 20c4 20c7 20cb 20cf 20d1 20d2 20d7
1 20db 20df 20e3 20e6 20ea 20ee 20f2
20f6 20f9 20fd 2101 2104 2107 210c 210f
2112 2115 2116 211b 211c 1 211e 2123
2127 212b 212e 2133 2138 213b 213f 2140
2145 2148 214d 214e 2153 2156 215b 215c
2161 2164 2168 2169 216e 2171 2176 2177
217c 217f 2183 2187 218a 218d 218e 2190
2191 2196 2197 219c 219e 21a2 21a5 21a7
21ab 21ad 21b9 21bb 21bd 21be 21c3 21c7
21c9 21d5 21d7 21db 21df 21e2 21e6 21e9
21ed 21f0 21f1 21f6 21f9 21fd 2201 2204
2208 220c 220f 2212 2217 221a 221d 2220
2221 2226 2227 1 2229 222e 2232 2236
2239 223e 2243 2246 224a 224b 2250 2253
2258 2259 225e 2261 2266 2267 226c 226f
2273 2277 227b 227f 2282 2283 2285 228a
228b 228d 228e 2293 2296 229b 229c 22a1
22a4 22a9 22aa 22af 22b2 22b6 22b7 22bc
22bf 22c4 22c5 22ca 22cb 22d0 22d2 22d6
22d9 22dd 22e1 22e4 22e8 22ec 22ef 22f2
22f7 22fa 22fd 2300 2301 2306 2307 1
2309 230e 2312 2316 2319 231e 2323 2326
232a 232b 2330 2331 2336 2338 233c 233f
2343 2347 234a 234e 2352 2355 2359 235d
235e 2363 2365 2369 236c 236e 2372 2376
2379 237d 2381 2384 2387 238c 238f 2392
2395 2396 239b 239c 1 239e 23a3 23a7
23ab 23ae 23b3 23b8 23bb 23bf 23c0 23c5
23c8 23cd 23ce 23d3 23d6 23db 23dc 23e1
23e4 23e8 23ec 23f0 23f4 23f7 23f8 23fa
23ff 2400 2402 2403 2408 240b 2410 2411
2416 2419 241e 241f 2424 2427 242b 242c
2431 2434 2439 243a 243f 2440 2445 2447
244b 244e 2452 2456 2459 245d 2461 2464
2467 246c 246f 2472 2475 2476 247b 247c
1 247e 2483 2487 248b 248e 2493 2498
249b 249f 24a0 24a5 24a6 24ab 24ad 24b1
24b4 24b8 24bc 24bf 24c3 24c7 24ca 24ce
24d2 24d3 24d8 24da 24de 24e2 24e5 24e7
24eb 24ef 24f2 24f6 24fa 24fd 24fe 2500
2503 2506 2507 250c 250f 2513 2517 251a
251b 251d 2520 2523 2524 2529 1 252c
2531 2535 2538 253c 253e 2542 2545 2549
254c 254f 2550 2555 2559 255d 2561 2565
256a 256e 2572 2576 257a 257e 2582 2586
2589 258a 258c 2590 2594 2597 2598 259a
259e 25a2 25a5 25a6 25a8 25ac 25b0 25b3
25b4 25b6 25ba 25be 25c1 25c2 25c4 25c8
25cc 25cf 25d0 25d2 25d6 25da 25dd 25de
25e0 25e4 25e8 25eb 25ec 25ee 25f2 25f6
25fa 25fb 25fd 2601 2605 2609 260c 260d
260f 2613 2616 261a 261d 261e 2623 2627
262b 262e 2632 2636 2639 263c 2641 2644
2647 264a 264b 2650 2651 1 2653 2658
265c 2660 2663 2668 266d 2670 2674 2675
267a 267d 2682 2683 2688 268b 2690 2691
2696 2699 269d 26a1 26a5 26a9 26ac 26ad
26af 26b4 26b5 26b7 26b8 26bd 26be 26c3
26c5 26c9 26cc 26d0 26d4 26d7 26db 26df
26e2 26e5 26ea 26ed 26f0 26f3 26f4 26f9
26fa 1 26fc 2701 2705 2709 270c 2711
2716 2719 271d 271e 2723 2724 2729 272b
272f 2732 2736 273a 273d 2741 2745 2748
274c 274d 2752 2756 2758 275c 2760 2763
2764 2766 2769 276c 276d 2772 2776 277a
277d 2781 2785 2788 278b 2790 2793 2796
2799 279a 279f 27a0 1 27a2 27a7 27ab
27af 27b2 27b7 27bc 27bf 27c3 27c4 27c9
27cc 27d1 27d2 27d7 27da 27df 27e0 27e5
27e8 27ec 27f0 27f4 27f5 27f7 27fc 27fd
27ff 2800 2805 2808 280d 280e 2813 2816
281b 281c 2821 2824 2828 2829 282e 2831
2836 2837 283c 283d 2842 2844 2848 284b
284f 2853 2856 285a 285e 2861 2864 2869
286c 286f 2872 2873 2878 2879 1 287b
2880 2884 2888 288b 2890 2895 2898 289c
289d 28a2 28a3 28a8 28aa 28ae 28b1 28b5
28b9 28bc 28c0 28c4 28c7 28c8 28ca 28ce
28d2 28d3 28d8 28da 28de 28e2 28e5 28e7
28eb 28ef 28f3 28f7 28fb 28fe 28ff 2901
2904 2907 2908 290d 2911 2915 2919 291c
291d 291f 2922 2926 292a 292d 292e 2930
2931 2936 293a 293c 2940 2943 2945 2949
294d 2950 2954 2958 295b 295c 295e 2961
2964 2965 296a 296d 2971 2975 2978 2979
297b 297e 2981 2982 2987 1 298a 298f
2993 2997 299a 299b 299d 29a0 29a3 29a4
29a9 29ac 29b0 29b4 29b7 29b8 29ba 29bd
29c0 29c1 29c6 1 29c9 29ce 29d2 29d5
29d9 29dd 29df 29e3 29e7 29ea 29eb 29ed
29f0 29f3 29f4 29f9 29fd 2a00 2a04 2a08
2a0a 2a0e 2a12 2a16 2a19 2a1a 2a1c 2a1f
2a22 2a23 2a28 2a2b 2a2f 2a33 2a36 2a37
2a39 2a3c 2a3f 2a40 2a45 1 2a48 2a4d
2a51 2a54 2a58 2a5c 2a5e 2a62 2a66 2a6a
2a6d 2a6e 2a70 2a73 2a76 2a77 2a7c 2a80
2a83 2a87 2a89 2a8d 2a91 2a94 2a96 2a9a
2a9d 2aa1 2aa5 2aa6 2aab 2aaf 2ab3 2ab8
2abc 2ac0 2ac5 2ac9 2acd 2ad2 2ad6 2ada
2adf 2ae3 2ae7 2aeb 2aef 2af2 2af5 2af6
2af8 2afc 2b00 2b04 2b08 2b0b 2b0e 2b0f
2b11 2b15 2b19 2b1d 2b20 2b21 2b23 2b26
2b29 2b2a 2b2f 2b33 2b34 2b38 2b3c 2b40
2b44 2b48 2b4c 2b4f 2b52 2b53 2b55 2b58
2b5d 2b5e 2b63 2b67 2b6b 2b6f 2b73 2b77
2b7b 2b7f 2b83 2b87 2b8b 2b8f 2b93 2b97
2b9b 2b9f 2ba3 2ba7 2bab 2baf 2bb3 2bb7
2bbb 2bbf 2bc3 2bc7 2bd3 2bd7 2bdb 2bde
2be2 2be6 2be8 2bec 2bf0 2bf4 2bf7 2bfb
2bff 2c01 2c02 2c07 1 2c0b 2c0f 2c13
2c16 2c1a 2c1e 2c22 2c26 2c29 2c2d 2c31
2c34 2c37 2c3c 2c3f 2c42 2c45 2c46 2c4b
2c4c 1 2c4e 2c53 2c57 2c5b 2c5e 2c63
2c68 2c6b 2c6f 2c70 2c75 2c78 2c7d 2c7e
2c83 2c86 2c8b 2c8c 2c91 2c94 2c98 2c99
2c9e 2ca1 2ca6 2ca7 2cac 2caf 2cb3 2cb7
2cba 2cbd 2cbe 2cc0 2cc1 2cc6 2cc7 2ccc
2cce 2cd2 2cd5 2cd7 2cdb 2cdd 2ce9 2ceb
2ced 2cee 2cf3 2cf7 2cf9 2d05 2d07 2d0b
2d0f 2d13 2d17 2d1b 2d27 2d2b 2d2f 2d32
2d36 2d3a 2d3c 2d40 2d44 2d48 2d4b 2d4f
2d53 2d55 2d56 2d5b 1 2d5f 2d63 2d67
2d6a 2d6e 2d72 2d76 2d7a 2d7d 2d81 2d85
2d88 2d8b 2d90 2d93 2d96 2d99 2d9a 2d9f
2da0 1 2da2 2da7 2dab 2daf 2db2 2db7
2dbc 2dbf 2dc3 2dc4 2dc9 2dcc 2dd1 2dd2
2dd7 2dda 2ddf 2de0 2de5 2de8 2dec 2ded
2df2 2df5 2dfa 2dfb 2e00 2e03 2e07 2e0b
2e0e 2e11 2e12 2e14 2e15 2e1a 2e1b 2e20
2e22 2e26 2e29 2e2b 2e2f 2e31 2e3d 2e3f
2e41 2e42 2e47 2e4b 2e4d 2e59 2e5b 2e5f
2e63 2e66 2e6a 2e6d 2e71 2e74 2e75 2e7a
2e7d 2e81 2e85 2e88 2e8c 2e90 2e93 2e96
2e9b 2e9e 2ea1 2ea4 2ea5 2eaa 2eab 1
2ead 2eb2 2eb6 2eba 2ebd 2ec2 2ec7 2eca
2ece 2ecf 2ed4 2ed7 2edc 2edd 2ee2 2ee5
2eea 2eeb 2ef0 2ef3 2ef7 2efb 2eff 2f03
2f06 2f07 2f09 2f0e 2f0f 2f11 2f12 2f17
2f1a 2f1f 2f20 2f25 2f28 2f2d 2f2e 2f33
2f36 2f3a 2f3b 2f40 2f43 2f48 2f49 2f4e
2f4f 2f54 2f56 2f5a 2f5d 2f61 2f65 2f68
2f6c 2f70 2f73 2f76 2f7b 2f7e 2f81 2f84
2f85 2f8a 2f8b 1 2f8d 2f92 2f96 2f9a
2f9d 2fa2 2fa7 2faa 2fae 2faf 2fb4 2fb5
2fba 2fbc 2fc0 2fc3 2fc7 2fcb 2fce 2fd2
2fd6 2fd9 2fdd 2fe1 2fe2 2fe7 2fe9 2fed
2ff0 2ff4 2ff8 2ffc 3000 3004 3008 300c
3010 3014 3018 301c 3020 3024 3030 3034
3038 303b 303f 3043 3045 3049 304d 3051
3054 3058 305c 305e 305f 3064 1 3068
306c 3070 3073 3077 307b 307f 3083 3086
308a 308e 3091 3094 3099 309c 309f 30a2
30a3 30a8 30a9 1 30ab 30b0 30b4 30b8
30bb 30c0 30c5 30c8 30cc 30cd 30d2 30d5
30da 30db 30e0 30e3 30e8 30e9 30ee 30f1
30f5 30f6 30fb 30fe 3103 3104 3109 310c
3110 3114 3117 311a 311b 311d 311e 3123
3124 3129 312b 312f 3132 3134 3138 313a
3146 3148 314a 314b 3150 3154 3156 3162
3164 3168 316a 316e 3172 3175 3178 3179
317b 317e 3183 3184 3189 318d 3191 3195
3199 319d 31a9 31ad 31b1 31b4 31b8 31bc
31be 31c2 31c6 31ca 31cd 31d1 31d5 31d7
31d8 31dd 1 31e1 31e5 31e9 31ec 31f0
31f4 31f8 31fc 31ff 3203 3207 320a 320d
3212 3215 3218 321b 321c 3221 3222 1
3224 3229 322d 3231 3234 3239 323e 3241
3245 3246 324b 324e 3253 3254 3259 325c
3261 3262 3267 326a 326e 326f 3274 3277
327c 327d 3282 3285 3289 328d 3290 3293
3294 3296 3297 329c 329d 32a2 32a4 32a8
32ab 32ad 32b1 32b3 32bf 32c1 32c3 32c4
32c9 32cd 32cf 32db 32dd 32e1 32e5 32e8
32ec 32ef 32f3 32f6 32f7 32fc 32ff 3303
3307 330a 330e 3312 3315 3318 331d 3320
3323 3326 3327 332c 332d 1 332f 3334
3338 333c 333f 3344 3349 334c 3350 3351
3356 3359 335e 335f 3364 3367 336c 336d
3372 3375 3379 337d 3381 3385 3388 3389
338b 3390 3391 3393 3394 3399 339c 33a1
33a2 33a7 33aa 33af 33b0 33b5 33b8 33bc
33bd 33c2 33c5 33ca 33cb 33d0 33d1 33d6
33d8 33dc 33df 33e3 33e7 33ea 33ee 33f2
33f5 33f8 33fd 3400 3403 3406 3407 340c
340d 1 340f 3414 3418 341c 341f 3424
3429 342c 3430 3431 3436 3437 343c 343e
3442 3445 3449 344d 3450 3454 3458 345b
345f 3463 3464 3469 346b 346f 3472 3476
347a 347e 3482 3486 348a 348e 3492 3496
349a 349e 34a2 34a6 34aa 34ae 34b2 34b6
34ba 34be 34c2 34c6 34ca 34ce 34d2 34d6
34da 34de 34e2 34ee 34f2 34f6 34f9 34fd
3501 3503 3507 350b 350f 3512 3516 351a
351c 351d 3522 1 3526 352a 352e 3531
3535 3539 353d 3541 3544 3548 354c 354f
3552 3557 355a 355d 3560 3561 3566 3567
1 3569 356e 3572 3576 3579 357e 3583
3586 358a 358b 3590 3593 3598 3599 359e
35a1 35a6 35a7 35ac 35af 35b3 35b4 35b9
35bc 35c1 35c2 35c7 35ca 35ce 35d2 35d5
35d8 35d9 35db 35dc 35e1 35e2 35e7 35e9
35ed 35f0 35f2 35f6 35f8 3604 3606 3608
3609 360e 3612 3614 3620 3622 3626 362a
362d 3631 3634 3638 363b 363c 3641 3644
3648 364b 364f 3653 3657 365b 365f 3663
3667 366b 366f 3673 3677 367b 367f 3683
3687 368b 368f 3693 3697 369b 369f 36a3
36a7 36ab 36af 36b3 36bf 36c3 36c7 36ca
36ce 36d2 36d4 36d8 36dc 36e0 36e3 36e7
36eb 36ed 36ee 36f3 1 36f7 36fb 36ff
3702 3706 370a 370e 3712 3715 3719 371d
3720 3723 3728 372b 372e 3731 3732 3737
3738 1 373a 373f 3743 3747 374a 374f
3754 3757 375b 375c 3761 3764 3769 376a
376f 3772 3777 3778 377d 3780 3784 3785
378a 378d 3792 3793 3798 379b 379f 37a3
37a6 37a9 37aa 37ac 37ad 37b2 37b3 37b8
37ba 37be 37c1 37c3 37c7 37c9 37d5 37d7
37d9 37da 37df 37e3 37e5 37f1 37f3 37f7
37fb 37fe 3802 3805 3809 380c 380d 3812
3815 3819 381c 381f 3820 3825 3829 382d
3831 3835 3838 3839 383b 383c 383e 3841
3844 3845 384a 384e 3851 3855 3859 385d
3861 3865 3869 386d 3871 3875 3879 387d
3889 388d 3891 3894 3898 389c 389e 38a2
38a6 38aa 38ad 38b1 38b5 38b7 38b8 38bd
1 38c1 38c5 38c9 38cc 38d0 38d4 38d8
38dc 38df 38e3 38e7 38ea 38ed 38f2 38f5
38f8 38fb 38fc 3901 3902 1 3904 3909
390d 3911 3914 3919 391e 3921 3925 3926
392b 392e 3933 3934 3939 393c 3941 3942
3947 394a 394e 394f 3954 3957 395c 395d
3962 3965 3969 396d 3970 3973 3974 3976
3977 397c 397d 3982 3984 3988 398b 398d
3991 3993 399f 39a1 39a3 39a4 39a9 39ad
39af 39bb 39bd 39c1 39c5 39c8 39c9 39cb
39ce 39d1 39d2 39d7 39db 39df 39e2 39e6
39ea 39ed 39f0 39f5 39f8 39fb 39fe 39ff
3a04 3a05 1 3a07 3a0c 3a10 3a14 3a17
3a1c 3a21 3a24 3a28 3a29 3a2e 3a31 3a36
3a37 3a3c 3a3f 3a44 3a45 3a4a 3a4d 3a51
3a55 3a59 3a5d 3a60 3a61 3a63 3a68 3a69
3a6b 3a6c 3a71 3a74 3a79 3a7a 3a7f 3a82
3a87 3a88 3a8d 3a90 3a94 3a95 3a9a 3a9d
3aa2 3aa3 3aa8 3aa9 3aae 3ab0 3ab4 3ab7
3abb 3abf 3ac2 3ac6 3aca 3acd 3ad0 3ad5
3ad8 3adb 3ade 3adf 3ae4 3ae5 1 3ae7
3aec 3af0 3af4 3af7 3afc 3b01 3b04 3b08
3b09 3b0e 3b0f 3b14 3b16 3b1a 3b1d 3b21
3b25 3b28 3b2c 3b30 3b33 3b37 3b3b 3b3c
3b41 3b43 3b47 3b4a 3b4c 3b50 3b53 3b55
3b59 3b5c 3b5e 3b62 3b65 3b69 3b6d 3b71
3b75 3b79 3b7d 3b81 3b85 3b89 3b8d 3b99
3b9d 3ba1 3ba4 3ba8 3bac 3bae 3bb2 3bb6
3bba 3bbd 3bc1 3bc5 3bc7 3bc8 3bcd 1
3bd1 3bd5 3bd9 3bdc 3be0 3be4 3be8 3bec
3bef 3bf3 3bf7 3bfa 3bfd 3c02 3c05 3c08
3c0b 3c0c 3c11 3c12 1 3c14 3c19 3c1d
3c21 3c24 3c29 3c2e 3c31 3c35 3c36 3c3b
3c3e 3c43 3c44 3c49 3c4c 3c51 3c52 3c57
3c5a 3c5e 3c5f 3c64 3c67 3c6c 3c6d 3c72
3c75 3c79 3c7d 3c80 3c83 3c84 3c86 3c87
3c8c 3c8d 3c92 3c94 3c98 3c9b 3c9d 3ca1
3ca3 3caf 3cb1 3cb3 3cb4 3cb9 3cbd 3cbf
3ccb 3ccd 3ccf 3cd3 3cd7 3cdb 3cde 3ce2
3ce6 3ce9 3cec 3cf1 3cf4 3cf7 3cfa 3cfb
3d00 3d01 1 3d03 3d08 3d0c 3d10 3d13
3d18 3d1d 3d20 3d24 3d25 3d2a 3d2d 3d32
3d33 3d38 3d3b 3d40 3d41 3d46 3d49 3d4d
3d51 3d55 3d59 3d5c 3d5d 3d5f 3d64 3d65
3d67 3d68 3d6d 3d6e 3d73 3d75 3d79 3d7c
3d80 3d84 3d87 3d8b 3d8f 3d92 3d95 3d9a
3d9d 3da0 3da3 3da4 3da9 3daa 1 3dac
3db1 3db5 3db9 3dbc 3dc1 3dc6 3dc9 3dcd
3dce 3dd3 3dd4 3dd9 3ddb 3ddf 3de2 3de6
3dea 3ded 3df1 3df5 3df8 3dfc 3dfd 3e02
3e04 3e08 3e0c 3e0f 3e13 3e17 3e1a 3e1e
3e21 3e25 3e28 3e29 3e2e 3e31 3e35 3e39
3e3c 3e40 3e44 3e47 3e48 3e4a 3e4e 3e52
3e55 3e59 3e5a 3e5c 3e60 3e64 3e68 3e6b
3e6f 3e73 3e76 3e77 3e79 3e7d 3e81 3e84
3e88 3e89 3e8b 3e8f 3e93 3e97 3e9b 3e9f
3ea3 3ea7 3eab 3eaf 3eb3 3eb7 3ebb 3ebf
3ec3 3ec7 3ecb 3ecf 3ed3 3ed7 3edb 3edf
3ee3 3ee7 3eeb 3eef 3ef3 3ef7 3efb 3eff
3f03 3f07 3f0b 3f0f 3f13 3f17 3f1b 3f1f
3f23 3f2f 3f33 3f38 3f3c 3f3f 3f40 3f45
3f49 3f4d 3f50 3f53 3f57 3f59 3f5d 3f61
3f64 3f67 3f6b 3f6d 3f71 3f75 3f78 3f7a
3f7e 3f82 3f86 3f89 3f8d 3f91 3f93 3f94
3f99 1 3f9d 3fa1 3fa5 3fa8 3fac 3fb0
3fb4 3fb8 3fbb 3fbf 3fc3 3fc6 3fc9 3fce
3fd1 3fd4 3fd7 3fd8 3fdd 3fde 1 3fe0
3fe5 3fe9 3fed 3ff0 3ff5 3ffa 3ffd 4001
4002 4007 400a 400f 4010 4015 4018 401d
401e 4023 4026 402a 402b 4030 4033 4038
4039 403e 4041 4045 4049 404c 404f 4050
4052 4053 4058 4059 405e 4060 4064 4067
4069 406d 406f 407b 407d 407f 4080 4085
4089 408b 4097 4099 409d 40a1 40a5 40a6
40a8 40ac 40ae 40b2 40b6 40b7 40bc 40c0
40c4 40c8 40cb 40cf 40d3 40d6 40d7 40d9
40dd 40e1 40e4 40e8 40e9 40eb 40ef 40f3
40f7 40fb 40fe 4102 4106 4109 410d 4111
4115 4119 411d 4121 4125 4129 412d 4131
4132 4134 4138 413c 4140 4144 4148 414c
4150 4154 4158 415c 4160 4164 4168 416c
4170 4174 4178 417c 4180 4184 4188 418c
4190 4194 4198 41a4 41a8 41ad 41b1 41b4
41b5 41ba 41be 41c2 41c5 41c8 41cc 41ce
41d2 41d6 41d9 41dc 41e0 41e2 41e6 41ea
41ed 41ef 41f3 41f7 41fb 41fe 4202 4206
4208 4209 420e 1 4212 4216 421a 421d
4221 4225 4229 422d 4230 4234 4238 423b
423e 4243 4246 4249 424c 424d 4252 4253
1 4255 425a 425e 4262 4265 426a 426f
4272 4276 4277 427c 427f 4284 4285 428a
428d 4292 4293 4298 429b 429f 42a0 42a5
42a8 42ad 42ae 42b3 42b6 42ba 42be 42c1
42c4 42c5 42c7 42c8 42cd 42ce 42d3 42d5
42d9 42dc 42de 42e2 42e4 42f0 42f2 42f4
42f5 42fa 42fe 4300 430c 430e 4310 4314
4318 431b 431f 4323 4326 4327 4329 432c
432f 4330 4335 4338 433c 433f 4340 4345
1 4348 434d 4351 4354 4357 4358 435d
1 4360 4365 4369 436d 4370 4371 4373
4376 4379 437a 437f 4383 4387 438a 438b
438d 4390 4393 4394 4399 439d 43a1 43a5
43a8 43a9 43ab 43af 43b1 43b5 43b9 43bd
43c1 43c5 43c8 43c9 43cb 43ce 43d2 43d6
43d9 43da 43dc 43dd 43e2 43e5 43e6 43e8
43eb 43ee 43ef 43f4 43f7 43fa 43fb 4400
4401 4403 4407 4409 440d 4411 4414 4418
4419 441d 4421 4425 4429 442d 4431 4435
4439 443d 4441 4445 4449 444d 4451 4455
4459 445d 4461 4465 4469 446d 4471 4475
4479 447d 4481 4485 4489 448d 4491 4495
4499 449d 44a1 44ad 44b1 44b5 44b8 44bc
44c0 44c2 44c6 44ca 44ce 44d1 44d5 44d9
44db 44dc 44e1 1 44e5 44e9 44ed 44f0
44f4 44f8 44fc 4500 4503 4507 450b 450e
4511 4516 4519 451c 451f 4520 4525 4526
1 4528 452d 4531 4535 4538 453d 4542
4545 4549 454a 454f 4552 4557 4558 455d
4560 4565 4566 456b 456e 4572 4573 4578
457b 4580 4581 4586 4589 458d 4591 4594
4597 4598 459a 459b 45a0 45a1 45a6 45a8
45ac 45af 45b1 45b5 45b7 45c3 45c5 45c7
45c8 45cd 45d1 45d3 45df 45e1 45e5 45e8
45e9 45ee 45f1 45f5 45f9 45fd 4601 4605
4609 460d 4611 4615 4621 4625 4629 462c
4630 4634 4636 463a 463e 4642 4645 4649
464d 464f 4650 4655 1 4659 465d 4661
4664 4668 466c 4670 4674 4677 467b 467f
4682 4685 468a 468d 4690 4693 4694 4699
469a 1 469c 46a1 46a5 46a9 46ac 46b1
46b6 46b9 46bd 46be 46c3 46c6 46cb 46cc
46d1 46d4 46d9 46da 46df 46e2 46e6 46e7
46ec 46ef 46f4 46f5 46fa 46fd 4701 4705
4708 470b 470c 470e 470f 4714 4715 471a
471c 4720 4723 4725 4729 472b 4737 4739
473b 473c 4741 4745 4747 4753 4755 4757
475b 475f 4763 4767 476b 476f 4773 4777
477b 477f 4783 4787 478b 478f 479b 479f
47a3 47a6 47aa 47ae 47b0 47b4 47b8 47bc
47bf 47c3 47c7 47c9 47ca 47cf 1 47d3
47d7 47db 47de 47e2 47e6 47ea 47ee 47f1
47f5 47f9 47fc 47ff 4804 4807 480a 480d
480e 4813 4814 1 4816 481b 481f 4823
4826 482b 4830 4833 4837 4838 483d 4840
4845 4846 484b 484e 4853 4854 4859 485c
4860 4861 4866 4869 486e 486f 4874 4877
487b 487f 4882 4885 4886 4888 4889 488e
488f 4894 4896 489a 489d 489f 48a3 48a5
48b1 48b3 48b5 48b6 48bb 48bf 48c1 48cd
48cf 48d1 48d5 48d9 48dc 48e0 48e3 48e6
48e7 48ec 48f0 48f4 48f7 48fb 48ff 4902
4903 4905 4908 490b 490c 1 4911 4916
491a 491e 4921 4925 4929 492c 492f 4934
4937 493a 493d 493e 4943 4944 1 4946
494b 494f 4953 4956 495b 4960 4963 4967
4968 496d 4970 4975 4976 497b 497e 4983
4984 4989 498c 4990 4994 4998 499c 499f
49a0 49a2 49a7 49a8 49aa 49ab 49b0 49b3
49b8 49b9 49be 49c1 49c6 49c7 49cc 49cf
49d3 49d4 49d9 49dc 49e1 49e2 49e7 49e8
49ed 49ef 49f3 49f6 49fa 49fe 4a01 4a05
4a09 4a0c 4a0f 4a14 4a17 4a1a 4a1d 4a1e
4a23 4a24 1 4a26 4a2b 4a2f 4a33 4a36
4a3b 4a40 4a43 4a47 4a48 4a4d 4a4e 4a53
4a55 4a59 4a5c 4a60 4a64 4a67 4a6b 4a6f
4a72 4a76 4a7a 4a7b 4a80 4a82 4a86 4a89
4a8d 4a8f 4a93 4a96 4a99 4a9a 4a9f 4aa3
4aa6 4aaa 4aae 4ab2 4ab6 4aba 4abe 4ac2
4ac6 4aca 4ace 4ad2 4ad6 4ada 4ade 4ae2
4ae6 4af2 4af6 4afa 4afd 4b01 4b05 4b07
4b0b 4b0f 4b13 4b16 4b1a 4b1e 4b20 4b21
4b26 1 4b2a 4b2e 4b32 4b35 4b39 4b3d
4b41 4b45 4b48 4b4c 4b50 4b53 4b56 4b5b
4b5e 4b61 4b64 4b65 4b6a 4b6b 1 4b6d
4b72 4b76 4b7a 4b7d 4b82 4b87 4b8a 4b8e
4b8f 4b94 4b97 4b9c 4b9d 4ba2 4ba5 4baa
4bab 4bb0 4bb3 4bb7 4bb8 4bbd 4bc0 4bc5
4bc6 4bcb 4bce 4bd2 4bd6 4bd9 4bdc 4bdd
4bdf 4be0 4be5 4be6 4beb 4bed 4bf1 4bf4
4bf6 4bfa 4bfc 4c08 4c0a 4c0c 4c0d 4c12
4c16 4c18 4c24 4c26 4c2a 4c2d 4c31 4c35
4c39 4c3d 4c41 4c45 4c49 4c4d 4c51 4c55
4c59 4c5d 4c61 4c65 4c71 4c75 4c79 4c7c
4c80 4c84 4c86 4c8a 4c8e 4c92 4c95 4c99
4c9d 4c9f 4ca0 4ca5 1 4ca9 4cad 4cb1
4cb4 4cb8 4cbc 4cc0 4cc4 4cc7 4ccb 4ccf
4cd2 4cd5 4cda 4cdd 4ce0 4ce3 4ce4 4ce9
4cea 1 4cec 4cf1 4cf5 4cf9 4cfc 4d01
4d06 4d09 4d0d 4d0e 4d13 4d16 4d1b 4d1c
4d21 4d24 4d29 4d2a 4d2f 4d32 4d36 4d37
4d3c 4d3f 4d44 4d45 4d4a 4d4d 4d51 4d55
4d58 4d5b 4d5c 4d5e 4d5f 4d64 4d65 4d6a
4d6c 4d70 4d73 4d75 4d79 4d7b 4d87 4d89
4d8b 4d8c 4d91 4d95 4d97 4da3 4da5 4da9
4dad 4db0 4db1 4db3 4db6 4dba 4dbe 4dc1
4dc2 4dc4 4dc7 4dcb 4dcf 4dd2 4dd3 4dd5
4dd6 4ddb 4dde 4ddf 4de4 4de8 4dec 4def
4df3 4df7 4dfa 4dfd 4e02 4e05 4e08 4e0b
4e0c 4e11 4e12 1 4e14 4e19 4e1d 4e21
4e24 4e29 4e2e 4e31 4e35 4e36 4e3b 4e3e
4e43 4e44 4e49 4e4c 4e51 4e52 4e57 4e5a
4e5e 4e62 4e66 4e6a 4e6d 4e6e 4e70 4e75
4e76 4e78 4e79 4e7e 4e81 4e86 4e87 4e8c
4e8f 4e94 4e95 4e9a 4e9d 4ea1 4ea2 4ea7
4eaa 4eaf 4eb0 4eb5 4eb6 4ebb 4ebd 4ec1
4ec4 4ec8 4ecc 4ecf 4ed3 4ed7 4eda 4edd
4ee2 4ee5 4ee8 4eeb 4eec 4ef1 4ef2 1
4ef4 4ef9 4efd 4f01 4f04 4f09 4f0e 4f11
4f15 4f16 4f1b 4f1c 4f21 4f23 4f27 4f2a
4f2e 4f32 4f35 4f39 4f3d 4f40 4f44 4f48
4f49 4f4e 4f50 4f54 4f57 4f59 4f5d 4f61
4f64 4f68 4f6c 4f70 4f74 4f78 4f84 4f88
4f8c 4f8f 4f93 4f97 4f99 4f9d 4fa1 4fa5
4fa8 4fac 4fb0 4fb2 4fb3 4fb8 1 4fbc
4fc0 4fc4 4fc7 4fcb 4fcf 4fd3 4fd7 4fda
4fde 4fe2 4fe5 4fe8 4fed 4ff0 4ff3 4ff6
4ff7 4ffc 4ffd 1 4fff 5004 5008 500c
500f 5014 5019 501c 5020 5021 5026 5029
502e 502f 5034 5037 503c 503d 5042 5045
5049 504a 504f 5052 5057 5058 505d 5060
5064 5068 506b 506e 506f 5071 5072 5077
5078 507d 507f 5083 5086 5088 508c 508e
509a 509c 509e 509f 50a4 50a8 50aa 50b6
50b8 50bc 50c0 50c3 50c6 50c7 50c9 50cc
50d1 50d2 50d7 50db 50de 50e1 50e2 50e7
50eb 50ef 50f3 50f6 50fa 50fe 5102 5106
510a 510e 5112 5116 511a 511e 5122 5123
5125 5129 512b 512f 5132 5134 5138 513b
513f 5143 5146 5149 514a 514c 514f 5154
5155 515a 515e 5162 5166 5169 516d 516f
5173 5177 517b 517e 517f 5181 5185 5187
518b 518f 5192 5196 519a 519e 51a2 51a6
51aa 51ae 51b2 51b6 51ba 51be 51c2 51c6
51ca 51ce 51d2 51d6 51da 51de 51e2 51e6
51ea 51ee 51f2 51f6 51fa 51fe 5202 5206
520a 520d 5210 5213 5216 5219 521a 521c
5220 5224 5227 522a 522b 5230 5234 5238
523c 5240 524c 5250 5255 5259 525c 525d
5262 5266 526a 526d 5270 5274 5276 527a
527e 5281 5284 5288 528a 528e 5292 5295
5297 529b 529f 52a3 52a6 52aa 52ae 52b0
52b1 52b6 1 52ba 52be 52c2 52c5 52c9
52cd 52d1 52d5 52d8 52dc 52e0 52e3 52e6
52eb 52ee 52f1 52f4 52f5 52fa 52fb 1
52fd 5302 5306 530a 530d 5312 5317 531a
531e 531f 5324 5327 532c 532d 5332 5335
533a 533b 5340 5343 5347 5348 534d 5350
5355 5356 535b 535e 5362 5366 5369 536c
536d 536f 5370 5375 5376 537b 537d 5381
5384 5386 538a 538c 5398 539a 539c 539d
53a2 53a6 53a8 53b4 53b6 53b8 53bc 53bf
53c1 53c5 53ca 53ce 53d2 53d7 53db 53df
53e3 53e7 53eb 53ef 53f3 53f4 53f6 53f9
53fa 53fc 53ff 5402 5403 5408 540c 540f
5413 5415 5419 541d 5421 5425 5429 542a
542c 542f 5430 5432 5435 5438 5439 543e
5441 5444 5447 5448 544d 544e 5450 5454
5456 545a 545e 5461 5465 5468 546b 546c
5471 5475 5478 547c 5480 5484 5488 548b
548c 548e 5492 5495 5499 549a 549f 54a1
54a5 54a9 54ad 54b0 54b3 54b6 54ba 54be
54c1 54c2 54c4 54c7 54ca 54cb 54d0 54d3
54d6 54d7 54dc 54e0 54e1 54e3 54e7 54eb
54ef 54f3 54f6 54f9 54fc 5500 5504 5507
5508 550a 550d 5510 5511 5516 5519 551c
551d 5522 5525 5528 5529 552e 5532 5533
5535 5539 553d 5541 5544 5547 5548 554a
554d 5552 5553 5558 555c 5560 5564 5567
556b 556f 5573 5577 5578 557a 557d 557e
5580 5583 5586 5587 558c 5590 5594 5598
559a 559e 55a2 55a6 55a9 55ae 55af 55b4
55b7 55ba 55bb 55bd 55c1 55c5 55c9 55cd
55d0 55d4 55d5 55da 55dd 55e0 55e1 55e3
55e7 55e9 55ed 55f1 55f4 55f6 55fa 55fe
5602 5605 5606 5608 560c 5610 5614 5618
5619 561b 561e 561f 5621 5624 5627 5628
562d 5631 5635 5639 563b 563f 5643 5647
564a 564f 5650 5655 5658 565b 565c 565e
5662 5666 566a 566e 5671 5675 5676 567b
567e 5681 5682 5684 5688 568a 568e 5692
5695 5697 569b 569f 56a2 56a6 56aa 56ad
56b0 56b1 56b3 56b6 56bb 56bc 56c1 56c5
56c8 56cc 56ce 56d2 56d5 56d9 56dc 56e0
56e4 56e7 56eb 56ef 56f3 56f7 56fb 56ff
5703 5707 570b 570f 5713 5717 571b 5727
572b 572f 5732 5736 573a 573c 5740 5744
5748 574b 574f 5753 5755 5756 575b 1
575f 5763 5767 576a 576e 5772 5776 577a
577d 5781 5785 5788 578b 5790 5793 5796
5799 579a 579f 57a0 1 57a2 57a7 57ab
57af 57b2 57b7 57bc 57bf 57c3 57c4 57c9
57cc 57d1 57d2 57d7 57da 57df 57e0 57e5
57e8 57ec 57ed 57f2 57f5 57fa 57fb 5800
5803 5807 580b 580e 5811 5812 5814 5815
581a 581b 5820 5822 5826 5829 582b 582f
5831 583d 583f 5841 5842 5847 584b 584d
5859 585b 585f 5863 5866 586a 586d 5871
5874 5875 587a 587d 5881 5885 5889 588d
5891 5895 5899 589d 58a1 58a5 58a9 58ad
58b9 58bd 58c1 58c4 58c8 58cc 58ce 58d2
58d6 58da 58dd 58e1 58e5 58e7 58e8 58ed
1 58f1 58f5 58f9 58fc 5900 5904 5908
590c 590f 5913 5917 591a 591d 5922 5925
5928 592b 592c 5931 5932 1 5934 5939
593d 5941 5944 5949 594e 5951 5955 5956
595b 595e 5963 5964 5969 596c 5971 5972
5977 597a 597e 597f 5984 5987 598c 598d
5992 5995 5999 599d 59a0 59a3 59a4 59a6
59a7 59ac 59ad 59b2 59b4 59b8 59bb 59bd
59c1 59c3 59cf 59d1 59d3 59d4 59d9 59dd
59df 59eb 59ed 59f1 59f5 59f8 59fc 59ff
5a03 5a06 5a07 5a0c 5a0f 5a13 5a16 5a1a
5a1c 5a20 5a24 5a28 5a2a 5a2e 5a32 5a35
5a37 5a3b 5a3e 5a42 5a46 5a49 5a4a 5a4c
5a4f 5a52 5a53 5a58 5a5c 5a60 5a63 5a64
5a66 5a69 5a6c 5a6d 5a72 5a76 5a7a 5a7d
5a7e 5a80 5a83 5a86 5a87 5a8c 5a90 5a94
5a98 5a9b 5a9c 5a9e 5aa2 5aa4 5aa8 5aac
5ab0 5ab4 5ab8 5abb 5abc 5abe 5ac1 5ac5
5ac9 5acc 5acd 5acf 5ad0 5ad5 5ad8 5ad9
5adb 5ade 5ae1 5ae2 5ae7 5aea 5aed 5aee
5af3 5af4 5af6 5afa 5afc 5b00 5b04 5b07
5b0b 5b0c 5b10 5b14 5b18 5b1c 5b20 5b24
5b28 5b2c 5b30 5b34 5b38 5b3c 5b40 5b44
5b48 5b4c 5b50 5b54 5b58 5b5c 5b60 5b64
5b68 5b6c 5b70 5b74 5b78 5b7c 5b80 5b84
5b88 5b8c 5b90 5b94 5ba0 5ba4 5ba8 5bab
5baf 5bb3 5bb5 5bb9 5bbd 5bc1 5bc4 5bc8
5bcc 5bce 5bcf 5bd4 1 5bd8 5bdc 5be0
5be3 5be7 5beb 5bef 5bf3 5bf6 5bfa 5bfe
5c01 5c04 5c09 5c0c 5c0f 5c12 5c13 5c18
5c19 1 5c1b 5c20 5c24 5c28 5c2b 5c30
5c35 5c38 5c3c 5c3d 5c42 5c45 5c4a 5c4b
5c50 5c53 5c58 5c59 5c5e 5c61 5c65 5c66
5c6b 5c6e 5c73 5c74 5c79 5c7c 5c80 5c84
5c87 5c8a 5c8b 5c8d 5c8e 5c93 5c94 5c99
5c9b 5c9f 5ca2 5ca4 5ca8 5caa 5cb6 5cb8
5cba 5cbb 5cc0 5cc4 5cc6 5cd2 5cd4 5cd8
5cdb 5cdc 5ce1 5ce4 5ce8 5cec 5cf0 5cf4
5cf8 5cfc 5d00 5d04 5d08 5d0c 5d10 5d14
5d18 5d1c 5d28 5d2c 5d30 5d33 5d37 5d3b
5d3d 5d41 5d45 5d49 5d4c 5d50 5d54 5d56
5d57 5d5c 1 5d60 5d64 5d68 5d6b 5d6f
5d73 5d77 5d7b 5d7e 5d82 5d86 5d89 5d8c
5d91 5d94 5d97 5d9a 5d9b 5da0 5da1 1
5da3 5da8 5dac 5db0 5db3 5db8 5dbd 5dc0
5dc4 5dc5 5dca 5dcd 5dd2 5dd3 5dd8 5ddb
5de0 5de1 5de6 5de9 5ded 5dee 5df3 5df6
5dfb 5dfc 5e01 5e04 5e08 5e0c 5e0f 5e12
5e13 5e15 5e16 5e1b 5e1c 5e21 5e23 5e27
5e2a 5e2c 5e30 5e32 5e3e 5e40 5e42 5e43
5e48 5e4c 5e4e 5e5a 5e5c 5e5e 5e62 5e65
5e69 5e6b 5e6f 5e73 5e76 5e7a 5e7e 5e81
5e82 5e84 5e87 5e8a 5e8b 5e90 5e94 5e98
5e9b 5e9f 5ea3 5ea6 5ea7 5ea9 5eac 5eaf
5eb0 1 5eb5 5eba 5ebe 5ec2 5ec6 5eca
5ece 5ed2 5ed6 5eda 5ede 5eea 5eee 5ef2
5ef5 5ef9 5efd 5eff 5f03 5f07 5f0b 5f0e
5f12 5f16 5f18 5f19 5f1e 1 5f22 5f26
5f2a 5f2d 5f31 5f35 5f39 5f3d 5f40 5f44
5f48 5f4b 5f4e 5f53 5f56 5f59 5f5c 5f5d
5f62 5f63 1 5f65 5f6a 5f6e 5f72 5f75
5f7a 5f7f 5f82 5f86 5f87 5f8c 5f8f 5f94
5f95 5f9a 5f9d 5fa2 5fa3 5fa8 5fab 5faf
5fb0 5fb5 5fb8 5fbd 5fbe 5fc3 5fc6 5fca
5fce 5fd1 5fd4 5fd5 5fd7 5fd8 5fdd 5fde
5fe3 5fe5 5fe9 5fec 5fee 5ff2 5ff4 6000
6002 6004 6005 600a 600e 6010 601c 601e
6020 6024 6028 602c 6030 6034 6038 603c
603e 6042 6046 6049 604b 604f 6053 6057
605b 605f 6063 6065 6069 606d 6070 6074
6078 607b 607c 607e 6081 6084 6085 608a
608e 6092 6095 6098 6099 609b 609e 60a3
60a4 60a9 60ad 60b0 60b4 60b6 60ba 60bd
60c1 60c3 60c7 60cb 60ce 60d1 60d2 60d4
60d7 60dc 60dd 60e2 60e6 60ea 60ee 60f1
60f5 60f7 60fb 60ff 6103 6107 610a 610b
610d 6111 6113 6117 611b 611e 6122 6126
612a 612e 6132 6136 613a 613e 6142 6146
614a 614e 6152 6156 615a 615e 6162 6166
616a 616e 6172 6176 617a 617e 6182 6186
618a 618e 6192 6196 6199 619c 619f 61a2
61a5 61a6 61a8 61ac 61b0 61b3 61b6 61b7
61bc 61c0 61c4 61c8 61cc 61d8 61dc 61e1
61e5 61e8 61e9 61ee 61f2 61f6 61f9 61fc
6200 6202 6206 620a 620d 6210 6214 6216
621a 621e 6221 6223 6227 622b 622f 6232
6236 623a 623c 623d 6242 1 6246 624a
624e 6251 6255 6259 625d 6261 6264 6268
626c 626f 6272 6277 627a 627d 6280 6281
6286 6287 1 6289 628e 6292 6296 6299
629e 62a3 62a6 62aa 62ab 62b0 62b3 62b8
62b9 62be 62c1 62c6 62c7 62cc 62cf 62d3
62d4 62d9 62dc 62e1 62e2 62e7 62ea 62ee
62f2 62f5 62f8 62f9 62fb 62fc 6301 6302
6307 6309 630d 6310 6312 6316 6318 6324
6326 6328 6329 632e 6332 6334 6340 6342
6344 6348 634b 634f 6353 6357 635a 635b
635d 6360 6363 6364 6369 636d 636f 6373
637a 637c 6380 6383 6385 6389 638d 6390
6394 6397 639a 639b 63a0 63a3 63a7 63ab
63ae 63af 63b1 63b4 63b7 63b8 63bd 1
63c0 63c5 63c9 63cd 63d0 63d4 63d8 63db
63de 63e3 63e6 63e9 63ec 63ed 63f2 63f3
1 63f5 63fa 63fe 6402 6405 640a 640f
6412 6416 6417 641c 641f 6424 6425 642a
642d 6432 6433 6438 643b 643f 6443 6447
644b 644e 644f 6451 6456 6457 6459 645a
645f 6462 6467 6468 646d 6470 6475 6476
647b 647e 6482 6483 6488 648b 6490 6491
6496 6497 649c 649e 64a2 64a5 64a9 64ad
64b0 64b4 64b8 64bb 64be 64c3 64c6 64c9
64cc 64cd 64d2 64d3 1 64d5 64da 64de
64e2 64e5 64ea 64ef 64f2 64f6 64f7 64fc
64fd 6502 6504 6508 650b 650f 6513 6516
651a 651e 6521 6525 6529 652a 652f 6531
6535 6538 653c 6540 6543 6544 6546 6549
654c 654d 6552 6556 655a 655e 6560 6564
6567 656b 656f 6573 6574 6576 6579 657a
657c 657f 6582 6583 6588 658b 658f 6593
6597 6598 659a 659d 659e 65a0 65a3 65a6
65a7 65ac 1 65af 65b4 65b8 65bd 65c0
65c5 65c6 65cb 65ce 65d3 65d4 65d9 65dc
65e1 65e2 65e7 65ea 65ef 65f0 65f5 65f8
65fc 6600 6604 6607 6608 660a 660b 660d
660e 6613 6616 661b 661c 6621 6624 6628
662c 6630 6633 6634 6636 6637 6639 663a
663f 6642 6647 6648 664d 6650 6654 6658
665c 665f 6660 6662 6663 6665 6666 666b
666e 6673 6674 6679 667c 6681 6682 6687
668a 668f 6690 6695 6698 669d 669e 66a3
66a6 66ab 66ac 66b1 66b4 66b9 66ba 66bf
66c2 66c6 66c7 66cc 66cf 66d4 66d5 66da
66dd 66e1 66e2 66e7 66ea 66ef 66f0 66f5
66f8 66fd 66fe 6703 6706 670b 670c 6711
6714 6719 671a 671f 6722 6726 672a 672d
672e 6733 6736 673b 673c 6741 6744 6748
674c 674f 6750 6755 6758 675d 675e 6763
6766 676b 676c 6771 6774 6779 677a 677f
6782 6786 678a 678e 6791 6792 6794 6795
6797 6798 679d 67a0 67a5 67a6 67ab 67ae
67b2 67b6 67ba 67bd 67be 67c0 67c1 67c3
67c4 67c9 67cc 67d1 67d2 67d7 67da 67df
67e0 67e5 67e8 67ec 67f0 67f4 67f7 67f8
67fa 67fb 67fd 67fe 6803 6806 680b 680c
6811 6814 6819 681a 681f 6822 6826 6827
682c 682f 6834 6835 683a 683d 6841 6842
6847 684a 684f 6850 6855 6858 685d 685e
6863 6866 686b 686c 6871 6875 6879 687b
687f 6883 6887 6888 688a 688d 688e 6890
6893 6896 6897 689c 68a0 68a5 68a8 68ad
68ae 68b3 68b6 68bb 68bc 68c1 68c4 68c9
68ca 68cf 68d2 68d7 68d8 68dd 68e0 68e4
68e8 68ec 68ef 68f0 68f2 68f3 68f5 68f6
68fb 68fe 6903 6904 6909 690c 6910 6914
6918 691b 691c 691e 691f 6921 6922 6927
692a 692f 6930 6935 6938 693c 6940 6944
6947 6948 694a 694b 694d 694e 6953 6956
695b 695c 6961 6964 6969 696a 696f 6972
6977 6978 697d 6980 6985 6986 698b 698e
6993 6994 6999 699c 69a1 69a2 69a7 69aa
69ae 69af 69b4 69b7 69bc 69bd 69c2 69c5
69c9 69ca 69cf 69d2 69d7 69d8 69dd 69e0
69e5 69e6 69eb 69ef 69f3 69f5 69f9 69fd
6a01 6a05 6a06 6a08 6a0b 6a0c 6a0e 6a11
6a14 6a15 6a1a 6a1e 6a23 6a26 6a2b 6a2c
6a31 6a34 6a38 6a3c 6a3f 6a40 6a45 6a48
6a4d 6a4e 6a53 6a56 6a5a 6a5e 6a61 6a62
6a67 6a6a 6a6f 6a70 6a75 6a78 6a7d 6a7e
6a83 6a86 6a8b 6a8c 6a91 6a94 6a98 6a9c
6aa0 6aa3 6aa4 6aa6 6aa7 6aa9 6aaa 6aaf
6ab2 6ab7 6ab8 6abd 6ac0 6ac4 6ac8 6acc
6acf 6ad0 6ad2 6ad3 6ad5 6ad6 6adb 6ade
6ae3 6ae4 6ae9 6aec 6af1 6af2 6af7 6afa
6afe 6b02 6b06 6b09 6b0a 6b0c 6b0d 6b0f
6b10 6b15 6b18 6b1d 6b1e 6b23 6b26 6b2b
6b2c 6b31 6b34 6b38 6b39 6b3e 6b41 6b46
6b47 6b4c 6b4f 6b53 6b54 6b59 6b5c 6b61
6b62 6b67 6b6a 6b6f 6b70 6b75 6b78 6b7d
6b7e 6b83 6b87 6b89 6b8d 6b91 6b94 6b98
6b9c 6b9f 6ba3 6ba7 6baa 6bad 6bb2 6bb5
6bb8 6bbb 6bbc 6bc1 6bc2 1 6bc4 6bc9
6bcd 6bd1 6bd4 6bd9 6bde 6be1 6be5 6be6
6beb 6bec 6bf1 6bf3 6bf7 6bfa 6bfe 6c02
6c05 6c09 6c0d 6c10 6c13 6c18 6c1b 6c1e
6c21 6c22 6c27 6c28 1 6c2a 6c2f 6c33
6c37 6c3a 6c3f 6c44 6c47 6c4b 6c4c 6c51
6c52 6c57 6c59 6c5d 6c60 6c64 6c68 6c6c
6c6f 6c73 6c74 6c76 6c7a 6c7c 6c80 6c84
6c87 6c8b 6c8f 6c92 6c96 6c9a 6c9d 6ca0
6ca5 6ca8 6cab 6cae 6caf 6cb4 6cb5 1
6cb7 6cbc 6cc0 6cc4 6cc7 6ccc 6cd1 6cd4
6cd8 6cd9 6cde 6cdf 6ce4 6ce8 6cec 6cef
6cf4 6cf9 6cfc 6d00 6d04 6d07 6d08 6d0d
6d10 6d15 6d16 6d1b 6d1e 6d22 6d26 6d29
6d2a 6d2f 6d30 6d35 6d37 6d3b 6d3e 6d42
6d46 6d4a 6d4e 6d52 6d56 6d5a 6d5e 6d62
6d6e 6d73 6d77 6d7b 6d7f 6d83 6d85 6d86
6d8b 1 6d8f 6d93 6d97 6d9a 6d9e 6da2
6da6 6daa 6dad 6db1 6db5 6db8 6dbb 6dc0
6dc3 6dc6 6dc9 6dca 6dcf 6dd0 1 6dd2
6dd7 6ddb 6ddf 6de2 6de7 6dec 6def 6df3
6df4 6df9 6dfa 6dff 6e03 6e07 6e0a 6e0f
6e14 6e17 6e1b 6e1c 6e21 6e24 6e29 6e2a
6e2f 6e32 6e36 6e3a 6e3d 6e40 6e41 6e43
6e44 6e49 6e4a 6e4f 6e51 6e55 6e58 6e5c
6e60 6e64 6e68 6e6c 6e70 6e74 6e80 6e85
6e89 6e8d 6e91 6e95 6e97 6e9b 6e9d 6ea9
6eab 6ead 6eae 6eb3 6eb7 6eb9 6ec5 6ec9
6ecb 6ecc 6ed5 
2013
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
d 16 15 :2 d :2 4 11 1a 19
:2 11 :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 :3 10 :2 4 11 1a
19 :2 11 :2 4 f 18 17 :2 f :2 4
13 1c 1b :2 13 :2 4 10 19 18
:2 10 :2 4 18 21 20 :2 18 :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 10 19 18 :2 10 :2 4 :3 9 :2 4
:3 9 :2 4 10 19 18 :2 10 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 b
1a b :2 4 :2 d 1c d :2 4 :2 10
1f 10 :2 4 :2 a 19 a :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 f
1e f :2 4 :2 b 1a b :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 f
1e f :2 4 :2 b 1a b :2 4 :2 f
19 f :2 4 :2 f 1e f :2 4 :2 16
25 16 :2 4 :2 11 20 11 :2 4 :2 10
1f 10 :2 4 :2 14 23 14 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 17
26 17 :2 4 17 1c 1b :2 17 :2 4
18 1d 1c :2 18 :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 9 12 11
:2 9 :2 4 :2 11 20 11 :2 4 :2 f 1e
f :2 4 :2 6 1e 6 :2 4 :2 7 1f
7 :2 4 :2 f 27 f :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 14 1d
26 2e :2 1d :2 14 :2 4 12 :2 4 10
4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 18 :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 8 11 1c :2 8 22 1f
:2 2b :2 1f 7 :4 46 45 44 :2 7 :4 14
13 12 :2 7 11 1c 21 33 3e
43 :2 f :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 8b 8e :2 27 96 99
:2 27 a5 a8 af b8 bb :2 a8 :2 27
:2 10 5c :2 d :2 a :4 16 :2 a 7 :3 31
b :2 14 1f 1d :2 28 :2 1d a 3d
46 4f :2 3d 52 54 :2 52 3c :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 c0 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 50 :2 a 57 :3 7
e 7 4 31 :4 c b a :4 2a
29 28 :2 a 11 23 f :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :4 43 31 :3 4 d :2 16
22 29 32 3e :2 29 42 :2 4b :2 22
21 5a :2 d :2 4 13 1a 23 2f
:2 1a 33 :2 3c :2 13 12 4 7 10
1c :2 7 21 1f :2 2a :2 1f 7 15
7 3f :2 4 7 10 18 :2 7 1b
1d :2 1b 11 1a 30 39 51 f
1a 26 f 1d 2a :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f b :2 14 1f 1d :2 28
:2 1d a 26 31 3d 4d 5d 6a
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 27 bf c2
:2 27 ca cd :2 27 d2 d5 :2 27 e2
e5 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 45 53 :2 d
3b :2 a 38 :3 7 15 7 11 21
f 10 1d :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 1f a 13 1f :2 a 22 24 :2 22
14 24 12 13 20 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 26 d :2 18 1f 2d :2 d
32 34 :2 32 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 bb :2 8c :2 27 c3 c6 :2 27 ce
d1 :2 27 d6 d9 :2 27 e6 e9 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 49 57 :2 d 36 :2 a
26 :2 7 1f :4 b a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 b9 :2 89 :2 24 :2 d 58
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 2b
:2 34 49 :2 a 1e :3 7 16 :2 7 13
1a 21 2e 31 :2 1a 36 39 :2 13
:2 7 15 :2 1e 27 2a 2d 31 :2 15
7 a 18 21 29 :2 18 :2 a 2d
30 :2 2d 14 20 29 3f 48 60
12 20 2b 37 12 20 2d 3b
47 50 5b 64 70 79 87 90
9e a7 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 32
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e1 e4 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3b :2 a 32 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 24 be c1
:2 24 c9 cc :2 24 d1 d4 :2 24 de
e1 :2 24 :2 d 59 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 29 :2 32 44 4f :2 a
:4 7 :4 4 8 11 1d :2 8 20 22
:2 20 7 2a 33 3b :2 2a 3e 41
:2 3e 29 :3 7 11 7 46 :2 4 7
b d :2 b 7 15 :2 7 16 :2 7
15 26 32 3f 48 51 :2 3f 55
5e 66 :2 55 22 2b 37 :2 22 3b
44 4f :2 3b 53 20 2b :2 53 2f
38 46 :2 2f 4a 53 5e :2 4a 22
2b 37 :2 22 3b 43 4d :2 15 7
a 13 1f :2 a 24 22 :2 2d :2 22
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 44 :2 a 7 3c
d 16 22 :2 d 25 28 :2 25 d
:2 17 29 :2 33 3f 43 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 92 a7 :2 89 :2 24 af
b2 :2 24 ba bd :2 24 c2 c5 :2 24
d2 d5 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 32 3e :2 29
42 50 :2 a 2a 3c :2 7 f 7
16 7 a 13 1b :2 a 1e 20
:2 1e a 14 1d 25 :2 14 28 2a
33 3f :2 2a :2 14 a 22 :2 7 :4 4
8 11 19 :2 8 1c 1e :2 1c 7
26 2f 37 :2 26 3a 3d :2 3a 25
:2 7 b 14 1c :2 b 1f 21 :2 1f
a 28 31 39 :2 28 3c 3e :2 3c
27 :3 a 15 a 7 41 d 16
1e :2 d 21 23 :2 21 a 15 a
7 25 41 e 17 1f :2 e 22
24 :2 22 d 2b 34 3c :2 2b 3f
41 :2 3f 2a :2 d a 15 a 7
44 41 d 16 1e :2 d 21 23
:2 21 a 15 a 25 41 :2 7 42
:3 4 :3 17 :2 4 12 :2 4 13 :2 4 13
:2 4 13 :2 4 10 17 21 24 :2 10
:2 4 12 19 25 28 :2 12 4 7
10 18 :2 7 1b 1d :2 1b 7 f
:2 7 15 7 a 11 1d 20 :2 a
23 25 :2 23 14 27 2f 36 51
59 60 7c 86 d 1b 12 27
2d 33 3f d 19 12 13 1b
2c 38 45 5b :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 29 14 26 37 46 53 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 29 e :2 17 22
20 :2 2b :2 20 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 a6 :2 95 b9 :2 8c :2 27 c1 c4 :2 27
cc cf :2 27 d4 d7 :2 27 e0 e3
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 47 51 :2 d 3b
:3 a 19 a 14 27 38 45 12
13 20 2e 46 54 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 29 7 29 d 14 20
23 :2 d 26 28 :2 26 14 23 34
44 52 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 2c
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e0 e3 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
51 :2 d 3b :3 a 18 a 14 27
2f 36 51 59 60 7c 86 d
1b 12 27 2d 33 3f d 19
12 13 1b 2c 38 45 5b :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 2c e :2 17 22
20 :2 2b :2 20 :2 d 1b d 17 2a
32 39 54 5c 63 7f 89 10
1e 15 2a 30 36 42 10 1c
15 16 1e 2f 3b 48 5e :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :3 3b 11 :2 1a 25
23 :2 2e :2 23 :2 10 1e 1f :2 1e 10
13 21 2a 32 :2 21 :2 13 36 39
:2 36 13 21 13 1d 2d 3d 60
1c 29 3a 45 54 62 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 61 64 65
:2 61 :2 38 :3 1c :2 22 27 33 71 74
:2 33 81 84 :2 33 88 8b :2 33 97
9a :2 33 a2 a5 :2 33 b1 b4 bb
c4 c7 :2 b4 :2 33 :2 1c 68 :2 19 :2 16
:4 22 :2 16 13 :3 3b 16 1f 2b :2 16
2e 31 :2 2e 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 92 95 9e a6 :2 af
:2 9e d0 :2 95 :2 30 d8 db :2 30 e3
e6 :2 30 eb ee :2 30 f7 fa :2 30
:2 19 65 :2 16 19 :2 23 35 :2 3f 4b
4e 5d 60 61 :2 5d :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 :2 19 64 :3 16
:2 21 35 :2 3e 5e 1e :2 16 33 :2 13
3b :2 10 3e :2 d 3b :2 a 14 27
38 45 12 13 20 2e 46 54
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :4 2c 29 d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 a3 :2 92 b4 :2 89 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 44 :2 a :4 7 b :2 14
1f 1d :2 28 :2 1d :2 a 1d 2b 2e
37 3f :2 2e 43 :2 4c 24 :2 1d :2 a
1d 2b 2e 37 3f :2 2e 43 :2 4c
24 :2 1d a 14 2d 12 20 38
49 52 5d 66 72 7b 89 92
a0 a9 bd c6 12 20 39 42
12 20 38 41 12 1b 23 30
39 :2 12 20 3a 12 13 27 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 38
a 1d 33 :2 1d a 38 a :3 19
:2 a 1d 2b 2e 37 3f :2 2e 43
:2 4c 24 :2 1d :2 a 20 :2 29 :2 a 1c
:2 a 1d 34 42 4c 54 2d 41
4d :2 1d a 19 2e 41 4d 59
67 d 1c 29 36 43 4d 15
22 30 3b 43 d 19 23 2c
39 4d 5a d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :7 7 b 14 21 :2 b
24 26 :2 24 a :4 2e 2d :2 a 45
50 52 :2 50 44 :2 a d 16 1e
:2 d 21 23 :2 21 10 19 21 :2 10
24 27 :2 24 10 1e 27 2f :2 1e
10 2b 10 1e 24 2f 38 40
:2 2f 43 45 4e 59 :2 45 :2 2f 2e
:2 24 5e 60 :2 24 68 6a :2 24 :2 1e
10 :5 d 15 d 17 1b 1f 2e
15 2a 2f 40 16 1a 27 14
18 2c 14 18 24 2c 33 14
18 14 18 25 14 18 23 27
15 19 29 2d 3b :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6b 6e :2 2d
7b 7e :2 2d 82 85 :2 2d 91 94
:2 2d 9c 9f :2 2d ab ae b5 be
c1 :2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :3 25 :4 11 10 1b 26 33
3b 42 5a 65 7b 8b :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 61 62
:2 5e :2 35 :3 19 :2 1f 24 30 6e 71
:2 30 7e 81 :2 30 85 88 :2 30 94
97 :2 30 9f a2 :2 30 ae b1 b8
c1 c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13
:4 1f :2 13 10 :4 1f 1a 25 32 3c
45 55 66 18 19 26 17 2b
17 22 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 94 97 :2 30 9f a2
:2 30 ae b1 b8 c1 c4 :2 b1 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :7 d
10 14 16 :2 14 1c :2 27 2f 3b
48 :2 1c 4c 4e :2 4c :2 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8c 8f
98 a0 :2 a9 :2 98 c1 :2 8f :2 2a c9
cc :2 2a d4 d7 :2 2a dc df :2 2a
e8 eb :2 2a :2 13 5f :2 10 13 :2 1d
2f :2 39 45 48 57 5a 5b :2 57
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
:2 13 5e :3 10 :2 1b 2f :2 38 4f 59
:2 10 50 :2 d a 25 10 14 16
:2 14 d 20 d 17 1b 2b 15
16 23 14 28 14 25 2d 34
4c 54 5b :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6b 6e :2 2d 7b 7e
:2 2d 82 85 :2 2d 91 94 :2 2d 9c
9f :2 2d ab ae b5 be c1 :2 ae
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:3 18 d 1c d 17 1b 2f 15
16 23 30 41 49 50 68 70
77 :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5e 5f :2 5b :2 32 :3 16 :2 1c 21
2d 6b 6e :2 2d 7b 7e :2 2d 82
85 :2 2d 91 94 :2 2d 9c 9f :2 2d
ab ae b5 be c1 :2 ae :2 2d :2 16
62 :2 13 :2 10 :4 1c :2 10 d :3 18 10
19 26 :2 10 29 2c 35 46 :2 2c
49 4b 54 5e :2 4b :2 2c 2b :2 29
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8c 8f 98 a0 :2 a9 :2 98 c1 :2 8f
:2 2a c9 cc :2 2a d4 d7 :2 2a dc
df :2 2a e8 eb :2 2a :2 13 5f :2 10
13 :2 1d 2f :2 39 45 48 57 5a
5b :2 57 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a :2 13 5e :3 10 :2 1b 2f :2 38
4f 59 :2 10 62 :2 d 18 25 :2 a
14 36 4a 60 6d :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 55 d 14 24 27 :2 d
2a 2c :2 2a d 1d 1e :2 1d :2 d
:2 16 22 39 47 55 6a 2f 35
41 4d 2f 42 :2 22 d 30 :2 a
55 :2 7 a 11 1d 20 :2 a 23
25 :2 23 a 15 :2 1e a 29 a
15 1e 2a :2 15 a :5 7 13 1f
2c 3a 45 4f 5b 1b 28 35
42 4f 1b 28 34 3e 46 4f
57 5e 1b 27 34 3f 4a 58
1b 26 32 3e 41 44 4a 50
:2 13 7 a 13 15 :2 13 14 27
44 4b d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :4 17 :2 7 1f 7 15 :2 7
16 :2 7 16 7 a 13 1a :2 13
28 :2 a 2b 2d :2 2b a 16 a
30 a 16 1d 26 2d :2 26 3b
:2 1d 3e 40 :2 1d 1c 43 45 :2 1c
:2 16 a :4 7 a 13 15 :2 13 a
15 :2 a 10 19 22 :2 10 27 25
30 :2 25 a d 19 :2 22 2b 2f
33 3c 45 :2 33 48 4a :2 33 4c
4d :2 33 50 :2 19 :2 d 1b :2 24 2d
30 33 3c 45 :2 33 48 4a :2 33
4d 4f :2 33 51 52 :2 33 55 :2 1b
d 10 17 23 26 :2 10 29 2b
:2 29 10 1b :2 24 10 13 1c 23
:2 1c 31 :2 13 34 36 :2 34 13 22
13 38 13 22 29 35 38 :2 29
41 44 :2 22 :2 13 22 29 35 38
:2 29 42 45 :2 22 13 :4 10 2f 10
1b 24 30 :2 1b 10 13 1c 23
:2 1c 30 :2 13 33 35 :2 33 13 21
13 37 13 21 28 33 36 :2 28
3f 42 :2 21 :2 13 21 28 33 36
:2 28 40 43 :2 21 13 :4 10 :4 d 10
17 23 26 :2 10 29 2b :2 29 10
1f 10 2f :3 d 1b :2 d 1c d
17 2a 34 15 2a 36 15 16
1e 2f 3b 48 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5b 5e 5f :2 5b :2 32
:3 16 :2 1c 21 2d 6b 6e :2 2d 7b
7e :2 2d 82 85 :2 2d 91 94 :2 2d
9c 9f :2 2d ab ae b5 be c1
:2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10
d :3 30 11 :2 1a 25 23 :2 2e :2 23
10 1a 2d 37 18 2d 39 18
19 21 32 3e 4b :2 13 :2 1c 28
13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 61 62 :2 5e
:2 35 :3 19 :2 1f 24 30 6e 71 :2 30
7e 81 :2 30 85 88 :2 30 94 97
:2 30 9f a2 :2 30 ae b1 b8 c1
c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f
:2 13 10 :3 3e 14 :2 1d 28 26 :2 31
:2 26 :2 13 22 13 41 13 21 13
:4 10 3e :2 d 10 19 26 :2 10 29
2b :2 29 13 1c 24 :2 13 27 29
:2 27 16 1f 27 :2 16 2a 2d :2 2a
16 24 2d 35 :2 24 16 31 16
24 2a 35 3e 46 :2 35 49 4b
54 5f :2 4b :2 35 34 :2 2a 64 66
:2 2a 6e 70 :2 2a :2 24 16 :5 13 1b
13 1d 21 25 34 1b 30 35
46 1c 20 2d 1a 1e 32 1a
1e 2a 32 39 1a 1e 1a 1e
2b 1a 1e 29 2d 1b 1f 2f
33 41 :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 61 65 66 :2 61 :2 38 :3 1c :2 22
27 33 72 75 :2 33 82 85 :2 33
89 8c :2 33 98 9b :2 33 a3 a6
:2 33 b2 b5 bc c5 c8 :2 b5 :2 33
:2 1c 69 :2 19 :2 16 :4 22 :2 16 13 :3 2b
:4 17 16 20 2b 38 42 4b 5b
6c 1e 1f 2c 1d 31 1d 28
:2 19 :2 22 2e 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 64
68 69 :2 64 :2 3b :3 1f :2 25 2a 36
75 78 :2 36 85 88 :2 36 8c 8f
:2 36 9b 9e :2 36 a6 a9 :2 36 b5
b8 bf c8 cb :2 b8 :2 36 :2 1f 6c
:2 1c :2 19 :4 25 :2 19 16 :4 29 :2 13 10
2b 16 :2 21 29 37 43 :2 16 47
4a :2 47 50 :2 5b 63 18 25 :2 50
29 2c :2 29 :2 16 1f 2a 37 3f
46 64 6f 1d 2d :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 61 65 66 :2 61
:2 38 :3 1c :2 22 27 33 72 75 :2 33
82 85 :2 33 89 8c :2 33 98 9b
:2 33 a3 a6 :2 33 b2 b5 bc c5
c8 :2 b5 :2 33 :2 1c 69 :2 19 :2 16 :4 22
:2 16 13 :4 2e 2b 13 21 :2 13 22
13 :4 10 2d 10 1e :2 10 1f 10
:4 d 10 19 25 :2 10 28 2a :2 28
13 1a 26 29 :2 13 2c 2e :2 2c
13 1f 13 32 :2 10 d 2c 13
1a 26 29 :2 13 2c 2e :2 2c 10
1b :2 24 10 32 2c 10 1b 24
30 :2 1b 10 :5 d 19 25 32 40
4b 55 61 1b 28 35 42 4f
1b 28 34 3e 46 4f 57 5e
1b 27 34 3f 4a 58 1b 26
32 3e 41 44 4a 50 :2 19 d
10 19 1b :2 19 1a 2d 4a 51
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 62 63 :2 5e :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:4 1d :3 d 18 21 2a :2 18 2d 2f
:2 18 d 30 e a 17 :2 7 :4 4
8 11 14 :2 11 7 1c 25 2d
:2 1c 30 32 :2 30 1b :2 7 a :2 14
26 :2 30 3c 40 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 60 63 :2 21
70 73 :2 21 77 7a :2 21 84 87
90 98 :2 a1 :2 90 c2 :2 87 :2 21 ca
cd :2 21 d5 d8 :2 21 dd e0 :2 21
ec ef :2 21 :2 a 57 :2 7 a :2 14
26 :2 30 3c 3f 4e 52 53 :2 4e
:2 26 :3 a :2 10 15 21 60 63 :2 21
:2 a 56 :3 7 :2 12 26 :2 2f 4f f
:2 7 35 :2 4 7 10 18 :2 7 1b
1d :2 1b 7 17 7 1f :2 4 8
11 18 :2 11 25 :2 8 28 2a :2 28
7 32 3b 42 :2 3b 50 :2 32 53
55 :2 53 31 :3 7 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d 2c 2f 37 40 4a :2 37 :2 2f
:2 d 4e 51 :2 d 13 16 1e 27
30 :2 1e :2 16 :2 d 13 16 :2 d e
11 19 22 2d :2 19 :2 11 :2 d 13
16 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d 29 2c :2 d 13 16 :2 d 4e
51 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 1a :2 d 32 35 :2 d 48 4b :2 54
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d 47 4a 52 5b 65 :2 52
:2 4a :2 d 13 16 :2 d 2a 2d 35
3e 47 :2 35 :2 2d :2 d 4b 4e :2 d
e 11 :2 d 54 57 5f 13 1e
:2 5f :2 57 :2 d 13 16 :2 d e 11
:2 d 4d 50 :2 d 13 16 :2 d 50
53 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d 7 4 58 a 13
1a :2 13 27 :2 a 2a 2c :2 2a 7
d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 2c 2f 37
40 4a :2 37 :2 2f :2 d 4e 51 :2 d
13 16 1e 27 30 :2 1e :2 16 :2 d
13 16 :2 d e 11 19 22 2d
:2 19 :2 11 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 29 2c :2 d
13 16 :2 d 4e 51 :2 d 13 16
:2 d e 11 :2 d 7 4 2e 58
a 13 1a :2 13 28 :2 a 2b 2d
:2 2b 7 d e 11 :2 d e 11
:2 1a :2 d 32 35 :2 d 48 4b :2 54
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d 47 4a 52 5b 65 :2 52
:2 4a :2 d 13 16 :2 d 2a 2d 35
3e 47 :2 35 :2 2d :2 d 4b 4e :2 d
e 11 :2 d 54 57 5f 13 1e
:2 5f :2 57 :2 d 13 16 :2 d e 11
:2 d 4d 50 :2 d 13 16 :2 d 50
53 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d 7 2f 58 :2 4 7
:2 11 23 :2 2d 39 3c 4b 4f 50
:2 4b :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :2 7 53 :2 4 7 :2 11 23 :2 2d
39 3c 4b 4f 50 :2 4b :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 53
:3 4 b :2 16 26 :2 b 4 1 9
12 9 a :2 14 26 :2 30 3c 40
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 60 63 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 57 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4c 50 51 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 54 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
2013
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :5 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:7 48 :7 49 :6 4a :6 4b
:7 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:5 54 :7 56 :b 58 :11 59
5a :2 59 :2 5a :2 59
:2 5a :2 59 :2 5b :2 59
:2 5b :2 59 :2 5b :2 59
:2 5b :2 59 :2 5c :2 59
:2 5c :2 59 :2 5c :2 59
:2 5c :2 59 :2 5d :2 59
:9 5d :2 59 :2 5e :2 59
:9 5e :2 59 :2 5f :2 59
:9 5f :2 59 :2 60 :2 59
:9 60 :2 59 :2 61 :2 59
:9 61 :2 59 :2 62 :2 59
:9 62 :2 59 :2 63 :2 59
:9 63 :2 59 :2 64 :2 59
:9 64 :2 59 :2 65 :2 59
:9 65 :2 59 :2 66 :2 59
:9 66 :2 59 :2 67 :2 59
:2 67 :2 59 :2 67 :2 59
:2 67 :2 59 :2 68 :2 59
:2 68 :2 59 :2 68 :2 59
:2 68 :2 59 :2 68 :4 59
:3 58 :11 6b :b 6c :3 6b
:3 73 :3 74 :3 75 :3 76
:3 78 :3 7a :3 7c :3 7e
:3 7f :3 80 :3 81 :3 82
:3 83 :3 84 :3 86 :a 87
:3 8b :3 8c :5 8e :11 8f
:20 90 :3 8f :11 92 :b 93
:3 92 :9 95 :3 8e :1f 98
:11 99 :20 9a :3 99 :11 9c
:b 9d :3 9c :9 9f :3 98
:14 a2 :6 a3 :2 a2 :6 a5
a6 a7 a5 :5 a8
a4 aa :5 ab :3 aa
:2 ac :5 ae :11 af :24 b0
:3 af :2 ad :6 ac a9
:3 a3 :16 b5 :11 b6 :20 b7
:3 b6 :11 b9 :b ba :3 b9
:9 bc :3 b5 :3 bf c0
a3 :e c0 :2 c2 c3
c2 :5 c4 c1 c6
:5 c7 :3 c6 :2 c8 :5 ca
:11 cb :24 cc :3 cb :2 c9
:6 c8 c5 :4 c0 a3
:2 a2 :14 d4 :e d6 :b d9
:3 da :3 d9 :9 dd :5 df
:3 e0 :3 e1 df :5 e2
de e4 :5 e5 :3 e4
:2 e6 :5 e8 :11 e9 :24 ea
:3 e9 :2 e7 :6 e6 e3
:3 dd :a ef :7 f1 :5 f2
f0 f4 :5 f5 :3 f4
:2 f6 :5 f8 :11 f9 :24 fa
:3 f9 :2 f7 :6 f6 f3
:3 ef :a fe :11 ff :30 100
:3 ff :11 102 :b 103 :3 102
:a 105 :3 fe :3 ef :3 109
:2 10b 10c :2 10d 10b
:5 10e 10a 110 :5 111
:3 110 :2 112 :5 114 :11 115
:24 116 :3 115 :2 113 :6 112
10f :3 dd :9 11b :2 11d
11e :2 11f 11d :5 120
11c 122 :5 123 :3 122
:2 124 :5 126 :11 127 :24 128
:3 127 :2 125 :6 124 121
:3 11b :b 12d :11 12e :30 12f
:3 12e :11 131 :b 132 :3 131
:a 134 :3 12d :3 11b dd
:5 138 :11 139 :20 13a :3 139
:11 13c :b 13d :3 13c :9 13f
:3 138 :3 142 :d 146 :b 14a
:c 14c :6 14e :4 14f :e 150
14e :5 151 14d 153
:5 154 :3 153 :2 155 :5 157
:11 158 :24 159 :3 158 :2 156
:6 155 152 :3 14c :a 15e
:11 15f :30 160 :3 15f :11 162
:b 163 :3 162 :a 165 :3 15e
14c :11 168 :30 169 :3 168
:11 16b :b 16c :3 16b :a 16e
167 :3 14c 137 :3 dd
:16 173 :3 174 :3 173 :5 177
:3 179 :3 17a :e 17c :b 17d
:2 17e :2 17d :a 17e :8 17f
:3 17c :b 181 :11 182 :20 183
:3 182 :11 185 :b 186 :3 185
:9 188 189 181 :9 189
:11 18a :2e 18b :3 18a :11 18d
:b 18e :3 18d :c 190 189
:3 181 177 :3 193 :9 195
:f 196 :3 195 192 :3 177
:16 199 :16 19a :3 19b 19c
19a :9 19c :3 19d 19e
19c 19a :16 19e :3 19f
1a0 19e 19a :9 1a0
:3 1a1 1a0 :3 19a :3 199
:5 1a5 :3 1a8 :3 1a9 :3 1aa
:3 1ab :8 1ad :8 1af :9 1b4
:3 1b5 :3 1b6 :a 1b7 :9 1b9
:2 1ba :5 1bb :2 1bc 1bd
:6 1be 1b9 :5 1bf 1b8
1c1 :5 1c2 :3 1c1 :2 1c3
:5 1c5 :11 1c6 :24 1c7 :3 1c6
:2 1c4 :6 1c3 1c0 :3 1b7
:6 1cd :5 1ce 1cc 1d0
:5 1d1 :3 1d0 :2 1d2 :5 1d4
:11 1d5 :24 1d6 :3 1d5 :2 1d3
:6 1d2 1cf :3 1b7 :a 1db
:11 1dc :30 1dd :3 1dc :11 1df
:b 1e0 :3 1df :a 1e2 :3 1db
:3 1e5 :4 1e8 1e9 :5 1ea
1e8 :5 1eb 1e7 1ed
:5 1ee :3 1ed :2 1ef :5 1f1
:11 1f2 :24 1f3 :3 1f2 :2 1f0
:6 1ef 1ec :3 1b7 1f7
1b7 :a 1f7 :6 1f9 :5 1fa
1f8 1fc :5 1fd :3 1fc
:2 1fe :5 200 :11 201 :24 202
:3 201 :2 1ff :6 1fe 1fb
:3 1f7 :a 207 :11 208 :30 209
:3 208 :11 20b :b 20c :3 20b
:a 20e :3 207 :3 211 :9 214
:2 215 :5 216 :2 217 218
:6 219 214 :5 21a 213
21c :5 21d :3 21c :2 21e
:5 220 :11 221 :24 222 :3 221
:2 21f :6 21e 21b :3 1f7
:a 228 :3 229 :9 22b :2 22c
:5 22d :2 22e 22f :6 230
22b :5 231 22a 233
:5 234 :3 233 :2 235 :5 237
:11 238 :24 239 :3 238 :2 236
:6 235 232 :3 228 :a 23e
:6 23f :c 241 :3 242 :4 244
:6 245 244 :5 246 243
248 :5 249 :3 248 :2 24a
:5 24c :11 24d :24 24e :3 24d
:2 24b :6 24a 247 :3 241
:9 252 :11 253 :30 254 :3 253
:11 256 :b 257 :3 256 :7 259
25a :2 259 :3 252 :3 241
:3 23e :3 228 :4 261 262
:5 263 261 :5 264 260
266 :5 267 :3 266 :2 268
:5 26a :11 26b :24 26c :3 26b
:2 269 :6 268 265 :4 1f7
1b7 :11 271 :20 272 :3 271
:11 274 :b 275 :3 274 :9 277
270 :3 1b7 :a 27b :b 27c
27d :3 27c :b 27e 27f
:3 27e :2 282 :f 284 :4 285
:4 286 :5 287 288 :3 28a
28b :2 28d 282 :6 28e
:5 28f 28e :5 291 290
:3 28e 281 294 :5 295
:3 294 :2 296 :5 298 :11 299
:24 29a :3 299 :2 297 :6 296
293 :3 27b :6 29f 27b
:5 2a2 :b 2a4 2a5 :3 2a4
:5 2a7 :3 2a8 :6 2aa :3 2ab
:3 2aa :6 2ae :6 2af :5 2b0
:7 2b1 2ae :6 2b2 :5 2b3
2b2 :5 2b5 2b4 :3 2b2
2ad 2b8 :5 2b9 :3 2b8
:2 2ba :5 2bc :11 2bd :24 2be
:3 2bd :2 2bb :6 2ba 2b7
:4 2a0 :3 27b :19 2c5 :9 2c6
:9 2c7 :7 2c8 2c7 :1e 2ca
2c9 :3 2c7 :3 2cd :4 2cf
:4 2d0 :3 2d1 :3 2d2 :5 2d3
:2 2d4 :3 2d5 :4 2d6 :5 2d7
2cf :5 2d8 2ce 2da
:5 2db :3 2da :2 2dc :5 2de
:11 2df :24 2e0 :3 2df :2 2dd
:6 2dc 2d9 :3 2c6 :5 2e5
:a 2e7 :5 2e8 2e6 2ea
:5 2eb :3 2ea :2 2ec :5 2ee
:11 2ef :24 2f0 :3 2ef :2 2ed
:6 2ec 2e9 :4 2e5 :7 2f6
2f7 :2 2f8 :2 2f9 :2 2fa
2f6 :5 2fb 2f5 2fd
:5 2fe :3 2fd :2 2ff :5 301
:11 302 :24 303 :3 302 :2 300
:6 2ff 2fc :4 2f4 :3 2e5
:13 309 :11 30a :30 30b :3 30a
:11 30d :b 30e :3 30d :a 310
:3 309 312 2c6 :5 312
:3 313 :3 315 316 :2 317
:2 318 :7 319 315 :5 31a
314 31c :5 31d :3 31c
:2 31e :5 320 :11 321 :24 322
:3 321 :2 31f :6 31e 31b
:3 312 :3 327 :3 329 32a
:9 32b 329 :5 32c 328
32e :5 32f :3 32e :2 330
:5 332 :11 333 :24 334 :3 333
:2 331 :6 330 32d :3 312
:16 339 :11 33a :30 33b :3 33a
:11 33d :b 33e :3 33d :a 340
:3 339 312 :3 2c6 :6 345
:5 346 344 348 :5 349
:3 348 :2 34a :5 34c :11 34d
:24 34e :3 34d :2 34b :6 34a
347 :3 2c5 :a 354 :6 355
:8 356 :4 357 :2 358 :3 356
:3 354 :3 2c5 :a 35f :5 360
35f :7 363 361 :3 35f
:8 367 :5 368 :8 369 :6 36a
:8 36b :3 367 :5 36e :5 370
:6 371 :5 372 371 :5 374
373 :3 371 36f 377
:5 378 :3 377 :2 379 :5 37b
:11 37c :24 37d :3 37c :2 37a
:6 379 376 :6 36e 1b4
:3 383 :3 384 :3 386 :c 388
:3 389 388 :16 38b 38a
:3 388 :5 38e :3 38f :c 390
:17 393 :1b 395 :a 397 :5 398
:c 39a :3 39b 39a :c 39d
:c 39e 39c :3 39a 397
:7 3a1 :c 3a3 :3 3a4 3a3
:c 3a6 :c 3a7 3a5 :3 3a3
3a0 :3 397 :a 3ab :3 3ac
:3 3ab :3 3af :3 3b0 :3 3b3
:3 3b4 3b5 :5 3b6 3b3
:5 3b7 3b2 3b9 :5 3ba
:3 3b9 :2 3bb :5 3bd :11 3be
:24 3bf :3 3be :2 3bc :6 3bb
3b8 :3 390 :a 3c4 :3 3c6
:3 3c7 3c8 :5 3c9 3c6
:5 3ca 3c5 3cc :5 3cd
:3 3cc :2 3ce :5 3d0 :11 3d1
:24 3d2 :3 3d1 :2 3cf :6 3ce
3cb :3 3c4 :a 3d6 :3 3d7
3d6 :3 3d9 3d8 :3 3d6
:3 3c4 :9 3dd :9 3de :9 3df
:7 3e0 3df :1e 3e2 3e1
:3 3df :3 3e5 :4 3e7 :4 3e8
:3 3e9 :3 3ea :5 3eb :2 3ec
:3 3ed :4 3ee :5 3ef 3e7
:5 3f0 3e6 3f2 :5 3f3
:3 3f2 :2 3f4 :5 3f6 :11 3f7
:24 3f8 :3 3f7 :2 3f5 :6 3f4
3f1 :3 3de :5 3fd :7 3ff
400 :2 401 :2 402 :2 403
3ff :5 404 3fe 406
:5 407 :3 406 :2 408 :5 40a
:11 40b :24 40c :3 40b :2 409
:6 408 405 :6 3fd 411
3de :10 411 :2 412 :2 411
:4 412 :2 411 :7 414 :2 415
414 :5 416 413 418
:5 419 :3 418 :2 41a :5 41c
:11 41d :24 41e :3 41d :2 41b
:6 41a 417 :4 412 3de
:3 423 :3 424 422 :3 3de
3dd :3 427 :3 428 426
:3 3dd :9 42b :a 42d :3 42e
:3 42d 430 42b :a 430
:5 431 430 42b :7 433
432 :3 42b :8 436 :5 437
:8 438 :6 439 :8 43a :3 436
:5 43d :5 43f :6 440 :5 441
440 :5 443 442 :3 440
43e 446 :5 447 :3 446
:2 448 :5 44a :11 44b :24 44c
:3 44b :2 449 :6 448 445
:6 43d :b 452 390 453
390 :3 38e 382 :3 1b4
:12 458 :11 459 :30 45a :3 459
:11 45c :b 45d :3 45c :7 45f
460 :2 45f :3 458 :9 463
:3 464 :3 463 :1c 469 46a
46b :2 46c :2 46b :2 46d
:2 46b :2 46e :2 46b :2 46f
:2 46b :9 46f :2 46b :2 46f
:2 46b :9 470 :2 46b :2 471
:2 46b :9 472 :2 46b :2 473
:2 46b :2 474 :2 46b :2 475
:2 46b :2 476 :2 46b :2 477
:2 46b :2 478 :2 46b :2 478
:2 46b :2 479 :2 46b :2 479
:2 46b :2 47a :2 46b :2 47b
:2 46b :2 47c :2 46b :2 47d
:2 46b :4 47e :2 46b :2 47e
:2 46b :4 47e :2 46b :2 47f
:2 46b :2 480 :2 46b :2 481
:2 46b :9 481 :2 46b :2 482
:2 46b :9 482 :2 46b :2 482
:2 46b :2 483 :2 46b :3 483
:2 484 :4 483 :2 46b :2 485
:2 46b :2 486 :2 46b :2 486
:2 46b :2 487 :2 46b :2 487
:2 46b :2 488 :2 46b :2 489
:2 46b :2 48a :2 46b 46a
48b 469 :c 48b 48c
48d :2 48e :2 48d :2 48f
:2 48d :2 490 :2 48d :2 491
:2 48d :9 491 :2 48d :2 491
:2 48d :9 492 :2 48d :2 493
:2 48d :9 494 :2 48d :2 495
:2 48d :2 496 :2 48d :2 497
:2 48d :2 498 :2 48d :2 499
:2 48d :2 49a :2 48d :2 49a
:2 48d :2 49b :2 48d :2 49b
:2 48d :2 49c :2 48d :2 49d
:2 48d 48c 49e 48b
469 :c 49e 49f 4a0
:2 4a1 :2 4a0 :4 4a2 :2 4a0
:2 4a2 :2 4a0 :4 4a2 :2 4a0
:2 4a3 :2 4a0 :2 4a4 :2 4a0
:2 4a5 :2 4a0 :9 4a5 :2 4a0
:2 4a6 :2 4a0 :9 4a6 :2 4a0
:2 4a6 :2 4a0 :2 4a7 :2 4a0
:3 4a7 :2 4a8 :4 4a7 :2 4a0
:2 4a9 :2 4a0 :2 4aa :2 4a0
:2 4aa :2 4a0 :2 4ab :2 4a0
:2 4ab :2 4a0 :2 4ac :2 4a0
:2 4ad :2 4a0 :2 4ae :2 4a0
49f 49e :3 469 :11 4b2
:b 4b3 :3 4b2 :11 4b5 :b 4b6
:3 4b5 :8 4b8 57 :3 4bc
:11 4bd :b 4be :17 4bf :3 4bd
:2 4c1 :3 4c2 :3 4c3 4c4
4c2 4c1 4c2 :3 4c5
:3 4bc :2 4c6 :5 4c8 :11 4c9
:b 4ca :18 4cb :3 4c9 :2 4cd
4ce :3 4cf 4d0 4ce
4cd 4ce :3 4d1 :2 4c7
:6 4c6 4bb :7 1 
6ed7
4
:3 0 1 :3 0 2
:a 0 200e 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 200e 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 200c
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 200c
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 200c
0 1a :6 0 1d
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 200c
0 1b :6 0 1d
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 200c
0 1c :6 0 1d
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 200c
0 1e :6 0 4d
21f 0 4b 4
:3 0 49 71 73
:6 0 76 74 0
200c 0 1f :6 0
23 :2 0 51 21
:3 0 78 :7 0 7b
79 0 200c 0
20 :6 0 4 :3 0
23 :2 0 4f 7d
7f :6 0 82 80
0 200c 0 22
:6 0 23 :2 0 55
4 :3 0 53 84
86 :6 0 89 87
0 200c 0 24
:6 0 18 :2 0 59
4 :3 0 57 8b
8d :6 0 90 8e
0 200c 0 25
:6 0 18 :2 0 5d
4 :3 0 5b 92
94 :6 0 97 95
0 200c 0 26
:6 0 29 :2 0 61
4 :3 0 5f 99
9b :6 0 9e 9c
0 200c 0 27
:6 0 29 :2 0 65
4 :3 0 63 a0
a2 :6 0 a5 a3
0 200c 0 28
:6 0 29 :2 0 69
4 :3 0 67 a7
a9 :6 0 ac aa
0 200c 0 2a
:6 0 6f 322 0
6d 4 :3 0 6b
ae b0 :6 0 b3
b1 0 200c 0
2b :6 0 2f :2 0
71 21 :3 0 b5
:7 0 b8 b6 0
200c 0 2c :6 0
21 :3 0 ba :7 0
bd bb 0 200c
0 2d :6 0 31
:2 0 75 4 :3 0
73 bf c1 :6 0
c4 c2 0 200c
0 2e :6 0 31
:2 0 77 8 :3 0
c6 :7 0 ca c7
c8 200c 0 30
:6 0 31 :2 0 79
8 :3 0 cc :7 0
d0 cd ce 200c
0 32 :6 0 31
:2 0 7b 8 :3 0
d2 :7 0 d6 d3
d4 200c 0 33
:6 0 31 :2 0 7d
8 :3 0 d8 :7 0
dc d9 da 200c
0 34 :6 0 31
:2 0 7f 8 :3 0
de :7 0 e2 df
e0 200c 0 35
:6 0 31 :2 0 81
8 :3 0 e4 :7 0
e8 e5 e6 200c
0 36 :6 0 31
:2 0 83 8 :3 0
ea :7 0 ee eb
ec 200c 0 37
:6 0 31 :2 0 85
8 :3 0 f0 :7 0
f4 f1 f2 200c
0 38 :6 0 31
:2 0 87 8 :3 0
f6 :7 0 fa f7
f8 200c 0 39
:6 0 31 :2 0 89
8 :3 0 fc :7 0
100 fd fe 200c
0 3a :6 0 31
:2 0 8b 8 :3 0
102 :7 0 106 103
104 200c 0 3b
:6 0 31 :2 0 8d
8 :3 0 108 :7 0
10c 109 10a 200c
0 3c :6 0 31
:2 0 8f 8 :3 0
10e :7 0 112 10f
110 200c 0 3d
:6 0 31 :2 0 91
8 :3 0 114 :7 0
118 115 116 200c
0 3e :6 0 31
:2 0 93 8 :3 0
11a :7 0 11e 11b
11c 200c 0 3f
:6 0 31 :2 0 95
8 :3 0 120 :7 0
124 121 122 200c
0 40 :6 0 31
:2 0 97 8 :3 0
126 :7 0 12a 127
128 200c 0 41
:6 0 31 :2 0 99
8 :3 0 12c :7 0
130 12d 12e 200c
0 42 :6 0 31
:2 0 9b 8 :3 0
132 :7 0 136 133
134 200c 0 43
:6 0 31 :2 0 9d
8 :3 0 138 :7 0
13c 139 13a 200c
0 44 :6 0 31
:2 0 9f 8 :3 0
13e :7 0 142 13f
140 200c 0 45
:6 0 31 :2 0 a1
8 :3 0 144 :7 0
148 145 146 200c
0 46 :6 0 31
:2 0 a3 8 :3 0
14a :7 0 14e 14b
14c 200c 0 47
:6 0 31 :2 0 a5
8 :3 0 150 :7 0
154 151 152 200c
0 48 :6 0 31
:2 0 a7 4a :3 0
156 :7 0 15a 157
158 200c 0 49
:6 0 31 :2 0 a9
8 :3 0 15c :7 0
160 15d 15e 200c
0 4b :6 0 31
:2 0 ab 8 :3 0
162 :7 0 166 163
164 200c 0 4c
:6 0 31 :2 0 ad
8 :3 0 168 :7 0
16c 169 16a 200c
0 4d :6 0 31
:2 0 af 8 :3 0
16e :7 0 172 16f
170 200c 0 4e
:6 0 51 :2 0 b1
8 :3 0 174 :7 0
178 175 176 200c
0 4f :6 0 51
:2 0 b3 4a :3 0
17a :7 0 17e 17b
17c 200c 0 50
:6 0 31 :2 0 b5
4a :3 0 180 :7 0
184 181 182 200c
0 52 :6 0 18
:2 0 b7 8 :3 0
186 :7 0 18a 187
188 200c 0 53
:6 0 18 :2 0 bb
55 :3 0 b9 18c
18e :6 0 191 18f
0 200c 0 54
:6 0 31 :2 0 bf
55 :3 0 bd 193
195 :6 0 198 196
0 200c 0 56
:6 0 31 :2 0 c1
8 :3 0 19a :7 0
19e 19b 19c 200c
0 57 :6 0 5a
:2 0 c3 8 :3 0
1a0 :7 0 1a4 1a1
1a2 200c 0 58
:6 0 31 :2 0 c7
4 :3 0 c5 1a6
1a8 :6 0 1ab 1a9
0 200c 0 59
:6 0 31 :2 0 c9
8 :3 0 1ad :7 0
1b1 1ae 1af 200c
0 5b :6 0 23
:2 0 cb 8 :3 0
1b3 :7 0 1b7 1b4
1b5 200c 0 5c
:6 0 23 :2 0 cd
8 :3 0 1b9 0
2 :5 0 1bd 1ba
1bb 200c 0 5d
:6 0 31 :2 0 cf
8 :3 0 1bf 0
2 :5 0 1c3 1c0
1c1 200c 0 5e
:6 0 31 :2 0 d1
8 :3 0 1c5 0
2 :5 0 1c9 1c6
1c7 200c 0 5f
:6 0 31 :2 0 d3
8 :3 0 1cb 0
2 :5 0 1cf 1cc
1cd 200c 0 60
:6 0 d7 862 0
d5 8 :3 0 1d1
0 2 :5 0 1d5
1d2 1d3 200c 0
61 :6 0 1e2 1e3
0 d9 8 :3 0
1d7 :7 0 1da 1d8
0 200c 0 62
:6 0 15 :3 0 16
:2 0 4 1dc 1dd
0 1de :7 0 1e1
1df 0 200c 0
63 :6 0 64 :3 0
65 :3 0 64 :3 0
66 :3 0 1e5 1e6
0 2 :4 0 db
1e7 1e9 1e4 1eb
1ea :2 0 67 :3 0
68 :3 0 1ed 1ee
0 69 :4 0 64
:3 0 6a :3 0 1f1
1f2 0 2 :4 0
dd 1f3 1f5 6b
:4 0 6c :2 0 6d
:3 0 df 1f8 1fa
:3 0 6e :4 0 6c
:2 0 6f :4 0 e2
1fd 1ff :3 0 6c
:2 0 3 :3 0 e5
201 203 :3 0 6c
:2 0 6f :4 0 e8
205 207 :3 0 6c
:2 0 70 :4 0 eb
209 20b :3 0 6c
:2 0 6f :4 0 ee
20d 20f :3 0 6c
:2 0 5 :3 0 f1
211 213 :3 0 6c
:2 0 6f :4 0 f4
215 217 :3 0 6c
:2 0 70 :4 0 f7
219 21b :3 0 6c
:2 0 6f :4 0 fa
21d 21f :3 0 6c
:2 0 6 :3 0 fd
221 223 :3 0 6c
:2 0 6f :4 0 100
225 227 :3 0 6c
:2 0 70 :4 0 103
229 22b :3 0 6c
:2 0 71 :3 0 72
:3 0 7 :3 0 106
22f 231 73 :4 0
108 22e 234 10b
22d 236 :3 0 6c
:2 0 70 :4 0 10e
238 23a :3 0 6c
:2 0 71 :3 0 72
:3 0 9 :3 0 111
23e 240 73 :4 0
113 23d 243 116
23c 245 :3 0 6c
:2 0 70 :4 0 119
247 249 :3 0 6c
:2 0 71 :3 0 72
:3 0 a :3 0 11c
24d 24f 73 :4 0
11e 24c 252 121
24b 254 :3 0 6c
:2 0 70 :4 0 124
256 258 :3 0 6c
:2 0 71 :3 0 72
:3 0 b :3 0 127
25c 25e 73 :4 0
129 25b 261 12c
25a 263 :3 0 6c
:2 0 70 :4 0 12f
265 267 :3 0 6c
:2 0 71 :3 0 72
:3 0 c :3 0 132
26b 26d 73 :4 0
134 26a 270 137
269 272 :3 0 6c
:2 0 70 :4 0 13a
274 276 :3 0 6c
:2 0 71 :3 0 72
:3 0 d :3 0 13d
27a 27c 73 :4 0
13f 279 27f 142
278 281 :3 0 6c
:2 0 70 :4 0 145
283 285 :3 0 6c
:2 0 71 :3 0 72
:3 0 e :3 0 148
289 28b 73 :4 0
14a 288 28e 14d
287 290 :3 0 6c
:2 0 70 :4 0 150
292 294 :3 0 6c
:2 0 71 :3 0 72
:3 0 f :3 0 153
298 29a 73 :4 0
155 297 29d 158
296 29f :3 0 6c
:2 0 70 :4 0 15b
2a1 2a3 :3 0 6c
:2 0 71 :3 0 72
:3 0 10 :3 0 15e
2a7 2a9 73 :4 0
160 2a6 2ac 163
2a5 2ae :3 0 6c
:2 0 70 :4 0 166
2b0 2b2 :3 0 6c
:2 0 71 :3 0 72
:3 0 11 :3 0 169
2b6 2b8 73 :4 0
16b 2b5 2bb 16e
2b4 2bd :3 0 6c
:2 0 70 :4 0 171
2bf 2c1 :3 0 6c
:2 0 6f :4 0 174
2c3 2c5 :3 0 6c
:2 0 12 :3 0 177
2c7 2c9 :3 0 6c
:2 0 6f :4 0 17a
2cb 2cd :3 0 6c
:2 0 70 :4 0 17d
2cf 2d1 :3 0 6c
:2 0 6f :4 0 180
2d3 2d5 :3 0 6c
:2 0 13 :3 0 183
2d7 2d9 :3 0 6c
:2 0 6f :4 0 186
2db 2dd :3 0 6c
:2 0 74 :4 0 189
2df 2e1 :3 0 18c
1ef 2e3 :2 0 2e5
191 2e6 1ec 2e5
0 2e7 193 0
1f6c 64 :3 0 65
:3 0 2e8 2e9 0
64 :3 0 75 :3 0
2eb 2ec 0 23
:2 0 2 :4 0 76
:2 0 77 :2 0 23
:2 0 195 2f1 2f3
:3 0 198 2ed 2f5
2ea 2f7 2f6 :2 0
67 :3 0 78 :3 0
2f9 2fa 0 69
:4 0 79 :4 0 6c
:2 0 6d :3 0 19c
2fe 300 :3 0 19f
2fb 302 :2 0 304
1a2 305 2f8 304
0 306 1a4 0
1f6c 17 :3 0 3
:3 0 307 308 0
1f6c 1c :3 0 5
:3 0 30a 30b 0
1f6c 1f :3 0 6
:3 0 30d 30e 0
1f6c 1a :3 0 13
:3 0 310 311 0
1f6c 39 :3 0 7
:3 0 313 314 0
1f6c 37 :3 0 9
:3 0 316 317 0
1f6c 38 :3 0 e
:3 0 319 31a 0
1f6c 3a :3 0 b
:3 0 31c 31d 0
1f6c 3c :3 0 f
:3 0 31f 320 0
1f6c 3b :3 0 c
:3 0 322 323 0
1f6c 33 :3 0 11
:3 0 325 326 0
1f6c 32 :3 0 a
:3 0 328 329 0
1f6c 3d :3 0 d
:3 0 32b 32c 0
1f6c 35 :3 0 10
:3 0 32e 32f 0
1f6c 19 :3 0 17
:3 0 331 332 0
1f6c 5b :3 0 7a
:3 0 71 :3 0 33
:3 0 31 :2 0 1a6
336 339 1a9 335
33b 334 33c 0
1f6c 49 :3 0 51
:2 0 33e 33f 0
1f6c 34 :3 0 31
:2 0 341 342 0
1f6c 3 :3 0 7b
:2 0 1ab 345 346
:3 0 347 :2 0 64
:3 0 65 :3 0 349
34a 0 64 :3 0
75 :3 0 34c 34d
0 7c :2 0 2
:4 0 7d :2 0 77
:2 0 23 :2 0 1ad
352 354 :3 0 1b0
34e 356 34b 358
357 :2 0 67 :3 0
78 :3 0 35a 35b
0 69 :4 0 7e
:4 0 6c :2 0 6d
:3 0 1b4 35f 361
:3 0 6c :2 0 7f
:4 0 1b7 363 365
:3 0 6c :2 0 80
:4 0 1ba 367 369
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 82 :3 0 36e
36f 0 1bd 36d
371 73 :4 0 1bf
36c 374 1c2 36b
376 :3 0 1c5 35c
378 :2 0 37a 1c8
37b 359 37a 0
37c 1ca 0 3a5
64 :3 0 65 :3 0
37d 37e 0 64
:3 0 75 :3 0 380
381 0 23 :2 0
2 :4 0 83 :2 0
77 :2 0 23 :2 0
1cc 386 388 :3 0
1cf 382 38a 37f
38c 38b :2 0 67
:3 0 78 :3 0 38e
38f 0 69 :4 0
84 :4 0 6c :2 0
6d :3 0 1d3 393
395 :3 0 1d6 390
397 :2 0 399 1d9
39a 38d 399 0
39b 1db 0 3a5
85 :3 0 86 :3 0
39c 39d 0 81
:3 0 82 :3 0 39f
3a0 0 87 :3 0
1dd 39e 3a3 :2 0
3a5 1e0 3a6 348
3a5 0 3a7 1e4
0 1f6c 71 :3 0
32 :3 0 31 :2 0
1e6 3a8 3ab 88
:2 0 89 :2 0 1eb
3ad 3af :3 0 71
:3 0 3b :3 0 31
:2 0 1ee 3b1 3b4
88 :2 0 89 :2 0
1f3 3b6 3b8 :3 0
3b0 3ba 3b9 :2 0
71 :3 0 37 :3 0
31 :2 0 1f6 3bc
3bf 88 :2 0 89
:2 0 1fb 3c1 3c3
:3 0 3bb 3c5 3c4
:2 0 64 :3 0 65
:3 0 3c7 3c8 0
64 :3 0 75 :3 0
3ca 3cb 0 7c
:2 0 2 :4 0 8a
:2 0 77 :2 0 23
:2 0 1fe 3d0 3d2
:3 0 201 3cc 3d4
3c9 3d6 3d5 :2 0
67 :3 0 78 :3 0
3d8 3d9 0 69
:4 0 8b :4 0 6c
:2 0 6d :3 0 205
3dd 3df :3 0 6c
:2 0 7f :4 0 208
3e1 3e3 :3 0 6c
:2 0 80 :4 0 20b
3e5 3e7 :3 0 6c
:2 0 71 :3 0 72
:3 0 81 :3 0 8c
:3 0 3ec 3ed 0
20e 3eb 3ef 73
:4 0 210 3ea 3f2
213 3e9 3f4 :3 0
216 3da 3f6 :2 0
3f8 219 3f9 3d7
3f8 0 3fa 21b
0 423 64 :3 0
65 :3 0 3fb 3fc
0 64 :3 0 75
:3 0 3fe 3ff 0
23 :2 0 2 :4 0
8d :2 0 77 :2 0
23 :2 0 21d 404
406 :3 0 220 400
408 3fd 40a 409
:2 0 67 :3 0 78
:3 0 40c 40d 0
69 :4 0 8e :4 0
6c :2 0 6d :3 0
224 411 413 :3 0
227 40e 415 :2 0
417 22a 418 40b
417 0 419 22c
0 423 85 :3 0
86 :3 0 41a 41b
0 81 :3 0 8c
:3 0 41d 41e 0
87 :3 0 22e 41c
421 :2 0 423 231
424 3c6 423 0
425 235 0 1f6c
71 :3 0 32 :3 0
31 :2 0 237 426
429 81 :3 0 8f
:2 0 90 :3 0 42b
42d 0 23c 42c
42f :3 0 430 :2 0
5 :3 0 91 :2 0
23f 433 434 :3 0
435 :2 0 436 :2 0
431 438 437 :2 0
6 :3 0 91 :2 0
241 43b 43c :3 0
43d :2 0 43e :2 0
439 440 43f :2 0
92 :3 0 93 :3 0
6 :3 0 92 :3 0
93 :3 0 5 :3 0
45 :3 0 94 :4 0
95 1 :8 0 450
15 :3 0 96 :3 0
44b 44c 0 97
:3 0 44d 44e 0
450 243 4a3 98
:3 0 15 :3 0 96
:3 0 452 453 0
97 :3 0 454 455
0 457 246 459
248 458 457 :2 0
4a1 99 :3 0 15
:3 0 96 :3 0 45c
45d 0 97 :3 0
45e 45f 0 499
64 :3 0 65 :3 0
461 462 0 64
:3 0 75 :3 0 464
465 0 9a :2 0
2 :4 0 9b :2 0
77 :2 0 23 :2 0
24a 46a 46c :3 0
24d 466 46e 463
470 46f :2 0 67
:3 0 78 :3 0 472
473 0 69 :4 0
9c :4 0 6c :2 0
6d :3 0 251 477
479 :3 0 6c :2 0
7f :4 0 254 47b
47d :3 0 6c :2 0
9d :4 0 257 47f
481 :3 0 6c :2 0
97 :3 0 25a 483
485 :3 0 6c :2 0
9e :4 0 25d 487
489 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
260 48c 490 264
48b 492 :3 0 267
474 494 :2 0 496
26a 497 471 496
0 498 26c 0
499 26e 49c :3 0
49c 0 49c 49b
499 49a :6 0 49e
2 :3 0 271 4a0
273 49f 49e :2 0
4a1 275 :2 0 4a3
0 4a3 4a2 450
4a1 :6 0 51e 1
:3 0 15 :3 0 96
:3 0 4a5 4a6 0
15 :3 0 88 :2 0
a2 :3 0 4a8 4aa
0 27a 4a9 4ac
:3 0 4ad :2 0 71
:3 0 45 :3 0 31
:2 0 27d 4af 4b2
a3 :2 0 31 :2 0
282 4b4 4b6 :3 0
4b7 :2 0 4ae 4b9
4b8 :2 0 64 :3 0
65 :3 0 4bb 4bc
0 64 :3 0 75
:3 0 4be 4bf 0
7c :2 0 2 :4 0
a4 :2 0 77 :2 0
23 :2 0 285 4c4
4c6 :3 0 288 4c0
4c8 4bd 4ca 4c9
:2 0 67 :3 0 78
:3 0 4cc 4cd 0
69 :4 0 a5 :4 0
6c :2 0 6d :3 0
28c 4d1 4d3 :3 0
6c :2 0 7f :4 0
28f 4d5 4d7 :3 0
6c :2 0 80 :4 0
292 4d9 4db :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
a6 :3 0 4e0 4e1
0 295 4df 4e3
73 :4 0 297 4de
4e6 29a 4dd 4e8
:3 0 29d 4ce 4ea
:2 0 4ec 2a0 4ed
4cb 4ec 0 4ee
2a2 0 517 64
:3 0 65 :3 0 4ef
4f0 0 64 :3 0
75 :3 0 4f2 4f3
0 23 :2 0 2
:4 0 a7 :2 0 77
:2 0 23 :2 0 2a4
4f8 4fa :3 0 2a7
4f4 4fc 4f1 4fe
4fd :2 0 67 :3 0
78 :3 0 500 501
0 69 :4 0 a8
:4 0 6c :2 0 6d
:3 0 2ab 505 507
:3 0 2ae 502 509
:2 0 50b 2b1 50c
4ff 50b 0 50d
2b3 0 517 85
:3 0 86 :3 0 50e
50f 0 81 :3 0
a6 :3 0 511 512
0 87 :3 0 2b5
510 515 :2 0 517
2b8 518 4ba 517
0 519 2bc 0
51e 61 :3 0 23
:2 0 51a 51b 0
51e a9 :3 0 2be
58d 5 :3 0 7b
:2 0 2c2 520 521
:3 0 522 :2 0 523
:2 0 6 :3 0 7b
:2 0 2c4 526 527
:3 0 528 :2 0 529
:2 0 524 52b 52a
:2 0 6d :3 0 1c
:3 0 94 :4 0 aa
1 :8 0 536 15
:3 0 96 :3 0 531
532 0 97 :3 0
533 534 0 536
2c6 589 98 :3 0
15 :3 0 96 :3 0
538 539 0 97
:3 0 53a 53b 0
53d 2c9 53f 2cb
53e 53d :2 0 587
99 :3 0 15 :3 0
96 :3 0 542 543
0 97 :3 0 544
545 0 57f 64
:3 0 65 :3 0 547
548 0 64 :3 0
75 :3 0 54a 54b
0 9a :2 0 2
:4 0 ab :2 0 77
:2 0 23 :2 0 2cd
550 552 :3 0 2d0
54c 554 549 556
555 :2 0 67 :3 0
78 :3 0 558 559
0 69 :4 0 ac
:4 0 6c :2 0 6d
:3 0 2d4 55d 55f
:3 0 6c :2 0 7f
:4 0 2d7 561 563
:3 0 6c :2 0 9d
:4 0 2da 565 567
:3 0 6c :2 0 97
:3 0 2dd 569 56b
:3 0 6c :2 0 9e
:4 0 2e0 56d 56f
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 2e3
572 576 2e7 571
578 :3 0 2ea 55a
57a :2 0 57c 2ed
57d 557 57c 0
57e 2ef 0 57f
2f1 582 :3 0 582
0 582 581 57f
580 :6 0 584 4
:3 0 2f4 586 2f6
585 584 :2 0 587
2f8 :2 0 589 0
589 588 536 587
:6 0 58b 1 :3 0
2fb 58c 52c 58b
0 58e 441 51e
0 58e 2fd 0
1f6c 36 :3 0 ad
:3 0 ae :3 0 590
591 0 af :3 0
71 :3 0 3c :3 0
31 :2 0 300 594
597 81 :3 0 b0
:3 0 599 59a 0
303 593 59c 59d
:2 0 b1 :2 0 306
592 5a0 58f 5a1
0 1f6c 3c :3 0
af :3 0 71 :3 0
3c :3 0 31 :2 0
309 5a5 5a8 81
:3 0 b2 :3 0 5aa
5ab 0 30c 5a4
5ad 5ae :2 0 5a3
5af 0 1f6c 71
:3 0 3c :3 0 31
:2 0 30f 5b1 5b4
81 :3 0 88 :2 0
b3 :3 0 5b6 5b8
0 314 5b7 5ba
:3 0 3c :3 0 9a
:2 0 5bc 5bd 0
5bf 317 5c0 5bb
5bf 0 5c1 319
0 1f6c 71 :3 0
33 :3 0 31 :2 0
31b 5c2 5c5 88
:2 0 31 :2 0 320
5c7 5c9 :3 0 71
:3 0 b4 :3 0 71
:3 0 b5 :3 0 b6
:3 0 3f :3 0 40
:3 0 47 :3 0 b7
:3 0 b8 :3 0 17
:4 0 b9 1 :8 0
5dc 15 :3 0 96
:3 0 5d7 5d8 0
97 :3 0 5d9 5da
0 5dc 323 62f
98 :3 0 15 :3 0
96 :3 0 5de 5df
0 97 :3 0 5e0
5e1 0 5e3 326
5e5 328 5e4 5e3
:2 0 62d 99 :3 0
15 :3 0 96 :3 0
5e8 5e9 0 97
:3 0 5ea 5eb 0
625 64 :3 0 65
:3 0 5ed 5ee 0
64 :3 0 75 :3 0
5f0 5f1 0 9a
:2 0 2 :4 0 ba
:2 0 77 :2 0 23
:2 0 32a 5f6 5f8
:3 0 32d 5f2 5fa
5ef 5fc 5fb :2 0
67 :3 0 78 :3 0
5fe 5ff 0 69
:4 0 bb :4 0 6c
:2 0 6d :3 0 331
603 605 :3 0 6c
:2 0 7f :4 0 334
607 609 :3 0 6c
:2 0 9d :4 0 337
60b 60d :3 0 6c
:2 0 97 :3 0 33a
60f 611 :3 0 6c
:2 0 9e :4 0 33d
613 615 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 340 618 61c
344 617 61e :3 0
347 600 620 :2 0
622 34a 623 5fd
622 0 624 34c
0 625 34e 628
:3 0 628 0 628
627 625 626 :6 0
62a 6 :3 0 351
62c 353 62b 62a
:2 0 62d 355 :2 0
62f 0 62f 62e
5dc 62d :6 0 863
1 :3 0 15 :3 0
96 :3 0 631 632
0 15 :3 0 88
:2 0 bc :3 0 634
636 0 35a 635
638 :3 0 639 :2 0
3f :3 0 40 :3 0
47 :3 0 bd :3 0
b8 :3 0 17 :4 0
be 1 :8 0 647
15 :3 0 96 :3 0
642 643 0 97
:3 0 644 645 0
647 35d 69a 98
:3 0 15 :3 0 96
:3 0 649 64a 0
97 :3 0 64b 64c
0 64e 360 650
362 64f 64e :2 0
698 99 :3 0 15
:3 0 96 :3 0 653
654 0 97 :3 0
655 656 0 690
64 :3 0 65 :3 0
658 659 0 64
:3 0 75 :3 0 65b
65c 0 9a :2 0
2 :4 0 bf :2 0
77 :2 0 23 :2 0
364 661 663 :3 0
367 65d 665 65a
667 666 :2 0 67
:3 0 78 :3 0 669
66a 0 69 :4 0
c0 :4 0 6c :2 0
6d :3 0 36b 66e
670 :3 0 6c :2 0
7f :4 0 36e 672
674 :3 0 6c :2 0
9d :4 0 371 676
678 :3 0 6c :2 0
97 :3 0 374 67a
67c :3 0 6c :2 0
9e :4 0 377 67e
680 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
37a 683 687 37e
682 689 :3 0 381
66b 68b :2 0 68d
384 68e 668 68d
0 68f 386 0
690 388 693 :3 0
693 0 693 692
690 691 :6 0 695
8 :3 0 38b 697
38d 696 695 :2 0
698 38f :2 0 69a
0 69a 699 647
698 :6 0 716 1
:3 0 15 :3 0 96
:3 0 69c 69d 0
15 :3 0 88 :2 0
bc :3 0 69f 6a1
0 394 6a0 6a3
:3 0 6a4 :2 0 64
:3 0 65 :3 0 6a6
6a7 0 64 :3 0
75 :3 0 6a9 6aa
0 18 :2 0 2
:4 0 2f :2 0 77
:2 0 23 :2 0 397
6af 6b1 :3 0 39a
6ab 6b3 6a8 6b5
6b4 :2 0 67 :3 0
78 :3 0 6b7 6b8
0 69 :4 0 c1
:4 0 6c :2 0 6d
:3 0 39e 6bc 6be
:3 0 6c :2 0 7f
:4 0 3a1 6c0 6c2
:3 0 6c :2 0 80
:4 0 3a4 6c4 6c6
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 8c :3 0 6cb
6cc 0 3a7 6ca
6ce 73 :4 0 3a9
6c9 6d1 3ac 6c8
6d3 :3 0 6c :2 0
c2 :4 0 3af 6d5
6d7 :3 0 6c :2 0
6f :4 0 3b2 6d9
6db :3 0 6c :2 0
17 :3 0 3b5 6dd
6df :3 0 6c :2 0
6f :4 0 3b8 6e1
6e3 :3 0 3bb 6b9
6e5 :2 0 6e7 3be
6e8 6b6 6e7 0
6e9 3c0 0 713
64 :3 0 65 :3 0
6ea 6eb 0 64
:3 0 75 :3 0 6ed
6ee 0 23 :2 0
2 :4 0 c3 :2 0
77 :2 0 23 :2 0
3c2 6f3 6f5 :3 0
3c5 6ef 6f7 6ec
6f9 6f8 :2 0 67
:3 0 78 :3 0 6fb
6fc 0 69 :4 0
c4 :4 0 6c :2 0
6d :3 0 3c9 700
702 :3 0 3cc 6fd
704 :2 0 706 3cf
707 6fa 706 0
708 3d1 0 713
85 :3 0 c5 :3 0
709 70a 0 81
:3 0 8c :3 0 70c
70d 0 17 :3 0
87 :3 0 3d3 70b
711 :2 0 713 3d7
714 6a5 713 0
715 3db 0 716
3dd 717 63a 716
0 718 3e0 0
863 5c :3 0 31
:2 0 719 71a 0
863 c6 :3 0 5c
:3 0 c7 :3 0 c8
:3 0 17 :4 0 c9
1 :8 0 727 15
:3 0 96 :3 0 722
723 0 97 :3 0
724 725 0 727
3e2 77a 98 :3 0
15 :3 0 96 :3 0
729 72a 0 97
:3 0 72b 72c 0
72e 3e5 730 3e7
72f 72e :2 0 778
99 :3 0 15 :3 0
96 :3 0 733 734
0 97 :3 0 735
736 0 770 64
:3 0 65 :3 0 738
739 0 64 :3 0
75 :3 0 73b 73c
0 9a :2 0 2
:4 0 ca :2 0 77
:2 0 23 :2 0 3e9
741 743 :3 0 3ec
73d 745 73a 747
746 :2 0 67 :3 0
78 :3 0 749 74a
0 69 :4 0 cb
:4 0 6c :2 0 6d
:3 0 3f0 74e 750
:3 0 6c :2 0 7f
:4 0 3f3 752 754
:3 0 6c :2 0 9d
:4 0 3f6 756 758
:3 0 6c :2 0 97
:3 0 3f9 75a 75c
:3 0 6c :2 0 9e
:4 0 3fc 75e 760
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 3ff
763 767 403 762
769 :3 0 406 74b
76b :2 0 76d 409
76e 748 76d 0
76f 40b 0 770
40d 773 :3 0 773
0 773 772 770
771 :6 0 775 a
:3 0 410 777 412
776 775 :2 0 778
414 :2 0 77a 0
77a 779 727 778
:6 0 863 1 :3 0
71 :3 0 5c :3 0
31 :2 0 417 77c
77f cc :2 0 31
:2 0 41c 781 783
:3 0 cd :3 0 22
:3 0 b7 :3 0 b8
:3 0 17 :4 0 ce
1 :8 0 790 15
:3 0 96 :3 0 78b
78c 0 97 :3 0
78d 78e 0 790
41f 7e3 98 :3 0
15 :3 0 96 :3 0
792 793 0 97
:3 0 794 795 0
797 422 799 424
798 797 :2 0 7e1
99 :3 0 15 :3 0
96 :3 0 79c 79d
0 97 :3 0 79e
79f 0 7d9 64
:3 0 65 :3 0 7a1
7a2 0 64 :3 0
75 :3 0 7a4 7a5
0 9a :2 0 2
:4 0 cf :2 0 77
:2 0 23 :2 0 426
7aa 7ac :3 0 429
7a6 7ae 7a3 7b0
7af :2 0 67 :3 0
78 :3 0 7b2 7b3
0 69 :4 0 d0
:4 0 6c :2 0 6d
:3 0 42d 7b7 7b9
:3 0 6c :2 0 7f
:4 0 430 7bb 7bd
:3 0 6c :2 0 9d
:4 0 433 7bf 7c1
:3 0 6c :2 0 97
:3 0 436 7c3 7c5
:3 0 6c :2 0 9e
:4 0 439 7c7 7c9
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 43c
7cc 7d0 440 7cb
7d2 :3 0 443 7b4
7d4 :2 0 7d6 446
7d7 7b1 7d6 0
7d8 448 0 7d9
44a 7dc :3 0 7dc
0 7dc 7db 7d9
7da :6 0 7de c
:3 0 44d 7e0 44f
7df 7de :2 0 7e1
451 :2 0 7e3 0
7e3 7e2 790 7e1
:6 0 860 1 :3 0
92 :3 0 d1 :3 0
7e5 7e6 0 22
:3 0 d2 :4 0 454
7e7 7ea 88 :2 0
31 :2 0 459 7ec
7ee :3 0 64 :3 0
65 :3 0 7f0 7f1
0 64 :3 0 75
:3 0 7f3 7f4 0
18 :2 0 2 :4 0
d3 :2 0 77 :2 0
23 :2 0 45c 7f9
7fb :3 0 45f 7f5
7fd 7f2 7ff 7fe
:2 0 67 :3 0 78
:3 0 801 802 0
69 :4 0 d4 :4 0
6c :2 0 6d :3 0
463 806 808 :3 0
6c :2 0 7f :4 0
466 80a 80c :3 0
6c :2 0 80 :4 0
469 80e 810 :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
d5 :3 0 815 816
0 46c 814 818
73 :4 0 46e 813
81b 471 812 81d
:3 0 6c :2 0 c2
:4 0 474 81f 821
:3 0 6c :2 0 6f
:4 0 477 823 825
:3 0 6c :2 0 17
:3 0 47a 827 829
:3 0 6c :2 0 6f
:4 0 47d 82b 82d
:3 0 480 803 82f
:2 0 831 483 832
800 831 0 833
485 0 85d 64
:3 0 65 :3 0 834
835 0 64 :3 0
75 :3 0 837 838
0 23 :2 0 2
:4 0 d6 :2 0 77
:2 0 23 :2 0 487
83d 83f :3 0 48a
839 841 836 843
842 :2 0 67 :3 0
78 :3 0 845 846
0 69 :4 0 d7
:4 0 6c :2 0 6d
:3 0 48e 84a 84c
:3 0 491 847 84e
:2 0 850 494 851
844 850 0 852
496 0 85d 85
:3 0 c5 :3 0 853
854 0 81 :3 0
d5 :3 0 856 857
0 17 :3 0 87
:3 0 498 855 85b
:2 0 85d 49c 85e
7ef 85d 0 85f
4a0 0 860 4a2
861 784 860 0
862 4a5 0 863
4a7 a4f 12 :3 0
7b :2 0 4ad 865
866 :3 0 867 :2 0
64 :3 0 65 :3 0
869 86a 0 64
:3 0 75 :3 0 86c
86d 0 7c :2 0
2 :4 0 d8 :2 0
77 :2 0 23 :2 0
4af 872 874 :3 0
4b2 86e 876 86b
878 877 :2 0 67
:3 0 78 :3 0 87a
87b 0 69 :4 0
d9 :4 0 6c :2 0
6d :3 0 4b6 87f
881 :3 0 6c :2 0
7f :4 0 4b9 883
885 :3 0 6c :2 0
80 :4 0 4bc 887
889 :3 0 6c :2 0
71 :3 0 72 :3 0
81 :3 0 82 :3 0
88e 88f 0 4bf
88d 891 73 :4 0
4c1 88c 894 4c4
88b 896 :3 0 4c7
87c 898 :2 0 89a
4ca 89b 879 89a
0 89c 4cc 0
8c5 64 :3 0 65
:3 0 89d 89e 0
64 :3 0 75 :3 0
8a0 8a1 0 23
:2 0 2 :4 0 da
:2 0 77 :2 0 23
:2 0 4ce 8a6 8a8
:3 0 4d1 8a2 8aa
89f 8ac 8ab :2 0
67 :3 0 78 :3 0
8ae 8af 0 69
:4 0 db :4 0 6c
:2 0 6d :3 0 4d5
8b3 8b5 :3 0 4d8
8b0 8b7 :2 0 8b9
4db 8ba 8ad 8b9
0 8bb 4dd 0
8c5 85 :3 0 86
:3 0 8bc 8bd 0
81 :3 0 82 :3 0
8bf 8c0 0 87
:3 0 4df 8be 8c3
:2 0 8c5 4e2 8c6
868 8c5 0 8c7
4e6 0 a4e 28
:3 0 12 :3 0 8c8
8c9 0 a4e 1b
:3 0 9f :3 0 9f
:3 0 28 :3 0 23
:2 0 18 :2 0 4e8
8cd 8d1 23 :2 0
18 :2 0 4ec 8cc
8d5 8cb 8d6 0
a4e 24 :3 0 dc
:3 0 dd :3 0 8d9
8da 0 23 :2 0
23 :2 0 de :2 0
28 :3 0 4f0 8db
8e0 8d8 8e1 0
a4e df :3 0 71
:3 0 33 :3 0 31
:2 0 4f5 8e4 8e7
4f8 8e3 8e9 8f
:2 0 31 :2 0 4fc
8eb 8ed :3 0 c8
:3 0 71 :3 0 b4
:3 0 71 :3 0 b5
:3 0 b6 :3 0 17
:3 0 3f :3 0 40
:3 0 47 :3 0 b7
:3 0 b8 :3 0 19
:3 0 e0 :3 0 81
:3 0 e1 :3 0 81
:3 0 e2 :3 0 81
:3 0 e3 :3 0 81
:3 0 e4 :3 0 81
:3 0 e5 :4 0 e6
1 :8 0 90d 15
:3 0 96 :3 0 908
909 0 97 :3 0
90a 90b 0 90d
4ff 960 98 :3 0
15 :3 0 96 :3 0
90f 910 0 97
:3 0 911 912 0
914 502 916 504
915 914 :2 0 95e
99 :3 0 15 :3 0
96 :3 0 919 91a
0 97 :3 0 91b
91c 0 956 64
:3 0 65 :3 0 91e
91f 0 64 :3 0
75 :3 0 921 922
0 9a :2 0 2
:4 0 e7 :2 0 77
:2 0 23 :2 0 506
927 929 :3 0 509
923 92b 920 92d
92c :2 0 67 :3 0
78 :3 0 92f 930
0 69 :4 0 e8
:4 0 6c :2 0 6d
:3 0 50d 934 936
:3 0 6c :2 0 7f
:4 0 510 938 93a
:3 0 6c :2 0 9d
:4 0 513 93c 93e
:3 0 6c :2 0 97
:3 0 516 940 942
:3 0 6c :2 0 9e
:4 0 519 944 946
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 51c
949 94d 520 948
94f :3 0 523 931
951 :2 0 953 526
954 92e 953 0
955 528 0 956
52a 959 :3 0 959
0 959 958 956
957 :6 0 95b e
:3 0 52d 95d 52f
95c 95b :2 0 95e
531 :2 0 960 0
960 95f 90d 95e
:6 0 9dc 1 :3 0
15 :3 0 96 :3 0
962 963 0 15
:3 0 88 :2 0 bc
:3 0 965 967 0
536 966 969 :3 0
96a :2 0 64 :3 0
65 :3 0 96c 96d
0 64 :3 0 75
:3 0 96f 970 0
18 :2 0 2 :4 0
e9 :2 0 77 :2 0
23 :2 0 539 975
977 :3 0 53c 971
979 96e 97b 97a
:2 0 67 :3 0 78
:3 0 97d 97e 0
69 :4 0 ea :4 0
6c :2 0 6d :3 0
540 982 984 :3 0
6c :2 0 7f :4 0
543 986 988 :3 0
6c :2 0 80 :4 0
546 98a 98c :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
eb :3 0 991 992
0 549 990 994
73 :4 0 54b 98f
997 54e 98e 999
:3 0 6c :2 0 c2
:4 0 551 99b 99d
:3 0 6c :2 0 6f
:4 0 554 99f 9a1
:3 0 6c :2 0 19
:3 0 557 9a3 9a5
:3 0 6c :2 0 6f
:4 0 55a 9a7 9a9
:3 0 55d 97f 9ab
:2 0 9ad 560 9ae
97c 9ad 0 9af
562 0 9d9 64
:3 0 65 :3 0 9b0
9b1 0 64 :3 0
75 :3 0 9b3 9b4
0 23 :2 0 2
:4 0 ec :2 0 77
:2 0 23 :2 0 564
9b9 9bb :3 0 567
9b5 9bd 9b2 9bf
9be :2 0 67 :3 0
78 :3 0 9c1 9c2
0 69 :4 0 ed
:4 0 6c :2 0 6d
:3 0 56b 9c6 9c8
:3 0 56e 9c3 9ca
:2 0 9cc 571 9cd
9c0 9cc 0 9ce
573 0 9d9 85
:3 0 c5 :3 0 9cf
9d0 0 81 :3 0
eb :3 0 9d2 9d3
0 19 :3 0 87
:3 0 575 9d1 9d7
:2 0 9d9 579 9da
96b 9d9 0 9db
57d 0 9dc 57f
a4b 64 :3 0 65
:3 0 9dd 9de 0
64 :3 0 75 :3 0
9e0 9e1 0 18
:2 0 2 :4 0 ee
:2 0 77 :2 0 23
:2 0 582 9e6 9e8
:3 0 585 9e2 9ea
9df 9ec 9eb :2 0
67 :3 0 78 :3 0
9ee 9ef 0 69
:4 0 ef :4 0 6c
:2 0 6d :3 0 589
9f3 9f5 :3 0 6c
:2 0 7f :4 0 58c
9f7 9f9 :3 0 6c
:2 0 80 :4 0 58f
9fb 9fd :3 0 6c
:2 0 71 :3 0 72
:3 0 81 :3 0 eb
:3 0 a02 a03 0
592 a01 a05 73
:4 0 594 a00 a08
597 9ff a0a :3 0
6c :2 0 c2 :4 0
59a a0c a0e :3 0
6c :2 0 6f :4 0
59d a10 a12 :3 0
6c :2 0 19 :3 0
5a0 a14 a16 :3 0
6c :2 0 6f :4 0
5a3 a18 a1a :3 0
5a6 9f0 a1c :2 0
a1e 5a9 a1f 9ed
a1e 0 a20 5ab
0 a4a 64 :3 0
65 :3 0 a21 a22
0 64 :3 0 75
:3 0 a24 a25 0
23 :2 0 2 :4 0
f0 :2 0 77 :2 0
23 :2 0 5ad a2a
a2c :3 0 5b0 a26
a2e a23 a30 a2f
:2 0 67 :3 0 78
:3 0 a32 a33 0
69 :4 0 f1 :4 0
6c :2 0 6d :3 0
5b4 a37 a39 :3 0
5b7 a34 a3b :2 0
a3d 5ba a3e a31
a3d 0 a3f 5bc
0 a4a 85 :3 0
c5 :3 0 a40 a41
0 81 :3 0 eb
:3 0 a43 a44 0
19 :3 0 87 :3 0
5be a42 a48 :2 0
a4a 5c2 a4c 8ee
9dc 0 a4d 0
a4a 0 a4d 5c6
0 a4e 5c9 a50
5ca 863 0 a51
0 a4e 0 a51
5cf 0 1f6c 71
:3 0 d :3 0 31
:2 0 5d2 a52 a55
88 :2 0 31 :2 0
5d7 a57 a59 :3 0
a5a :2 0 71 :3 0
3b :3 0 31 :2 0
5da a5c a5f 8f
:2 0 f2 :2 0 5df
a61 a63 :3 0 a64
:2 0 a5b a66 a65
:2 0 37 :3 0 31
:2 0 a68 a69 0
a6b 5e2 a6c a67
a6b 0 a6d 5e4
0 1f6c 61 :3 0
88 :2 0 31 :2 0
5e8 a6f a71 :3 0
1e :3 0 5 :3 0
a73 a74 0 b8e
1f :3 0 f3 :4 0
a76 a77 0 b8e
5c :3 0 f4 :3 0
1e :3 0 1f :3 0
71 :3 0 3a :3 0
31 :2 0 5eb a7d
a80 71 :3 0 3b
:3 0 31 :2 0 5ee
a82 a85 71 :3 0
3c :3 0 31 :2 0
5f1 a87 a8a 71
:3 0 32 :3 0 31
:2 0 5f4 a8c a8f
71 :3 0 3d :3 0
31 :2 0 5f7 a91
a94 71 :3 0 38
:3 0 31 :2 0 5fa
a96 a99 71 :3 0
3f :3 0 31 :2 0
5fd a9b a9e 71
:3 0 40 :3 0 31
:2 0 600 aa0 aa3
37 :3 0 39 :3 0
43 :3 0 603 a7a
aa8 a79 aa9 0
b8e 71 :3 0 5c
:3 0 31 :2 0 611
aab aae 81 :3 0
88 :2 0 8c :3 0
ab0 ab2 0 616
ab1 ab4 :3 0 64
:3 0 65 :3 0 ab6
ab7 0 64 :3 0
75 :3 0 ab9 aba
0 7c :2 0 2
:4 0 f5 :2 0 77
:2 0 23 :2 0 619
abf ac1 :3 0 61c
abb ac3 ab8 ac5
ac4 :2 0 67 :3 0
78 :3 0 ac7 ac8
0 69 :4 0 f6
:4 0 6c :2 0 6d
:3 0 620 acc ace
:3 0 6c :2 0 7f
:4 0 623 ad0 ad2
:3 0 6c :2 0 80
:4 0 626 ad4 ad6
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 8c :3 0 adb
adc 0 629 ada
ade 73 :4 0 62b
ad9 ae1 62e ad8
ae3 :3 0 631 ac9
ae5 :2 0 ae7 634
ae8 ac6 ae7 0
ae9 636 0 b13
64 :3 0 65 :3 0
aea aeb 0 64
:3 0 75 :3 0 aed
aee 0 23 :2 0
2 :4 0 f7 :2 0
77 :2 0 23 :2 0
638 af3 af5 :3 0
63b aef af7 aec
af9 af8 :2 0 67
:3 0 78 :3 0 afb
afc 0 69 :4 0
f8 :4 0 6c :2 0
6d :3 0 63f b00
b02 :3 0 642 afd
b04 :2 0 b06 645
b07 afa b06 0
b08 647 0 b13
85 :3 0 86 :3 0
b09 b0a 0 81
:3 0 8c :3 0 b0c
b0d 0 87 :3 0
649 b0b b10 :2 0
b13 a9 :3 0 64c
b8c 71 :3 0 5c
:3 0 31 :2 0 650
b14 b17 8f :2 0
31 :2 0 655 b19
b1b :3 0 64 :3 0
65 :3 0 b1d b1e
0 64 :3 0 75
:3 0 b20 b21 0
18 :2 0 2 :4 0
f9 :2 0 77 :2 0
23 :2 0 658 b26
b28 :3 0 65b b22
b2a b1f b2c b2b
:2 0 67 :3 0 78
:3 0 b2e b2f 0
69 :4 0 fa :4 0
6c :2 0 6d :3 0
65f b33 b35 :3 0
6c :2 0 7f :4 0
662 b37 b39 :3 0
6c :2 0 80 :4 0
665 b3b b3d :3 0
6c :2 0 71 :3 0
72 :3 0 5c :3 0
668 b41 b43 73
:4 0 66a b40 b46
66d b3f b48 :3 0
6c :2 0 c2 :4 0
670 b4a b4c :3 0
6c :2 0 6f :4 0
673 b4e b50 :3 0
6c :2 0 17 :3 0
676 b52 b54 :3 0
6c :2 0 6f :4 0
679 b56 b58 :3 0
67c b30 b5a :2 0
b5c 67f b5d b2d
b5c 0 b5e 681
0 b8a 64 :3 0
65 :3 0 b5f b60
0 64 :3 0 75
:3 0 b62 b63 0
23 :2 0 2 :4 0
fb :2 0 77 :2 0
23 :2 0 683 b68
b6a :3 0 686 b64
b6c b61 b6e b6d
:2 0 67 :3 0 78
:3 0 b70 b71 0
69 :4 0 fc :4 0
6c :2 0 6d :3 0
68a b75 b77 :3 0
68d b72 b79 :2 0
b7b 690 b7c b6f
b7b 0 b7d 692
0 b8a 85 :3 0
c5 :3 0 b7e b7f
0 71 :3 0 5c
:3 0 31 :2 0 694
b81 b84 17 :3 0
87 :3 0 697 b80
b88 :2 0 b8a 69b
b8b b1c b8a 0
b8d ab5 b13 0
b8d 69f 0 b8e
6a2 bae 1f :3 0
6 :3 0 b8f b90
0 bad 71 :3 0
3b :3 0 31 :2 0
6a7 b92 b95 88
:2 0 89 :2 0 6ac
b97 b99 :3 0 37
:3 0 71 :3 0 37
:3 0 31 :2 0 6af
b9c b9f fd :2 0
71 :3 0 40 :3 0
31 :2 0 6b2 ba2
ba5 6b5 ba1 ba7
:3 0 b9b ba8 0
baa 6b8 bab b9a
baa 0 bac 6ba
0 bad 6bc baf
a72 b8e 0 bb0
0 bad 0 bb0
6bf 0 1f6c 71
:3 0 37 :3 0 31
:2 0 6c2 bb1 bb4
cc :2 0 31 :2 0
6c7 bb6 bb8 :3 0
bb9 :2 0 71 :3 0
3b :3 0 31 :2 0
6ca bbb bbe 8f
:2 0 f2 :2 0 6cf
bc0 bc2 :3 0 bc3
:2 0 bba bc5 bc4
:2 0 71 :3 0 3b
:3 0 31 :2 0 6d2
bc7 bca 88 :2 0
23 :2 0 6d7 bcc
bce :3 0 bcf :2 0
71 :3 0 3b :3 0
31 :2 0 6da bd1
bd4 88 :2 0 fe
:2 0 6df bd6 bd8
:3 0 bd9 :2 0 bd0
bdb bda :2 0 3a
:3 0 fe :2 0 bdd
bde 0 be1 a9
:3 0 6e2 c1b 71
:3 0 3b :3 0 31
:2 0 6e4 be2 be5
88 :2 0 31 :2 0
6e9 be7 be9 :3 0
3a :3 0 23 :2 0
beb bec 0 bef
a9 :3 0 6ec bf0
bea bef 0 c1c
71 :3 0 3b :3 0
31 :2 0 6ee bf1
bf4 88 :2 0 ff
:2 0 6f3 bf6 bf8
:3 0 bf9 :2 0 71
:3 0 3b :3 0 31
:2 0 6f6 bfb bfe
88 :2 0 100 :2 0
6fb c00 c02 :3 0
c03 :2 0 bfa c05
c04 :2 0 3a :3 0
23 :2 0 c07 c08
0 c0b a9 :3 0
6fe c0c c06 c0b
0 c1c 71 :3 0
3b :3 0 31 :2 0
700 c0d c10 88
:2 0 89 :2 0 705
c12 c14 :3 0 3a
:3 0 ff :2 0 c16
c17 0 c19 708
c1a c15 c19 0
c1c bdc be1 0
c1c 70a 0 c1d
70f c1e bc6 c1d
0 c1f 711 0
1f6c 58 :3 0 101
:4 0 c21 c22 :3 0
c20 c23 0 1f6c
2a :3 0 f3 :4 0
c25 c26 0 1f6c
2b :3 0 f3 :4 0
c28 c29 0 1f6c
20 :3 0 f3 :4 0
c2b c2c 0 1f6c
26 :3 0 f3 :4 0
c2e c2f 0 1f6c
1b :3 0 9f :3 0
1b :3 0 23 :2 0
18 :2 0 713 c32
c36 c31 c37 0
1f6c 24 :3 0 9f
:3 0 24 :3 0 23
:2 0 23 :2 0 717
c3a c3e c39 c3f
0 1f6c 71 :3 0
33 :3 0 31 :2 0
71b c41 c44 cc
:2 0 31 :2 0 720
c46 c48 :3 0 2c
:4 0 c4a c4b 0
17ff 1e :3 0 1c
:3 0 c4d c4e 0
17ff 9f :3 0 24
:3 0 23 :2 0 23
:2 0 723 c50 c54
88 :2 0 23 :4 0
729 c56 c58 :3 0
102 :3 0 103 :3 0
9f :3 0 104 :3 0
103 :3 0 9f :3 0
105 :3 0 106 :3 0
107 :3 0 108 :3 0
109 :3 0 27 :3 0
2c :3 0 2d :3 0
4b :3 0 4c :3 0
50 :3 0 52 :3 0
10a :3 0 10b :3 0
17 :3 0 10c :3 0
1b :3 0 10d :3 0
10e :4 0 10f 1
:8 0 c79 15 :3 0
96 :3 0 c74 c75
0 97 :3 0 c76
c77 0 c79 72c
ccc 98 :3 0 15
:3 0 96 :3 0 c7b
c7c 0 97 :3 0
c7d c7e 0 c80
72f c82 731 c81
c80 :2 0 cca 99
:3 0 15 :3 0 96
:3 0 c85 c86 0
97 :3 0 c87 c88
0 cc2 64 :3 0
65 :3 0 c8a c8b
0 64 :3 0 75
:3 0 c8d c8e 0
9a :2 0 2 :4 0
110 :2 0 77 :2 0
23 :2 0 733 c93
c95 :3 0 736 c8f
c97 c8c c99 c98
:2 0 67 :3 0 78
:3 0 c9b c9c 0
69 :4 0 111 :4 0
6c :2 0 6d :3 0
73a ca0 ca2 :3 0
6c :2 0 7f :4 0
73d ca4 ca6 :3 0
6c :2 0 9d :4 0
740 ca8 caa :3 0
6c :2 0 97 :3 0
743 cac cae :3 0
6c :2 0 9e :4 0
746 cb0 cb2 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 749 cb5
cb9 74d cb4 cbb
:3 0 750 c9d cbd
:2 0 cbf 753 cc0
c9a cbf 0 cc1
755 0 cc2 757
cc5 :3 0 cc5 0
cc5 cc4 cc2 cc3
:6 0 cc7 10 :3 0
75a cc9 75c cc8
cc7 :2 0 cca 75e
:2 0 ccc 0 ccc
ccb c79 cca :6 0
e11 1 :3 0 112
:3 0 2e :3 0 113
:3 0 114 :3 0 1b
:4 0 115 1 :8 0
cd9 15 :3 0 96
:3 0 cd4 cd5 0
97 :3 0 cd6 cd7
0 cd9 761 d2c
98 :3 0 15 :3 0
96 :3 0 cdb cdc
0 97 :3 0 cdd
cde 0 ce0 764
ce2 766 ce1 ce0
:2 0 d2a 99 :3 0
15 :3 0 96 :3 0
ce5 ce6 0 97
:3 0 ce7 ce8 0
d22 64 :3 0 65
:3 0 cea ceb 0
64 :3 0 75 :3 0
ced cee 0 9a
:2 0 2 :4 0 116
:2 0 77 :2 0 23
:2 0 768 cf3 cf5
:3 0 76b cef cf7
cec cf9 cf8 :2 0
67 :3 0 78 :3 0
cfb cfc 0 69
:4 0 117 :4 0 6c
:2 0 6d :3 0 76f
d00 d02 :3 0 6c
:2 0 7f :4 0 772
d04 d06 :3 0 6c
:2 0 9d :4 0 775
d08 d0a :3 0 6c
:2 0 97 :3 0 778
d0c d0e :3 0 6c
:2 0 9e :4 0 77b
d10 d12 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 77e d15 d19
782 d14 d1b :3 0
785 cfd d1d :2 0
d1f 788 d20 cfa
d1f 0 d21 78a
0 d22 78c d25
:3 0 d25 0 d25
d24 d22 d23 :6 0
d27 12 :3 0 78f
d29 791 d28 d27
:2 0 d2a 793 :2 0
d2c 0 d2c d2b
cd9 d2a :6 0 e11
1 :3 0 15 :3 0
96 :3 0 d2e d2f
0 15 :3 0 88
:2 0 bc :3 0 d31
d33 0 798 d32
d35 :3 0 d36 :2 0
64 :3 0 65 :3 0
d38 d39 0 64
:3 0 75 :3 0 d3b
d3c 0 18 :2 0
2 :4 0 118 :2 0
77 :2 0 23 :2 0
79b d41 d43 :3 0
79e d3d d45 d3a
d47 d46 :2 0 67
:3 0 78 :3 0 d49
d4a 0 69 :4 0
119 :4 0 6c :2 0
6d :3 0 7a2 d4e
d50 :3 0 6c :2 0
7f :4 0 7a5 d52
d54 :3 0 6c :2 0
80 :4 0 7a8 d56
d58 :3 0 6c :2 0
71 :3 0 72 :3 0
81 :3 0 eb :3 0
d5d d5e 0 7ab
d5c d60 73 :4 0
7ad d5b d63 7b0
d5a d65 :3 0 6c
:2 0 c2 :4 0 7b3
d67 d69 :3 0 6c
:2 0 6f :4 0 7b6
d6b d6d :3 0 6c
:2 0 1b :3 0 7b9
d6f d71 :3 0 6c
:2 0 6f :4 0 7bc
d73 d75 :3 0 7bf
d4b d77 :2 0 d79
7c2 d7a d48 d79
0 d7b 7c4 0
da5 64 :3 0 65
:3 0 d7c d7d 0
64 :3 0 75 :3 0
d7f d80 0 23
:2 0 2 :4 0 11a
:2 0 77 :2 0 23
:2 0 7c6 d85 d87
:3 0 7c9 d81 d89
d7e d8b d8a :2 0
67 :3 0 78 :3 0
d8d d8e 0 69
:4 0 11b :4 0 6c
:2 0 6d :3 0 7cd
d92 d94 :3 0 7d0
d8f d96 :2 0 d98
7d3 d99 d8c d98
0 d9a 7d5 0
da5 85 :3 0 c5
:3 0 d9b d9c 0
81 :3 0 eb :3 0
d9e d9f 0 1b
:3 0 87 :3 0 7d7
d9d da3 :2 0 da5
7db da6 d37 da5
0 da7 7df 0
e11 2b :3 0 1b
:3 0 da8 da9 0
e11 11c :3 0 11d
:3 0 26 :3 0 44
:3 0 11e :3 0 b8
:3 0 19 :3 0 10d
:3 0 10c :3 0 1b
:4 0 11f 1 :8 0
dbb 15 :3 0 96
:3 0 db6 db7 0
97 :3 0 db8 db9
0 dbb 7e1 e0e
98 :3 0 15 :3 0
96 :3 0 dbd dbe
0 97 :3 0 dbf
dc0 0 dc2 7e4
dc4 7e6 dc3 dc2
:2 0 e0c 99 :3 0
15 :3 0 96 :3 0
dc7 dc8 0 97
:3 0 dc9 dca 0
e04 64 :3 0 65
:3 0 dcc dcd 0
64 :3 0 75 :3 0
dcf dd0 0 9a
:2 0 2 :4 0 120
:2 0 77 :2 0 23
:2 0 7e8 dd5 dd7
:3 0 7eb dd1 dd9
dce ddb dda :2 0
67 :3 0 78 :3 0
ddd dde 0 69
:4 0 121 :4 0 6c
:2 0 6d :3 0 7ef
de2 de4 :3 0 6c
:2 0 7f :4 0 7f2
de6 de8 :3 0 6c
:2 0 9d :4 0 7f5
dea dec :3 0 6c
:2 0 97 :3 0 7f8
dee df0 :3 0 6c
:2 0 9e :4 0 7fb
df2 df4 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 7fe df7 dfb
802 df6 dfd :3 0
805 ddf dff :2 0
e01 808 e02 ddc
e01 0 e03 80a
0 e04 80c e07
:3 0 e07 0 e07
e06 e04 e05 :6 0
e09 14 :3 0 80f
e0b 811 e0a e09
:2 0 e0c 813 :2 0
e0e 0 e0e e0d
dbb e0c :6 0 e11
1 :3 0 a9 :3 0
816 11b8 9f :3 0
24 :3 0 23 :2 0
23 :2 0 81c e12
e16 88 :2 0 31
:4 0 822 e18 e1a
:3 0 122 :3 0 2e
:3 0 123 :3 0 10c
:3 0 1b :4 0 124
1 :8 0 e27 15
:3 0 96 :3 0 e22
e23 0 97 :3 0
e24 e25 0 e27
825 e7a 98 :3 0
15 :3 0 96 :3 0
e29 e2a 0 97
:3 0 e2b e2c 0
e2e 828 e30 82a
e2f e2e :2 0 e78
99 :3 0 15 :3 0
96 :3 0 e33 e34
0 97 :3 0 e35
e36 0 e70 64
:3 0 65 :3 0 e38
e39 0 64 :3 0
75 :3 0 e3b e3c
0 9a :2 0 2
:4 0 125 :2 0 77
:2 0 23 :2 0 82c
e41 e43 :3 0 82f
e3d e45 e3a e47
e46 :2 0 67 :3 0
78 :3 0 e49 e4a
0 69 :4 0 126
:4 0 6c :2 0 6d
:3 0 833 e4e e50
:3 0 6c :2 0 7f
:4 0 836 e52 e54
:3 0 6c :2 0 9d
:4 0 839 e56 e58
:3 0 6c :2 0 97
:3 0 83c e5a e5c
:3 0 6c :2 0 9e
:4 0 83f e5e e60
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 842
e63 e67 846 e62
e69 :3 0 849 e4b
e6b :2 0 e6d 84c
e6e e48 e6d 0
e6f 84e 0 e70
850 e73 :3 0 e73
0 e73 e72 e70
e71 :6 0 e75 16
:3 0 853 e77 855
e76 e75 :2 0 e78
857 :2 0 e7a 0
e7a e79 e27 e78
:6 0 1159 1 :3 0
15 :3 0 96 :3 0
e7c e7d 0 15
:3 0 88 :2 0 bc
:3 0 e7f e81 0
85c e80 e83 :3 0
e84 :2 0 64 :3 0
65 :3 0 e86 e87
0 64 :3 0 75
:3 0 e89 e8a 0
18 :2 0 2 :4 0
127 :2 0 77 :2 0
23 :2 0 85f e8f
e91 :3 0 862 e8b
e93 e88 e95 e94
:2 0 67 :3 0 78
:3 0 e97 e98 0
69 :4 0 128 :4 0
6c :2 0 6d :3 0
866 e9c e9e :3 0
6c :2 0 7f :4 0
869 ea0 ea2 :3 0
6c :2 0 80 :4 0
86c ea4 ea6 :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
eb :3 0 eab eac
0 86f eaa eae
73 :4 0 871 ea9
eb1 874 ea8 eb3
:3 0 6c :2 0 c2
:4 0 877 eb5 eb7
:3 0 6c :2 0 6f
:4 0 87a eb9 ebb
:3 0 6c :2 0 1b
:3 0 87d ebd ebf
:3 0 6c :2 0 6f
:4 0 880 ec1 ec3
:3 0 883 e99 ec5
:2 0 ec7 886 ec8
e96 ec7 0 ec9
888 0 ef3 64
:3 0 65 :3 0 eca
ecb 0 64 :3 0
75 :3 0 ecd ece
0 23 :2 0 2
:4 0 129 :2 0 77
:2 0 23 :2 0 88a
ed3 ed5 :3 0 88d
ecf ed7 ecc ed9
ed8 :2 0 67 :3 0
78 :3 0 edb edc
0 69 :4 0 12a
:4 0 6c :2 0 6d
:3 0 891 ee0 ee2
:3 0 894 edd ee4
:2 0 ee6 897 ee7
eda ee6 0 ee8
899 0 ef3 85
:3 0 c5 :3 0 ee9
eea 0 81 :3 0
eb :3 0 eec eed
0 1b :3 0 87
:3 0 89b eeb ef1
:2 0 ef3 89f ef4
e85 ef3 0 ef5
8a3 0 1159 2a
:3 0 1b :3 0 ef6
ef7 0 1159 102
:3 0 103 :3 0 9f
:3 0 104 :3 0 103
:3 0 9f :3 0 105
:3 0 106 :3 0 107
:3 0 108 :3 0 109
:3 0 27 :3 0 2c
:3 0 2d :3 0 4b
:3 0 4c :3 0 50
:3 0 52 :3 0 10a
:3 0 10b :3 0 17
:3 0 10c :3 0 1b
:3 0 10d :3 0 10e
:4 0 12b 1 :8 0
f18 15 :3 0 96
:3 0 f13 f14 0
97 :3 0 f15 f16
0 f18 8a5 f6b
98 :3 0 15 :3 0
96 :3 0 f1a f1b
0 97 :3 0 f1c
f1d 0 f1f 8a8
f21 8aa f20 f1f
:2 0 f69 99 :3 0
15 :3 0 96 :3 0
f24 f25 0 97
:3 0 f26 f27 0
f61 64 :3 0 65
:3 0 f29 f2a 0
64 :3 0 75 :3 0
f2c f2d 0 9a
:2 0 2 :4 0 12c
:2 0 77 :2 0 23
:2 0 8ac f32 f34
:3 0 8af f2e f36
f2b f38 f37 :2 0
67 :3 0 78 :3 0
f3a f3b 0 69
:4 0 12d :4 0 6c
:2 0 6d :3 0 8b3
f3f f41 :3 0 6c
:2 0 7f :4 0 8b6
f43 f45 :3 0 6c
:2 0 9d :4 0 8b9
f47 f49 :3 0 6c
:2 0 97 :3 0 8bc
f4b f4d :3 0 6c
:2 0 9e :4 0 8bf
f4f f51 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 8c2 f54 f58
8c6 f53 f5a :3 0
8c9 f3c f5c :2 0
f5e 8cc f5f f39
f5e 0 f60 8ce
0 f61 8d0 f64
:3 0 f64 0 f64
f63 f61 f62 :6 0
f66 18 :3 0 8d3
f68 8d5 f67 f66
:2 0 f69 8d7 :2 0
f6b 0 f6b f6a
f18 f69 :6 0 1159
1 :3 0 15 :3 0
96 :3 0 f6d f6e
0 15 :3 0 88
:2 0 bc :3 0 f70
f72 0 8dc f71
f74 :3 0 f75 :2 0
5f :3 0 23 :2 0
f77 f78 0 10f1
102 :3 0 103 :3 0
9f :3 0 104 :3 0
103 :3 0 9f :3 0
105 :3 0 106 :3 0
107 :3 0 108 :3 0
109 :3 0 27 :3 0
2c :3 0 2d :3 0
4b :3 0 4c :3 0
50 :3 0 52 :3 0
10a :3 0 10b :3 0
17 :3 0 10c :3 0
1b :3 0 10d :3 0
10e :4 0 12e 1
:8 0 f99 15 :3 0
96 :3 0 f94 f95
0 97 :3 0 f96
f97 0 f99 8df
fec 98 :3 0 15
:3 0 96 :3 0 f9b
f9c 0 97 :3 0
f9d f9e 0 fa0
8e2 fa2 8e4 fa1
fa0 :2 0 fea 99
:3 0 15 :3 0 96
:3 0 fa5 fa6 0
97 :3 0 fa7 fa8
0 fe2 64 :3 0
65 :3 0 faa fab
0 64 :3 0 75
:3 0 fad fae 0
9a :2 0 2 :4 0
12f :2 0 77 :2 0
23 :2 0 8e6 fb3
fb5 :3 0 8e9 faf
fb7 fac fb9 fb8
:2 0 67 :3 0 78
:3 0 fbb fbc 0
69 :4 0 130 :4 0
6c :2 0 6d :3 0
8ed fc0 fc2 :3 0
6c :2 0 7f :4 0
8f0 fc4 fc6 :3 0
6c :2 0 9d :4 0
8f3 fc8 fca :3 0
6c :2 0 97 :3 0
8f6 fcc fce :3 0
6c :2 0 9e :4 0
8f9 fd0 fd2 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 8fc fd5
fd9 900 fd4 fdb
:3 0 903 fbd fdd
:2 0 fdf 906 fe0
fba fdf 0 fe1
908 0 fe2 90a
fe5 :3 0 fe5 0
fe5 fe4 fe2 fe3
:6 0 fe7 1a :3 0
90d fe9 90f fe8
fe7 :2 0 fea 911
:2 0 fec 0 fec
feb f99 fea :6 0
10f1 1 :3 0 15
:3 0 96 :3 0 fee
fef 0 15 :3 0
88 :2 0 bc :3 0
ff1 ff3 0 916
ff2 ff5 :3 0 ff6
:2 0 5f :3 0 131
:2 0 23 :2 0 919
ff9 ffb :3 0 ff8
ffc 0 10ee df
:3 0 71 :3 0 33
:3 0 31 :2 0 91b
fff 1002 91e ffe
1004 8f :2 0 31
:2 0 922 1006 1008
:3 0 5c :3 0 31
:2 0 100a 100b 0
10eb 132 :3 0 5c
:3 0 94 :3 0 10a
:3 0 c8 :3 0 17
:3 0 10b :3 0 c8
:3 0 10c :3 0 1b
:4 0 133 1 :8 0
101d 15 :3 0 96
:3 0 1018 1019 0
97 :3 0 101a 101b
0 101d 925 1070
98 :3 0 15 :3 0
96 :3 0 101f 1020
0 97 :3 0 1021
1022 0 1024 928
1026 92a 1025 1024
:2 0 106e 99 :3 0
15 :3 0 96 :3 0
1029 102a 0 97
:3 0 102b 102c 0
1066 64 :3 0 65
:3 0 102e 102f 0
64 :3 0 75 :3 0
1031 1032 0 9a
:2 0 2 :4 0 134
:2 0 77 :2 0 23
:2 0 92c 1037 1039
:3 0 92f 1033 103b
1030 103d 103c :2 0
67 :3 0 78 :3 0
103f 1040 0 69
:4 0 135 :4 0 6c
:2 0 6d :3 0 933
1044 1046 :3 0 6c
:2 0 7f :4 0 936
1048 104a :3 0 6c
:2 0 9d :4 0 939
104c 104e :3 0 6c
:2 0 97 :3 0 93c
1050 1052 :3 0 6c
:2 0 9e :4 0 93f
1054 1056 :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 942 1059 105d
946 1058 105f :3 0
949 1041 1061 :2 0
1063 94c 1064 103e
1063 0 1065 94e
0 1066 950 1069
:3 0 1069 0 1069
1068 1066 1067 :6 0
106b 1c :3 0 953
106d 955 106c 106b
:2 0 106e 957 :2 0
1070 0 1070 106f
101d 106e :6 0 10eb
1 :3 0 71 :3 0
5c :3 0 31 :2 0
95a 1072 1075 8f
:2 0 31 :2 0 95f
1077 1079 :3 0 64
:3 0 65 :3 0 107b
107c 0 64 :3 0
75 :3 0 107e 107f
0 18 :2 0 2
:4 0 136 :2 0 77
:2 0 23 :2 0 962
1084 1086 :3 0 965
1080 1088 107d 108a
1089 :2 0 67 :3 0
78 :3 0 108c 108d
0 69 :4 0 137
:4 0 6c :2 0 6d
:3 0 969 1091 1093
:3 0 6c :2 0 7f
:4 0 96c 1095 1097
:3 0 6c :2 0 80
:4 0 96f 1099 109b
:3 0 6c :2 0 71
:3 0 72 :3 0 81
:3 0 138 :3 0 10a0
10a1 0 972 109f
10a3 73 :4 0 974
109e 10a6 977 109d
10a8 :3 0 6c :2 0
c2 :4 0 97a 10aa
10ac :3 0 6c :2 0
6f :4 0 97d 10ae
10b0 :3 0 6c :2 0
1b :3 0 980 10b2
10b4 :3 0 6c :2 0
6f :4 0 983 10b6
10b8 :3 0 986 108e
10ba :2 0 10bc 989
10bd 108b 10bc 0
10be 98b 0 10e8
64 :3 0 65 :3 0
10bf 10c0 0 64
:3 0 75 :3 0 10c2
10c3 0 23 :2 0
2 :4 0 139 :2 0
77 :2 0 23 :2 0
98d 10c8 10ca :3 0
990 10c4 10cc 10c1
10ce 10cd :2 0 67
:3 0 78 :3 0 10d0
10d1 0 69 :4 0
13a :4 0 6c :2 0
6d :3 0 994 10d5
10d7 :3 0 997 10d2
10d9 :2 0 10db 99a
10dc 10cf 10db 0
10dd 99c 0 10e8
85 :3 0 c5 :3 0
10de 10df 0 81
:3 0 138 :3 0 10e1
10e2 0 1b :3 0
87 :3 0 99e 10e0
10e6 :2 0 10e8 9a2
10e9 107a 10e8 0
10ea 9a6 0 10eb
9a8 10ec 1009 10eb
0 10ed 9ac 0
10ee 9ae 10ef ff7
10ee 0 10f0 9b1
0 10f1 9b3 10f2
f76 10f1 0 10f3
9b7 0 1159 11c
:3 0 11d :3 0 26
:3 0 44 :3 0 11e
:3 0 b8 :3 0 19
:3 0 10d :3 0 10c
:3 0 1b :4 0 13b
1 :8 0 1104 15
:3 0 96 :3 0 10ff
1100 0 97 :3 0
1101 1102 0 1104
9b9 1157 98 :3 0
15 :3 0 96 :3 0
1106 1107 0 97
:3 0 1108 1109 0
110b 9bc 110d 9be
110c 110b :2 0 1155
99 :3 0 15 :3 0
96 :3 0 1110 1111
0 97 :3 0 1112
1113 0 114d 64
:3 0 65 :3 0 1115
1116 0 64 :3 0
75 :3 0 1118 1119
0 9a :2 0 2
:4 0 13c :2 0 77
:2 0 23 :2 0 9c0
111e 1120 :3 0 9c3
111a 1122 1117 1124
1123 :2 0 67 :3 0
78 :3 0 1126 1127
0 69 :4 0 13d
:4 0 6c :2 0 6d
:3 0 9c7 112b 112d
:3 0 6c :2 0 7f
:4 0 9ca 112f 1131
:3 0 6c :2 0 9d
:4 0 9cd 1133 1135
:3 0 6c :2 0 97
:3 0 9d0 1137 1139
:3 0 6c :2 0 9e
:4 0 9d3 113b 113d
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 9d6
1140 1144 9da 113f
1146 :3 0 9dd 1128
1148 :2 0 114a 9e0
114b 1125 114a 0
114c 9e2 0 114d
9e4 1150 :3 0 1150
0 1150 114f 114d
114e :6 0 1152 1e
:3 0 9e7 1154 9e9
1153 1152 :2 0 1155
9eb :2 0 1157 0
1157 1156 1104 1155
:6 0 1159 1 :3 0
9ee 115a e1b 1159
0 11ba 64 :3 0
65 :3 0 115b 115c
0 64 :3 0 75
:3 0 115e 115f 0
7c :2 0 2 :4 0
13e :2 0 77 :2 0
23 :2 0 9f5 1164
1166 :3 0 9f8 1160
1168 115d 116a 1169
:2 0 67 :3 0 78
:3 0 116c 116d 0
69 :4 0 13f :4 0
6c :2 0 6d :3 0
9fc 1171 1173 :3 0
6c :2 0 7f :4 0
9ff 1175 1177 :3 0
6c :2 0 80 :4 0
a02 1179 117b :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
8c :3 0 1180 1181
0 a05 117f 1183
73 :4 0 a07 117e
1186 a0a 117d 1188
:3 0 a0d 116e 118a
:2 0 118c a10 118d
116b 118c 0 118e
a12 0 11b7 64
:3 0 65 :3 0 118f
1190 0 64 :3 0
75 :3 0 1192 1193
0 23 :2 0 2
:4 0 140 :2 0 77
:2 0 23 :2 0 a14
1198 119a :3 0 a17
1194 119c 1191 119e
119d :2 0 67 :3 0
78 :3 0 11a0 11a1
0 69 :4 0 141
:4 0 6c :2 0 6d
:3 0 a1b 11a5 11a7
:3 0 a1e 11a2 11a9
:2 0 11ab a21 11ac
119f 11ab 0 11ad
a23 0 11b7 85
:3 0 86 :3 0 11ae
11af 0 81 :3 0
8c :3 0 11b1 11b2
0 87 :3 0 a25
11b0 11b5 :2 0 11b7
a28 11b9 c59 e11
0 11ba 0 11b7
0 11ba a2c 0
17ff 15 :3 0 96
:3 0 11bb 11bc 0
15 :3 0 88 :2 0
a2 :3 0 11be 11c0
0 a32 11bf 11c2
:3 0 11c3 :2 0 58
:3 0 142 :3 0 31
:2 0 71 :3 0 33
:3 0 31 :2 0 a35
11c8 11cb 81 :3 0
143 :3 0 11cd 11ce
0 54 :3 0 a38
11c6 11d1 11c5 11d2
0 1279 58 :3 0
142 :3 0 31 :2 0
71 :3 0 33 :3 0
31 :2 0 a3d 11d7
11da 81 :3 0 144
:3 0 11dc 11dd 0
56 :3 0 a40 11d5
11e0 11d4 11e1 0
1279 11e :3 0 11d
:3 0 145 :3 0 56
:3 0 146 :3 0 81
:3 0 e1 :3 0 81
:3 0 e2 :3 0 81
:3 0 e3 :3 0 81
:3 0 e4 :3 0 81
:3 0 e5 :3 0 81
:3 0 147 :3 0 145
:3 0 56 :3 0 81
:3 0 148 :3 0 145
:3 0 54 :3 0 81
:3 0 147 :3 0 dc
:3 0 149 :3 0 11d
:3 0 81 :3 0 148
:3 0 145 :3 0 145
:3 0 56 :3 0 54
:3 0 145 :3 0 11c
:3 0 26 :4 0 14a
1 :8 0 121e 14b
:4 0 1209 :3 0 87
:3 0 88 :2 0 a47
120c 120d :3 0 15
:3 0 96 :3 0 120f
1210 0 31 :2 0
1211 1212 0 1214
a4a 121b 15 :3 0
96 :3 0 1215 1216
0 f2 :2 0 1217
1218 0 121a a4c
121c 120e 1214 0
121d 0 121a 0
121d a4e 0 121e
a51 1271 98 :3 0
15 :3 0 96 :3 0
1220 1221 0 97
:3 0 1222 1223 0
1225 a54 1227 a56
1226 1225 :2 0 126f
99 :3 0 15 :3 0
96 :3 0 122a 122b
0 97 :3 0 122c
122d 0 1267 64
:3 0 65 :3 0 122f
1230 0 64 :3 0
75 :3 0 1232 1233
0 9a :2 0 2
:4 0 14c :2 0 77
:2 0 23 :2 0 a58
1238 123a :3 0 a5b
1234 123c 1231 123e
123d :2 0 67 :3 0
78 :3 0 1240 1241
0 69 :4 0 14d
:4 0 6c :2 0 6d
:3 0 a5f 1245 1247
:3 0 6c :2 0 7f
:4 0 a62 1249 124b
:3 0 6c :2 0 9d
:4 0 a65 124d 124f
:3 0 6c :2 0 97
:3 0 a68 1251 1253
:3 0 6c :2 0 9e
:4 0 a6b 1255 1257
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 a6e
125a 125e a72 1259
1260 :3 0 a75 1242
1262 :2 0 1264 a78
1265 123f 1264 0
1266 a7a 0 1267
a7c 126a :3 0 126a
0 126a 1269 1267
1268 :6 0 126c 20
:3 0 a7f 126e a81
126d 126c :2 0 126f
a83 :2 0 1271 0
1271 1270 121e 126f
:6 0 1279 1 :3 0
58 :3 0 14e :3 0
26 :3 0 a86 1274
1276 1273 1277 0
1279 a88 1326 26
:3 0 14f :4 0 127b
127c :3 0 127a 127d
0 1325 58 :3 0
142 :3 0 31 :2 0
71 :3 0 33 :3 0
31 :2 0 a8d 1282
1285 81 :3 0 143
:3 0 1287 1288 0
54 :3 0 a90 1280
128b 127f 128c 0
1325 53 :3 0 81
:3 0 147 :3 0 128f
1290 0 128e 1291
0 1325 57 :3 0
23 :2 0 1293 1294
0 1325 58 :3 0
150 :3 0 17 :3 0
1b :3 0 33 :3 0
53 :3 0 54 :3 0
24 :3 0 57 :3 0
a95 1297 129f 1296
12a0 0 1325 11e
:3 0 11c :3 0 c8
:3 0 b8 :3 0 146
:3 0 151 :3 0 10d
:3 0 10c :3 0 11d
:3 0 145 :3 0 152
:3 0 153 :3 0 26
:3 0 17 :3 0 19
:3 0 33 :3 0 5b
:3 0 24 :3 0 1b
:3 0 81 :3 0 147
:3 0 54 :3 0 13
:3 0 6d :4 0 154
1 :8 0 12d0 14b
:4 0 12bb :3 0 87
:3 0 88 :2 0 a9f
12be 12bf :3 0 15
:3 0 96 :3 0 12c1
12c2 0 31 :2 0
12c3 12c4 0 12c6
aa2 12cd 15 :3 0
96 :3 0 12c7 12c8
0 f2 :2 0 12c9
12ca 0 12cc aa4
12ce 12c0 12c6 0
12cf 0 12cc 0
12cf aa6 0 12d0
aa9 1323 98 :3 0
15 :3 0 96 :3 0
12d2 12d3 0 97
:3 0 12d4 12d5 0
12d7 aac 12d9 aae
12d8 12d7 :2 0 1321
99 :3 0 15 :3 0
96 :3 0 12dc 12dd
0 97 :3 0 12de
12df 0 1319 64
:3 0 65 :3 0 12e1
12e2 0 64 :3 0
75 :3 0 12e4 12e5
0 9a :2 0 2
:4 0 155 :2 0 77
:2 0 23 :2 0 ab0
12ea 12ec :3 0 ab3
12e6 12ee 12e3 12f0
12ef :2 0 67 :3 0
78 :3 0 12f2 12f3
0 69 :4 0 156
:4 0 6c :2 0 6d
:3 0 ab7 12f7 12f9
:3 0 6c :2 0 7f
:4 0 aba 12fb 12fd
:3 0 6c :2 0 9d
:4 0 abd 12ff 1301
:3 0 6c :2 0 97
:3 0 ac0 1303 1305
:3 0 6c :2 0 9e
:4 0 ac3 1307 1309
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 ac6
130c 1310 aca 130b
1312 :3 0 acd 12f4
1314 :2 0 1316 ad0
1317 12f1 1316 0
1318 ad2 0 1319
ad4 131c :3 0 131c
0 131c 131b 1319
131a :6 0 131e 22
:3 0 ad7 1320 ad9
131f 131e :2 0 1321
adb :2 0 1323 0
1323 1322 12d0 1321
:6 0 1325 1 :3 0
ade 1327 11c4 1279
0 1328 0 1325
0 1328 ae5 0
17ff 71 :3 0 35
:3 0 31 :2 0 ae8
1329 132c 88 :2 0
31 :2 0 aed 132e
1330 :3 0 1331 :2 0
2c :3 0 91 :2 0
af0 1334 1335 :3 0
1336 :2 0 1332 1338
1337 :2 0 5f :3 0
88 :2 0 31 :2 0
af4 133b 133d :3 0
133e :2 0 1339 1340
133f :2 0 71 :3 0
37 :3 0 31 :2 0
af7 1342 1345 cc
:2 0 31 :2 0 afc
1347 1349 :3 0 71
:3 0 3b :3 0 31
:2 0 aff 134b 134e
8f :2 0 f2 :2 0
b04 1350 1352 :3 0
5c :3 0 71 :3 0
37 :3 0 31 :2 0
b07 1355 1358 1354
1359 0 135b b0a
137b 5c :3 0 157
:3 0 158 :3 0 71
:3 0 37 :3 0 31
:2 0 b0c 135f 1362
fd :2 0 71 :3 0
3f :3 0 31 :2 0
b0f 1365 1368 b12
1364 136a :3 0 136b
:2 0 b15 135e 136d
159 :2 0 15a :2 0
b17 136f 1371 :3 0
77 :2 0 15b :2 0
b1a 1373 1375 :3 0
b1d 135d 1377 135c
1378 0 137a b1f
137c 1353 135b 0
137d 0 137a 0
137d b21 0 1558
2c :4 0 137e 137f
0 1558 15c :3 0
15d :3 0 15e :3 0
2c :3 0 15f :3 0
160 :3 0 161 :3 0
15d :3 0 15d :3 0
c8 :3 0 17 :3 0
15d :3 0 102 :3 0
27 :3 0 15d :3 0
15e :3 0 103 :3 0
9f :3 0 1e :3 0
15d :3 0 162 :3 0
160 :3 0 b8 :3 0
1b :3 0 160 :3 0
15e :3 0 15d :3 0
15e :3 0 160 :3 0
163 :3 0 15d :3 0
164 :3 0 5c :4 0
165 1 :8 0 13a8
15 :3 0 96 :3 0
13a3 13a4 0 97
:3 0 13a5 13a6 0
13a8 b24 13fb 98
:3 0 15 :3 0 96
:3 0 13aa 13ab 0
97 :3 0 13ac 13ad
0 13af b27 13b1
b29 13b0 13af :2 0
13f9 99 :3 0 15
:3 0 96 :3 0 13b4
13b5 0 97 :3 0
13b6 13b7 0 13f1
64 :3 0 65 :3 0
13b9 13ba 0 64
:3 0 75 :3 0 13bc
13bd 0 9a :2 0
2 :4 0 166 :2 0
77 :2 0 23 :2 0
b2b 13c2 13c4 :3 0
b2e 13be 13c6 13bb
13c8 13c7 :2 0 67
:3 0 78 :3 0 13ca
13cb 0 69 :4 0
167 :4 0 6c :2 0
6d :3 0 b32 13cf
13d1 :3 0 6c :2 0
7f :4 0 b35 13d3
13d5 :3 0 6c :2 0
9d :4 0 b38 13d7
13d9 :3 0 6c :2 0
97 :3 0 b3b 13db
13dd :3 0 6c :2 0
9e :4 0 b3e 13df
13e1 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
b41 13e4 13e8 b45
13e3 13ea :3 0 b48
13cc 13ec :2 0 13ee
b4b 13ef 13c9 13ee
0 13f0 b4d 0
13f1 b4f 13f4 :3 0
13f4 0 13f4 13f3
13f1 13f2 :6 0 13f6
24 :3 0 b52 13f8
b54 13f7 13f6 :2 0
13f9 b56 :2 0 13fb
0 13fb 13fa 13a8
13f9 :6 0 1558 1
:3 0 2c :3 0 7b
:2 0 b59 13fe 13ff
:3 0 1400 :2 0 92
:3 0 168 :3 0 103
:3 0 9f :3 0 2d
:3 0 92 :3 0 169
:3 0 1e :3 0 94
:4 0 16a 1 :8 0
1411 15 :3 0 96
:3 0 140c 140d 0
97 :3 0 140e 140f
0 1411 b5b 1464
98 :3 0 15 :3 0
96 :3 0 1413 1414
0 97 :3 0 1415
1416 0 1418 b5e
141a b60 1419 1418
:2 0 1462 99 :3 0
15 :3 0 96 :3 0
141d 141e 0 97
:3 0 141f 1420 0
145a 64 :3 0 65
:3 0 1422 1423 0
64 :3 0 75 :3 0
1425 1426 0 9a
:2 0 2 :4 0 16b
:2 0 77 :2 0 23
:2 0 b62 142b 142d
:3 0 b65 1427 142f
1424 1431 1430 :2 0
67 :3 0 78 :3 0
1433 1434 0 69
:4 0 16c :4 0 6c
:2 0 6d :3 0 b69
1438 143a :3 0 6c
:2 0 7f :4 0 b6c
143c 143e :3 0 6c
:2 0 9d :4 0 b6f
1440 1442 :3 0 6c
:2 0 97 :3 0 b72
1444 1446 :3 0 6c
:2 0 9e :4 0 b75
1448 144a :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 b78 144d 1451
b7c 144c 1453 :3 0
b7f 1435 1455 :2 0
1457 b82 1458 1432
1457 0 1459 b84
0 145a b86 145d
:3 0 145d 0 145d
145c 145a 145b :6 0
145f 26 :3 0 b89
1461 b8b 1460 145f
:2 0 1462 b8d :2 0
1464 0 1464 1463
1411 1462 :6 0 1466
1 :3 0 b90 14d1
92 :3 0 168 :3 0
15e :3 0 dc :3 0
16d :3 0 16e :3 0
1e :3 0 161 :3 0
c8 :3 0 17 :3 0
102 :3 0 27 :3 0
15e :3 0 2c :4 0
16f 1 :8 0 147b
15 :3 0 96 :3 0
1476 1477 0 97
:3 0 1478 1479 0
147b b92 14ce 98
:3 0 15 :3 0 96
:3 0 147d 147e 0
97 :3 0 147f 1480
0 1482 b95 1484
b97 1483 1482 :2 0
14cc 99 :3 0 15
:3 0 96 :3 0 1487
1488 0 97 :3 0
1489 148a 0 14c4
64 :3 0 65 :3 0
148c 148d 0 64
:3 0 75 :3 0 148f
1490 0 9a :2 0
2 :4 0 170 :2 0
77 :2 0 23 :2 0
b99 1495 1497 :3 0
b9c 1491 1499 148e
149b 149a :2 0 67
:3 0 78 :3 0 149d
149e 0 69 :4 0
171 :4 0 6c :2 0
6d :3 0 ba0 14a2
14a4 :3 0 6c :2 0
7f :4 0 ba3 14a6
14a8 :3 0 6c :2 0
9d :4 0 ba6 14aa
14ac :3 0 6c :2 0
97 :3 0 ba9 14ae
14b0 :3 0 6c :2 0
9e :4 0 bac 14b2
14b4 :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
baf 14b7 14bb bb3
14b6 14bd :3 0 bb6
149f 14bf :2 0 14c1
bb9 14c2 149c 14c1
0 14c3 bbb 0
14c4 bbd 14c7 :3 0
14c7 0 14c7 14c6
14c4 14c5 :6 0 14c9
28 :3 0 bc0 14cb
bc2 14ca 14c9 :2 0
14cc bc4 :2 0 14ce
0 14ce 14cd 147b
14cc :6 0 14d0 1
:3 0 bc7 14d2 1401
1466 0 14d3 0
14d0 0 14d3 bc9
0 1558 61 :3 0
88 :2 0 23 :2 0
bce 14d5 14d7 :3 0
92 :3 0 172 :3 0
14d9 14da 0 1e
:3 0 1f :3 0 173
:2 0 bd1 14db 14df
cc :2 0 31 :2 0
bd7 14e1 14e3 :3 0
14d8 14e5 14e4 :2 0
64 :3 0 65 :3 0
14e7 14e8 0 64
:3 0 75 :3 0 14ea
14eb 0 18 :2 0
2 :4 0 174 :2 0
77 :2 0 23 :2 0
bda 14f0 14f2 :3 0
bdd 14ec 14f4 14e9
14f6 14f5 :2 0 67
:3 0 78 :3 0 14f8
14f9 0 69 :4 0
175 :4 0 6c :2 0
6d :3 0 be1 14fd
14ff :3 0 6c :2 0
7f :4 0 be4 1501
1503 :3 0 6c :2 0
80 :4 0 be7 1505
1507 :3 0 6c :2 0
71 :3 0 72 :3 0
81 :3 0 176 :3 0
150c 150d 0 bea
150b 150f 73 :4 0
bec 150a 1512 bef
1509 1514 :3 0 6c
:2 0 c2 :4 0 bf2
1516 1518 :3 0 6c
:2 0 6f :4 0 bf5
151a 151c :3 0 6c
:2 0 1b :3 0 bf8
151e 1520 :3 0 6c
:2 0 6f :4 0 bfb
1522 1524 :3 0 bfe
14fa 1526 :2 0 1528
c01 1529 14f7 1528
0 152a c03 0
1554 64 :3 0 65
:3 0 152b 152c 0
64 :3 0 75 :3 0
152e 152f 0 23
:2 0 2 :4 0 177
:2 0 77 :2 0 23
:2 0 c05 1534 1536
:3 0 c08 1530 1538
152d 153a 1539 :2 0
67 :3 0 78 :3 0
153c 153d 0 69
:4 0 178 :4 0 6c
:2 0 6d :3 0 c0c
1541 1543 :3 0 c0f
153e 1545 :2 0 1547
c12 1548 153b 1547
0 1549 c14 0
1554 85 :3 0 c5
:3 0 154a 154b 0
81 :3 0 176 :3 0
154d 154e 0 1b
:3 0 87 :3 0 c16
154c 1552 :2 0 1554
c1a 1555 14e6 1554
0 1556 c1e 0
1558 a9 :3 0 c20
16be 61 :3 0 88
:2 0 23 :2 0 c28
155a 155c :3 0 4f
:3 0 31 :2 0 155e
155f 0 16bc 179
:3 0 164 :3 0 4f
:3 0 161 :3 0 c8
:3 0 17 :3 0 102
:3 0 27 :3 0 15e
:3 0 103 :3 0 9f
:3 0 1e :3 0 103
:3 0 9f :3 0 1f
:4 0 17a 1 :8 0
1576 15 :3 0 96
:3 0 1571 1572 0
97 :3 0 1573 1574
0 1576 c2b 15c9
98 :3 0 15 :3 0
96 :3 0 1578 1579
0 97 :3 0 157a
157b 0 157d c2e
157f c30 157e 157d
:2 0 15c7 99 :3 0
15 :3 0 96 :3 0
1582 1583 0 97
:3 0 1584 1585 0
15bf 64 :3 0 65
:3 0 1587 1588 0
64 :3 0 75 :3 0
158a 158b 0 9a
:2 0 2 :4 0 17b
:2 0 77 :2 0 23
:2 0 c32 1590 1592
:3 0 c35 158c 1594
1589 1596 1595 :2 0
67 :3 0 78 :3 0
1598 1599 0 69
:4 0 17c :4 0 6c
:2 0 6d :3 0 c39
159d 159f :3 0 6c
:2 0 7f :4 0 c3c
15a1 15a3 :3 0 6c
:2 0 9d :4 0 c3f
15a5 15a7 :3 0 6c
:2 0 97 :3 0 c42
15a9 15ab :3 0 6c
:2 0 9e :4 0 c45
15ad 15af :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 c48 15b2 15b6
c4c 15b1 15b8 :3 0
c4f 159a 15ba :2 0
15bc c52 15bd 1597
15bc 0 15be c54
0 15bf c56 15c2
:3 0 15c2 0 15c2
15c1 15bf 15c0 :6 0
15c4 2a :3 0 c59
15c6 c5b 15c5 15c4
:2 0 15c7 c5d :2 0
15c9 0 15c9 15c8
1576 15c7 :6 0 16bc
1 :3 0 4e :3 0
31 :2 0 15cb 15cc
0 16bc 179 :3 0
163 :3 0 4e :3 0
15f :3 0 b8 :3 0
1b :3 0 15e :3 0
103 :3 0 9f :3 0
1e :3 0 103 :3 0
9f :3 0 1f :4 0
17d 1 :8 0 15e1
15 :3 0 96 :3 0
15dc 15dd 0 97
:3 0 15de 15df 0
15e1 c60 1634 98
:3 0 15 :3 0 96
:3 0 15e3 15e4 0
97 :3 0 15e5 15e6
0 15e8 c63 15ea
c65 15e9 15e8 :2 0
1632 99 :3 0 15
:3 0 96 :3 0 15ed
15ee 0 97 :3 0
15ef 15f0 0 162a
64 :3 0 65 :3 0
15f2 15f3 0 64
:3 0 75 :3 0 15f5
15f6 0 9a :2 0
2 :4 0 17e :2 0
77 :2 0 23 :2 0
c67 15fb 15fd :3 0
c6a 15f7 15ff 15f4
1601 1600 :2 0 67
:3 0 78 :3 0 1603
1604 0 69 :4 0
17f :4 0 6c :2 0
6d :3 0 c6e 1608
160a :3 0 6c :2 0
7f :4 0 c71 160c
160e :3 0 6c :2 0
9d :4 0 c74 1610
1612 :3 0 6c :2 0
97 :3 0 c77 1614
1616 :3 0 6c :2 0
9e :4 0 c7a 1618
161a :3 0 6c :2 0
9f :3 0 a0 :3 0
23 :2 0 a1 :2 0
c7d 161d 1621 c81
161c 1623 :3 0 c84
1605 1625 :2 0 1627
c87 1628 1602 1627
0 1629 c89 0
162a c8b 162d :3 0
162d 0 162d 162c
162a 162b :6 0 162f
2c :3 0 c8e 1631
c90 1630 162f :2 0
1632 c92 :2 0 1634
0 1634 1633 15e1
1632 :6 0 16bc 1
:3 0 71 :3 0 4e
:3 0 31 :2 0 c95
1636 1639 a3 :2 0
71 :3 0 4f :3 0
31 :2 0 c98 163c
163f 77 :2 0 71
:3 0 39 :3 0 31
:2 0 c9b 1642 1645
c9e 1641 1647 :3 0
1648 :2 0 ca3 163b
164a :3 0 64 :3 0
65 :3 0 164c 164d
0 64 :3 0 75
:3 0 164f 1650 0
18 :2 0 2 :4 0
180 :2 0 77 :2 0
23 :2 0 ca6 1655
1657 :3 0 ca9 1651
1659 164e 165b 165a
:2 0 67 :3 0 78
:3 0 165d 165e 0
69 :4 0 181 :4 0
6c :2 0 6d :3 0
cad 1662 1664 :3 0
6c :2 0 7f :4 0
cb0 1666 1668 :3 0
6c :2 0 80 :4 0
cb3 166a 166c :3 0
6c :2 0 71 :3 0
72 :3 0 81 :3 0
176 :3 0 1671 1672
0 cb6 1670 1674
73 :4 0 cb8 166f
1677 cbb 166e 1679
:3 0 6c :2 0 c2
:4 0 cbe 167b 167d
:3 0 6c :2 0 6f
:4 0 cc1 167f 1681
:3 0 6c :2 0 1b
:3 0 cc4 1683 1685
:3 0 6c :2 0 6f
:4 0 cc7 1687 1689
:3 0 cca 165f 168b
:2 0 168d ccd 168e
165c 168d 0 168f
ccf 0 16b9 64
:3 0 65 :3 0 1690
1691 0 64 :3 0
75 :3 0 1693 1694
0 23 :2 0 2
:4 0 182 :2 0 77
:2 0 23 :2 0 cd1
1699 169b :3 0 cd4
1695 169d 1692 169f
169e :2 0 67 :3 0
78 :3 0 16a1 16a2
0 69 :4 0 183
:4 0 6c :2 0 6d
:3 0 cd8 16a6 16a8
:3 0 cdb 16a3 16aa
:2 0 16ac cde 16ad
16a0 16ac 0 16ae
ce0 0 16b9 85
:3 0 c5 :3 0 16af
16b0 0 81 :3 0
176 :3 0 16b2 16b3
0 1b :3 0 87
:3 0 ce2 16b1 16b7
:2 0 16b9 ce6 16ba
164b 16b9 0 16bb
cea 0 16bc cec
16bd 155d 16bc 0
16bf 134a 1558 0
16bf cf2 0 1744
184 :3 0 25 :3 0
c7 :3 0 c8 :3 0
17 :4 0 185 1
:8 0 16cb 15 :3 0
96 :3 0 16c6 16c7
0 97 :3 0 16c8
16c9 0 16cb cf5
171e 98 :3 0 15
:3 0 96 :3 0 16cd
16ce 0 97 :3 0
16cf 16d0 0 16d2
cf8 16d4 cfa 16d3
16d2 :2 0 171c 99
:3 0 15 :3 0 96
:3 0 16d7 16d8 0
97 :3 0 16d9 16da
0 1714 64 :3 0
65 :3 0 16dc 16dd
0 64 :3 0 75
:3 0 16df 16e0 0
9a :2 0 2 :4 0
186 :2 0 77 :2 0
23 :2 0 cfc 16e5
16e7 :3 0 cff 16e1
16e9 16de 16eb 16ea
:2 0 67 :3 0 78
:3 0 16ed 16ee 0
69 :4 0 187 :4 0
6c :2 0 6d :3 0
d03 16f2 16f4 :3 0
6c :2 0 7f :4 0
d06 16f6 16f8 :3 0
6c :2 0 9d :4 0
d09 16fa 16fc :3 0
6c :2 0 97 :3 0
d0c 16fe 1700 :3 0
6c :2 0 9e :4 0
d0f 1702 1704 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 d12 1707
170b d16 1706 170d
:3 0 d19 16ef 170f
:2 0 1711 d1c 1712
16ec 1711 0 1713
d1e 0 1714 d20
1717 :3 0 1717 0
1717 1716 1714 1715
:6 0 1719 2e :3 0
d23 171b d25 171a
1719 :2 0 171c d27
:2 0 171e 0 171e
171d 16cb 171c :6 0
1744 1 :3 0 9f
:3 0 25 :3 0 23
:2 0 23 :2 0 d2a
1720 1724 88 :2 0
188 :4 0 d30 1726
1728 :3 0 4d :3 0
131 :2 0 23 :2 0
d33 172b 172d :3 0
172a 172e 0 1741
15 :3 0 96 :3 0
1730 1731 0 189
:3 0 17 :3 0 17
:3 0 27 :3 0 2c
:3 0 2d :3 0 50
:3 0 52 :3 0 4d
:3 0 4c :3 0 4b
:3 0 d35 1733 173e
1732 173f 0 1741
d40 1742 1729 1741
0 1743 d43 0
1744 d45 1745 1341
1744 0 1746 d49
0 17ff 9f :3 0
24 :3 0 23 :2 0
23 :2 0 d4b 1747
174b 88 :2 0 23
:4 0 d51 174d 174f
:3 0 46 :3 0 81
:3 0 18a :3 0 1752
1753 0 1751 1754
0 1756 d54 175f
46 :3 0 71 :3 0
3c :3 0 31 :2 0
d56 1758 175b 1757
175c 0 175e d59
1760 1750 1756 0
1761 0 175e 0
1761 d5b 0 17ff
60 :3 0 18b :3 0
26 :3 0 17 :3 0
19 :3 0 1b :3 0
49 :3 0 33 :3 0
20 :3 0 20 :3 0
20 :3 0 20 :3 0
1e :3 0 1f :3 0
43 :3 0 39 :3 0
37 :3 0 3a :3 0
3b :3 0 36 :3 0
46 :3 0 24 :3 0
35 :3 0 32 :3 0
3d :3 0 38 :3 0
34 :3 0 3f :3 0
47 :3 0 1a :3 0
31 :2 0 31 :2 0
51 :2 0 51 :2 0
31 :2 0 d5e 1763
1785 1762 1786 0
17ff 60 :3 0 88
:2 0 31 :2 0 d82
1789 178b :3 0 18c
:3 0 18d :3 0 18e
:3 0 1b :4 0 18f
1 :8 0 17a7 14b
:4 0 1792 :3 0 87
:3 0 88 :2 0 d87
1795 1796 :3 0 15
:3 0 96 :3 0 1798
1799 0 31 :2 0
179a 179b 0 179d
d8a 17a4 15 :3 0
96 :3 0 179e 179f
0 f2 :2 0 17a0
17a1 0 17a3 d8c
17a5 1797 179d 0
17a6 0 17a3 0
17a6 d8e 0 17a7
d91 17fa 98 :3 0
15 :3 0 96 :3 0
17a9 17aa 0 97
:3 0 17ab 17ac 0
17ae d94 17b0 d96
17af 17ae :2 0 17f8
99 :3 0 15 :3 0
96 :3 0 17b3 17b4
0 97 :3 0 17b5
17b6 0 17f0 64
:3 0 65 :3 0 17b8
17b9 0 64 :3 0
75 :3 0 17bb 17bc
0 9a :2 0 2
:4 0 190 :2 0 77
:2 0 23 :2 0 d98
17c1 17c3 :3 0 d9b
17bd 17c5 17ba 17c7
17c6 :2 0 67 :3 0
78 :3 0 17c9 17ca
0 69 :4 0 191
:4 0 6c :2 0 6d
:3 0 d9f 17ce 17d0
:3 0 6c :2 0 7f
:4 0 da2 17d2 17d4
:3 0 6c :2 0 9d
:4 0 da5 17d6 17d8
:3 0 6c :2 0 97
:3 0 da8 17da 17dc
:3 0 6c :2 0 9e
:4 0 dab 17de 17e0
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 dae
17e3 17e7 db2 17e2
17e9 :3 0 db5 17cb
17eb :2 0 17ed db8
17ee 17c8 17ed 0
17ef dba 0 17f0
dbc 17f3 :3 0 17f3
0 17f3 17f2 17f0
17f1 :6 0 17f5 30
:3 0 dbf 17f7 dc1
17f6 17f5 :2 0 17f8
dc3 :2 0 17fa 0
17fa 17f9 17a7 17f8
:6 0 17fc 1 :3 0
dc6 17fd 178c 17fc
0 17fe dc8 0
17ff dca 1ca4 2a
:3 0 f3 :4 0 1800
1801 0 1ca3 2b
:3 0 f3 :4 0 1803
1804 0 1ca3 28
:3 0 12 :3 0 1806
1807 0 1ca3 71
:3 0 192 :3 0 28
:3 0 dd3 180a 180c
31 :2 0 dd5 1809
180f a3 :2 0 18
:2 0 dda 1811 1813
:3 0 62 :3 0 31
:2 0 1815 1816 0
1818 ddd 1830 62
:3 0 157 :3 0 71
:3 0 192 :3 0 28
:3 0 ddf 181c 181e
31 :2 0 de1 181b
1821 77 :2 0 23
:2 0 de4 1823 1825
:3 0 1826 :2 0 159
:2 0 de :2 0 de7
1828 182a :3 0 dea
181a 182c 1819 182d
0 182f dec 1831
1814 1818 0 1832
0 182f 0 1832
dee 0 1ca3 62
:3 0 cc :2 0 31
:2 0 df3 1834 1836
:3 0 30 :3 0 31
:2 0 1838 1839 0
1ca0 193 :3 0 71
:3 0 30 :3 0 31
:2 0 df6 183c 183f
62 :3 0 a3 :2 0
194 :3 0 dfb 1842
1844 :3 0 1845 1c9f
1b :3 0 dc :3 0
dd :3 0 1848 1849
0 18 :2 0 18
:2 0 71 :3 0 30
:3 0 31 :2 0 dfe
184d 1850 fd :2 0
de :2 0 e01 1852
1854 :3 0 77 :2 0
23 :2 0 e04 1856
1858 :3 0 28 :3 0
e07 184a 185b 1847
185c 0 1c9d 24
:3 0 dc :3 0 dd
:3 0 185f 1860 0
23 :2 0 23 :2 0
71 :3 0 30 :3 0
31 :2 0 e0c 1864
1867 fd :2 0 de
:2 0 e0f 1869 186b
:3 0 77 :2 0 18
:2 0 e12 186d 186f
:3 0 77 :2 0 23
:2 0 e15 1871 1873
:3 0 28 :3 0 e18
1861 1876 185e 1877
0 1c9d 9f :3 0
24 :3 0 23 :2 0
23 :2 0 e1d 1879
187d 88 :2 0 23
:4 0 e23 187f 1881
:3 0 46 :3 0 81
:3 0 18a :3 0 1884
1885 0 1883 1886
0 18b4 71 :3 0
192 :3 0 2b :3 0
e26 1889 188b 31
:2 0 e28 1888 188e
88 :2 0 31 :2 0
e2d 1890 1892 :3 0
2b :3 0 1b :3 0
1894 1895 0 1897
e30 18b1 2b :3 0
9f :3 0 2b :3 0
6c :2 0 195 :4 0
e32 189b 189d :3 0
23 :2 0 29 :2 0
e35 1899 18a1 1898
18a2 0 18b0 2b
:3 0 9f :3 0 2b
:3 0 6c :2 0 1b
:3 0 e39 18a7 18a9
:3 0 23 :2 0 29
:2 0 e3c 18a5 18ad
18a4 18ae 0 18b0
e40 18b2 1893 1897
0 18b3 0 18b0
0 18b3 e43 0
18b4 e46 18e9 46
:3 0 71 :3 0 3c
:3 0 31 :2 0 e49
18b6 18b9 18b5 18ba
0 18e8 71 :3 0
192 :3 0 2a :3 0
e4c 18bd 18bf 31
:2 0 e4e 18bc 18c2
88 :2 0 31 :2 0
e53 18c4 18c6 :3 0
2a :3 0 1b :3 0
18c8 18c9 0 18cb
e56 18e5 2a :3 0
9f :3 0 2a :3 0
6c :2 0 195 :4 0
e58 18cf 18d1 :3 0
23 :2 0 29 :2 0
e5b 18cd 18d5 18cc
18d6 0 18e4 2a
:3 0 9f :3 0 2a
:3 0 6c :2 0 1b
:3 0 e5f 18db 18dd
:3 0 23 :2 0 29
:2 0 e62 18d9 18e1
18d8 18e2 0 18e4
e66 18e6 18c7 18cb
0 18e7 0 18e4
0 18e7 e69 0
18e8 e6c 18ea 1882
18b4 0 18eb 0
18e8 0 18eb e6f
0 1c9d 9f :3 0
24 :3 0 23 :2 0
23 :2 0 e72 18ec
18f0 88 :2 0 23
:4 0 e78 18f2 18f4
:3 0 35 :3 0 31
:2 0 18f6 18f7 0
18f9 e7b 18fa 18f5
18f9 0 18fb e7d
0 1c9d 41 :3 0
31 :2 0 18fc 18fd
0 1c9d 35 :3 0
31 :2 0 18ff 1900
0 1c9d 102 :3 0
196 :3 0 197 :3 0
27 :3 0 1e :3 0
1f :3 0 10a :3 0
10b :3 0 17 :3 0
10c :3 0 1b :3 0
10e :4 0 198 1
:8 0 1914 15 :3 0
96 :3 0 190f 1910
0 97 :3 0 1911
1912 0 1914 e7f
1967 98 :3 0 15
:3 0 96 :3 0 1916
1917 0 97 :3 0
1918 1919 0 191b
e82 191d e84 191c
191b :2 0 1965 99
:3 0 15 :3 0 96
:3 0 1920 1921 0
97 :3 0 1922 1923
0 195d 64 :3 0
65 :3 0 1925 1926
0 64 :3 0 75
:3 0 1928 1929 0
9a :2 0 2 :4 0
199 :2 0 77 :2 0
23 :2 0 e86 192e
1930 :3 0 e89 192a
1932 1927 1934 1933
:2 0 67 :3 0 78
:3 0 1936 1937 0
69 :4 0 19a :4 0
6c :2 0 6d :3 0
e8d 193b 193d :3 0
6c :2 0 7f :4 0
e90 193f 1941 :3 0
6c :2 0 9d :4 0
e93 1943 1945 :3 0
6c :2 0 97 :3 0
e96 1947 1949 :3 0
6c :2 0 9e :4 0
e99 194b 194d :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 e9c 1950
1954 ea0 194f 1956
:3 0 ea3 1938 1958
:2 0 195a ea6 195b
1935 195a 0 195c
ea8 0 195d eaa
1960 :3 0 1960 0
1960 195f 195d 195e
:6 0 1962 33 :3 0
ead 1964 eaf 1963
1962 :2 0 1965 eb1
:2 0 1967 0 1967
1966 1914 1965 :6 0
1c9d 32 :3 0 15
:3 0 96 :3 0 1969
196a 0 15 :3 0
88 :2 0 bc :3 0
196c 196e 0 eb6
196d 1970 :3 0 1971
:2 0 102 :3 0 196
:3 0 197 :3 0 27
:3 0 1e :3 0 1f
:3 0 10a :3 0 10b
:3 0 17 :3 0 10c
:3 0 1b :3 0 10e
:4 0 19b 1 :8 0
1985 15 :3 0 96
:3 0 1980 1981 0
97 :3 0 1982 1983
0 1985 eb9 19d8
98 :3 0 15 :3 0
96 :3 0 1987 1988
0 97 :3 0 1989
198a 0 198c ebc
198e ebe 198d 198c
:2 0 19d6 99 :3 0
15 :3 0 96 :3 0
1991 1992 0 97
:3 0 1993 1994 0
19ce 64 :3 0 65
:3 0 1996 1997 0
64 :3 0 75 :3 0
1999 199a 0 9a
:2 0 2 :4 0 19c
:2 0 77 :2 0 23
:2 0 ec0 199f 19a1
:3 0 ec3 199b 19a3
1998 19a5 19a4 :2 0
67 :3 0 78 :3 0
19a7 19a8 0 69
:4 0 19d :4 0 6c
:2 0 6d :3 0 ec7
19ac 19ae :3 0 6c
:2 0 7f :4 0 eca
19b0 19b2 :3 0 6c
:2 0 9d :4 0 ecd
19b4 19b6 :3 0 6c
:2 0 97 :3 0 ed0
19b8 19ba :3 0 6c
:2 0 9e :4 0 ed3
19bc 19be :3 0 6c
:2 0 9f :3 0 a0
:3 0 23 :2 0 a1
:2 0 ed6 19c1 19c5
eda 19c0 19c7 :3 0
edd 19a9 19c9 :2 0
19cb ee0 19cc 19a6
19cb 0 19cd ee2
0 19ce ee4 19d1
:3 0 19d1 0 19d1
19d0 19ce 19cf :6 0
19d3 35 :3 0 ee7
19d5 ee9 19d4 19d3
:2 0 19d6 eeb :2 0
19d8 0 19d8 19d7
1985 19d6 :6 0 19ef
32 :3 0 15 :3 0
96 :3 0 19da 19db
0 15 :3 0 88
:2 0 a2 :3 0 19dd
19df 0 ef0 19de
19e1 :3 0 19e2 :2 0
35 :3 0 fe :2 0
19e4 19e5 0 19e7
ef3 19ec 1e :3 0
1c :3 0 19e8 19e9
0 19eb ef5 19ed
19e3 19e7 0 19ee
0 19eb 0 19ee
ef7 0 19ef efa
19f0 1972 19ef 0
19f1 efd 0 1c9d
71 :3 0 35 :3 0
31 :2 0 eff 19f2
19f5 88 :2 0 31
:2 0 f04 19f7 19f9
:3 0 71 :3 0 37
:3 0 31 :2 0 f07
19fb 19fe cc :2 0
31 :2 0 f0c 1a00
1a02 :3 0 71 :3 0
3b :3 0 31 :2 0
f0f 1a04 1a07 8f
:2 0 f2 :2 0 f14
1a09 1a0b :3 0 5c
:3 0 71 :3 0 37
:3 0 31 :2 0 f17
1a0e 1a11 1a0d 1a12
0 1a14 f1a 1a34
5c :3 0 157 :3 0
158 :3 0 71 :3 0
37 :3 0 31 :2 0
f1c 1a18 1a1b fd
:2 0 71 :3 0 3f
:3 0 31 :2 0 f1f
1a1e 1a21 f22 1a1d
1a23 :3 0 1a24 :2 0
f25 1a17 1a26 159
:2 0 15a :2 0 f27
1a28 1a2a :3 0 77
:2 0 15b :2 0 f2a
1a2c 1a2e :3 0 f2d
1a16 1a30 1a15 1a31
0 1a33 f2f 1a35
1a0c 1a14 0 1a36
0 1a33 0 1a36
f31 0 1b28 2c
:4 0 1a37 1a38 0
1b28 15c :3 0 15d
:3 0 15e :3 0 2c
:3 0 15f :3 0 160
:3 0 161 :3 0 15d
:3 0 15d :3 0 c8
:3 0 17 :3 0 15d
:3 0 102 :3 0 27
:3 0 15d :3 0 15e
:3 0 103 :3 0 9f
:3 0 1c :3 0 15d
:3 0 162 :3 0 160
:3 0 b8 :3 0 1b
:3 0 160 :3 0 15e
:3 0 15d :3 0 15e
:3 0 160 :3 0 163
:3 0 15d :3 0 164
:3 0 5c :4 0 19e
1 :8 0 1a61 15
:3 0 96 :3 0 1a5c
1a5d 0 97 :3 0
1a5e 1a5f 0 1a61
f34 1ab4 98 :3 0
15 :3 0 96 :3 0
1a63 1a64 0 97
:3 0 1a65 1a66 0
1a68 f37 1a6a f39
1a69 1a68 :2 0 1ab2
99 :3 0 15 :3 0
96 :3 0 1a6d 1a6e
0 97 :3 0 1a6f
1a70 0 1aaa 64
:3 0 65 :3 0 1a72
1a73 0 64 :3 0
75 :3 0 1a75 1a76
0 9a :2 0 2
:4 0 19f :2 0 77
:2 0 23 :2 0 f3b
1a7b 1a7d :3 0 f3e
1a77 1a7f 1a74 1a81
1a80 :2 0 67 :3 0
78 :3 0 1a83 1a84
0 69 :4 0 1a0
:4 0 6c :2 0 6d
:3 0 f42 1a88 1a8a
:3 0 6c :2 0 7f
:4 0 f45 1a8c 1a8e
:3 0 6c :2 0 9d
:4 0 f48 1a90 1a92
:3 0 6c :2 0 97
:3 0 f4b 1a94 1a96
:3 0 6c :2 0 9e
:4 0 f4e 1a98 1a9a
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 f51
1a9d 1aa1 f55 1a9c
1aa3 :3 0 f58 1a85
1aa5 :2 0 1aa7 f5b
1aa8 1a82 1aa7 0
1aa9 f5d 0 1aaa
f5f 1aad :3 0 1aad
0 1aad 1aac 1aaa
1aab :6 0 1aaf 37
:3 0 f62 1ab1 f64
1ab0 1aaf :2 0 1ab2
f66 :2 0 1ab4 0
1ab4 1ab3 1a61 1ab2
:6 0 1b28 32 :3 0
2c :3 0 91 :2 0
f69 1ab7 1ab8 :3 0
1ab9 :2 0 92 :3 0
168 :3 0 15e :3 0
dc :3 0 16d :3 0
16e :3 0 1e :3 0
161 :3 0 c8 :3 0
17 :3 0 102 :3 0
27 :3 0 15e :3 0
2c :4 0 1a1 1
:8 0 1acf 15 :3 0
96 :3 0 1aca 1acb
0 97 :3 0 1acc
1acd 0 1acf f6b
1b22 98 :3 0 15
:3 0 96 :3 0 1ad1
1ad2 0 97 :3 0
1ad3 1ad4 0 1ad6
f6e 1ad8 f70 1ad7
1ad6 :2 0 1b20 99
:3 0 15 :3 0 96
:3 0 1adb 1adc 0
97 :3 0 1add 1ade
0 1b18 64 :3 0
65 :3 0 1ae0 1ae1
0 64 :3 0 75
:3 0 1ae3 1ae4 0
9a :2 0 2 :4 0
1a2 :2 0 77 :2 0
23 :2 0 f72 1ae9
1aeb :3 0 f75 1ae5
1aed 1ae2 1aef 1aee
:2 0 67 :3 0 78
:3 0 1af1 1af2 0
69 :4 0 1a3 :4 0
6c :2 0 6d :3 0
f79 1af6 1af8 :3 0
6c :2 0 7f :4 0
f7c 1afa 1afc :3 0
6c :2 0 9d :4 0
f7f 1afe 1b00 :3 0
6c :2 0 97 :3 0
f82 1b02 1b04 :3 0
6c :2 0 9e :4 0
f85 1b06 1b08 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 f88 1b0b
1b0f f8c 1b0a 1b11
:3 0 f8f 1af3 1b13
:2 0 1b15 f92 1b16
1af0 1b15 0 1b17
f94 0 1b18 f96
1b1b :3 0 1b1b 0
1b1b 1b1a 1b18 1b19
:6 0 1b1d 39 :3 0
f99 1b1f f9b 1b1e
1b1d :2 0 1b20 f9d
:2 0 1b22 0 1b22
1b21 1acf 1b20 :6 0
1b24 32 :3 0 fa0
1b25 1aba 1b24 0
1b26 fa2 0 1b28
a9 :3 0 fa4 1bb0
92 :3 0 172 :3 0
1b29 1b2a 0 1c
:3 0 1e :3 0 9a
:2 0 fa9 1b2b 1b2f
1a4 :2 0 31 :2 0
faf 1b31 1b33 :3 0
92 :3 0 172 :3 0
1b35 1b36 0 1c
:3 0 1f :3 0 9a
:2 0 fb2 1b37 1b3b
1a5 :2 0 31 :2 0
fb8 1b3d 1b3f :3 0
1b34 1b41 1b40 :2 0
92 :3 0 168 :3 0
103 :3 0 9f :3 0
1e :3 0 92 :3 0
169 :3 0 1e :3 0
94 :4 0 1a6 1
:8 0 1b52 15 :3 0
96 :3 0 1b4d 1b4e
0 97 :3 0 1b4f
1b50 0 1b52 fbb
1ba5 98 :3 0 15
:3 0 96 :3 0 1b54
1b55 0 97 :3 0
1b56 1b57 0 1b59
fbe 1b5b fc0 1b5a
1b59 :2 0 1ba3 99
:3 0 15 :3 0 96
:3 0 1b5e 1b5f 0
97 :3 0 1b60 1b61
0 1b9b 64 :3 0
65 :3 0 1b63 1b64
0 64 :3 0 75
:3 0 1b66 1b67 0
9a :2 0 2 :4 0
1a7 :2 0 77 :2 0
23 :2 0 fc2 1b6c
1b6e :3 0 fc5 1b68
1b70 1b65 1b72 1b71
:2 0 67 :3 0 78
:3 0 1b74 1b75 0
69 :4 0 1a8 :4 0
6c :2 0 6d :3 0
fc9 1b79 1b7b :3 0
6c :2 0 7f :4 0
fcc 1b7d 1b7f :3 0
6c :2 0 9d :4 0
fcf 1b81 1b83 :3 0
6c :2 0 97 :3 0
fd2 1b85 1b87 :3 0
6c :2 0 9e :4 0
fd5 1b89 1b8b :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 fd8 1b8e
1b92 fdc 1b8d 1b94
:3 0 fdf 1b76 1b96
:2 0 1b98 fe2 1b99
1b73 1b98 0 1b9a
fe4 0 1b9b fe6
1b9e :3 0 1b9e 0
1b9e 1b9d 1b9b 1b9c
:6 0 1ba0 3b :3 0
fe9 1ba2 feb 1ba1
1ba0 :2 0 1ba3 fed
:2 0 1ba5 0 1ba5
1ba4 1b52 1ba3 :6 0
1ba7 32 :3 0 ff0
1ba8 1b42 1ba7 0
1bb2 1e :3 0 1c
:3 0 1ba9 1baa 0
1baf 1f :3 0 6
:3 0 1bac 1bad 0
1baf ff2 1bb1 1a03
1b28 0 1bb2 0
1baf 0 1bb2 ff5
0 1bb3 ff9 1bbb
1e :3 0 1c :3 0
1bb4 1bb5 0 1bba
1f :3 0 6 :3 0
1bb7 1bb8 0 1bba
ffb 1bbc 19fa 1bb3
0 1bbd 0 1bba
0 1bbd ffe 0
1c9d 71 :3 0 41
:3 0 31 :2 0 1001
1bbe 1bc1 cc :2 0
31 :2 0 1006 1bc3
1bc5 :3 0 9f :3 0
24 :3 0 23 :2 0
23 :2 0 1009 1bc7
1bcb 88 :2 0 23
:4 0 100f 1bcd 1bcf
:3 0 34 :3 0 ff
:2 0 1bd1 1bd2 0
1bd4 1012 1bd5 1bd0
1bd4 0 1bd6 1014
0 1bd8 a9 :3 0
1016 1bf2 9f :3 0
24 :3 0 23 :2 0
23 :2 0 1018 1bd9
1bdd 88 :2 0 23
:4 0 101e 1bdf 1be1
:3 0 46 :3 0 81
:3 0 18a :3 0 1be4
1be5 0 1be3 1be6
0 1be8 1021 1be9
1be2 1be8 0 1bf4
46 :3 0 71 :3 0
3c :3 0 31 :2 0
1023 1beb 1bee 1bea
1bef 0 1bf1 1026
1bf3 1bc6 1bd8 0
1bf4 0 1bf1 0
1bf4 1028 0 1c9d
60 :3 0 18b :3 0
26 :3 0 17 :3 0
19 :3 0 1b :3 0
49 :3 0 33 :3 0
20 :3 0 20 :3 0
20 :3 0 20 :3 0
1e :3 0 1f :3 0
43 :3 0 39 :3 0
37 :3 0 3a :3 0
3b :3 0 36 :3 0
46 :3 0 24 :3 0
35 :3 0 32 :3 0
3d :3 0 38 :3 0
34 :3 0 3f :3 0
47 :3 0 1a :3 0
31 :2 0 31 :2 0
51 :2 0 51 :2 0
31 :2 0 102c 1bf6
1c18 1bf5 1c19 0
1c9d 60 :3 0 88
:2 0 31 :2 0 1050
1c1c 1c1e :3 0 18c
:3 0 18d :3 0 18e
:3 0 1b :4 0 18f
1 :8 0 1c3a 14b
:4 0 1c25 :3 0 87
:3 0 88 :2 0 1055
1c28 1c29 :3 0 15
:3 0 96 :3 0 1c2b
1c2c 0 31 :2 0
1c2d 1c2e 0 1c30
1058 1c37 15 :3 0
96 :3 0 1c31 1c32
0 f2 :2 0 1c33
1c34 0 1c36 105a
1c38 1c2a 1c30 0
1c39 0 1c36 0
1c39 105c 0 1c3a
105f 1c8d 98 :3 0
15 :3 0 96 :3 0
1c3c 1c3d 0 97
:3 0 1c3e 1c3f 0
1c41 1062 1c43 1064
1c42 1c41 :2 0 1c8b
99 :3 0 15 :3 0
96 :3 0 1c46 1c47
0 97 :3 0 1c48
1c49 0 1c83 64
:3 0 65 :3 0 1c4b
1c4c 0 64 :3 0
75 :3 0 1c4e 1c4f
0 9a :2 0 2
:4 0 1a9 :2 0 77
:2 0 23 :2 0 1066
1c54 1c56 :3 0 1069
1c50 1c58 1c4d 1c5a
1c59 :2 0 67 :3 0
78 :3 0 1c5c 1c5d
0 69 :4 0 1aa
:4 0 6c :2 0 6d
:3 0 106d 1c61 1c63
:3 0 6c :2 0 7f
:4 0 1070 1c65 1c67
:3 0 6c :2 0 9d
:4 0 1073 1c69 1c6b
:3 0 6c :2 0 97
:3 0 1076 1c6d 1c6f
:3 0 6c :2 0 9e
:4 0 1079 1c71 1c73
:3 0 6c :2 0 9f
:3 0 a0 :3 0 23
:2 0 a1 :2 0 107c
1c76 1c7a 1080 1c75
1c7c :3 0 1083 1c5e
1c7e :2 0 1c80 1086
1c81 1c5b 1c80 0
1c82 1088 0 1c83
108a 1c86 :3 0 1c86
0 1c86 1c85 1c83
1c84 :6 0 1c88 3d
:3 0 108d 1c8a 108f
1c89 1c88 :2 0 1c8b
1091 :2 0 1c8d 0
1c8d 1c8c 1c3a 1c8b
:6 0 1c8f 32 :3 0
1094 1c90 1c1f 1c8f
0 1c91 1096 0
1c9d 30 :3 0 71
:3 0 30 :3 0 31
:2 0 1098 1c93 1c96
77 :2 0 23 :2 0
109b 1c98 1c9a :3 0
1c92 1c9b 0 1c9d
109e 1c9f 194 :3 0
1846 1c9d :4 0 1ca0
10ac 1ca1 1837 1ca0
0 1ca2 10af 0
1ca3 10b1 1ca5 c49
17ff 0 1ca6 0
1ca3 0 1ca6 10b7
0 1f6c 60 :3 0
8f :2 0 31 :2 0
10bc 1ca8 1caa :3 0
1cab :2 0 71 :3 0
33 :3 0 31 :2 0
10bf 1cad 1cb0 cc
:2 0 31 :2 0 10c4
1cb2 1cb4 :3 0 1cb5
:2 0 1cac 1cb7 1cb6
:2 0 64 :3 0 65
:3 0 1cb9 1cba 0
64 :3 0 75 :3 0
1cbc 1cbd 0 18
:2 0 2 :4 0 1ab
:2 0 77 :2 0 23
:2 0 10c7 1cc2 1cc4
:3 0 10ca 1cbe 1cc6
1cbb 1cc8 1cc7 :2 0
67 :3 0 78 :3 0
1cca 1ccb 0 69
:4 0 1ac :4 0 6c
:2 0 6d :3 0 10ce
1ccf 1cd1 :3 0 6c
:2 0 7f :4 0 10d1
1cd3 1cd5 :3 0 6c
:2 0 80 :4 0 10d4
1cd7 1cd9 :3 0 6c
:2 0 71 :3 0 72
:3 0 81 :3 0 1ad
:3 0 1cde 1cdf 0
10d7 1cdd 1ce1 73
:4 0 10d9 1cdc 1ce4
10dc 1cdb 1ce6 :3 0
6c :2 0 c2 :4 0
10df 1ce8 1cea :3 0
6c :2 0 6f :4 0
10e2 1cec 1cee :3 0
6c :2 0 26 :3 0
10e5 1cf0 1cf2 :3 0
6c :2 0 6f :4 0
10e8 1cf4 1cf6 :3 0
10eb 1ccc 1cf8 :2 0
1cfa 10ee 1cfb 1cc9
1cfa 0 1cfc 10f0
0 1d26 64 :3 0
65 :3 0 1cfd 1cfe
0 64 :3 0 75
:3 0 1d00 1d01 0
23 :2 0 2 :4 0
1ae :2 0 77 :2 0
23 :2 0 10f2 1d06
1d08 :3 0 10f5 1d02
1d0a 1cff 1d0c 1d0b
:2 0 67 :3 0 78
:3 0 1d0e 1d0f 0
69 :4 0 1af :4 0
6c :2 0 6d :3 0
10f9 1d13 1d15 :3 0
10fc 1d10 1d17 :2 0
1d19 10ff 1d1a 1d0d
1d19 0 1d1b 1101
0 1d26 85 :3 0
c5 :3 0 1d1c 1d1d
0 81 :3 0 1ad
:3 0 1d1f 1d20 0
26 :3 0 87 :3 0
1103 1d1e 1d24 :2 0
1d26 1107 1d27 1cb8
1d26 0 1d28 110b
0 1f6c 71 :3 0
33 :3 0 31 :2 0
110d 1d29 1d2c cc
:2 0 31 :2 0 1112
1d2e 1d30 :3 0 17
:3 0 19 :3 0 1d32
1d33 0 1d35 1115
1d36 1d31 1d35 0
1d37 1117 0 1f6c
71 :3 0 192 :3 0
2a :3 0 1119 1d39
1d3b 31 :2 0 111b
1d38 1d3e cc :2 0
31 :2 0 1120 1d40
1d42 :3 0 1d43 :2 0
71 :3 0 192 :3 0
2b :3 0 1123 1d46
1d48 31 :2 0 1125
1d45 1d4b cc :2 0
31 :2 0 112a 1d4d
1d4f :3 0 1d50 :2 0
1d44 1d52 1d51 :2 0
59 :3 0 1b0 :4 0
6c :2 0 1b1 :4 0
112d 1d56 1d58 :3 0
6c :2 0 1b2 :4 0
1130 1d5a 1d5c :3 0
6c :2 0 1b3 :4 0
1133 1d5e 1d60 :3 0
6c :2 0 1b4 :4 0
1136 1d62 1d64 :3 0
6c :2 0 72 :3 0
71 :3 0 39 :3 0
31 :2 0 1139 1d68
1d6b 113c 1d67 1d6d
113e 1d66 1d6f :3 0
6c :2 0 1b5 :4 0
1141 1d71 1d73 :3 0
6c :2 0 72 :3 0
71 :3 0 3a :3 0
31 :2 0 1144 1d77
1d7a 1147 1d76 1d7c
1149 1d75 1d7e :3 0
6c :2 0 1b6 :4 0
114c 1d80 1d82 :3 0
6c :2 0 72 :3 0
71 :3 0 3f :3 0
31 :2 0 114f 1d86
1d89 1152 1d85 1d8b
1154 1d84 1d8d :3 0
6c :2 0 1b7 :4 0
1157 1d8f 1d91 :3 0
6c :2 0 1b8 :4 0
115a 1d93 1d95 :3 0
6c :2 0 1b9 :4 0
115d 1d97 1d99 :3 0
6c :2 0 1ba :4 0
1160 1d9b 1d9d :3 0
6c :2 0 1bb :4 0
1163 1d9f 1da1 :3 0
6c :2 0 1bc :4 0
1166 1da3 1da5 :3 0
6c :2 0 17 :3 0
1169 1da7 1da9 :3 0
6c :2 0 1bd :4 0
116c 1dab 1dad :3 0
6c :2 0 2a :3 0
116f 1daf 1db1 :3 0
6c :2 0 1be :4 0
1172 1db3 1db5 :3 0
6c :2 0 1bf :4 0
1175 1db7 1db9 :3 0
6c :2 0 1c0 :4 0
1178 1dbb 1dbd :3 0
6c :2 0 1c1 :4 0
117b 1dbf 1dc1 :3 0
6c :2 0 81 :3 0
1c2 :3 0 1dc4 1dc5
0 117e 1dc3 1dc7
:3 0 6c :2 0 1c3
:4 0 1181 1dc9 1dcb
:3 0 6c :2 0 81
:3 0 1c2 :3 0 1dce
1dcf 0 1184 1dcd
1dd1 :3 0 6c :2 0
1c4 :4 0 1187 1dd3
1dd5 :3 0 6c :2 0
1c5 :4 0 118a 1dd7
1dd9 :3 0 6c :2 0
1c6 :4 0 118d 1ddb
1ddd :3 0 6c :2 0
72 :3 0 71 :3 0
39 :3 0 31 :2 0
1190 1de1 1de4 1193
1de0 1de6 1195 1ddf
1de8 :3 0 6c :2 0
1b5 :4 0 1198 1dea
1dec :3 0 6c :2 0
72 :3 0 71 :3 0
3a :3 0 31 :2 0
119b 1df0 1df3 119e
1def 1df5 11a0 1dee
1df7 :3 0 6c :2 0
1c7 :4 0 11a3 1df9
1dfb :3 0 6c :2 0
1c8 :4 0 11a6 1dfd
1dff :3 0 6c :2 0
72 :3 0 71 :3 0
3f :3 0 31 :2 0
11a9 1e03 1e06 11ac
1e02 1e08 11ae 1e01
1e0a :3 0 6c :2 0
1c9 :4 0 11b1 1e0c
1e0e :3 0 6c :2 0
1ca :4 0 11b4 1e10
1e12 :3 0 6c :2 0
17 :3 0 11b7 1e14
1e16 :3 0 6c :2 0
1cb :4 0 11ba 1e18
1e1a :3 0 6c :2 0
2b :3 0 11bd 1e1c
1e1e :3 0 6c :2 0
1cc :4 0 11c0 1e20
1e22 :3 0 6c :2 0
1cd :4 0 11c3 1e24
1e26 :3 0 6c :2 0
1ce :4 0 11c6 1e28
1e2a :3 0 1d54 1e2b
0 1e2e a9 :3 0
11c9 1f24 71 :3 0
192 :3 0 2a :3 0
11cb 1e30 1e32 31
:2 0 11cd 1e2f 1e35
cc :2 0 31 :2 0
11d2 1e37 1e39 :3 0
59 :3 0 1b0 :4 0
6c :2 0 1b1 :4 0
11d5 1e3d 1e3f :3 0
6c :2 0 1b2 :4 0
11d8 1e41 1e43 :3 0
6c :2 0 1b3 :4 0
11db 1e45 1e47 :3 0
6c :2 0 1b4 :4 0
11de 1e49 1e4b :3 0
6c :2 0 72 :3 0
71 :3 0 39 :3 0
31 :2 0 11e1 1e4f
1e52 11e4 1e4e 1e54
11e6 1e4d 1e56 :3 0
6c :2 0 1b5 :4 0
11e9 1e58 1e5a :3 0
6c :2 0 72 :3 0
71 :3 0 3a :3 0
31 :2 0 11ec 1e5e
1e61 11ef 1e5d 1e63
11f1 1e5c 1e65 :3 0
6c :2 0 1b6 :4 0
11f4 1e67 1e69 :3 0
6c :2 0 72 :3 0
71 :3 0 3f :3 0
31 :2 0 11f7 1e6d
1e70 11fa 1e6c 1e72
11fc 1e6b 1e74 :3 0
6c :2 0 1b7 :4 0
11ff 1e76 1e78 :3 0
6c :2 0 1b8 :4 0
1202 1e7a 1e7c :3 0
6c :2 0 1b9 :4 0
1205 1e7e 1e80 :3 0
6c :2 0 1ba :4 0
1208 1e82 1e84 :3 0
6c :2 0 1bb :4 0
120b 1e86 1e88 :3 0
6c :2 0 1bc :4 0
120e 1e8a 1e8c :3 0
6c :2 0 17 :3 0
1211 1e8e 1e90 :3 0
6c :2 0 1bd :4 0
1214 1e92 1e94 :3 0
6c :2 0 2a :3 0
1217 1e96 1e98 :3 0
6c :2 0 1be :4 0
121a 1e9a 1e9c :3 0
6c :2 0 1ce :4 0
121d 1e9e 1ea0 :3 0
1e3b 1ea1 0 1ea4
a9 :3 0 1220 1ea5
1e3a 1ea4 0 1f25
71 :3 0 192 :3 0
2b :3 0 1222 1ea7
1ea9 31 :2 0 1224
1ea6 1eac cc :2 0
31 :2 0 1229 1eae
1eb0 :3 0 59 :3 0
1c0 :4 0 6c :2 0
1c1 :4 0 122c 1eb4
1eb6 :3 0 6c :2 0
81 :3 0 1c2 :3 0
1eb9 1eba 0 122f
1eb8 1ebc :3 0 6c
:2 0 1c3 :4 0 1232
1ebe 1ec0 :3 0 6c
:2 0 81 :3 0 1c2
:3 0 1ec3 1ec4 0
1235 1ec2 1ec6 :3 0
6c :2 0 1c4 :4 0
1238 1ec8 1eca :3 0
6c :2 0 1c5 :4 0
123b 1ecc 1ece :3 0
6c :2 0 1c6 :4 0
123e 1ed0 1ed2 :3 0
6c :2 0 72 :3 0
71 :3 0 39 :3 0
31 :2 0 1241 1ed6
1ed9 1244 1ed5 1edb
1246 1ed4 1edd :3 0
6c :2 0 1b5 :4 0
1249 1edf 1ee1 :3 0
6c :2 0 72 :3 0
71 :3 0 3a :3 0
31 :2 0 124c 1ee5
1ee8 124f 1ee4 1eea
1251 1ee3 1eec :3 0
6c :2 0 1c7 :4 0
1254 1eee 1ef0 :3 0
6c :2 0 1c8 :4 0
1257 1ef2 1ef4 :3 0
6c :2 0 72 :3 0
71 :3 0 3f :3 0
31 :2 0 125a 1ef8
1efb 125d 1ef7 1efd
125f 1ef6 1eff :3 0
6c :2 0 1c9 :4 0
1262 1f01 1f03 :3 0
6c :2 0 1ca :4 0
1265 1f05 1f07 :3 0
6c :2 0 17 :3 0
1268 1f09 1f0b :3 0
6c :2 0 1cb :4 0
126b 1f0d 1f0f :3 0
6c :2 0 2b :3 0
126e 1f11 1f13 :3 0
6c :2 0 1cc :4 0
1271 1f15 1f17 :3 0
6c :2 0 1cd :4 0
1274 1f19 1f1b :3 0
6c :2 0 1ce :4 0
1277 1f1d 1f1f :3 0
1eb2 1f20 0 1f22
127a 1f23 1eb1 1f22
0 1f25 1d53 1e2e
0 1f25 127c 0
1f6c 64 :3 0 65
:3 0 1f26 1f27 0
64 :3 0 75 :3 0
1f29 1f2a 0 23
:2 0 2 :4 0 1cf
:2 0 77 :2 0 23
:2 0 1280 1f2f 1f31
:3 0 1283 1f2b 1f33
1f28 1f35 1f34 :2 0
67 :3 0 78 :3 0
1f37 1f38 0 69
:4 0 1d0 :4 0 6c
:2 0 6d :3 0 1287
1f3c 1f3e :3 0 128a
1f39 1f40 :2 0 1f42
128d 1f43 1f36 1f42
0 1f44 128f 0
1f6c 64 :3 0 65
:3 0 1f45 1f46 0
64 :3 0 75 :3 0
1f48 1f49 0 23
:2 0 2 :4 0 1d1
:2 0 77 :2 0 23
:2 0 1291 1f4e 1f50
:3 0 1294 1f4a 1f52
1f47 1f54 1f53 :2 0
67 :3 0 78 :3 0
1f56 1f57 0 69
:4 0 1d2 :4 0 6c
:2 0 6d :3 0 1298
1f5b 1f5d :3 0 129b
1f58 1f5f :2 0 1f61
129e 1f62 1f55 1f61
0 1f63 12a0 0
1f6c 14 :3 0 85
:3 0 1d3 :3 0 1f65
1f66 0 59 :3 0
12a2 1f67 1f69 1f6a
:2 0 1f6c 12a4 200d
15 :3 0 1d4 :2 0
4 1f6d 1f6e 0
64 :3 0 65 :3 0
1f70 1f71 0 64
:3 0 75 :3 0 1f73
1f74 0 9a :2 0
2 :4 0 1d5 :2 0
77 :2 0 23 :2 0
12d1 1f79 1f7b :3 0
12d4 1f75 1f7d 1f72
1f7f 1f7e :2 0 67
:3 0 78 :3 0 1f81
1f82 0 69 :4 0
1d6 :4 0 6c :2 0
6d :3 0 12d8 1f86
1f88 :3 0 12db 1f83
1f8a :2 0 1fa3 67
:3 0 78 :3 0 1f8c
1f8d 0 69 :4 0
1d7 :4 0 6c :2 0
15 :3 0 1d8 :3 0
1f92 1f93 0 12de
1f91 1f95 :3 0 6c
:2 0 c2 :4 0 12e1
1f97 1f99 :3 0 6c
:2 0 15 :3 0 1d9
:3 0 1f9c 1f9d 0
12e4 1f9b 1f9f :3 0
12e7 1f8e 1fa1 :2 0
1fa3 12ea 1fa4 1f80
1fa3 0 1fa5 12ed
0 1fb5 1da :3 0
63 :3 0 15 :3 0
1d8 :3 0 1db :3 0
15 :3 0 1d9 :3 0
1dc :3 0 94 :4 0
1dd 1 :a 0 1fb1
:2 0 1fb5 1fa7 1faf
:2 0 14 :3 0 63
:3 0 1fb3 :2 0 1fb5
12ef 1fb7 12f3 1fb6
1fb5 :2 0 200b 99
:3 0 15 :3 0 96
:3 0 1fba 1fbb 0
97 :3 0 1fbc 1fbd
0 2003 64 :3 0
65 :3 0 1fbf 1fc0
0 64 :3 0 75
:3 0 1fc2 1fc3 0
9a :2 0 2 :4 0
1de :2 0 77 :2 0
23 :2 0 12f5 1fc8
1fca :3 0 12f8 1fc4
1fcc 1fc1 1fce 1fcd
:2 0 67 :3 0 78
:3 0 1fd0 1fd1 0
69 :4 0 1df :4 0
6c :2 0 6d :3 0
12fc 1fd5 1fd7 :3 0
12ff 1fd2 1fd9 :2 0
1ff3 67 :3 0 78
:3 0 1fdb 1fdc 0
69 :4 0 9d :4 0
6c :2 0 97 :3 0
1302 1fe0 1fe2 :3 0
6c :2 0 9e :4 0
1305 1fe4 1fe6 :3 0
6c :2 0 9f :3 0
a0 :3 0 23 :2 0
a1 :2 0 1308 1fe9
1fed 130c 1fe8 1fef
:3 0 130f 1fdd 1ff1
:2 0 1ff3 1312 1ff4
1fcf 1ff3 0 1ff5
1315 0 2003 1da
:3 0 63 :3 0 1db
:3 0 15 :3 0 1d9
:3 0 1dc :3 0 94
:4 0 1e0 1 :a 0
1fff :2 0 2003 1ff7
1ffd :2 0 14 :3 0
63 :3 0 2001 :2 0
2003 1317 2006 :3 0
2006 0 2006 2005
2003 2004 :6 0 2008
1 :3 0 131c 200a
131e 2009 2008 :2 0
200b 1320 :2 0 200d
1323 200d 200c 1f6c
200b :6 0 200e :2 0
2 44 200d 2011
:3 0 2010 200e 2012
:8 0 
1366
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
77 1 7e 1
7c 1 85 1
83 1 8c 1
8a 1 93 1
91 1 9a 1
98 1 a1 1
9f 1 a8 1
a6 1 af 1
ad 1 b4 1
b9 1 c0 1
be 1 c5 1
cb 1 d1 1
d7 1 dd 1
e3 1 e9 1
ef 1 f5 1
fb 1 101 1
107 1 10d 1
113 1 119 1
11f 1 125 1
12b 1 131 1
137 1 13d 1
143 1 149 1
14f 1 155 1
15b 1 161 1
167 1 16d 1
173 1 179 1
17f 1 185 1
18d 1 18b 1
194 1 192 1
199 1 19f 1
1a7 1 1a5 1
1ac 1 1b2 1
1b8 1 1be 1
1c4 1 1ca 1
1d0 1 1d6 1
1db 1 1e8 1
1f4 2 1f7 1f9
2 1fc 1fe 2
200 202 2 204
206 2 208 20a
2 20c 20e 2
210 212 2 214
216 2 218 21a
2 21c 21e 2
220 222 2 224
226 2 228 22a
1 230 2 232
233 2 22c 235
2 237 239 1
23f 2 241 242
2 23b 244 2
246 248 1 24e
2 250 251 2
24a 253 2 255
257 1 25d 2
25f 260 2 259
262 2 264 266
1 26c 2 26e
26f 2 268 271
2 273 275 1
27b 2 27d 27e
2 277 280 2
282 284 1 28a
2 28c 28d 2
286 28f 2 291
293 1 299 2
29b 29c 2 295
29e 2 2a0 2a2
1 2a8 2 2aa
2ab 2 2a4 2ad
2 2af 2b1 1
2b7 2 2b9 2ba
2 2b3 2bc 2
2be 2c0 2 2c2
2c4 2 2c6 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2d6 2d8
2 2da 2dc 2
2de 2e0 4 1f0
1f6 1fb 2e2 1
2e4 1 2e6 2
2f0 2f2 3 2ee
2ef 2f4 2 2fd
2ff 2 2fc 301
1 303 1 305
2 337 338 1
33a 1 344 2
351 353 3 34f
350 355 2 35e
360 2 362 364
2 366 368 1
370 2 372 373
2 36a 375 2
35d 377 1 379
1 37b 2 385
387 3 383 384
389 2 392 394
2 391 396 1
398 1 39a 2
3a1 3a2 3 37c
39b 3a4 1 3a6
2 3a9 3aa 1
3ae 2 3ac 3ae
2 3b2 3b3 1
3b7 2 3b5 3b7
2 3bd 3be 1
3c2 2 3c0 3c2
2 3cf 3d1 3
3cd 3ce 3d3 2
3dc 3de 2 3e0
3e2 2 3e4 3e6
1 3ee 2 3f0
3f1 2 3e8 3f3
2 3db 3f5 1
3f7 1 3f9 2
403 405 3 401
402 407 2 410
412 2 40f 414
1 416 1 418
2 41f 420 3
3fa 419 422 1
424 2 427 428
1 42e 2 42a
42e 1 432 1
43a 2 44a 44f
1 456 1 451
2 469 46b 3
467 468 46d 2
476 478 2 47a
47c 2 47e 480
2 482 484 2
486 488 3 48d
48e 48f 2 48a
491 2 475 493
1 495 1 497
2 460 498 1
49c 1 45b 2
459 4a0 1 4ab
2 4a7 4ab 2
4b0 4b1 1 4b5
2 4b3 4b5 2
4c3 4c5 3 4c1
4c2 4c7 2 4d0
4d2 2 4d4 4d6
2 4d8 4da 1
4e2 2 4e4 4e5
2 4dc 4e7 2
4cf 4e9 1 4eb
1 4ed 2 4f7
4f9 3 4f5 4f6
4fb 2 504 506
2 503 508 1
50a 1 50c 2
513 514 3 4ee
50d 516 1 518
3 4a3 519 51c
1 51f 1 525
2 530 535 1
53c 1 537 2
54f 551 3 54d
54e 553 2 55c
55e 2 560 562
2 564 566 2
568 56a 2 56c
56e 3 573 574
575 2 570 577
2 55b 579 1
57b 1 57d 2
546 57e 1 582
1 541 2 53f
586 1 589 2
58d 58c 2 595
596 2 598 59b
2 59e 59f 2
5a6 5a7 2 5a9
5ac 2 5b2 5b3
1 5b9 2 5b5
5b9 1 5be 1
5c0 2 5c3 5c4
1 5c8 2 5c6
5c8 2 5d6 5db
1 5e2 1 5dd
2 5f5 5f7 3
5f3 5f4 5f9 2
602 604 2 606
608 2 60a 60c
2 60e 610 2
612 614 3 619
61a 61b 2 616
61d 2 601 61f
1 621 1 623
2 5ec 624 1
628 1 5e7 2
5e5 62c 1 637
2 633 637 2
641 646 1 64d
1 648 2 660
662 3 65e 65f
664 2 66d 66f
2 671 673 2
675 677 2 679
67b 2 67d 67f
3 684 685 686
2 681 688 2
66c 68a 1 68c
1 68e 2 657
68f 1 693 1
652 2 650 697
1 6a2 2 69e
6a2 2 6ae 6b0
3 6ac 6ad 6b2
2 6bb 6bd 2
6bf 6c1 2 6c3
6c5 1 6cd 2
6cf 6d0 2 6c7
6d2 2 6d4 6d6
2 6d8 6da 2
6dc 6de 2 6e0
6e2 2 6ba 6e4
1 6e6 1 6e8
2 6f2 6f4 3
6f0 6f1 6f6 2
6ff 701 2 6fe
703 1 705 1
707 3 70e 70f
710 3 6e9 708
712 1 714 2
69a 715 1 717
2 721 726 1
72d 1 728 2
740 742 3 73e
73f 744 2 74d
74f 2 751 753
2 755 757 2
759 75b 2 75d
75f 3 764 765
766 2 761 768
2 74c 76a 1
76c 1 76e 2
737 76f 1 773
1 732 2 730
777 2 77d 77e
1 782 2 780
782 2 78a 78f
1 796 1 791
2 7a9 7ab 3
7a7 7a8 7ad 2
7b6 7b8 2 7ba
7bc 2 7be 7c0
2 7c2 7c4 2
7c6 7c8 3 7cd
7ce 7cf 2 7ca
7d1 2 7b5 7d3
1 7d5 1 7d7
2 7a0 7d8 1
7dc 1 79b 2
799 7e0 2 7e8
7e9 1 7ed 2
7eb 7ed 2 7f8
7fa 3 7f6 7f7
7fc 2 805 807
2 809 80b 2
80d 80f 1 817
2 819 81a 2
811 81c 2 81e
820 2 822 824
2 826 828 2
82a 82c 2 804
82e 1 830 1
832 2 83c 83e
3 83a 83b 840
2 849 84b 2
848 84d 1 84f
1 851 3 858
859 85a 3 833
852 85c 1 85e
2 7e3 85f 1
861 5 62f 718
71b 77a 862 1
864 2 871 873
3 86f 870 875
2 87e 880 2
882 884 2 886
888 1 890 2
892 893 2 88a
895 2 87d 897
1 899 1 89b
2 8a5 8a7 3
8a3 8a4 8a9 2
8b2 8b4 2 8b1
8b6 1 8b8 1
8ba 2 8c1 8c2
3 89c 8bb 8c4
1 8c6 3 8ce
8cf 8d0 3 8d2
8d3 8d4 4 8dc
8dd 8de 8df 2
8e5 8e6 1 8e8
1 8ec 2 8ea
8ec 2 907 90c
1 913 1 90e
2 926 928 3
924 925 92a 2
933 935 2 937
939 2 93b 93d
2 93f 941 2
943 945 3 94a
94b 94c 2 947
94e 2 932 950
1 952 1 954
2 91d 955 1
959 1 918 2
916 95d 1 968
2 964 968 2
974 976 3 972
973 978 2 981
983 2 985 987
2 989 98b 1
993 2 995 996
2 98d 998 2
99a 99c 2 99e
9a0 2 9a2 9a4
2 9a6 9a8 2
980 9aa 1 9ac
1 9ae 2 9b8
9ba 3 9b6 9b7
9bc 2 9c5 9c7
2 9c4 9c9 1
9cb 1 9cd 3
9d4 9d5 9d6 3
9af 9ce 9d8 1
9da 2 960 9db
2 9e5 9e7 3
9e3 9e4 9e9 2
9f2 9f4 2 9f6
9f8 2 9fa 9fc
1 a04 2 a06
a07 2 9fe a09
2 a0b a0d 2
a0f a11 2 a13
a15 2 a17 a19
2 9f1 a1b 1
a1d 1 a1f 2
a29 a2b 3 a27
a28 a2d 2 a36
a38 2 a35 a3a
1 a3c 1 a3e
3 a45 a46 a47
3 a20 a3f a49
2 a4b a4c 5
8c7 8ca 8d7 8e2
a4d 2 a4f a50
2 a53 a54 1
a58 2 a56 a58
2 a5d a5e 1
a62 2 a60 a62
1 a6a 1 a6c
1 a70 2 a6e
a70 2 a7e a7f
2 a83 a84 2
a88 a89 2 a8d
a8e 2 a92 a93
2 a97 a98 2
a9c a9d 2 aa1
aa2 d a7b a7c
a81 a86 a8b a90
a95 a9a a9f aa4
aa5 aa6 aa7 2
aac aad 1 ab3
2 aaf ab3 2
abe ac0 3 abc
abd ac2 2 acb
acd 2 acf ad1
2 ad3 ad5 1
add 2 adf ae0
2 ad7 ae2 2
aca ae4 1 ae6
1 ae8 2 af2
af4 3 af0 af1
af6 2 aff b01
2 afe b03 1
b05 1 b07 2
b0e b0f 3 ae9
b08 b11 2 b15
b16 1 b1a 2
b18 b1a 2 b25
b27 3 b23 b24
b29 2 b32 b34
2 b36 b38 2
b3a b3c 1 b42
2 b44 b45 2
b3e b47 2 b49
b4b 2 b4d b4f
2 b51 b53 2
b55 b57 2 b31
b59 1 b5b 1
b5d 2 b67 b69
3 b65 b66 b6b
2 b74 b76 2
b73 b78 1 b7a
1 b7c 2 b82
b83 3 b85 b86
b87 3 b5e b7d
b89 2 b8c b8b
4 a75 a78 aaa
b8d 2 b93 b94
1 b98 2 b96
b98 2 b9d b9e
2 ba3 ba4 2
ba0 ba6 1 ba9
1 bab 2 b91
bac 2 bae baf
2 bb2 bb3 1
bb7 2 bb5 bb7
2 bbc bbd 1
bc1 2 bbf bc1
2 bc8 bc9 1
bcd 2 bcb bcd
2 bd2 bd3 1
bd7 2 bd5 bd7
1 bdf 2 be3
be4 1 be8 2
be6 be8 1 bed
2 bf2 bf3 1
bf7 2 bf5 bf7
2 bfc bfd 1
c01 2 bff c01
1 c09 2 c0e
c0f 1 c13 2
c11 c13 1 c18
4 c1b bf0 c0c
c1a 1 c1c 1
c1e 3 c33 c34
c35 3 c3b c3c
c3d 2 c42 c43
1 c47 2 c45
c47 3 c51 c52
c53 1 c57 2
c55 c57 2 c73
c78 1 c7f 1
c7a 2 c92 c94
3 c90 c91 c96
2 c9f ca1 2
ca3 ca5 2 ca7
ca9 2 cab cad
2 caf cb1 3
cb6 cb7 cb8 2
cb3 cba 2 c9e
cbc 1 cbe 1
cc0 2 c89 cc1
1 cc5 1 c84
2 c82 cc9 2
cd3 cd8 1 cdf
1 cda 2 cf2
cf4 3 cf0 cf1
cf6 2 cff d01
2 d03 d05 2
d07 d09 2 d0b
d0d 2 d0f d11
3 d16 d17 d18
2 d13 d1a 2
cfe d1c 1 d1e
1 d20 2 ce9
d21 1 d25 1
ce4 2 ce2 d29
1 d34 2 d30
d34 2 d40 d42
3 d3e d3f d44
2 d4d d4f 2
d51 d53 2 d55
d57 1 d5f 2
d61 d62 2 d59
d64 2 d66 d68
2 d6a d6c 2
d6e d70 2 d72
d74 2 d4c d76
1 d78 1 d7a
2 d84 d86 3
d82 d83 d88 2
d91 d93 2 d90
d95 1 d97 1
d99 3 da0 da1
da2 3 d7b d9a
da4 1 da6 2
db5 dba 1 dc1
1 dbc 2 dd4
dd6 3 dd2 dd3
dd8 2 de1 de3
2 de5 de7 2
de9 deb 2 ded
def 2 df1 df3
3 df8 df9 dfa
2 df5 dfc 2
de0 dfe 1 e00
1 e02 2 dcb
e03 1 e07 1
dc6 2 dc4 e0b
5 ccc d2c da7
daa e0e 3 e13
e14 e15 1 e19
2 e17 e19 2
e21 e26 1 e2d
1 e28 2 e40
e42 3 e3e e3f
e44 2 e4d e4f
2 e51 e53 2
e55 e57 2 e59
e5b 2 e5d e5f
3 e64 e65 e66
2 e61 e68 2
e4c e6a 1 e6c
1 e6e 2 e37
e6f 1 e73 1
e32 2 e30 e77
1 e82 2 e7e
e82 2 e8e e90
3 e8c e8d e92
2 e9b e9d 2
e9f ea1 2 ea3
ea5 1 ead 2
eaf eb0 2 ea7
eb2 2 eb4 eb6
2 eb8 eba 2
ebc ebe 2 ec0
ec2 2 e9a ec4
1 ec6 1 ec8
2 ed2 ed4 3
ed0 ed1 ed6 2
edf ee1 2 ede
ee3 1 ee5 1
ee7 3 eee eef
ef0 3 ec9 ee8
ef2 1 ef4 2
f12 f17 1 f1e
1 f19 2 f31
f33 3 f2f f30
f35 2 f3e f40
2 f42 f44 2
f46 f48 2 f4a
f4c 2 f4e f50
3 f55 f56 f57
2 f52 f59 2
f3d f5b 1 f5d
1 f5f 2 f28
f60 1 f64 1
f23 2 f21 f68
1 f73 2 f6f
f73 2 f93 f98
1 f9f 1 f9a
2 fb2 fb4 3
fb0 fb1 fb6 2
fbf fc1 2 fc3
fc5 2 fc7 fc9
2 fcb fcd 2
fcf fd1 3 fd6
fd7 fd8 2 fd3
fda 2 fbe fdc
1 fde 1 fe0
2 fa9 fe1 1
fe5 1 fa4 2
fa2 fe9 1 ff4
2 ff0 ff4 1
ffa 2 1000 1001
1 1003 1 1007
2 1005 1007 2
1017 101c 1 1023
1 101e 2 1036
1038 3 1034 1035
103a 2 1043 1045
2 1047 1049 2
104b 104d 2 104f
1051 2 1053 1055
3 105a 105b 105c
2 1057 105e 2
1042 1060 1 1062
1 1064 2 102d
1065 1 1069 1
1028 2 1026 106d
2 1073 1074 1
1078 2 1076 1078
2 1083 1085 3
1081 1082 1087 2
1090 1092 2 1094
1096 2 1098 109a
1 10a2 2 10a4
10a5 2 109c 10a7
2 10a9 10ab 2
10ad 10af 2 10b1
10b3 2 10b5 10b7
2 108f 10b9 1
10bb 1 10bd 2
10c7 10c9 3 10c5
10c6 10cb 2 10d4
10d6 2 10d3 10d8
1 10da 1 10dc
3 10e3 10e4 10e5
3 10be 10dd 10e7
1 10e9 3 100c
1070 10ea 1 10ec
2 ffd 10ed 1
10ef 3 f79 fec
10f0 1 10f2 2
10fe 1103 1 110a
1 1105 2 111d
111f 3 111b 111c
1121 2 112a 112c
2 112e 1130 2
1132 1134 2 1136
1138 2 113a 113c
3 1141 1142 1143
2 113e 1145 2
1129 1147 1 1149
1 114b 2 1114
114c 1 1150 1
110f 2 110d 1154
6 e7a ef5 ef8
f6b 10f3 1157 2
1163 1165 3 1161
1162 1167 2 1170
1172 2 1174 1176
2 1178 117a 1
1182 2 1184 1185
2 117c 1187 2
116f 1189 1 118b
1 118d 2 1197
1199 3 1195 1196
119b 2 11a4 11a6
2 11a3 11a8 1
11aa 1 11ac 2
11b3 11b4 3 118e
11ad 11b6 3 11b8
115a 11b9 1 11c1
2 11bd 11c1 2
11c9 11ca 4 11c7
11cc 11cf 11d0 2
11d8 11d9 4 11d6
11db 11de 11df 1
120b 2 120a 120b
1 1213 1 1219
2 121b 121c 2
1208 121d 1 1224
1 121f 2 1237
1239 3 1235 1236
123b 2 1244 1246
2 1248 124a 2
124c 124e 2 1250
1252 2 1254 1256
3 125b 125c 125d
2 1258 125f 2
1243 1261 1 1263
1 1265 2 122e
1266 1 126a 1
1229 2 1227 126e
1 1275 4 11d3
11e2 1271 1278 2
1283 1284 4 1281
1286 1289 128a 7
1298 1299 129a 129b
129c 129d 129e 1
12bd 2 12bc 12bd
1 12c5 1 12cb
2 12cd 12ce 2
12ba 12cf 1 12d6
1 12d1 2 12e9
12eb 3 12e7 12e8
12ed 2 12f6 12f8
2 12fa 12fc 2
12fe 1300 2 1302
1304 2 1306 1308
3 130d 130e 130f
2 130a 1311 2
12f5 1313 1 1315
1 1317 2 12e0
1318 1 131c 1
12db 2 12d9 1320
6 127e 128d 1292
1295 12a1 1323 2
1326 1327 2 132a
132b 1 132f 2
132d 132f 1 1333
1 133c 2 133a
133c 2 1343 1344
1 1348 2 1346
1348 2 134c 134d
1 1351 2 134f
1351 2 1356 1357
1 135a 2 1360
1361 2 1366 1367
2 1363 1369 1
136c 2 136e 1370
2 1372 1374 1
1376 1 1379 2
137b 137c 2 13a2
13a7 1 13ae 1
13a9 2 13c1 13c3
3 13bf 13c0 13c5
2 13ce 13d0 2
13d2 13d4 2 13d6
13d8 2 13da 13dc
2 13de 13e0 3
13e5 13e6 13e7 2
13e2 13e9 2 13cd
13eb 1 13ed 1
13ef 2 13b8 13f0
1 13f4 1 13b3
2 13b1 13f8 1
13fd 2 140b 1410
1 1417 1 1412
2 142a 142c 3
1428 1429 142e 2
1437 1439 2 143b
143d 2 143f 1441
2 1443 1445 2
1447 1449 3 144e
144f 1450 2 144b
1452 2 1436 1454
1 1456 1 1458
2 1421 1459 1
145d 1 141c 2
141a 1461 1 1464
2 1475 147a 1
1481 1 147c 2
1494 1496 3 1492
1493 1498 2 14a1
14a3 2 14a5 14a7
2 14a9 14ab 2
14ad 14af 2 14b1
14b3 3 14b8 14b9
14ba 2 14b5 14bc
2 14a0 14be 1
14c0 1 14c2 2
148b 14c3 1 14c7
1 1486 2 1484
14cb 1 14ce 2
14d1 14d2 1 14d6
2 14d4 14d6 3
14dc 14dd 14de 1
14e2 2 14e0 14e2
2 14ef 14f1 3
14ed 14ee 14f3 2
14fc 14fe 2 1500
1502 2 1504 1506
1 150e 2 1510
1511 2 1508 1513
2 1515 1517 2
1519 151b 2 151d
151f 2 1521 1523
2 14fb 1525 1
1527 1 1529 2
1533 1535 3 1531
1532 1537 2 1540
1542 2 153f 1544
1 1546 1 1548
3 154f 1550 1551
3 152a 1549 1553
1 1555 5 137d
1380 13fb 14d3 1556
1 155b 2 1559
155b 2 1570 1575
1 157c 1 1577
2 158f 1591 3
158d 158e 1593 2
159c 159e 2 15a0
15a2 2 15a4 15a6
2 15a8 15aa 2
15ac 15ae 3 15b3
15b4 15b5 2 15b0
15b7 2 159b 15b9
1 15bb 1 15bd
2 1586 15be 1
15c2 1 1581 2
157f 15c6 2 15db
15e0 1 15e7 1
15e2 2 15fa 15fc
3 15f8 15f9 15fe
2 1607 1609 2
160b 160d 2 160f
1611 2 1613 1615
2 1617 1619 3
161e 161f 1620 2
161b 1622 2 1606
1624 1 1626 1
1628 2 15f1 1629
1 162d 1 15ec
2 15ea 1631 2
1637 1638 2 163d
163e 2 1643 1644
2 1640 1646 1
1649 2 163a 1649
2 1654 1656 3
1652 1653 1658 2
1661 1663 2 1665
1667 2 1669 166b
1 1673 2 1675
1676 2 166d 1678
2 167a 167c 2
167e 1680 2 1682
1684 2 1686 1688
2 1660 168a 1
168c 1 168e 2
1698 169a 3 1696
1697 169c 2 16a5
16a7 2 16a4 16a9
1 16ab 1 16ad
3 16b4 16b5 16b6
3 168f 16ae 16b8
1 16ba 5 1560
15c9 15cd 1634 16bb
2 16be 16bd 2
16c5 16ca 1 16d1
1 16cc 2 16e4
16e6 3 16e2 16e3
16e8 2 16f1 16f3
2 16f5 16f7 2
16f9 16fb 2 16fd
16ff 2 1701 1703
3 1708 1709 170a
2 1705 170c 2
16f0 170e 1 1710
1 1712 2 16db
1713 1 1717 1
16d6 2 16d4 171b
3 1721 1722 1723
1 1727 2 1725
1727 1 172c a
1734 1735 1736 1737
1738 1739 173a 173b
173c 173d 2 172f
1740 1 1742 3
16bf 171e 1743 1
1745 3 1748 1749
174a 1 174e 2
174c 174e 1 1755
2 1759 175a 1
175d 2 175f 1760
21 1764 1765 1766
1767 1768 1769 176a
176b 176c 176d 176e
176f 1770 1771 1772
1773 1774 1775 1776
1777 1778 1779 177a
177b 177c 177d 177e
177f 1780 1781 1782
1783 1784 1 178a
2 1788 178a 1
1794 2 1793 1794
1 179c 1 17a2
2 17a4 17a5 2
1791 17a6 1 17ad
1 17a8 2 17c0
17c2 3 17be 17bf
17c4 2 17cd 17cf
2 17d1 17d3 2
17d5 17d7 2 17d9
17db 2 17dd 17df
3 17e4 17e5 17e6
2 17e1 17e8 2
17cc 17ea 1 17ec
1 17ee 2 17b7
17ef 1 17f3 1
17b2 2 17b0 17f7
1 17fa 1 17fd
8 c4c c4f 11ba
1328 1746 1761 1787
17fe 1 180b 2
180d 180e 1 1812
2 1810 1812 1
1817 1 181d 2
181f 1820 2 1822
1824 2 1827 1829
1 182b 1 182e
2 1830 1831 1
1835 2 1833 1835
2 183d 183e 1
1841 2 1840 1841
2 184e 184f 2
1851 1853 2 1855
1857 4 184b 184c
1859 185a 2 1865
1866 2 1868 186a
2 186c 186e 2
1870 1872 4 1862
1863 1874 1875 3
187a 187b 187c 1
1880 2 187e 1880
1 188a 2 188c
188d 1 1891 2
188f 1891 1 1896
2 189a 189c 3
189e 189f 18a0 2
18a6 18a8 3 18aa
18ab 18ac 2 18a3
18af 2 18b1 18b2
2 1887 18b3 2
18b7 18b8 1 18be
2 18c0 18c1 1
18c5 2 18c3 18c5
1 18ca 2 18ce
18d0 3 18d2 18d3
18d4 2 18da 18dc
3 18de 18df 18e0
2 18d7 18e3 2
18e5 18e6 2 18bb
18e7 2 18e9 18ea
3 18ed 18ee 18ef
1 18f3 2 18f1
18f3 1 18f8 1
18fa 2 190e 1913
1 191a 1 1915
2 192d 192f 3
192b 192c 1931 2
193a 193c 2 193e
1940 2 1942 1944
2 1946 1948 2
194a 194c 3 1951
1952 1953 2 194e
1955 2 1939 1957
1 1959 1 195b
2 1924 195c 1
1960 1 191f 2
191d 1964 1 196f
2 196b 196f 2
197f 1984 1 198b
1 1986 2 199e
19a0 3 199c 199d
19a2 2 19ab 19ad
2 19af 19b1 2
19b3 19b5 2 19b7
19b9 2 19bb 19bd
3 19c2 19c3 19c4
2 19bf 19c6 2
19aa 19c8 1 19ca
1 19cc 2 1995
19cd 1 19d1 1
1990 2 198e 19d5
1 19e0 2 19dc
19e0 1 19e6 1
19ea 2 19ec 19ed
2 19d8 19ee 1
19f0 2 19f3 19f4
1 19f8 2 19f6
19f8 2 19fc 19fd
1 1a01 2 19ff
1a01 2 1a05 1a06
1 1a0a 2 1a08
1a0a 2 1a0f 1a10
1 1a13 2 1a19
1a1a 2 1a1f 1a20
2 1a1c 1a22 1
1a25 2 1a27 1a29
2 1a2b 1a2d 1
1a2f 1 1a32 2
1a34 1a35 2 1a5b
1a60 1 1a67 1
1a62 2 1a7a 1a7c
3 1a78 1a79 1a7e
2 1a87 1a89 2
1a8b 1a8d 2 1a8f
1a91 2 1a93 1a95
2 1a97 1a99 3
1a9e 1a9f 1aa0 2
1a9b 1aa2 2 1a86
1aa4 1 1aa6 1
1aa8 2 1a71 1aa9
1 1aad 1 1a6c
2 1a6a 1ab1 1
1ab6 2 1ac9 1ace
1 1ad5 1 1ad0
2 1ae8 1aea 3
1ae6 1ae7 1aec 2
1af5 1af7 2 1af9
1afb 2 1afd 1aff
2 1b01 1b03 2
1b05 1b07 3 1b0c
1b0d 1b0e 2 1b09
1b10 2 1af4 1b12
1 1b14 1 1b16
2 1adf 1b17 1
1b1b 1 1ada 2
1ad8 1b1f 1 1b22
1 1b25 4 1a36
1a39 1ab4 1b26 3
1b2c 1b2d 1b2e 1
1b32 2 1b30 1b32
3 1b38 1b39 1b3a
1 1b3e 2 1b3c
1b3e 2 1b4c 1b51
1 1b58 1 1b53
2 1b6b 1b6d 3
1b69 1b6a 1b6f 2
1b78 1b7a 2 1b7c
1b7e 2 1b80 1b82
2 1b84 1b86 2
1b88 1b8a 3 1b8f
1b90 1b91 2 1b8c
1b93 2 1b77 1b95
1 1b97 1 1b99
2 1b62 1b9a 1
1b9e 1 1b5d 2
1b5b 1ba2 1 1ba5
2 1bab 1bae 3
1bb0 1ba8 1bb1 1
1bb2 2 1bb6 1bb9
2 1bbb 1bbc 2
1bbf 1bc0 1 1bc4
2 1bc2 1bc4 3
1bc8 1bc9 1bca 1
1bce 2 1bcc 1bce
1 1bd3 1 1bd5
1 1bd6 3 1bda
1bdb 1bdc 1 1be0
2 1bde 1be0 1
1be7 2 1bec 1bed
1 1bf0 3 1bf2
1be9 1bf3 21 1bf7
1bf8 1bf9 1bfa 1bfb
1bfc 1bfd 1bfe 1bff
1c00 1c01 1c02 1c03
1c04 1c05 1c06 1c07
1c08 1c09 1c0a 1c0b
1c0c 1c0d 1c0e 1c0f
1c10 1c11 1c12 1c13
1c14 1c15 1c16 1c17
1 1c1d 2 1c1b
1c1d 1 1c27 2
1c26 1c27 1 1c2f
1 1c35 2 1c37
1c38 2 1c24 1c39
1 1c40 1 1c3b
2 1c53 1c55 3
1c51 1c52 1c57 2
1c60 1c62 2 1c64
1c66 2 1c68 1c6a
2 1c6c 1c6e 2
1c70 1c72 3 1c77
1c78 1c79 2 1c74
1c7b 2 1c5f 1c7d
1 1c7f 1 1c81
2 1c4a 1c82 1
1c86 1 1c45 2
1c43 1c8a 1 1c8d
1 1c90 2 1c94
1c95 2 1c97 1c99
d 185d 1878 18eb
18fb 18fe 1901 1967
19f1 1bbd 1bf4 1c1a
1c91 1c9c 2 183a
1c9f 1 1ca1 5
1802 1805 1808 1832
1ca2 2 1ca4 1ca5
1 1ca9 2 1ca7
1ca9 2 1cae 1caf
1 1cb3 2 1cb1
1cb3 2 1cc1 1cc3
3 1cbf 1cc0 1cc5
2 1cce 1cd0 2
1cd2 1cd4 2 1cd6
1cd8 1 1ce0 2
1ce2 1ce3 2 1cda
1ce5 2 1ce7 1ce9
2 1ceb 1ced 2
1cef 1cf1 2 1cf3
1cf5 2 1ccd 1cf7
1 1cf9 1 1cfb
2 1d05 1d07 3
1d03 1d04 1d09 2
1d12 1d14 2 1d11
1d16 1 1d18 1
1d1a 3 1d21 1d22
1d23 3 1cfc 1d1b
1d25 1 1d27 2
1d2a 1d2b 1 1d2f
2 1d2d 1d2f 1
1d34 1 1d36 1
1d3a 2 1d3c 1d3d
1 1d41 2 1d3f
1d41 1 1d47 2
1d49 1d4a 1 1d4e
2 1d4c 1d4e 2
1d55 1d57 2 1d59
1d5b 2 1d5d 1d5f
2 1d61 1d63 2
1d69 1d6a 1 1d6c
2 1d65 1d6e 2
1d70 1d72 2 1d78
1d79 1 1d7b 2
1d74 1d7d 2 1d7f
1d81 2 1d87 1d88
1 1d8a 2 1d83
1d8c 2 1d8e 1d90
2 1d92 1d94 2
1d96 1d98 2 1d9a
1d9c 2 1d9e 1da0
2 1da2 1da4 2
1da6 1da8 2 1daa
1dac 2 1dae 1db0
2 1db2 1db4 2
1db6 1db8 2 1dba
1dbc 2 1dbe 1dc0
2 1dc2 1dc6 2
1dc8 1dca 2 1dcc
1dd0 2 1dd2 1dd4
2 1dd6 1dd8 2
1dda 1ddc 2 1de2
1de3 1 1de5 2
1dde 1de7 2 1de9
1deb 2 1df1 1df2
1 1df4 2 1ded
1df6 2 1df8 1dfa
2 1dfc 1dfe 2
1e04 1e05 1 1e07
2 1e00 1e09 2
1e0b 1e0d 2 1e0f
1e11 2 1e13 1e15
2 1e17 1e19 2
1e1b 1e1d 2 1e1f
1e21 2 1e23 1e25
2 1e27 1e29 1
1e2c 1 1e31 2
1e33 1e34 1 1e38
2 1e36 1e38 2
1e3c 1e3e 2 1e40
1e42 2 1e44 1e46
2 1e48 1e4a 2
1e50 1e51 1 1e53
2 1e4c 1e55 2
1e57 1e59 2 1e5f
1e60 1 1e62 2
1e5b 1e64 2 1e66
1e68 2 1e6e 1e6f
1 1e71 2 1e6a
1e73 2 1e75 1e77
2 1e79 1e7b 2
1e7d 1e7f 2 1e81
1e83 2 1e85 1e87
2 1e89 1e8b 2
1e8d 1e8f 2 1e91
1e93 2 1e95 1e97
2 1e99 1e9b 2
1e9d 1e9f 1 1ea2
1 1ea8 2 1eaa
1eab 1 1eaf 2
1ead 1eaf 2 1eb3
1eb5 2 1eb7 1ebb
2 1ebd 1ebf 2
1ec1 1ec5 2 1ec7
1ec9 2 1ecb 1ecd
2 1ecf 1ed1 2
1ed7 1ed8 1 1eda
2 1ed3 1edc 2
1ede 1ee0 2 1ee6
1ee7 1 1ee9 2
1ee2 1eeb 2 1eed
1eef 2 1ef1 1ef3
2 1ef9 1efa 1
1efc 2 1ef5 1efe
2 1f00 1f02 2
1f04 1f06 2 1f08
1f0a 2 1f0c 1f0e
2 1f10 1f12 2
1f14 1f16 2 1f18
1f1a 2 1f1c 1f1e
1 1f21 3 1f24
1ea5 1f23 2 1f2e
1f30 3 1f2c 1f2d
1f32 2 1f3b 1f3d
2 1f3a 1f3f 1
1f41 1 1f43 2
1f4d 1f4f 3 1f4b
1f4c 1f51 2 1f5a
1f5c 2 1f59 1f5e
1 1f60 1 1f62
1 1f68 2c 2e7
306 309 30c 30f
312 315 318 31b
31e 321 324 327
32a 32d 330 333
33d 340 343 3a7
425 58e 5a2 5b0
5c1 a51 a6d bb0
c1f c24 c27 c2a
c2d c30 c38 c40
1ca6 1d28 1d37 1f25
1f44 1f63 1f6b 2
1f78 1f7a 3 1f76
1f77 1f7c 2 1f85
1f87 2 1f84 1f89
2 1f90 1f94 2
1f96 1f98 2 1f9a
1f9e 2 1f8f 1fa0
2 1f8b 1fa2 1
1fa4 3 1fa5 1fb0
1fb4 1 1f6f 2
1fc7 1fc9 3 1fc5
1fc6 1fcb 2 1fd4
1fd6 2 1fd3 1fd8
2 1fdf 1fe1 2
1fe3 1fe5 3 1fea
1feb 1fec 2 1fe7
1fee 2 1fde 1ff0
2 1fda 1ff2 1
1ff4 4 1fbe 1ff5
1ffe 2002 1 2006
1 1fb9 2 1fb7
200a 42 4b 52
59 60 67 6e
75 7a 81 88
8f 96 9d a4
ab b2 b7 bc
c3 c9 cf d5
db e1 e7 ed
f3 f9 ff 105
10b 111 117 11d
123 129 12f 135
13b 141 147 14d
153 159 15f 165
16b 171 177 17d
183 189 190 197
19d 1a3 1aa 1b0
1b6 1bc 1c2 1c8
1ce 1d4 1d9 1e0

1
4
0 
2011
0
1
50
3f
52
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 33 32 35 32 37
32 39 32 3b 32 3d 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
143 1 0
2b 1 0
173 1 0
185 1 0
1ca 1 0
14f 1 0
2f 1 0
1b2 1 0
a6 1 0
107 1 0
e3 1 0
1be 1 0
8a 1 0
27 1 0
167 1 0
18b 1 0
98 1 0
1f 1 0
1b 1 0
1d0 1 0
83 1 0
c5 1 0
17f 1 0
16d 1 0
91 1 0
d7 1 0
1a5 1 0
77 1 0
1d6 1 0
19f 1 0
13 1 0
101 1 0
f5 1 0
69 1 0
7c 1 0
137 1 0
9f 1 0
62 1 0
f 1 0
ef 1 0
15b 1 0
3 1 0
cb 1 0
b9 1 0
70 1 0
199 1 0
13d 1 0
161 1 0
11f 1 0
113 1 0
23 1 0
2 0 1
125 1 0
4d 1 0
1b8 1 0
7 1 0
155 1 0
fb 1 0
e9 1 0
149 1 0
dd 1 0
1ac 1 0
d1 1 0
5b 1 0
46 1 0
119 1 0
37 1 0
ad 1 0
12b 1 0
17 1 0
179 1 0
b4 1 0
be 1 0
131 1 0
54 1 0
33 1 0
1c4 1 0
10d 1 0
b 1 0
1db 1 0
192 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_3;
ALTER FUNCTION SP_SEARCH_3 COMPILE DEBUG;
/*
#Stored Procedure  :SP_I_PROFILE
#Short Description :Assign a profile to a task or project
#Description       :used tables: RESOURCE_ASSIGNMENTS, PROFILES
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_I_PROFILE ==
CREATE OR REPLACE FUNCTION SP_I_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bb
2 :e:
1FUNCTION:
1SP_I_PROFILE:
1PRJ_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_COUNT:
1PLS_INTEGER:
10:
1H_NUMBER:
1H_TYPE_ID:
1NUMITEMS:
1NUMITEMS001:
1CURSOR:
1CEXISTS:
1PROFILE_ID:
1PROFILES:
1ROWNUM:
1PROJECT_ID:
1ROLE_ID:
1SELECT PROFILE_ID FROM PROFILES:n         WHERE  ROWNUM <= 1 AND  PROJECT_ID=+
1prj_id AND ROLE_ID=h_role_id:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_I_PROFILE(:
1':
1, :
1);:
1CHECK_TRACE:
11:
139:
1+:
1FPUT:
1               ENTER:: SP_I_PROFILE(40) :: cplan.sql(5833) :: :
1IS NULL:
18:
146:
1      RETURN_INVALID:: SP_I_PROFILE(47) :: cplan.sql(5840) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
149:
1                EXIT:: SP_I_PROFILE(50) :: cplan.sql(5843) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SUBSTR:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
1TNGROLE:
17:
1=:
1SELECT PROFILE_ID INTO h_uniqueID:n            FROM PROFILES:n            WHE+
1RE PROJECT_ID=prj_id AND ROLE_ID=h_role_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
176:
1           EXCEPTION:: SP_I_PROFILE(77) :: cplan.sql(5870) :: :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1OPEN:
1FOUND:
1100:
1SC_SQL_SUCCESS:
1CLOSE:
1101:
1           EXCEPTION:: SP_I_PROFILE(102) :: cplan.sql(5895) :: :
1106:
1        RETURN_ERROR:: SP_I_PROFILE(107) :: cplan.sql(5900) :: :
1 ID:: :
1109:
1                EXIT:: SP_I_PROFILE(110) :: cplan.sql(5903) :: :
1PMO_RETURN_ERROR_SP:
1123:
1           EXCEPTION:: SP_I_PROFILE(124) :: cplan.sql(5917) :: :
1MAX:
1PROF_NUMBER:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n      FROM PROFILES:n   +
1   WHERE PROJECT_ID=prj_id/**prj_id*/ AND ROLE_ID=h_role_id:
1143:
1           EXCEPTION:: SP_I_PROFILE(144) :: cplan.sql(5937) :: :
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1ELEMENT_ID:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')'):n      IN+
1TO h_full_name FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n      WHERE TC+
1.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1160:
1           EXCEPTION:: SP_I_PROFILE(161) :: cplan.sql(5954) :: :
1SC_SQL_NO_DATA:
1167:
1        RETURN_ERROR:: SP_I_PROFILE(168) :: cplan.sql(5961) :: :
1RECORD_NOT_FOUND:
1170:
1                EXIT:: SP_I_PROFILE(171) :: cplan.sql(5964) :: :
1TYPE_ID:
1TMT_WBS:
1SELECT TYPE_ID INTO h_type_id:n      FROM TMT_WBS:n      WHERE ELEMENT_ID=prj+
1_id:
1187:
1           EXCEPTION:: SP_I_PROFILE(188) :: cplan.sql(5981) :: :
1!=:
1ISPROJECTTYPE:
1NOT:
1195:
1        RETURN_ERROR:: SP_I_PROFILE(196) :: cplan.sql(5989) :: :
1198:
1                EXIT:: SP_I_PROFILE(199) :: cplan.sql(5992) :: :
1SYS_GUID:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME,+
1 POOL_ID, GEO_ID, ORG_ID):n      VALUES(h_uniqueID, prj_id, h_role_id, h_numb+
1er, h_full_name, pool_id001, geo_id001, org_id001):
1221:
1           EXCEPTION:: SP_I_PROFILE(222) :: cplan.sql(6015) :: :
1TRUNC:
1LENGTH:
1/:
1>:
1WHILE:
1<:
1LOOP:
1PMO_STPU:
1STRNPCPY:
1*:
1RESOURCE_ASSIGN_ROLES:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_uniqueID, ELEMENT_+
1ID, PROFICIENCY_LEVEL_ID, PREFERENCE_LEVEL_ID,:n               EXPERIENCE_ID,+
1 LAST_USED_DATETIME, TO_CHAR(h_count):n               FROM TMT_COMPETENCIES W+
1HERE ELEMENT_ID = h_role_id:
1254:
1           EXCEPTION:: SP_I_PROFILE(255) :: cplan.sql(6048) :: :
1RESOURCE_ASSIGN_SKILLS:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_uniqueID, h_ro+
1le_id, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID,:n                  PREFERENCE_LEV+
1EL_ID, LAST_USED_DATETIME, TO_CHAR(h_count):n                  FROM TMT_COMPE+
1TENCIES WHERE ELEMENT_ID = h_role_id:
1293:
1           EXCEPTION:: SP_I_PROFILE(294) :: cplan.sql(6087) :: :
14:
1305:
1       RETURN_STATUS:: SP_I_PROFILE(306) :: cplan.sql(6099) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1312:
1           EXCEPTION:: SP_I_PROFILE(313) :: cplan.sql(6106) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1324:
1           EXCEPTION:: SP_I_PROFILE(325) :: cplan.sql(6118) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
8d6
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a0 f4 b4 bf
c8 :7 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e :2 5a a0 7e b4 2e :2 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :4 a0 :2 51 a5
b :2 51 a5 b d a0 7e b4
2e 5a :2 a0 d :2 a0 6b a0 6e
51 a5 b 7e 51 b4 2e :7 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 e9 dd b3 :2 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 19 3c b7 19 3c :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:1f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:3 a0 51 a5 b a5 b 5a 7e
51 b4 2e 7e b4 2e 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 b4 2e d :11 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
a5 b 51 a5 b 7e 51 b4
2e 5a 7e 51 b4 2e a5 b
d a0 7e 51 b4 2e a0 51
d :3 a0 51 a5 b a0 7e a0
b4 2e 82 :3 a0 6b :2 51 :2 a0 51
a5 b 7e 51 b4 2e 7e 51
b4 2e a0 a5 b d :c a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 51
a5 b 7e 51 b4 2e d b7
a0 47 b7 19 3c a0 7e b4
2e 5a :2 a0 d :5 a0 a5 b 51
a5 b 7e 51 b4 2e 5a 7e
51 b4 2e a5 b d a0 7e
51 b4 2e a0 51 d :3 a0 51
a5 b a0 7e a0 b4 2e 82
:3 a0 6b :2 51 :2 a0 51 a5 b 7e
51 b4 2e 7e 51 b4 2e a0
a5 b d :c a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b 7e
51 b4 2e d b7 a0 47 b7
19 3c b7 19 3c b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
8d6
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10c fa d9 fe
ff 107 f9 129 117 f6 11b 11c
124 116 145 134 138 113 140 133
161 150 154 130 15c 14f 17d 16c
170 14c 178 16b 199 188 18c 194
168 1b1 1a0 1a4 1ac 187 1b8 1bc
184 1cd 1d0 1d4 1d8 1dc 1e0 1e4
1e8 1ec 1f0 1fc 201 203 20f 213
231 219 21d 221 224 22c 218 238
23c 215 240 244 248 24b 250 251
1 253 258 25c 260 263 268 26c
270 273 278 279 27b 280 283 287
288 28d 292 295 29a 29b 2a0 2a3
2a7 2a8 2ad 2b0 2b5 2b6 2bb 2be
2c3 2c4 2c9 2cc 2d1 2d2 2d7 2da
2de 2df 2e4 2e7 2ec 2ed 2f2 2f5
2fa 2fb 300 303 308 309 30e 311
315 316 31b 31e 323 324 329 32c
331 332 337 33a 33f 340 345 348
34c 34d 352 355 35a 35b 360 363
368 369 36e 371 376 377 37c 37f
383 384 389 38c 391 392 397 39a
39f 3a0 3a5 3a8 3ad 3ae 3b3 3b6
3ba 3bb 3c0 3c3 3c8 3c9 3ce 3d1
3d6 3d7 3dc 3df 3e4 3e5 3ea 3ed
3f1 3f2 3f7 3fa 3ff 400 405 408
40d 40e 413 414 419 41b 41f 422
426 42a 42d 431 435 438 43b 440
443 446 449 44a 44f 450 1 452
457 45b 45f 462 467 46c 46f 473
474 479 47a 47f 481 485 488 48c
48f 490 495 498 49b 49f 4a2 4a3
4a8 4ab 1 4ae 4b3 4b7 4bb 4be
4c2 4c6 4c9 4cc 4d1 4d4 4d7 4da
4db 4e0 4e1 1 4e3 4e8 4ec 4f0
4f3 4f8 4fd 500 504 505 50a 50d
512 513 518 51b 520 521 526 529
52d 531 535 539 53c 53d 53f 544
545 547 548 54d 54e 553 555 559
55c 560 564 567 56b 56f 572 575
57a 57d 580 583 584 589 58a 1
58c 591 595 599 59c 5a1 5a6 5a9
5ad 5ae 5b3 5b4 5b9 5bb 5bf 5c2
5c6 5ca 5cd 5d1 5d5 5d8 5dc 5dd
5e2 5e4 5e8 5eb 5ef 5f3 5f7 5fb
5ff 603 607 60a 60d 60e 610 613
616 617 619 61d 621 624 625 62a
62d 631 635 639 63d 641 644 648
64d 650 651 653 656 659 65a 65f
663 667 66b 66f 673 677 67b 687
68b 68f 692 696 69a 69c 6a0 6a4
6a8 6ab 6af 6b3 6b5 6b6 6bb 1
6bf 6c3 6c7 6ca 6ce 6d2 6d6 6da
6dd 6e1 6e5 6e8 6eb 6f0 6f3 6f6
6f9 6fa 6ff 700 1 702 707 70b
70f 712 717 71c 71f 723 724 729
72c 731 732 737 73a 73f 740 745
748 74c 74d 752 755 75a 75b 760
763 767 76b 76e 771 772 774 775
77a 77b 780 782 786 789 78b 78f
791 79d 79f 7a1 7a2 7a7 7ab 7ad
7b9 7bb 7bf 7c3 7c8 7cc 7cd 7d1
7d5 7da 7df 7e3 7e7 7ec 7f0 7f4
7f7 7fa 7fe 800 804 808 80b 80e
812 814 818 81c 81f 823 827 82a
82e 831 835 838 839 83e 841 845
849 84e 850 854 858 85b 85f 863
865 869 86d 871 874 878 87c 87e
87f 884 1 888 88c 890 893 897
89b 89f 8a3 8a6 8aa 8ae 8b1 8b4
8b9 8bc 8bf 8c2 8c3 8c8 8c9 1
8cb 8d0 8d4 8d8 8db 8e0 8e5 8e8
8ec 8ed 8f2 8f5 8fa 8fb 900 903
908 909 90e 911 915 916 91b 91e
923 924 929 92c 930 934 937 93a
93b 93d 93e 943 944 949 94b 94f
952 954 958 95a 966 968 96a 96b
970 974 976 982 984 988 98c 98f
993 997 99a 99d 9a2 9a5 9a8 9ab
9ac 9b1 9b2 1 9b4 9b9 9bd 9c1
9c4 9c9 9ce 9d1 9d5 9d6 9db 9de
9e3 9e4 9e9 9ec 9f1 9f2 9f7 9fa
9fe a02 a06 a0a a0d a0e a10 a15
a16 a18 a19 a1e a21 a26 a27 a2c
a2f a34 a35 a3a a3d a41 a42 a47
a4a a4f a50 a55 a56 a5b a5d a61
a64 a68 a6c a6f a73 a77 a7a a7d
a82 a85 a88 a8b a8c a91 a92 1
a94 a99 a9d aa1 aa4 aa9 aae ab1
ab5 ab6 abb abc ac1 ac3 ac7 aca
ace ad2 ad5 ad9 add ae0 ae4 ae8
ae9 aee af0 af4 af8 afd aff b03
b07 b0a b0e b12 b14 b18 b1c b20
b23 b27 b2b b2d b2e b33 1 b37
b3b b3f b42 b46 b4a b4e b52 b55
b59 b5d b60 b63 b68 b6b b6e b71
b72 b77 b78 1 b7a b7f b83 b87
b8a b8f b94 b97 b9b b9c ba1 ba4
ba9 baa baf bb2 bb7 bb8 bbd bc0
bc4 bc5 bca bcd bd2 bd3 bd8 bdb
bdf be3 be6 be9 bea bec bed bf2
bf3 bf8 bfa bfe c01 c03 c07 c09
c15 c17 c19 c1a c1f c23 c25 c31
c33 c35 c39 c3d c40 c42 c46 c49
c4b c4f c52 c56 c5a c5e c62 c66
c6a c6e c72 c76 c82 c86 c8a c8d
c91 c95 c97 c9b c9f ca3 ca6 caa
cae cb0 cb1 cb6 1 cba cbe cc2
cc5 cc9 ccd cd1 cd5 cd8 cdc ce0
ce3 ce6 ceb cee cf1 cf4 cf5 cfa
cfb 1 cfd d02 d06 d0a d0d d12
d17 d1a d1e d1f d24 d27 d2c d2d
d32 d35 d3a d3b d40 d43 d47 d48
d4d d50 d55 d56 d5b d5e d62 d66
d69 d6c d6d d6f d70 d75 d76 d7b
d7d d81 d84 d86 d8a d8c d98 d9a
d9c d9d da2 da6 da8 db4 db6 dba
dbe dc2 dc6 dca dce dd2 dd6 dda
dde de2 de6 dea dee df2 df6 dfa
dfe e02 e06 e0a e0e e12 e16 e1a
e1e e22 e26 e2a e2e e32 e3e e42
e46 e49 e4d e51 e53 e57 e5b e5f
e62 e66 e6a e6c e6d e72 1 e76
e7a e7e e81 e85 e89 e8d e91 e94
e98 e9c e9f ea2 ea7 eaa ead eb0
eb1 eb6 eb7 1 eb9 ebe ec2 ec6
ec9 ece ed3 ed6 eda edb ee0 ee3
ee8 ee9 eee ef1 ef6 ef7 efc eff
f03 f04 f09 f0c f11 f12 f17 f1a
f1e f22 f25 f28 f29 f2b f2c f31
f32 f37 f39 f3d f40 f42 f46 f48
f54 f56 f58 f59 f5e f62 f64 f70
f72 f76 f7a f7d f81 f84 f88 f8b
f8c f91 f94 f98 f9c f9f fa3 fa7
faa fad fb2 fb5 fb8 fbb fbc fc1
fc2 1 fc4 fc9 fcd fd1 fd4 fd9
fde fe1 fe5 fe6 feb fee ff3 ff4
ff9 ffc 1001 1002 1007 100a 100e 1012
1016 101a 101d 101e 1020 1025 1026 1028
1029 102e 1031 1036 1037 103c 103f 1044
1045 104a 104d 1051 1052 1057 105a 105f
1060 1065 1066 106b 106d 1071 1074 1078
107c 107f 1083 1087 108a 108d 1092 1095
1098 109b 109c 10a1 10a2 1 10a4 10a9
10ad 10b1 10b4 10b9 10be 10c1 10c5 10c6
10cb 10cc 10d1 10d3 10d7 10da 10de 10e2
10e5 10e9 10ed 10f0 10f4 10f8 10f9 10fe
1100 1104 1107 110b 110f 1113 1117 111b
1127 112b 112f 1132 1136 113a 113c 1140
1144 1148 114b 114f 1153 1155 1156 115b
1 115f 1163 1167 116a 116e 1172 1176
117a 117d 1181 1185 1188 118b 1190 1193
1196 1199 119a 119f 11a0 1 11a2 11a7
11ab 11af 11b2 11b7 11bc 11bf 11c3 11c4
11c9 11cc 11d1 11d2 11d7 11da 11df 11e0
11e5 11e8 11ec 11ed 11f2 11f5 11fa 11fb
1200 1203 1207 120b 120e 1211 1212 1214
1215 121a 121b 1220 1222 1226 1229 122b
122f 1231 123d 123f 1241 1242 1247 124b
124d 1259 125b 125f 1263 1266 126a 126d
1271 1274 1275 127a 127d 1281 1285 1289
128c 128d 128f 1290 1292 1295 1298 129b
129c 12a1 12a4 12a5 1 12aa 12af 12b3
12b7 12ba 12be 12c2 12c5 12c8 12cd 12d0
12d3 12d6 12d7 12dc 12dd 1 12df 12e4
12e8 12ec 12ef 12f4 12f9 12fc 1300 1301
1306 1309 130e 130f 1314 1317 131c 131d
1322 1325 1329 132d 1331 1335 1338 1339
133b 1340 1341 1343 1344 1349 134c 1351
1352 1357 135a 135f 1360 1365 1368 136c
136d 1372 1375 137a 137b 1380 1381 1386
1388 138c 138f 1393 1397 139a 139e 13a2
13a5 13a8 13ad 13b0 13b3 13b6 13b7 13bc
13bd 1 13bf 13c4 13c8 13cc 13cf 13d4
13d9 13dc 13e0 13e1 13e6 13e7 13ec 13ee
13f2 13f5 13f9 13fd 1400 1404 1408 140b
140f 1413 1414 1419 141b 141f 1422 1426
142a 142b 1430 1434 1438 143c 1440 1444
1448 144c 1450 1454 1458 145c 1460 1464
1468 146c 1470 1474 1478 1484 1488 148d
1491 1494 1495 149a 149e 14a2 14a5 14a8
14ac 14ae 14b2 14b6 14b9 14bc 14c0 14c2
14c6 14ca 14cd 14cf 14d3 14d7 14db 14de
14e2 14e6 14e8 14e9 14ee 1 14f2 14f6
14fa 14fd 1501 1505 1509 150d 1510 1514
1518 151b 151e 1523 1526 1529 152c 152d
1532 1533 1 1535 153a 153e 1542 1545
154a 154f 1552 1556 1557 155c 155f 1564
1565 156a 156d 1572 1573 1578 157b 157f
1580 1585 1588 158d 158e 1593 1596 159a
159e 15a1 15a4 15a5 15a7 15a8 15ad 15ae
15b3 15b5 15b9 15bc 15be 15c2 15c4 15d0
15d2 15d4 15d5 15da 15de 15e0 15ec 15ee
15f2 15f6 15f9 15fd 1600 1604 1607 1608
160d 1610 1614 1618 161c 1620 1624 1625
1627 162a 162b 162d 1630 1633 1634 1639
163c 163f 1642 1643 1648 1649 164b 164f
1653 1656 1659 165a 165f 1663 1666 166a
166e 1672 1676 1679 167a 167c 1680 1683
1687 1688 168d 168f 1693 1697 169b 169e
16a1 16a4 16a8 16ac 16af 16b0 16b2 16b5
16b8 16b9 16be 16c1 16c4 16c5 16ca 16ce
16cf 16d1 16d5 16d9 16dd 16e1 16e5 16e9
16ed 16f1 16f5 16f9 16fd 1701 1705 1711
1715 171a 171e 1721 1722 1727 172b 172f
1732 1735 1739 173b 173f 1743 1746 1749
174d 174f 1753 1757 175a 175c 1760 1764
1768 176b 176f 1773 1775 1776 177b 1
177f 1783 1787 178a 178e 1792 1796 179a
179d 17a1 17a5 17a8 17ab 17b0 17b3 17b6
17b9 17ba 17bf 17c0 1 17c2 17c7 17cb
17cf 17d2 17d7 17dc 17df 17e3 17e4 17e9
17ec 17f1 17f2 17f7 17fa 17ff 1800 1805
1808 180c 180d 1812 1815 181a 181b 1820
1823 1827 182b 182e 1831 1832 1834 1835
183a 183b 1840 1842 1846 1849 184b 184f
1851 185d 185f 1861 1862 1867 186b 186d
1879 187b 187f 1883 1887 188a 188b 188d
1890 1893 1894 1899 189d 189f 18a3 18aa
18ac 18b0 18b3 18b7 18ba 18bb 18c0 18c3
18c7 18cb 18cf 18d3 18d7 18db 18df 18e3
18e4 18e6 18e9 18ea 18ec 18ef 18f2 18f3
18f8 18fb 18fe 1901 1902 1907 1908 190a
190e 1912 1915 1918 1919 191e 1922 1925
1929 192d 1931 1935 1938 1939 193b 193f
1942 1946 1947 194c 194e 1952 1956 195a
195d 1960 1963 1967 196b 196e 196f 1971
1974 1977 1978 197d 1980 1983 1984 1989
198d 198e 1990 1994 1998 199c 19a0 19a4
19a8 19ac 19b0 19b4 19b8 19bc 19c0 19c4
19d0 19d4 19d9 19dd 19e0 19e1 19e6 19ea
19ee 19f1 19f4 19f8 19fa 19fe 1a02 1a05
1a08 1a0c 1a0e 1a12 1a16 1a19 1a1b 1a1f
1a23 1a27 1a2a 1a2e 1a32 1a34 1a35 1a3a
1 1a3e 1a42 1a46 1a49 1a4d 1a51 1a55
1a59 1a5c 1a60 1a64 1a67 1a6a 1a6f 1a72
1a75 1a78 1a79 1a7e 1a7f 1 1a81 1a86
1a8a 1a8e 1a91 1a96 1a9b 1a9e 1aa2 1aa3
1aa8 1aab 1ab0 1ab1 1ab6 1ab9 1abe 1abf
1ac4 1ac7 1acb 1acc 1ad1 1ad4 1ad9 1ada
1adf 1ae2 1ae6 1aea 1aed 1af0 1af1 1af3
1af4 1af9 1afa 1aff 1b01 1b05 1b08 1b0a
1b0e 1b10 1b1c 1b1e 1b20 1b21 1b26 1b2a
1b2c 1b38 1b3a 1b3e 1b42 1b46 1b49 1b4a
1b4c 1b4f 1b52 1b53 1b58 1b5c 1b5e 1b62
1b69 1b6b 1b6f 1b72 1b74 1b78 1b7b 1b7d
1b81 1b84 1b88 1b8c 1b8f 1b93 1b97 1b9a
1b9d 1ba2 1ba5 1ba8 1bab 1bac 1bb1 1bb2
1 1bb4 1bb9 1bbd 1bc1 1bc4 1bc9 1bce
1bd1 1bd5 1bd6 1bdb 1bde 1be3 1be4 1be9
1bec 1bf1 1bf2 1bf7 1bfa 1bfe 1c02 1c06
1c0a 1c0d 1c0e 1c10 1c15 1c16 1c18 1c19
1c1e 1c21 1c26 1c27 1c2c 1c2f 1c34 1c35
1c3a 1c3d 1c41 1c42 1c47 1c4a 1c4f 1c50
1c55 1c56 1c5b 1c5d 1c61 1c64 1c68 1c6c
1c6f 1c73 1c77 1c7a 1c7e 1c82 1c83 1c88
1c8a 1c8e 1c92 1c95 1c99 1c9d 1ca0 1ca4
1ca8 1cab 1cae 1cb3 1cb6 1cb9 1cbc 1cbd
1cc2 1cc3 1 1cc5 1cca 1cce 1cd2 1cd5
1cda 1cdf 1ce2 1ce6 1ce7 1cec 1ced 1cf2
1cf6 1cfa 1cfd 1d02 1d07 1d0a 1d0e 1d12
1d15 1d16 1d1b 1d1e 1d23 1d24 1d29 1d2c
1d30 1d34 1d37 1d38 1d3d 1d3e 1d43 1d45
1d49 1d4c 1d50 1d54 1d58 1d5c 1d60 1d64
1d68 1d6c 1d70 1d7c 1d81 1d85 1d89 1d8d
1d91 1d93 1d94 1d99 1 1d9d 1da1 1da5
1da8 1dac 1db0 1db4 1db8 1dbb 1dbf 1dc3
1dc6 1dc9 1dce 1dd1 1dd4 1dd7 1dd8 1ddd
1dde 1 1de0 1de5 1de9 1ded 1df0 1df5
1dfa 1dfd 1e01 1e02 1e07 1e08 1e0d 1e11
1e15 1e18 1e1d 1e22 1e25 1e29 1e2a 1e2f
1e32 1e37 1e38 1e3d 1e40 1e44 1e48 1e4b
1e4e 1e4f 1e51 1e52 1e57 1e58 1e5d 1e5f
1e63 1e66 1e6a 1e6e 1e72 1e76 1e7a 1e7e
1e82 1e8e 1e93 1e97 1e9b 1e9f 1ea3 1ea5
1ea9 1eab 1eb7 1eb9 1ebb 1ebc 1ec1 1ec5
1ec7 1ed3 1ed7 1ed9 1eda 1ee3 
8d6
2
0 1 a 6 d :3 6 10 :3 6
11 :3 6 10 :3 6 10 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 e 17 16 :2 e :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :3 d :2 4 :3 10 4 7 e 0
:2 7 11 21 11 22 2d 38 40
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 17
1a :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 28 2b :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 29
2c :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 28 2b :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 28
2b :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 29 2c :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2a
2d :2 6b 32 35 :2 6b :2 7 4a :2 4
7 :2 11 23 :2 2d 39 3c 4c 4e
4f :2 4c :2 23 :3 7 :2 d 12 1e 5c
5f :2 1e :2 7 52 :2 4 :4 9 8 7
:4 1f 1e 1d :2 7 a :2 14 26 :2 30
3c 3f 4f 51 52 :2 4f :2 26 :3 a
:2 10 15 21 5f 62 :2 21 6f 72
:2 21 76 79 :2 21 83 86 8f 97
:2 a0 :2 8f b1 :2 86 :2 21 :2 a 55 :2 7
a :2 14 26 :2 30 3c 3f 4f 51
52 :2 4f :2 26 :3 a :2 10 15 21 5f
62 :2 21 :2 a 55 :3 7 :2 12 28 :2 31
41 :2 7 33 :3 4 13 :2 4 11 18
1f 2c 2f :2 18 34 37 :2 11 4
:4 8 :2 7 15 7 a :2 15 1d 29
34 :2 a 37 39 :2 37 14 24 12
13 1e 29 31 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5b 5c :2 59 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 3b a f :3 a 10 1d :2 a
d 15 :2 d :2 16 22 d 1b d
:2 16 22 d :4 a e :2 17 22 20
:2 2b :2 20 d 10 16 :3 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5c 5f 60 :2 5c
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :3 3b 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8a 8d 96 9e :2 a7
:2 96 b2 :2 8d :2 27 ba bd :2 27 c5
c8 :2 27 cd d0 :2 27 db de :2 27
:2 10 5d :2 d 10 :2 1a 2c :2 36 42
45 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 :2 10 5c :3 d
:2 18 2c :2 35 3f 4b :2 d 3b 10
16 :3 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5c 5f 60 :2 5c :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :7 a 3b
:2 7 20 :2 4 e 17 1b 32 c
d 18 2e 36 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 e 19 26 31 3e 49
56 61 6e 79 86 8c 90 a6
ac af c5 cb d3 c 1d 2e
32 43 d 10 1d 2b 2f 3c
3f :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
53 56 57 :2 53 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 89 8c :2 24 94 97 :2 24
a3 a6 ad b6 b9 :2 a6 :2 24 :2 d
5a :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 50 53 54 :2 50
:2 26 :3 a :2 10 15 21 60 63 :2 21
70 73 :2 21 77 7a :2 21 84 87
90 98 :2 a1 :2 90 b4 :2 87 :2 21 bc
bf :2 21 c7 ca :2 21 cf d2 :2 21
dc df :2 21 :2 a 57 :2 7 a :2 14
26 :2 30 3c 3f 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 60 63 :2 21
:2 a 56 :3 7 :2 12 26 :2 2f 41 4c
:2 7 35 :2 4 e 1b c d 18
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 53
56 57 :2 53 :2 29 :3 d :2 13 18 24
63 66 :2 24 73 76 :2 24 7a 7d
:2 24 89 8c :2 24 94 97 :2 24 a3
a6 ad b6 b9 :2 a6 :2 24 :2 d 5a
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1d 1a :2 26 :2 1a 7 3e 4c a
15 :2 4c :2 3e 3d 1a 1d :2 1a :3 39
:2 7 a :2 14 26 :2 30 3c 40 50
53 54 :2 50 :2 26 :3 a :2 10 15 21
60 63 :2 21 70 73 :2 21 77 7a
:2 21 84 87 90 98 :2 a1 :2 90 ac
:2 87 :2 21 b4 b7 :2 21 bf c2 :2 21
c7 ca :2 21 d1 d4 :2 21 :2 a 57
:2 7 a :2 14 26 :2 30 3c 3f 4f
52 53 :2 4f :2 26 :3 a :2 10 15 21
60 63 :2 21 :2 a 56 :3 7 :2 12 26
:2 2f 39 41 :2 7 1f :3 4 :3 12 4
13 1c 27 32 3a 47 55 5e
66 e 1a 22 2d 37 44 50
5b 7 e a 16 :3 14 a :2 13
1f a 1b a :2 13 1f a :4 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
:2 7 13 1a 23 2a :2 23 38 :2 1a
3b 3d :2 1a 19 40 42 :2 19 :2 13
7 a 13 15 :2 13 a 15 :2 a
10 19 22 :2 10 27 25 30 :2 25
a d 1a :2 23 2c 30 34 3d
46 :2 34 49 4b :2 34 4d 4e :2 34
51 :2 1a d 1c 17 23 2f 45
10 1f 33 3b 15 2c 39 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5c 5f 60 :2 5c :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 30
d 18 21 2a :2 18 2d 2f :2 18
d 30 e a 17 :2 7 :4 b :2 a
19 :2 a 19 20 29 30 :2 29 3e
:2 20 41 43 :2 20 1f 46 48 :2 1f
:2 19 a d 19 1b :2 19 d 18
:2 d 13 1c 25 :2 13 2a 28 36
:2 28 d 10 1d :2 26 2f 33 37
40 49 :2 37 4c 4e :2 37 50 51
:2 37 54 :2 1d 10 1f 1a 26 31
47 13 28 3c 44 18 2f 3c
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5f 62 63 :2 5f :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:3 36 10 1b 24 2d :2 1b 30 32
:2 1b 10 36 11 d 1d :2 a 23
:2 7 35 :2 4 7 :2 11 23 :2 2d 39
3c 4c 4f 50 :2 4c :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e 6d 70 :2 1e
74 77 :2 1e 81 84 8d 95 :2 9e
:2 8d a9 :2 84 :2 1e b1 b4 :2 1e bc
bf :2 1e c4 c7 :2 1e d2 d5 :2 1e
:2 7 53 :3 4 :2 f 21 :2 2a 34 40
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 60 63 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 57
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4d 50 51 :2 4d :2 23
:3 7 :2 d 12 1e 5d 60 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 54 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
8d6
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :5 13
:5 14 :2 16 0 :2 16
:2 17 :5 18 17 :5 16
:7 1a :b 1c :11 1d 1e
:2 1d :2 1e :2 1d :2 1e
:2 1d :2 1f :2 1d :2 1f
:2 1d :2 1f :2 1d :2 1f
:2 1d :2 20 :2 1d :2 20
:2 1d :2 20 :2 1d :2 20
:2 1d :2 21 :2 1d :2 21
:2 1d :2 21 :2 1d :2 21
:2 1d :2 22 :2 1d :2 22
:2 1d :2 22 :2 1d :2 22
:2 1d :2 23 :2 1d :2 23
:2 1d :2 23 :2 1d :2 23
:2 1d :2 24 :2 1d :2 24
:2 1d :2 24 :2 1d :2 24
:2 1d :2 24 :4 1d :3 1c
:11 27 :b 28 :3 27 :e 2d
:11 2e :20 2f :3 2e :11 31
:b 32 :3 31 :9 34 :3 2d
:3 38 :d 3b :5 3d :3 3e
:c 40 :2 42 43 :4 44
42 :5 45 41 47
:5 48 :3 47 :2 49 :5 4b
:11 4c :24 4d :3 4c :2 4a
:6 49 46 :3 40 :5 52
:4 54 :3 55 :5 56 55
:5 58 57 :3 55 :a 5b
:4 5d :5 5e 5c 60
:5 61 :3 60 :2 62 :5 64
:11 65 :24 66 :3 65 :2 63
:6 62 5f :3 5b :11 6a
:30 6b :3 6a :11 6d :b 6e
:3 6d :a 70 5b :4 73
:5 74 72 76 :5 77
:3 76 :2 78 :5 7a :11 7b
:24 7c :3 7b :2 79 :6 78
75 :4 71 :3 5b :3 40
:3 3d :4 85 86 :4 87
85 :5 88 84 8a
:5 8b :3 8a :2 8c :5 8e
:11 8f :24 90 :3 8f :2 8d
:6 8c 89 :3 1b :13 96
:5 97 :7 98 96 :5 99
95 9b :5 9c :3 9b
:2 9d :5 9f :11 a0 :24 a1
:3 a0 :2 9e :6 9d 9a
:3 1b :a a6 :11 a7 :30 a8
:3 a7 :11 aa :b ab :3 aa
:a ad :3 a6 :2 b1 b2
:2 b3 b1 :5 b4 b0
b6 :5 b7 :3 b6 :2 b8
:5 ba :11 bb :24 bc :3 bb
:2 b9 :6 b8 b5 :3 1b
:c c1 :2 c2 :5 c1 :4 c2
:5 c1 :11 c3 :30 c4 :3 c3
:11 c6 :b c7 :3 c6 :a c9
c2 :2 c1 :5 cd :9 d0
:8 d1 d0 :6 d2 :5 d3
d2 :5 d5 d4 :3 d2
cf d8 :5 d9 :3 d8
:2 da :5 dc :11 dd :24 de
:3 dd :2 db :6 da d7
:3 1b :a e3 :16 e5 :5 e6
:3 e7 :c e8 :17 ec ef
:4 f0 :4 f1 :3 f2 ef
:6 f3 :5 f4 f3 :5 f6
f5 :3 f3 ee f9
:5 fa :3 f9 :2 fb :5 fd
:11 fe :24 ff :3 fe :2 fc
:6 fb f8 :3 e8 :b 103
e8 104 e8 :3 e6
:5 108 :3 10a :16 10b :5 10d
:3 10e :c 10f :17 113 116
:4 117 :4 118 :3 119 116
:6 11a :5 11b 11a :5 11d
11c :3 11a 115 120
:5 121 :3 120 :2 122 :5 124
:11 125 :24 126 :3 125 :2 123
:6 122 11f :3 10f :b 12b
10f 12c 10f :3 10d
:3 108 :3 e3 :11 131 :30 132
:3 131 :a 134 1b :3 137
:11 138 :b 139 :17 13a :3 138
:2 13c :3 13d :3 13e 13f
13d 13c 13d :3 140
:3 137 :2 141 :5 143 :11 144
:b 145 :18 146 :3 144 :2 148
149 :3 14a 14b 149
148 149 :3 14c :2 142
:6 141 136 :7 1 
1ee5
4
:3 0 1 :3 0 2
:a 0 8d1 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
:2 0 f 4 :3 0
9 :7 0 19 18
:3 0 4 :3 0 a
:7 0 1d 1c :3 0
b :3 0 c :3 0
d :2 0 4 21
22 0 1f 23
0 8d1 2 24
:2 0 11 :2 0 1b
4 :3 0 f :2 0
19 27 29 :6 0
2c 2a 0 8cf
0 e :6 0 f
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 8cf
0 10 :6 0 14
:2 0 23 4 :3 0
21 35 37 :6 0
3a 38 0 8cf
0 12 :6 0 17
:2 0 27 4 :3 0
25 3c 3e :6 0
41 3f 0 8cf
0 13 :6 0 17
:2 0 29 16 :3 0
43 :7 0 47 44
45 8cf 0 15
:6 0 17 :2 0 2b
16 :3 0 49 :7 0
4d 4a 4b 8cf
0 18 :6 0 2f
184 0 2d 16
:3 0 4f :7 0 53
50 51 8cf 0
19 :9 0 31 16
:3 0 55 :7 0 58
56 0 8cf 0
1a :6 0 16 :3 0
5a :7 0 5d 5b
0 8cf 0 1b
:6 0 1c :3 0 1d
:a 0 2 6b :4 0
5f 62 0 60
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 3 :3 0 22
:3 0 12 :4 0 23
1 :8 0 6c 5f
62 6d 0 8cf
33 6d 6f 6c
6e :6 0 6b :7 0
6d 77 78 0
35 c :3 0 d
:2 0 4 71 72
0 73 :7 0 76
74 0 8cf 0
24 :6 0 25 :3 0
26 :3 0 25 :3 0
27 :3 0 7a 7b
0 2 :4 0 37
7c 7e 79 80
7f :2 0 28 :3 0
29 :3 0 82 83
0 2a :4 0 25
:3 0 2b :3 0 86
87 0 2 :4 0
39 88 8a 2c
:4 0 2d :2 0 2e
:3 0 3b 8d 8f
:3 0 2f :4 0 2d
:2 0 30 :4 0 3e
92 94 :3 0 2d
:2 0 3 :3 0 41
96 98 :3 0 2d
:2 0 30 :4 0 44
9a 9c :3 0 2d
:2 0 31 :4 0 47
9e a0 :3 0 2d
:2 0 30 :4 0 4a
a2 a4 :3 0 2d
:2 0 5 :3 0 4d
a6 a8 :3 0 2d
:2 0 30 :4 0 50
aa ac :3 0 2d
:2 0 31 :4 0 53
ae b0 :3 0 2d
:2 0 30 :4 0 56
b2 b4 :3 0 2d
:2 0 6 :3 0 59
b6 b8 :3 0 2d
:2 0 30 :4 0 5c
ba bc :3 0 2d
:2 0 31 :4 0 5f
be c0 :3 0 2d
:2 0 30 :4 0 62
c2 c4 :3 0 2d
:2 0 7 :3 0 65
c6 c8 :3 0 2d
:2 0 30 :4 0 68
ca cc :3 0 2d
:2 0 31 :4 0 6b
ce d0 :3 0 2d
:2 0 30 :4 0 6e
d2 d4 :3 0 2d
:2 0 8 :3 0 71
d6 d8 :3 0 2d
:2 0 30 :4 0 74
da dc :3 0 2d
:2 0 31 :4 0 77
de e0 :3 0 2d
:2 0 30 :4 0 7a
e2 e4 :3 0 2d
:2 0 9 :3 0 7d
e6 e8 :3 0 2d
:2 0 30 :4 0 80
ea ec :3 0 2d
:2 0 31 :4 0 83
ee f0 :3 0 2d
:2 0 30 :4 0 86
f2 f4 :3 0 2d
:2 0 a :3 0 89
f6 f8 :3 0 2d
:2 0 30 :4 0 8c
fa fc :3 0 2d
:2 0 32 :4 0 8f
fe 100 :3 0 92
84 102 :2 0 104
97 105 81 104
0 106 99 0
82f 25 :3 0 26
:3 0 107 108 0
25 :3 0 33 :3 0
10a 10b 0 34
:2 0 2 :4 0 35
:2 0 36 :2 0 34
:2 0 9b 110 112
:3 0 9e 10c 114
109 116 115 :2 0
28 :3 0 37 :3 0
118 119 0 2a
:4 0 38 :4 0 2d
:2 0 2e :3 0 a2
11d 11f :3 0 a5
11a 121 :2 0 123
a8 124 117 123
0 125 aa 0
82f 3 :3 0 39
:2 0 ac 127 128
:3 0 129 :2 0 12a
:2 0 5 :3 0 39
:2 0 ae 12d 12e
:3 0 12f :2 0 130
:2 0 12b 132 131
:2 0 25 :3 0 26
:3 0 134 135 0
25 :3 0 33 :3 0
137 138 0 3a
:2 0 2 :4 0 3b
:2 0 36 :2 0 34
:2 0 b0 13d 13f
:3 0 b3 139 141
136 143 142 :2 0
28 :3 0 37 :3 0
145 146 0 2a
:4 0 3c :4 0 2d
:2 0 2e :3 0 b7
14a 14c :3 0 2d
:2 0 3d :4 0 ba
14e 150 :3 0 2d
:2 0 3e :4 0 bd
152 154 :3 0 2d
:2 0 3f :3 0 40
:3 0 41 :3 0 42
:3 0 159 15a 0
c0 158 15c 43
:4 0 c2 157 15f
c5 156 161 :3 0
c8 147 163 :2 0
165 cb 166 144
165 0 167 cd
0 190 25 :3 0
26 :3 0 168 169
0 25 :3 0 33
:3 0 16b 16c 0
34 :2 0 2 :4 0
44 :2 0 36 :2 0
34 :2 0 cf 171
173 :3 0 d2 16d
175 16a 177 176
:2 0 28 :3 0 37
:3 0 179 17a 0
2a :4 0 45 :4 0
2d :2 0 2e :3 0
d6 17e 180 :3 0
d9 17b 182 :2 0
184 dc 185 178
184 0 186 de
0 190 46 :3 0
47 :3 0 187 188
0 41 :3 0 42
:3 0 18a 18b 0
48 :3 0 e0 189
18e :2 0 190 e3
191 133 190 0
192 e7 0 82f
10 :3 0 5 :3 0
193 194 0 82f
12 :3 0 49 :3 0
49 :3 0 10 :3 0
34 :2 0 f :2 0
e9 198 19c 34
:2 0 f :2 0 ed
197 1a0 196 1a1
0 82f 9 :3 0
4a :2 0 f1 1a4
1a5 :3 0 1a6 :2 0
e :3 0 9 :3 0
1a8 1a9 0 36f
4b :3 0 4c :3 0
1ab 1ac 0 e
:3 0 4d :4 0 4e
:2 0 f3 1ad 1b1
4f :2 0 17 :2 0
f9 1b3 1b5 :3 0
1e :3 0 e :3 0
1f :3 0 21 :3 0
3 :3 0 22 :3 0
12 :4 0 50 1
:8 0 1c4 c :3 0
51 :3 0 1bf 1c0
0 52 :3 0 1c1
1c2 0 1c4 fc
217 53 :3 0 c
:3 0 51 :3 0 1c6
1c7 0 52 :3 0
1c8 1c9 0 1cb
ff 1cd 101 1cc
1cb :2 0 215 54
:3 0 c :3 0 51
:3 0 1d0 1d1 0
52 :3 0 1d2 1d3
0 20d 25 :3 0
26 :3 0 1d5 1d6
0 25 :3 0 33
:3 0 1d8 1d9 0
55 :2 0 2 :4 0
56 :2 0 36 :2 0
34 :2 0 103 1de
1e0 :3 0 106 1da
1e2 1d7 1e4 1e3
:2 0 28 :3 0 37
:3 0 1e6 1e7 0
2a :4 0 57 :4 0
2d :2 0 2e :3 0
10a 1eb 1ed :3 0
2d :2 0 3d :4 0
10d 1ef 1f1 :3 0
2d :2 0 58 :4 0
110 1f3 1f5 :3 0
2d :2 0 52 :3 0
113 1f7 1f9 :3 0
2d :2 0 59 :4 0
116 1fb 1fd :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 119 200
204 11d 1ff 206
:3 0 120 1e8 208
:2 0 20a 123 20b
1e5 20a 0 20c
125 0 20d 127
210 :3 0 210 0
210 20f 20d 20e
:6 0 212 3 :3 0
12a 214 12c 213
212 :2 0 215 12e
:2 0 217 0 217
216 1c4 215 :6 0
36c 1 :3 0 5c
:3 0 1d :4 0 21c
:2 0 36c 21a 21d
:3 0 1d :3 0 e
:4 0 221 :2 0 36c
21e 21f :3 0 1d
:3 0 5d :3 0 222
223 :3 0 c :3 0
51 :3 0 225 226
0 17 :2 0 227
228 0 22a 131
231 c :3 0 51
:3 0 22b 22c 0
5e :2 0 22d 22e
0 230 133 232
224 22a 0 233
0 230 0 233
135 0 36c c
:3 0 51 :3 0 234
235 0 c :3 0
4f :2 0 5f :3 0
237 239 0 13a
238 23b :3 0 23c
:2 0 60 :3 0 1d
:4 0 241 :2 0 247
23f 0 c :3 0
51 :3 0 242 243
0 52 :3 0 244
245 0 247 13d
29a 53 :3 0 c
:3 0 51 :3 0 249
24a 0 52 :3 0
24b 24c 0 24e
140 250 142 24f
24e :2 0 298 54
:3 0 c :3 0 51
:3 0 253 254 0
52 :3 0 255 256
0 290 25 :3 0
26 :3 0 258 259
0 25 :3 0 33
:3 0 25b 25c 0
55 :2 0 2 :4 0
61 :2 0 36 :2 0
34 :2 0 144 261
263 :3 0 147 25d
265 25a 267 266
:2 0 28 :3 0 37
:3 0 269 26a 0
2a :4 0 62 :4 0
2d :2 0 2e :3 0
14b 26e 270 :3 0
2d :2 0 3d :4 0
14e 272 274 :3 0
2d :2 0 58 :4 0
151 276 278 :3 0
2d :2 0 52 :3 0
154 27a 27c :3 0
2d :2 0 59 :4 0
157 27e 280 :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 15a 283
287 15e 282 289
:3 0 161 26b 28b
:2 0 28d 164 28e
268 28d 0 28f
166 0 290 168
293 :3 0 293 0
293 292 290 291
:6 0 295 5 :3 0
16b 297 16d 296
295 :2 0 298 16f
:2 0 29a 0 29a
299 247 298 :6 0
309 1 :3 0 25
:3 0 26 :3 0 29c
29d 0 25 :3 0
33 :3 0 29f 2a0
0 f :2 0 2
:4 0 63 :2 0 36
:2 0 34 :2 0 172
2a5 2a7 :3 0 175
2a1 2a9 29e 2ab
2aa :2 0 28 :3 0
37 :3 0 2ad 2ae
0 2a :4 0 64
:4 0 2d :2 0 2e
:3 0 179 2b2 2b4
:3 0 2d :2 0 3d
:4 0 17c 2b6 2b8
:3 0 2d :2 0 3e
:4 0 17f 2ba 2bc
:3 0 2d :2 0 3f
:3 0 40 :3 0 c
:3 0 51 :3 0 2c1
2c2 0 182 2c0
2c4 43 :4 0 184
2bf 2c7 187 2be
2c9 :3 0 2d :2 0
65 :4 0 18a 2cb
2cd :3 0 2d :2 0
30 :4 0 18d 2cf
2d1 :3 0 2d :2 0
e :3 0 190 2d3
2d5 :3 0 2d :2 0
30 :4 0 193 2d7
2d9 :3 0 196 2af
2db :2 0 2dd 199
2de 2ac 2dd 0
2df 19b 0 309
25 :3 0 26 :3 0
2e0 2e1 0 25
:3 0 33 :3 0 2e3
2e4 0 34 :2 0
2 :4 0 66 :2 0
36 :2 0 34 :2 0
19d 2e9 2eb :3 0
1a0 2e5 2ed 2e2
2ef 2ee :2 0 28
:3 0 37 :3 0 2f1
2f2 0 2a :4 0
67 :4 0 2d :2 0
2e :3 0 1a4 2f6
2f8 :3 0 1a7 2f3
2fa :2 0 2fc 1aa
2fd 2f0 2fc 0
2fe 1ac 0 309
46 :3 0 68 :3 0
2ff 300 0 c
:3 0 51 :3 0 302
303 0 e :3 0
48 :3 0 1ae 301
307 :2 0 309 1b2
369 60 :3 0 1d
:4 0 30d :2 0 313
30b 0 c :3 0
51 :3 0 30e 30f
0 52 :3 0 310
311 0 313 1b7
366 53 :3 0 c
:3 0 51 :3 0 315
316 0 52 :3 0
317 318 0 31a
1ba 31c 1bc 31b
31a :2 0 364 54
:3 0 c :3 0 51
:3 0 31f 320 0
52 :3 0 321 322
0 35c 25 :3 0
26 :3 0 324 325
0 25 :3 0 33
:3 0 327 328 0
55 :2 0 2 :4 0
69 :2 0 36 :2 0
34 :2 0 1be 32d
32f :3 0 1c1 329
331 326 333 332
:2 0 28 :3 0 37
:3 0 335 336 0
2a :4 0 6a :4 0
2d :2 0 2e :3 0
1c5 33a 33c :3 0
2d :2 0 3d :4 0
1c8 33e 340 :3 0
2d :2 0 58 :4 0
1cb 342 344 :3 0
2d :2 0 52 :3 0
1ce 346 348 :3 0
2d :2 0 59 :4 0
1d1 34a 34c :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 1d4 34f
353 1d8 34e 355
:3 0 1db 337 357
:2 0 359 1de 35a
334 359 0 35b
1e0 0 35c 1e2
35f :3 0 35f 0
35f 35e 35c 35d
:6 0 361 7 :3 0
1e5 363 1e7 362
361 :2 0 364 1e9
:2 0 366 0 366
365 313 364 :6 0
368 1 :3 0 1ec
36a 23d 309 0
36b 0 368 0
36b 1ee 0 36c
1f1 36d 1b6 36c
0 36e 1f7 0
36f 1f9 370 1a7
36f 0 371 1fc
0 82f 3f :3 0
6b :3 0 6c :3 0
18 :3 0 1f :3 0
21 :3 0 3 :3 0
22 :3 0 12 :4 0
6d 1 :8 0 381
c :3 0 51 :3 0
37c 37d 0 52
:3 0 37e 37f 0
381 1fe 3d4 53
:3 0 c :3 0 51
:3 0 383 384 0
52 :3 0 385 386
0 388 201 38a
203 389 388 :2 0
3d2 54 :3 0 c
:3 0 51 :3 0 38d
38e 0 52 :3 0
38f 390 0 3ca
25 :3 0 26 :3 0
392 393 0 25
:3 0 33 :3 0 395
396 0 55 :2 0
2 :4 0 6e :2 0
36 :2 0 34 :2 0
205 39b 39d :3 0
208 397 39f 394
3a1 3a0 :2 0 28
:3 0 37 :3 0 3a3
3a4 0 2a :4 0
6f :4 0 2d :2 0
2e :3 0 20c 3a8
3aa :3 0 2d :2 0
3d :4 0 20f 3ac
3ae :3 0 2d :2 0
58 :4 0 212 3b0
3b2 :3 0 2d :2 0
52 :3 0 215 3b4
3b6 :3 0 2d :2 0
59 :4 0 218 3b8
3ba :3 0 2d :2 0
49 :3 0 5a :3 0
34 :2 0 5b :2 0
21b 3bd 3c1 21f
3bc 3c3 :3 0 222
3a5 3c5 :2 0 3c7
225 3c8 3a2 3c7
0 3c9 227 0
3ca 229 3cd :3 0
3cd 0 3cd 3cc
3ca 3cb :6 0 3cf
9 :3 0 22c 3d1
22e 3d0 3cf :2 0
3d2 230 :2 0 3d4
0 3d4 3d3 381
3d2 :6 0 82f 1
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 4b :3 0 70
:3 0 71 :3 0 72
:3 0 73 :3 0 71
:3 0 74 :3 0 73
:3 0 71 :3 0 40
:3 0 18 :3 0 13
:3 0 75 :3 0 74
:3 0 75 :3 0 72
:3 0 74 :3 0 76
:3 0 12 :3 0 72
:3 0 76 :3 0 74
:3 0 77 :4 0 78
1 :8 0 3fb c
:3 0 51 :3 0 3f6
3f7 0 52 :3 0
3f8 3f9 0 3fb
233 44e 53 :3 0
c :3 0 51 :3 0
3fd 3fe 0 52
:3 0 3ff 400 0
402 236 404 238
403 402 :2 0 44c
54 :3 0 c :3 0
51 :3 0 407 408
0 52 :3 0 409
40a 0 444 25
:3 0 26 :3 0 40c
40d 0 25 :3 0
33 :3 0 40f 410
0 55 :2 0 2
:4 0 79 :2 0 36
:2 0 34 :2 0 23a
415 417 :3 0 23d
411 419 40e 41b
41a :2 0 28 :3 0
37 :3 0 41d 41e
0 2a :4 0 7a
:4 0 2d :2 0 2e
:3 0 241 422 424
:3 0 2d :2 0 3d
:4 0 244 426 428
:3 0 2d :2 0 58
:4 0 247 42a 42c
:3 0 2d :2 0 52
:3 0 24a 42e 430
:3 0 2d :2 0 59
:4 0 24d 432 434
:3 0 2d :2 0 49
:3 0 5a :3 0 34
:2 0 5b :2 0 250
437 43b 254 436
43d :3 0 257 41f
43f :2 0 441 25a
442 41c 441 0
443 25c 0 444
25e 447 :3 0 447
0 447 446 444
445 :6 0 449 b
:3 0 261 44b 263
44a 449 :2 0 44c
265 :2 0 44e 0
44e 44d 3fb 44c
:6 0 82f 1 :3 0
c :3 0 51 :3 0
450 451 0 c
:3 0 4f :2 0 7b
:3 0 453 455 0
26a 454 457 :3 0
458 :2 0 25 :3 0
26 :3 0 45a 45b
0 25 :3 0 33
:3 0 45d 45e 0
f :2 0 2 :4 0
7c :2 0 36 :2 0
34 :2 0 26d 463
465 :3 0 270 45f
467 45c 469 468
:2 0 28 :3 0 37
:3 0 46b 46c 0
2a :4 0 7d :4 0
2d :2 0 2e :3 0
274 470 472 :3 0
2d :2 0 3d :4 0
277 474 476 :3 0
2d :2 0 3e :4 0
27a 478 47a :3 0
2d :2 0 3f :3 0
40 :3 0 41 :3 0
7e :3 0 47f 480
0 27d 47e 482
43 :4 0 27f 47d
485 282 47c 487
:3 0 2d :2 0 65
:4 0 285 489 48b
:3 0 2d :2 0 30
:4 0 288 48d 48f
:3 0 2d :2 0 12
:3 0 28b 491 493
:3 0 2d :2 0 30
:4 0 28e 495 497
:3 0 291 46d 499
:2 0 49b 294 49c
46a 49b 0 49d
296 0 4c7 25
:3 0 26 :3 0 49e
49f 0 25 :3 0
33 :3 0 4a1 4a2
0 34 :2 0 2
:4 0 7f :2 0 36
:2 0 34 :2 0 298
4a7 4a9 :3 0 29b
4a3 4ab 4a0 4ad
4ac :2 0 28 :3 0
37 :3 0 4af 4b0
0 2a :4 0 80
:4 0 2d :2 0 2e
:3 0 29f 4b4 4b6
:3 0 2a2 4b1 4b8
:2 0 4ba 2a5 4bb
4ae 4ba 0 4bc
2a7 0 4c7 46
:3 0 68 :3 0 4bd
4be 0 41 :3 0
7e :3 0 4c0 4c1
0 12 :3 0 48
:3 0 2a9 4bf 4c5
:2 0 4c7 2ad 4c8
459 4c7 0 4c9
2b1 0 82f 81
:3 0 19 :3 0 82
:3 0 76 :3 0 3
:4 0 83 1 :8 0
4d5 c :3 0 51
:3 0 4d0 4d1 0
52 :3 0 4d2 4d3
0 4d5 2b3 528
53 :3 0 c :3 0
51 :3 0 4d7 4d8
0 52 :3 0 4d9
4da 0 4dc 2b6
4de 2b8 4dd 4dc
:2 0 526 54 :3 0
c :3 0 51 :3 0
4e1 4e2 0 52
:3 0 4e3 4e4 0
51e 25 :3 0 26
:3 0 4e6 4e7 0
25 :3 0 33 :3 0
4e9 4ea 0 55
:2 0 2 :4 0 84
:2 0 36 :2 0 34
:2 0 2ba 4ef 4f1
:3 0 2bd 4eb 4f3
4e8 4f5 4f4 :2 0
28 :3 0 37 :3 0
4f7 4f8 0 2a
:4 0 85 :4 0 2d
:2 0 2e :3 0 2c1
4fc 4fe :3 0 2d
:2 0 3d :4 0 2c4
500 502 :3 0 2d
:2 0 58 :4 0 2c7
504 506 :3 0 2d
:2 0 52 :3 0 2ca
508 50a :3 0 2d
:2 0 59 :4 0 2cd
50c 50e :3 0 2d
:2 0 49 :3 0 5a
:3 0 34 :2 0 5b
:2 0 2d0 511 515
2d4 510 517 :3 0
2d7 4f9 519 :2 0
51b 2da 51c 4f6
51b 0 51d 2dc
0 51e 2de 521
:3 0 521 0 521
520 51e 51f :6 0
523 d :3 0 2e1
525 2e3 524 523
:2 0 526 2e5 :2 0
528 0 528 527
4d5 526 :6 0 82f
1 :3 0 c :3 0
51 :3 0 52a 52b
0 c :3 0 86
:2 0 5f :3 0 52d
52f 0 2ea 52e
531 :3 0 532 :2 0
87 :3 0 3f :3 0
19 :3 0 17 :2 0
2ed 535 538 2f0
534 53a 53b :2 0
86 :2 0 17 :2 0
2f4 53d 53f :3 0
88 :2 0 2f7 541
542 :3 0 533 544
543 :2 0 25 :3 0
26 :3 0 546 547
0 25 :3 0 33
:3 0 549 54a 0
f :2 0 2 :4 0
89 :2 0 36 :2 0
34 :2 0 2f9 54f
551 :3 0 2fc 54b
553 548 555 554
:2 0 28 :3 0 37
:3 0 557 558 0
2a :4 0 8a :4 0
2d :2 0 2e :3 0
300 55c 55e :3 0
2d :2 0 3d :4 0
303 560 562 :3 0
2d :2 0 3e :4 0
306 564 566 :3 0
2d :2 0 3f :3 0
40 :3 0 c :3 0
51 :3 0 56b 56c
0 309 56a 56e
43 :4 0 30b 569
571 30e 568 573
:3 0 2d :2 0 65
:4 0 311 575 577
:3 0 2d :2 0 30
:4 0 314 579 57b
:3 0 2d :2 0 3
:3 0 317 57d 57f
:3 0 2d :2 0 30
:4 0 31a 581 583
:3 0 31d 559 585
:2 0 587 320 588
556 587 0 589
322 0 5b3 25
:3 0 26 :3 0 58a
58b 0 25 :3 0
33 :3 0 58d 58e
0 34 :2 0 2
:4 0 8b :2 0 36
:2 0 34 :2 0 324
593 595 :3 0 327
58f 597 58c 599
598 :2 0 28 :3 0
37 :3 0 59b 59c
0 2a :4 0 8c
:4 0 2d :2 0 2e
:3 0 32b 5a0 5a2
:3 0 32e 59d 5a4
:2 0 5a6 331 5a7
59a 5a6 0 5a8
333 0 5b3 46
:3 0 68 :3 0 5a9
5aa 0 c :3 0
51 :3 0 5ac 5ad
0 3 :3 0 48
:3 0 335 5ab 5b1
:2 0 5b3 339 5b4
545 5b3 0 5b5
33d 0 82f e
:3 0 8d :4 0 5b7
5b8 :3 0 5b6 5b9
0 82f 1f :3 0
1e :3 0 21 :3 0
22 :3 0 6c :3 0
8e :3 0 8f :3 0
90 :3 0 91 :3 0
e :3 0 3 :3 0
12 :3 0 18 :3 0
13 :3 0 9 :3 0
8 :3 0 7 :4 0
92 1 :8 0 5e2
5d :4 0 5cd :3 0
48 :3 0 4f :2 0
341 5d0 5d1 :3 0
c :3 0 51 :3 0
5d3 5d4 0 17
:2 0 5d5 5d6 0
5d8 344 5df c
:3 0 51 :3 0 5d9
5da 0 5e :2 0
5db 5dc 0 5de
346 5e0 5d2 5d8
0 5e1 0 5de
0 5e1 348 0
5e2 34b 635 53
:3 0 c :3 0 51
:3 0 5e4 5e5 0
52 :3 0 5e6 5e7
0 5e9 34e 5eb
350 5ea 5e9 :2 0
633 54 :3 0 c
:3 0 51 :3 0 5ee
5ef 0 52 :3 0
5f0 5f1 0 62b
25 :3 0 26 :3 0
5f3 5f4 0 25
:3 0 33 :3 0 5f6
5f7 0 55 :2 0
2 :4 0 93 :2 0
36 :2 0 34 :2 0
352 5fc 5fe :3 0
355 5f8 600 5f5
602 601 :2 0 28
:3 0 37 :3 0 604
605 0 2a :4 0
94 :4 0 2d :2 0
2e :3 0 359 609
60b :3 0 2d :2 0
3d :4 0 35c 60d
60f :3 0 2d :2 0
58 :4 0 35f 611
613 :3 0 2d :2 0
52 :3 0 362 615
617 :3 0 2d :2 0
59 :4 0 365 619
61b :3 0 2d :2 0
49 :3 0 5a :3 0
34 :2 0 5b :2 0
368 61e 622 36c
61d 624 :3 0 36f
606 626 :2 0 628
372 629 603 628
0 62a 374 0
62b 376 62e :3 0
62e 0 62e 62d
62b 62c :6 0 630
f :3 0 379 632
37b 631 630 :2 0
633 37d :2 0 635
0 635 634 5e2
633 :6 0 82f 1
:3 0 c :3 0 51
:3 0 637 638 0
c :3 0 4f :2 0
5f :3 0 63a 63c
0 382 63b 63e
:3 0 63f :2 0 1a
:3 0 95 :3 0 3f
:3 0 96 :3 0 10
:3 0 385 644 646
17 :2 0 387 643
649 36 :2 0 34
:2 0 38a 64b 64d
:3 0 64e :2 0 97
:2 0 f :2 0 38d
650 652 :3 0 390
642 654 641 655
0 7de 1a :3 0
98 :2 0 34 :2 0
394 658 65a :3 0
15 :3 0 34 :2 0
65c 65d 0 707
99 :3 0 3f :3 0
15 :3 0 17 :2 0
397 660 663 1a
:3 0 9a :2 0 9b
:3 0 39c 666 668
:3 0 669 706 12
:3 0 9c :3 0 9d
:3 0 66c 66d 0
f :2 0 f :2 0
3f :3 0 15 :3 0
17 :2 0 39f 671
674 9e :2 0 f
:2 0 3a2 676 678
:3 0 36 :2 0 34
:2 0 3a5 67a 67c
:3 0 10 :3 0 3a8
66e 67f 66b 680
0 704 9f :3 0
e :3 0 76 :3 0
a0 :3 0 a1 :3 0
a2 :3 0 a3 :3 0
40 :3 0 15 :3 0
75 :3 0 76 :3 0
12 :4 0 a4 1
:8 0 6a4 5d :4 0
68f :3 0 48 :3 0
4f :2 0 3af 692
693 :3 0 c :3 0
51 :3 0 695 696
0 17 :2 0 697
698 0 69a 3b2
6a1 c :3 0 51
:3 0 69b 69c 0
5e :2 0 69d 69e
0 6a0 3b4 6a2
694 69a 0 6a3
0 6a0 0 6a3
3b6 0 6a4 3b9
6f7 53 :3 0 c
:3 0 51 :3 0 6a6
6a7 0 52 :3 0
6a8 6a9 0 6ab
3bc 6ad 3be 6ac
6ab :2 0 6f5 54
:3 0 c :3 0 51
:3 0 6b0 6b1 0
52 :3 0 6b2 6b3
0 6ed 25 :3 0
26 :3 0 6b5 6b6
0 25 :3 0 33
:3 0 6b8 6b9 0
55 :2 0 2 :4 0
a5 :2 0 36 :2 0
34 :2 0 3c0 6be
6c0 :3 0 3c3 6ba
6c2 6b7 6c4 6c3
:2 0 28 :3 0 37
:3 0 6c6 6c7 0
2a :4 0 a6 :4 0
2d :2 0 2e :3 0
3c7 6cb 6cd :3 0
2d :2 0 3d :4 0
3ca 6cf 6d1 :3 0
2d :2 0 58 :4 0
3cd 6d3 6d5 :3 0
2d :2 0 52 :3 0
3d0 6d7 6d9 :3 0
2d :2 0 59 :4 0
3d3 6db 6dd :3 0
2d :2 0 49 :3 0
5a :3 0 34 :2 0
5b :2 0 3d6 6e0
6e4 3da 6df 6e6
:3 0 3dd 6c8 6e8
:2 0 6ea 3e0 6eb
6c5 6ea 0 6ec
3e2 0 6ed 3e4
6f0 :3 0 6f0 0
6f0 6ef 6ed 6ee
:6 0 6f2 12 :3 0
3e7 6f4 3e9 6f3
6f2 :2 0 6f5 3eb
:2 0 6f7 0 6f7
6f6 6a4 6f5 :6 0
704 11 :3 0 15
:3 0 3f :3 0 15
:3 0 17 :2 0 3ee
6fa 6fd 36 :2 0
34 :2 0 3f1 6ff
701 :3 0 6f9 702
0 704 3f4 706
9b :3 0 66a 704
:4 0 707 3f8 708
65b 707 0 709
3fb 0 7de 6
:3 0 4a :2 0 3fd
70b 70c :3 0 70d
:2 0 10 :3 0 6
:3 0 70f 710 0
7db 1b :3 0 95
:3 0 3f :3 0 96
:3 0 10 :3 0 3ff
715 717 17 :2 0
401 714 71a 36
:2 0 34 :2 0 404
71c 71e :3 0 71f
:2 0 97 :2 0 f
:2 0 407 721 723
:3 0 40a 713 725
712 726 0 7db
1b :3 0 98 :2 0
17 :2 0 40e 729
72b :3 0 15 :3 0
17 :2 0 72d 72e
0 7d8 99 :3 0
3f :3 0 15 :3 0
17 :2 0 411 731
734 1b :3 0 9a
:2 0 9b :3 0 416
737 739 :3 0 73a
7d7 12 :3 0 9c
:3 0 9d :3 0 73d
73e 0 f :2 0
f :2 0 3f :3 0
15 :3 0 17 :2 0
419 742 745 9e
:2 0 f :2 0 41c
747 749 :3 0 36
:2 0 34 :2 0 41f
74b 74d :3 0 10
:3 0 422 73f 750
73c 751 0 7d5
a7 :3 0 e :3 0
12 :3 0 a0 :3 0
a2 :3 0 a1 :3 0
a3 :3 0 40 :3 0
15 :3 0 75 :3 0
76 :3 0 12 :4 0
a8 1 :8 0 775
5d :4 0 760 :3 0
48 :3 0 4f :2 0
429 763 764 :3 0
c :3 0 51 :3 0
766 767 0 17
:2 0 768 769 0
76b 42c 772 c
:3 0 51 :3 0 76c
76d 0 5e :2 0
76e 76f 0 771
42e 773 765 76b
0 774 0 771
0 774 430 0
775 433 7c8 53
:3 0 c :3 0 51
:3 0 777 778 0
52 :3 0 779 77a
0 77c 436 77e
438 77d 77c :2 0
7c6 54 :3 0 c
:3 0 51 :3 0 781
782 0 52 :3 0
783 784 0 7be
25 :3 0 26 :3 0
786 787 0 25
:3 0 33 :3 0 789
78a 0 55 :2 0
2 :4 0 a9 :2 0
36 :2 0 34 :2 0
43a 78f 791 :3 0
43d 78b 793 788
795 794 :2 0 28
:3 0 37 :3 0 797
798 0 2a :4 0
aa :4 0 2d :2 0
2e :3 0 441 79c
79e :3 0 2d :2 0
3d :4 0 444 7a0
7a2 :3 0 2d :2 0
58 :4 0 447 7a4
7a6 :3 0 2d :2 0
52 :3 0 44a 7a8
7aa :3 0 2d :2 0
59 :4 0 44d 7ac
7ae :3 0 2d :2 0
49 :3 0 5a :3 0
34 :2 0 5b :2 0
450 7b1 7b5 454
7b0 7b7 :3 0 457
799 7b9 :2 0 7bb
45a 7bc 796 7bb
0 7bd 45c 0
7be 45e 7c1 :3 0
7c1 0 7c1 7c0
7be 7bf :6 0 7c3
15 :3 0 461 7c5
463 7c4 7c3 :2 0
7c6 465 :2 0 7c8
0 7c8 7c7 775
7c6 :6 0 7d5 14
:3 0 15 :3 0 3f
:3 0 15 :3 0 17
:2 0 468 7cb 7ce
36 :2 0 34 :2 0
46b 7d0 7d2 :3 0
7ca 7d3 0 7d5
46e 7d7 9b :3 0
73b 7d5 :4 0 7d8
472 7d9 72c 7d8
0 7da 475 0
7db 477 7dc 70e
7db 0 7dd 47b
0 7de 47d 7df
640 7de 0 7e0
481 0 82f 25
:3 0 26 :3 0 7e1
7e2 0 25 :3 0
33 :3 0 7e4 7e5
0 ab :2 0 2
:4 0 ac :2 0 36
:2 0 34 :2 0 483
7ea 7ec :3 0 486
7e6 7ee 7e3 7f0
7ef :2 0 28 :3 0
37 :3 0 7f2 7f3
0 2a :4 0 ad
:4 0 2d :2 0 2e
:3 0 48a 7f7 7f9
:3 0 2d :2 0 3d
:4 0 48d 7fb 7fd
:3 0 2d :2 0 3e
:4 0 490 7ff 801
:3 0 2d :2 0 3f
:3 0 40 :3 0 c
:3 0 51 :3 0 806
807 0 493 805
809 43 :4 0 495
804 80c 498 803
80e :3 0 2d :2 0
65 :4 0 49b 810
812 :3 0 2d :2 0
30 :4 0 49e 814
816 :3 0 2d :2 0
e :3 0 4a1 818
81a :3 0 2d :2 0
30 :4 0 4a4 81c
81e :3 0 4a7 7f4
820 :2 0 822 4aa
823 7f1 822 0
824 4ac 0 82f
46 :3 0 ae :3 0
825 826 0 c
:3 0 51 :3 0 828
829 0 e :3 0
48 :3 0 4ae 827
82d :2 0 82f 4b2
8d0 c :3 0 af
:2 0 4 830 831
0 25 :3 0 26
:3 0 833 834 0
25 :3 0 33 :3 0
836 837 0 55
:2 0 2 :4 0 b0
:2 0 36 :2 0 34
:2 0 4c3 83c 83e
:3 0 4c6 838 840
835 842 841 :2 0
28 :3 0 37 :3 0
844 845 0 2a
:4 0 b1 :4 0 2d
:2 0 2e :3 0 4ca
849 84b :3 0 4cd
846 84d :2 0 866
28 :3 0 37 :3 0
84f 850 0 2a
:4 0 b2 :4 0 2d
:2 0 c :3 0 b3
:3 0 855 856 0
4d0 854 858 :3 0
2d :2 0 65 :4 0
4d3 85a 85c :3 0
2d :2 0 c :3 0
b4 :3 0 85f 860
0 4d6 85e 862
:3 0 4d9 851 864
:2 0 866 4dc 867
843 866 0 868
4df 0 878 5c
:3 0 24 :3 0 c
:3 0 b3 :3 0 b5
:3 0 c :3 0 b4
:3 0 b6 :3 0 b7
:4 0 b8 1 :a 0
874 :2 0 878 86a
872 :2 0 b :3 0
24 :3 0 876 :2 0
878 4e1 87a 4e5
879 878 :2 0 8ce
54 :3 0 c :3 0
51 :3 0 87d 87e
0 52 :3 0 87f
880 0 8c6 25
:3 0 26 :3 0 882
883 0 25 :3 0
33 :3 0 885 886
0 55 :2 0 2
:4 0 b9 :2 0 36
:2 0 34 :2 0 4e7
88b 88d :3 0 4ea
887 88f 884 891
890 :2 0 28 :3 0
37 :3 0 893 894
0 2a :4 0 ba
:4 0 2d :2 0 2e
:3 0 4ee 898 89a
:3 0 4f1 895 89c
:2 0 8b6 28 :3 0
37 :3 0 89e 89f
0 2a :4 0 58
:4 0 2d :2 0 52
:3 0 4f4 8a3 8a5
:3 0 2d :2 0 59
:4 0 4f7 8a7 8a9
:3 0 2d :2 0 49
:3 0 5a :3 0 34
:2 0 5b :2 0 4fa
8ac 8b0 4fe 8ab
8b2 :3 0 501 8a0
8b4 :2 0 8b6 504
8b7 892 8b6 0
8b8 507 0 8c6
5c :3 0 24 :3 0
b5 :3 0 c :3 0
b4 :3 0 b6 :3 0
b7 :4 0 bb 1
:a 0 8c2 :2 0 8c6
8ba 8c0 :2 0 b
:3 0 24 :3 0 8c4
:2 0 8c6 509 8c9
:3 0 8c9 0 8c9
8c8 8c6 8c7 :6 0
8cb 1 :3 0 50e
8cd 510 8cc 8cb
:2 0 8ce 512 :2 0
8d0 515 8d0 8cf
82f 8ce :6 0 8d1
:2 0 2 24 8d0
8d4 :3 0 8d3 8d1
8d5 :8 0 
521
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
36 1 34 1
3d 1 3b 1
42 1 48 1
4e 1 54 1
59 1 6a 1
70 1 7d 1
89 2 8c 8e
2 91 93 2
95 97 2 99
9b 2 9d 9f
2 a1 a3 2
a5 a7 2 a9
ab 2 ad af
2 b1 b3 2
b5 b7 2 b9
bb 2 bd bf
2 c1 c3 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 2
d5 d7 2 d9
db 2 dd df
2 e1 e3 2
e5 e7 2 e9
eb 2 ed ef
2 f1 f3 2
f5 f7 2 f9
fb 2 fd ff
4 85 8b 90
101 1 103 1
105 2 10f 111
3 10d 10e 113
2 11c 11e 2
11b 120 1 122
1 124 1 126
1 12c 2 13c
13e 3 13a 13b
140 2 149 14b
2 14d 14f 2
151 153 1 15b
2 15d 15e 2
155 160 2 148
162 1 164 1
166 2 170 172
3 16e 16f 174
2 17d 17f 2
17c 181 1 183
1 185 2 18c
18d 3 167 186
18f 1 191 3
199 19a 19b 3
19d 19e 19f 1
1a3 3 1ae 1af
1b0 1 1b4 2
1b2 1b4 2 1be
1c3 1 1ca 1
1c5 2 1dd 1df
3 1db 1dc 1e1
2 1ea 1ec 2
1ee 1f0 2 1f2
1f4 2 1f6 1f8
2 1fa 1fc 3
201 202 203 2
1fe 205 2 1e9
207 1 209 1
20b 2 1d4 20c
1 210 1 1cf
2 1cd 214 1
229 1 22f 2
231 232 1 23a
2 236 23a 2
240 246 1 24d
1 248 2 260
262 3 25e 25f
264 2 26d 26f
2 271 273 2
275 277 2 279
27b 2 27d 27f
3 284 285 286
2 281 288 2
26c 28a 1 28c
1 28e 2 257
28f 1 293 1
252 2 250 297
2 2a4 2a6 3
2a2 2a3 2a8 2
2b1 2b3 2 2b5
2b7 2 2b9 2bb
1 2c3 2 2c5
2c6 2 2bd 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2d6 2d8
2 2b0 2da 1
2dc 1 2de 2
2e8 2ea 3 2e6
2e7 2ec 2 2f5
2f7 2 2f4 2f9
1 2fb 1 2fd
3 304 305 306
4 29a 2df 2fe
308 2 30c 312
1 319 1 314
2 32c 32e 3
32a 32b 330 2
339 33b 2 33d
33f 2 341 343
2 345 347 2
349 34b 3 350
351 352 2 34d
354 2 338 356
1 358 1 35a
2 323 35b 1
35f 1 31e 2
31c 363 1 366
2 369 36a 5
217 21b 220 233
36b 1 36d 2
1aa 36e 1 370
2 37b 380 1
387 1 382 2
39a 39c 3 398
399 39e 2 3a7
3a9 2 3ab 3ad
2 3af 3b1 2
3b3 3b5 2 3b7
3b9 3 3be 3bf
3c0 2 3bb 3c2
2 3a6 3c4 1
3c6 1 3c8 2
391 3c9 1 3cd
1 38c 2 38a
3d1 2 3f5 3fa
1 401 1 3fc
2 414 416 3
412 413 418 2
421 423 2 425
427 2 429 42b
2 42d 42f 2
431 433 3 438
439 43a 2 435
43c 2 420 43e
1 440 1 442
2 40b 443 1
447 1 406 2
404 44b 1 456
2 452 456 2
462 464 3 460
461 466 2 46f
471 2 473 475
2 477 479 1
481 2 483 484
2 47b 486 2
488 48a 2 48c
48e 2 490 492
2 494 496 2
46e 498 1 49a
1 49c 2 4a6
4a8 3 4a4 4a5
4aa 2 4b3 4b5
2 4b2 4b7 1
4b9 1 4bb 3
4c2 4c3 4c4 3
49d 4bc 4c6 1
4c8 2 4cf 4d4
1 4db 1 4d6
2 4ee 4f0 3
4ec 4ed 4f2 2
4fb 4fd 2 4ff
501 2 503 505
2 507 509 2
50b 50d 3 512
513 514 2 50f
516 2 4fa 518
1 51a 1 51c
2 4e5 51d 1
521 1 4e0 2
4de 525 1 530
2 52c 530 2
536 537 1 539
1 53e 2 53c
53e 1 540 2
54e 550 3 54c
54d 552 2 55b
55d 2 55f 561
2 563 565 1
56d 2 56f 570
2 567 572 2
574 576 2 578
57a 2 57c 57e
2 580 582 2
55a 584 1 586
1 588 2 592
594 3 590 591
596 2 59f 5a1
2 59e 5a3 1
5a5 1 5a7 3
5ae 5af 5b0 3
589 5a8 5b2 1
5b4 1 5cf 2
5ce 5cf 1 5d7
1 5dd 2 5df
5e0 2 5cc 5e1
1 5e8 1 5e3
2 5fb 5fd 3
5f9 5fa 5ff 2
608 60a 2 60c
60e 2 610 612
2 614 616 2
618 61a 3 61f
620 621 2 61c
623 2 607 625
1 627 1 629
2 5f2 62a 1
62e 1 5ed 2
5eb 632 1 63d
2 639 63d 1
645 2 647 648
2 64a 64c 2
64f 651 1 653
1 659 2 657
659 2 661 662
1 665 2 664
665 2 672 673
2 675 677 2
679 67b 4 66f
670 67d 67e 1
691 2 690 691
1 699 1 69f
2 6a1 6a2 2
68e 6a3 1 6aa
1 6a5 2 6bd
6bf 3 6bb 6bc
6c1 2 6ca 6cc
2 6ce 6d0 2
6d2 6d4 2 6d6
6d8 2 6da 6dc
3 6e1 6e2 6e3
2 6de 6e5 2
6c9 6e7 1 6e9
1 6eb 2 6b4
6ec 1 6f0 1
6af 2 6ad 6f4
2 6fb 6fc 2
6fe 700 3 681
6f7 703 2 65e
706 1 708 1
70a 1 716 2
718 719 2 71b
71d 2 720 722
1 724 1 72a
2 728 72a 2
732 733 1 736
2 735 736 2
743 744 2 746
748 2 74a 74c
4 740 741 74e
74f 1 762 2
761 762 1 76a
1 770 2 772
773 2 75f 774
1 77b 1 776
2 78e 790 3
78c 78d 792 2
79b 79d 2 79f
7a1 2 7a3 7a5
2 7a7 7a9 2
7ab 7ad 3 7b2
7b3 7b4 2 7af
7b6 2 79a 7b8
1 7ba 1 7bc
2 785 7bd 1
7c1 1 780 2
77e 7c5 2 7cc
7cd 2 7cf 7d1
3 752 7c8 7d4
2 72f 7d7 1
7d9 3 711 727
7da 1 7dc 3
656 709 7dd 1
7df 2 7e9 7eb
3 7e7 7e8 7ed
2 7f6 7f8 2
7fa 7fc 2 7fe
800 1 808 2
80a 80b 2 802
80d 2 80f 811
2 813 815 2
817 819 2 81b
81d 2 7f5 81f
1 821 1 823
3 82a 82b 82c
10 106 125 192
195 1a2 371 3d4
44e 4c9 528 5b5
5ba 635 7e0 824
82e 2 83b 83d
3 839 83a 83f
2 848 84a 2
847 84c 2 853
857 2 859 85b
2 85d 861 2
852 863 2 84e
865 1 867 3
868 873 877 1
832 2 88a 88c
3 888 889 88e
2 897 899 2
896 89b 2 8a2
8a4 2 8a6 8a8
3 8ad 8ae 8af
2 8aa 8b1 2
8a1 8b3 2 89d
8b5 1 8b7 4
881 8b8 8c1 8c5
1 8c9 1 87c
2 87a 8cd b
2b 32 39 40
46 4c 52 57
5c 6b 75 
1
4
0 
8d4
0
1
28
17
13
0 1 1 3 1 5 1 7
1 9 1 b 1 d 1 f
1 11 12 1 14 15 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

1b 1 0
b 1 0
34 1 0
42 1 0
54 1 0
4e 1 0
17 1 0
48 1 0
2d 1 0
13 1 0
f 1 0
26 1 0
3 1 0
59 1 0
5f 1 2
2 0 1
7 1 0
3b 1 0
70 1 0
0

/
SHOW ERRORS FUNCTION SP_I_PROFILE;
ALTER FUNCTION SP_I_PROFILE COMPILE DEBUG;
/*######################################################################################*/
/* assign a profile to a task or project, used tables: RESOURCE_ASSIGNMENTS, PROFILES   */
/****************************************************************************************/
/*  RES_ID is profile_id, role_id is role_id in TMT_COMPETENCIES    */
/****************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKPROF
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKPROF ==
CREATE OR REPLACE FUNCTION SP_A_TSKPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
d7
2 :e:
1FUNCTION:
1SP_A_TSKPROF:
1TASK_ID001:
1VARCHAR2:
1RES_ID001:
1ROLE_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_PROJECT_ID:
1H_RES_ID:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_REC_STATUS:
11:
1H_FULL_NAME:
1255:
1H_TYPE:
1PLS_INTEGER:
10:
1H_CRI:
1H_BITFLAG:
1H_NUMBER:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_RES_TYPE:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKPROF(:
1':
1, :
1);:
1CHECK_TRACE:
137:
1+:
1FPUT:
1               ENTER:: SP_A_TSKPROF(38) :: cplan.sql(6190) :: :
1IS NULL:
18:
144:
1      RETURN_INVALID:: SP_A_TSKPROF(45) :: cplan.sql(6197) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
147:
1                EXIT:: SP_A_TSKPROF(48) :: cplan.sql(6200) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1PROJECT_ID:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_WBS WHERE ELEME+
1NT_ID = task_id001:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
162:
1           EXCEPTION:: SP_A_TSKPROF(63) :: cplan.sql(6215) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_CRI WHERE ELEME+
1NT_ID = task_id001:
178:
1           EXCEPTION:: SP_A_TSKPROF(79) :: cplan.sql(6231) :: :
185:
1        RETURN_ERROR:: SP_A_TSKPROF(86) :: cplan.sql(6238) :: :
1RECORD_NOT_FOUND:
1 ID:: :
188:
1                EXIT:: SP_A_TSKPROF(89) :: cplan.sql(6241) :: :
1PMO_RETURN_ERROR_SP:
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1PROFILE_ID:
1PROFILE_NAME:
1REC_STATUS:
1PROFILES:
1SELECT PROFILE_ID, PROFILE_NAME, REC_STATUS INTO h_res_id, h_full_name, h_rec+
1_status:n      FROM PROFILES WHERE PROFILE_ID = h_res_id:
1113:
1           EXCEPTION:: SP_A_TSKPROF(114) :: cplan.sql(6266) :: :
1MAX:
1PROF_NUMBER:
1ROLE_ID:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n         FROM PROFILES:n+
1         WHERE PROJECT_ID=h_project_id AND ROLE_ID=h_role_id:
1135:
1           EXCEPTION:: SP_A_TSKPROF(136) :: cplan.sql(6288) :: :
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')') INTO h_fu+
1ll_name:n         FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n         WH+
1ERE TC.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1152:
1           EXCEPTION:: SP_A_TSKPROF(153) :: cplan.sql(6305) :: :
1159:
1        RETURN_ERROR:: SP_A_TSKPROF(160) :: cplan.sql(6312) :: :
1162:
1                EXIT:: SP_A_TSKPROF(163) :: cplan.sql(6315) :: :
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME)+
1:n         VALUES(h_res_id, h_project_id, h_role_id, h_number, h_full_name):
1FOUND:
1100:
1182:
1           EXCEPTION:: SP_A_TSKPROF(183) :: cplan.sql(6335) :: :
1!=:
1SC_SQL_SUCCESS:
1189:
1        RETURN_ERROR:: SP_A_TSKPROF(190) :: cplan.sql(6342) :: :
1192:
1                EXIT:: SP_A_TSKPROF(193) :: cplan.sql(6345) :: :
1ELSIF:
1ISNOTPROJECTTYPE:
1A:
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT a.RES_ASSIGNMENT_ID INTO h_uniqueID :n            FROM RESOURCE_ASSIGN+
1MENTS a:n            WHERE a.ELEMENT_ID = task_id001  :n            AND a.RES+
1OURCE_ID = res_id001:n            AND a.RESOURCE_TYPE = '1':
1212:
1           EXCEPTION:: SP_A_TSKPROF(213) :: cplan.sql(6365) :: :
1219:
1        RETURN_ERROR:: SP_A_TSKPROF(220) :: cplan.sql(6372) :: :
1RECORD_ALREADY_ASSIGNED:
1222:
1                EXIT:: SP_A_TSKPROF(223) :: cplan.sql(6375) :: :
1D:
1UPDATE PROFILES SET REC_STATUS = 'U' WHERE PROFILE_ID = h_res_id:
1243:
1           EXCEPTION:: SP_A_TSKPROF(244) :: cplan.sql(6396) :: :
1250:
1        RETURN_ERROR:: SP_A_TSKPROF(251) :: cplan.sql(6403) :: :
1253:
1                EXIT:: SP_A_TSKPROF(254) :: cplan.sql(6406) :: :
1SELECT RES_ASSIGNMENT_ID INTO h_uniqueID :n      FROM RESOURCE_ASSIGNMENTS:n +
1     WHERE ELEMENT_ID = task_id001 :n      AND RESOURCE_ID = h_res_id :n     +
1 AND RESOURCE_TYPE = '1':
1273:
1           EXCEPTION:: SP_A_TSKPROF(274) :: cplan.sql(6426) :: :
1ASSIGN_NAMES:
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1304:
1           EXCEPTION:: SP_A_TSKPROF(305) :: cplan.sql(6457) :: :
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1332:
1           EXCEPTION:: SP_A_TSKPROF(333) :: cplan.sql(6485) :: :
1SYS_GUID:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1ISPROJECTTYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1FC_BEFORE_I_RES_ASSIGN:
1ELEMENT_TYPE:
1PARTICIPANT:
1SECURITY_ID:
1REC_USER:
1REC_DATETIME:
1TABLE_TYPE:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT, SECURITY_ID, +
1REC_USER, REC_DATETIME,TABLE_TYPE) :n         VALUES (h_uniqueID, h_project_i+
1d,task_id001, h_type, :n         '1', h_res_id, h_temp_participant, h_temp_se+
1curity_id, rec_user001, SYSTIMESTAMP,h_table_type):
1372:
1           EXCEPTION:: SP_A_TSKPROF(373) :: cplan.sql(6525) :: :
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_OR(PARTICIPANT, pm+
1o_cnst.SC_TEAMMEMBER):n         WHERE RES_ASSIGNMENT_ID = h_uniqueID:
1393:
1           EXCEPTION:: SP_A_TSKPROF(394) :: cplan.sql(6546) :: :
1FC_AFTER_U_RES_ASSIGN:
14:
1402:
1       RETURN_STATUS:: SP_A_TSKPROF(403) :: cplan.sql(6555) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1409:
1           EXCEPTION:: SP_A_TSKPROF(410) :: cplan.sql(6562) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1421:
1           EXCEPTION:: SP_A_TSKPROF(422) :: cplan.sql(6574) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
b52
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :7 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 51 d :3 a0 6b d b7
a0 51 d :3 a0 6b d b7 :2 19
3c :2 a0 d :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 d
:3 a0 :2 51 a5 b d :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :1f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :3 a0 51 a5 b a5 b
7e 51 b4 2e :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c :2 a0 :2 51 a5 b
7e 6e b4 2e :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c a0 51 d :8 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 b4
2e d :4 a0 51 a5 b :2 a0 51
a5 b :2 a0 6b a0 a5 b d
:3 a0 51 a5 b a5 b 7e 51
b4 2e :3 a0 6b d b7 :3 a0 6b
d b7 :2 19 3c a0 6e d a0
51 d :9 a0 a5 b d :16 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 a5 b d b7 :2 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
b52
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10c fa
d9 fe ff 107 f9 129 117 f6
11b 11c 124 116 146 134 113 138
139 141 133 162 151 155 130 15d
150 17e 16d 171 14d 179 16c 19a
189 18d 169 195 188 1b6 1a5 1a9
185 1b1 1a4 1d2 1c1 1c5 1a1 1cd
1c0 1ef 1dd 1bd 1e1 1e2 1ea 1dc
20b 1fa 1fe 1d9 206 1f9 228 216
1f6 21a 21b 223 215 244 233 237
212 23f 232 260 24f 253 22f 25b
24e 280 26b 26f 24b 273 27b 26a
287 28b 267 28f 293 297 29a 29f
2a0 1 2a2 2a7 2ab 2af 2b2 2b7
2bb 2bf 2c2 2c7 2c8 2ca 2cf 2d2
2d6 2d7 2dc 2e1 2e4 2e9 2ea 2ef
2f2 2f6 2f7 2fc 2ff 304 305 30a
30d 312 313 318 31b 320 321 326
329 32d 32e 333 336 33b 33c 341
344 349 34a 34f 352 357 358 35d
360 364 365 36a 36d 372 373 378
37b 380 381 386 389 38e 38f 394
397 39b 39c 3a1 3a4 3a9 3aa 3af
3b2 3b7 3b8 3bd 3be 3c3 3c5 3c9
3cc 3d0 3d4 3d7 3db 3df 3e2 3e5
3ea 3ed 3f0 3f3 3f4 3f9 3fa 1
3fc 401 405 409 40c 411 416 419
41d 41e 423 424 429 42b 42f 432
436 439 43a 43f 442 445 449 44c
44d 452 455 1 458 45d 461 464
465 46a 46d 1 470 475 479 47d
480 484 488 48b 48e 493 496 499
49c 49d 4a2 4a3 1 4a5 4aa 4ae
4b2 4b5 4ba 4bf 4c2 4c6 4c7 4cc
4cf 4d4 4d5 4da 4dd 4e2 4e3 4e8
4eb 4ef 4f3 4f7 4fb 4fe 4ff 501
506 507 509 50a 50f 510 515 517
51b 51e 522 526 529 52d 531 534
537 53c 53f 542 545 546 54b 54c
1 54e 553 557 55b 55e 563 568
56b 56f 570 575 576 57b 57d 581
584 588 58c 58f 593 597 59a 59e
59f 5a4 5a6 5aa 5ad 5b1 5b5 5b9
5bd 5c1 5c5 5c9 5d5 5d9 5dd 5e0
5e4 5e8 5ea 5ee 5f2 5f6 5f9 5fd
601 603 604 609 1 60d 611 615
618 61c 620 624 628 62b 62f 633
636 639 63e 641 644 647 648 64d
64e 1 650 655 659 65d 660 665
66a 66d 671 672 677 67a 67f 680
685 688 68d 68e 693 696 69a 69b
6a0 6a3 6a8 6a9 6ae 6b1 6b5 6b9
6bc 6bf 6c0 6c2 6c3 6c8 6c9 6ce
6d0 6d4 6d7 6d9 6dd 6df 6eb 6ed
6ef 6f0 6f5 6f9 6fb 707 709 70d
711 714 718 71b 71f 722 723 728
72b 72f 733 737 73b 73f 743 747
753 757 75b 75e 762 766 768 76c
770 774 777 77b 77f 781 782 787
1 78b 78f 793 796 79a 79e 7a2
7a6 7a9 7ad 7b1 7b4 7b7 7bc 7bf
7c2 7c5 7c6 7cb 7cc 1 7ce 7d3
7d7 7db 7de 7e3 7e8 7eb 7ef 7f0
7f5 7f8 7fd 7fe 803 806 80b 80c
811 814 818 819 81e 821 826 827
82c 82f 833 837 83a 83d 83e 840
841 846 847 84c 84e 852 855 857
85b 85d 869 86b 86d 86e 873 877
879 885 887 88b 88f 892 896 899
89d 8a0 8a1 8a6 8a9 8ad 8b1 8b4
8b8 8bc 8bf 8c2 8c7 8ca 8cd 8d0
8d1 8d6 8d7 1 8d9 8de 8e2 8e6
8e9 8ee 8f3 8f6 8fa 8fb 900 903
908 909 90e 911 916 917 91c 91f
923 927 92b 92f 932 933 935 93a
93b 93d 93e 943 946 94b 94c 951
954 959 95a 95f 962 966 967 96c
96f 974 975 97a 97b 980 982 986
989 98d 991 994 998 99c 99f 9a2
9a7 9aa 9ad 9b0 9b1 9b6 9b7 1
9b9 9be 9c2 9c6 9c9 9ce 9d3 9d6
9da 9db 9e0 9e1 9e6 9e8 9ec 9ef
9f3 9f7 9fa 9fe a02 a05 a09 a0d
a0e a13 a15 a19 a1c a20 a23 a27
a2b a2f a33 a36 a3a a3c a40 a43
a47 a4b a4f a53 a56 a5a a5c a60
a64 a67 a6b a6f a73 a77 a7b a7f
a83 a87 a8b a8f a93 a97 aa3 aa7
aab aae ab2 ab6 ab8 abc ac0 ac4
ac7 acb acf ad1 ad2 ad7 1 adb
adf ae3 ae6 aea aee af2 af6 af9
afd b01 b04 b07 b0c b0f b12 b15
b16 b1b b1c 1 b1e b23 b27 b2b
b2e b33 b38 b3b b3f b40 b45 b48
b4d b4e b53 b56 b5b b5c b61 b64
b68 b69 b6e b71 b76 b77 b7c b7f
b83 b87 b8a b8d b8e b90 b91 b96
b97 b9c b9e ba2 ba5 ba7 bab bad
bb9 bbb bbd bbe bc3 bc7 bc9 bd5
bd7 bdb bdf be2 be6 be9 bed bf0
bf1 bf6 bf9 bfd c01 c05 c09 c0d
c11 c14 c17 c18 c1a c1e c22 c26
c2a c2e c32 c36 c3a c3e c42 c4e
c52 c56 c59 c5d c61 c63 c67 c6b
c6f c72 c76 c7a c7c c7d c82 1
c86 c8a c8e c91 c95 c99 c9d ca1
ca4 ca8 cac caf cb2 cb7 cba cbd
cc0 cc1 cc6 cc7 1 cc9 cce cd2
cd6 cd9 cde ce3 ce6 cea ceb cf0
cf3 cf8 cf9 cfe d01 d06 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d52 d56
d58 d64 d66 d68 d69 d6e d72 d74
d80 d82 d86 d8a d8e d92 d96 d9a
d9e da2 da6 daa dae db2 db6 dba
dbe dc2 dc6 dca dce dd2 dd6 dda
dde de2 de6 dea dee df2 df6 dfa
dfe e0a e0e e12 e15 e19 e1d e1f
e23 e27 e2b e2e e32 e36 e38 e39
e3e 1 e42 e46 e4a e4d e51 e55
e59 e5d e60 e64 e68 e6b e6e e73
e76 e79 e7c e7d e82 e83 1 e85
e8a e8e e92 e95 e9a e9f ea2 ea6
ea7 eac eaf eb4 eb5 eba ebd ec2
ec3 ec8 ecb ecf ed0 ed5 ed8 edd
ede ee3 ee6 eea eee ef1 ef4 ef5
ef7 ef8 efd efe f03 f05 f09 f0c
f0e f12 f14 f20 f22 f24 f25 f2a
f2e f30 f3c f3e f42 f46 f49 f4d
f50 f54 f57 f58 f5d f60 f64 f68
f6b f6f f73 f76 f79 f7e f81 f84
f87 f88 f8d f8e 1 f90 f95 f99
f9d fa0 fa5 faa fad fb1 fb2 fb7
fba fbf fc0 fc5 fc8 fcd fce fd3
fd6 fda fde fe2 fe6 fe9 fea fec
ff1 ff2 ff4 ff5 ffa ffd 1002 1003
1008 100b 1010 1011 1016 1019 101d 101e
1023 1026 102b 102c 1031 1032 1037 1039
103d 1040 1044 1048 104b 104f 1053 1056
1059 105e 1061 1064 1067 1068 106d 106e
1 1070 1075 1079 107d 1080 1085 108a
108d 1091 1092 1097 1098 109d 109f 10a3
10a6 10aa 10ae 10b1 10b5 10b9 10bc 10c0
10c4 10c5 10ca 10cc 10d0 10d3 10d7 10db
10df 10e3 10e7 10eb 10ef 10f3 10f7 10fb
10ff 110b 110f 1114 1118 111b 111c 1121
1125 1129 112c 112f 1133 1135 1139 113d
1140 1143 1147 1149 114d 1151 1154 1156
115a 115e 1162 1165 1169 116d 116f 1170
1175 1 1179 117d 1181 1184 1188 118c
1190 1194 1197 119b 119f 11a2 11a5 11aa
11ad 11b0 11b3 11b4 11b9 11ba 1 11bc
11c1 11c5 11c9 11cc 11d1 11d6 11d9 11dd
11de 11e3 11e6 11eb 11ec 11f1 11f4 11f9
11fa 11ff 1202 1206 1207 120c 120f 1214
1215 121a 121d 1221 1225 1228 122b 122c
122e 122f 1234 1235 123a 123c 1240 1243
1245 1249 124b 1257 1259 125b 125c 1261
1265 1267 1273 1275 1279 127d 1280 1284
1287 128b 128e 128f 1294 1297 129b 129f
12a2 12a6 12aa 12ad 12b0 12b5 12b8 12bb
12be 12bf 12c4 12c5 1 12c7 12cc 12d0
12d4 12d7 12dc 12e1 12e4 12e8 12e9 12ee
12f1 12f6 12f7 12fc 12ff 1304 1305 130a
130d 1311 1315 1319 131d 1320 1321 1323
1328 1329 132b 132c 1331 1334 1339 133a
133f 1342 1347 1348 134d 1350 1354 1355
135a 135d 1362 1363 1368 1369 136e 1370
1374 1377 137b 137f 1382 1386 138a 138d
1390 1395 1398 139b 139e 139f 13a4 13a5
1 13a7 13ac 13b0 13b4 13b7 13bc 13c1
13c4 13c8 13c9 13ce 13cf 13d4 13d6 13da
13dd 13e1 13e5 13e8 13ec 13f0 13f3 13f7
13fb 13fc 1401 1403 1407 140a 140e 1410
1414 1418 141b 141f 1422 1426 1429 142a
142f 1432 1436 143a 143e 1441 1442 1444
1445 1447 144a 144d 144e 1453 1457 145b
145f 1463 1467 146b 146f 1473 1477 147b
147f 1483 1487 1493 1497 149b 149e 14a2
14a6 14a8 14ac 14b0 14b4 14b7 14bb 14bf
14c1 14c2 14c7 1 14cb 14cf 14d3 14d6
14da 14de 14e2 14e6 14e9 14ed 14f1 14f4
14f7 14fc 14ff 1502 1505 1506 150b 150c
1 150e 1513 1517 151b 151e 1523 1528
152b 152f 1530 1535 1538 153d 153e 1543
1546 154b 154c 1551 1554 1558 1559 155e
1561 1566 1567 156c 156f 1573 1577 157a
157d 157e 1580 1581 1586 1587 158c 158e
1592 1595 1597 159b 159d 15a9 15ab 15ad
15ae 15b3 15b7 15b9 15c5 15c7 15cb 15cf
15d2 15d6 15d9 15dd 15e0 15e1 15e6 15e9
15ed 15f1 15f4 15f8 15fc 15ff 1602 1607
160a 160d 1610 1611 1616 1617 1 1619
161e 1622 1626 1629 162e 1633 1636 163a
163b 1640 1643 1648 1649 164e 1651 1656
1657 165c 165f 1663 1667 166b 166f 1672
1673 1675 167a 167b 167d 167e 1683 1686
168b 168c 1691 1694 1699 169a 169f 16a2
16a6 16a7 16ac 16af 16b4 16b5 16ba 16bb
16c0 16c2 16c6 16c9 16cd 16d1 16d4 16d8
16dc 16df 16e2 16e7 16ea 16ed 16f0 16f1
16f6 16f7 1 16f9 16fe 1702 1706 1709
170e 1713 1716 171a 171b 1720 1721 1726
1728 172c 172f 1733 1737 173a 173e 1742
1745 1749 174d 174e 1753 1755 1759 175c
175e 1762 1765 1769 176d 1770 1773 1774
1776 1779 177e 177f 1784 1788 178c 1790
1794 17a0 17a4 17a9 17ad 17b0 17b1 17b6
17ba 17be 17c1 17c4 17c8 17ca 17ce 17d2
17d5 17d8 17dc 17de 17e2 17e6 17e9 17eb
17ef 17f3 17f7 17fa 17fe 1802 1804 1805
180a 1 180e 1812 1816 1819 181d 1821
1825 1829 182c 1830 1834 1837 183a 183f
1842 1845 1848 1849 184e 184f 1 1851
1856 185a 185e 1861 1866 186b 186e 1872
1873 1878 187b 1880 1881 1886 1889 188e
188f 1894 1897 189b 189c 18a1 18a4 18a9
18aa 18af 18b2 18b6 18ba 18bd 18c0 18c1
18c3 18c4 18c9 18ca 18cf 18d1 18d5 18d8
18da 18de 18e0 18ec 18ee 18f0 18f1 18f6
18fa 18fc 1908 190a 190c 1910 1913 1915
1919 191d 1921 1924 1928 192c 192f 1932
1937 193a 193d 1940 1941 1946 1947 1
1949 194e 1952 1956 1959 195e 1963 1966
196a 196b 1970 1973 1978 1979 197e 1981
1986 1987 198c 198f 1993 1997 199b 199f
19a2 19a3 19a5 19aa 19ab 19ad 19ae 19b3
19b6 19bb 19bc 19c1 19c4 19c9 19ca 19cf
19d2 19d6 19d7 19dc 19df 19e4 19e5 19ea
19eb 19f0 19f2 19f6 19f9 19fd 1a01 1a04
1a08 1a0c 1a0f 1a12 1a17 1a1a 1a1d 1a20
1a21 1a26 1a27 1 1a29 1a2e 1a32 1a36
1a39 1a3e 1a43 1a46 1a4a 1a4b 1a50 1a51
1a56 1a58 1a5c 1a5f 1a63 1a67 1a6a 1a6e
1a72 1a75 1a79 1a7d 1a7e 1a83 1a85 1a89
1a8d 1a90 1a94 1a97 1a9b 1a9f 1aa3 1aa7
1aab 1aaf 1ab3 1ab7 1abb 1ac7 1acb 1acf
1ad2 1ad6 1ada 1adc 1ae0 1ae4 1ae8 1aeb
1aef 1af3 1af5 1af6 1afb 1 1aff 1b03
1b07 1b0a 1b0e 1b12 1b16 1b1a 1b1d 1b21
1b25 1b28 1b2b 1b30 1b33 1b36 1b39 1b3a
1b3f 1b40 1 1b42 1b47 1b4b 1b4f 1b52
1b57 1b5c 1b5f 1b63 1b64 1b69 1b6c 1b71
1b72 1b77 1b7a 1b7f 1b80 1b85 1b88 1b8c
1b8d 1b92 1b95 1b9a 1b9b 1ba0 1ba3 1ba7
1bab 1bae 1bb1 1bb2 1bb4 1bb5 1bba 1bbb
1bc0 1bc2 1bc6 1bc9 1bcb 1bcf 1bd1 1bdd
1bdf 1be1 1be2 1be7 1beb 1bed 1bf9 1bfb
1bff 1c03 1c06 1c0a 1c0d 1c11 1c14 1c15
1c1a 1c1d 1c21 1c25 1c28 1c29 1c2b 1c2e
1c31 1c32 1c37 1c3b 1c3f 1c43 1c47 1c4b
1c4f 1c53 1c57 1c5b 1c5f 1c63 1c67 1c6b
1c6f 1c73 1c7f 1c83 1c88 1c8c 1c8f 1c90
1c95 1c99 1c9d 1ca0 1ca3 1ca7 1ca9 1cad
1cb1 1cb4 1cb7 1cbb 1cbd 1cc1 1cc5 1cc8
1cca 1cce 1cd2 1cd6 1cd9 1cdd 1ce1 1ce3
1ce4 1ce9 1 1ced 1cf1 1cf5 1cf8 1cfc
1d00 1d04 1d08 1d0b 1d0f 1d13 1d16 1d19
1d1e 1d21 1d24 1d27 1d28 1d2d 1d2e 1
1d30 1d35 1d39 1d3d 1d40 1d45 1d4a 1d4d
1d51 1d52 1d57 1d5a 1d5f 1d60 1d65 1d68
1d6d 1d6e 1d73 1d76 1d7a 1d7b 1d80 1d83
1d88 1d89 1d8e 1d91 1d95 1d99 1d9c 1d9f
1da0 1da2 1da3 1da8 1da9 1dae 1db0 1db4
1db7 1db9 1dbd 1dbf 1dcb 1dcd 1dcf 1dd0
1dd5 1dd9 1ddb 1de7 1de9 1ded 1def 1df3
1df7 1dfa 1dfb 1dfd 1e00 1e03 1e04 1e09
1e0d 1e11 1e15 1e19 1e1d 1e21 1e25 1e29
1e2d 1e31 1e35 1e39 1e3d 1e41 1e45 1e51
1e55 1e5a 1e5e 1e61 1e62 1e67 1e6b 1e6f
1e72 1e75 1e79 1e7b 1e7f 1e83 1e86 1e89
1e8d 1e8f 1e93 1e97 1e9a 1e9c 1ea0 1ea4
1ea8 1eab 1eaf 1eb3 1eb5 1eb6 1ebb 1
1ebf 1ec3 1ec7 1eca 1ece 1ed2 1ed6 1eda
1edd 1ee1 1ee5 1ee8 1eeb 1ef0 1ef3 1ef6
1ef9 1efa 1eff 1f00 1 1f02 1f07 1f0b
1f0f 1f12 1f17 1f1c 1f1f 1f23 1f24 1f29
1f2c 1f31 1f32 1f37 1f3a 1f3f 1f40 1f45
1f48 1f4c 1f4d 1f52 1f55 1f5a 1f5b 1f60
1f63 1f67 1f6b 1f6e 1f71 1f72 1f74 1f75
1f7a 1f7b 1f80 1f82 1f86 1f89 1f8b 1f8f
1f91 1f9d 1f9f 1fa1 1fa2 1fa7 1fab 1fad
1fb9 1fbb 1fbd 1fc1 1fc5 1fc8 1fcc 1fd0
1fd1 1fd6 1fda 1fde 1fe2 1fe6 1fea 1fed
1fee 1ff0 1ff4 1ff8 1ffb 1ffc 1ffe 2002
2006 2009 200d 200e 2010 2014 2018 201c
2020 2023 2024 2026 2027 2029 202c 202f
2030 2035 2039 203d 2041 2044 2048 204a
204e 2052 2056 2059 205d 205f 2063 2067
206a 206e 2073 2077 207b 207e 2082 2086
208a 208e 2092 2096 209a 209e 20a2 20a6
20a7 20a9 20ad 20b1 20b5 20b9 20bd 20c1
20c5 20c9 20cd 20d1 20d5 20d9 20dd 20e1
20e5 20e9 20ed 20f1 20f5 20f9 20fd 2101
2105 2111 2115 211a 211e 2121 2122 2127
212b 212f 2132 2135 2139 213b 213f 2143
2146 2149 214d 214f 2153 2157 215a 215c
2160 2164 2168 216b 216f 2173 2175 2176
217b 1 217f 2183 2187 218a 218e 2192
2196 219a 219d 21a1 21a5 21a8 21ab 21b0
21b3 21b6 21b9 21ba 21bf 21c0 1 21c2
21c7 21cb 21cf 21d2 21d7 21dc 21df 21e3
21e4 21e9 21ec 21f1 21f2 21f7 21fa 21ff
2200 2205 2208 220c 220d 2212 2215 221a
221b 2220 2223 2227 222b 222e 2231 2232
2234 2235 223a 223b 2240 2242 2246 2249
224b 224f 2251 225d 225f 2261 2262 2267
226b 226d 2279 227b 227f 2281 2285 2289
228c 2290 2293 2297 229a 229b 22a0 22a3
22a7 22ab 22af 22b3 22b7 22bb 22bf 22c3
22c7 22d3 22d7 22dc 22e0 22e3 22e4 22e9
22ed 22f1 22f4 22f7 22fb 22fd 2301 2305
2308 230b 230f 2311 2315 2319 231c 231e
2322 2326 232a 232d 2331 2335 2337 2338
233d 1 2341 2345 2349 234c 2350 2354
2358 235c 235f 2363 2367 236a 236d 2372
2375 2378 237b 237c 2381 2382 1 2384
2389 238d 2391 2394 2399 239e 23a1 23a5
23a6 23ab 23ae 23b3 23b4 23b9 23bc 23c1
23c2 23c7 23ca 23ce 23cf 23d4 23d7 23dc
23dd 23e2 23e5 23e9 23ed 23f0 23f3 23f4
23f6 23f7 23fc 23fd 2402 2404 2408 240b
240d 2411 2413 241f 2421 2423 2424 2429
242d 242f 243b 243d 2441 2445 2449 244a
244c 2450 2452 2456 245a 245d 2461 2465
2468 246c 2470 2473 2476 247b 247e 2481
2484 2485 248a 248b 1 248d 2492 2496
249a 249d 24a2 24a7 24aa 24ae 24af 24b4
24b7 24bc 24bd 24c2 24c5 24ca 24cb 24d0
24d3 24d7 24db 24df 24e3 24e6 24e7 24e9
24ee 24ef 24f1 24f2 24f7 24fa 24ff 2500
2505 2508 250d 250e 2513 2516 251a 251b
2520 2523 2528 2529 252e 252f 2534 2536
253a 253d 2541 2545 2548 254c 2550 2553
2557 255b 255c 2561 2563 2567 256b 256e
2572 2576 2579 257d 2581 2584 2587 258c
258f 2592 2595 2596 259b 259c 1 259e
25a3 25a7 25ab 25ae 25b3 25b8 25bb 25bf
25c0 25c5 25c6 25cb 25cf 25d3 25d6 25db
25e0 25e3 25e7 25eb 25ee 25ef 25f4 25f7
25fc 25fd 2602 2605 2609 260d 2610 2611
2616 2617 261c 261e 2622 2625 2629 262d
2631 2635 2639 263d 2641 2645 2649 2655
265a 265e 2662 2666 266a 266c 266d 2672
1 2676 267a 267e 2681 2685 2689 268d
2691 2694 2698 269c 269f 26a2 26a7 26aa
26ad 26b0 26b1 26b6 26b7 1 26b9 26be
26c2 26c6 26c9 26ce 26d3 26d6 26da 26db
26e0 26e1 26e6 26ea 26ee 26f1 26f6 26fb
26fe 2702 2703 2708 270b 2710 2711 2716
2719 271d 2721 2724 2727 2728 272a 272b
2730 2731 2736 2738 273c 273f 2743 2747
274b 274f 2753 2757 275b 2767 276c 2770
2774 2778 277c 277e 2782 2784 2790 2792
2794 2795 279a 279e 27a0 27ac 27b0 27b2
27b3 27bc 
b52
2
0 1 a 6 11 :3 6 10 :3 6
11 :3 6 12 :2 6 1 3 a 13
a :2 1 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 d 16 15
:2 d :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 11 1a 19 :2 11
:2 4 10 19 18 :2 10 :2 4 :2 b 1a
b :2 4 :2 a 19 a :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 17 26
17 :2 4 17 20 1f :2 17 :2 4 :2 13
22 13 :2 4 14 1d 1c :2 14 :2 4
:2 14 23 14 :2 4 :2 11 20 11 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 54 5a 5d :2 54 6b 81 8
:2 6b d 10 :2 6b 1b 1e :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 29 2c :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
2a 2d :2 6b 32 35 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e :2 7 52 :2 4 :4 9 8
7 :4 23 22 21 :2 7 :4 3c 3b 3a
:2 7 a :2 14 26 :2 30 3c 3f 4f
51 52 :2 4f :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b1
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 51
:2 4 e 1a 27 35 41 4f 5c
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 88 8b :2 24 93 96 :2 24 a2
a5 ac b5 b8 :2 a5 :2 24 :2 d 59
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 11 1d 2a
38 44 52 5f :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 58 59 :2 56 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :3 35 b :2 14 1f 1d :2 28 :2 1d
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 24 be c1 :2 24 c9 cc :2 24
d1 d4 :2 24 df e2 :2 24 :2 d 59
:2 a d :2 17 29 :2 33 3f 42 52
54 55 :2 52 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 29
:2 32 44 50 :2 a 38 :3 7 10 :2 7
17 :2 20 7 35 7 10 :2 7 17
:2 20 7 :5 4 10 4 e 1a 28
38 42 4f c 1b 28 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 63 66
:2 24 73 76 :2 24 7a 7d :2 24 89
8c :2 24 94 97 :2 24 a3 a6 ad
b6 b9 :2 a6 :2 24 :2 d 5a :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a :2 7 16 :2 7 14 1b 28
2b :2 14 7 11 1a 1e 35 f
10 1b 2c 34 :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 35 11 1c 29 34 41 4c
59 64 71 7c 89 8f 93 a9
af b2 c8 ce d6 ed f 20
24 35 10 13 20 2e 32 3f
42 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 35 b
:2 14 1f 1d :2 28 :2 1d a d :2 17
29 :2 33 3f 43 53 56 57 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 b7 :2 8a :2 24 bf
c2 :2 24 ca cd :2 24 d2 d5 :2 24
de e1 :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 44 4e
:2 a 38 :2 7 16 1f 2a 35 3d
4a 11 1b 29 34 3e a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 35 b
:2 14 20 1d :2 29 :2 1d a d :2 17
29 :2 33 3f 43 53 56 57 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 af :2 8a :2 24 b7
ba :2 24 c2 c5 :2 24 ca cd :2 24
d7 da :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 3c 47
:2 a 39 :2 7 4 35 b :2 14 1f
1d :2 28 :2 1d :2 a 1b 24 2c :2 1b
:2 a 30 33 :2 30 14 16 2d 12
27 13 15 22 11 13 21 11
13 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 35 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8a 8d
96 9e :2 a7 :2 96 c1 :2 8d :2 27 c9
cc :2 27 d4 d7 :2 27 dc df :2 27
e9 ec :2 27 :2 10 5d :2 d 10 :2 1a
2c :2 36 42 45 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
:2 10 5c :3 d :2 18 2c :2 35 4e 59
:2 d 3b :2 a 35 :2 7 a 11 1f
22 :2 a 25 27 :2 25 14 21 38
45 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 2b :2 7 38 35 a :2 14 26
:2 30 3c 40 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 60 63 :2 21 70
73 :2 21 77 7a :2 21 84 87 90
98 :2 a1 :2 90 b4 :2 87 :2 21 bc bf
:2 21 c7 ca :2 21 cf d2 :2 21 dc
df :2 21 :2 a 57 :2 7 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 60 63 :2 21 :2 a
56 :3 7 :2 12 26 :2 2f 41 4c :2 7
:5 4 11 4 e 25 c d 1a
b 19 b :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 89 8c :2 24 94
97 :2 24 a3 a6 ad b6 b9 :2 a6
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 8 :2 11 1c 1a :2 25 :2 1a 7
a 13 1a :2 a 1d 1f :2 1d 14
20 12 19 27 44 12 19 28
2f 49 12 22 13 20 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 21 7
21 d 16 1d :2 d 20 22 :2 20
14 20 12 19 27 44 12 19
28 2f 49 12 22 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :4 24
21 :3 7 :3 15 :2 7 1a 28 31 3f
:2 28 43 4c 54 :2 43 24 :2 2d 42
:2 1a 7 a 18 21 29 :2 18 :2 a
2d 30 :2 2d a 20 :2 29 a 32
a 20 :2 29 a :5 7 1a :2 7 19
:2 7 1a 31 3f 49 51 2d 41
52 :2 1a 7 16 2b 3e 4a 56
a 19 26 33 40 4a 57 12
1e 2b 37 f 19 2d 41 4e
5b a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 35 4 35 b :2 14 1f 1d
:2 28 :2 1d a 11 2a 38 41 48
55 5e 10 24 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 38 7 1a 30
:2 1a 7 38 35 :2 4 7 :2 11 23
:2 2d 39 3c 4c 4f 50 :2 4c :2 23
:3 7 :2 d 12 1e 5d 60 :2 1e 6d
70 :2 1e 74 77 :2 1e 81 84 8d
95 :2 9e :2 8d a9 :2 84 :2 1e b1 b4
:2 1e bc bf :2 1e c4 c7 :2 1e d2
d5 :2 1e :2 7 53 :3 4 :2 f 21 :2 2a
34 40 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 60 63
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 57 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4d 50 51
:2 4d :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 54 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
b52
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :6 13
:6 14 :7 15 :6 16 :7 17
:6 18 :6 19 :7 1b :b 1d
:11 1e 1f :2 1e :2 1f
:2 1e :2 1f :2 1e :2 20
:2 1e :2 20 :2 1e :2 20
:2 1e :2 20 :2 1e :2 21
:2 1e :2 21 :2 1e :2 21
:2 1e :2 21 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:4 1e :3 1d :11 25 :b 26
:3 25 :16 2b :11 2c :20 2d
:3 2c :11 2f :b 30 :3 2f
:9 32 :3 2b :8 36 :5 37
35 39 :5 3a :3 39
:2 3b :5 3d :11 3e :24 3f
:3 3e :2 3c :6 3b 38
:3 1c :a 44 :8 46 :5 47
45 49 :5 4a :3 49
:2 4b :5 4d :11 4e :24 4f
:3 4e :2 4c :6 4b 48
:3 44 :a 54 :11 55 :30 56
:3 55 :11 58 :b 59 :3 58
:a 5b :3 54 :3 5d :5 5e
44 :3 60 :5 61 5f
:3 44 :3 64 :6 68 :3 69
68 :5 6a 67 6c
:5 6d :3 6c :2 6e :5 70
:11 71 :24 72 :3 71 :2 6f
:6 6e 6b :3 1c :a 77
:3 78 :8 7a :4 7d 7e
:4 7f 7d :5 80 7c
82 :5 83 :3 82 :2 84
:5 86 :11 87 :24 88 :3 87
:2 85 :6 84 81 :3 77
:14 8e :4 8f :7 90 8e
:5 91 8d 93 :5 94
:3 93 :2 95 :5 97 :11 98
:24 99 :3 98 :2 96 :6 95
92 :3 77 :a 9e :11 9f
:30 a0 :3 9f :11 a2 :b a3
:3 a2 :a a5 :3 9e :6 a9
:5 aa a9 :6 ab :5 ac
ab :5 ae ad :3 ab
a8 b1 :5 b2 :3 b1
:2 b3 :5 b5 :11 b6 :24 b7
:3 b6 :2 b4 :6 b3 b0
:3 77 :a bc :11 bd :30 be
:3 bd :11 c0 :b c1 :3 c0
:a c3 :3 bc c5 77
:a c5 :c c6 :3 c8 :2 c9
:3 ca :3 cb :2 cc c8
:5 cd c7 cf :5 d0
:3 cf :2 d1 :5 d3 :11 d4
:24 d5 :3 d4 :2 d2 :6 d1
ce :3 c6 :a da :11 db
:30 dc :3 db :11 de :b df
:3 de :a e1 :3 da :3 c6
:a e5 :5 e7 :6 e8 :5 e9
e8 :5 eb ea :3 e8
e6 ee :5 ef :3 ee
:2 f0 :5 f2 :11 f3 :24 f4
:3 f3 :2 f1 :6 f0 ed
:6 e5 c5 77 :11 fa
:30 fb :3 fa :11 fd :b fe
:3 fd :a 100 f9 :3 77
:3 103 :2 105 106 :2 107
:2 108 109 105 :5 10a
104 10c :5 10d :3 10c
:2 10e :5 110 :11 111 :24 112
:3 111 :2 10f :6 10e 10b
:3 1c :a 118 :9 119 :2 11b
:4 11d :5 120 :2 121 :2 124
11b :6 125 :5 126 125
:5 128 127 :3 125 11a
12b :5 12c :3 12b :2 12d
:5 12f :11 130 :24 131 :3 130
:2 12e :6 12d 12a :3 119
135 119 :9 135 :2 137
:4 139 :5 13c :2 13d :2 140
137 :6 141 :5 142 141
:5 144 143 :3 141 136
147 :5 148 :3 147 :2 149
:5 14b :11 14c :24 14d :3 14c
:2 14a :6 149 146 :4 135
:3 119 :5 154 :c 155 :4 156
:3 155 :c 158 :5 159 158
:5 15b 15a :3 158 :3 15e
:3 15f :6 161 :3 162 :3 161
:5 165 :7 166 :4 167 :6 168
165 :6 169 :5 16a 169
:5 16c 16b :3 169 164
16f :5 170 :3 16f :2 171
:5 173 :11 174 :24 175 :3 174
:2 172 :6 171 16e :3 118
17a 118 :a 17a :7 17c
:2 17d 17c :6 17e :5 17f
17e :5 181 180 :3 17e
17b 184 :5 185 :3 184
:2 186 :5 188 :11 189 :24 18a
:3 189 :2 187 :6 186 183
:3 17a :6 18f 17a :3 118
:11 192 :30 193 :3 192 :a 195
1c :3 198 :11 199 :b 19a
:17 19b :3 199 :2 19d :3 19e
:3 19f 1a0 19e 19d
19e :3 1a1 :3 198 :2 1a2
:5 1a4 :11 1a5 :b 1a6 :18 1a7
:3 1a5 :2 1a9 1aa :3 1ab
1ac 1aa 1a9 1aa
:3 1ad :2 1a3 :6 1a2 197
:7 1 
27be
4
:3 0 1 :3 0 2
:a 0 b4d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 b4d 2
18 :2 0 c :2 0
12 4 :3 0 c
:2 0 10 1b 1d
:6 0 20 1e 0
b4b 0 b :6 0
c :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
b4b 0 d :6 0
10 :2 0 1a 4
:3 0 18 29 2b
:6 0 2e 2c 0
b4b 0 e :6 0
c :2 0 1e 4
:3 0 1c 30 32
:6 0 35 33 0
b4b 0 f :6 0
13 :2 0 22 4
:3 0 20 37 39
:6 0 3c 3a 0
b4b 0 11 :6 0
15 :2 0 26 4
:3 0 24 3e 40
:6 0 43 41 0
b4b 0 12 :6 0
18 :2 0 2a 4
:3 0 28 45 47
:6 0 4a 48 0
b4b 0 14 :6 0
18 :2 0 2c 17
:3 0 4c :7 0 50
4d 4e b4b 0
16 :6 0 18 :2 0
2e 17 :3 0 52
:7 0 56 53 54
b4b 0 19 :6 0
18 :2 0 30 17
:3 0 58 :7 0 5c
59 5a b4b 0
1a :6 0 18 :2 0
32 17 :3 0 5e
:7 0 62 5f 60
b4b 0 1b :6 0
c :2 0 34 17
:3 0 64 :7 0 68
65 66 b4b 0
1c :6 0 18 :2 0
38 4 :3 0 36
6a 6c :6 0 6f
6d 0 b4b 0
1d :6 0 13 :2 0
3a 17 :3 0 71
:7 0 75 72 73
b4b 0 1e :6 0
18 :2 0 3e 4
:3 0 3c 77 79
:6 0 7c 7a 0
b4b 0 1f :6 0
18 :2 0 40 17
:3 0 7e :7 0 82
7f 80 b4b 0
20 :6 0 8a 8b
0 42 17 :3 0
84 :7 0 88 85
86 b4b 0 21
:6 0 90 91 0
44 9 :3 0 a
:2 0 4 8c :7 0
8f 8d 0 b4b
0 22 :6 0 23
:3 0 24 :3 0 23
:3 0 25 :3 0 93
94 0 2 :4 0
46 95 97 92
99 98 :2 0 26
:3 0 27 :3 0 9b
9c 0 28 :4 0
23 :3 0 29 :3 0
9f a0 0 2
:4 0 48 a1 a3
2a :4 0 2b :2 0
2c :3 0 4a a6
a8 :3 0 2d :4 0
2b :2 0 2e :4 0
4d ab ad :3 0
2b :2 0 3 :3 0
50 af b1 :3 0
2b :2 0 2e :4 0
53 b3 b5 :3 0
2b :2 0 2f :4 0
56 b7 b9 :3 0
2b :2 0 2e :4 0
59 bb bd :3 0
2b :2 0 5 :3 0
5c bf c1 :3 0
2b :2 0 2e :4 0
5f c3 c5 :3 0
2b :2 0 2f :4 0
62 c7 c9 :3 0
2b :2 0 2e :4 0
65 cb cd :3 0
2b :2 0 6 :3 0
68 cf d1 :3 0
2b :2 0 2e :4 0
6b d3 d5 :3 0
2b :2 0 2f :4 0
6e d7 d9 :3 0
2b :2 0 2e :4 0
71 db dd :3 0
2b :2 0 7 :3 0
74 df e1 :3 0
2b :2 0 2e :4 0
77 e3 e5 :3 0
2b :2 0 30 :4 0
7a e7 e9 :3 0
7d 9d eb :2 0
ed 82 ee 9a
ed 0 ef 84
0 aab 23 :3 0
24 :3 0 f0 f1
0 23 :3 0 31
:3 0 f3 f4 0
13 :2 0 2 :4 0
32 :2 0 33 :2 0
13 :2 0 86 f9
fb :3 0 89 f5
fd f2 ff fe
:2 0 26 :3 0 34
:3 0 101 102 0
28 :4 0 35 :4 0
2b :2 0 2c :3 0
8d 106 108 :3 0
90 103 10a :2 0
10c 93 10d 100
10c 0 10e 95
0 aab 3 :3 0
36 :2 0 97 110
111 :3 0 112 :2 0
113 :2 0 5 :3 0
36 :2 0 99 116
117 :3 0 118 :2 0
119 :2 0 114 11b
11a :2 0 6 :3 0
36 :2 0 9b 11e
11f :3 0 120 :2 0
121 :2 0 11c 123
122 :2 0 23 :3 0
24 :3 0 125 126
0 23 :3 0 31
:3 0 128 129 0
37 :2 0 2 :4 0
38 :2 0 33 :2 0
13 :2 0 9d 12e
130 :3 0 a0 12a
132 127 134 133
:2 0 26 :3 0 34
:3 0 136 137 0
28 :4 0 39 :4 0
2b :2 0 2c :3 0
a4 13b 13d :3 0
2b :2 0 3a :4 0
a7 13f 141 :3 0
2b :2 0 3b :4 0
aa 143 145 :3 0
2b :2 0 3c :3 0
3d :3 0 3e :3 0
3f :3 0 14a 14b
0 ad 149 14d
40 :4 0 af 148
150 b2 147 152
:3 0 b5 138 154
:2 0 156 b8 157
135 156 0 158
ba 0 181 23
:3 0 24 :3 0 159
15a 0 23 :3 0
31 :3 0 15c 15d
0 13 :2 0 2
:4 0 41 :2 0 33
:2 0 13 :2 0 bc
162 164 :3 0 bf
15e 166 15b 168
167 :2 0 26 :3 0
34 :3 0 16a 16b
0 28 :4 0 42
:4 0 2b :2 0 2c
:3 0 c3 16f 171
:3 0 c6 16c 173
:2 0 175 c9 176
169 175 0 177
cb 0 181 43
:3 0 44 :3 0 178
179 0 3e :3 0
3f :3 0 17b 17c
0 45 :3 0 cd
17a 17f :2 0 181
d0 182 124 181
0 183 d4 0
aab 46 :3 0 47
:3 0 d :3 0 16
:3 0 48 :3 0 49
:3 0 3 :4 0 4a
1 :8 0 191 9
:3 0 4b :3 0 18c
18d 0 4c :3 0
18e 18f 0 191
d6 1e4 4d :3 0
9 :3 0 4b :3 0
193 194 0 4c
:3 0 195 196 0
198 d9 19a db
199 198 :2 0 1e2
4e :3 0 9 :3 0
4b :3 0 19d 19e
0 4c :3 0 19f
1a0 0 1da 23
:3 0 24 :3 0 1a2
1a3 0 23 :3 0
31 :3 0 1a5 1a6
0 4f :2 0 2
:4 0 50 :2 0 33
:2 0 13 :2 0 dd
1ab 1ad :3 0 e0
1a7 1af 1a4 1b1
1b0 :2 0 26 :3 0
34 :3 0 1b3 1b4
0 28 :4 0 51
:4 0 2b :2 0 2c
:3 0 e4 1b8 1ba
:3 0 2b :2 0 3a
:4 0 e7 1bc 1be
:3 0 2b :2 0 52
:4 0 ea 1c0 1c2
:3 0 2b :2 0 4c
:3 0 ed 1c4 1c6
:3 0 2b :2 0 53
:4 0 f0 1c8 1ca
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 f3
1cd 1d1 f7 1cc
1d3 :3 0 fa 1b5
1d5 :2 0 1d7 fd
1d8 1b2 1d7 0
1d9 ff 0 1da
101 1dd :3 0 1dd
0 1dd 1dc 1da
1db :6 0 1df 2
:3 0 104 1e1 106
1e0 1df :2 0 1e2
108 :2 0 1e4 0
1e4 1e3 191 1e2
:6 0 aab 1 :3 0
9 :3 0 4b :3 0
1e6 1e7 0 9
:3 0 57 :2 0 58
:3 0 1e9 1eb 0
10d 1ea 1ed :3 0
1ee :2 0 46 :3 0
47 :3 0 d :3 0
16 :3 0 59 :3 0
49 :3 0 3 :4 0
5a 1 :8 0 1fd
9 :3 0 4b :3 0
1f8 1f9 0 4c
:3 0 1fa 1fb 0
1fd 110 250 4d
:3 0 9 :3 0 4b
:3 0 1ff 200 0
4c :3 0 201 202
0 204 113 206
115 205 204 :2 0
24e 4e :3 0 9
:3 0 4b :3 0 209
20a 0 4c :3 0
20b 20c 0 246
23 :3 0 24 :3 0
20e 20f 0 23
:3 0 31 :3 0 211
212 0 4f :2 0
2 :4 0 5b :2 0
33 :2 0 13 :2 0
117 217 219 :3 0
11a 213 21b 210
21d 21c :2 0 26
:3 0 34 :3 0 21f
220 0 28 :4 0
5c :4 0 2b :2 0
2c :3 0 11e 224
226 :3 0 2b :2 0
3a :4 0 121 228
22a :3 0 2b :2 0
52 :4 0 124 22c
22e :3 0 2b :2 0
4c :3 0 127 230
232 :3 0 2b :2 0
53 :4 0 12a 234
236 :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
12d 239 23d 131
238 23f :3 0 134
221 241 :2 0 243
137 244 21e 243
0 245 139 0
246 13b 249 :3 0
249 0 249 248
246 247 :6 0 24b
4 :3 0 13e 24d
140 24c 24b :2 0
24e 142 :2 0 250
0 250 24f 1fd
24e :6 0 2d4 1
:3 0 9 :3 0 4b
:3 0 252 253 0
9 :3 0 57 :2 0
58 :3 0 255 257
0 147 256 259
:3 0 25a :2 0 23
:3 0 24 :3 0 25c
25d 0 23 :3 0
31 :3 0 25f 260
0 c :2 0 2
:4 0 5d :2 0 33
:2 0 13 :2 0 14a
265 267 :3 0 14d
261 269 25e 26b
26a :2 0 26 :3 0
34 :3 0 26d 26e
0 28 :4 0 5e
:4 0 2b :2 0 2c
:3 0 151 272 274
:3 0 2b :2 0 3a
:4 0 154 276 278
:3 0 2b :2 0 3b
:4 0 157 27a 27c
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5f :3 0 281
282 0 15a 280
284 40 :4 0 15c
27f 287 15f 27e
289 :3 0 2b :2 0
60 :4 0 162 28b
28d :3 0 2b :2 0
2e :4 0 165 28f
291 :3 0 2b :2 0
3 :3 0 168 293
295 :3 0 2b :2 0
2e :4 0 16b 297
299 :3 0 16e 26f
29b :2 0 29d 171
29e 26c 29d 0
29f 173 0 2c9
23 :3 0 24 :3 0
2a0 2a1 0 23
:3 0 31 :3 0 2a3
2a4 0 13 :2 0
2 :4 0 61 :2 0
33 :2 0 13 :2 0
175 2a9 2ab :3 0
178 2a5 2ad 2a2
2af 2ae :2 0 26
:3 0 34 :3 0 2b1
2b2 0 28 :4 0
62 :4 0 2b :2 0
2c :3 0 17c 2b6
2b8 :3 0 17f 2b3
2ba :2 0 2bc 182
2bd 2b0 2bc 0
2be 184 0 2c9
43 :3 0 63 :3 0
2bf 2c0 0 3e
:3 0 5f :3 0 2c2
2c3 0 3 :3 0
45 :3 0 186 2c1
2c7 :2 0 2c9 18a
2ca 25b 2c9 0
2cb 18e 0 2d4
19 :3 0 13 :2 0
2cc 2cd 0 2d4
21 :3 0 3e :3 0
64 :3 0 2d0 2d1
0 2cf 2d2 0
2d4 190 2de 19
:3 0 18 :2 0 2d5
2d6 0 2dd 21
:3 0 3e :3 0 65
:3 0 2d9 2da 0
2d8 2db 0 2dd
195 2df 1ef 2d4
0 2e0 0 2dd
0 2e0 198 0
aab e :3 0 5
:3 0 2e1 2e2 0
aab 66 :3 0 67
:3 0 68 :3 0 e
:3 0 14 :3 0 12
:3 0 69 :3 0 66
:3 0 e :4 0 6a
1 :8 0 2f3 9
:3 0 4b :3 0 2ee
2ef 0 4c :3 0
2f0 2f1 0 2f3
19b 346 4d :3 0
9 :3 0 4b :3 0
2f5 2f6 0 4c
:3 0 2f7 2f8 0
2fa 19e 2fc 1a0
2fb 2fa :2 0 344
4e :3 0 9 :3 0
4b :3 0 2ff 300
0 4c :3 0 301
302 0 33c 23
:3 0 24 :3 0 304
305 0 23 :3 0
31 :3 0 307 308
0 4f :2 0 2
:4 0 6b :2 0 33
:2 0 13 :2 0 1a2
30d 30f :3 0 1a5
309 311 306 313
312 :2 0 26 :3 0
34 :3 0 315 316
0 28 :4 0 6c
:4 0 2b :2 0 2c
:3 0 1a9 31a 31c
:3 0 2b :2 0 3a
:4 0 1ac 31e 320
:3 0 2b :2 0 52
:4 0 1af 322 324
:3 0 2b :2 0 4c
:3 0 1b2 326 328
:3 0 2b :2 0 53
:4 0 1b5 32a 32c
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 1b8
32f 333 1bc 32e
335 :3 0 1bf 317
337 :2 0 339 1c2
33a 314 339 0
33b 1c4 0 33c
1c6 33f :3 0 33f
0 33f 33e 33c
33d :6 0 341 6
:3 0 1c9 343 1cb
342 341 :2 0 344
1cd :2 0 346 0
346 345 2f3 344
:6 0 aab 1 :3 0
9 :3 0 4b :3 0
348 349 0 9
:3 0 57 :2 0 58
:3 0 34b 34d 0
1d2 34c 34f :3 0
350 :2 0 f :3 0
6 :3 0 352 353
0 5a6 11 :3 0
54 :3 0 f :3 0
13 :2 0 c :2 0
1d5 356 35a 355
35b 0 5a6 3c
:3 0 6d :3 0 6e
:3 0 1b :3 0 69
:3 0 46 :3 0 d
:3 0 6f :3 0 11
:4 0 70 1 :8 0
36c 9 :3 0 4b
:3 0 367 368 0
4c :3 0 369 36a
0 36c 1d9 3bf
4d :3 0 9 :3 0
4b :3 0 36e 36f
0 4c :3 0 370
371 0 373 1dc
375 1de 374 373
:2 0 3bd 4e :3 0
9 :3 0 4b :3 0
378 379 0 4c
:3 0 37a 37b 0
3b5 23 :3 0 24
:3 0 37d 37e 0
23 :3 0 31 :3 0
380 381 0 4f
:2 0 2 :4 0 71
:2 0 33 :2 0 13
:2 0 1e0 386 388
:3 0 1e3 382 38a
37f 38c 38b :2 0
26 :3 0 34 :3 0
38e 38f 0 28
:4 0 72 :4 0 2b
:2 0 2c :3 0 1e7
393 395 :3 0 2b
:2 0 3a :4 0 1ea
397 399 :3 0 2b
:2 0 52 :4 0 1ed
39b 39d :3 0 2b
:2 0 4c :3 0 1f0
39f 3a1 :3 0 2b
:2 0 53 :4 0 1f3
3a3 3a5 :3 0 2b
:2 0 54 :3 0 55
:3 0 13 :2 0 56
:2 0 1f6 3a8 3ac
1fa 3a7 3ae :3 0
1fd 390 3b0 :2 0
3b2 200 3b3 38d
3b2 0 3b4 202
0 3b5 204 3b8
:3 0 3b8 0 3b8
3b7 3b5 3b6 :6 0
3ba 8 :3 0 207
3bc 209 3bb 3ba
:2 0 3bd 20b :2 0
3bf 0 3bf 3be
36c 3bd :6 0 5a6
1 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 75 :3 0
76 :3 0 77 :3 0
75 :3 0 78 :3 0
77 :3 0 75 :3 0
3d :3 0 1b :3 0
14 :3 0 79 :3 0
78 :3 0 79 :3 0
76 :3 0 78 :3 0
49 :3 0 11 :3 0
76 :3 0 49 :3 0
78 :3 0 7a :4 0
7b 1 :8 0 3e6
9 :3 0 4b :3 0
3e1 3e2 0 4c
:3 0 3e3 3e4 0
3e6 20e 439 4d
:3 0 9 :3 0 4b
:3 0 3e8 3e9 0
4c :3 0 3ea 3eb
0 3ed 211 3ef
213 3ee 3ed :2 0
437 4e :3 0 9
:3 0 4b :3 0 3f2
3f3 0 4c :3 0
3f4 3f5 0 42f
23 :3 0 24 :3 0
3f7 3f8 0 23
:3 0 31 :3 0 3fa
3fb 0 4f :2 0
2 :4 0 7c :2 0
33 :2 0 13 :2 0
215 400 402 :3 0
218 3fc 404 3f9
406 405 :2 0 26
:3 0 34 :3 0 408
409 0 28 :4 0
7d :4 0 2b :2 0
2c :3 0 21c 40d
40f :3 0 2b :2 0
3a :4 0 21f 411
413 :3 0 2b :2 0
52 :4 0 222 415
417 :3 0 2b :2 0
4c :3 0 225 419
41b :3 0 2b :2 0
53 :4 0 228 41d
41f :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
22b 422 426 22f
421 428 :3 0 232
40a 42a :2 0 42c
235 42d 407 42c
0 42e 237 0
42f 239 432 :3 0
432 0 432 431
42f 430 :6 0 434
a :3 0 23c 436
23e 435 434 :2 0
437 240 :2 0 439
0 439 438 3e6
437 :6 0 5a6 1
:3 0 9 :3 0 4b
:3 0 43b 43c 0
9 :3 0 57 :2 0
58 :3 0 43e 440
0 245 43f 442
:3 0 443 :2 0 23
:3 0 24 :3 0 445
446 0 23 :3 0
31 :3 0 448 449
0 c :2 0 2
:4 0 7e :2 0 33
:2 0 13 :2 0 248
44e 450 :3 0 24b
44a 452 447 454
453 :2 0 26 :3 0
34 :3 0 456 457
0 28 :4 0 7f
:4 0 2b :2 0 2c
:3 0 24f 45b 45d
:3 0 2b :2 0 3a
:4 0 252 45f 461
:3 0 2b :2 0 3b
:4 0 255 463 465
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5f :3 0 46a
46b 0 258 469
46d 40 :4 0 25a
468 470 25d 467
472 :3 0 2b :2 0
60 :4 0 260 474
476 :3 0 2b :2 0
2e :4 0 263 478
47a :3 0 2b :2 0
e :3 0 266 47c
47e :3 0 2b :2 0
2e :4 0 269 480
482 :3 0 26c 458
484 :2 0 486 26f
487 455 486 0
488 271 0 4b2
23 :3 0 24 :3 0
489 48a 0 23
:3 0 31 :3 0 48c
48d 0 13 :2 0
2 :4 0 80 :2 0
33 :2 0 13 :2 0
273 492 494 :3 0
276 48e 496 48b
498 497 :2 0 26
:3 0 34 :3 0 49a
49b 0 28 :4 0
81 :4 0 2b :2 0
2c :3 0 27a 49f
4a1 :3 0 27d 49c
4a3 :2 0 4a5 280
4a6 499 4a5 0
4a7 282 0 4b2
43 :3 0 63 :3 0
4a8 4a9 0 3e
:3 0 5f :3 0 4ab
4ac 0 e :3 0
45 :3 0 284 4aa
4b0 :2 0 4b2 288
4b3 444 4b2 0
4b4 28c 0 5a6
69 :3 0 66 :3 0
46 :3 0 6f :3 0
6e :3 0 67 :3 0
e :3 0 d :3 0
11 :3 0 1b :3 0
14 :4 0 82 1
:8 0 4d6 83 :4 0
4c1 :3 0 45 :3 0
57 :2 0 290 4c4
4c5 :3 0 9 :3 0
4b :3 0 4c7 4c8
0 18 :2 0 4c9
4ca 0 4cc 293
4d3 9 :3 0 4b
:3 0 4cd 4ce 0
84 :2 0 4cf 4d0
0 4d2 295 4d4
4c6 4cc 0 4d5
0 4d2 0 4d5
297 0 4d6 29a
529 4d :3 0 9
:3 0 4b :3 0 4d8
4d9 0 4c :3 0
4da 4db 0 4dd
29d 4df 29f 4de
4dd :2 0 527 4e
:3 0 9 :3 0 4b
:3 0 4e2 4e3 0
4c :3 0 4e4 4e5
0 51f 23 :3 0
24 :3 0 4e7 4e8
0 23 :3 0 31
:3 0 4ea 4eb 0
4f :2 0 2 :4 0
85 :2 0 33 :2 0
13 :2 0 2a1 4f0
4f2 :3 0 2a4 4ec
4f4 4e9 4f6 4f5
:2 0 26 :3 0 34
:3 0 4f8 4f9 0
28 :4 0 86 :4 0
2b :2 0 2c :3 0
2a8 4fd 4ff :3 0
2b :2 0 3a :4 0
2ab 501 503 :3 0
2b :2 0 52 :4 0
2ae 505 507 :3 0
2b :2 0 4c :3 0
2b1 509 50b :3 0
2b :2 0 53 :4 0
2b4 50d 50f :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 2b7 512
516 2bb 511 518
:3 0 2be 4fa 51a
:2 0 51c 2c1 51d
4f7 51c 0 51e
2c3 0 51f 2c5
522 :3 0 522 0
522 521 51f 520
:6 0 524 c :3 0
2c8 526 2ca 525
524 :2 0 527 2cc
:2 0 529 0 529
528 4d6 527 :6 0
5a6 1 :3 0 9
:3 0 4b :3 0 52b
52c 0 9 :3 0
87 :2 0 88 :3 0
52e 530 0 2d1
52f 532 :3 0 533
:2 0 23 :3 0 24
:3 0 535 536 0
23 :3 0 31 :3 0
538 539 0 c
:2 0 2 :4 0 89
:2 0 33 :2 0 13
:2 0 2d4 53e 540
:3 0 2d7 53a 542
537 544 543 :2 0
26 :3 0 34 :3 0
546 547 0 28
:4 0 8a :4 0 2b
:2 0 2c :3 0 2db
54b 54d :3 0 2b
:2 0 3a :4 0 2de
54f 551 :3 0 2b
:2 0 3b :4 0 2e1
553 555 :3 0 2b
:2 0 3c :3 0 3d
:3 0 9 :3 0 4b
:3 0 55a 55b 0
2e4 559 55d 40
:4 0 2e6 558 560
2e9 557 562 :3 0
2b :2 0 60 :4 0
2ec 564 566 :3 0
2b :2 0 2e :4 0
2ef 568 56a :3 0
2b :2 0 5 :3 0
2f2 56c 56e :3 0
2b :2 0 2e :4 0
2f5 570 572 :3 0
2f8 548 574 :2 0
576 2fb 577 545
576 0 578 2fd
0 5a2 23 :3 0
24 :3 0 579 57a
0 23 :3 0 31
:3 0 57c 57d 0
13 :2 0 2 :4 0
8b :2 0 33 :2 0
13 :2 0 2ff 582
584 :3 0 302 57e
586 57b 588 587
:2 0 26 :3 0 34
:3 0 58a 58b 0
28 :4 0 8c :4 0
2b :2 0 2c :3 0
306 58f 591 :3 0
309 58c 593 :2 0
595 30c 596 589
595 0 597 30e
0 5a2 43 :3 0
63 :3 0 598 599
0 9 :3 0 4b
:3 0 59b 59c 0
5 :3 0 45 :3 0
310 59a 5a0 :2 0
5a2 314 5a3 534
5a2 0 5a4 318
0 5a6 8d :3 0
31a 78e 9 :3 0
4b :3 0 5a7 5a8
0 9 :3 0 57
:2 0 88 :3 0 5aa
5ac 0 324 5ab
5ae :3 0 5af :2 0
8e :3 0 3c :3 0
16 :3 0 18 :2 0
327 5b2 5b5 32a
5b1 5b7 87 :2 0
18 :2 0 32e 5b9
5bb :3 0 8f :3 0
90 :3 0 b :3 0
91 :3 0 8f :3 0
8f :3 0 49 :3 0
3 :3 0 8f :3 0
92 :3 0 5 :3 0
8f :3 0 93 :4 0
94 1 :8 0 5d0
9 :3 0 4b :3 0
5cb 5cc 0 4c
:3 0 5cd 5ce 0
5d0 331 623 4d
:3 0 9 :3 0 4b
:3 0 5d2 5d3 0
4c :3 0 5d4 5d5
0 5d7 334 5d9
336 5d8 5d7 :2 0
621 4e :3 0 9
:3 0 4b :3 0 5dc
5dd 0 4c :3 0
5de 5df 0 619
23 :3 0 24 :3 0
5e1 5e2 0 23
:3 0 31 :3 0 5e4
5e5 0 4f :2 0
2 :4 0 95 :2 0
33 :2 0 13 :2 0
338 5ea 5ec :3 0
33b 5e6 5ee 5e3
5f0 5ef :2 0 26
:3 0 34 :3 0 5f2
5f3 0 28 :4 0
96 :4 0 2b :2 0
2c :3 0 33f 5f7
5f9 :3 0 2b :2 0
3a :4 0 342 5fb
5fd :3 0 2b :2 0
52 :4 0 345 5ff
601 :3 0 2b :2 0
4c :3 0 348 603
605 :3 0 2b :2 0
53 :4 0 34b 607
609 :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
34e 60c 610 352
60b 612 :3 0 355
5f4 614 :2 0 616
358 617 5f1 616
0 618 35a 0
619 35c 61c :3 0
61c 0 61c 61b
619 61a :6 0 61e
e :3 0 35f 620
361 61f 61e :2 0
621 363 :2 0 623
0 623 622 5d0
621 :6 0 69f 1
:3 0 9 :3 0 4b
:3 0 625 626 0
9 :3 0 57 :2 0
88 :3 0 628 62a
0 368 629 62c
:3 0 62d :2 0 23
:3 0 24 :3 0 62f
630 0 23 :3 0
31 :3 0 632 633
0 c :2 0 2
:4 0 97 :2 0 33
:2 0 13 :2 0 36b
638 63a :3 0 36e
634 63c 631 63e
63d :2 0 26 :3 0
34 :3 0 640 641
0 28 :4 0 98
:4 0 2b :2 0 2c
:3 0 372 645 647
:3 0 2b :2 0 3a
:4 0 375 649 64b
:3 0 2b :2 0 3b
:4 0 378 64d 64f
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 99 :3 0 654
655 0 37b 653
657 40 :4 0 37d
652 65a 380 651
65c :3 0 2b :2 0
60 :4 0 383 65e
660 :3 0 2b :2 0
2e :4 0 386 662
664 :3 0 2b :2 0
5 :3 0 389 666
668 :3 0 2b :2 0
2e :4 0 38c 66a
66c :3 0 38f 642
66e :2 0 670 392
671 63f 670 0
672 394 0 69c
23 :3 0 24 :3 0
673 674 0 23
:3 0 31 :3 0 676
677 0 13 :2 0
2 :4 0 9a :2 0
33 :2 0 13 :2 0
396 67c 67e :3 0
399 678 680 675
682 681 :2 0 26
:3 0 34 :3 0 684
685 0 28 :4 0
9b :4 0 2b :2 0
2c :3 0 39d 689
68b :3 0 3a0 686
68d :2 0 68f 3a3
690 683 68f 0
691 3a5 0 69c
43 :3 0 63 :3 0
692 693 0 3e
:3 0 99 :3 0 695
696 0 5 :3 0
45 :3 0 3a7 694
69a :2 0 69c 3ab
69d 62e 69c 0
69e 3af 0 69f
3b1 6a0 5bc 69f
0 6a1 3b4 0
71e 54 :3 0 12
:3 0 13 :2 0 13
:2 0 3b6 6a2 6a6
57 :2 0 9c :4 0
3bc 6a8 6aa :3 0
69 :3 0 68 :3 0
66 :3 0 e :4 0
9d 1 :8 0 6c6
83 :4 0 6b1 :3 0
45 :3 0 57 :2 0
3c1 6b4 6b5 :3 0
9 :3 0 4b :3 0
6b7 6b8 0 18
:2 0 6b9 6ba 0
6bc 3c4 6c3 9
:3 0 4b :3 0 6bd
6be 0 84 :2 0
6bf 6c0 0 6c2
3c6 6c4 6b6 6bc
0 6c5 0 6c2
0 6c5 3c8 0
6c6 3cb 719 4d
:3 0 9 :3 0 4b
:3 0 6c8 6c9 0
4c :3 0 6ca 6cb
0 6cd 3ce 6cf
3d0 6ce 6cd :2 0
717 4e :3 0 9
:3 0 4b :3 0 6d2
6d3 0 4c :3 0
6d4 6d5 0 70f
23 :3 0 24 :3 0
6d7 6d8 0 23
:3 0 31 :3 0 6da
6db 0 4f :2 0
2 :4 0 9e :2 0
33 :2 0 13 :2 0
3d2 6e0 6e2 :3 0
3d5 6dc 6e4 6d9
6e6 6e5 :2 0 26
:3 0 34 :3 0 6e8
6e9 0 28 :4 0
9f :4 0 2b :2 0
2c :3 0 3d9 6ed
6ef :3 0 2b :2 0
3a :4 0 3dc 6f1
6f3 :3 0 2b :2 0
52 :4 0 3df 6f5
6f7 :3 0 2b :2 0
4c :3 0 3e2 6f9
6fb :3 0 2b :2 0
53 :4 0 3e5 6fd
6ff :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
3e8 702 706 3ec
701 708 :3 0 3ef
6ea 70a :2 0 70c
3f2 70d 6e7 70c
0 70e 3f4 0
70f 3f6 712 :3 0
712 0 712 711
70f 710 :6 0 714
10 :3 0 3f9 716
3fb 715 714 :2 0
717 3fd :2 0 719
0 719 718 6c6
717 :6 0 71b 1
:3 0 400 71c 6ab
71b 0 71d 402
0 71e 404 71f
5b0 71e 0 790
23 :3 0 24 :3 0
720 721 0 23
:3 0 31 :3 0 723
724 0 c :2 0
2 :4 0 a0 :2 0
33 :2 0 13 :2 0
407 729 72b :3 0
40a 725 72d 722
72f 72e :2 0 26
:3 0 34 :3 0 731
732 0 28 :4 0
a1 :4 0 2b :2 0
2c :3 0 40e 736
738 :3 0 2b :2 0
3a :4 0 411 73a
73c :3 0 2b :2 0
3b :4 0 414 73e
740 :3 0 2b :2 0
3c :3 0 3d :3 0
3e :3 0 5f :3 0
745 746 0 417
744 748 40 :4 0
419 743 74b 41c
742 74d :3 0 2b
:2 0 60 :4 0 41f
74f 751 :3 0 2b
:2 0 2e :4 0 422
753 755 :3 0 2b
:2 0 5 :3 0 425
757 759 :3 0 2b
:2 0 2e :4 0 428
75b 75d :3 0 42b
733 75f :2 0 761
42e 762 730 761
0 763 430 0
78d 23 :3 0 24
:3 0 764 765 0
23 :3 0 31 :3 0
767 768 0 13
:2 0 2 :4 0 a2
:2 0 33 :2 0 13
:2 0 432 76d 76f
:3 0 435 769 771
766 773 772 :2 0
26 :3 0 34 :3 0
775 776 0 28
:4 0 a3 :4 0 2b
:2 0 2c :3 0 439
77a 77c :3 0 43c
777 77e :2 0 780
43f 781 774 780
0 782 441 0
78d 43 :3 0 63
:3 0 783 784 0
3e :3 0 5f :3 0
786 787 0 5
:3 0 45 :3 0 443
785 78b :2 0 78d
447 78f 351 5a6
0 790 0 78d
0 790 44b 0
aab 1a :3 0 18
:2 0 791 792 0
aab 90 :3 0 b
:3 0 91 :3 0 49
:3 0 3 :3 0 92
:3 0 e :3 0 93
:4 0 a4 1 :8 0
7a2 9 :3 0 4b
:3 0 79d 79e 0
4c :3 0 79f 7a0
0 7a2 44f 7f5
4d :3 0 9 :3 0
4b :3 0 7a4 7a5
0 4c :3 0 7a6
7a7 0 7a9 452
7ab 454 7aa 7a9
:2 0 7f3 4e :3 0
9 :3 0 4b :3 0
7ae 7af 0 4c
:3 0 7b0 7b1 0
7eb 23 :3 0 24
:3 0 7b3 7b4 0
23 :3 0 31 :3 0
7b6 7b7 0 4f
:2 0 2 :4 0 a5
:2 0 33 :2 0 13
:2 0 456 7bc 7be
:3 0 459 7b8 7c0
7b5 7c2 7c1 :2 0
26 :3 0 34 :3 0
7c4 7c5 0 28
:4 0 a6 :4 0 2b
:2 0 2c :3 0 45d
7c9 7cb :3 0 2b
:2 0 3a :4 0 460
7cd 7cf :3 0 2b
:2 0 52 :4 0 463
7d1 7d3 :3 0 2b
:2 0 4c :3 0 466
7d5 7d7 :3 0 2b
:2 0 53 :4 0 469
7d9 7db :3 0 2b
:2 0 54 :3 0 55
:3 0 13 :2 0 56
:2 0 46c 7de 7e2
470 7dd 7e4 :3 0
473 7c6 7e6 :2 0
7e8 476 7e9 7c3
7e8 0 7ea 478
0 7eb 47a 7ee
:3 0 7ee 0 7ee
7ed 7eb 7ec :6 0
7f0 12 :3 0 47d
7f2 47f 7f1 7f0
:2 0 7f3 481 :2 0
7f5 0 7f5 7f4
7a2 7f3 :6 0 aab
1 :3 0 9 :3 0
4b :3 0 7f7 7f8
0 9 :3 0 57
:2 0 58 :3 0 7fa
7fc 0 486 7fb
7fe :3 0 7ff :2 0
3c :3 0 19 :3 0
18 :2 0 489 801
804 57 :2 0 18
:2 0 48e 806 808
:3 0 48 :3 0 a7
:3 0 a8 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a9 :3 0 14
:3 0 a9 :3 0 a7
:3 0 a7 :3 0 a7
:3 0 14 :3 0 49
:3 0 3 :4 0 aa
1 :8 0 82f 83
:4 0 81a :3 0 45
:3 0 57 :2 0 493
81d 81e :3 0 9
:3 0 4b :3 0 820
821 0 18 :2 0
822 823 0 825
496 82c 9 :3 0
4b :3 0 826 827
0 84 :2 0 828
829 0 82b 498
82d 81f 825 0
82e 0 82b 0
82e 49a 0 82f
49d 882 4d :3 0
9 :3 0 4b :3 0
831 832 0 4c
:3 0 833 834 0
836 4a0 838 4a2
837 836 :2 0 880
4e :3 0 9 :3 0
4b :3 0 83b 83c
0 4c :3 0 83d
83e 0 878 23
:3 0 24 :3 0 840
841 0 23 :3 0
31 :3 0 843 844
0 4f :2 0 2
:4 0 ab :2 0 33
:2 0 13 :2 0 4a4
849 84b :3 0 4a7
845 84d 842 84f
84e :2 0 26 :3 0
34 :3 0 851 852
0 28 :4 0 ac
:4 0 2b :2 0 2c
:3 0 4ab 856 858
:3 0 2b :2 0 3a
:4 0 4ae 85a 85c
:3 0 2b :2 0 52
:4 0 4b1 85e 860
:3 0 2b :2 0 4c
:3 0 4b4 862 864
:3 0 2b :2 0 53
:4 0 4b7 866 868
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 4ba
86b 86f 4be 86a
871 :3 0 4c1 853
873 :2 0 875 4c4
876 850 875 0
877 4c6 0 878
4c8 87b :3 0 87b
0 87b 87a 878
879 :6 0 87d 14
:3 0 4cb 87f 4cd
87e 87d :2 0 880
4cf :2 0 882 0
882 881 82f 880
:6 0 885 1 :3 0
8d :3 0 4d2 90b
3c :3 0 19 :3 0
18 :2 0 4d4 886
889 57 :2 0 13
:2 0 4d9 88b 88d
:3 0 59 :3 0 a7
:3 0 a8 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a9 :3 0 14
:3 0 a9 :3 0 a7
:3 0 a7 :3 0 a7
:3 0 14 :3 0 49
:3 0 3 :4 0 ad
1 :8 0 8b4 83
:4 0 89f :3 0 45
:3 0 57 :2 0 4de
8a2 8a3 :3 0 9
:3 0 4b :3 0 8a5
8a6 0 18 :2 0
8a7 8a8 0 8aa
4e1 8b1 9 :3 0
4b :3 0 8ab 8ac
0 84 :2 0 8ad
8ae 0 8b0 4e3
8b2 8a4 8aa 0
8b3 0 8b0 0
8b3 4e5 0 8b4
4e8 907 4d :3 0
9 :3 0 4b :3 0
8b6 8b7 0 4c
:3 0 8b8 8b9 0
8bb 4eb 8bd 4ed
8bc 8bb :2 0 905
4e :3 0 9 :3 0
4b :3 0 8c0 8c1
0 4c :3 0 8c2
8c3 0 8fd 23
:3 0 24 :3 0 8c5
8c6 0 23 :3 0
31 :3 0 8c8 8c9
0 4f :2 0 2
:4 0 ae :2 0 33
:2 0 13 :2 0 4ef
8ce 8d0 :3 0 4f2
8ca 8d2 8c7 8d4
8d3 :2 0 26 :3 0
34 :3 0 8d6 8d7
0 28 :4 0 af
:4 0 2b :2 0 2c
:3 0 4f6 8db 8dd
:3 0 2b :2 0 3a
:4 0 4f9 8df 8e1
:3 0 2b :2 0 52
:4 0 4fc 8e3 8e5
:3 0 2b :2 0 4c
:3 0 4ff 8e7 8e9
:3 0 2b :2 0 53
:4 0 502 8eb 8ed
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 505
8f0 8f4 509 8ef
8f6 :3 0 50c 8d8
8f8 :2 0 8fa 50f
8fb 8d5 8fa 0
8fc 511 0 8fd
513 900 :3 0 900
0 900 8ff 8fd
8fe :6 0 902 16
:3 0 516 904 518
903 902 :2 0 905
51a :2 0 907 0
907 906 8b4 905
:6 0 909 1 :3 0
51d 90a 88e 909
0 90c 809 885
0 90c 51f 0
9d4 b :3 0 b0
:4 0 90e 90f :3 0
90d 910 0 9d4
20 :3 0 b1 :3 0
3c :3 0 21 :3 0
18 :2 0 522 914
917 3c :3 0 16
:3 0 18 :2 0 525
919 91c 3e :3 0
b2 :3 0 91e 91f
0 1d :3 0 528
913 922 912 923
0 9d4 b3 :3 0
3c :3 0 16 :3 0
18 :2 0 52d 926
929 530 925 92b
87 :2 0 18 :2 0
534 92d 92f :3 0
1c :3 0 3e :3 0
b4 :3 0 932 933
0 931 934 0
936 537 93d 1c
:3 0 3e :3 0 b5
:3 0 938 939 0
937 93a 0 93c
539 93e 930 936
0 93f 0 93c
0 93f 53b 0
9d4 1f :3 0 13
:4 0 940 941 0
9d4 1e :3 0 13
:2 0 943 944 0
9d4 20 :3 0 b6
:3 0 d :3 0 e
:3 0 16 :3 0 1c
:3 0 1d :3 0 1f
:3 0 1e :3 0 53e
947 94f 946 950
0 9d4 91 :3 0
90 :3 0 46 :3 0
49 :3 0 b7 :3 0
93 :3 0 92 :3 0
b8 :3 0 b9 :3 0
ba :3 0 bb :3 0
bc :3 0 b :3 0
d :3 0 3 :3 0
16 :3 0 e :3 0
1c :3 0 1d :3 0
7 :3 0 2c :3 0
21 :4 0 bd 1
:8 0 97e 83 :4 0
969 :3 0 45 :3 0
57 :2 0 548 96c
96d :3 0 9 :3 0
4b :3 0 96f 970
0 18 :2 0 971
972 0 974 54b
97b 9 :3 0 4b
:3 0 975 976 0
84 :2 0 977 978
0 97a 54d 97c
96e 974 0 97d
0 97a 0 97d
54f 0 97e 552
9d1 4d :3 0 9
:3 0 4b :3 0 980
981 0 4c :3 0
982 983 0 985
555 987 557 986
985 :2 0 9cf 4e
:3 0 9 :3 0 4b
:3 0 98a 98b 0
4c :3 0 98c 98d
0 9c7 23 :3 0
24 :3 0 98f 990
0 23 :3 0 31
:3 0 992 993 0
4f :2 0 2 :4 0
be :2 0 33 :2 0
13 :2 0 559 998
99a :3 0 55c 994
99c 991 99e 99d
:2 0 26 :3 0 34
:3 0 9a0 9a1 0
28 :4 0 bf :4 0
2b :2 0 2c :3 0
560 9a5 9a7 :3 0
2b :2 0 3a :4 0
563 9a9 9ab :3 0
2b :2 0 52 :4 0
566 9ad 9af :3 0
2b :2 0 4c :3 0
569 9b1 9b3 :3 0
2b :2 0 53 :4 0
56c 9b5 9b7 :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 56f 9ba
9be 573 9b9 9c0
:3 0 576 9a2 9c2
:2 0 9c4 579 9c5
99f 9c4 0 9c6
57b 0 9c7 57d
9ca :3 0 9ca 0
9ca 9c9 9c7 9c8
:6 0 9cc 18 :3 0
580 9ce 582 9cd
9cc :2 0 9cf 584
:2 0 9d1 0 9d1
9d0 97e 9cf :6 0
9d4 1 :3 0 8d
:3 0 587 a5b 9
:3 0 4b :3 0 9d5
9d6 0 9 :3 0
57 :2 0 88 :3 0
9d8 9da 0 592
9d9 9dc :3 0 9dd
:2 0 91 :3 0 b8
:3 0 c0 :3 0 c1
:3 0 b8 :3 0 3e
:3 0 b5 :3 0 90
:3 0 b :4 0 c2
1 :8 0 9fe 83
:4 0 9e9 :3 0 45
:3 0 57 :2 0 597
9ec 9ed :3 0 9
:3 0 4b :3 0 9ef
9f0 0 18 :2 0
9f1 9f2 0 9f4
59a 9fb 9 :3 0
4b :3 0 9f5 9f6
0 84 :2 0 9f7
9f8 0 9fa 59c
9fc 9ee 9f4 0
9fd 0 9fa 0
9fd 59e 0 9fe
5a1 a51 4d :3 0
9 :3 0 4b :3 0
a00 a01 0 4c
:3 0 a02 a03 0
a05 5a4 a07 5a6
a06 a05 :2 0 a4f
4e :3 0 9 :3 0
4b :3 0 a0a a0b
0 4c :3 0 a0c
a0d 0 a47 23
:3 0 24 :3 0 a0f
a10 0 23 :3 0
31 :3 0 a12 a13
0 4f :2 0 2
:4 0 c3 :2 0 33
:2 0 13 :2 0 5a8
a18 a1a :3 0 5ab
a14 a1c a11 a1e
a1d :2 0 26 :3 0
34 :3 0 a20 a21
0 28 :4 0 c4
:4 0 2b :2 0 2c
:3 0 5af a25 a27
:3 0 2b :2 0 3a
:4 0 5b2 a29 a2b
:3 0 2b :2 0 52
:4 0 5b5 a2d a2f
:3 0 2b :2 0 4c
:3 0 5b8 a31 a33
:3 0 2b :2 0 53
:4 0 5bb a35 a37
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 5be
a3a a3e 5c2 a39
a40 :3 0 5c5 a22
a42 :2 0 a44 5c8
a45 a1f a44 0
a46 5ca 0 a47
5cc a4a :3 0 a4a
0 a4a a49 a47
a48 :6 0 a4c 1a
:3 0 5cf a4e 5d1
a4d a4c :2 0 a4f
5d3 :2 0 a51 0
a51 a50 9fe a4f
:6 0 a59 1 :3 0
20 :3 0 c5 :3 0
b :3 0 5d6 a54
a56 a53 a57 0
a59 5d8 a5a 9de
a59 0 a5c 800
9d4 0 a5c 5db
0 aab 23 :3 0
24 :3 0 a5d a5e
0 23 :3 0 31
:3 0 a60 a61 0
c6 :2 0 2 :4 0
c7 :2 0 33 :2 0
13 :2 0 5de a66
a68 :3 0 5e1 a62
a6a a5f a6c a6b
:2 0 26 :3 0 34
:3 0 a6e a6f 0
28 :4 0 c8 :4 0
2b :2 0 2c :3 0
5e5 a73 a75 :3 0
2b :2 0 3a :4 0
5e8 a77 a79 :3 0
2b :2 0 3b :4 0
5eb a7b a7d :3 0
2b :2 0 3c :3 0
3d :3 0 9 :3 0
4b :3 0 a82 a83
0 5ee a81 a85
40 :4 0 5f0 a80
a88 5f3 a7f a8a
:3 0 2b :2 0 60
:4 0 5f6 a8c a8e
:3 0 2b :2 0 2e
:4 0 5f9 a90 a92
:3 0 2b :2 0 b
:3 0 5fc a94 a96
:3 0 2b :2 0 2e
:4 0 5ff a98 a9a
:3 0 602 a70 a9c
:2 0 a9e 605 a9f
a6d a9e 0 aa0
607 0 aab 43
:3 0 c9 :3 0 aa1
aa2 0 9 :3 0
4b :3 0 aa4 aa5
0 b :3 0 45
:3 0 609 aa3 aa9
:2 0 aab 60d b4c
9 :3 0 ca :2 0
4 aac aad 0
23 :3 0 24 :3 0
aaf ab0 0 23
:3 0 31 :3 0 ab2
ab3 0 4f :2 0
2 :4 0 cb :2 0
33 :2 0 13 :2 0
61b ab8 aba :3 0
61e ab4 abc ab1
abe abd :2 0 26
:3 0 34 :3 0 ac0
ac1 0 28 :4 0
cc :4 0 2b :2 0
2c :3 0 622 ac5
ac7 :3 0 625 ac2
ac9 :2 0 ae2 26
:3 0 34 :3 0 acb
acc 0 28 :4 0
cd :4 0 2b :2 0
9 :3 0 ce :3 0
ad1 ad2 0 628
ad0 ad4 :3 0 2b
:2 0 60 :4 0 62b
ad6 ad8 :3 0 2b
:2 0 9 :3 0 cf
:3 0 adb adc 0
62e ada ade :3 0
631 acd ae0 :2 0
ae2 634 ae3 abf
ae2 0 ae4 637
0 af4 d0 :3 0
22 :3 0 9 :3 0
ce :3 0 d1 :3 0
9 :3 0 cf :3 0
d2 :3 0 d3 :4 0
d4 1 :a 0 af0
:2 0 af4 ae6 aee
:2 0 8 :3 0 22
:3 0 af2 :2 0 af4
639 af6 63d af5
af4 :2 0 b4a 4e
:3 0 9 :3 0 4b
:3 0 af9 afa 0
4c :3 0 afb afc
0 b42 23 :3 0
24 :3 0 afe aff
0 23 :3 0 31
:3 0 b01 b02 0
4f :2 0 2 :4 0
d5 :2 0 33 :2 0
13 :2 0 63f b07
b09 :3 0 642 b03
b0b b00 b0d b0c
:2 0 26 :3 0 34
:3 0 b0f b10 0
28 :4 0 d6 :4 0
2b :2 0 2c :3 0
646 b14 b16 :3 0
649 b11 b18 :2 0
b32 26 :3 0 34
:3 0 b1a b1b 0
28 :4 0 52 :4 0
2b :2 0 4c :3 0
64c b1f b21 :3 0
2b :2 0 53 :4 0
64f b23 b25 :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 652 b28
b2c 656 b27 b2e
:3 0 659 b1c b30
:2 0 b32 65c b33
b0e b32 0 b34
65f 0 b42 d0
:3 0 22 :3 0 d1
:3 0 9 :3 0 cf
:3 0 d2 :3 0 d3
:4 0 d7 1 :a 0
b3e :2 0 b42 b36
b3c :2 0 8 :3 0
22 :3 0 b40 :2 0
b42 661 b45 :3 0
b45 0 b45 b44
b42 b43 :6 0 b47
1 :3 0 666 b49
668 b48 b47 :2 0
b4a 66a :2 0 b4c
66d b4c b4b aab
b4a :6 0 b4d :2 0
2 18 b4c b50
:3 0 b4f b4d b51
:8 0 
680
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 38
1 36 1 3f
1 3d 1 46
1 44 1 4b
1 51 1 57
1 5d 1 63
1 6b 1 69
1 70 1 78
1 76 1 7d
1 83 1 89
1 96 1 a2
2 a5 a7 2
aa ac 2 ae
b0 2 b2 b4
2 b6 b8 2
ba bc 2 be
c0 2 c2 c4
2 c6 c8 2
ca cc 2 ce
d0 2 d2 d4
2 d6 d8 2
da dc 2 de
e0 2 e2 e4
2 e6 e8 4
9e a4 a9 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 1 10f 1
115 1 11d 2
12d 12f 3 12b
12c 131 2 13a
13c 2 13e 140
2 142 144 1
14c 2 14e 14f
2 146 151 2
139 153 1 155
1 157 2 161
163 3 15f 160
165 2 16e 170
2 16d 172 1
174 1 176 2
17d 17e 3 158
177 180 1 182
2 18b 190 1
197 1 192 2
1aa 1ac 3 1a8
1a9 1ae 2 1b7
1b9 2 1bb 1bd
2 1bf 1c1 2
1c3 1c5 2 1c7
1c9 3 1ce 1cf
1d0 2 1cb 1d2
2 1b6 1d4 1
1d6 1 1d8 2
1a1 1d9 1 1dd
1 19c 2 19a
1e1 1 1ec 2
1e8 1ec 2 1f7
1fc 1 203 1
1fe 2 216 218
3 214 215 21a
2 223 225 2
227 229 2 22b
22d 2 22f 231
2 233 235 3
23a 23b 23c 2
237 23e 2 222
240 1 242 1
244 2 20d 245
1 249 1 208
2 206 24d 1
258 2 254 258
2 264 266 3
262 263 268 2
271 273 2 275
277 2 279 27b
1 283 2 285
286 2 27d 288
2 28a 28c 2
28e 290 2 292
294 2 296 298
2 270 29a 1
29c 1 29e 2
2a8 2aa 3 2a6
2a7 2ac 2 2b5
2b7 2 2b4 2b9
1 2bb 1 2bd
3 2c4 2c5 2c6
3 29f 2be 2c8
1 2ca 4 250
2cb 2ce 2d3 2
2d7 2dc 2 2de
2df 2 2ed 2f2
1 2f9 1 2f4
2 30c 30e 3
30a 30b 310 2
319 31b 2 31d
31f 2 321 323
2 325 327 2
329 32b 3 330
331 332 2 32d
334 2 318 336
1 338 1 33a
2 303 33b 1
33f 1 2fe 2
2fc 343 1 34e
2 34a 34e 3
357 358 359 2
366 36b 1 372
1 36d 2 385
387 3 383 384
389 2 392 394
2 396 398 2
39a 39c 2 39e
3a0 2 3a2 3a4
3 3a9 3aa 3ab
2 3a6 3ad 2
391 3af 1 3b1
1 3b3 2 37c
3b4 1 3b8 1
377 2 375 3bc
2 3e0 3e5 1
3ec 1 3e7 2
3ff 401 3 3fd
3fe 403 2 40c
40e 2 410 412
2 414 416 2
418 41a 2 41c
41e 3 423 424
425 2 420 427
2 40b 429 1
42b 1 42d 2
3f6 42e 1 432
1 3f1 2 3ef
436 1 441 2
43d 441 2 44d
44f 3 44b 44c
451 2 45a 45c
2 45e 460 2
462 464 1 46c
2 46e 46f 2
466 471 2 473
475 2 477 479
2 47b 47d 2
47f 481 2 459
483 1 485 1
487 2 491 493
3 48f 490 495
2 49e 4a0 2
49d 4a2 1 4a4
1 4a6 3 4ad
4ae 4af 3 488
4a7 4b1 1 4b3
1 4c3 2 4c2
4c3 1 4cb 1
4d1 2 4d3 4d4
2 4c0 4d5 1
4dc 1 4d7 2
4ef 4f1 3 4ed
4ee 4f3 2 4fc
4fe 2 500 502
2 504 506 2
508 50a 2 50c
50e 3 513 514
515 2 510 517
2 4fb 519 1
51b 1 51d 2
4e6 51e 1 522
1 4e1 2 4df
526 1 531 2
52d 531 2 53d
53f 3 53b 53c
541 2 54a 54c
2 54e 550 2
552 554 1 55c
2 55e 55f 2
556 561 2 563
565 2 567 569
2 56b 56d 2
56f 571 2 549
573 1 575 1
577 2 581 583
3 57f 580 585
2 58e 590 2
58d 592 1 594
1 596 3 59d
59e 59f 3 578
597 5a1 1 5a3
7 354 35c 3bf
439 4b4 529 5a4
1 5ad 2 5a9
5ad 2 5b3 5b4
1 5b6 1 5ba
2 5b8 5ba 2
5ca 5cf 1 5d6
1 5d1 2 5e9
5eb 3 5e7 5e8
5ed 2 5f6 5f8
2 5fa 5fc 2
5fe 600 2 602
604 2 606 608
3 60d 60e 60f
2 60a 611 2
5f5 613 1 615
1 617 2 5e0
618 1 61c 1
5db 2 5d9 620
1 62b 2 627
62b 2 637 639
3 635 636 63b
2 644 646 2
648 64a 2 64c
64e 1 656 2
658 659 2 650
65b 2 65d 65f
2 661 663 2
665 667 2 669
66b 2 643 66d
1 66f 1 671
2 67b 67d 3
679 67a 67f 2
688 68a 2 687
68c 1 68e 1
690 3 697 698
699 3 672 691
69b 1 69d 2
623 69e 1 6a0
3 6a3 6a4 6a5
1 6a9 2 6a7
6a9 1 6b3 2
6b2 6b3 1 6bb
1 6c1 2 6c3
6c4 2 6b0 6c5
1 6cc 1 6c7
2 6df 6e1 3
6dd 6de 6e3 2
6ec 6ee 2 6f0
6f2 2 6f4 6f6
2 6f8 6fa 2
6fc 6fe 3 703
704 705 2 700
707 2 6eb 709
1 70b 1 70d
2 6d6 70e 1
712 1 6d1 2
6cf 716 1 719
1 71c 2 6a1
71d 2 728 72a
3 726 727 72c
2 735 737 2
739 73b 2 73d
73f 1 747 2
749 74a 2 741
74c 2 74e 750
2 752 754 2
756 758 2 75a
75c 2 734 75e
1 760 1 762
2 76c 76e 3
76a 76b 770 2
779 77b 2 778
77d 1 77f 1
781 3 788 789
78a 3 763 782
78c 3 78e 71f
78f 2 79c 7a1
1 7a8 1 7a3
2 7bb 7bd 3
7b9 7ba 7bf 2
7c8 7ca 2 7cc
7ce 2 7d0 7d2
2 7d4 7d6 2
7d8 7da 3 7df
7e0 7e1 2 7dc
7e3 2 7c7 7e5
1 7e7 1 7e9
2 7b2 7ea 1
7ee 1 7ad 2
7ab 7f2 1 7fd
2 7f9 7fd 2
802 803 1 807
2 805 807 1
81c 2 81b 81c
1 824 1 82a
2 82c 82d 2
819 82e 1 835
1 830 2 848
84a 3 846 847
84c 2 855 857
2 859 85b 2
85d 85f 2 861
863 2 865 867
3 86c 86d 86e
2 869 870 2
854 872 1 874
1 876 2 83f
877 1 87b 1
83a 2 838 87f
1 882 2 887
888 1 88c 2
88a 88c 1 8a1
2 8a0 8a1 1
8a9 1 8af 2
8b1 8b2 2 89e
8b3 1 8ba 1
8b5 2 8cd 8cf
3 8cb 8cc 8d1
2 8da 8dc 2
8de 8e0 2 8e2
8e4 2 8e6 8e8
2 8ea 8ec 3
8f1 8f2 8f3 2
8ee 8f5 2 8d9
8f7 1 8f9 1
8fb 2 8c4 8fc
1 900 1 8bf
2 8bd 904 1
907 2 90b 90a
2 915 916 2
91a 91b 4 918
91d 920 921 2
927 928 1 92a
1 92e 2 92c
92e 1 935 1
93b 2 93d 93e
7 948 949 94a
94b 94c 94d 94e
1 96b 2 96a
96b 1 973 1
979 2 97b 97c
2 968 97d 1
984 1 97f 2
997 999 3 995
996 99b 2 9a4
9a6 2 9a8 9aa
2 9ac 9ae 2
9b0 9b2 2 9b4
9b6 3 9bb 9bc
9bd 2 9b8 9bf
2 9a3 9c1 1
9c3 1 9c5 2
98e 9c6 1 9ca
1 989 2 987
9ce 8 90c 911
924 93f 942 945
951 9d1 1 9db
2 9d7 9db 1
9eb 2 9ea 9eb
1 9f3 1 9f9
2 9fb 9fc 2
9e8 9fd 1 a04
1 9ff 2 a17
a19 3 a15 a16
a1b 2 a24 a26
2 a28 a2a 2
a2c a2e 2 a30
a32 2 a34 a36
3 a3b a3c a3d
2 a38 a3f 2
a23 a41 1 a43
1 a45 2 a0e
a46 1 a4a 1
a09 2 a07 a4e
1 a55 2 a51
a58 2 a5b a5a
2 a65 a67 3
a63 a64 a69 2
a72 a74 2 a76
a78 2 a7a a7c
1 a84 2 a86
a87 2 a7e a89
2 a8b a8d 2
a8f a91 2 a93
a95 2 a97 a99
2 a71 a9b 1
a9d 1 a9f 3
aa6 aa7 aa8 d
ef 10e 183 1e4
2e0 2e3 346 790
793 7f5 a5c aa0
aaa 2 ab7 ab9
3 ab5 ab6 abb
2 ac4 ac6 2
ac3 ac8 2 acf
ad3 2 ad5 ad7
2 ad9 add 2
ace adf 2 aca
ae1 1 ae3 3
ae4 aef af3 1
aae 2 b06 b08
3 b04 b05 b0a
2 b13 b15 2
b12 b17 2 b1e
b20 2 b22 b24
3 b29 b2a b2b
2 b26 b2d 2
b1d b2f 2 b19
b31 1 b33 4
afd b34 b3d b41
1 b45 1 af8
2 af6 b49 12
1f 26 2d 34
3b 42 49 4f
55 5b 61 67
6e 74 7b 81
87 8e 
1
4
0 
b50
0
1
28
1c
17
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

f 1 0
63 1 0
51 1 0
69 1 0
7 1 0
36 1 0
76 1 0
7d 1 0
b 1 0
3d 1 0
5d 1 0
2f 1 0
1a 1 0
57 1 0
3 1 0
70 1 0
2 0 1
83 1 0
4b 1 0
28 1 0
21 1 0
44 1 0
89 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKPROF;
ALTER FUNCTION SP_A_TSKPROF COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKRES ==
CREATE OR REPLACE FUNCTION SP_A_TSKRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
61
2 :e:
1FUNCTION:
1SP_A_TSKRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_PROJECT_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
126:
1+:
1FPUT:
1               ENTER:: SP_A_TSKRES(27) :: cplan.sql(6627) :: :
1IS NULL:
18:
131:
1      RETURN_INVALID:: SP_A_TSKRES(32) :: cplan.sql(6632) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
134:
1                EXIT:: SP_A_TSKRES(35) :: cplan.sql(6635) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_WBS:
1TYPE_ID:
1PROJECT_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID, PROJECT_ID INTO h_type_id, h_project_id:n      FROM TMT_WBS W+
1HERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
157:
1           EXCEPTION:: SP_A_TSKRES(58) :: cplan.sql(6658) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
1=:
1RECORD_ALREADY_ASSIGNED:
14:
172:
1       RETURN_STATUS:: SP_A_TSKRES(73) :: cplan.sql(6673) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
179:
1           EXCEPTION:: SP_A_TSKRES(80) :: cplan.sql(6680) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
191:
1           EXCEPTION:: SP_A_TSKRES(92) :: cplan.sql(6692) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2bc
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :3 a0 6b d :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 b4
2e d :8 a0 a5 b d :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
2bc
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 116 105 109 e4 111 104 132
121 125 101 12d 120 14e 13d 141
11d 149 13c 16e 159 15d 139 161
169 158 175 179 155 17d 181 185
188 18d 18e 1 190 195 199 19d
1a0 1a5 1a9 1ad 1b0 1b5 1b6 1b8
1bd 1c0 1c4 1c5 1ca 1cf 1d2 1d7
1d8 1dd 1e0 1e4 1e5 1ea 1ed 1f2
1f3 1f8 1fb 200 201 206 209 20e
20f 214 217 21b 21c 221 224 229
22a 22f 232 237 238 23d 240 245
246 24b 24e 252 253 258 25b 260
261 266 269 26e 26f 274 275 27a
27c 280 283 287 28b 28e 292 296
299 29c 2a1 2a4 2a7 2aa 2ab 2b0
2b1 1 2b3 2b8 2bc 2c0 2c3 2c8
2cd 2d0 2d4 2d5 2da 2db 2e0 2e2
2e6 2e9 2ed 2f0 2f1 2f6 2f9 2fc
300 303 304 309 30c 1 30f 314
318 31b 31c 321 324 1 327 32c
330 334 337 33b 33f 342 345 34a
34d 350 353 354 359 35a 1 35c
361 365 369 36c 371 376 379 37d
37e 383 386 38b 38c 391 394 399
39a 39f 3a2 3a6 3aa 3ae 3b2 3b5
3b6 3b8 3bd 3be 3c0 3c1 3c6 3c7
3cc 3ce 3d2 3d5 3d9 3dd 3e0 3e4
3e8 3eb 3ee 3f3 3f6 3f9 3fc 3fd
402 403 1 405 40a 40e 412 415
41a 41f 422 426 427 42c 42d 432
434 438 43b 43f 443 446 44a 44e
451 455 456 45b 45d 461 464 468
46c 470 474 478 47c 480 484 488
48c 490 494 497 49b 49f 4a3 4a7
4ab 4af 4b3 4b7 4c3 4c7 4cb 4ce
4d2 4d6 4d8 4dc 4e0 4e4 4e7 4eb
4ef 4f1 4f2 4f7 1 4fb 4ff 503
506 50a 50e 512 516 519 51d 521
524 527 52c 52f 532 535 536 53b
53c 1 53e 543 547 54b 54e 553
558 55b 55f 560 565 568 56d 56e
573 576 57b 57c 581 584 588 589
58e 591 596 597 59c 59f 5a3 5a7
5aa 5ad 5ae 5b0 5b1 5b6 5b7 5bc
5be 5c2 5c5 5c7 5cb 5cd 5d9 5db
5dd 5de 5e3 5e7 5e9 5f5 5f7 5fb
5ff 600 605 609 60d 611 615 619
61d 621 625 629 62a 62c 630 634
638 63b 63c 63e 641 644 645 64a
64e 652 656 659 65d 65f 663 666
66a 66e 671 675 679 67c 67f 684
687 68a 68d 68e 693 694 1 696
69b 69f 6a3 6a6 6ab 6b0 6b3 6b7
6b8 6bd 6c0 6c5 6c6 6cb 6ce 6d3
6d4 6d9 6dc 6e0 6e4 6e8 6e9 6eb
6f0 6f1 6f3 6f4 6f9 6fc 701 702
707 70a 70f 710 715 718 71c 71d
722 725 72a 72b 730 731 736 738
73c 73f 743 747 74a 74e 752 755
756 758 75c 760 761 766 768 76c
770 773 777 77b 77e 782 786 789
78c 791 794 797 79a 79b 7a0 7a1
1 7a3 7a8 7ac 7b0 7b3 7b8 7bd
7c0 7c4 7c5 7ca 7cb 7d0 7d4 7d8
7db 7e0 7e5 7e8 7ec 7f0 7f3 7f4
7f9 7fc 801 802 807 80a 80e 812
815 816 81b 81c 821 823 827 82a
82e 832 836 83a 83e 842 846 84a
84e 85a 85f 863 867 86b 86f 871
872 877 1 87b 87f 883 886 88a
88e 892 896 899 89d 8a1 8a4 8a7
8ac 8af 8b2 8b5 8b6 8bb 8bc 1
8be 8c3 8c7 8cb 8ce 8d3 8d8 8db
8df 8e0 8e5 8e6 8eb 8ef 8f3 8f6
8fb 900 903 907 908 90d 910 915
916 91b 91e 922 926 929 92c 92d
92f 930 935 936 93b 93d 941 944
948 94c 950 954 958 95c 960 96c
971 975 979 97d 981 983 987 989
995 997 999 99a 99f 9a3 9a5 9b1
9b5 9b7 9b8 9c1 
2bc
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 11 1a 19 :2 11 :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :2 11 20 11 :2 4 :2 e 1d
e :2 4 :2 14 23 14 :2 4 e 17
:3 e 4 7 :2 11 23 :2 2d 3a :2 23
:3 7 :2 d 19 25 :2 2f 43 :2 25 53
59 5c :2 53 6a 7f 8 :2 6a d
10 :2 6a 13 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 51 :2 4
:4 9 8 7 :4 1b 1a 19 :2 7 :4 34
33 32 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b0 :2 85 :2 21 :2 a 54 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 54 :3 7 :2 12 28 :2 31 41
:2 7 4a :3 4 14 :2 4 15 :2 4 12
:2 4 14 :2 1d 4 e 17 27 32
c 1a 27 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 52 54 55 :2 52 :2 29 :3 d
:2 13 18 24 61 64 :2 24 71 74
:2 24 78 7b :2 24 87 8a :2 24 92
95 :2 24 a1 a4 ab b4 b7 :2 a4
:2 24 :2 d 58 :2 a :2 7 :4 13 :2 7 4
:3 1 4 :3 f :2 4 17 26 34 3f
4d 5c 25 :2 17 4 7 10 21
:2 7 24 26 :2 24 7 1a :2 23 7
28 :2 4 7 :2 11 23 :2 2d 39 3c
4b 4d 4e :2 4b :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e 6b 6e :2 1e 72
75 :2 1e 7f 82 8b 93 :2 8b a5
:2 82 :2 1e ad b0 :2 1e b8 bb :2 1e
c0 c3 :2 1e cb ce :2 1e :2 7 51
:3 4 :2 f 21 2a 3b :2 21 3f 48
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5e 61 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 55
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4c 4e 4f :2 4c :2 23
:3 7 :2 d 12 1e 5b 5e :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 52 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
2bc
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :6 d :6 e :6 f
:7 11 :b 13 :11 14 15
:2 14 :2 15 :2 14 :2 15
:2 14 :2 16 :2 14 :2 16
:2 14 :2 16 :2 14 :2 16
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :4 14 :3 13
:11 1a :b 1b :3 1a :16 1e
:11 1f :20 20 :3 1f :11 22
:b 23 :3 22 :9 25 :3 1e
:3 2a :3 2b :3 2c :5 2d
:4 30 :3 31 30 :5 32
2f 34 :5 35 :3 34
:2 36 :5 38 :11 39 :24 3a
:3 39 :2 37 :6 36 33
:3 12 :5 3f :7 41 42
:3 41 :9 44 :5 45 :3 44
:11 48 :2e 49 :3 48 :c 4b
12 :3 4e :11 4f :b 50
:17 51 :3 4f :2 53 :3 54
:3 55 56 54 53
54 :3 57 :3 4e :2 58
:5 5a :11 5b :b 5c :18 5d
:3 5b :2 5f 60 :3 61
62 60 5f 60
:3 63 :2 59 :6 58 4d
:7 1 
9c3
4
:3 0 1 :3 0 2
:a 0 2b7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2b7 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2b5
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2b5
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2b5
0 d :6 0 b
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2b5
0 e :6 0 12
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 2b5
0 f :6 0 12
:2 0 21 11 :3 0
3a :7 0 3e 3b
3c 2b5 0 10
:6 0 12 :2 0 23
11 :3 0 40 :7 0
44 41 42 2b5
0 13 :6 0 4c
4d 0 25 11
:3 0 46 :7 0 4a
47 48 2b5 0
14 :6 0 52 53
0 27 8 :3 0
9 :2 0 4 4e
:7 0 51 4f 0
2b5 0 15 :6 0
16 :3 0 17 :3 0
16 :3 0 18 :3 0
55 56 0 2
:4 0 29 57 59
54 5b 5a :2 0
19 :3 0 1a :3 0
5d 5e 0 1b
:4 0 16 :3 0 1c
:3 0 61 62 0
2 :4 0 2b 63
65 1d :4 0 1e
:2 0 1f :3 0 2d
68 6a :3 0 20
:4 0 1e :2 0 21
:4 0 30 6d 6f
:3 0 1e :2 0 3
:3 0 33 71 73
:3 0 1e :2 0 21
:4 0 36 75 77
:3 0 1e :2 0 22
:4 0 39 79 7b
:3 0 1e :2 0 21
:4 0 3c 7d 7f
:3 0 1e :2 0 5
:3 0 3f 81 83
:3 0 1e :2 0 21
:4 0 42 85 87
:3 0 1e :2 0 22
:4 0 45 89 8b
:3 0 1e :2 0 21
:4 0 48 8d 8f
:3 0 1e :2 0 6
:3 0 4b 91 93
:3 0 1e :2 0 21
:4 0 4e 95 97
:3 0 1e :2 0 23
:4 0 51 99 9b
:3 0 54 5f 9d
:2 0 9f 59 a0
5c 9f 0 a1
5b 0 215 16
:3 0 17 :3 0 a2
a3 0 16 :3 0
24 :3 0 a5 a6
0 25 :2 0 2
:4 0 26 :2 0 27
:2 0 25 :2 0 5d
ab ad :3 0 60
a7 af a4 b1
b0 :2 0 19 :3 0
28 :3 0 b3 b4
0 1b :4 0 29
:4 0 1e :2 0 1f
:3 0 64 b8 ba
:3 0 67 b5 bc
:2 0 be 6a bf
b2 be 0 c0
6c 0 215 3
:3 0 2a :2 0 6e
c2 c3 :3 0 c4
:2 0 c5 :2 0 5
:3 0 2a :2 0 70
c8 c9 :3 0 ca
:2 0 cb :2 0 c6
cd cc :2 0 6
:3 0 2a :2 0 72
d0 d1 :3 0 d2
:2 0 d3 :2 0 ce
d5 d4 :2 0 16
:3 0 17 :3 0 d7
d8 0 16 :3 0
24 :3 0 da db
0 2b :2 0 2
:4 0 2c :2 0 27
:2 0 25 :2 0 74
e0 e2 :3 0 77
dc e4 d9 e6
e5 :2 0 19 :3 0
28 :3 0 e8 e9
0 1b :4 0 2d
:4 0 1e :2 0 1f
:3 0 7b ed ef
:3 0 1e :2 0 2e
:4 0 7e f1 f3
:3 0 1e :2 0 2f
:4 0 81 f5 f7
:3 0 1e :2 0 30
:3 0 31 :3 0 32
:3 0 33 :3 0 fc
fd 0 84 fb
ff 34 :4 0 86
fa 102 89 f9
104 :3 0 8c ea
106 :2 0 108 8f
109 e7 108 0
10a 91 0 133
16 :3 0 17 :3 0
10b 10c 0 16
:3 0 24 :3 0 10e
10f 0 25 :2 0
2 :4 0 35 :2 0
27 :2 0 25 :2 0
93 114 116 :3 0
96 110 118 10d
11a 119 :2 0 19
:3 0 28 :3 0 11c
11d 0 1b :4 0
36 :4 0 1e :2 0
1f :3 0 9a 121
123 :3 0 9d 11e
125 :2 0 127 a0
128 11b 127 0
129 a2 0 133
37 :3 0 38 :3 0
12a 12b 0 32
:3 0 33 :3 0 12d
12e 0 39 :3 0
a4 12c 131 :2 0
133 a7 134 d6
133 0 135 ab
0 215 a :3 0
3 :3 0 136 137
0 215 f :3 0
5 :3 0 139 13a
0 215 e :3 0
6 :3 0 13c 13d
0 215 10 :3 0
32 :3 0 3a :3 0
140 141 0 13f
142 0 215 3b
:3 0 3c :3 0 13
:3 0 d :3 0 3d
:3 0 3e :3 0 a
:4 0 3f 1 :8 0
151 8 :3 0 40
:3 0 14c 14d 0
41 :3 0 14e 14f
0 151 ad 1a4
42 :3 0 8 :3 0
40 :3 0 153 154
0 41 :3 0 155
156 0 158 b0
15a b2 159 158
:2 0 1a2 43 :3 0
8 :3 0 40 :3 0
15d 15e 0 41
:3 0 15f 160 0
19a 16 :3 0 17
:3 0 162 163 0
16 :3 0 24 :3 0
165 166 0 44
:2 0 2 :4 0 45
:2 0 27 :2 0 25
:2 0 b4 16b 16d
:3 0 b7 167 16f
164 171 170 :2 0
19 :3 0 28 :3 0
173 174 0 1b
:4 0 46 :4 0 1e
:2 0 1f :3 0 bb
178 17a :3 0 1e
:2 0 2e :4 0 be
17c 17e :3 0 1e
:2 0 47 :4 0 c1
180 182 :3 0 1e
:2 0 41 :3 0 c4
184 186 :3 0 1e
:2 0 48 :4 0 c7
188 18a :3 0 1e
:2 0 49 :3 0 4a
:3 0 25 :2 0 4b
:2 0 ca 18d 191
ce 18c 193 :3 0
d1 175 195 :2 0
197 d4 198 172
197 0 199 d6
0 19a d8 19d
:3 0 19d 0 19d
19c 19a 19b :6 0
19f 2 :3 0 db
1a1 dd 1a0 19f
:2 0 1a2 df :2 0
1a4 0 1a4 1a3
151 1a2 :6 0 215
1 :3 0 c :3 0
4c :4 0 1a7 1a8
:3 0 1a6 1a9 0
215 14 :3 0 4d
:3 0 10 :3 0 13
:3 0 a :3 0 f
:3 0 e :3 0 c
:3 0 e2 1ac 1b3
1ab 1b4 0 215
30 :3 0 14 :3 0
12 :2 0 e9 1b6
1b9 4e :2 0 25
:2 0 ee 1bb 1bd
:3 0 14 :3 0 32
:3 0 4f :3 0 1c0
1c1 0 1bf 1c2
0 1c4 f1 1c5
1be 1c4 0 1c6
f3 0 215 16
:3 0 17 :3 0 1c7
1c8 0 16 :3 0
24 :3 0 1ca 1cb
0 50 :2 0 2
:4 0 51 :2 0 27
:2 0 25 :2 0 f5
1d0 1d2 :3 0 f8
1cc 1d4 1c9 1d6
1d5 :2 0 19 :3 0
28 :3 0 1d8 1d9
0 1b :4 0 52
:4 0 1e :2 0 1f
:3 0 fc 1dd 1df
:3 0 1e :2 0 2e
:4 0 ff 1e1 1e3
:3 0 1e :2 0 2f
:4 0 102 1e5 1e7
:3 0 1e :2 0 30
:3 0 31 :3 0 14
:3 0 105 1eb 1ed
34 :4 0 107 1ea
1f0 10a 1e9 1f2
:3 0 1e :2 0 53
:4 0 10d 1f4 1f6
:3 0 1e :2 0 21
:4 0 110 1f8 1fa
:3 0 1e :2 0 c
:3 0 113 1fc 1fe
:3 0 1e :2 0 21
:4 0 116 200 202
:3 0 119 1da 204
:2 0 206 11c 207
1d7 206 0 208
11e 0 215 37
:3 0 54 :3 0 209
20a 0 30 :3 0
14 :3 0 12 :2 0
120 20c 20f c
:3 0 39 :3 0 123
20b 213 :2 0 215
127 2b6 8 :3 0
55 :2 0 4 216
217 0 16 :3 0
17 :3 0 219 21a
0 16 :3 0 24
:3 0 21c 21d 0
44 :2 0 2 :4 0
56 :2 0 27 :2 0
25 :2 0 135 222
224 :3 0 138 21e
226 21b 228 227
:2 0 19 :3 0 28
:3 0 22a 22b 0
1b :4 0 57 :4 0
1e :2 0 1f :3 0
13c 22f 231 :3 0
13f 22c 233 :2 0
24c 19 :3 0 28
:3 0 235 236 0
1b :4 0 58 :4 0
1e :2 0 8 :3 0
59 :3 0 23b 23c
0 142 23a 23e
:3 0 1e :2 0 53
:4 0 145 240 242
:3 0 1e :2 0 8
:3 0 5a :3 0 245
246 0 148 244
248 :3 0 14b 237
24a :2 0 24c 14e
24d 229 24c 0
24e 151 0 25e
5b :3 0 15 :3 0
8 :3 0 59 :3 0
5c :3 0 8 :3 0
5a :3 0 3 :3 0
5d :4 0 5e 1
:a 0 25a :2 0 25e
250 258 :2 0 7
:3 0 15 :3 0 25c
:2 0 25e 153 260
157 25f 25e :2 0
2b4 43 :3 0 8
:3 0 40 :3 0 263
264 0 41 :3 0
265 266 0 2ac
16 :3 0 17 :3 0
268 269 0 16
:3 0 24 :3 0 26b
26c 0 44 :2 0
2 :4 0 5f :2 0
27 :2 0 25 :2 0
159 271 273 :3 0
15c 26d 275 26a
277 276 :2 0 19
:3 0 28 :3 0 279
27a 0 1b :4 0
60 :4 0 1e :2 0
1f :3 0 160 27e
280 :3 0 163 27b
282 :2 0 29c 19
:3 0 28 :3 0 284
285 0 1b :4 0
47 :4 0 1e :2 0
41 :3 0 166 289
28b :3 0 1e :2 0
48 :4 0 169 28d
28f :3 0 1e :2 0
49 :3 0 4a :3 0
25 :2 0 4b :2 0
16c 292 296 170
291 298 :3 0 173
286 29a :2 0 29c
176 29d 278 29c
0 29e 179 0
2ac 5b :3 0 15
:3 0 5c :3 0 8
:3 0 5a :3 0 3
:3 0 5d :4 0 61
1 :a 0 2a8 :2 0
2ac 2a0 2a6 :2 0
7 :3 0 15 :3 0
2aa :2 0 2ac 17b
2af :3 0 2af 0
2af 2ae 2ac 2ad
:6 0 2b1 1 :3 0
180 2b3 182 2b2
2b1 :2 0 2b4 184
:2 0 2b6 187 2b6
2b5 215 2b4 :6 0
2b7 :2 0 2 14
2b6 2ba :3 0 2b9
2b7 2bb :8 0 
191
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
39 1 3f 1
45 1 4b 1
58 1 64 2
67 69 2 6c
6e 2 70 72
2 74 76 2
78 7a 2 7c
7e 2 80 82
2 84 86 2
88 8a 2 8c
8e 2 90 92
2 94 96 2
98 9a 4 60
66 6b 9c 1
9e 1 a0 2
aa ac 3 a8
a9 ae 2 b7
b9 2 b6 bb
1 bd 1 bf
1 c1 1 c7
1 cf 2 df
e1 3 dd de
e3 2 ec ee
2 f0 f2 2
f4 f6 1 fe
2 100 101 2
f8 103 2 eb
105 1 107 1
109 2 113 115
3 111 112 117
2 120 122 2
11f 124 1 126
1 128 2 12f
130 3 10a 129
132 1 134 2
14b 150 1 157
1 152 2 16a
16c 3 168 169
16e 2 177 179
2 17b 17d 2
17f 181 2 183
185 2 187 189
3 18e 18f 190
2 18b 192 2
176 194 1 196
1 198 2 161
199 1 19d 1
15c 2 15a 1a1
6 1ad 1ae 1af
1b0 1b1 1b2 2
1b7 1b8 1 1bc
2 1ba 1bc 1
1c3 1 1c5 2
1cf 1d1 3 1cd
1ce 1d3 2 1dc
1de 2 1e0 1e2
2 1e4 1e6 1
1ec 2 1ee 1ef
2 1e8 1f1 2
1f3 1f5 2 1f7
1f9 2 1fb 1fd
2 1ff 201 2
1db 203 1 205
1 207 2 20d
20e 3 210 211
212 d a1 c0
135 138 13b 13e
143 1a4 1aa 1b5
1c6 208 214 2
221 223 3 21f
220 225 2 22e
230 2 22d 232
2 239 23d 2
23f 241 2 243
247 2 238 249
2 234 24b 1
24d 3 24e 259
25d 1 218 2
270 272 3 26e
26f 274 2 27d
27f 2 27c 281
2 288 28a 2
28c 28e 3 293
294 295 2 290
297 2 287 299
2 283 29b 1
29d 4 267 29e
2a7 2ab 1 2af
1 262 2 260
2b3 9 1b 22
29 30 37 3d
43 49 50 
1
4
0 
2ba
0
1
14
4
d
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
32 1 0
3 1 0
7 1 0
2 0 1
45 1 0
3f 1 0
1d 1 0
39 1 0
24 1 0
2b 1 0
4b 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKRES;
ALTER FUNCTION SP_A_TSKRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_CRIRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_CRIRES ==
CREATE OR REPLACE FUNCTION SP_A_CRIRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
65
2 :e:
1FUNCTION:
1SP_A_CRIRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_CRIRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_CRIRES(26) :: cplan.sql(6742) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_CRIRES(31) :: cplan.sql(6747) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_CRIRES(34) :: cplan.sql(6750) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
154:
1           EXCEPTION:: SP_A_CRIRES(55) :: cplan.sql(6771) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CRI WHERE ELEMENT_ID = h_element_id:
171:
1           EXCEPTION:: SP_A_CRIRES(72) :: cplan.sql(6788) :: :
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1SYS_GUID:
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
14:
191:
1       RETURN_STATUS:: SP_A_CRIRES(92) :: cplan.sql(6808) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
198:
1           EXCEPTION:: SP_A_CRIRES(99) :: cplan.sql(6815) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1110:
1           EXCEPTION:: SP_A_CRIRES(111) :: cplan.sql(6827) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
327
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a 52 10 a0 7e b4 2e :2 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
6b d b7 :3 a0 6b d b7 :2 19
3c :2 a0 b4 2e d :8 a0 a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
327
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 131 120
124 100 12c 11f 151 13c 140 11c
144 14c 13b 158 15c 138 160 164
168 16b 170 171 1 173 178 17c
180 183 188 18c 190 193 198 199
19b 1a0 1a3 1a7 1a8 1ad 1b2 1b5
1ba 1bb 1c0 1c3 1c7 1c8 1cd 1d0
1d5 1d6 1db 1de 1e3 1e4 1e9 1ec
1f1 1f2 1f7 1fa 1fe 1ff 204 207
20c 20d 212 215 21a 21b 220 223
228 229 22e 231 235 236 23b 23e
243 244 249 24c 251 252 257 258
25d 25f 263 266 26a 26e 271 275
279 27c 27f 284 287 28a 28d 28e
293 294 1 296 29b 29f 2a3 2a6
2ab 2b0 2b3 2b7 2b8 2bd 2be 2c3
2c5 2c9 2cc 2d0 2d3 2d4 2d9 2dc
2df 2e3 2e6 2e7 2ec 2ef 1 2f2
2f7 2fb 2fe 2ff 304 307 1 30a
30f 313 317 31a 31e 322 325 328
32d 330 333 336 337 33c 33d 1
33f 344 348 34c 34f 354 359 35c
360 361 366 369 36e 36f 374 377
37c 37d 382 385 389 38d 391 395
398 399 39b 3a0 3a1 3a3 3a4 3a9
3aa 3af 3b1 3b5 3b8 3bc 3c0 3c3
3c7 3cb 3ce 3d1 3d6 3d9 3dc 3df
3e0 3e5 3e6 1 3e8 3ed 3f1 3f5
3f8 3fd 402 405 409 40a 40f 410
415 417 41b 41e 422 426 429 42d
431 434 438 439 43e 440 444 447
44b 44f 453 457 45b 45f 463 467
46b 46f 473 477 47b 47f 48b 48f
493 496 49a 49e 4a0 4a4 4a8 4ac
4af 4b3 4b7 4b9 4ba 4bf 1 4c3
4c7 4cb 4ce 4d2 4d6 4da 4de 4e1
4e5 4e9 4ec 4ef 4f4 4f7 4fa 4fd
4fe 503 504 1 506 50b 50f 513
516 51b 520 523 527 528 52d 530
535 536 53b 53e 543 544 549 54c
550 551 556 559 55e 55f 564 567
56b 56f 572 575 576 578 579 57e
57f 584 586 58a 58d 58f 593 595
5a1 5a3 5a5 5a6 5ab 5af 5b1 5bd
5bf 5c3 5c7 5ca 5ce 5d1 5d5 5d8
5d9 5de 5e1 5e5 5e9 5ed 5f1 5f5
601 605 609 60c 610 614 616 61a
61e 622 625 629 62d 62f 630 635
1 639 63d 641 644 648 64c 650
654 657 65b 65f 662 665 66a 66d
670 673 674 679 67a 1 67c 681
685 689 68c 691 696 699 69d 69e
6a3 6a6 6ab 6ac 6b1 6b4 6b9 6ba
6bf 6c2 6c6 6c7 6cc 6cf 6d4 6d5
6da 6dd 6e1 6e5 6e8 6eb 6ec 6ee
6ef 6f4 6f5 6fa 6fc 700 703 705
709 70b 717 719 71b 71c 721 725
727 733 735 739 73d 741 744 748
74a 74e 752 756 759 75d 75f 763
767 76a 76e 772 773 778 77c 780
784 788 78c 790 794 798 79c 79d
79f 7a3 7a7 7ab 7ae 7af 7b1 7b4
7b7 7b8 7bd 7c1 7c5 7c9 7cc 7d0
7d2 7d6 7d9 7dd 7e1 7e4 7e8 7ec
7ef 7f2 7f7 7fa 7fd 800 801 806
807 1 809 80e 812 816 819 81e
823 826 82a 82b 830 833 838 839
83e 841 846 847 84c 84f 853 857
85b 85c 85e 863 864 866 867 86c
86f 874 875 87a 87d 882 883 888
88b 88f 890 895 898 89d 89e 8a3
8a4 8a9 8ab 8af 8b2 8b6 8ba 8bd
8c1 8c5 8c8 8c9 8cb 8cf 8d3 8d4
8d9 8db 8df 8e3 8e6 8ea 8ee 8f1
8f5 8f9 8fc 8ff 904 907 90a 90d
90e 913 914 1 916 91b 91f 923
926 92b 930 933 937 938 93d 93e
943 947 94b 94e 953 958 95b 95f
963 966 967 96c 96f 974 975 97a
97d 981 985 988 989 98e 98f 994
996 99a 99d 9a1 9a5 9a9 9ad 9b1
9b5 9b9 9bd 9c1 9cd 9d2 9d6 9da
9de 9e2 9e4 9e5 9ea 1 9ee 9f2
9f6 9f9 9fd a01 a05 a09 a0c a10
a14 a17 a1a a1f a22 a25 a28 a29
a2e a2f 1 a31 a36 a3a a3e a41
a46 a4b a4e a52 a53 a58 a59 a5e
a62 a66 a69 a6e a73 a76 a7a a7b
a80 a83 a88 a89 a8e a91 a95 a99
a9c a9f aa0 aa2 aa3 aa8 aa9 aae
ab0 ab4 ab7 abb abf ac3 ac7 acb
acf ad3 adf ae4 ae8 aec af0 af4
af6 afa afc b08 b0a b0c b0d b12
b16 b18 b24 b28 b2a b2b b34 
327
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 14 23 14
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 13 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 9 8 7 :4 1b 1a
19 :2 7 :4 34 33 32 :2 7 a :2 14
26 :2 30 3c 3f 4e 50 51 :2 4e
:2 26 :3 a :2 10 15 21 5e 61 :2 21
6e 71 :2 21 75 78 :2 21 82 85
8e 96 :2 9f :2 8e b0 :2 85 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 54 :3 7 :2 12
28 :2 31 41 :2 7 4a :3 4 14 :2 4
15 :2 4 12 4 e 1b 2a 38
45 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
52 54 55 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 87 8a :2 24 92 95 :2 24
a1 a4 ab b4 b7 :2 a4 :2 24 :2 d
58 :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 11 1e
2d 3b 48 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 35 7 17 :2 20 7 35 7 17
:2 20 7 :5 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e 6b 6e :2 1e
72 75 :2 1e 7f 82 8b 93 :2 8b
a5 :2 82 :2 1e ad b0 :2 1e b8 bb
:2 1e c0 c3 :2 1e cb ce :2 1e :2 7
51 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5e 61 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
55 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
327
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :6 2e :5 2f
2d 31 :5 32 :3 31
:2 33 :5 35 :11 36 :24 37
:3 36 :2 34 :6 33 30
:3 11 :a 3d :6 3f :5 40
3e 42 :5 43 :3 42
:2 44 :5 46 :11 47 :24 48
:3 47 :2 45 :6 44 41
:3 3d :5 4d 3d :5 4f
4e :3 3d :5 52 :7 54
55 :3 54 :9 57 :5 58
:3 57 :11 5b :2e 5c :3 5b
:c 5e 11 :3 61 :11 62
:b 63 :17 64 :3 62 :2 66
:3 67 :3 68 69 67
66 67 :3 6a :3 61
:2 6b :5 6d :11 6e :b 6f
:18 70 :3 6e :2 72 73
:3 74 75 73 72
73 :3 76 :2 6c :6 6b
60 :7 1 
b36
4
:3 0 1 :3 0 2
:a 0 322 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 322 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 320
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 320
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 320
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 320
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 320 0 f
:6 0 11 :2 0 1f
10 :3 0 39 :7 0
3d 3a 3b 320
0 12 :6 0 45
46 0 21 10
:3 0 3f :7 0 43
40 41 320 0
13 :6 0 4b 4c
0 23 8 :3 0
9 :2 0 4 47
:7 0 4a 48 0
320 0 14 :6 0
15 :3 0 16 :3 0
15 :3 0 17 :3 0
4e 4f 0 2
:4 0 25 50 52
4d 54 53 :2 0
18 :3 0 19 :3 0
56 57 0 1a
:4 0 15 :3 0 1b
:3 0 5a 5b 0
2 :4 0 27 5c
5e 1c :4 0 1d
:2 0 1e :3 0 29
61 63 :3 0 1f
:4 0 1d :2 0 20
:4 0 2c 66 68
:3 0 1d :2 0 3
:3 0 2f 6a 6c
:3 0 1d :2 0 20
:4 0 32 6e 70
:3 0 1d :2 0 21
:4 0 35 72 74
:3 0 1d :2 0 20
:4 0 38 76 78
:3 0 1d :2 0 5
:3 0 3b 7a 7c
:3 0 1d :2 0 20
:4 0 3e 7e 80
:3 0 1d :2 0 21
:4 0 41 82 84
:3 0 1d :2 0 20
:4 0 44 86 88
:3 0 1d :2 0 6
:3 0 47 8a 8c
:3 0 1d :2 0 20
:4 0 4a 8e 90
:3 0 1d :2 0 22
:4 0 4d 92 94
:3 0 50 58 96
:2 0 98 55 99
55 98 0 9a
57 0 280 15
:3 0 16 :3 0 9b
9c 0 15 :3 0
23 :3 0 9e 9f
0 24 :2 0 2
:4 0 25 :2 0 26
:2 0 24 :2 0 59
a4 a6 :3 0 5c
a0 a8 9d aa
a9 :2 0 18 :3 0
27 :3 0 ac ad
0 1a :4 0 28
:4 0 1d :2 0 1e
:3 0 60 b1 b3
:3 0 63 ae b5
:2 0 b7 66 b8
ab b7 0 b9
68 0 280 3
:3 0 29 :2 0 6a
bb bc :3 0 bd
:2 0 be :2 0 5
:3 0 29 :2 0 6c
c1 c2 :3 0 c3
:2 0 c4 :2 0 bf
c6 c5 :2 0 6
:3 0 29 :2 0 6e
c9 ca :3 0 cb
:2 0 cc :2 0 c7
ce cd :2 0 15
:3 0 16 :3 0 d0
d1 0 15 :3 0
23 :3 0 d3 d4
0 2a :2 0 2
:4 0 2b :2 0 26
:2 0 24 :2 0 70
d9 db :3 0 73
d5 dd d2 df
de :2 0 18 :3 0
27 :3 0 e1 e2
0 1a :4 0 2c
:4 0 1d :2 0 1e
:3 0 77 e6 e8
:3 0 1d :2 0 2d
:4 0 7a ea ec
:3 0 1d :2 0 2e
:4 0 7d ee f0
:3 0 1d :2 0 2f
:3 0 30 :3 0 31
:3 0 32 :3 0 f5
f6 0 80 f4
f8 33 :4 0 82
f3 fb 85 f2
fd :3 0 88 e3
ff :2 0 101 8b
102 e0 101 0
103 8d 0 12c
15 :3 0 16 :3 0
104 105 0 15
:3 0 23 :3 0 107
108 0 24 :2 0
2 :4 0 34 :2 0
26 :2 0 24 :2 0
8f 10d 10f :3 0
92 109 111 106
113 112 :2 0 18
:3 0 27 :3 0 115
116 0 1a :4 0
35 :4 0 1d :2 0
1e :3 0 96 11a
11c :3 0 99 117
11e :2 0 120 9c
121 114 120 0
122 9e 0 12c
36 :3 0 37 :3 0
123 124 0 31
:3 0 32 :3 0 126
127 0 38 :3 0
a0 125 12a :2 0
12c a3 12d cf
12c 0 12e a7
0 280 a :3 0
3 :3 0 12f 130
0 280 e :3 0
5 :3 0 132 133
0 280 d :3 0
6 :3 0 135 136
0 280 39 :3 0
12 :3 0 3a :3 0
3b :3 0 a :4 0
3c 1 :8 0 143
8 :3 0 3d :3 0
13e 13f 0 3e
:3 0 140 141 0
143 a9 196 3f
:3 0 8 :3 0 3d
:3 0 145 146 0
3e :3 0 147 148
0 14a ac 14c
ae 14b 14a :2 0
194 40 :3 0 8
:3 0 3d :3 0 14f
150 0 3e :3 0
151 152 0 18c
15 :3 0 16 :3 0
154 155 0 15
:3 0 23 :3 0 157
158 0 41 :2 0
2 :4 0 42 :2 0
26 :2 0 24 :2 0
b0 15d 15f :3 0
b3 159 161 156
163 162 :2 0 18
:3 0 27 :3 0 165
166 0 1a :4 0
43 :4 0 1d :2 0
1e :3 0 b7 16a
16c :3 0 1d :2 0
2d :4 0 ba 16e
170 :3 0 1d :2 0
44 :4 0 bd 172
174 :3 0 1d :2 0
3e :3 0 c0 176
178 :3 0 1d :2 0
45 :4 0 c3 17a
17c :3 0 1d :2 0
46 :3 0 47 :3 0
24 :2 0 48 :2 0
c6 17f 183 ca
17e 185 :3 0 cd
167 187 :2 0 189
d0 18a 164 189
0 18b d2 0
18c d4 18f :3 0
18f 0 18f 18e
18c 18d :6 0 191
2 :3 0 d7 193
d9 192 191 :2 0
194 db :2 0 196
0 196 195 143
194 :6 0 280 1
:3 0 8 :3 0 3d
:3 0 198 199 0
8 :3 0 49 :2 0
4a :3 0 19b 19d
0 e0 19c 19f
:3 0 1a0 :2 0 39
:3 0 12 :3 0 4b
:3 0 3b :3 0 a
:4 0 4c 1 :8 0
1ad 8 :3 0 3d
:3 0 1a8 1a9 0
3e :3 0 1aa 1ab
0 1ad e3 200
3f :3 0 8 :3 0
3d :3 0 1af 1b0
0 3e :3 0 1b1
1b2 0 1b4 e6
1b6 e8 1b5 1b4
:2 0 1fe 40 :3 0
8 :3 0 3d :3 0
1b9 1ba 0 3e
:3 0 1bb 1bc 0
1f6 15 :3 0 16
:3 0 1be 1bf 0
15 :3 0 23 :3 0
1c1 1c2 0 41
:2 0 2 :4 0 4d
:2 0 26 :2 0 24
:2 0 ea 1c7 1c9
:3 0 ed 1c3 1cb
1c0 1cd 1cc :2 0
18 :3 0 27 :3 0
1cf 1d0 0 1a
:4 0 4e :4 0 1d
:2 0 1e :3 0 f1
1d4 1d6 :3 0 1d
:2 0 2d :4 0 f4
1d8 1da :3 0 1d
:2 0 44 :4 0 f7
1dc 1de :3 0 1d
:2 0 3e :3 0 fa
1e0 1e2 :3 0 1d
:2 0 45 :4 0 fd
1e4 1e6 :3 0 1d
:2 0 46 :3 0 47
:3 0 24 :2 0 48
:2 0 100 1e9 1ed
104 1e8 1ef :3 0
107 1d1 1f1 :2 0
1f3 10a 1f4 1ce
1f3 0 1f5 10c
0 1f6 10e 1f9
:3 0 1f9 0 1f9
1f8 1f6 1f7 :6 0
1fb 4 :3 0 111
1fd 113 1fc 1fb
:2 0 1fe 115 :2 0
200 0 200 1ff
1ad 1fe :6 0 207
1 :3 0 f :3 0
31 :3 0 4f :3 0
203 204 0 202
205 0 207 118
20e f :3 0 31
:3 0 50 :3 0 209
20a 0 208 20b
0 20d 11b 20f
1a1 207 0 210
0 20d 0 210
11d 0 280 c
:3 0 51 :4 0 212
213 :3 0 211 214
0 280 13 :3 0
52 :3 0 f :3 0
12 :3 0 a :3 0
e :3 0 d :3 0
c :3 0 120 217
21e 216 21f 0
280 2f :3 0 13
:3 0 11 :2 0 127
221 224 49 :2 0
24 :2 0 12c 226
228 :3 0 13 :3 0
31 :3 0 53 :3 0
22b 22c 0 22a
22d 0 22f 12f
230 229 22f 0
231 131 0 280
15 :3 0 16 :3 0
232 233 0 15
:3 0 23 :3 0 235
236 0 54 :2 0
2 :4 0 55 :2 0
26 :2 0 24 :2 0
133 23b 23d :3 0
136 237 23f 234
241 240 :2 0 18
:3 0 27 :3 0 243
244 0 1a :4 0
56 :4 0 1d :2 0
1e :3 0 13a 248
24a :3 0 1d :2 0
2d :4 0 13d 24c
24e :3 0 1d :2 0
2e :4 0 140 250
252 :3 0 1d :2 0
2f :3 0 30 :3 0
13 :3 0 143 256
258 33 :4 0 145
255 25b 148 254
25d :3 0 1d :2 0
57 :4 0 14b 25f
261 :3 0 1d :2 0
20 :4 0 14e 263
265 :3 0 1d :2 0
c :3 0 151 267
269 :3 0 1d :2 0
20 :4 0 154 26b
26d :3 0 157 245
26f :2 0 271 15a
272 242 271 0
273 15c 0 280
36 :3 0 58 :3 0
274 275 0 2f
:3 0 13 :3 0 11
:2 0 15e 277 27a
c :3 0 38 :3 0
161 276 27e :2 0
280 165 321 8
:3 0 59 :2 0 4
281 282 0 15
:3 0 16 :3 0 284
285 0 15 :3 0
23 :3 0 287 288
0 41 :2 0 2
:4 0 5a :2 0 26
:2 0 24 :2 0 173
28d 28f :3 0 176
289 291 286 293
292 :2 0 18 :3 0
27 :3 0 295 296
0 1a :4 0 5b
:4 0 1d :2 0 1e
:3 0 17a 29a 29c
:3 0 17d 297 29e
:2 0 2b7 18 :3 0
27 :3 0 2a0 2a1
0 1a :4 0 5c
:4 0 1d :2 0 8
:3 0 5d :3 0 2a6
2a7 0 180 2a5
2a9 :3 0 1d :2 0
57 :4 0 183 2ab
2ad :3 0 1d :2 0
8 :3 0 5e :3 0
2b0 2b1 0 186
2af 2b3 :3 0 189
2a2 2b5 :2 0 2b7
18c 2b8 294 2b7
0 2b9 18f 0
2c9 5f :3 0 14
:3 0 8 :3 0 5d
:3 0 60 :3 0 8
:3 0 5e :3 0 3
:3 0 61 :4 0 62
1 :a 0 2c5 :2 0
2c9 2bb 2c3 :2 0
7 :3 0 14 :3 0
2c7 :2 0 2c9 191
2cb 195 2ca 2c9
:2 0 31f 40 :3 0
8 :3 0 3d :3 0
2ce 2cf 0 3e
:3 0 2d0 2d1 0
317 15 :3 0 16
:3 0 2d3 2d4 0
15 :3 0 23 :3 0
2d6 2d7 0 41
:2 0 2 :4 0 63
:2 0 26 :2 0 24
:2 0 197 2dc 2de
:3 0 19a 2d8 2e0
2d5 2e2 2e1 :2 0
18 :3 0 27 :3 0
2e4 2e5 0 1a
:4 0 64 :4 0 1d
:2 0 1e :3 0 19e
2e9 2eb :3 0 1a1
2e6 2ed :2 0 307
18 :3 0 27 :3 0
2ef 2f0 0 1a
:4 0 44 :4 0 1d
:2 0 3e :3 0 1a4
2f4 2f6 :3 0 1d
:2 0 45 :4 0 1a7
2f8 2fa :3 0 1d
:2 0 46 :3 0 47
:3 0 24 :2 0 48
:2 0 1aa 2fd 301
1ae 2fc 303 :3 0
1b1 2f1 305 :2 0
307 1b4 308 2e3
307 0 309 1b7
0 317 5f :3 0
14 :3 0 60 :3 0
8 :3 0 5e :3 0
3 :3 0 61 :4 0
65 1 :a 0 313
:2 0 317 30b 311
:2 0 7 :3 0 14
:3 0 315 :2 0 317
1b9 31a :3 0 31a
0 31a 319 317
318 :6 0 31c 1
:3 0 1be 31e 1c0
31d 31c :2 0 31f
1c2 :2 0 321 1c5
321 320 280 31f
:6 0 322 :2 0 2
14 321 325 :3 0
324 322 326 :8 0

1ce
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 44 1
51 1 5d 2
60 62 2 65
67 2 69 6b
2 6d 6f 2
71 73 2 75
77 2 79 7b
2 7d 7f 2
81 83 2 85
87 2 89 8b
2 8d 8f 2
91 93 4 59
5f 64 95 1
97 1 99 2
a3 a5 3 a1
a2 a7 2 b0
b2 2 af b4
1 b6 1 b8
1 ba 1 c0
1 c8 2 d8
da 3 d6 d7
dc 2 e5 e7
2 e9 eb 2
ed ef 1 f7
2 f9 fa 2
f1 fc 2 e4
fe 1 100 1
102 2 10c 10e
3 10a 10b 110
2 119 11b 2
118 11d 1 11f
1 121 2 128
129 3 103 122
12b 1 12d 2
13d 142 1 149
1 144 2 15c
15e 3 15a 15b
160 2 169 16b
2 16d 16f 2
171 173 2 175
177 2 179 17b
3 180 181 182
2 17d 184 2
168 186 1 188
1 18a 2 153
18b 1 18f 1
14e 2 14c 193
1 19e 2 19a
19e 2 1a7 1ac
1 1b3 1 1ae
2 1c6 1c8 3
1c4 1c5 1ca 2
1d3 1d5 2 1d7
1d9 2 1db 1dd
2 1df 1e1 2
1e3 1e5 3 1ea
1eb 1ec 2 1e7
1ee 2 1d2 1f0
1 1f2 1 1f4
2 1bd 1f5 1
1f9 1 1b8 2
1b6 1fd 2 200
206 1 20c 2
20e 20f 6 218
219 21a 21b 21c
21d 2 222 223
1 227 2 225
227 1 22e 1
230 2 23a 23c
3 238 239 23e
2 247 249 2
24b 24d 2 24f
251 1 257 2
259 25a 2 253
25c 2 25e 260
2 262 264 2
266 268 2 26a
26c 2 246 26e
1 270 1 272
2 278 279 3
27b 27c 27d d
9a b9 12e 131
134 137 196 210
215 220 231 273
27f 2 28c 28e
3 28a 28b 290
2 299 29b 2
298 29d 2 2a4
2a8 2 2aa 2ac
2 2ae 2b2 2
2a3 2b4 2 29f
2b6 1 2b8 3
2b9 2c4 2c8 1
283 2 2db 2dd
3 2d9 2da 2df
2 2e8 2ea 2
2e7 2ec 2 2f3
2f5 2 2f7 2f9
3 2fe 2ff 300
2 2fb 302 2
2f2 304 2 2ee
306 1 308 4
2d2 309 312 316
1 31a 1 2cd
2 2cb 31e 8
1b 22 29 30
36 3c 42 49

1
4
0 
325
0
1
14
6
c
0 1 2 1 4 1 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
3 1 0
7 1 0
3e 1 0
38 1 0
2 0 1
1d 1 0
32 1 0
24 1 0
44 1 0
0

/
SHOW ERRORS FUNCTION SP_A_CRIRES;
ALTER FUNCTION SP_A_CRIRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_REQRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_REQRES ==
CREATE OR REPLACE FUNCTION SP_A_REQRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
59
2 :e:
1FUNCTION:
1SP_A_REQRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TYPE_ID:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_REQRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
123:
1+:
1FPUT:
1               ENTER:: SP_A_REQRES(24) :: cplan.sql(6877) :: :
1IS NULL:
18:
128:
1      RETURN_INVALID:: SP_A_REQRES(29) :: cplan.sql(6882) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
131:
1                EXIT:: SP_A_REQRES(32) :: cplan.sql(6885) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
152:
1           EXCEPTION:: SP_A_REQRES(53) :: cplan.sql(6906) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
14:
164:
1       RETURN_STATUS:: SP_A_REQRES(65) :: cplan.sql(6918) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
171:
1           EXCEPTION:: SP_A_REQRES(72) :: cplan.sql(6925) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
183:
1           EXCEPTION:: SP_A_REQRES(84) :: cplan.sql(6937) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
284
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a 52 10 a0
7e b4 2e :2 5a 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 b4 2e d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
284
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
119 104 108 e4 10c 114 103 120
124 100 128 12c 130 133 138 139
1 13b 140 144 148 14b 150 154
158 15b 160 161 163 168 16b 16f
170 175 17a 17d 182 183 188 18b
18f 190 195 198 19d 19e 1a3 1a6
1ab 1ac 1b1 1b4 1b9 1ba 1bf 1c2
1c6 1c7 1cc 1cf 1d4 1d5 1da 1dd
1e2 1e3 1e8 1eb 1f0 1f1 1f6 1f9
1fd 1fe 203 206 20b 20c 211 214
219 21a 21f 220 225 227 22b 22e
232 236 239 23d 241 244 247 24c
24f 252 255 256 25b 25c 1 25e
263 267 26b 26e 273 278 27b 27f
280 285 286 28b 28d 291 294 298
29b 29c 2a1 2a4 2a8 2ab 2ac 2b1
1 2b4 2b9 2bd 2c0 2c1 2c6 2c9
1 2cc 2d1 2d5 2d9 2dc 2e0 2e4
2e7 2ea 2ef 2f2 2f5 2f8 2f9 2fe
2ff 1 301 306 30a 30e 311 316
31b 31e 322 323 328 32b 330 331
336 339 33e 33f 344 347 34b 34f
353 357 35a 35b 35d 362 363 365
366 36b 36c 371 373 377 37a 37e
382 385 389 38d 390 393 398 39b
39e 3a1 3a2 3a7 3a8 1 3aa 3af
3b3 3b7 3ba 3bf 3c4 3c7 3cb 3cc
3d1 3d2 3d7 3d9 3dd 3e0 3e4 3e8
3eb 3ef 3f3 3f6 3fa 3fb 400 402
406 409 40d 411 415 419 41d 421
425 429 42d 431 435 439 43d 441
44d 451 455 458 45c 460 462 466
46a 46e 471 475 479 47b 47c 481
1 485 489 48d 490 494 498 49c
4a0 4a3 4a7 4ab 4ae 4b1 4b6 4b9
4bc 4bf 4c0 4c5 4c6 1 4c8 4cd
4d1 4d5 4d8 4dd 4e2 4e5 4e9 4ea
4ef 4f2 4f7 4f8 4fd 500 505 506
50b 50e 512 513 518 51b 520 521
526 529 52d 531 534 537 538 53a
53b 540 541 546 548 54c 54f 551
555 557 563 565 567 568 56d 571
573 57f 581 585 589 58a 58f 593
597 59b 59e 5a2 5a6 5a9 5ac 5b1
5b4 5b7 5ba 5bb 5c0 5c1 1 5c3
5c8 5cc 5d0 5d3 5d8 5dd 5e0 5e4
5e5 5ea 5ed 5f2 5f3 5f8 5fb 600
601 606 609 60d 611 615 619 61c
61d 61f 624 625 627 628 62d 630
635 636 63b 63e 643 644 649 64c
650 651 656 659 65e 65f 664 665
66a 66c 670 673 677 67b 67e 682
686 689 68d 691 692 697 699 69d
6a1 6a4 6a8 6ac 6af 6b3 6b7 6ba
6bd 6c2 6c5 6c8 6cb 6cc 6d1 6d2
1 6d4 6d9 6dd 6e1 6e4 6e9 6ee
6f1 6f5 6f6 6fb 6fc 701 705 709
70c 711 716 719 71d 721 724 725
72a 72d 732 733 738 73b 73f 743
746 747 74c 74d 752 754 758 75b
75f 763 767 76b 76f 773 777 77b
77f 78b 790 794 798 79c 7a0 7a2
7a3 7a8 1 7ac 7b0 7b4 7b7 7bb
7bf 7c3 7c7 7ca 7ce 7d2 7d5 7d8
7dd 7e0 7e3 7e6 7e7 7ec 7ed 1
7ef 7f4 7f8 7fc 7ff 804 809 80c
810 811 816 817 81c 820 824 827
82c 831 834 838 839 83e 841 846
847 84c 84f 853 857 85a 85d 85e
860 861 866 867 86c 86e 872 875
879 87d 881 885 889 88d 891 89d
8a2 8a6 8aa 8ae 8b2 8b4 8b8 8ba
8c6 8c8 8ca 8cb 8d0 8d4 8d6 8e2
8e6 8e8 8e9 8f2 
284
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 e 1d e
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 13 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 8 7 :4 18 17 :2 7
:4 30 2f 2e :2 7 a :2 14 26 :2 30
3c 3f 4e 50 51 :2 4e :2 26 :3 a
:2 10 15 21 5e 61 :2 21 6e 71
:2 21 75 78 :2 21 82 85 8e 96
:2 9f :2 8e b0 :2 85 :2 21 :2 a 54 :2 7
a :2 14 26 :2 30 3c 3f 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :2 a 54 :3 7 :2 12 28 :2 31
41 :2 7 46 :3 4 14 :2 4 15 :2 4
12 4 e 1b 2a 38 45 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 52 54
55 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
87 8a :2 24 92 95 :2 24 a1 a4
ab b4 b7 :2 a4 :2 24 :2 d 58 :2 a
:2 7 :4 13 :2 7 4 :3 1 4 :3 f 4
7 :2 11 23 :2 2d 39 3c 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e 6b 6e :2 1e 72 75 :2 1e
7f 82 8b 93 :2 9c :2 8b a7 :2 82
:2 1e af b2 :2 1e ba bd :2 1e c2
c5 :2 1e cd d0 :2 1e :2 7 51 :3 4
:2 f 21 :2 2a 34 3d :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5e 61 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 55 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4c 4e 4f :2 4c :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 52 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
284
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :7 e :b 10 :11 11
12 :2 11 :2 12 :2 11
:2 12 :2 11 :2 13 :2 11
:2 13 :2 11 :2 13 :2 11
:2 13 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :4 11
:3 10 :11 17 :b 18 :3 17
:14 1b :11 1c :20 1d :3 1c
:11 1f :b 20 :3 1f :9 22
:3 1b :3 27 :3 28 :3 29
:6 2c :5 2d 2b 2f
:5 30 :3 2f :2 31 :5 33
:11 34 :24 35 :3 34 :2 32
:6 31 2e :3 f :5 3c
:11 40 :30 41 :3 40 :a 43
f :3 46 :11 47 :b 48
:17 49 :3 47 :2 4b :3 4c
:3 4d 4e 4c 4b
4c :3 4f :3 46 :2 50
:5 52 :11 53 :b 54 :18 55
:3 53 :2 57 58 :3 59
5a 58 57 58
:3 5b :2 51 :6 50 45
:7 1 
8f4
4
:3 0 1 :3 0 2
:a 0 27f 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 27f 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 27d
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 27d
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 27d
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 27d
0 e :6 0 39
3a 0 1d 10
:3 0 33 :7 0 37
34 35 27d 0
f :6 0 3f 40
0 1f 8 :3 0
9 :2 0 4 3b
:7 0 3e 3c 0
27d 0 12 :6 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
42 43 0 2
:4 0 21 44 46
41 48 47 :2 0
16 :3 0 17 :3 0
4a 4b 0 18
:4 0 13 :3 0 19
:3 0 4e 4f 0
2 :4 0 23 50
52 1a :4 0 1b
:2 0 1c :3 0 25
55 57 :3 0 1d
:4 0 1b :2 0 1e
:4 0 28 5a 5c
:3 0 1b :2 0 3
:3 0 2b 5e 60
:3 0 1b :2 0 1e
:4 0 2e 62 64
:3 0 1b :2 0 1f
:4 0 31 66 68
:3 0 1b :2 0 1e
:4 0 34 6a 6c
:3 0 1b :2 0 5
:3 0 37 6e 70
:3 0 1b :2 0 1e
:4 0 3a 72 74
:3 0 1b :2 0 1f
:4 0 3d 76 78
:3 0 1b :2 0 1e
:4 0 40 7a 7c
:3 0 1b :2 0 6
:3 0 43 7e 80
:3 0 1b :2 0 1e
:4 0 46 82 84
:3 0 1b :2 0 20
:4 0 49 86 88
:3 0 :2 4c 8a :2 0
8c 51 8d 49
8c 0 8e 53
0 1dd 13 :3 0
14 :3 0 8f 90
0 13 :3 0 21
:3 0 92 93 0
22 :2 0 2 :4 0
23 :2 0 24 :2 0
22 :2 0 55 98
9a :3 0 58 94
9c 91 9e 9d
:2 0 16 :3 0 25
:3 0 a0 a1 0
18 :4 0 26 :4 0
1b :2 0 1c :3 0
5c a5 a7 :3 0
5f a2 a9 :2 0
ab 62 ac 9f
ab 0 ad 64
0 1dd 3 :3 0
27 :2 0 66 af
b0 :3 0 b1 :2 0
5 :3 0 27 :2 0
68 b4 b5 :3 0
b6 :2 0 b2 b8
b7 :2 0 6 :3 0
27 :2 0 6a bb
bc :3 0 bd :2 0
be :2 0 b9 c0
bf :2 0 13 :3 0
14 :3 0 c2 c3
0 13 :3 0 21
:3 0 c5 c6 0
28 :2 0 2 :4 0
29 :2 0 24 :2 0
22 :2 0 6c cb
cd :3 0 6f c7
cf c4 d1 d0
:2 0 16 :3 0 25
:3 0 d3 d4 0
18 :4 0 2a :4 0
1b :2 0 1c :3 0
73 d8 da :3 0
1b :2 0 2b :4 0
76 dc de :3 0
1b :2 0 2c :4 0
79 e0 e2 :3 0
1b :2 0 2d :3 0
2e :3 0 2f :3 0
30 :3 0 e7 e8
0 7c e6 ea
31 :4 0 7e e5
ed 81 e4 ef
:3 0 84 d5 f1
:2 0 f3 87 f4
d2 f3 0 f5
89 0 11e 13
:3 0 14 :3 0 f6
f7 0 13 :3 0
21 :3 0 f9 fa
0 22 :2 0 2
:4 0 32 :2 0 24
:2 0 22 :2 0 8b
ff 101 :3 0 8e
fb 103 f8 105
104 :2 0 16 :3 0
25 :3 0 107 108
0 18 :4 0 33
:4 0 1b :2 0 1c
:3 0 92 10c 10e
:3 0 95 109 110
:2 0 112 98 113
106 112 0 114
9a 0 11e 34
:3 0 35 :3 0 115
116 0 2f :3 0
30 :3 0 118 119
0 36 :3 0 9c
117 11c :2 0 11e
9f 11f c1 11e
0 120 a3 0
1dd a :3 0 3
:3 0 121 122 0
1dd e :3 0 5
:3 0 124 125 0
1dd d :3 0 6
:3 0 127 128 0
1dd 37 :3 0 f
:3 0 38 :3 0 39
:3 0 a :4 0 3a
1 :8 0 135 8
:3 0 3b :3 0 130
131 0 3c :3 0
132 133 0 135
a5 188 3d :3 0
8 :3 0 3b :3 0
137 138 0 3c
:3 0 139 13a 0
13c a8 13e aa
13d 13c :2 0 186
3e :3 0 8 :3 0
3b :3 0 141 142
0 3c :3 0 143
144 0 17e 13
:3 0 14 :3 0 146
147 0 13 :3 0
21 :3 0 149 14a
0 3f :2 0 2
:4 0 40 :2 0 24
:2 0 22 :2 0 ac
14f 151 :3 0 af
14b 153 148 155
154 :2 0 16 :3 0
25 :3 0 157 158
0 18 :4 0 41
:4 0 1b :2 0 1c
:3 0 b3 15c 15e
:3 0 1b :2 0 2b
:4 0 b6 160 162
:3 0 1b :2 0 42
:4 0 b9 164 166
:3 0 1b :2 0 3c
:3 0 bc 168 16a
:3 0 1b :2 0 43
:4 0 bf 16c 16e
:3 0 1b :2 0 44
:3 0 45 :3 0 22
:2 0 46 :2 0 c2
171 175 c6 170
177 :3 0 c9 159
179 :2 0 17b cc
17c 156 17b 0
17d ce 0 17e
d0 181 :3 0 181
0 181 180 17e
17f :6 0 183 2
:3 0 d3 185 d5
184 183 :2 0 186
d7 :2 0 188 0
188 187 135 186
:6 0 1dd 1 :3 0
c :3 0 47 :4 0
18b 18c :3 0 18a
18d 0 1dd 13
:3 0 14 :3 0 18f
190 0 13 :3 0
21 :3 0 192 193
0 48 :2 0 2
:4 0 49 :2 0 24
:2 0 22 :2 0 da
198 19a :3 0 dd
194 19c 191 19e
19d :2 0 16 :3 0
25 :3 0 1a0 1a1
0 18 :4 0 4a
:4 0 1b :2 0 1c
:3 0 e1 1a5 1a7
:3 0 1b :2 0 2b
:4 0 e4 1a9 1ab
:3 0 1b :2 0 2c
:4 0 e7 1ad 1af
:3 0 1b :2 0 2d
:3 0 2e :3 0 8
:3 0 3b :3 0 1b4
1b5 0 ea 1b3
1b7 31 :4 0 ec
1b2 1ba ef 1b1
1bc :3 0 1b :2 0
4b :4 0 f2 1be
1c0 :3 0 1b :2 0
1e :4 0 f5 1c2
1c4 :3 0 1b :2 0
c :3 0 f8 1c6
1c8 :3 0 1b :2 0
1e :4 0 fb 1ca
1cc :3 0 fe 1a2
1ce :2 0 1d0 101
1d1 19f 1d0 0
1d2 103 0 1dd
34 :3 0 4c :3 0
1d3 1d4 0 8
:3 0 3b :3 0 1d6
1d7 0 c :3 0
36 :3 0 105 1d5
1db :2 0 1dd 109
27e 8 :3 0 4d
:2 0 4 1de 1df
0 13 :3 0 14
:3 0 1e1 1e2 0
13 :3 0 21 :3 0
1e4 1e5 0 3f
:2 0 2 :4 0 4e
:2 0 24 :2 0 22
:2 0 114 1ea 1ec
:3 0 117 1e6 1ee
1e3 1f0 1ef :2 0
16 :3 0 25 :3 0
1f2 1f3 0 18
:4 0 4f :4 0 1b
:2 0 1c :3 0 11b
1f7 1f9 :3 0 11e
1f4 1fb :2 0 214
16 :3 0 25 :3 0
1fd 1fe 0 18
:4 0 50 :4 0 1b
:2 0 8 :3 0 51
:3 0 203 204 0
121 202 206 :3 0
1b :2 0 4b :4 0
124 208 20a :3 0
1b :2 0 8 :3 0
52 :3 0 20d 20e
0 127 20c 210
:3 0 12a 1ff 212
:2 0 214 12d 215
1f1 214 0 216
130 0 226 53
:3 0 12 :3 0 8
:3 0 51 :3 0 54
:3 0 8 :3 0 52
:3 0 3 :3 0 55
:4 0 56 1 :a 0
222 :2 0 226 218
220 :2 0 7 :3 0
12 :3 0 224 :2 0
226 132 228 136
227 226 :2 0 27c
3e :3 0 8 :3 0
3b :3 0 22b 22c
0 3c :3 0 22d
22e 0 274 13
:3 0 14 :3 0 230
231 0 13 :3 0
21 :3 0 233 234
0 3f :2 0 2
:4 0 57 :2 0 24
:2 0 22 :2 0 138
239 23b :3 0 13b
235 23d 232 23f
23e :2 0 16 :3 0
25 :3 0 241 242
0 18 :4 0 58
:4 0 1b :2 0 1c
:3 0 13f 246 248
:3 0 142 243 24a
:2 0 264 16 :3 0
25 :3 0 24c 24d
0 18 :4 0 42
:4 0 1b :2 0 3c
:3 0 145 251 253
:3 0 1b :2 0 43
:4 0 148 255 257
:3 0 1b :2 0 44
:3 0 45 :3 0 22
:2 0 46 :2 0 14b
25a 25e 14f 259
260 :3 0 152 24e
262 :2 0 264 155
265 240 264 0
266 158 0 274
53 :3 0 12 :3 0
54 :3 0 8 :3 0
52 :3 0 3 :3 0
55 :4 0 59 1
:a 0 270 :2 0 274
268 26e :2 0 7
:3 0 12 :3 0 272
:2 0 274 15a 277
:3 0 277 0 277
276 274 275 :6 0
279 1 :3 0 15f
27b 161 27a 279
:2 0 27c 163 :2 0
27e 166 27e 27d
1dd 27c :6 0 27f
:2 0 2 14 27e
282 :3 0 281 27f
283 :8 0 
16d
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
45 1 51 2
54 56 2 59
5b 2 5d 5f
2 61 63 2
65 67 2 69
6b 2 6d 6f
2 71 73 2
75 77 2 79
7b 2 7d 7f
2 81 83 2
85 87 4 4d
53 58 89 1
8b 1 8d 2
97 99 3 95
96 9b 2 a4
a6 2 a3 a8
1 aa 1 ac
1 ae 1 b3
1 ba 2 ca
cc 3 c8 c9
ce 2 d7 d9
2 db dd 2
df e1 1 e9
2 eb ec 2
e3 ee 2 d6
f0 1 f2 1
f4 2 fe 100
3 fc fd 102
2 10b 10d 2
10a 10f 1 111
1 113 2 11a
11b 3 f5 114
11d 1 11f 2
12f 134 1 13b
1 136 2 14e
150 3 14c 14d
152 2 15b 15d
2 15f 161 2
163 165 2 167
169 2 16b 16d
3 172 173 174
2 16f 176 2
15a 178 1 17a
1 17c 2 145
17d 1 181 1
140 2 13e 185
2 197 199 3
195 196 19b 2
1a4 1a6 2 1a8
1aa 2 1ac 1ae
1 1b6 2 1b8
1b9 2 1b0 1bb
2 1bd 1bf 2
1c1 1c3 2 1c5
1c7 2 1c9 1cb
2 1a3 1cd 1
1cf 1 1d1 3
1d8 1d9 1da a
8e ad 120 123
126 129 188 18e
1d2 1dc 2 1e9
1eb 3 1e7 1e8
1ed 2 1f6 1f8
2 1f5 1fa 2
201 205 2 207
209 2 20b 20f
2 200 211 2
1fc 213 1 215
3 216 221 225
1 1e0 2 238
23a 3 236 237
23c 2 245 247
2 244 249 2
250 252 2 254
256 3 25b 25c
25d 2 258 25f
2 24f 261 2
24b 263 1 265
4 22f 266 26f
273 1 277 1
22a 2 228 27b
6 1b 22 29
30 36 3d 
1
4
0 
282
0
1
14
4
a
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
3 1 0
7 1 0
32 1 0
1d 1 0
24 1 0
2 0 1
38 1 0
0

/
SHOW ERRORS FUNCTION SP_A_REQRES;
ALTER FUNCTION SP_A_REQRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_POOLRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_POOLRES ==
CREATE OR REPLACE FUNCTION SP_A_POOLRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5f
2 :e:
1FUNCTION:
1SP_A_POOLRES:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_POOLRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_POOLRES(26) :: cplan.sql(6987) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_POOLRES(31) :: cplan.sql(6992) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_POOLRES(34) :: cplan.sql(6995) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_POL:
1TYPE_ID:
1TMT_POOLS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOLS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
155:
1           EXCEPTION:: SP_A_POOLRES(56) :: cplan.sql(7017) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
1=:
1RECORD_ALREADY_ASSIGNED:
14:
170:
1       RETURN_STATUS:: SP_A_POOLRES(71) :: cplan.sql(7032) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
177:
1           EXCEPTION:: SP_A_POOLRES(78) :: cplan.sql(7039) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
189:
1           EXCEPTION:: SP_A_POOLRES(90) :: cplan.sql(7051) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2b3
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a 52 10 a0 7e b4 2e :2 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :3 a0 6b d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
b4 2e d :8 a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
6b d b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
2b3
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 131 120
124 100 12c 11f 151 13c 140 11c
144 14c 13b 158 15c 138 160 164
168 16b 170 171 1 173 178 17c
180 183 188 18c 190 193 198 199
19b 1a0 1a3 1a7 1a8 1ad 1b2 1b5
1ba 1bb 1c0 1c3 1c7 1c8 1cd 1d0
1d5 1d6 1db 1de 1e3 1e4 1e9 1ec
1f1 1f2 1f7 1fa 1fe 1ff 204 207
20c 20d 212 215 21a 21b 220 223
228 229 22e 231 235 236 23b 23e
243 244 249 24c 251 252 257 258
25d 25f 263 266 26a 26e 271 275
279 27c 27f 284 287 28a 28d 28e
293 294 1 296 29b 29f 2a3 2a6
2ab 2b0 2b3 2b7 2b8 2bd 2be 2c3
2c5 2c9 2cc 2d0 2d3 2d4 2d9 2dc
2df 2e3 2e6 2e7 2ec 2ef 1 2f2
2f7 2fb 2fe 2ff 304 307 1 30a
30f 313 317 31a 31e 322 325 328
32d 330 333 336 337 33c 33d 1
33f 344 348 34c 34f 354 359 35c
360 361 366 369 36e 36f 374 377
37c 37d 382 385 389 38d 391 395
398 399 39b 3a0 3a1 3a3 3a4 3a9
3aa 3af 3b1 3b5 3b8 3bc 3c0 3c3
3c7 3cb 3ce 3d1 3d6 3d9 3dc 3df
3e0 3e5 3e6 1 3e8 3ed 3f1 3f5
3f8 3fd 402 405 409 40a 40f 410
415 417 41b 41e 422 426 429 42d
431 434 438 439 43e 440 444 447
44b 44f 453 457 45b 45f 463 467
46b 46f 473 477 47a 47e 482 486
48a 48e 492 49e 4a2 4a6 4a9 4ad
4b1 4b3 4b7 4bb 4bf 4c2 4c6 4ca
4cc 4cd 4d2 1 4d6 4da 4de 4e1
4e5 4e9 4ed 4f1 4f4 4f8 4fc 4ff
502 507 50a 50d 510 511 516 517
1 519 51e 522 526 529 52e 533
536 53a 53b 540 543 548 549 54e
551 556 557 55c 55f 563 564 569
56c 571 572 577 57a 57e 582 585
588 589 58b 58c 591 592 597 599
59d 5a0 5a2 5a6 5a8 5b4 5b6 5b8
5b9 5be 5c2 5c4 5d0 5d2 5d6 5da
5db 5e0 5e4 5e8 5ec 5f0 5f4 5f8
5fc 600 604 605 607 60b 60f 613
616 617 619 61c 61f 620 625 629
62d 631 634 638 63a 63e 641 645
649 64c 650 654 657 65a 65f 662
665 668 669 66e 66f 1 671 676
67a 67e 681 686 68b 68e 692 693
698 69b 6a0 6a1 6a6 6a9 6ae 6af
6b4 6b7 6bb 6bf 6c3 6c4 6c6 6cb
6cc 6ce 6cf 6d4 6d7 6dc 6dd 6e2
6e5 6ea 6eb 6f0 6f3 6f7 6f8 6fd
700 705 706 70b 70c 711 713 717
71a 71e 722 725 729 72d 730 731
733 737 73b 73c 741 743 747 74b
74e 752 756 759 75d 761 764 767
76c 76f 772 775 776 77b 77c 1
77e 783 787 78b 78e 793 798 79b
79f 7a0 7a5 7a6 7ab 7af 7b3 7b6
7bb 7c0 7c3 7c7 7cb 7ce 7cf 7d4
7d7 7dc 7dd 7e2 7e5 7e9 7ed 7f0
7f1 7f6 7f7 7fc 7fe 802 805 809
80d 811 815 819 81d 821 825 829
835 83a 83e 842 846 84a 84c 84d
852 1 856 85a 85e 861 865 869
86d 871 874 878 87c 87f 882 887
88a 88d 890 891 896 897 1 899
89e 8a2 8a6 8a9 8ae 8b3 8b6 8ba
8bb 8c0 8c1 8c6 8ca 8ce 8d1 8d6
8db 8de 8e2 8e3 8e8 8eb 8f0 8f1
8f6 8f9 8fd 901 904 907 908 90a
90b 910 911 916 918 91c 91f 923
927 92b 92f 933 937 93b 947 94c
950 954 958 95c 95e 962 964 970
972 974 975 97a 97e 980 98c 990
992 993 99c 
2b3
2
0 1 a 6 9 :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 14 23 14
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 54 5a 5d :2 54 6b 81
8 :2 6b d 10 :2 6b 13 16 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 28 2b :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 2a 2d :2 6b
32 35 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 :4 9 8 7 :4 1b 1a
19 :2 7 :4 34 33 32 :2 7 a :2 14
26 :2 30 3c 3f 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
6f 72 :2 21 76 79 :2 21 83 86
8f 97 :2 a0 :2 8f b1 :2 86 :2 21 :2 a
55 :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5f 62 :2 21 :2 a 55 :3 7 :2 12
28 :2 31 41 :2 7 4a :3 4 14 :2 4
15 :2 4 12 :2 4 14 :2 1d 4 e
1b 2a 3a 47 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 55 56 :2 53 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 88 8b :2 24
93 96 :2 24 a2 a5 ac b5 b8
:2 a5 :2 24 :2 d 59 :2 a :2 7 :4 13 :2 7
4 :3 1 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4c 4e 4f :2 4c :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 8c 94 :2 8c
a6 :2 83 :2 1e ae b1 :2 1e b9 bc
:2 1e c1 c4 :2 1e cc cf :2 1e :2 7
52 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 50 52 53 :2 50
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
2b3
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :5 2c :6 2f
:5 30 2e 32 :5 33
:3 32 :2 34 :5 36 :11 37
:24 38 :3 37 :2 35 :6 34
31 :3 11 :5 3d :7 3f
40 :3 3f :9 42 :5 43
:3 42 :11 46 :2e 47 :3 46
:c 49 11 :3 4c :11 4d
:b 4e :17 4f :3 4d :2 51
:3 52 :3 53 54 52
51 52 :3 55 :3 4c
:2 56 :5 58 :11 59 :b 5a
:18 5b :3 59 :2 5d 5e
:3 5f 60 5e 5d
5e :3 61 :2 57 :6 56
4b :7 1 
99e
4
:3 0 1 :3 0 2
:a 0 2ae 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2ae 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2ac
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2ac
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2ac
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2ac
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 2ac 0 f
:6 0 11 :2 0 1f
10 :3 0 39 :7 0
3d 3a 3b 2ac
0 12 :6 0 45
46 0 21 10
:3 0 3f :7 0 43
40 41 2ac 0
13 :6 0 4b 4c
0 23 8 :3 0
9 :2 0 4 47
:7 0 4a 48 0
2ac 0 14 :6 0
15 :3 0 16 :3 0
15 :3 0 17 :3 0
4e 4f 0 2
:4 0 25 50 52
4d 54 53 :2 0
18 :3 0 19 :3 0
56 57 0 1a
:4 0 15 :3 0 1b
:3 0 5a 5b 0
2 :4 0 27 5c
5e 1c :4 0 1d
:2 0 1e :3 0 29
61 63 :3 0 1f
:4 0 1d :2 0 20
:4 0 2c 66 68
:3 0 1d :2 0 3
:3 0 2f 6a 6c
:3 0 1d :2 0 20
:4 0 32 6e 70
:3 0 1d :2 0 21
:4 0 35 72 74
:3 0 1d :2 0 20
:4 0 38 76 78
:3 0 1d :2 0 5
:3 0 3b 7a 7c
:3 0 1d :2 0 20
:4 0 3e 7e 80
:3 0 1d :2 0 21
:4 0 41 82 84
:3 0 1d :2 0 20
:4 0 44 86 88
:3 0 1d :2 0 6
:3 0 47 8a 8c
:3 0 1d :2 0 20
:4 0 4a 8e 90
:3 0 1d :2 0 22
:4 0 4d 92 94
:3 0 50 58 96
:2 0 98 55 99
55 98 0 9a
57 0 20c 15
:3 0 16 :3 0 9b
9c 0 15 :3 0
23 :3 0 9e 9f
0 24 :2 0 2
:4 0 25 :2 0 26
:2 0 24 :2 0 59
a4 a6 :3 0 5c
a0 a8 9d aa
a9 :2 0 18 :3 0
27 :3 0 ac ad
0 1a :4 0 28
:4 0 1d :2 0 1e
:3 0 60 b1 b3
:3 0 63 ae b5
:2 0 b7 66 b8
ab b7 0 b9
68 0 20c 3
:3 0 29 :2 0 6a
bb bc :3 0 bd
:2 0 be :2 0 5
:3 0 29 :2 0 6c
c1 c2 :3 0 c3
:2 0 c4 :2 0 bf
c6 c5 :2 0 6
:3 0 29 :2 0 6e
c9 ca :3 0 cb
:2 0 cc :2 0 c7
ce cd :2 0 15
:3 0 16 :3 0 d0
d1 0 15 :3 0
23 :3 0 d3 d4
0 2a :2 0 2
:4 0 2b :2 0 26
:2 0 24 :2 0 70
d9 db :3 0 73
d5 dd d2 df
de :2 0 18 :3 0
27 :3 0 e1 e2
0 1a :4 0 2c
:4 0 1d :2 0 1e
:3 0 77 e6 e8
:3 0 1d :2 0 2d
:4 0 7a ea ec
:3 0 1d :2 0 2e
:4 0 7d ee f0
:3 0 1d :2 0 2f
:3 0 30 :3 0 31
:3 0 32 :3 0 f5
f6 0 80 f4
f8 33 :4 0 82
f3 fb 85 f2
fd :3 0 88 e3
ff :2 0 101 8b
102 e0 101 0
103 8d 0 12c
15 :3 0 16 :3 0
104 105 0 15
:3 0 23 :3 0 107
108 0 24 :2 0
2 :4 0 34 :2 0
26 :2 0 24 :2 0
8f 10d 10f :3 0
92 109 111 106
113 112 :2 0 18
:3 0 27 :3 0 115
116 0 1a :4 0
35 :4 0 1d :2 0
1e :3 0 96 11a
11c :3 0 99 117
11e :2 0 120 9c
121 114 120 0
122 9e 0 12c
36 :3 0 37 :3 0
123 124 0 31
:3 0 32 :3 0 126
127 0 38 :3 0
a0 125 12a :2 0
12c a3 12d cf
12c 0 12e a7
0 20c a :3 0
3 :3 0 12f 130
0 20c e :3 0
5 :3 0 132 133
0 20c d :3 0
6 :3 0 135 136
0 20c f :3 0
31 :3 0 39 :3 0
139 13a 0 138
13b 0 20c 3a
:3 0 12 :3 0 3b
:3 0 3c :3 0 a
:4 0 3d 1 :8 0
148 8 :3 0 3e
:3 0 143 144 0
3f :3 0 145 146
0 148 a9 19b
40 :3 0 8 :3 0
3e :3 0 14a 14b
0 3f :3 0 14c
14d 0 14f ac
151 ae 150 14f
:2 0 199 41 :3 0
8 :3 0 3e :3 0
154 155 0 3f
:3 0 156 157 0
191 15 :3 0 16
:3 0 159 15a 0
15 :3 0 23 :3 0
15c 15d 0 42
:2 0 2 :4 0 43
:2 0 26 :2 0 24
:2 0 b0 162 164
:3 0 b3 15e 166
15b 168 167 :2 0
18 :3 0 27 :3 0
16a 16b 0 1a
:4 0 44 :4 0 1d
:2 0 1e :3 0 b7
16f 171 :3 0 1d
:2 0 2d :4 0 ba
173 175 :3 0 1d
:2 0 45 :4 0 bd
177 179 :3 0 1d
:2 0 3f :3 0 c0
17b 17d :3 0 1d
:2 0 46 :4 0 c3
17f 181 :3 0 1d
:2 0 47 :3 0 48
:3 0 24 :2 0 49
:2 0 c6 184 188
ca 183 18a :3 0
cd 16c 18c :2 0
18e d0 18f 169
18e 0 190 d2
0 191 d4 194
:3 0 194 0 194
193 191 192 :6 0
196 2 :3 0 d7
198 d9 197 196
:2 0 199 db :2 0
19b 0 19b 19a
148 199 :6 0 20c
1 :3 0 c :3 0
4a :4 0 19e 19f
:3 0 19d 1a0 0
20c 13 :3 0 4b
:3 0 f :3 0 12
:3 0 a :3 0 e
:3 0 d :3 0 c
:3 0 de 1a3 1aa
1a2 1ab 0 20c
2f :3 0 13 :3 0
11 :2 0 e5 1ad
1b0 4c :2 0 24
:2 0 ea 1b2 1b4
:3 0 13 :3 0 31
:3 0 4d :3 0 1b7
1b8 0 1b6 1b9
0 1bb ed 1bc
1b5 1bb 0 1bd
ef 0 20c 15
:3 0 16 :3 0 1be
1bf 0 15 :3 0
23 :3 0 1c1 1c2
0 4e :2 0 2
:4 0 4f :2 0 26
:2 0 24 :2 0 f1
1c7 1c9 :3 0 f4
1c3 1cb 1c0 1cd
1cc :2 0 18 :3 0
27 :3 0 1cf 1d0
0 1a :4 0 50
:4 0 1d :2 0 1e
:3 0 f8 1d4 1d6
:3 0 1d :2 0 2d
:4 0 fb 1d8 1da
:3 0 1d :2 0 2e
:4 0 fe 1dc 1de
:3 0 1d :2 0 2f
:3 0 30 :3 0 13
:3 0 101 1e2 1e4
33 :4 0 103 1e1
1e7 106 1e0 1e9
:3 0 1d :2 0 51
:4 0 109 1eb 1ed
:3 0 1d :2 0 20
:4 0 10c 1ef 1f1
:3 0 1d :2 0 c
:3 0 10f 1f3 1f5
:3 0 1d :2 0 20
:4 0 112 1f7 1f9
:3 0 115 1d1 1fb
:2 0 1fd 118 1fe
1ce 1fd 0 1ff
11a 0 20c 36
:3 0 52 :3 0 200
201 0 2f :3 0
13 :3 0 11 :2 0
11c 203 206 c
:3 0 38 :3 0 11f
202 20a :2 0 20c
123 2ad 8 :3 0
53 :2 0 4 20d
20e 0 15 :3 0
16 :3 0 210 211
0 15 :3 0 23
:3 0 213 214 0
42 :2 0 2 :4 0
54 :2 0 26 :2 0
24 :2 0 131 219
21b :3 0 134 215
21d 212 21f 21e
:2 0 18 :3 0 27
:3 0 221 222 0
1a :4 0 55 :4 0
1d :2 0 1e :3 0
138 226 228 :3 0
13b 223 22a :2 0
243 18 :3 0 27
:3 0 22c 22d 0
1a :4 0 56 :4 0
1d :2 0 8 :3 0
57 :3 0 232 233
0 13e 231 235
:3 0 1d :2 0 51
:4 0 141 237 239
:3 0 1d :2 0 8
:3 0 58 :3 0 23c
23d 0 144 23b
23f :3 0 147 22e
241 :2 0 243 14a
244 220 243 0
245 14d 0 255
59 :3 0 14 :3 0
8 :3 0 57 :3 0
5a :3 0 8 :3 0
58 :3 0 3 :3 0
5b :4 0 5c 1
:a 0 251 :2 0 255
247 24f :2 0 7
:3 0 14 :3 0 253
:2 0 255 14f 257
153 256 255 :2 0
2ab 41 :3 0 8
:3 0 3e :3 0 25a
25b 0 3f :3 0
25c 25d 0 2a3
15 :3 0 16 :3 0
25f 260 0 15
:3 0 23 :3 0 262
263 0 42 :2 0
2 :4 0 5d :2 0
26 :2 0 24 :2 0
155 268 26a :3 0
158 264 26c 261
26e 26d :2 0 18
:3 0 27 :3 0 270
271 0 1a :4 0
5e :4 0 1d :2 0
1e :3 0 15c 275
277 :3 0 15f 272
279 :2 0 293 18
:3 0 27 :3 0 27b
27c 0 1a :4 0
45 :4 0 1d :2 0
3f :3 0 162 280
282 :3 0 1d :2 0
46 :4 0 165 284
286 :3 0 1d :2 0
47 :3 0 48 :3 0
24 :2 0 49 :2 0
168 289 28d 16c
288 28f :3 0 16f
27d 291 :2 0 293
172 294 26f 293
0 295 175 0
2a3 59 :3 0 14
:3 0 5a :3 0 8
:3 0 58 :3 0 3
:3 0 5b :4 0 5f
1 :a 0 29f :2 0
2a3 297 29d :2 0
7 :3 0 14 :3 0
2a1 :2 0 2a3 177
2a6 :3 0 2a6 0
2a6 2a5 2a3 2a4
:6 0 2a8 1 :3 0
17c 2aa 17e 2a9
2a8 :2 0 2ab 180
:2 0 2ad 183 2ad
2ac 20c 2ab :6 0
2ae :2 0 2 14
2ad 2b1 :3 0 2b0
2ae 2b2 :8 0 
18c
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 44 1
51 1 5d 2
60 62 2 65
67 2 69 6b
2 6d 6f 2
71 73 2 75
77 2 79 7b
2 7d 7f 2
81 83 2 85
87 2 89 8b
2 8d 8f 2
91 93 4 59
5f 64 95 1
97 1 99 2
a3 a5 3 a1
a2 a7 2 b0
b2 2 af b4
1 b6 1 b8
1 ba 1 c0
1 c8 2 d8
da 3 d6 d7
dc 2 e5 e7
2 e9 eb 2
ed ef 1 f7
2 f9 fa 2
f1 fc 2 e4
fe 1 100 1
102 2 10c 10e
3 10a 10b 110
2 119 11b 2
118 11d 1 11f
1 121 2 128
129 3 103 122
12b 1 12d 2
142 147 1 14e
1 149 2 161
163 3 15f 160
165 2 16e 170
2 172 174 2
176 178 2 17a
17c 2 17e 180
3 185 186 187
2 182 189 2
16d 18b 1 18d
1 18f 2 158
190 1 194 1
153 2 151 198
6 1a4 1a5 1a6
1a7 1a8 1a9 2
1ae 1af 1 1b3
2 1b1 1b3 1
1ba 1 1bc 2
1c6 1c8 3 1c4
1c5 1ca 2 1d3
1d5 2 1d7 1d9
2 1db 1dd 1
1e3 2 1e5 1e6
2 1df 1e8 2
1ea 1ec 2 1ee
1f0 2 1f2 1f4
2 1f6 1f8 2
1d2 1fa 1 1fc
1 1fe 2 204
205 3 207 208
209 d 9a b9
12e 131 134 137
13c 19b 1a1 1ac
1bd 1ff 20b 2
218 21a 3 216
217 21c 2 225
227 2 224 229
2 230 234 2
236 238 2 23a
23e 2 22f 240
2 22b 242 1
244 3 245 250
254 1 20f 2
267 269 3 265
266 26b 2 274
276 2 273 278
2 27f 281 2
283 285 3 28a
28b 28c 2 287
28e 2 27e 290
2 27a 292 1
294 4 25e 295
29e 2a2 1 2a6
1 259 2 257
2aa 8 1b 22
29 30 36 3c
42 49 
1
4
0 
2b1
0
1
14
4
c
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
2 0 1
3 1 0
7 1 0
3e 1 0
38 1 0
1d 1 0
32 1 0
24 1 0
44 1 0
0

/
SHOW ERRORS FUNCTION SP_A_POOLRES;
ALTER FUNCTION SP_A_POOLRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_DOCRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_DOCRES ==
CREATE OR REPLACE FUNCTION SP_A_DOCRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
7e
2 :e:
1FUNCTION:
1SP_A_DOCRES:
1TABLE_TYPE001:
1PLS_INTEGER:
1ID:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_DOCRES(:
1COALESCE:
1TO_CHAR:
1NULL:
1, :
1':
1);:
1CHECK_TRACE:
11:
127:
1+:
1FPUT:
1               ENTER:: SP_A_DOCRES(28) :: cplan.sql(7105) :: :
1IS NULL:
18:
1      RETURN_INVALID:: SP_A_DOCRES(33) :: cplan.sql(7110) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
135:
1                EXIT:: SP_A_DOCRES(36) :: cplan.sql(7113) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
1SC_TABLE_DOC:
1TYPE_ID:
1TMT_DOCUMENTS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_DOCUMENTS WHERE ELEMENT_ID = h_element+
1_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
158:
1           EXCEPTION:: SP_A_DOCRES(59) :: cplan.sql(7136) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1ELSIF:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSIGNED_SCORECARDS WHERE ELEMENT_ID =+
1 h_element_id:
173:
1           EXCEPTION:: SP_A_DOCRES(74) :: cplan.sql(7151) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOL_DOCUMENTS WHERE ELEMENT_ID = h_el+
1ement_id:
188:
1           EXCEPTION:: SP_A_DOCRES(89) :: cplan.sql(7166) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_RESOURCE_DOCUMENTS WHERE ELEMENT_ID = +
1h_element_id:
1103:
1           EXCEPTION:: SP_A_DOCRES(104) :: cplan.sql(7181) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CLIENT_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1118:
1           EXCEPTION:: SP_A_DOCRES(119) :: cplan.sql(7196) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSET_DOCUMENTS WHERE ELEMENT_ID = h_e+
1lement_id:
1133:
1           EXCEPTION:: SP_A_DOCRES(134) :: cplan.sql(7211) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_VENDOR_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1148:
1           EXCEPTION:: SP_A_DOCRES(149) :: cplan.sql(7226) :: :
1SYS_GUID:
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
14:
1164:
1       RETURN_STATUS:: SP_A_DOCRES(165) :: cplan.sql(7242) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1171:
1           EXCEPTION:: SP_A_DOCRES(172) :: cplan.sql(7249) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1183:
1           EXCEPTION:: SP_A_DOCRES(184) :: cplan.sql(7261) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
566
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a 52 10 a0 7e b4 2e
:2 5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 51 a5
b a0 7e a0 6b b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 19 :2 a0 51 a5 b a0 7e
a0 6b b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
19 :2 a0 51 a5 b a0 7e a0
6b b4 2e :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 19
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 b4 2e
d :8 a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 51 a5 b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
566
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10b fa
fe d9 106 f9 127 116 11a f6
122 115 143 132 136 112 13e 131
163 14e 152 12e 156 15e 14d 16a
16e 14a 172 176 17a 17d 182 183
1 185 18a 18e 192 195 19a 19e
1a2 1a5 1aa 1ab 1ad 1b2 1b5 1b9
1ba 1bf 1c4 1c7 1cb 1cf 1d3 1d4
1d6 1db 1dc 1de 1df 1e4 1e7 1ec
1ed 1f2 1f5 1fa 1fb 200 203 207
208 20d 210 215 216 21b 21e 223
224 229 22c 231 232 237 23a 23e
23f 244 247 24c 24d 252 255 25a
25b 260 263 268 269 26e 271 275
276 27b 27e 283 284 289 28c 291
292 297 298 29d 29f 2a3 2a6 2aa
2ae 2b1 2b5 2b9 2bc 2bf 2c4 2c7
2ca 2cd 2ce 2d3 2d4 1 2d6 2db
2df 2e3 2e6 2eb 2f0 2f3 2f7 2f8
2fd 2fe 303 305 309 30c 310 313
314 319 31c 31f 323 326 327 32c
32f 1 332 337 33b 33e 33f 344
347 1 34a 34f 353 357 35a 35e
362 365 368 36d 370 373 376 377
37c 37d 1 37f 384 388 38c 38f
394 399 39c 3a0 3a1 3a6 3a9 3ae
3af 3b4 3b7 3bc 3bd 3c2 3c5 3c9
3cd 3d1 3d5 3d8 3d9 3db 3e0 3e1
3e3 3e4 3e9 3ea 3ef 3f1 3f5 3f8
3fc 400 403 407 40b 40e 411 416
419 41c 41f 420 425 426 1 428
42d 431 435 438 43d 442 445 449
44a 44f 450 455 457 45b 45e 462
466 469 46d 471 474 478 479 47e
480 484 487 48b 48f 493 497 49b
49f 4a3 4a7 4ab 4af 4b3 4b7 4bb
4bf 4c2 4c3 4c5 4c9 4cc 4d0 4d3
4d4 4d9 4dd 4e1 4e5 4e9 4ed 4f9
4fd 501 504 508 50c 50e 512 516
51a 51d 521 525 527 528 52d 1
531 535 539 53c 540 544 548 54c
54f 553 557 55a 55d 562 565 568
56b 56c 571 572 1 574 579 57d
581 584 589 58e 591 595 596 59b
59e 5a3 5a4 5a9 5ac 5b1 5b2 5b7
5ba 5be 5bf 5c4 5c7 5cc 5cd 5d2
5d5 5d9 5dd 5e0 5e3 5e4 5e6 5e7
5ec 5ed 5f2 5f4 5f8 5fb 5fd 601
603 60f 611 613 614 619 61d 61f
62b 62d 631 633 637 63b 63e 63f
641 645 648 64c 64f 650 655 659
65d 661 665 669 675 679 67d 680
684 688 68a 68e 692 696 699 69d
6a1 6a3 6a4 6a9 1 6ad 6b1 6b5
6b8 6bc 6c0 6c4 6c8 6cb 6cf 6d3
6d6 6d9 6de 6e1 6e4 6e7 6e8 6ed
6ee 1 6f0 6f5 6f9 6fd 700 705
70a 70d 711 712 717 71a 71f 720
725 728 72d 72e 733 736 73a 73b
740 743 748 749 74e 751 755 759
75c 75f 760 762 763 768 769 76e
770 774 777 779 77d 77f 78b 78d
78f 790 795 799 79b 7a7 7a9 7ad
7af 7b3 7b7 7bb 7be 7bf 7c1 7c5
7c8 7cc 7cf 7d0 7d5 7d9 7dd 7e1
7e5 7e9 7f5 7f9 7fd 800 804 808
80a 80e 812 816 819 81d 821 823
824 829 1 82d 831 835 838 83c
840 844 848 84b 84f 853 856 859
85e 861 864 867 868 86d 86e 1
870 875 879 87d 880 885 88a 88d
891 892 897 89a 89f 8a0 8a5 8a8
8ad 8ae 8b3 8b6 8ba 8bb 8c0 8c3
8c8 8c9 8ce 8d1 8d5 8d9 8dc 8df
8e0 8e2 8e3 8e8 8e9 8ee 8f0 8f4
8f7 8f9 8fd 8ff 90b 90d 90f 910
915 919 91b 927 929 92d 92f 933
937 93b 93e 93f 941 945 948 94c
94f 950 955 959 95d 961 965 969
975 979 97d 980 984 988 98a 98e
992 996 999 99d 9a1 9a3 9a4 9a9
1 9ad 9b1 9b5 9b8 9bc 9c0 9c4
9c8 9cb 9cf 9d3 9d6 9d9 9de 9e1
9e4 9e7 9e8 9ed 9ee 1 9f0 9f5
9f9 9fd a00 a05 a0a a0d a11 a12
a17 a1a a1f a20 a25 a28 a2d a2e
a33 a36 a3a a3b a40 a43 a48 a49
a4e a51 a55 a59 a5c a5f a60 a62
a63 a68 a69 a6e a70 a74 a77 a79
a7d a7f a8b a8d a8f a90 a95 a99
a9b aa7 aa9 aad aaf ab3 ab7 abb
abe abf ac1 ac5 ac8 acc acf ad0
ad5 ad9 add ae1 ae5 ae9 af5 af9
afd b00 b04 b08 b0a b0e b12 b16
b19 b1d b21 b23 b24 b29 1 b2d
b31 b35 b38 b3c b40 b44 b48 b4b
b4f b53 b56 b59 b5e b61 b64 b67
b68 b6d b6e 1 b70 b75 b79 b7d
b80 b85 b8a b8d b91 b92 b97 b9a
b9f ba0 ba5 ba8 bad bae bb3 bb6
bba bbb bc0 bc3 bc8 bc9 bce bd1
bd5 bd9 bdc bdf be0 be2 be3 be8
be9 bee bf0 bf4 bf7 bf9 bfd bff
c0b c0d c0f c10 c15 c19 c1b c27
c29 c2d c2f c33 c37 c3b c3e c3f
c41 c45 c48 c4c c4f c50 c55 c59
c5d c61 c65 c69 c75 c79 c7d c80
c84 c88 c8a c8e c92 c96 c99 c9d
ca1 ca3 ca4 ca9 1 cad cb1 cb5
cb8 cbc cc0 cc4 cc8 ccb ccf cd3
cd6 cd9 cde ce1 ce4 ce7 ce8 ced
cee 1 cf0 cf5 cf9 cfd d00 d05
d0a d0d d11 d12 d17 d1a d1f d20
d25 d28 d2d d2e d33 d36 d3a d3b
d40 d43 d48 d49 d4e d51 d55 d59
d5c d5f d60 d62 d63 d68 d69 d6e
d70 d74 d77 d79 d7d d7f d8b d8d
d8f d90 d95 d99 d9b da7 da9 dad
daf db3 db7 dbb dbe dbf dc1 dc5
dc8 dcc dcf dd0 dd5 dd9 ddd de1
de5 de9 df5 df9 dfd e00 e04 e08
e0a e0e e12 e16 e19 e1d e21 e23
e24 e29 1 e2d e31 e35 e38 e3c
e40 e44 e48 e4b e4f e53 e56 e59
e5e e61 e64 e67 e68 e6d e6e 1
e70 e75 e79 e7d e80 e85 e8a e8d
e91 e92 e97 e9a e9f ea0 ea5 ea8
ead eae eb3 eb6 eba ebb ec0 ec3
ec8 ec9 ece ed1 ed5 ed9 edc edf
ee0 ee2 ee3 ee8 ee9 eee ef0 ef4
ef7 ef9 efd eff f0b f0d f0f f10
f15 f19 f1b f27 f29 f2b f2f f33
f36 f3a f3e f3f f44 f48 f4c f50
f54 f58 f5c f60 f64 f68 f69 f6b
f6f f73 f77 f7a f7b f7d f80 f83
f84 f89 f8d f91 f95 f98 f9c f9e
fa2 fa5 fa9 fad fb0 fb4 fb8 fbb
fbe fc3 fc6 fc9 fcc fcd fd2 fd3
1 fd5 fda fde fe2 fe5 fea fef
ff2 ff6 ff7 ffc fff 1004 1005 100a
100d 1012 1013 1018 101b 101f 1023 1027
1028 102a 102f 1030 1032 1033 1038 103b
1040 1041 1046 1049 104e 104f 1054 1057
105b 105c 1061 1064 1069 106a 106f 1070
1075 1077 107b 107e 1082 1086 1089 108d
1091 1094 1095 1097 109b 109f 10a0 10a5
10a7 10ab 10af 10b2 10b6 10ba 10bd 10c1
10c5 10c8 10cb 10d0 10d3 10d6 10d9 10da
10df 10e0 1 10e2 10e7 10eb 10ef 10f2
10f7 10fc 10ff 1103 1104 1109 110a 110f
1113 1117 111a 111f 1124 1127 112b 112f
1132 1133 1138 113b 1140 1141 1146 1149
114d 1151 1154 1155 115a 115b 1160 1162
1166 1169 116d 1171 1175 1179 117d 1181
1185 1189 118d 1199 119e 11a2 11a6 11aa
11ae 11b0 11b1 11b6 1 11ba 11be 11c2
11c5 11c9 11cd 11d1 11d5 11d8 11dc 11e0
11e3 11e6 11eb 11ee 11f1 11f4 11f5 11fa
11fb 1 11fd 1202 1206 120a 120d 1212
1217 121a 121e 121f 1224 1225 122a 122e
1232 1235 123a 123f 1242 1246 1247 124c
124f 1254 1255 125a 125d 1261 1265 1268
126b 126c 126e 126f 1274 1275 127a 127c
1280 1283 1287 128b 128f 1293 1297 129b
129f 12ab 12b0 12b4 12b8 12bc 12c0 12c2
12c6 12c8 12d4 12d6 12d8 12d9 12de 12e2
12e4 12f0 12f4 12f6 12f7 1300 
566
2
0 1 a 6 14 :3 6 9 :3 6
10 :3 6 12 :2 6 1 3 a 13
a :2 1 4 11 1a 19 :2 11 :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 12 1b 1a :2 12 :2 4 :2 11
20 11 :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 53 59 5c :2 53
6a 7f 8 11 19 :2 11 29 :2 8
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 21 24 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 51 :2 4
:4 9 8 7 :4 1b 1a 19 :2 7 :4 34
33 32 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b0 :2 85 :2 21 :2 a 54 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 54 :3 7 :2 12 28 :2 31 41
:2 7 4a :3 4 14 :2 4 15 :2 4 12
:2 4 14 4 7 10 1e :2 7 23
21 :2 2c :2 21 11 1e 2d 41 4e
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
57 58 :2 55 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5b
:2 d :2 a :4 16 :2 a 7 :3 39 4 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 4b 58 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 57 58 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 8a 8d
:2 27 95 98 :2 27 a4 a7 ae b7
ba :2 a7 :2 27 :2 10 5b :2 d :2 a :4 16
:2 a 7 :3 3c 4 3c 39 a 13
21 :2 a 26 24 :2 2f :2 24 11 1e
2d 46 53 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 40 4 40 39 a 13 21 :2 a
26 24 :2 2f :2 24 11 1e 2d 4a
57 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 40 4
40 39 a 13 21 :2 a 26 24
:2 2f :2 24 11 1e 2d 48 55 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
8b 8e :2 27 96 99 :2 27 a5 a8
af b8 bb :2 a8 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 40 4 40 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 47 54 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 40 4 40 39 a 13
21 :2 a 26 24 :2 2f :2 24 11 1e
2d 48 55 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:4 40 39 :3 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 8c 94 :2 8c
a6 :2 83 :2 1e ae b1 :2 1e b9 bc
:2 1e c1 c4 :2 1e cc cf :2 1e :2 7
52 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
566
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :6 d :6 e :6 f
:7 11 :b 13 :11 14 :8 15
:2 14 :2 16 :2 14 :2 16
:2 14 :2 16 :2 14 :2 16
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :2 14 :2 17
:2 14 :2 18 :2 14 :2 18
:2 14 :2 18 :2 14 :2 18
:2 14 :2 18 :4 14 :3 13
:11 1b :b 1c :3 1b :16 1f
:11 20 :20 21 :3 20 :11 23
:b 24 :3 23 :9 26 :3 1f
:3 2b :3 2c :3 2d :3 2e
:b 30 :6 32 :5 33 31
35 :5 36 :3 35 :2 37
:5 39 :11 3a :24 3b :3 3a
:2 38 :6 37 34 :3 30
3f 30 :b 3f :6 41
:5 42 40 44 :5 45
:3 44 :2 46 :5 48 :11 49
:24 4a :3 49 :2 47 :6 46
43 :3 3f 4e 3f
30 :b 4e :6 50 :5 51
4f 53 :5 54 :3 53
:2 55 :5 57 :11 58 :24 59
:3 58 :2 56 :6 55 52
:3 4e 5d 4e 30
:b 5d :6 5f :5 60 5e
62 :5 63 :3 62 :2 64
:5 66 :11 67 :24 68 :3 67
:2 65 :6 64 61 :3 5d
6c 5d 30 :b 6c
:6 6e :5 6f 6d 71
:5 72 :3 71 :2 73 :5 75
:11 76 :24 77 :3 76 :2 74
:6 73 70 :3 6c 7b
6c 30 :b 7b :6 7d
:5 7e 7c 80 :5 81
:3 80 :2 82 :5 84 :11 85
:24 86 :3 85 :2 83 :6 82
7f :3 7b 8a 7b
30 :b 8a :6 8c :5 8d
8b 8f :5 90 :3 8f
:2 91 :5 93 :11 94 :24 95
:3 94 :2 92 :6 91 8e
:4 8a :3 30 :5 9b :7 9d
9e :3 9d :9 a0 :5 a1
:3 a0 :11 a4 :2e a5 :3 a4
:c a7 12 :3 aa :11 ab
:b ac :17 ad :3 ab :2 af
:3 b0 :3 b1 b2 b0
af b0 :3 b3 :3 aa
:2 b4 :5 b6 :11 b7 :b b8
:18 b9 :3 b7 :2 bb bc
:3 bd be bc bb
bc :3 bf :2 b5 :6 b4
a9 :7 1 
1302
4
:3 0 1 :3 0 2
:a 0 561 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 6 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 561 2
18 :2 0 d :2 0
12 6 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
55f 0 c :6 0
d :2 0 16 6
:3 0 14 22 24
:6 0 27 25 0
55f 0 e :6 0
d :2 0 1a 6
:3 0 18 29 2b
:6 0 2e 2c 0
55f 0 f :6 0
12 :2 0 1e 6
:3 0 1c 30 32
:6 0 35 33 0
55f 0 10 :6 0
12 :2 0 20 4
:3 0 37 :7 0 3b
38 39 55f 0
11 :6 0 12 :2 0
22 4 :3 0 3d
:7 0 41 3e 3f
55f 0 13 :6 0
49 4a 0 24
4 :3 0 43 :7 0
47 44 45 55f
0 14 :6 0 4f
50 0 26 a
:3 0 b :2 0 4
4b :7 0 4e 4c
0 55f 0 15
:6 0 16 :3 0 17
:3 0 16 :3 0 18
:3 0 52 53 0
2 :4 0 28 54
56 51 58 57
:2 0 19 :3 0 1a
:3 0 5a 5b 0
1b :4 0 16 :3 0
1c :3 0 5e 5f
0 2 :4 0 2a
60 62 1d :4 0
1e :2 0 1f :3 0
2c 65 67 :3 0
20 :4 0 1e :2 0
21 :3 0 22 :3 0
3 :3 0 2f 6c
6e 23 :4 0 31
6b 71 34 6a
73 :3 0 1e :2 0
24 :4 0 37 75
77 :3 0 1e :2 0
25 :4 0 3a 79
7b :3 0 1e :2 0
5 :3 0 3d 7d
7f :3 0 1e :2 0
25 :4 0 40 81
83 :3 0 1e :2 0
24 :4 0 43 85
87 :3 0 1e :2 0
25 :4 0 46 89
8b :3 0 1e :2 0
7 :3 0 49 8d
8f :3 0 1e :2 0
25 :4 0 4c 91
93 :3 0 1e :2 0
24 :4 0 4f 95
97 :3 0 1e :2 0
25 :4 0 52 99
9b :3 0 1e :2 0
8 :3 0 55 9d
9f :3 0 1e :2 0
25 :4 0 58 a1
a3 :3 0 1e :2 0
26 :4 0 5b a5
a7 :3 0 5e 5c
a9 :2 0 ab 63
ac 59 ab 0
ad 65 0 4bf
16 :3 0 17 :3 0
ae af 0 16
:3 0 27 :3 0 b1
b2 0 28 :2 0
2 :4 0 29 :2 0
2a :2 0 28 :2 0
67 b7 b9 :3 0
6a b3 bb b0
bd bc :2 0 19
:3 0 2b :3 0 bf
c0 0 1b :4 0
2c :4 0 1e :2 0
1f :3 0 6e c4
c6 :3 0 71 c1
c8 :2 0 ca 74
cb be ca 0
cc 76 0 4bf
5 :3 0 2d :2 0
78 ce cf :3 0
d0 :2 0 d1 :2 0
7 :3 0 2d :2 0
7a d4 d5 :3 0
d6 :2 0 d7 :2 0
d2 d9 d8 :2 0
8 :3 0 2d :2 0
7c dc dd :3 0
de :2 0 df :2 0
da e1 e0 :2 0
16 :3 0 17 :3 0
e3 e4 0 16
:3 0 27 :3 0 e6
e7 0 2e :2 0
2 :4 0 d :2 0
2a :2 0 28 :2 0
7e ec ee :3 0
81 e8 f0 e5
f2 f1 :2 0 19
:3 0 2b :3 0 f4
f5 0 1b :4 0
2f :4 0 1e :2 0
1f :3 0 85 f9
fb :3 0 1e :2 0
30 :4 0 88 fd
ff :3 0 1e :2 0
31 :4 0 8b 101
103 :3 0 1e :2 0
21 :3 0 22 :3 0
32 :3 0 33 :3 0
108 109 0 8e
107 10b 23 :4 0
90 106 10e 93
105 110 :3 0 96
f6 112 :2 0 114
99 115 f3 114
0 116 9b 0
13f 16 :3 0 17
:3 0 117 118 0
16 :3 0 27 :3 0
11a 11b 0 28
:2 0 2 :4 0 34
:2 0 2a :2 0 28
:2 0 9d 120 122
:3 0 a0 11c 124
119 126 125 :2 0
19 :3 0 2b :3 0
128 129 0 1b
:4 0 35 :4 0 1e
:2 0 1f :3 0 a4
12d 12f :3 0 a7
12a 131 :2 0 133
aa 134 127 133
0 135 ac 0
13f 36 :3 0 37
:3 0 136 137 0
32 :3 0 33 :3 0
139 13a 0 38
:3 0 ae 138 13d
:2 0 13f b1 140
e2 13f 0 141
b5 0 4bf c
:3 0 5 :3 0 142
143 0 4bf 10
:3 0 7 :3 0 145
146 0 4bf f
:3 0 8 :3 0 148
149 0 4bf 11
:3 0 3 :3 0 14b
14c 0 4bf 21
:3 0 11 :3 0 12
:2 0 b7 14e 151
32 :3 0 39 :2 0
3a :3 0 153 155
0 bc 154 157
:3 0 3b :3 0 13
:3 0 3c :3 0 3d
:3 0 c :4 0 3e
1 :8 0 164 a
:3 0 3f :3 0 15f
160 0 40 :3 0
161 162 0 164
bf 1b7 41 :3 0
a :3 0 3f :3 0
166 167 0 40
:3 0 168 169 0
16b c2 16d c4
16c 16b :2 0 1b5
42 :3 0 a :3 0
3f :3 0 170 171
0 40 :3 0 172
173 0 1ad 16
:3 0 17 :3 0 175
176 0 16 :3 0
27 :3 0 178 179
0 43 :2 0 2
:4 0 44 :2 0 2a
:2 0 28 :2 0 c6
17e 180 :3 0 c9
17a 182 177 184
183 :2 0 19 :3 0
2b :3 0 186 187
0 1b :4 0 45
:4 0 1e :2 0 1f
:3 0 cd 18b 18d
:3 0 1e :2 0 30
:4 0 d0 18f 191
:3 0 1e :2 0 46
:4 0 d3 193 195
:3 0 1e :2 0 40
:3 0 d6 197 199
:3 0 1e :2 0 47
:4 0 d9 19b 19d
:3 0 1e :2 0 48
:3 0 49 :3 0 28
:2 0 4a :2 0 dc
1a0 1a4 e0 19f
1a6 :3 0 e3 188
1a8 :2 0 1aa e6
1ab 185 1aa 0
1ac e8 0 1ad
ea 1b0 :3 0 1b0
0 1b0 1af 1ad
1ae :6 0 1b2 2
:3 0 ed 1b4 ef
1b3 1b2 :2 0 1b5
f1 :2 0 1b7 0
1b7 1b6 164 1b5
:6 0 1ba 1 :3 0
4b :3 0 f4 44e
21 :3 0 11 :3 0
12 :2 0 f6 1bb
1be 32 :3 0 39
:2 0 4c :3 0 1c0
1c2 0 fb 1c1
1c4 :3 0 3b :3 0
13 :3 0 4d :3 0
3d :3 0 c :4 0
4e 1 :8 0 1d1
a :3 0 3f :3 0
1cc 1cd 0 40
:3 0 1ce 1cf 0
1d1 fe 224 41
:3 0 a :3 0 3f
:3 0 1d3 1d4 0
40 :3 0 1d5 1d6
0 1d8 101 1da
103 1d9 1d8 :2 0
222 42 :3 0 a
:3 0 3f :3 0 1dd
1de 0 40 :3 0
1df 1e0 0 21a
16 :3 0 17 :3 0
1e2 1e3 0 16
:3 0 27 :3 0 1e5
1e6 0 43 :2 0
2 :4 0 4f :2 0
2a :2 0 28 :2 0
105 1eb 1ed :3 0
108 1e7 1ef 1e4
1f1 1f0 :2 0 19
:3 0 2b :3 0 1f3
1f4 0 1b :4 0
50 :4 0 1e :2 0
1f :3 0 10c 1f8
1fa :3 0 1e :2 0
30 :4 0 10f 1fc
1fe :3 0 1e :2 0
46 :4 0 112 200
202 :3 0 1e :2 0
40 :3 0 115 204
206 :3 0 1e :2 0
47 :4 0 118 208
20a :3 0 1e :2 0
48 :3 0 49 :3 0
28 :2 0 4a :2 0
11b 20d 211 11f
20c 213 :3 0 122
1f5 215 :2 0 217
125 218 1f2 217
0 219 127 0
21a 129 21d :3 0
21d 0 21d 21c
21a 21b :6 0 21f
4 :3 0 12c 221
12e 220 21f :2 0
222 130 :2 0 224
0 224 223 1d1
222 :6 0 227 1
:3 0 4b :3 0 133
228 1c5 227 0
44f 21 :3 0 11
:3 0 12 :2 0 135
229 22c 32 :3 0
39 :2 0 51 :3 0
22e 230 0 13a
22f 232 :3 0 3b
:3 0 13 :3 0 52
:3 0 3d :3 0 c
:4 0 53 1 :8 0
23f a :3 0 3f
:3 0 23a 23b 0
40 :3 0 23c 23d
0 23f 13d 292
41 :3 0 a :3 0
3f :3 0 241 242
0 40 :3 0 243
244 0 246 140
248 142 247 246
:2 0 290 42 :3 0
a :3 0 3f :3 0
24b 24c 0 40
:3 0 24d 24e 0
288 16 :3 0 17
:3 0 250 251 0
16 :3 0 27 :3 0
253 254 0 43
:2 0 2 :4 0 54
:2 0 2a :2 0 28
:2 0 144 259 25b
:3 0 147 255 25d
252 25f 25e :2 0
19 :3 0 2b :3 0
261 262 0 1b
:4 0 55 :4 0 1e
:2 0 1f :3 0 14b
266 268 :3 0 1e
:2 0 30 :4 0 14e
26a 26c :3 0 1e
:2 0 46 :4 0 151
26e 270 :3 0 1e
:2 0 40 :3 0 154
272 274 :3 0 1e
:2 0 47 :4 0 157
276 278 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 15a 27b 27f
15e 27a 281 :3 0
161 263 283 :2 0
285 164 286 260
285 0 287 166
0 288 168 28b
:3 0 28b 0 28b
28a 288 289 :6 0
28d 6 :3 0 16b
28f 16d 28e 28d
:2 0 290 16f :2 0
292 0 292 291
23f 290 :6 0 295
1 :3 0 4b :3 0
172 296 233 295
0 44f 21 :3 0
11 :3 0 12 :2 0
174 297 29a 32
:3 0 39 :2 0 56
:3 0 29c 29e 0
179 29d 2a0 :3 0
3b :3 0 13 :3 0
57 :3 0 3d :3 0
c :4 0 58 1
:8 0 2ad a :3 0
3f :3 0 2a8 2a9
0 40 :3 0 2aa
2ab 0 2ad 17c
300 41 :3 0 a
:3 0 3f :3 0 2af
2b0 0 40 :3 0
2b1 2b2 0 2b4
17f 2b6 181 2b5
2b4 :2 0 2fe 42
:3 0 a :3 0 3f
:3 0 2b9 2ba 0
40 :3 0 2bb 2bc
0 2f6 16 :3 0
17 :3 0 2be 2bf
0 16 :3 0 27
:3 0 2c1 2c2 0
43 :2 0 2 :4 0
59 :2 0 2a :2 0
28 :2 0 183 2c7
2c9 :3 0 186 2c3
2cb 2c0 2cd 2cc
:2 0 19 :3 0 2b
:3 0 2cf 2d0 0
1b :4 0 5a :4 0
1e :2 0 1f :3 0
18a 2d4 2d6 :3 0
1e :2 0 30 :4 0
18d 2d8 2da :3 0
1e :2 0 46 :4 0
190 2dc 2de :3 0
1e :2 0 40 :3 0
193 2e0 2e2 :3 0
1e :2 0 47 :4 0
196 2e4 2e6 :3 0
1e :2 0 48 :3 0
49 :3 0 28 :2 0
4a :2 0 199 2e9
2ed 19d 2e8 2ef
:3 0 1a0 2d1 2f1
:2 0 2f3 1a3 2f4
2ce 2f3 0 2f5
1a5 0 2f6 1a7
2f9 :3 0 2f9 0
2f9 2f8 2f6 2f7
:6 0 2fb 8 :3 0
1aa 2fd 1ac 2fc
2fb :2 0 2fe 1ae
:2 0 300 0 300
2ff 2ad 2fe :6 0
303 1 :3 0 4b
:3 0 1b1 304 2a1
303 0 44f 21
:3 0 11 :3 0 12
:2 0 1b3 305 308
32 :3 0 39 :2 0
5b :3 0 30a 30c
0 1b8 30b 30e
:3 0 3b :3 0 13
:3 0 5c :3 0 3d
:3 0 c :4 0 5d
1 :8 0 31b a
:3 0 3f :3 0 316
317 0 40 :3 0
318 319 0 31b
1bb 36e 41 :3 0
a :3 0 3f :3 0
31d 31e 0 40
:3 0 31f 320 0
322 1be 324 1c0
323 322 :2 0 36c
42 :3 0 a :3 0
3f :3 0 327 328
0 40 :3 0 329
32a 0 364 16
:3 0 17 :3 0 32c
32d 0 16 :3 0
27 :3 0 32f 330
0 43 :2 0 2
:4 0 5e :2 0 2a
:2 0 28 :2 0 1c2
335 337 :3 0 1c5
331 339 32e 33b
33a :2 0 19 :3 0
2b :3 0 33d 33e
0 1b :4 0 5f
:4 0 1e :2 0 1f
:3 0 1c9 342 344
:3 0 1e :2 0 30
:4 0 1cc 346 348
:3 0 1e :2 0 46
:4 0 1cf 34a 34c
:3 0 1e :2 0 40
:3 0 1d2 34e 350
:3 0 1e :2 0 47
:4 0 1d5 352 354
:3 0 1e :2 0 48
:3 0 49 :3 0 28
:2 0 4a :2 0 1d8
357 35b 1dc 356
35d :3 0 1df 33f
35f :2 0 361 1e2
362 33c 361 0
363 1e4 0 364
1e6 367 :3 0 367
0 367 366 364
365 :6 0 369 a
:3 0 1e9 36b 1eb
36a 369 :2 0 36c
1ed :2 0 36e 0
36e 36d 31b 36c
:6 0 371 1 :3 0
4b :3 0 1f0 372
30f 371 0 44f
21 :3 0 11 :3 0
12 :2 0 1f2 373
376 32 :3 0 39
:2 0 60 :3 0 378
37a 0 1f7 379
37c :3 0 3b :3 0
13 :3 0 61 :3 0
3d :3 0 c :4 0
62 1 :8 0 389
a :3 0 3f :3 0
384 385 0 40
:3 0 386 387 0
389 1fa 3dc 41
:3 0 a :3 0 3f
:3 0 38b 38c 0
40 :3 0 38d 38e
0 390 1fd 392
1ff 391 390 :2 0
3da 42 :3 0 a
:3 0 3f :3 0 395
396 0 40 :3 0
397 398 0 3d2
16 :3 0 17 :3 0
39a 39b 0 16
:3 0 27 :3 0 39d
39e 0 43 :2 0
2 :4 0 63 :2 0
2a :2 0 28 :2 0
201 3a3 3a5 :3 0
204 39f 3a7 39c
3a9 3a8 :2 0 19
:3 0 2b :3 0 3ab
3ac 0 1b :4 0
64 :4 0 1e :2 0
1f :3 0 208 3b0
3b2 :3 0 1e :2 0
30 :4 0 20b 3b4
3b6 :3 0 1e :2 0
46 :4 0 20e 3b8
3ba :3 0 1e :2 0
40 :3 0 211 3bc
3be :3 0 1e :2 0
47 :4 0 214 3c0
3c2 :3 0 1e :2 0
48 :3 0 49 :3 0
28 :2 0 4a :2 0
217 3c5 3c9 21b
3c4 3cb :3 0 21e
3ad 3cd :2 0 3cf
221 3d0 3aa 3cf
0 3d1 223 0
3d2 225 3d5 :3 0
3d5 0 3d5 3d4
3d2 3d3 :6 0 3d7
c :3 0 228 3d9
22a 3d8 3d7 :2 0
3da 22c :2 0 3dc
0 3dc 3db 389
3da :6 0 3df 1
:3 0 4b :3 0 22f
3e0 37d 3df 0
44f 21 :3 0 11
:3 0 12 :2 0 231
3e1 3e4 32 :3 0
39 :2 0 65 :3 0
3e6 3e8 0 236
3e7 3ea :3 0 3b
:3 0 13 :3 0 66
:3 0 3d :3 0 c
:4 0 67 1 :8 0
3f7 a :3 0 3f
:3 0 3f2 3f3 0
40 :3 0 3f4 3f5
0 3f7 239 44a
41 :3 0 a :3 0
3f :3 0 3f9 3fa
0 40 :3 0 3fb
3fc 0 3fe 23c
400 23e 3ff 3fe
:2 0 448 42 :3 0
a :3 0 3f :3 0
403 404 0 40
:3 0 405 406 0
440 16 :3 0 17
:3 0 408 409 0
16 :3 0 27 :3 0
40b 40c 0 43
:2 0 2 :4 0 68
:2 0 2a :2 0 28
:2 0 240 411 413
:3 0 243 40d 415
40a 417 416 :2 0
19 :3 0 2b :3 0
419 41a 0 1b
:4 0 69 :4 0 1e
:2 0 1f :3 0 247
41e 420 :3 0 1e
:2 0 30 :4 0 24a
422 424 :3 0 1e
:2 0 46 :4 0 24d
426 428 :3 0 1e
:2 0 40 :3 0 250
42a 42c :3 0 1e
:2 0 47 :4 0 253
42e 430 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 256 433 437
25a 432 439 :3 0
25d 41b 43b :2 0
43d 260 43e 418
43d 0 43f 262
0 440 264 443
:3 0 443 0 443
442 440 441 :6 0
445 e :3 0 267
447 269 446 445
:2 0 448 26b :2 0
44a 0 44a 449
3f7 448 :6 0 44c
1 :3 0 26e 44d
3eb 44c 0 44f
158 1ba 0 44f
270 0 4bf e
:3 0 6a :4 0 451
452 :3 0 450 453
0 4bf 14 :3 0
6b :3 0 11 :3 0
13 :3 0 c :3 0
10 :3 0 f :3 0
e :3 0 278 456
45d 455 45e 0
4bf 21 :3 0 14
:3 0 12 :2 0 27f
460 463 39 :2 0
28 :2 0 284 465
467 :3 0 14 :3 0
32 :3 0 6c :3 0
46a 46b 0 469
46c 0 46e 287
46f 468 46e 0
470 289 0 4bf
16 :3 0 17 :3 0
471 472 0 16
:3 0 27 :3 0 474
475 0 6d :2 0
2 :4 0 6e :2 0
2a :2 0 28 :2 0
28b 47a 47c :3 0
28e 476 47e 473
480 47f :2 0 19
:3 0 2b :3 0 482
483 0 1b :4 0
6f :4 0 1e :2 0
1f :3 0 292 487
489 :3 0 1e :2 0
30 :4 0 295 48b
48d :3 0 1e :2 0
31 :4 0 298 48f
491 :3 0 1e :2 0
21 :3 0 22 :3 0
14 :3 0 29b 495
497 23 :4 0 29d
494 49a 2a0 493
49c :3 0 1e :2 0
70 :4 0 2a3 49e
4a0 :3 0 1e :2 0
25 :4 0 2a6 4a2
4a4 :3 0 1e :2 0
e :3 0 2a9 4a6
4a8 :3 0 1e :2 0
25 :4 0 2ac 4aa
4ac :3 0 2af 484
4ae :2 0 4b0 2b2
4b1 481 4b0 0
4b2 2b4 0 4bf
36 :3 0 71 :3 0
4b3 4b4 0 21
:3 0 14 :3 0 12
:2 0 2b6 4b6 4b9
e :3 0 38 :3 0
2b9 4b5 4bd :2 0
4bf 2bd 560 a
:3 0 72 :2 0 4
4c0 4c1 0 16
:3 0 17 :3 0 4c3
4c4 0 16 :3 0
27 :3 0 4c6 4c7
0 43 :2 0 2
:4 0 73 :2 0 2a
:2 0 28 :2 0 2cb
4cc 4ce :3 0 2ce
4c8 4d0 4c5 4d2
4d1 :2 0 19 :3 0
2b :3 0 4d4 4d5
0 1b :4 0 74
:4 0 1e :2 0 1f
:3 0 2d2 4d9 4db
:3 0 2d5 4d6 4dd
:2 0 4f6 19 :3 0
2b :3 0 4df 4e0
0 1b :4 0 75
:4 0 1e :2 0 a
:3 0 76 :3 0 4e5
4e6 0 2d8 4e4
4e8 :3 0 1e :2 0
70 :4 0 2db 4ea
4ec :3 0 1e :2 0
a :3 0 77 :3 0
4ef 4f0 0 2de
4ee 4f2 :3 0 2e1
4e1 4f4 :2 0 4f6
2e4 4f7 4d3 4f6
0 4f8 2e7 0
508 78 :3 0 15
:3 0 a :3 0 76
:3 0 79 :3 0 a
:3 0 77 :3 0 5
:3 0 7a :4 0 7b
1 :a 0 504 :2 0
508 4fa 502 :2 0
9 :3 0 15 :3 0
506 :2 0 508 2e9
50a 2ed 509 508
:2 0 55e 42 :3 0
a :3 0 3f :3 0
50d 50e 0 40
:3 0 50f 510 0
556 16 :3 0 17
:3 0 512 513 0
16 :3 0 27 :3 0
515 516 0 43
:2 0 2 :4 0 7c
:2 0 2a :2 0 28
:2 0 2ef 51b 51d
:3 0 2f2 517 51f
514 521 520 :2 0
19 :3 0 2b :3 0
523 524 0 1b
:4 0 7d :4 0 1e
:2 0 1f :3 0 2f6
528 52a :3 0 2f9
525 52c :2 0 546
19 :3 0 2b :3 0
52e 52f 0 1b
:4 0 46 :4 0 1e
:2 0 40 :3 0 2fc
533 535 :3 0 1e
:2 0 47 :4 0 2ff
537 539 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 302 53c 540
306 53b 542 :3 0
309 530 544 :2 0
546 30c 547 522
546 0 548 30f
0 556 78 :3 0
15 :3 0 79 :3 0
a :3 0 77 :3 0
5 :3 0 7a :4 0
7e 1 :a 0 552
:2 0 556 54a 550
:2 0 9 :3 0 15
:3 0 554 :2 0 556
311 559 :3 0 559
0 559 558 556
557 :6 0 55b 1
:3 0 316 55d 318
55c 55b :2 0 55e
31a :2 0 560 31d
560 55f 4bf 55e
:6 0 561 :2 0 2
18 560 564 :3 0
563 561 565 :8 0

326
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 36
1 3c 1 42
1 48 1 55
1 61 2 64
66 1 6d 2
6f 70 2 69
72 2 74 76
2 78 7a 2
7c 7e 2 80
82 2 84 86
2 88 8a 2
8c 8e 2 90
92 2 94 96
2 98 9a 2
9c 9e 2 a0
a2 2 a4 a6
4 5d 63 68
a8 1 aa 1
ac 2 b6 b8
3 b4 b5 ba
2 c3 c5 2
c2 c7 1 c9
1 cb 1 cd
1 d3 1 db
2 eb ed 3
e9 ea ef 2
f8 fa 2 fc
fe 2 100 102
1 10a 2 10c
10d 2 104 10f
2 f7 111 1
113 1 115 2
11f 121 3 11d
11e 123 2 12c
12e 2 12b 130
1 132 1 134
2 13b 13c 3
116 135 13e 1
140 2 14f 150
1 156 2 152
156 2 15e 163
1 16a 1 165
2 17d 17f 3
17b 17c 181 2
18a 18c 2 18e
190 2 192 194
2 196 198 2
19a 19c 3 1a1
1a2 1a3 2 19e
1a5 2 189 1a7
1 1a9 1 1ab
2 174 1ac 1
1b0 1 16f 2
16d 1b4 1 1b7
2 1bc 1bd 1
1c3 2 1bf 1c3
2 1cb 1d0 1
1d7 1 1d2 2
1ea 1ec 3 1e8
1e9 1ee 2 1f7
1f9 2 1fb 1fd
2 1ff 201 2
203 205 2 207
209 3 20e 20f
210 2 20b 212
2 1f6 214 1
216 1 218 2
1e1 219 1 21d
1 1dc 2 1da
221 1 224 2
22a 22b 1 231
2 22d 231 2
239 23e 1 245
1 240 2 258
25a 3 256 257
25c 2 265 267
2 269 26b 2
26d 26f 2 271
273 2 275 277
3 27c 27d 27e
2 279 280 2
264 282 1 284
1 286 2 24f
287 1 28b 1
24a 2 248 28f
1 292 2 298
299 1 29f 2
29b 29f 2 2a7
2ac 1 2b3 1
2ae 2 2c6 2c8
3 2c4 2c5 2ca
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 3
2ea 2eb 2ec 2
2e7 2ee 2 2d2
2f0 1 2f2 1
2f4 2 2bd 2f5
1 2f9 1 2b8
2 2b6 2fd 1
300 2 306 307
1 30d 2 309
30d 2 315 31a
1 321 1 31c
2 334 336 3
332 333 338 2
341 343 2 345
347 2 349 34b
2 34d 34f 2
351 353 3 358
359 35a 2 355
35c 2 340 35e
1 360 1 362
2 32b 363 1
367 1 326 2
324 36b 1 36e
2 374 375 1
37b 2 377 37b
2 383 388 1
38f 1 38a 2
3a2 3a4 3 3a0
3a1 3a6 2 3af
3b1 2 3b3 3b5
2 3b7 3b9 2
3bb 3bd 2 3bf
3c1 3 3c6 3c7
3c8 2 3c3 3ca
2 3ae 3cc 1
3ce 1 3d0 2
399 3d1 1 3d5
1 394 2 392
3d9 1 3dc 2
3e2 3e3 1 3e9
2 3e5 3e9 2
3f1 3f6 1 3fd
1 3f8 2 410
412 3 40e 40f
414 2 41d 41f
2 421 423 2
425 427 2 429
42b 2 42d 42f
3 434 435 436
2 431 438 2
41c 43a 1 43c
1 43e 2 407
43f 1 443 1
402 2 400 447
1 44a 7 44e
228 296 304 372
3e0 44d 6 457
458 459 45a 45b
45c 2 461 462
1 466 2 464
466 1 46d 1
46f 2 479 47b
3 477 478 47d
2 486 488 2
48a 48c 2 48e
490 1 496 2
498 499 2 492
49b 2 49d 49f
2 4a1 4a3 2
4a5 4a7 2 4a9
4ab 2 485 4ad
1 4af 1 4b1
2 4b7 4b8 3
4ba 4bb 4bc d
ad cc 141 144
147 14a 14d 44f
454 45f 470 4b2
4be 2 4cb 4cd
3 4c9 4ca 4cf
2 4d8 4da 2
4d7 4dc 2 4e3
4e7 2 4e9 4eb
2 4ed 4f1 2
4e2 4f3 2 4de
4f5 1 4f7 3
4f8 503 507 1
4c2 2 51a 51c
3 518 519 51e
2 527 529 2
526 52b 2 532
534 2 536 538
3 53d 53e 53f
2 53a 541 2
531 543 2 52d
545 1 547 4
511 548 551 555
1 559 1 50c
2 50a 55d 8
1f 26 2d 34
3a 40 46 4d

1
4
0 
564
0
1
14
10
d
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
0 0 0 0 
f 1 0
1a 1 0
2f 1 0
7 1 0
b 1 0
42 1 0
3c 1 0
21 1 0
36 1 0
28 1 0
3 1 0
2 0 1
48 1 0
0

/
SHOW ERRORS FUNCTION SP_A_DOCRES;
ALTER FUNCTION SP_A_DOCRES COMPILE DEBUG;
/*****************************************************************************************/
Prompt == FUNCTION FC_U_CREATETMPTABLE ==
CREATE OR REPLACE FUNCTION FC_U_CREATETMPTABLE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1f
2 :e:
1FUNCTION:
1FC_U_CREATETMPTABLE:
1RETURN:
1PLS_INTEGER:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_CREATETMPTABLE();:
1CHECK_TRACE:
11:
18:
1+:
1FPUT:
1               ENTER:: FC_U_CREATETMPTABLE(9) :: cplan.sql(7286) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN01_TEMP:
1PMO_DB2M:
1SC_STATE:
10:
117:
1                EXIT:: FC_U_CREATETMPTABLE(18) :: cplan.sql(7295) :: :
1 :
1STATE:: :
0

0
0
8c
2
0 a0 8d a0 b4 a0 2c 6a
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
8c
2
0 3 f b a 23 27 2b
2f 33 7 37 3b 3f 42 47
48 1 4a 4f 53 57 5a 5f
63 67 6a 6f 70 72 77 7a
7e 7f 84 89 8a 8f 91 95
98 9c a0 a3 a7 ab ae b1
b6 b9 bc bf c0 c5 c6 1
c8 cd d1 d5 d8 dd e2 e5
e9 ea ef f0 f5 f7 fb fe
102 106 10b 110 114 118 11c 11f
122 126 12a 12e 131 135 139 13c
13f 144 147 14a 14d 14e 153 154
1 156 15b 15f 163 166 16b 170
173 177 178 17d 180 185 186 18b
18e 193 194 199 19c 1a0 1a4 1a7
1a8 1ad 1ae 1b3 1b5 1b9 1bc 1c0
1c4 1c8 1cb 1cf 1d1 1d5 1d7 1e3
1e7 1e9 1ea 1f3 
8c
2
0 1 a 1e 0 25 :2 1 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 5b 61 64 :2 5b
72 :2 7 51 :2 4 7 :2 11 23 :2 2d
39 3c 53 54 55 :2 53 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 58
:3 4 c 16 :3 4 :2 d 19 4 7
:2 11 23 :2 2d 39 3c 53 55 56
:2 53 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a :2 93 :2 1e :2 7 59 :3 4 b :2 14
4 :9 1 
8c
4
0 :3 1 0 :3 1
:b 4 :12 5 :3 4 :11 8
:b 9 :3 8 :5 e :5 f
:11 11 :19 12 :3 11 :5 14
:2 3 :7 1 
1f5
4
:3 0 1 :3 0 8
9 :2 0 3 :3 0
2 :a 0 87 1
:7 0 4 :3 0 4
5 0 87 2
6 :2 0 5 :3 0
6 :3 0 5 :3 0
7 :3 0 b c
0 2 :4 0 3
d f a 11
10 :2 0 8 :3 0
9 :3 0 13 14
0 a :4 0 5
:3 0 b :3 0 17
18 0 2 :4 0
5 19 1b c
:4 0 d :2 0 e
:3 0 7 1e 20
:3 0 f :4 0 a
15 23 :2 0 25
f 26 12 25
0 27 11 0
83 5 :3 0 6
:3 0 28 29 0
5 :3 0 10 :3 0
2b 2c 0 11
:2 0 2 :4 0 12
:2 0 13 :2 0 11
:2 0 13 31 33
:3 0 16 2d 35
2a 37 36 :2 0
8 :3 0 14 :3 0
39 3a 0 a
:4 0 15 :4 0 d
:2 0 e :3 0 1a
3e 40 :3 0 1d
3b 42 :2 0 44
20 45 38 44
0 46 22 0
83 16 :3 0 17
:3 0 18 :4 0 49
:4 0 4a :2 0 83
19 :3 0 1a :3 0
4c 4d 0 1b
:2 0 4e 4f 0
83 5 :3 0 6
:3 0 51 52 0
5 :3 0 10 :3 0
54 55 0 11
:2 0 2 :4 0 1c
:2 0 13 :2 0 11
:2 0 24 5a 5c
:3 0 27 56 5e
53 60 5f :2 0
8 :3 0 14 :3 0
62 63 0 a
:4 0 1d :4 0 d
:2 0 e :3 0 2b
67 69 :3 0 d
:2 0 1e :4 0 2e
6b 6d :3 0 d
:2 0 1f :4 0 31
6f 71 :3 0 d
:2 0 19 :3 0 1a
:3 0 74 75 0
34 73 77 :3 0
37 64 79 :2 0
7b 3a 7c 61
7b 0 7d 3c
0 83 3 :3 0
19 :3 0 1a :3 0
7f 80 0 81
:2 0 83 3e 86
:3 0 86 0 86
85 83 84 :6 0
87 :2 0 2 6
86 8a :3 0 89
87 8b :8 0 
45
4
:3 0 1 e 1
1a 2 1d 1f
4 16 1c 21
22 1 24 1
26 2 30 32
3 2e 2f 34
2 3d 3f 2
3c 41 1 43
1 45 2 59
5b 3 57 58
5d 2 66 68
2 6a 6c 2
6e 70 2 72
76 2 65 78
1 7a 1 7c
6 27 46 4b
50 7d 82 
1
4
0 
8a
0
1
14
1
1
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
0

/
SHOW ERRORS FUNCTION FC_U_CREATETMPTABLE;
ALTER FUNCTION FC_U_CREATETMPTABLE COMPILE DEBUG;
/************************************************************************************************/
/*****************************************************************************************/
Prompt == FUNCTION FC_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION FC_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ee
2 :e:
1FUNCTION:
1FC_U_TSKRES2:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_AND_ROLES:
1H_AND_SKILLS:
1SH_H_WORK_LOCATION:
1PLS_INTEGER:
1H_START_DATE:
1H_FINISH_DATE:
1SH_H_EFFORT:
1SH_H_WORK:
1SH_H_EUNIT:
1SH_H_UNIT:
1SH_H_WORK_TYPE:
1SH_H_BITFLAG:
1SH_H_CONTOUR:
1SH_H_CONTOUR_TYPE:
1SH_H_OCCURRENCE:
1H_ASSIGN_STRING:
1H_REC_USER:
1RETURN:
1H_WORK_LOCATION:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_TASK_ID:
132:
1H_RES_ID:
1H_START_DT:
126:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_LAST_SUBMITTED:
1H_TSK_ASSIGNMENT_ID:
1H_PROJECT_ID:
1H_CALENDAR_ID:
1H_SECURITY_ID:
1H_RES_TYPE:
11:
1H_BIT_FLAG:
1H_FULL_NAME:
1255:
1H_NULL_STR:
1H_MIN_PER_DAY:
10:
1H_TYPE:
1H_PER_WEEK:
1H_CONSIDER:
1H_ROLLUP:
1H_CRI:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_WORK_TODATE:
1H_TEMP_VAR:
1H_TEMP_SECURITY_ID:
1H_TEMP2_SECURITY_ID:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DURATION:
1H_PERCENT_UNITS:
1H_SCHED_WORK:
1H_PRIORITY:
1H_UPDATE:
1H_ZERO:
1H_RES_COST:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
194:
1+:
1FPUT:
1               ENTER:: FC_U_TSKRES2(95) :: cplan.sql(7402) :: :
1PMO_CNST:
1>=:
1SC_BIT_30:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ELSIF:
1SC_BIT_28:
1SC_BIT_NOT_28:
10.00:
1=:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1LAST_SUBMITTED:
1WORK_TODATE:
1TO_DATE:
1SUBSTR:
1SCHED_START:
1SCHED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n         PROJECT_ID,:n         TASK_ID,:n         RESOURCE_ID,:n     +
1    RESOURCE_TYPE,:n         LAST_SUBMITTED,:n         WORK_TODATE,:n        +
1 TO_DATE(SubStr(SCHED_START, 1, 10)),:n         TO_DATE(SubStr(SCHED_FINISH, +
11, 10)),:n         BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COS+
1T,:n         REGULAR_RATE:n         INTO:n         h_project_id,:n         h_+
1task_id,:n         h_res_id,:n         h_res_type,:n         h_last_submitted+
1,:n         h_work_todate,:n         h_SD,:n         h_FD,:n         h_billab+
1le,:n         h_capital_expense,:n         h_reg_cost,:n         h_reg_sale:n+
1         FROM TASK_ASSIGNMENTS:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assi+
1gnment_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1165:
1           EXCEPTION:: FC_U_TSKRES2(166) :: cplan.sql(7473) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1172:
1                EXIT:: FC_U_TSKRES2(173) :: cplan.sql(7480) :: :
1RECORD_NOT_FOUND:
1ELEMENT_ID:
1ELEMENT_TYPE:
1SECURITY_ID:
1CRI_SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1RES_ASSIGNMENT_ID:
1SELECT PROJECT_ID, ELEMENT_ID, RESOURCE_ID, ELEMENT_TYPE, :n         RESOURCE+
1_TYPE, SECURITY_ID, CASE WHEN CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END:n    +
1     INTO h_project_id, h_task_id, h_res_id, h_type,:n         h_res_type, h_+
1security_id, h_transfed_cri:n         FROM RESOURCE_ASSIGNMENTS :n         WH+
1ERE RES_ASSIGNMENT_ID = h_assign_id:
1192:
1           EXCEPTION:: FC_U_TSKRES2(193) :: cplan.sql(7500) :: :
1199:
1                EXIT:: FC_U_TSKRES2(200) :: cplan.sql(7507) :: :
1ISWBSTRANSFEREDDELIV:
1!=:
1204:
1                EXIT:: FC_U_TSKRES2(205) :: cplan.sql(7512) :: :
1TASK_ASSIGNMENT_ERROR:
1WORK_LOCATION:
1UPDATE RESOURCE_ASSIGNMENTS SET WORK_LOCATION = h_work_location:n         WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1TRUE:
1100:
1224:
1           EXCEPTION:: FC_U_TSKRES2(225) :: cplan.sql(7532) :: :
1ISPROJECTTYPE:
1NOT:
1SELECT TSK_ASSIGNMENT_ID INTO h_tsk_assignment_id:n            FROM TASK_ASSI+
1GNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
1241:
1           EXCEPTION:: FC_U_TSKRES2(242) :: cplan.sql(7549) :: :
1SC_SQL_SUCCESS:
1248:
1                EXIT:: FC_U_TSKRES2(249) :: cplan.sql(7556) :: :
1RECORD_ALREADY_ASSIGNED:
1FC_AFTER_U_RES_ASSIGN:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1CALENDAR_ID:
1PRIORITY:
1TMT_WBS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), CALEND+
1AR_ID, PRIORITY:n      INTO h_min_per_day, h_per_week, h_calendar_id, h_prior+
1ity:n      FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1270:
1           EXCEPTION:: FC_U_TSKRES2(271) :: cplan.sql(7578) :: :
1>:
15:
1*:
1IS NULL:
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT SUM(AVAILABLE_MIN) INTO h_effort FROM CALENDAR_DAY_OF_YEAR:n          +
1     WHERE ELEMENT_ID=h_project_id AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_star+
1t_date, 1, 10)) AND TO_DATE(SubStr(h_finish_date, 1, 10)):
1298:
1           EXCEPTION:: FC_U_TSKRES2(299) :: cplan.sql(7606) :: :
160:
12:
13:
1315:
1                EXIT:: FC_U_TSKRES2(316) :: cplan.sql(7623) :: :
1SC_BIT_NOT_30:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, UNRESOLVED_START, UNRESOLVED_FINISH, PLANNED_WORK+S+
1CHED_WORK, BIT_FLAG:n         INTO h_tsk_assignment_id, h_start_DT, h_finish_+
1DT, h_sched_work, h_bit_flag:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID = h_res_+
1id:
1338:
1           EXCEPTION:: FC_U_TSKRES2(339) :: cplan.sql(7646) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1BIT_OR:
1<:
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_SRCH_FROM_PROJECT:
1FC_SEARCH_2:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = h_effort:n                  WHERE RES_ASSIG+
1NMENT_ID = h_assign_id:
1389:
1           EXCEPTION:: FC_U_TSKRES2(390) :: cplan.sql(7697) :: :
1395:
1                EXIT:: FC_U_TSKRES2(396) :: cplan.sql(7703) :: :
1U_TSKRES2:
1110:
1RESOURCE_UNAVAILABLE:
1489:
1                EXIT:: FC_U_TSKRES2(490) :: cplan.sql(7797) :: :
1STATE:: :
0

0
0
af1
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 90
:3 a0 b0 3f 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d a0 51 d a0
51 d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:4 a0 51 a5 b :2 a0 6b a5 b
5a d a0 51 d b7 19 :3 a0
51 a5 b d a0 51 d a0
51 d b7 :2 19 3c a0 51 d
a0 6e d a0 51 d a0 4d
d a0 4d d a0 4d d a0
4d d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :1f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 :11 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 a0 b7 :3 a0
51 a5 b a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
:2 19 3c :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b a5 b
5a 7e 51 b4 2e 7e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c b7 19 3c :3 a0
a5 b d b7 :2 19 3c :d a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e a0 7e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c b7
:d a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e 51 b4 2e d a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 :2 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
a0 b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :12 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e 5a a 10
:4 a0 51 a5 b :2 a0 6b a5 b
5a d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 :2 51 a5 b 7e 6e
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
a0 51 d b7 19 3c b7 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
6b :2 a0 51 a5 b :2 a0 6b a5
b 5a d b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 :2 51
a5 b 7e 6e b4 2e a0 51
d b7 19 3c :2 a0 b4 2e d
:3 a0 6b d :20 a0 51 a5 b :4 51
a5 b d b7 19 3c :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 51 65 b7 19 3c b7
:2 19 3c b7 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :2 51 a5 b d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 6b :2 a0 6b d b7
:2 19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
af1
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 8c 80 84 88 6e 93 a8
9c a0 a4 6b af b8 b4 9b
c0 cd c9 98 d5 de da c8
e6 f3 ef c5 fb 104 100 ee
10c 119 115 eb 121 12a 126 114
132 13f 13b 111 147 150 14c 13a
158 16d 161 165 169 137 174 185
179 17d 181 160 18c 15d 191 195
199 19d 1ba 1a5 1a9 1b1 1b5 1a4
1da 1c5 1c9 1d1 1d5 1a1 1f6 1e1
1e5 1ed 1f1 1c4 216 201 205 20d
211 1c1 232 21d 221 229 22d 200
252 23d 241 249 24d 1fd 26e 259
25d 265 269 23c 28e 279 27d 285
289 239 2aa 295 299 2a1 2a5 278
2ca 2b5 2b9 2c1 2c5 275 2e6 2d1
2d5 2d8 2d9 2e1 2b4 303 2f1 2b1
2f5 2f6 2fe 2f0 320 30e 2ed 312
313 31b 30d 33d 32b 30a 32f 330
338 32a 359 348 34c 354 327 371
360 364 36c 347 38e 37c 344 380
381 389 37b 3ab 399 378 39d 39e
3a6 398 3c8 3b6 395 3ba 3bb 3c3
3b5 3e5 3d3 3b2 3d7 3d8 3e0 3d2
402 3f0 3cf 3f4 3f5 3fd 3ef 41f
40d 3ec 411 412 41a 40c 43c 42a
409 42e 42f 437 429 459 447 426
44b 44c 454 446 475 464 468 443
470 463 491 480 484 460 48c 47f
4ad 49c 4a0 47c 4a8 49b 4c9 4b8
4bc 498 4c4 4b7 4e5 4d4 4d8 4b4
4e0 4d3 501 4f0 4f4 4d0 4fc 4ef
51d 50c 510 4ec 518 50b 539 528
52c 508 534 527 555 544 548 524
550 543 571 560 564 540 56c 55f
58e 57c 55c 580 581 589 57b 5ab
599 578 59d 59e 5a6 598 5c7 5b6
5ba 5c2 595 5df 5ce 5d2 5da 5b5
5fb 5ea 5ee 5b2 5f6 5e9 617 606
60a 5e6 612 605 633 622 626 602
62e 621 64f 63e 642 61e 64a 63d
66b 65a 65e 63a 666 659 687 676
67a 656 682 675 6a3 692 696 672
69e 691 6bf 6ae 6b2 68e 6ba 6ad
6db 6ca 6ce 6aa 6d6 6c9 6f7 6e6
6ea 6c6 6f2 6e5 713 702 706 6e2
70e 701 72f 71e 722 6fe 72a 71d
736 73a 71a 73e 742 746 749 74e
74f 1 751 756 75a 75e 761 766
76a 76e 771 776 777 779 77e 781
785 786 78b 790 793 798 799 79e
7a1 7a5 7a6 7ab 7ae 7b3 7b4 7b9
7bc 7c1 7c2 7c7 7ca 7cf 7d0 7d5
7d8 7dc 7dd 7e2 7e5 7ea 7eb 7f0
7f3 7f8 7f9 7fe 801 806 807 80c
80f 813 814 819 81c 821 822 827
82a 82f 830 835 838 83c 840 844
845 847 84c 84d 84f 850 855 858
85d 85e 863 866 86b 86c 871 874
878 879 87e 881 886 887 88c 88f
894 895 89a 89d 8a2 8a3 8a8 8ab
8af 8b0 8b5 8b8 8bd 8be 8c3 8c6
8cb 8cc 8d1 8d4 8d8 8dc 8e0 8e1
8e3 8e8 8e9 8eb 8ec 8f1 8f4 8f9
8fa 8ff 902 906 90a 90e 90f 911
916 917 919 91a 91f 922 927 928
92d 930 934 938 93c 93d 93f 944
945 947 948 94d 950 955 956 95b
95e 962 966 96a 96b 96d 972 973
975 976 97b 97e 983 984 989 98c
990 994 998 999 99b 9a0 9a1 9a3
9a4 9a9 9ac 9b1 9b2 9b7 9ba 9be
9c2 9c6 9c7 9c9 9ce 9cf 9d1 9d2
9d7 9da 9df 9e0 9e5 9e8 9ec 9f0
9f4 9f5 9f7 9fc 9fd 9ff a00 a05
a08 a0d a0e a13 a16 a1a a1e a22
a23 a25 a2a a2b a2d a2e a33 a36
a3b a3c a41 a44 a48 a4c a50 a51
a53 a58 a59 a5b a5c a61 a64 a69
a6a a6f a72 a77 a78 a7d a80 a84
a85 a8a a8d a92 a93 a98 a9b aa0
aa1 aa6 aa9 aae aaf ab4 ab7 abb
abc ac1 ac4 ac9 aca acf ad2 ad7
ad8 add ade ae3 ae5 ae9 aec af0
af4 af7 afb aff b02 b05 b0a b0d
b10 b13 b14 b19 b1a 1 b1c b21
b25 b29 b2c b31 b36 b39 b3d b3e
b43 b44 b49 b4b b4f b52 b56 b5a
b5d b5e b60 b64 b67 b6b b6e b6f
b74 b78 b7c b80 b83 b87 b8b b8f
b92 b93 b95 b99 b9d ba0 ba1 ba3
ba6 ba9 baa bac bb0 bb4 bb8 bbc
bc0 bc3 bc4 bc6 bca bce bd1 bd2
bd4 bd8 bdc bdf be3 be7 bea bee
bf2 bf4 bf8 bfc bff c00 c02 c06
c09 c0d c10 c11 c16 c1a c1e c22
c26 c29 c2a c2c c30 c34 c37 c38
c3a c3d c41 c45 c49 c4d c51 c54
c55 c57 c5b c5f c62 c63 c65 c68
c6c c70 c73 c77 c79 c7d c81 c85
c89 c8c c8d c8f c93 c97 c9a c9e
ca2 ca5 ca9 cab caf cb3 cb6 cba
cbd cc1 cc5 cca cce cd2 cd5 cd9
cdd cde ce2 ce6 ce7 ceb cef cf0
cf4 cf8 cf9 cfd d01 d04 d08 d0c
d10 d13 d14 d16 d19 d1c d1d d22
d26 d2a d2e d32 d36 d3a d3e d42
d46 d4a d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 d9a d9e da2
da6 daa db6 dba dbe dc1 dc5 dc9
dcb dcf dd3 dd7 dda dde de2 de4
de5 dea 1 dee df2 df6 df9 dfd
e01 e05 e09 e0c e10 e14 e17 e1a
e1f e22 e25 e28 e29 e2e e2f 1
e31 e36 e3a e3e e41 e46 e4b e4e
e52 e53 e58 e5b e60 e61 e66 e69
e6e e6f e74 e77 e7b e7c e81 e84
e89 e8a e8f e92 e96 e9a e9d ea0
ea1 ea3 ea4 ea9 eaa eaf eb1 eb5
eb8 eba ebe ec0 ecc ece ed0 ed1
ed6 eda edc ee8 eea eee ef2 ef5
ef9 efc f00 f03 f04 f09 f0c f10
f14 f17 f1b f1f f22 f25 f2a f2d
f30 f33 f34 f39 f3a 1 f3c f41
f45 f49 f4c f51 f56 f59 f5d f5e
f63 f64 f69 f6b f6f f72 f76 f7a
f7e f81 f85 f87 f8b f8e f90 f94
f98 f9c fa0 fa4 fa8 fac fb0 fb4
fb8 fbc fc0 fc4 fc8 fcc fd0 fd4
fe0 fe4 fe8 feb fef ff3 ff5 ff9
ffd 1001 1004 1008 100c 100e 100f 1014
1 1018 101c 1020 1023 1027 102b 102f
1033 1036 103a 103e 1041 1044 1049 104c
104f 1052 1053 1058 1059 1 105b 1060
1064 1068 106b 1070 1075 1078 107c 107d
1082 1085 108a 108b 1090 1093 1098 1099
109e 10a1 10a5 10a6 10ab 10ae 10b3 10b4
10b9 10bc 10c0 10c4 10c7 10ca 10cb 10cd
10ce 10d3 10d4 10d9 10db 10df 10e2 10e4
10e8 10ea 10f6 10f8 10fa 10fb 1100 1104
1106 1112 1114 1118 111c 111f 1123 1126
112a 112d 112e 1133 1136 113a 113e 1141
1145 1149 114c 114f 1154 1157 115a 115d
115e 1163 1164 1 1166 116b 116f 1173
1176 117b 1180 1183 1187 1188 118d 118e
1193 1195 1199 119c 11a0 11a4 11a8 11ab
11af 11b3 11b5 11b9 11bd 11c1 11c4 11c5
11c7 11c8 11ca 11cd 11d0 11d1 11d6 11da
11de 11e1 11e5 11e9 11ec 11ef 11f4 11f7
11fa 11fd 11fe 1203 1204 1 1206 120b
120f 1213 1216 121b 1220 1223 1227 1228
122d 122e 1233 1235 1239 123c 1240 1244
1248 124b 124f 1251 1255 1259 125c 1260
1264 1268 126c 1270 127c 1280 1285 1289
128c 128d 1292 1296 129a 129d 12a0 12a4
12a6 12aa 12ae 12b1 12b4 12b8 12ba 12be
12c2 12c5 12c7 12cb 12cf 12d3 12d6 12da
12de 12e0 12e1 12e6 1 12ea 12ee 12f2
12f5 12f9 12fd 1301 1305 1308 130c 1310
1313 1316 131b 131e 1321 1324 1325 132a
132b 1 132d 1332 1336 133a 133d 1342
1347 134a 134e 134f 1354 1357 135c 135d
1362 1365 136a 136b 1370 1373 1377 1378
137d 1380 1385 1386 138b 138e 1392 1396
1399 139c 139d 139f 13a0 13a5 13a6 13ab
13ad 13b1 13b4 13b6 13ba 13bc 13c8 13ca
13cc 13cd 13d2 13d6 13d8 13e4 13e6 13ea
13ee 13f2 13f5 13f6 13f8 13f9 13fb 13fe
1401 1404 1405 140a 140d 140e 1413 1417
141b 141f 1423 1427 1433 1437 143b 143e
1442 1446 1448 144c 1450 1454 1457 145b
145f 1461 1462 1467 1 146b 146f 1473
1476 147a 147e 1482 1486 1489 148d 1491
1494 1497 149c 149f 14a2 14a5 14a6 14ab
14ac 1 14ae 14b3 14b7 14bb 14be 14c3
14c8 14cb 14cf 14d0 14d5 14d8 14dd 14de
14e3 14e6 14eb 14ec 14f1 14f4 14f8 14f9
14fe 1501 1506 1507 150c 150f 1513 1517
151a 151d 151e 1520 1521 1526 1527 152c
152e 1532 1535 1537 153b 153d 1549 154b
154d 154e 1553 1557 1559 1565 1567 156b
156f 1572 1576 1579 157d 1580 1581 1586
1589 158d 1591 1594 1598 159c 159f 15a2
15a7 15aa 15ad 15b0 15b1 15b6 15b7 1
15b9 15be 15c2 15c6 15c9 15ce 15d3 15d6
15da 15db 15e0 15e1 15e6 15e8 15ec 15ef
15f3 15f7 15fb 15fe 1602 1604 1608 160b
160d 1611 1614 1618 161c 1620 1621 1623
1627 1629 162d 1631 1634 1638 163c 1640
1644 1648 164c 1650 1654 1658 165c 1660
1664 1668 1674 1678 167c 167f 1683 1687
1689 168d 1691 1695 1698 169c 16a0 16a2
16a3 16a8 1 16ac 16b0 16b4 16b7 16bb
16bf 16c3 16c7 16ca 16ce 16d2 16d5 16d8
16dd 16e0 16e3 16e6 16e7 16ec 16ed 1
16ef 16f4 16f8 16fc 16ff 1704 1709 170c
1710 1711 1716 1719 171e 171f 1724 1727
172c 172d 1732 1735 1739 173a 173f 1742
1747 1748 174d 1750 1754 1758 175b 175e
175f 1761 1762 1767 1768 176d 176f 1773
1776 1778 177c 177e 178a 178c 178e 178f
1794 1798 179a 17a6 17a8 17ac 17b0 17b3
17b4 17b6 17b9 17bc 17bd 17c2 17c6 17ca
17cd 17ce 17d0 17d3 17d6 17d7 17dc 17df
17e3 17e7 17ea 17eb 17ed 17f0 17f3 17f4
17f9 1 17fc 1801 1805 1809 180d 1810
1811 1813 1816 181a 181e 1821 1822 1824
1825 182a 182e 1830 1834 1837 183b 183f
1842 1843 1845 1848 184b 184c 1851 1855
1858 1859 185e 1861 1865 1869 186c 186d
186f 1872 1875 1876 187b 187f 1883 1887
188a 188b 188d 1890 1894 1898 189b 189c
189e 189f 18a4 18a8 18aa 18ae 18b1 18b3
18b7 18bb 18bf 18c3 18c7 18cb 18cf 18d3
18d7 18db 18df 18e3 18e7 18f3 18f7 18fb
18fe 1902 1906 1908 190c 1910 1914 1917
191b 191f 1921 1922 1927 1 192b 192f
1933 1936 193a 193e 1942 1946 1949 194d
1951 1954 1957 195c 195f 1962 1965 1966
196b 196c 1 196e 1973 1977 197b 197e
1983 1988 198b 198f 1990 1995 1998 199d
199e 19a3 19a6 19ab 19ac 19b1 19b4 19b8
19b9 19be 19c1 19c6 19c7 19cc 19cf 19d3
19d7 19da 19dd 19de 19e0 19e1 19e6 19e7
19ec 19ee 19f2 19f5 19f7 19fb 19fd 1a09
1a0b 1a0d 1a0e 1a13 1a17 1a19 1a25 1a27
1a29 1a2d 1a31 1a34 1a36 1a3a 1a3e 1a41
1a42 1a44 1a47 1a4a 1a4b 1a50 1a54 1a58
1a5c 1a5f 1a60 1a62 1a65 1a68 1a69 1a6e
1a72 1a76 1a78 1a7c 1a80 1a83 1a84 1a86
1a89 1a8c 1a8d 1a92 1a96 1a9a 1a9e 1aa1
1aa2 1aa4 1aa7 1aab 1aaf 1ab2 1ab3 1ab5
1ab6 1abb 1abf 1ac3 1ac5 1ac9 1acd 1ad1
1ad4 1ad5 1ad7 1ada 1add 1ade 1ae3 1ae7
1aeb 1aef 1af2 1af3 1af5 1af8 1afc 1b00
1b03 1b04 1b06 1b07 1b0c 1b10 1b12 1b16
1b1a 1b1d 1b1f 1b23 1b27 1b2a 1b2e 1b32
1b35 1b36 1b38 1b3b 1b3e 1b3f 1b44 1b48
1b4c 1b4f 1b53 1b57 1b5a 1b5d 1b62 1b65
1b68 1b6b 1b6c 1b71 1b72 1 1b74 1b79
1b7d 1b81 1b84 1b89 1b8e 1b91 1b95 1b96
1b9b 1b9c 1ba1 1ba3 1ba7 1baa 1bae 1bb2
1bb6 1bb9 1bbd 1bbf 1bc3 1bc6 1bc8 1bcc
1bcf 1bd3 1bd7 1bda 1bdb 1bdd 1be0 1be3
1be4 1be9 1bed 1bf1 1bf5 1bf9 1bfc 1bfd
1bff 1c03 1c07 1c0a 1c0b 1c0d 1c10 1c14
1c18 1c1a 1c1e 1c22 1c25 1c28 1c29 1c2b
1c2e 1c33 1c34 1c39 1c3c 1c40 1c44 1c47
1c48 1c4a 1c4d 1c50 1c51 1c56 1 1c59
1c5e 1c62 1c66 1c6a 1c6e 1c72 1c76 1c7a
1c7e 1c82 1c86 1c8a 1c8e 1c92 1c96 1c9a
1c9e 1ca2 1ca6 1cb2 1cb6 1cba 1cbd 1cc1
1cc5 1cc7 1ccb 1ccf 1cd3 1cd6 1cda 1cde
1ce0 1ce1 1ce6 1 1cea 1cee 1cf2 1cf5
1cf9 1cfd 1d01 1d05 1d08 1d0c 1d10 1d13
1d16 1d1b 1d1e 1d21 1d24 1d25 1d2a 1d2b
1 1d2d 1d32 1d36 1d3a 1d3d 1d42 1d47
1d4a 1d4e 1d4f 1d54 1d57 1d5c 1d5d 1d62
1d65 1d6a 1d6b 1d70 1d73 1d77 1d78 1d7d
1d80 1d85 1d86 1d8b 1d8e 1d92 1d96 1d99
1d9c 1d9d 1d9f 1da0 1da5 1da6 1dab 1dad
1db1 1db4 1db6 1dba 1dbc 1dc8 1dca 1dcc
1dcd 1dd2 1dd6 1dd8 1de4 1de6 1dea 1dee
1df1 1df5 1df8 1dfc 1dff 1e00 1e05 1e08
1e0c 1e0f 1e10 1e15 1 1e18 1e1d 1e21
1e25 1e29 1e2d 1e30 1e31 1e33 1e37 1e3b
1e3e 1e3f 1e41 1e44 1e48 1e4c 1e50 1e53
1e57 1e5b 1e5e 1e5f 1e61 1e64 1e67 1e68
1e6d 1e70 1e74 1e78 1e7b 1e7f 1e83 1e86
1e87 1e89 1e8c 1e8f 1e90 1e95 1 1e98
1e9d 1ea1 1ea5 1ea8 1eab 1eac 1eae 1eb1
1eb6 1eb7 1ebc 1ec0 1ec4 1ec7 1ec8 1eca
1ecd 1ed0 1ed1 1ed6 1eda 1edd 1ee1 1ee3
1ee7 1eea 1eee 1ef1 1ef5 1ef7 1efb 1efe
1f00 1f04 1f08 1f0b 1f0c 1f0e 1f11 1f14
1f15 1f1a 1f1e 1f22 1f26 1f29 1f2d 1f31
1f34 1f35 1f37 1f3b 1f3f 1f42 1f43 1f45
1f48 1f4c 1f4e 1f52 1f55 1f59 1f5d 1f60
1f61 1f63 1f67 1f6a 1f6e 1f71 1f72 1f74
1f75 1f7a 1f7e 1f82 1f85 1f86 1f88 1f8b
1f8e 1f8f 1f94 1f98 1f9c 1f9f 1fa3 1fa7
1faa 1fab 1fad 1fb0 1fb3 1fb4 1 1fb9
1fbe 1fc2 1fc6 1fc9 1fcc 1fcd 1fcf 1fd2
1fd7 1fd8 1fdd 1fe1 1fe4 1fe8 1fea 1fee
1ff1 1ff5 1ff9 1ffa 1fff 2003 2007 200b
200f 2012 2016 201a 201e 2022 2026 202a
202e 2032 2036 203a 203e 2042 2046 204a
204e 2052 2056 205a 205e 2062 2066 206a
206e 2072 2076 207a 207e 2082 2086 208a
208e 2092 2096 2099 209a 209c 209f 20a2
20a5 20a8 20a9 20ab 20af 20b1 20b5 20b8
20bc 20c0 20c4 20c8 20cc 20d8 20dc 20e1
20e5 20e8 20e9 20ee 20f2 20f6 20f9 20fc
2100 2102 2106 210a 210d 2110 2114 2116
211a 211e 2121 2123 2127 212b 212f 2132
2136 213a 213c 213d 2142 1 2146 214a
214e 2151 2155 2159 215d 2161 2164 2168
216c 216f 2172 2177 217a 217d 2180 2181
2186 2187 1 2189 218e 2192 2196 2199
219e 21a3 21a6 21aa 21ab 21b0 21b3 21b8
21b9 21be 21c1 21c6 21c7 21cc 21cf 21d3
21d4 21d9 21dc 21e1 21e2 21e7 21ea 21ee
21f2 21f5 21f8 21f9 21fb 21fc 2201 2202
2207 2209 220d 2210 2212 2216 2218 2224
2226 2228 2229 222e 2232 2234 2240 2242
2246 224a 224d 2251 2255 2258 225b 2260
2263 2266 2269 226a 226f 2270 1 2272
2277 227b 227f 2282 2287 228c 228f 2293
2294 2299 229a 229f 22a1 22a5 22a8 22ac
22af 22b3 22b5 22b9 22bc 22be 22c2 22c6
22c9 22cb 22cf 22d2 22d4 22d8 22dc 22df
22e3 22e7 22ea 22eb 22ed 22f0 22f3 22f4
22f9 22fc 2300 2304 2307 2308 230a 230e
2311 2315 2318 2319 231b 231c 2321 1
2324 2329 232d 2331 2334 2335 2337 233a
233d 233e 2343 2347 234b 234f 2352 2356
235a 235d 235e 2360 2364 2368 236b 236c
236e 236f 2371 2374 2378 237a 237e 2381
2385 2389 238d 2391 2395 2399 239d 23a1
23a5 23a9 23ad 23b1 23b5 23b9 23bd 23c1
23c5 23c9 23cd 23d1 23d5 23d9 23dd 23e1
23e4 23e7 23e8 23ea 23ee 23f2 23f4 23f8
23fc 23ff 2400 2402 2405 2408 2409 240e
2412 2416 2419 241a 241c 241f 2422 2423
2428 242c 2430 2434 2437 243b 243f 2442
2443 2445 2449 244d 2450 2451 2453 2454
2456 2459 245d 245f 2463 2466 246a 246e
2472 2476 247a 247e 2482 2486 248a 248e
2492 2496 249a 249e 24a2 24a6 24aa 24ae
24b2 24b6 24ba 24be 24c2 24c6 24c9 24cc
24cd 24cf 24d3 24d5 24d9 24dd 24e0 24e4
24e8 24eb 24ec 24ee 24f1 24f4 24f5 24fa
24fe 2502 2505 2509 250d 2510 2514 2518
251a 251e 2522 2525 2526 2528 252b 252e
252f 2534 2538 253c 253f 2540 2542 2545
2548 2549 1 254e 2553 2557 255b 255e
2562 2566 2569 256d 256f 2573 2577 257a
257e 2582 2585 2588 258b 258c 2591 2595
2599 259c 259f 25a3 25a5 25a9 25ac 25b0
25b4 25b7 25bb 25bf 25c2 25c5 25ca 25cd
25d0 25d3 25d4 25d9 25da 1 25dc 25e1
25e5 25e9 25ec 25f1 25f6 25f9 25fd 25fe
2603 2606 260b 260c 2611 2614 2619 261a
261f 2622 2626 262a 262d 262e 2633 2634
2639 263b 263f 2642 2646 264a 264e 2651
2655 2657 265b 265d 2669 266d 266f 2670
2679 
af1
2
0 1 a 6 15 19 20 :3 6
15 19 20 :3 6 16 1a 21 :3 6
19 :3 6 16 1a 21 :3 6 17 1b
22 :3 6 12 :3 6 10 :3 6 11 :3 6
10 :3 6 15 :3 6 13 :3 6 13 :3 6
18 :3 6 16 :3 6 19 1d 24 :3 6
14 18 1f :2 6 1 3 a :2 1
4 :2 14 23 14 :2 4 :2 d 1c d
:2 4 :2 b 1a b :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 10 1f 10
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 13 22 13 :2 4 :2 11 20 11
:2 4 e 17 16 :2 e :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 :3 10 :2 4 :3 15
:2 4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 12 1b 1a :2 12 :2 4
12 1b 1a :2 12 :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 :2 12 21 12 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 14 23 14 :2 4 :2 13 22 13
:2 4 :2 12 21 12 :2 4 :2 f 1e f
:2 4 17 20 1f :2 17 :2 4 18 21
20 :2 18 :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 b
1a b :2 4 :2 f 19 f 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 1c
1f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2a 2d :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2b
2e :2 6b b e :2 6b 13 16 1f
27 :2 1f 3c :2 16 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2b 2e
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2c 2f :2 6b b e :2 6b
13 16 1f 27 :2 1f 35 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
33 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 34 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 38 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 36 :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 36
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 3b :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 39 :2 16 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 2e 31 :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 29 2c :2 6b
31 34 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 7 10 1b :2 7 21
1e :2 2a :2 1e 7 10 :2 19 25 2c
35 40 :2 2c 44 :2 4d :2 25 24 5c
:2 10 :2 7 15 1c 25 30 :2 1c 34
:2 3d :2 15 :2 7 14 :2 7 13 7 4
34 a 13 1e :2 a 24 21 :2 2d
:2 21 7 14 1b 24 2f :2 1b 33
:2 3c :2 14 13 :2 7 15 1c 25 30
:2 1c 34 :2 3d :2 15 14 :2 7 15 7
37 34 7 15 1e 29 :2 15 :2 7
14 :2 7 13 7 :5 4 12 :2 4 12
:2 4 15 :2 4 18 :2 4 c :2 4 c
:2 4 12 :2 4 12 4 7 10 1b
:2 7 1e 20 :2 1e 7 1e 7 :7 a
12 19 a 12 19 :10 a f 10
24 fffa a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 22
b :2 14 1f 1d :2 28 :2 1d a d
:2 17 29 :2 33 3f 42 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 63 66
:2 24 :2 d 59 :3 a 11 :2 1a a 38
:2 7 22 11 1d 29 36 a 19
30 f 1d 28 32 a 16 25
f 10 24 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 4 b :2 14 1f 1d :2 28 :2 1d a
d :2 17 29 :2 33 3f 42 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a 11 :2 1a a
7 38 d 22 2b 33 :2 22 :2 d
37 3a :2 37 d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 :2 1a a 3c 38 :2 7 11 2a
3a 10 24 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 f 1d 26 2e
:2 1d :2 f e 33 36 :2 33 :3 a 14
2b 12 29 3d :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 38 e :2 17 22 20 :2 2b :2 20
d 10 :2 1a 2c :2 36 42 45 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 :2 10 5c :3 d 14 :2 1d
d 3b :2 a 38 :3 7 1a 30 :2 1a
7 :4 4 e 17 2d 36 4e 5b
c 1b 27 36 c 1a 27 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1a
:2 7 1d 1f :2 1d b 14 1c :2 b
1f 21 :2 1f a 29 32 3a :2 29
3d 3f :2 3d 28 :3 a 14 1d 2c
:2 14 2f 31 3a 42 :2 31 :2 14 a
42 :2 7 a 13 1d :2 a 20 22
:2 20 :4 e d 10 19 21 :2 10 24
26 :2 24 10 1c 25 33 :2 1c 36
38 41 49 :2 38 :2 1c 10 28 :2 d
25 17 1b 2f 3d 16 21 32
43 4b 52 6c 74 7b :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5c 5f 60
:2 5c :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :7 a 24 d 16 1f
:2 d 22 24 :2 22 d 19 22 2c
:2 19 2f 31 :2 19 d a 26 10
19 22 :2 10 25 27 :2 25 d 19
22 31 :2 19 34 36 3f 49 :2 36
:2 19 d a 29 26 10 19 22
:2 10 25 27 :2 25 d 19 22 2e
:2 19 31 33 3c 46 :2 33 :2 19 d
29 26 :2 a :4 7 a 13 1d :2 a
20 22 :2 20 d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 :2 1a a 24 :2 7 21 :2 4 7
10 1b :2 7 1e 20 :2 1e 7 15
1c 25 30 :2 1c 34 :2 3d :2 15 14
7 4 22 b 12 1e 21 :2 b
24 26 :2 24 a 30 39 46 :2 30
49 4b :2 49 2f :2 a 11 24 36
49 56 62 f 24 30 3d 4b
f 10 1d 2e 38 49 57 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 4e b :2 14 1f
1d :2 28 :2 1d a :4 3d 3c :3 a 18
1f 28 33 :2 1f 37 :2 40 :2 18 17
a e :2 19 21 2f 3b :2 e 3f
42 :2 3f d 4a :2 55 5d 12 21
:2 4a 25 28 :2 25 49 :2 d 10 17
23 26 :2 10 29 2b :2 29 13 1c
26 :2 13 29 2b :2 29 13 20 13
2d :3 10 1f 10 2f :2 d 2b 10
19 24 :2 10 27 29 :2 27 10 1f
:2 28 2f 38 44 :2 2f 48 :2 51 :2 1f
1e 10 2b :2 d 10 19 27 :2 10
2c 2a 35 3f :2 2c :2 2a 13 1c
2a :2 13 2d 2f :2 2d 35 :2 40 48
56 63 :2 35 67 6a :2 67 :2 13 16
1d 29 2c :2 16 2f 31 :2 2f 16
22 16 35 :3 13 :3 26 :2 13 21 :2 2a
:2 13 26 32 3f 4d 58 62 6e
22 2f 3d 49 55 22 2f 37
45 4d 56 5e 22 2e 3a 47
52 22 30 3a 49 55 22 2b
3a :2 22 3e 41 47 4d :2 26 13
6c :2 10 1a 2f 35 19 2d 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5f 62 63 :2 5f :2 35 :3 19 :2 1f
24 30 6f 72 :2 30 7f 82 :2 30
86 89 :2 30 95 98 :2 30 a0 a3
:2 30 af b2 b9 c2 c5 :2 b2 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :3 42
13 :2 1d 2f :2 39 45 48 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a :2 13 5f :3 10 17 10 42
:2 d :4 a 5e :2 7 4e 22 :2 4 8
11 1c :2 8 1f 21 :2 1f 7 28
31 3f :2 28 44 42 4d 5c :2 44
:2 42 27 :2 7 a 13 1d :2 a 20
23 :2 20 a 18 :2 21 28 31 3c
:2 28 40 49 53 :2 40 :2 18 17 a
25 :3 7 1a 24 31 3f 4a 54
20 2e 3c 4b 55 5d 20 28
34 41 4c 57 20 2e 3a 4b
57 20 26 :2 1a 7 4 60 a
13 1e :2 a 21 23 :2 21 a 13
1d :2 a 20 23 :2 20 a 18 :2 21
28 31 3c :2 28 40 49 53 :2 40
:2 18 17 a 25 :3 7 1a 24 39
47 52 5c 20 2e 3c 4b 55
5d 20 28 34 41 4c 57 20
2e 3a 4b 57 20 26 :2 1a 7
25 60 :2 4 7 10 21 :2 7 24
26 :2 24 7 :2 10 1c :2 25 7 4
2a a 13 24 :2 a 27 2a :2 27
30 39 4a :2 30 4d 50 :2 4d :2 a
7 :2 10 1c :2 25 7 54 2a :2 4
7 :2 10 19 1b :2 19 7 :2 10 1c
7 1f :2 4 7 :2 11 23 :2 2d 39
3c 4c 4f 50 :2 4c :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e 6d 70 :2 1e
74 77 :2 1e 81 84 :2 8d :2 1e :2 7
53 :3 4 b :2 14 4 :9 1 
af1
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 :6 7 :6 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :6 12 :6 13 2
:2 14 :2 1 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:7 38 :7 39 :5 3a :5 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:b 49 :11 4a 4b :2 4a
:2 4b :2 4a :2 4b :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4e :2 4a :9 4e :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 51 :2 4a :9 51 :2 4a
:2 52 :2 4a :9 52 :2 4a
:2 53 :2 4a :9 53 :2 4a
:2 54 :2 4a :9 54 :2 4a
:2 55 :2 4a :9 55 :2 4a
:2 56 :2 4a :9 56 :2 4a
:2 57 :2 4a :9 57 :2 4a
:2 58 :2 4a :9 58 :2 4a
:2 59 :2 4a :9 59 :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :4 4a :3 49 :11 5e
:b 5f :3 5e :b 64 :14 65
:d 67 :3 68 :3 69 6a
64 :b 6a :e 6b :e 6d
:3 6f 6a 64 :7 71
:3 72 :3 73 70 :3 64
:3 76 :3 77 :3 78 :3 79
:3 7a :3 7b :3 7c :3 7d
:9 7f :3 80 83 84
85 86 87 88
:3 89 :3 8a 8b 8c
8d 8e 90 91
92 93 94 95
96 97 98 99
9a 9b 9c :2 9d
83 :5 9e 81 a0
:5 a1 :3 a0 :2 a2 :5 a4
:11 a5 :24 a6 :3 a5 :2 a3
:6 a2 9f :3 7f :a ab
:11 ac :b ad :3 ac :5 af
:3 ab 7f :4 b3 :3 b4
:4 b5 :3 b6 b7 :2 b8
b3 :5 b9 b2 bb
:5 bc :3 bb :2 bd :5 bf
:11 c0 :24 c1 :3 c0 :2 be
:6 bd ba :3 b1 :a c6
:11 c7 :b c8 :3 c7 :5 ca
cb c6 :c cb :11 cc
:b cd :3 cc :5 cf cb
:3 c6 :3 d3 :2 d4 d3
:6 d5 :5 d6 d5 :5 d8
d7 :3 d5 d2 db
:5 dc :3 db :2 dd :5 df
:11 e0 :24 e1 :3 e0 :2 de
:6 dd da :3 b1 :10 e6
:2 e8 :3 e9 e8 :5 ea
e7 ec :5 ed :3 ec
:2 ee :5 f0 :11 f1 :24 f2
:3 f1 :2 ef :6 ee eb
:3 e6 :a f7 :11 f8 :b f9
:3 f8 :5 fb :3 f7 :3 e6
:6 ff b1 :3 7f :6 104
:4 105 :3 106 104 :5 107
103 109 :5 10a :3 109
:2 10b :5 10d :11 10e :24 10f
:3 10e :2 10c :6 10b 108
:3 48 :9 114 :16 115 :f 116
:3 115 :9 119 :5 11b :9 11c
:f 11d :3 11c 11b :4 121
:9 122 121 :5 123 120
125 :5 126 :3 125 :2 127
:5 129 :11 12a :24 12b :3 12a
:2 128 :6 127 124 :4 11f
:3 11b 119 :9 131 :b 132
133 131 :9 133 :f 134
135 133 131 :9 135
:f 136 135 :3 131 130
:3 119 :9 13a :11 13b :b 13c
:3 13b :5 13e :3 13a :3 114
:9 142 :e 143 145 142
:17 145 :6 147 :5 148 149
:6 14a 147 :5 14b 146
14d :5 14e :3 14d :2 14f
:5 151 :11 152 :24 153 :3 152
:2 150 :6 14f 14c :3 145
:11 158 :e 159 :11 15b :2 15c
:2 15b :4 15c :3 15b :a 15d
:9 15e :3 15f :3 15e :3 161
:3 15d 15c :9 164 :10 165
:3 164 :d 168 :17 169 :a 16a
:3 16b :3 16a :5 16d :5 16e
:8 16f :5 170 :7 171 :5 172
:5 173 :9 174 :3 16f :3 169
:3 178 :2 179 178 :6 17a
:5 17b 17a :5 17d 17c
:3 17a 177 180 :5 181
:3 180 :2 182 :5 184 :11 185
:24 186 :3 185 :2 183 :6 182
17f :3 168 :11 18b :b 18c
:3 18b :3 18e :3 168 163
:3 15b :3 158 145 :3 142
:1a 194 :9 195 :12 196 :3 195
:7 19a :6 19b :6 19c :5 19d
:2 19e :3 19a 19f 194
:9 19f :9 1a0 :12 1a1 :3 1a0
:7 1d7 :6 1d8 :6 1d9 :5 1da
:2 1db :3 1d7 19f :3 194
:9 1df :7 1e0 1e1 1df
:14 1e1 :7 1e2 1e1 :3 1df
:7 1e5 :5 1e6 :3 1e5 :11 1e9
:19 1ea :3 1e9 :5 1ec :2 48
:7 1 
267b
4
:3 0 1 :3 0 2
:a 0 aec 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
a :3 0 9 :7 0
17 16 :3 0 4
:3 0 5 :3 0 6
:3 0 b :5 0 1
1d 1c :3 0 11
c5 0 f 4
:3 0 5 :3 0 6
:3 0 c :5 0 1
23 22 :3 0 a
:3 0 d :7 0 27
26 :3 0 15 eb
0 13 a :3 0
e :7 0 2b 2a
:3 0 a :3 0 f
:7 0 2f 2e :3 0
19 111 0 17
a :3 0 10 :7 0
33 32 :3 0 a
:3 0 11 :7 0 37
36 :3 0 1d 137
0 1b a :3 0
12 :7 0 3b 3a
:3 0 a :3 0 13
:7 0 3f 3e :3 0
21 15d 0 1f
a :3 0 14 :7 0
43 42 :3 0 a
:3 0 15 :7 0 47
46 :3 0 25 :2 0
23 4 :3 0 5
:3 0 6 :3 0 16
:5 0 1 4d 4c
:3 0 4 :3 0 5
:3 0 6 :3 0 17
:5 0 1 53 52
:3 0 18 :3 0 a
:3 0 55 57 0
aec 2 58 :2 0
39 1c1 0 37
a :3 0 5b :7 0
9 :3 0 5f 5c
5d aea 0 19
:6 0 3d 1fd 0
3b a :3 0 61
:7 0 d :3 0 65
62 63 aea 0
1a :6 0 a :3 0
67 :7 0 e :3 0
6b 68 69 aea
0 1b :6 0 41
239 0 3f a
:3 0 6d :7 0 f
:3 0 71 6e 6f
aea 0 1c :6 0
a :3 0 73 :7 0
10 :3 0 77 74
75 aea 0 1d
:6 0 45 275 0
43 a :3 0 79
:7 0 11 :3 0 7d
7a 7b aea 0
1e :6 0 a :3 0
7f :7 0 12 :3 0
83 80 81 aea
0 1f :6 0 49
2b1 0 47 a
:3 0 85 :7 0 13
:3 0 89 86 87
aea 0 20 :6 0
a :3 0 8b :7 0
14 :3 0 8f 8c
8d aea 0 21
:6 0 24 :2 0 4d
a :3 0 91 :7 0
15 :3 0 95 92
93 aea 0 22
:6 0 6 :3 0 24
:2 0 4b 97 99
:6 0 9c 9a 0
aea 0 23 :6 0
27 :2 0 51 6
:3 0 4f 9e a0
:6 0 a3 a1 0
aea 0 25 :6 0
27 :2 0 55 6
:3 0 53 a5 a7
:6 0 aa a8 0
aea 0 26 :6 0
5b 344 0 59
6 :3 0 57 ac
ae :6 0 b1 af
0 aea 0 28
:6 0 24 :2 0 5d
2a :3 0 b3 :7 0
b6 b4 0 aea
0 29 :6 0 2a
:3 0 b8 :7 0 bb
b9 0 aea 0
2b :6 0 24 :2 0
61 6 :3 0 5f
bd bf :6 0 c2
c0 0 aea 0
2c :6 0 24 :2 0
65 6 :3 0 63
c4 c6 :6 0 c9
c7 0 aea 0
2d :6 0 24 :2 0
69 6 :3 0 67
cb cd :6 0 d0
ce 0 aea 0
2e :6 0 31 :2 0
6d 6 :3 0 6b
d2 d4 :6 0 d7
d5 0 aea 0
2f :6 0 31 :2 0
71 6 :3 0 6f
d9 db :6 0 de
dc 0 aea 0
30 :6 0 34 :2 0
75 6 :3 0 73
e0 e2 :6 0 e5
e3 0 aea 0
32 :6 0 31 :2 0
79 6 :3 0 77
e7 e9 :6 0 ec
ea 0 aea 0
33 :6 0 37 :2 0
7d 6 :3 0 7b
ee f0 :6 0 f3
f1 0 aea 0
35 :6 0 37 :2 0
7f a :3 0 f5
:7 0 f9 f6 f7
aea 0 36 :6 0
37 :2 0 81 a
:3 0 fb :7 0 ff
fc fd aea 0
38 :6 0 37 :2 0
83 a :3 0 101
:7 0 105 102 103
aea 0 39 :6 0
37 :2 0 85 a
:3 0 107 :7 0 10b
108 109 aea 0
3a :6 0 37 :2 0
87 a :3 0 10d
:7 0 111 10e 10f
aea 0 3b :6 0
37 :2 0 89 a
:3 0 113 :7 0 117
114 115 aea 0
3c :6 0 37 :2 0
8b a :3 0 119
:7 0 11d 11a 11b
aea 0 3d :6 0
37 :2 0 8d a
:3 0 11f :7 0 123
120 121 aea 0
3e :6 0 37 :2 0
8f a :3 0 125
:7 0 129 126 127
aea 0 3f :6 0
24 :2 0 91 a
:3 0 12b :7 0 12f
12c 12d aea 0
40 :6 0 24 :2 0
95 6 :3 0 93
131 133 :6 0 136
134 0 aea 0
41 :6 0 9b 5b2
0 99 6 :3 0
97 138 13a :6 0
13d 13b 0 aea
0 42 :6 0 37
:2 0 9d 2a :3 0
13f :7 0 142 140
0 aea 0 43
:6 0 2a :3 0 144
:7 0 147 145 0
aea 0 44 :6 0
37 :2 0 9f 46
:3 0 149 :7 0 14d
14a 14b aea 0
45 :6 0 37 :2 0
a1 46 :3 0 14f
:7 0 153 150 151
aea 0 47 :6 0
37 :2 0 a3 a
:3 0 155 :7 0 159
156 157 aea 0
48 :6 0 37 :2 0
a5 a :3 0 15b
:7 0 15f 15c 15d
aea 0 49 :6 0
37 :2 0 a7 a
:3 0 161 :7 0 165
162 163 aea 0
4a :6 0 37 :2 0
a9 a :3 0 167
:7 0 16b 168 169
aea 0 4b :6 0
37 :2 0 ab a
:3 0 16d :7 0 171
16e 16f aea 0
4c :6 0 37 :2 0
ad a :3 0 173
:7 0 177 174 175
aea 0 4d :6 0
37 :2 0 af a
:3 0 179 :7 0 17d
17a 17b aea 0
4e :6 0 37 :2 0
b1 a :3 0 17f
:7 0 183 180 181
aea 0 4f :6 0
37 :2 0 b3 a
:3 0 185 :7 0 189
186 187 aea 0
50 :6 0 190 191
0 b5 46 :3 0
18b :7 0 18f 18c
18d aea 0 51
:6 0 52 :3 0 53
:3 0 52 :3 0 54
:3 0 193 194 0
2 :4 0 b7 195
197 192 199 198
:2 0 55 :3 0 56
:3 0 19b 19c 0
57 :4 0 52 :3 0
58 :3 0 19f 1a0
0 2 :4 0 b9
1a1 1a3 59 :4 0
5a :2 0 5b :3 0
bb 1a6 1a8 :3 0
5c :4 0 5a :2 0
5d :4 0 be 1ab
1ad :3 0 5a :2 0
3 :3 0 c1 1af
1b1 :3 0 5a :2 0
5d :4 0 c4 1b3
1b5 :3 0 5a :2 0
5e :4 0 c7 1b7
1b9 :3 0 5a :2 0
5d :4 0 ca 1bb
1bd :3 0 5a :2 0
7 :3 0 cd 1bf
1c1 :3 0 5a :2 0
5d :4 0 d0 1c3
1c5 :3 0 5a :2 0
5e :4 0 d3 1c7
1c9 :3 0 5a :2 0
5d :4 0 d6 1cb
1cd :3 0 5a :2 0
8 :3 0 d9 1cf
1d1 :3 0 5a :2 0
5d :4 0 dc 1d3
1d5 :3 0 5a :2 0
5e :4 0 df 1d7
1d9 :3 0 5a :2 0
5f :3 0 60 :3 0
9 :3 0 e2 1dd
1df 61 :4 0 e4
1dc 1e2 e7 1db
1e4 :3 0 5a :2 0
5e :4 0 ea 1e6
1e8 :3 0 5a :2 0
5d :4 0 ed 1ea
1ec :3 0 5a :2 0
b :3 0 f0 1ee
1f0 :3 0 5a :2 0
5d :4 0 f3 1f2
1f4 :3 0 5a :2 0
5e :4 0 f6 1f6
1f8 :3 0 5a :2 0
5d :4 0 f9 1fa
1fc :3 0 5a :2 0
c :3 0 fc 1fe
200 :3 0 5a :2 0
5d :4 0 ff 202
204 :3 0 5a :2 0
5e :4 0 102 206
208 :3 0 5a :2 0
5f :3 0 60 :3 0
d :3 0 105 20c
20e 61 :4 0 107
20b 211 10a 20a
213 :3 0 5a :2 0
5e :4 0 10d 215
217 :3 0 5a :2 0
5f :3 0 60 :3 0
e :3 0 110 21b
21d 61 :4 0 112
21a 220 115 219
222 :3 0 5a :2 0
5e :4 0 118 224
226 :3 0 5a :2 0
5f :3 0 60 :3 0
f :3 0 11b 22a
22c 61 :4 0 11d
229 22f 120 228
231 :3 0 5a :2 0
5e :4 0 123 233
235 :3 0 5a :2 0
5f :3 0 60 :3 0
10 :3 0 126 239
23b 61 :4 0 128
238 23e 12b 237
240 :3 0 5a :2 0
5e :4 0 12e 242
244 :3 0 5a :2 0
5f :3 0 60 :3 0
11 :3 0 131 248
24a 61 :4 0 133
247 24d 136 246
24f :3 0 5a :2 0
5e :4 0 139 251
253 :3 0 5a :2 0
5f :3 0 60 :3 0
12 :3 0 13c 257
259 61 :4 0 13e
256 25c 141 255
25e :3 0 5a :2 0
5e :4 0 144 260
262 :3 0 5a :2 0
5f :3 0 60 :3 0
13 :3 0 147 266
268 61 :4 0 149
265 26b 14c 264
26d :3 0 5a :2 0
5e :4 0 14f 26f
271 :3 0 5a :2 0
5f :3 0 60 :3 0
14 :3 0 152 275
277 61 :4 0 154
274 27a 157 273
27c :3 0 5a :2 0
5e :4 0 15a 27e
280 :3 0 5a :2 0
5f :3 0 60 :3 0
15 :3 0 15d 284
286 61 :4 0 15f
283 289 162 282
28b :3 0 5a :2 0
5e :4 0 165 28d
28f :3 0 5a :2 0
5d :4 0 168 291
293 :3 0 5a :2 0
16 :3 0 16b 295
297 :3 0 5a :2 0
5d :4 0 16e 299
29b :3 0 5a :2 0
5e :4 0 171 29d
29f :3 0 5a :2 0
5d :4 0 174 2a1
2a3 :3 0 5a :2 0
17 :3 0 177 2a5
2a7 :3 0 5a :2 0
5d :4 0 17a 2a9
2ab :3 0 5a :2 0
62 :4 0 17d 2ad
2af :3 0 180 19d
2b1 :2 0 2b3 185
2b4 19a 2b3 0
2b5 187 0 ae8
52 :3 0 53 :3 0
2b6 2b7 0 52
:3 0 63 :3 0 2b9
2ba 0 31 :2 0
2 :4 0 64 :2 0
65 :2 0 31 :2 0
189 2bf 2c1 :3 0
18c 2bb 2c3 2b8
2c5 2c4 :2 0 55
:3 0 66 :3 0 2c7
2c8 0 57 :4 0
67 :4 0 5a :2 0
5b :3 0 190 2cc
2ce :3 0 193 2c9
2d0 :2 0 2d2 196
2d3 2c6 2d2 0
2d4 198 0 ae8
5f :3 0 1f :3 0
37 :2 0 19a 2d5
2d8 68 :3 0 69
:2 0 6a :3 0 2da
2dc 0 19f 2db
2de :3 0 3c :3 0
6b :3 0 6c :3 0
2e1 2e2 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1a2
2e5 2e8 68 :3 0
6e :3 0 2ea 2eb
0 1a5 2e4 2ed
2ee :2 0 6f :2 0
1a8 2e3 2f1 2e0
2f2 0 308 3a
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 1ab 2f6 2f9
68 :3 0 70 :3 0
2fb 2fc 0 1ae
2f5 2fe 2f4 2ff
0 308 1f :3 0
37 :2 0 301 302
0 308 3b :3 0
37 :2 0 304 305
0 308 71 :3 0
1b1 343 5f :3 0
1f :3 0 37 :2 0
1b6 309 30c 68
:3 0 69 :2 0 72
:3 0 30e 310 0
1bb 30f 312 :3 0
3b :3 0 6d :3 0
5f :3 0 1f :3 0
37 :2 0 1be 316
319 68 :3 0 72
:3 0 31b 31c 0
1c1 315 31e 31f
:2 0 314 320 0
333 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1c4
324 327 68 :3 0
73 :3 0 329 32a
0 1c7 323 32c
32d :2 0 322 32e
0 333 3a :3 0
37 :2 0 330 331
0 333 1ca 334
313 333 0 345
3a :3 0 5f :3 0
1f :3 0 37 :2 0
1ce 336 339 335
33a 0 342 1f
:3 0 37 :2 0 33c
33d 0 342 3b
:3 0 37 :2 0 33f
340 0 342 1d1
344 2df 308 0
345 0 342 0
345 1d5 0 ae8
4b :3 0 37 :2 0
346 347 0 ae8
30 :3 0 37 :4 0
349 34a 0 ae8
3f :3 0 37 :2 0
34c 34d 0 ae8
2b :4 0 34f 350
0 ae8 43 :4 0
352 353 0 ae8
44 :4 0 355 356
0 ae8 35 :4 0
358 359 0 ae8
51 :3 0 74 :2 0
35b 35c 0 ae8
5f :3 0 1f :3 0
37 :2 0 1d9 35e
361 75 :2 0 31
:2 0 1de 363 365
:3 0 2c :3 0 3
:3 0 367 368 0
415 76 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7c
:3 0 7d :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 83
:3 0 2d :3 0 23
:3 0 25 :3 0 30
:3 0 2b :3 0 3f
:3 0 43 :3 0 44
:3 0 48 :3 0 49
:3 0 45 :3 0 47
:3 0 84 :3 0 85
:3 0 2c :4 0 86
1 :8 0 38f 87
:3 0 88 :3 0 38a
38b 0 89 :3 0
38c 38d 0 38f
1e1 3e2 8a :3 0
87 :3 0 88 :3 0
391 392 0 89
:3 0 393 394 0
396 1e4 398 1e6
397 396 :2 0 3e0
8b :3 0 87 :3 0
88 :3 0 39b 39c
0 89 :3 0 39d
39e 0 3d8 52
:3 0 53 :3 0 3a0
3a1 0 52 :3 0
63 :3 0 3a3 3a4
0 8c :2 0 2
:4 0 8d :2 0 65
:2 0 31 :2 0 1e8
3a9 3ab :3 0 1eb
3a5 3ad 3a2 3af
3ae :2 0 55 :3 0
66 :3 0 3b1 3b2
0 57 :4 0 8e
:4 0 5a :2 0 5b
:3 0 1ef 3b6 3b8
:3 0 5a :2 0 8f
:4 0 1f2 3ba 3bc
:3 0 5a :2 0 90
:4 0 1f5 3be 3c0
:3 0 5a :2 0 89
:3 0 1f8 3c2 3c4
:3 0 5a :2 0 91
:4 0 1fb 3c6 3c8
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 1fe
3cb 3cf 202 3ca
3d1 :3 0 205 3b3
3d3 :2 0 3d5 208
3d6 3b0 3d5 0
3d7 20a 0 3d8
20c 3db :3 0 3db
0 3db 3da 3d8
3d9 :6 0 3dd 2
:3 0 20f 3df 211
3de 3dd :2 0 3e0
213 :2 0 3e2 0
3e2 3e1 38f 3e0
:6 0 415 1 :3 0
87 :3 0 88 :3 0
3e4 3e5 0 87
:3 0 75 :2 0 94
:3 0 3e7 3e9 0
218 3e8 3eb :3 0
3ec :2 0 52 :3 0
53 :3 0 3ee 3ef
0 52 :3 0 63
:3 0 3f1 3f2 0
31 :2 0 2 :4 0
95 :2 0 65 :2 0
31 :2 0 21b 3f7
3f9 :3 0 21e 3f3
3fb 3f0 3fd 3fc
:2 0 55 :3 0 66
:3 0 3ff 400 0
57 :4 0 96 :4 0
5a :2 0 5b :3 0
222 404 406 :3 0
225 401 408 :2 0
40a 228 40b 3fe
40a 0 40c 22a
0 412 18 :3 0
68 :3 0 97 :3 0
40e 40f 0 410
:2 0 412 22c 413
3ed 412 0 414
22f 0 415 231
601 76 :3 0 98
:3 0 78 :3 0 99
:3 0 79 :3 0 9a
:3 0 9b :3 0 2d
:3 0 23 :3 0 25
:3 0 38 :3 0 30
:3 0 2f :3 0 3e
:3 0 9c :3 0 9d
:3 0 3 :4 0 9e
1 :8 0 42d 87
:3 0 88 :3 0 428
429 0 89 :3 0
42a 42b 0 42d
235 480 8a :3 0
87 :3 0 88 :3 0
42f 430 0 89
:3 0 431 432 0
434 238 436 23a
435 434 :2 0 47e
8b :3 0 87 :3 0
88 :3 0 439 43a
0 89 :3 0 43b
43c 0 476 52
:3 0 53 :3 0 43e
43f 0 52 :3 0
63 :3 0 441 442
0 8c :2 0 2
:4 0 9f :2 0 65
:2 0 31 :2 0 23c
447 449 :3 0 23f
443 44b 440 44d
44c :2 0 55 :3 0
66 :3 0 44f 450
0 57 :4 0 a0
:4 0 5a :2 0 5b
:3 0 243 454 456
:3 0 5a :2 0 8f
:4 0 246 458 45a
:3 0 5a :2 0 90
:4 0 249 45c 45e
:3 0 5a :2 0 89
:3 0 24c 460 462
:3 0 5a :2 0 91
:4 0 24f 464 466
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 252
469 46d 256 468
46f :3 0 259 451
471 :2 0 473 25c
474 44e 473 0
475 25e 0 476
260 479 :3 0 479
0 479 478 476
477 :6 0 47b 4
:3 0 263 47d 265
47c 47b :2 0 47e
267 :2 0 480 0
480 47f 42d 47e
:6 0 600 1 :3 0
87 :3 0 88 :3 0
482 483 0 87
:3 0 75 :2 0 94
:3 0 485 487 0
26c 486 489 :3 0
48a :2 0 52 :3 0
53 :3 0 48c 48d
0 52 :3 0 63
:3 0 48f 490 0
31 :2 0 2 :4 0
a1 :2 0 65 :2 0
31 :2 0 26f 495
497 :3 0 272 491
499 48e 49b 49a
:2 0 55 :3 0 66
:3 0 49d 49e 0
57 :4 0 a2 :4 0
5a :2 0 5b :3 0
276 4a2 4a4 :3 0
279 49f 4a6 :2 0
4a8 27c 4a9 49c
4a8 0 4aa 27e
0 4b1 18 :3 0
68 :3 0 97 :3 0
4ac 4ad 0 4ae
:2 0 4b1 71 :3 0
280 4e4 a3 :3 0
5f :3 0 38 :3 0
37 :2 0 283 4b3
4b6 286 4b2 4b8
a4 :2 0 37 :2 0
28a 4ba 4bc :3 0
52 :3 0 53 :3 0
4be 4bf 0 52
:3 0 63 :3 0 4c1
4c2 0 31 :2 0
2 :4 0 a5 :2 0
65 :2 0 31 :2 0
28d 4c7 4c9 :3 0
290 4c3 4cb 4c0
4cd 4cc :2 0 55
:3 0 66 :3 0 4cf
4d0 0 57 :4 0
a6 :4 0 5a :2 0
5b :3 0 294 4d4
4d6 :3 0 297 4d1
4d8 :2 0 4da 29a
4db 4ce 4da 0
4dc 29c 0 4e2
18 :3 0 68 :3 0
a7 :3 0 4de 4df
0 4e0 :2 0 4e2
29e 4e3 4bd 4e2
0 4e5 48b 4b1
0 4e5 2a1 0
600 9c :3 0 a8
:3 0 19 :3 0 9d
:3 0 3 :4 0 a9
1 :8 0 501 aa
:4 0 4ec :3 0 ab
:3 0 75 :2 0 2a6
4ef 4f0 :3 0 87
:3 0 88 :3 0 4f2
4f3 0 37 :2 0
4f4 4f5 0 4f7
2a9 4fe 87 :3 0
88 :3 0 4f8 4f9
0 ac :2 0 4fa
4fb 0 4fd 2ab
4ff 4f1 4f7 0
500 0 4fd 0
500 2ad 0 501
2b0 554 8a :3 0
87 :3 0 88 :3 0
503 504 0 89
:3 0 505 506 0
508 2b3 50a 2b5
509 508 :2 0 552
8b :3 0 87 :3 0
88 :3 0 50d 50e
0 89 :3 0 50f
510 0 54a 52
:3 0 53 :3 0 512
513 0 52 :3 0
63 :3 0 515 516
0 8c :2 0 2
:4 0 ad :2 0 65
:2 0 31 :2 0 2b7
51b 51d :3 0 2ba
517 51f 514 521
520 :2 0 55 :3 0
66 :3 0 523 524
0 57 :4 0 ae
:4 0 5a :2 0 5b
:3 0 2be 528 52a
:3 0 5a :2 0 8f
:4 0 2c1 52c 52e
:3 0 5a :2 0 90
:4 0 2c4 530 532
:3 0 5a :2 0 89
:3 0 2c7 534 536
:3 0 5a :2 0 91
:4 0 2ca 538 53a
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 2cd
53d 541 2d1 53c
543 :3 0 2d4 525
545 :2 0 547 2d7
548 522 547 0
549 2d9 0 54a
2db 54d :3 0 54d
0 54d 54c 54a
54b :6 0 54f 6
:3 0 2de 551 2e0
550 54f :2 0 552
2e2 :2 0 554 0
554 553 501 552
:6 0 600 1 :3 0
af :3 0 5f :3 0
38 :3 0 37 :2 0
2e5 557 55a 2e8
556 55c 55d :2 0
a4 :2 0 37 :2 0
2ec 55f 561 :3 0
b0 :2 0 2ef 563
564 :3 0 85 :3 0
2c :3 0 84 :3 0
9d :3 0 3 :4 0
b1 1 :8 0 571
87 :3 0 88 :3 0
56c 56d 0 89
:3 0 56e 56f 0
571 2f1 5c4 8a
:3 0 87 :3 0 88
:3 0 573 574 0
89 :3 0 575 576
0 578 2f4 57a
2f6 579 578 :2 0
5c2 8b :3 0 87
:3 0 88 :3 0 57d
57e 0 89 :3 0
57f 580 0 5ba
52 :3 0 53 :3 0
582 583 0 52
:3 0 63 :3 0 585
586 0 8c :2 0
2 :4 0 b2 :2 0
65 :2 0 31 :2 0
2f8 58b 58d :3 0
2fb 587 58f 584
591 590 :2 0 55
:3 0 66 :3 0 593
594 0 57 :4 0
b3 :4 0 5a :2 0
5b :3 0 2ff 598
59a :3 0 5a :2 0
8f :4 0 302 59c
59e :3 0 5a :2 0
90 :4 0 305 5a0
5a2 :3 0 5a :2 0
89 :3 0 308 5a4
5a6 :3 0 5a :2 0
91 :4 0 30b 5a8
5aa :3 0 5a :2 0
7d :3 0 92 :3 0
31 :2 0 93 :2 0
30e 5ad 5b1 312
5ac 5b3 :3 0 315
595 5b5 :2 0 5b7
318 5b8 592 5b7
0 5b9 31a 0
5ba 31c 5bd :3 0
5bd 0 5bd 5bc
5ba 5bb :6 0 5bf
8 :3 0 31f 5c1
321 5c0 5bf :2 0
5c2 323 :2 0 5c4
0 5c4 5c3 571
5c2 :6 0 5f7 1
:3 0 87 :3 0 88
:3 0 5c6 5c7 0
87 :3 0 75 :2 0
b4 :3 0 5c9 5cb
0 328 5ca 5cd
:3 0 5ce :2 0 52
:3 0 53 :3 0 5d0
5d1 0 52 :3 0
63 :3 0 5d3 5d4
0 31 :2 0 2
:4 0 b5 :2 0 65
:2 0 31 :2 0 32b
5d9 5db :3 0 32e
5d5 5dd 5d2 5df
5de :2 0 55 :3 0
66 :3 0 5e1 5e2
0 57 :4 0 b6
:4 0 5a :2 0 5b
:3 0 332 5e6 5e8
:3 0 335 5e3 5ea
:2 0 5ec 338 5ed
5e0 5ec 0 5ee
33a 0 5f4 18
:3 0 68 :3 0 b7
:3 0 5f0 5f1 0
5f2 :2 0 5f4 33c
5f5 5cf 5f4 0
5f6 33f 0 5f7
341 5f8 565 5f7
0 5f9 344 0
600 3d :3 0 b8
:3 0 3 :3 0 346
5fb 5fd 5fa 5fe
0 600 348 602
366 415 0 603
0 600 0 603
34e 0 ae8 5f
:3 0 b9 :3 0 5f
:3 0 ba :3 0 bb
:3 0 bc :3 0 36
:3 0 39 :3 0 2e
:3 0 4e :3 0 bd
:3 0 98 :3 0 2d
:4 0 be 1 :8 0
617 87 :3 0 88
:3 0 612 613 0
89 :3 0 614 615
0 617 351 66a
8a :3 0 87 :3 0
88 :3 0 619 61a
0 89 :3 0 61b
61c 0 61e 354
620 356 61f 61e
:2 0 668 8b :3 0
87 :3 0 88 :3 0
623 624 0 89
:3 0 625 626 0
660 52 :3 0 53
:3 0 628 629 0
52 :3 0 63 :3 0
62b 62c 0 8c
:2 0 2 :4 0 bf
:2 0 65 :2 0 31
:2 0 358 631 633
:3 0 35b 62d 635
62a 637 636 :2 0
55 :3 0 66 :3 0
639 63a 0 57
:4 0 c0 :4 0 5a
:2 0 5b :3 0 35f
63e 640 :3 0 5a
:2 0 8f :4 0 362
642 644 :3 0 5a
:2 0 90 :4 0 365
646 648 :3 0 5a
:2 0 89 :3 0 368
64a 64c :3 0 5a
:2 0 91 :4 0 36b
64e 650 :3 0 5a
:2 0 7d :3 0 92
:3 0 31 :2 0 93
:2 0 36e 653 657
372 652 659 :3 0
375 63b 65b :2 0
65d 378 65e 638
65d 0 65f 37a
0 660 37c 663
:3 0 663 0 663
662 660 661 :6 0
665 a :3 0 37f
667 381 666 665
:2 0 668 383 :2 0
66a 0 66a 669
617 668 :6 0 ae8
1 :3 0 5f :3 0
3b :3 0 37 :2 0
386 66c 66f 75
:2 0 37 :2 0 38b
671 673 :3 0 5f
:3 0 1b :3 0 37
:2 0 38e 675 678
c1 :2 0 37 :2 0
393 67a 67c :3 0
67d :2 0 5f :3 0
1d :3 0 37 :2 0
396 67f 682 75
:2 0 c2 :2 0 39b
684 686 :3 0 687
:2 0 67e 689 688
:2 0 1b :3 0 5f
:3 0 36 :3 0 37
:2 0 39e 68c 68f
c3 :2 0 5f :3 0
1b :3 0 37 :2 0
3a1 692 695 3a4
691 697 :3 0 68b
698 0 69a 3a7
69b 68a 69a 0
69c 3a9 0 7b5
5f :3 0 1a :3 0
37 :2 0 3ab 69d
6a0 75 :2 0 37
:2 0 3b0 6a2 6a4
:3 0 c :3 0 c4
:2 0 3b3 6a7 6a8
:3 0 6a9 :2 0 5f
:3 0 1b :3 0 37
:2 0 3b5 6ab 6ae
c1 :2 0 37 :2 0
3ba 6b0 6b2 :3 0
1a :3 0 5f :3 0
22 :3 0 37 :2 0
3bd 6b5 6b8 c3
:2 0 5f :3 0 1b
:3 0 37 :2 0 3c0
6bb 6be 3c3 6ba
6c0 :3 0 6b4 6c1
0 6c3 3c6 6c4
6b3 6c3 0 6c5
3c8 0 6c6 3ca
730 c5 :3 0 c6
:3 0 1a :3 0 c7
:3 0 98 :3 0 2d
:3 0 c8 :3 0 7c
:3 0 7d :3 0 b
:3 0 7c :3 0 7d
:3 0 c :4 0 c9
1 :8 0 6da 87
:3 0 88 :3 0 6d5
6d6 0 89 :3 0
6d7 6d8 0 6da
3cc 72d 8a :3 0
87 :3 0 88 :3 0
6dc 6dd 0 89
:3 0 6de 6df 0
6e1 3cf 6e3 3d1
6e2 6e1 :2 0 72b
8b :3 0 87 :3 0
88 :3 0 6e6 6e7
0 89 :3 0 6e8
6e9 0 723 52
:3 0 53 :3 0 6eb
6ec 0 52 :3 0
63 :3 0 6ee 6ef
0 8c :2 0 2
:4 0 ca :2 0 65
:2 0 31 :2 0 3d3
6f4 6f6 :3 0 3d6
6f0 6f8 6ed 6fa
6f9 :2 0 55 :3 0
66 :3 0 6fc 6fd
0 57 :4 0 cb
:4 0 5a :2 0 5b
:3 0 3da 701 703
:3 0 5a :2 0 8f
:4 0 3dd 705 707
:3 0 5a :2 0 90
:4 0 3e0 709 70b
:3 0 5a :2 0 89
:3 0 3e3 70d 70f
:3 0 5a :2 0 91
:4 0 3e6 711 713
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 3e9
716 71a 3ed 715
71c :3 0 3f0 6fe
71e :2 0 720 3f3
721 6fb 720 0
722 3f5 0 723
3f7 726 :3 0 726
0 726 725 723
724 :6 0 728 c
:3 0 3fa 72a 3fc
729 728 :2 0 72b
3fe :2 0 72d 0
72d 72c 6da 72b
:6 0 72f 1 :3 0
401 731 6aa 6c6
0 732 0 72f
0 732 403 0
733 406 782 5f
:3 0 1c :3 0 37
:2 0 408 734 737
75 :2 0 31 :2 0
40d 739 73b :3 0
1a :3 0 5f :3 0
1a :3 0 37 :2 0
410 73e 741 c3
:2 0 cc :2 0 413
743 745 :3 0 73d
746 0 749 71
:3 0 416 77f 5f
:3 0 1c :3 0 37
:2 0 418 74a 74d
75 :2 0 cd :2 0
41d 74f 751 :3 0
1a :3 0 5f :3 0
36 :3 0 37 :2 0
420 754 757 c3
:2 0 5f :3 0 1a
:3 0 37 :2 0 423
75a 75d 426 759
75f :3 0 753 760
0 763 71 :3 0
429 764 752 763
0 780 5f :3 0
1c :3 0 37 :2 0
42b 765 768 75
:2 0 ce :2 0 430
76a 76c :3 0 1a
:3 0 5f :3 0 39
:3 0 37 :2 0 433
76f 772 c3 :2 0
5f :3 0 1a :3 0
37 :2 0 436 775
778 439 774 77a
:3 0 76e 77b 0
77d 43c 77e 76d
77d 0 780 73c
749 0 780 43e
0 781 442 783
6a5 733 0 784
0 781 0 784
444 0 7b5 5f
:3 0 1a :3 0 37
:2 0 447 785 788
75 :2 0 37 :2 0
44c 78a 78c :3 0
52 :3 0 53 :3 0
78e 78f 0 52
:3 0 63 :3 0 791
792 0 31 :2 0
2 :4 0 cf :2 0
65 :2 0 31 :2 0
44f 797 799 :3 0
452 793 79b 790
79d 79c :2 0 55
:3 0 66 :3 0 79f
7a0 0 57 :4 0
d0 :4 0 5a :2 0
5b :3 0 456 7a4
7a6 :3 0 459 7a1
7a8 :2 0 7aa 45c
7ab 79e 7aa 0
7ac 45e 0 7b2
18 :3 0 68 :3 0
a7 :3 0 7ae 7af
0 7b0 :2 0 7b2
460 7b3 78d 7b2
0 7b4 463 0
7b5 465 7b6 674
7b5 0 7b7 469
0 ae8 5f :3 0
1f :3 0 37 :2 0
46b 7b8 7bb 75
:2 0 cd :2 0 470
7bd 7bf :3 0 1f
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 473 7c3 7c6
68 :3 0 d1 :3 0
7c8 7c9 0 476
7c2 7cb 7cc :2 0
7c1 7cd 0 7d0
71 :3 0 479 9d5
7d :3 0 30 :3 0
31 :2 0 31 :2 0
47b 7d1 7d5 75
:2 0 37 :4 0 481
7d7 7d9 :3 0 7da
:2 0 5f :3 0 1e
:3 0 37 :2 0 484
7dc 7df 75 :2 0
37 :2 0 489 7e1
7e3 :3 0 7e4 :2 0
7db 7e6 7e5 :2 0
85 :3 0 d2 :3 0
d3 :3 0 d4 :3 0
d5 :3 0 d6 :3 0
2c :3 0 26 :3 0
28 :3 0 4d :3 0
32 :3 0 84 :3 0
76 :3 0 2d :3 0
77 :3 0 2d :3 0
78 :3 0 25 :4 0
d7 1 :8 0 800
87 :3 0 88 :3 0
7fb 7fc 0 89
:3 0 7fd 7fe 0
800 48c 853 8a
:3 0 87 :3 0 88
:3 0 802 803 0
89 :3 0 804 805
0 807 48f 809
491 808 807 :2 0
851 8b :3 0 87
:3 0 88 :3 0 80c
80d 0 89 :3 0
80e 80f 0 849
52 :3 0 53 :3 0
811 812 0 52
:3 0 63 :3 0 814
815 0 8c :2 0
2 :4 0 d8 :2 0
65 :2 0 31 :2 0
493 81a 81c :3 0
496 816 81e 813
820 81f :2 0 55
:3 0 66 :3 0 822
823 0 57 :4 0
d9 :4 0 5a :2 0
5b :3 0 49a 827
829 :3 0 5a :2 0
8f :4 0 49d 82b
82d :3 0 5a :2 0
90 :4 0 4a0 82f
831 :3 0 5a :2 0
89 :3 0 4a3 833
835 :3 0 5a :2 0
91 :4 0 4a6 837
839 :3 0 5a :2 0
7d :3 0 92 :3 0
31 :2 0 93 :2 0
4a9 83c 840 4ad
83b 842 :3 0 4b0
824 844 :2 0 846
4b3 847 821 846
0 848 4b5 0
849 4b7 84c :3 0
84c 0 84c 84b
849 84a :6 0 84e
e :3 0 4ba 850
4bc 84f 84e :2 0
851 4be :2 0 853
0 853 852 800
851 :6 0 9d3 1
:3 0 87 :3 0 88
:3 0 855 856 0
87 :3 0 75 :2 0
b4 :3 0 858 85a
0 4c3 859 85c
:3 0 85d :2 0 2c
:3 0 da :2 0 4c6
860 861 :3 0 862
:2 0 85e 864 863
:2 0 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 4c8
868 86b 68 :3 0
d1 :3 0 86d 86e
0 4cb 867 870
871 :2 0 866 872
0 9d0 db :3 0
dc :3 0 874 875
0 b :3 0 26
:3 0 dd :2 0 4ce
876 87a 69 :2 0
37 :2 0 4d4 87c
87e :3 0 87f :2 0
db :3 0 dc :3 0
881 882 0 28
:3 0 c :3 0 dd
:2 0 4d7 883 887
69 :2 0 37 :2 0
4dd 889 88b :3 0
88c :2 0 880 88e
88d :2 0 7d :3 0
32 :3 0 31 :2 0
31 :2 0 4e0 890
894 75 :2 0 cd
:4 0 4e6 896 898
:3 0 5f :3 0 3b
:3 0 37 :2 0 4e9
89a 89d 75 :2 0
37 :2 0 4ee 89f
8a1 :3 0 1f :3 0
cd :2 0 8a3 8a4
0 8a6 4f1 8a7
8a2 8a6 0 8a8
4f3 0 8ac 1e
:3 0 cd :2 0 8a9
8aa 0 8ac 4f5
8ad 899 8ac 0
8ae 4f8 0 8af
4fa 9cd 5f :3 0
1f :3 0 37 :2 0
4fc 8b0 8b3 75
:2 0 31 :2 0 501
8b5 8b7 :3 0 3a
:3 0 6b :3 0 de
:3 0 8ba 8bb 0
5f :3 0 3a :3 0
37 :2 0 504 8bd
8c0 68 :3 0 6a
:3 0 8c2 8c3 0
507 8bc 8c5 8c6
:2 0 8b9 8c7 0
8c9 50a 8ca 8b8
8c9 0 8cb 50c
0 9cc 5f :3 0
4d :3 0 37 :2 0
50e 8cc 8cf 5f
:3 0 df :2 0 1a
:3 0 37 :2 0 511
8d1 8d5 516 8d2
8d7 :3 0 5f :3 0
4d :3 0 37 :2 0
519 8d9 8dc c1
:2 0 37 :2 0 51e
8de 8e0 :3 0 db
:3 0 dc :3 0 8e2
8e3 0 b :3 0
28 :3 0 dd :2 0
521 8e4 8e8 69
:2 0 37 :2 0 527
8ea 8ec :3 0 8e1
8ee 8ed :2 0 7d
:3 0 32 :3 0 31
:2 0 31 :2 0 52a
8f0 8f4 75 :2 0
37 :4 0 530 8f6
8f8 :3 0 4f :3 0
ce :2 0 8fa 8fb
0 8fd 533 8fe
8f9 8fd 0 8ff
535 0 934 3d
:3 0 e0 :4 0 901
902 :3 0 900 903
0 934 3a :3 0
68 :3 0 e1 :3 0
906 907 0 905
908 0 934 3d
:3 0 e2 :3 0 3
:3 0 2d :3 0 23
:3 0 25 :3 0 51
:3 0 38 :3 0 7
:3 0 8 :3 0 35
:3 0 35 :3 0 b
:3 0 28 :3 0 50
:3 0 4d :3 0 1b
:3 0 1c :3 0 1d
:3 0 50 :3 0 3a
:3 0 30 :3 0 1e
:3 0 1f :3 0 20
:3 0 22 :3 0 4f
:3 0 36 :3 0 4e
:3 0 17 :3 0 5f
:3 0 36 :3 0 37
:2 0 537 928 92b
37 :2 0 74 :2 0
74 :2 0 37 :2 0
53a 90b 931 90a
932 0 934 55c
935 8ef 934 0
936 561 0 9c9
84 :3 0 e3 :3 0
1a :3 0 9d :3 0
3 :4 0 e4 1
:8 0 952 aa :4 0
93d :3 0 ab :3 0
75 :2 0 565 940
941 :3 0 87 :3 0
88 :3 0 943 944
0 37 :2 0 945
946 0 948 568
94f 87 :3 0 88
:3 0 949 94a 0
ac :2 0 94b 94c
0 94e 56a 950
942 948 0 951
0 94e 0 951
56c 0 952 56f
9a5 8a :3 0 87
:3 0 88 :3 0 954
955 0 89 :3 0
956 957 0 959
572 95b 574 95a
959 :2 0 9a3 8b
:3 0 87 :3 0 88
:3 0 95e 95f 0
89 :3 0 960 961
0 99b 52 :3 0
53 :3 0 963 964
0 52 :3 0 63
:3 0 966 967 0
8c :2 0 2 :4 0
e5 :2 0 65 :2 0
31 :2 0 576 96c
96e :3 0 579 968
970 965 972 971
:2 0 55 :3 0 66
:3 0 974 975 0
57 :4 0 e6 :4 0
5a :2 0 5b :3 0
57d 979 97b :3 0
5a :2 0 8f :4 0
580 97d 97f :3 0
5a :2 0 90 :4 0
583 981 983 :3 0
5a :2 0 89 :3 0
586 985 987 :3 0
5a :2 0 91 :4 0
589 989 98b :3 0
5a :2 0 7d :3 0
92 :3 0 31 :2 0
93 :2 0 58c 98e
992 590 98d 994
:3 0 593 976 996
:2 0 998 596 999
973 998 0 99a
598 0 99b 59a
99e :3 0 99e 0
99e 99d 99b 99c
:6 0 9a0 10 :3 0
59d 9a2 59f 9a1
9a0 :2 0 9a3 5a1
:2 0 9a5 0 9a5
9a4 952 9a3 :6 0
9c9 1 :3 0 52
:3 0 53 :3 0 9a7
9a8 0 52 :3 0
63 :3 0 9aa 9ab
0 31 :2 0 2
:4 0 e7 :2 0 65
:2 0 31 :2 0 5a4
9b0 9b2 :3 0 5a7
9ac 9b4 9a9 9b6
9b5 :2 0 55 :3 0
66 :3 0 9b8 9b9
0 57 :4 0 e8
:4 0 5a :2 0 5b
:3 0 5ab 9bd 9bf
:3 0 5ae 9ba 9c1
:2 0 9c3 5b1 9c4
9b7 9c3 0 9c5
5b3 0 9c9 18
:3 0 37 :2 0 9c7
:2 0 9c9 5b5 9ca
8d8 9c9 0 9cb
5ba 0 9cc 5bc
9ce 88f 8af 0
9cf 0 9cc 0
9cf 5bf 0 9d0
5c2 9d1 865 9d0
0 9d2 5c5 0
9d3 5c7 9d4 7e7
9d3 0 9d6 7c0
7d0 0 9d6 5ca
0 ae8 5f :3 0
1f :3 0 37 :2 0
5cd 9d7 9da 75
:2 0 37 :2 0 5d2
9dc 9de :3 0 9df
:2 0 5f :3 0 22
:3 0 37 :2 0 5d5
9e1 9e4 5f :3 0
75 :2 0 3f :3 0
37 :2 0 5d8 9e6
9ea 5dd 9e7 9ec
:3 0 9ed :2 0 9e0
9ef 9ee :2 0 5f
:3 0 3b :3 0 37
:2 0 5e0 9f1 9f4
a4 :2 0 37 :2 0
5e5 9f6 9f8 :3 0
1f :3 0 6b :3 0
de :3 0 9fb 9fc
0 5f :3 0 1f
:3 0 37 :2 0 5e8
9fe a01 5f :3 0
3b :3 0 37 :2 0
5eb a03 a06 5ee
9fd a08 a09 :2 0
9fa a0a 0 a0c
5f1 a0d 9f9 a0c
0 a0e 5f3 0
a2d 3d :3 0 e9
:3 0 3 :3 0 2d
:3 0 23 :3 0 25
:3 0 7 :3 0 8
:3 0 b :3 0 c
:3 0 1a :3 0 1b
:3 0 1c :3 0 1d
:3 0 30 :3 0 1e
:3 0 1f :3 0 20
:3 0 21 :3 0 22
:3 0 3a :3 0 16
:3 0 17 :3 0 36
:3 0 74 :2 0 74
:2 0 5f5 a10 a29
a0f a2a 0 a2d
71 :3 0 60e a74
5f :3 0 1f :3 0
37 :2 0 611 a2e
a31 75 :2 0 31
:2 0 616 a33 a35
:3 0 5f :3 0 3b
:3 0 37 :2 0 619
a37 a3a a4 :2 0
37 :2 0 61e a3c
a3e :3 0 1f :3 0
6b :3 0 de :3 0
a41 a42 0 5f
:3 0 1f :3 0 37
:2 0 621 a44 a47
5f :3 0 3b :3 0
37 :2 0 624 a49
a4c 627 a43 a4e
a4f :2 0 a40 a50
0 a52 62a a53
a3f a52 0 a54
62c 0 a72 3d
:3 0 e9 :3 0 2c
:3 0 2d :3 0 23
:3 0 25 :3 0 7
:3 0 8 :3 0 b
:3 0 c :3 0 1a
:3 0 1b :3 0 1c
:3 0 1d :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 22 :3 0 3a
:3 0 16 :3 0 17
:3 0 36 :3 0 74
:2 0 74 :2 0 62e
a56 a6f a55 a70
0 a72 647 a73
a36 a72 0 a75
9f0 a2d 0 a75
64a 0 ae8 5f
:3 0 3d :3 0 37
:2 0 64d a76 a79
75 :2 0 ea :2 0
652 a7b a7d :3 0
87 :3 0 88 :3 0
a7f a80 0 68
:3 0 eb :3 0 a82
a83 0 a81 a84
0 a87 71 :3 0
655 aa5 5f :3 0
3d :3 0 37 :2 0
657 a88 a8b a4
:2 0 37 :2 0 65c
a8d a8f :3 0 5f
:3 0 3d :3 0 37
:2 0 65f a91 a94
a4 :2 0 ac :2 0
664 a96 a98 :3 0
a90 a9a a99 :2 0
87 :3 0 88 :3 0
a9c a9d 0 68
:3 0 a7 :3 0 a9f
aa0 0 a9e aa1
0 aa3 667 aa4
a9b aa3 0 aa6
a7e a87 0 aa6
669 0 ae8 87
:3 0 88 :3 0 aa7
aa8 0 75 :2 0
ac :2 0 66e aaa
aac :3 0 87 :3 0
88 :3 0 aae aaf
0 37 :2 0 ab0
ab1 0 ab3 671
ab4 aad ab3 0
ab5 673 0 ae8
52 :3 0 53 :3 0
ab6 ab7 0 52
:3 0 63 :3 0 ab9
aba 0 31 :2 0
2 :4 0 ec :2 0
65 :2 0 31 :2 0
675 abf ac1 :3 0
678 abb ac3 ab8
ac5 ac4 :2 0 55
:3 0 66 :3 0 ac7
ac8 0 57 :4 0
ed :4 0 5a :2 0
5b :3 0 67c acc
ace :3 0 5a :2 0
8f :4 0 67f ad0
ad2 :3 0 5a :2 0
ee :4 0 682 ad4
ad6 :3 0 5a :2 0
87 :3 0 88 :3 0
ad9 ada 0 685
ad8 adc :3 0 688
ac9 ade :2 0 ae0
68b ae1 ac6 ae0
0 ae2 68d 0
ae8 18 :3 0 87
:3 0 88 :3 0 ae4
ae5 0 ae6 :2 0
ae8 68f aeb :3 0
aeb 6a4 aeb aea
ae8 ae9 :6 0 aec
:2 0 2 58 aeb
aef :3 0 aee aec
af0 :8 0 
6d7
4
:3 0 1 3 1
9 1 f 1
15 1 19 1
1f 1 25 1
29 1 2d 1
31 1 35 1
39 1 3d 1
41 1 45 1
49 1 4f 11
8 e 14 18
1e 24 28 2c
30 34 38 3c
40 44 48 4e
54 1 5a 1
60 1 66 1
6c 1 72 1
78 1 7e 1
84 1 8a 1
90 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b2 1
b7 1 be 1
bc 1 c5 1
c3 1 cc 1
ca 1 d3 1
d1 1 da 1
d8 1 e1 1
df 1 e8 1
e6 1 ef 1
ed 1 f4 1
fa 1 100 1
106 1 10c 1
112 1 118 1
11e 1 124 1
12a 1 132 1
130 1 139 1
137 1 13e 1
143 1 148 1
14e 1 154 1
15a 1 160 1
166 1 16c 1
172 1 178 1
17e 1 184 1
18a 1 196 1
1a2 2 1a5 1a7
2 1aa 1ac 2
1ae 1b0 2 1b2
1b4 2 1b6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 2
1ce 1d0 2 1d2
1d4 2 1d6 1d8
1 1de 2 1e0
1e1 2 1da 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
2 1f5 1f7 2
1f9 1fb 2 1fd
1ff 2 201 203
2 205 207 1
20d 2 20f 210
2 209 212 2
214 216 1 21c
2 21e 21f 2
218 221 2 223
225 1 22b 2
22d 22e 2 227
230 2 232 234
1 23a 2 23c
23d 2 236 23f
2 241 243 1
249 2 24b 24c
2 245 24e 2
250 252 1 258
2 25a 25b 2
254 25d 2 25f
261 1 267 2
269 26a 2 263
26c 2 26e 270
1 276 2 278
279 2 272 27b
2 27d 27f 1
285 2 287 288
2 281 28a 2
28c 28e 2 290
292 2 294 296
2 298 29a 2
29c 29e 2 2a0
2a2 2 2a4 2a6
2 2a8 2aa 2
2ac 2ae 4 19e
1a4 1a9 2b0 1
2b2 1 2b4 2
2be 2c0 3 2bc
2bd 2c2 2 2cb
2cd 2 2ca 2cf
1 2d1 1 2d3
2 2d6 2d7 1
2dd 2 2d9 2dd
2 2e6 2e7 2
2e9 2ec 2 2ef
2f0 2 2f7 2f8
2 2fa 2fd 4
2f3 300 303 306
2 30a 30b 1
311 2 30d 311
2 317 318 2
31a 31d 2 325
326 2 328 32b
3 321 32f 332
2 337 338 3
33b 33e 341 3
343 334 344 2
35f 360 1 364
2 362 364 2
389 38e 1 395
1 390 2 3a8
3aa 3 3a6 3a7
3ac 2 3b5 3b7
2 3b9 3bb 2
3bd 3bf 2 3c1
3c3 2 3c5 3c7
3 3cc 3cd 3ce
2 3c9 3d0 2
3b4 3d2 1 3d4
1 3d6 2 39f
3d7 1 3db 1
39a 2 398 3df
1 3ea 2 3e6
3ea 2 3f6 3f8
3 3f4 3f5 3fa
2 403 405 2
402 407 1 409
1 40b 2 40c
411 1 413 3
369 3e2 414 2
427 42c 1 433
1 42e 2 446
448 3 444 445
44a 2 453 455
2 457 459 2
45b 45d 2 45f
461 2 463 465
3 46a 46b 46c
2 467 46e 2
452 470 1 472
1 474 2 43d
475 1 479 1
438 2 436 47d
1 488 2 484
488 2 494 496
3 492 493 498
2 4a1 4a3 2
4a0 4a5 1 4a7
1 4a9 2 4aa
4af 2 4b4 4b5
1 4b7 1 4bb
2 4b9 4bb 2
4c6 4c8 3 4c4
4c5 4ca 2 4d3
4d5 2 4d2 4d7
1 4d9 1 4db
2 4dc 4e1 2
4e4 4e3 1 4ee
2 4ed 4ee 1
4f6 1 4fc 2
4fe 4ff 2 4eb
500 1 507 1
502 2 51a 51c
3 518 519 51e
2 527 529 2
52b 52d 2 52f
531 2 533 535
2 537 539 3
53e 53f 540 2
53b 542 2 526
544 1 546 1
548 2 511 549
1 54d 1 50c
2 50a 551 2
558 559 1 55b
1 560 2 55e
560 1 562 2
56b 570 1 577
1 572 2 58a
58c 3 588 589
58e 2 597 599
2 59b 59d 2
59f 5a1 2 5a3
5a5 2 5a7 5a9
3 5ae 5af 5b0
2 5ab 5b2 2
596 5b4 1 5b6
1 5b8 2 581
5b9 1 5bd 1
57c 2 57a 5c1
1 5cc 2 5c8
5cc 2 5d8 5da
3 5d6 5d7 5dc
2 5e5 5e7 2
5e4 5e9 1 5eb
1 5ed 2 5ee
5f3 1 5f5 2
5c4 5f6 1 5f8
1 5fc 5 480
4e5 554 5f9 5ff
2 601 602 2
611 616 1 61d
1 618 2 630
632 3 62e 62f
634 2 63d 63f
2 641 643 2
645 647 2 649
64b 2 64d 64f
3 654 655 656
2 651 658 2
63c 65a 1 65c
1 65e 2 627
65f 1 663 1
622 2 620 667
2 66d 66e 1
672 2 670 672
2 676 677 1
67b 2 679 67b
2 680 681 1
685 2 683 685
2 68d 68e 2
693 694 2 690
696 1 699 1
69b 2 69e 69f
1 6a3 2 6a1
6a3 1 6a6 2
6ac 6ad 1 6b1
2 6af 6b1 2
6b6 6b7 2 6bc
6bd 2 6b9 6bf
1 6c2 1 6c4
1 6c5 2 6d4
6d9 1 6e0 1
6db 2 6f3 6f5
3 6f1 6f2 6f7
2 700 702 2
704 706 2 708
70a 2 70c 70e
2 710 712 3
717 718 719 2
714 71b 2 6ff
71d 1 71f 1
721 2 6ea 722
1 726 1 6e5
2 6e3 72a 1
72d 2 730 731
1 732 2 735
736 1 73a 2
738 73a 2 73f
740 2 742 744
1 747 2 74b
74c 1 750 2
74e 750 2 755
756 2 75b 75c
2 758 75e 1
761 2 766 767
1 76b 2 769
76b 2 770 771
2 776 777 2
773 779 1 77c
3 77f 764 77e
1 780 2 782
783 2 786 787
1 78b 2 789
78b 2 796 798
3 794 795 79a
2 7a3 7a5 2
7a2 7a7 1 7a9
1 7ab 2 7ac
7b1 1 7b3 3
69c 784 7b4 1
7b6 2 7b9 7ba
1 7be 2 7bc
7be 2 7c4 7c5
2 7c7 7ca 1
7ce 3 7d2 7d3
7d4 1 7d8 2
7d6 7d8 2 7dd
7de 1 7e2 2
7e0 7e2 2 7fa
7ff 1 806 1
801 2 819 81b
3 817 818 81d
2 826 828 2
82a 82c 2 82e
830 2 832 834
2 836 838 3
83d 83e 83f 2
83a 841 2 825
843 1 845 1
847 2 810 848
1 84c 1 80b
2 809 850 1
85b 2 857 85b
1 85f 2 869
86a 2 86c 86f
3 877 878 879
1 87d 2 87b
87d 3 884 885
886 1 88a 2
888 88a 3 891
892 893 1 897
2 895 897 2
89b 89c 1 8a0
2 89e 8a0 1
8a5 1 8a7 2
8a8 8ab 1 8ad
1 8ae 2 8b1
8b2 1 8b6 2
8b4 8b6 2 8be
8bf 2 8c1 8c4
1 8c8 1 8ca
2 8cd 8ce 2
8d3 8d4 1 8d6
2 8d0 8d6 2
8da 8db 1 8df
2 8dd 8df 3
8e5 8e6 8e7 1
8eb 2 8e9 8eb
3 8f1 8f2 8f3
1 8f7 2 8f5
8f7 1 8fc 1
8fe 2 929 92a
21 90c 90d 90e
90f 910 911 912
913 914 915 916
917 918 919 91a
91b 91c 91d 91e
91f 920 921 922
923 924 925 926
927 92c 92d 92e
92f 930 4 8ff
904 909 933 1
935 1 93f 2
93e 93f 1 947
1 94d 2 94f
950 2 93c 951
1 958 1 953
2 96b 96d 3
969 96a 96f 2
978 97a 2 97c
97e 2 980 982
2 984 986 2
988 98a 3 98f
990 991 2 98c
993 2 977 995
1 997 1 999
2 962 99a 1
99e 1 95d 2
95b 9a2 2 9af
9b1 3 9ad 9ae
9b3 2 9bc 9be
2 9bb 9c0 1
9c2 1 9c4 4
936 9a5 9c5 9c8
1 9ca 2 8cb
9cb 2 9cd 9ce
2 873 9cf 1
9d1 2 853 9d2
2 9d5 9d4 2
9d8 9d9 1 9dd
2 9db 9dd 2
9e2 9e3 2 9e8
9e9 1 9eb 2
9e5 9eb 2 9f2
9f3 1 9f7 2
9f5 9f7 2 9ff
a00 2 a04 a05
2 a02 a07 1
a0b 1 a0d 18
a11 a12 a13 a14
a15 a16 a17 a18
a19 a1a a1b a1c
a1d a1e a1f a20
a21 a22 a23 a24
a25 a26 a27 a28
2 a0e a2b 2
a2f a30 1 a34
2 a32 a34 2
a38 a39 1 a3d
2 a3b a3d 2
a45 a46 2 a4a
a4b 2 a48 a4d
1 a51 1 a53
18 a57 a58 a59
a5a a5b a5c a5d
a5e a5f a60 a61
a62 a63 a64 a65
a66 a67 a68 a69
a6a a6b a6c a6d
a6e 2 a54 a71
2 a74 a73 2
a77 a78 1 a7c
2 a7a a7c 1
a85 2 a89 a8a
1 a8e 2 a8c
a8e 2 a92 a93
1 a97 2 a95
a97 1 aa2 2
aa5 aa4 1 aab
2 aa9 aab 1
ab2 1 ab4 2
abe ac0 3 abc
abd ac2 2 acb
acd 2 acf ad1
2 ad3 ad5 2
ad7 adb 2 aca
add 1 adf 1
ae1 14 2b5 2d4
345 348 34b 34e
351 354 357 35a
35d 603 66a 7b7
9d6 a75 aa6 ab5
ae2 ae7 32 5e
64 6a 70 76
7c 82 88 8e
94 9b a2 a9
b0 b5 ba c1
c8 cf d6 dd
e4 eb f2 f8
fe 104 10a 110
116 11c 122 128
12e 135 13c 141
146 14c 152 158
15e 164 16a 170
176 17c 182 188
18e 
1
4
0 
aef
0
1
14
11
44
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 0 0 0 
ca 1 0
2 0 1
12a 1 0
41 1 0
39 1 0
f4 1 0
106 1 0
15 1 0
112 1 0
1f 1 0
bc 1 0
29 1 0
160 1 0
130 1 0
25 1 0
d8 1 0
14e 1 0
3 1 0
17e 1 0
b2 1 0
118 1 0
16c 1 0
10c 1 0
b7 1 0
72 1 0
f 1 0
a4 1 0
60 1 0
3d 1 0
8a 1 0
19 1 0
9 1 0
90 1 0
154 1 0
11e 1 0
d1 1 0
7e 1 0
2d 1 0
184 1 0
172 1 0
143 1 0
ab 1 0
15a 1 0
100 1 0
96 1 0
45 1 0
124 1 0
18a 1 0
6c 1 0
66 1 0
178 1 0
df 1 0
78 1 0
fa 1 0
c3 1 0
9d 1 0
35 1 0
5a 1 0
148 1 0
13e 1 0
31 1 0
e6 1 0
166 1 0
4f 1 0
49 1 0
84 1 0
137 1 0
ed 1 0
0

/
SHOW ERRORS FUNCTION FC_U_TSKRES2;
ALTER FUNCTION FC_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TSKRES2
#Short Description :Update resource/profile assignment
#Description       :Gets call from FC_SEARCH_2
#Table Name        :
#Parameters        :
 $$if bitflag  = 0 then insert new assignment (assign_id = RES_ASSIGNMENT_ID)
               = 1 then update an existing assignment (assign_id = TSK_ASSIGNMENT_ID)
               = 2 then insert new assignment using project assignment (assign_id = RES_ASSIGNMENT_ID)
               = 3 then reject a profile replacement, uncommit everything
               = 9 MSP
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION SP_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_TSKRES2:
1ASSIGN_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1WORK_LOCATION001:
1PLS_INTEGER:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1WORK001:
1EUNIT:
1UNIT:
1WORK_TYPE:
1BITFLAG001:
1CONTOUR001:
1CONTOUR_TYPE001:
1OCCURRENCE:
1ASSIGN_STRING001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_WORK_LOCATION:
10:
1H_START_DATE:
126:
1H_FINISH_DATE:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_ASSIGN_STRING:
18192:
1H_REC_USER:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
164:
1+:
1FPUT:
1               ENTER:: SP_U_TSKRES2(65) :: cplan.sql(7885) :: :
1IS NULL:
18:
172:
1      RETURN_INVALID:: SP_U_TSKRES2(73) :: cplan.sql(7893) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
175:
1                EXIT:: SP_U_TSKRES2(76) :: cplan.sql(7896) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_STATE:
1FC_U_TSKRES2:
14:
1105:
1       RETURN_STATUS:: SP_U_TSKRES2(106) :: cplan.sql(7926) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
1113:
1           EXCEPTION:: SP_U_TSKRES2(114) :: cplan.sql(7934) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
1125:
1           EXCEPTION:: SP_U_TSKRES2(126) :: cplan.sql(7946) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3ca
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 a0 7e b4 2e :2 5a 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :12 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
3ca
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 13a
160 164 168 16c 16f 173 190 17b
17f 182 183 18b 17a 1ad 19b 177
19f 1a0 1a8 19a 1ca 1b8 197 1bc
1bd 1c5 1b7 1e6 1d5 1d9 1b4 1e1
1d4 203 1f1 1d1 1f5 1f6 1fe 1f0
220 20e 1ed 212 213 21b 20d 23c
22b 22f 20a 237 22a 258 247 24b
227 253 246 274 263 267 243 26f
262 290 27f 283 25f 28b 27e 2ac
29b 29f 27b 2a7 29a 2c8 2b7 2bb
297 2c3 2b6 2e4 2d3 2d7 2b3 2df
2d2 300 2ef 2f3 2cf 2fb 2ee 31c
30b 30f 2eb 317 30a 339 327 307
32b 32c 334 326 356 344 323 348
349 351 343 372 361 365 340 36d
360 392 37d 381 35d 385 38d 37c
399 39d 379 3a1 3a5 3a9 3ac 3b1
3b2 1 3b4 3b9 3bd 3c1 3c4 3c9
3cd 3d1 3d4 3d9 3da 3dc 3e1 3e4
3e8 3e9 3ee 3f3 3f6 3fb 3fc 401
404 408 409 40e 411 416 417 41c
41f 424 425 42a 42d 432 433 438
43b 43f 440 445 448 44d 44e 453
456 45b 45c 461 464 469 46a 46f
472 476 477 47c 47f 484 485 48a
48d 492 493 498 49b 49f 4a3 4a7
4a8 4aa 4af 4b0 4b2 4b3 4b8 4bb
4c0 4c1 4c6 4c9 4ce 4cf 4d4 4d7
4db 4dc 4e1 4e4 4e9 4ea 4ef 4f2
4f7 4f8 4fd 500 505 506 50b 50e
512 513 518 51b 520 521 526 529
52e 52f 534 537 53b 53f 543 544
546 54b 54c 54e 54f 554 557 55c
55d 562 565 569 56d 571 572 574
579 57a 57c 57d 582 585 58a 58b
590 593 597 59b 59f 5a0 5a2 5a7
5a8 5aa 5ab 5b0 5b3 5b8 5b9 5be
5c1 5c5 5c9 5cd 5ce 5d0 5d5 5d6
5d8 5d9 5de 5e1 5e6 5e7 5ec 5ef
5f3 5f7 5fb 5fc 5fe 603 604 606
607 60c 60f 614 615 61a 61d 621
625 629 62a 62c 631 632 634 635
63a 63d 642 643 648 64b 64f 653
657 658 65a 65f 660 662 663 668
66b 670 671 676 679 67d 681 685
686 688 68d 68e 690 691 696 699
69e 69f 6a4 6a7 6ab 6af 6b3 6b4
6b6 6bb 6bc 6be 6bf 6c4 6c7 6cc
6cd 6d2 6d5 6da 6db 6e0 6e3 6e7
6e8 6ed 6f0 6f5 6f6 6fb 6fe 703
704 709 70c 711 712 717 71a 71e
71f 724 727 72c 72d 732 735 73a
73b 740 741 746 748 74c 74f 753
757 75a 75e 762 765 768 76d 770
773 776 777 77c 77d 1 77f 784
788 78c 78f 794 799 79c 7a0 7a1
7a6 7a7 7ac 7ae 7b2 7b5 7b9 7bc
7bd 7c2 7c5 7c8 7cc 7cf 7d0 7d5
7d8 1 7db 7e0 7e4 7e7 7e8 7ed
7f0 1 7f3 7f8 7fc 7ff 800 805
808 1 80b 810 814 818 81b 81f
823 826 829 82e 831 834 837 838
83d 83e 1 840 845 849 84d 850
855 85a 85d 861 862 867 86a 86f
870 875 878 87d 87e 883 886 88a
88e 892 896 899 89a 89c 8a1 8a2
8a4 8a5 8aa 8ab 8b0 8b2 8b6 8b9
8bd 8c1 8c4 8c8 8cc 8cf 8d2 8d7
8da 8dd 8e0 8e1 8e6 8e7 1 8e9
8ee 8f2 8f6 8f9 8fe 903 906 90a
90b 910 911 916 918 91c 91f 923
927 92a 92e 932 935 939 93a 93f
941 945 948 94c 950 954 958 95c
960 964 968 96c 970 974 978 97c
980 984 988 98c 990 994 998 99c
9a0 9a4 9a8 9ac 9b0 9b4 9b8 9bc
9c0 9c4 9c8 9cc 9d0 9d4 9d8 9dc
9e0 9e4 9e8 9ec 9f0 9f4 9f8 9fc
a00 a04 a08 a0c a10 a14 a18 a1c
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a68 a6a a6e a72 a76
a79 a7d a81 a84 a87 a8c a8f a92
a95 a96 a9b a9c 1 a9e aa3 aa7
aab aae ab3 ab8 abb abf ac0 ac5
ac8 acd ace ad3 ad6 adb adc ae1
ae4 ae8 aec af0 af4 af7 af8 afa
aff b00 b02 b03 b08 b0b b10 b11
b16 b19 b1e b1f b24 b27 b2b b2c
b31 b34 b39 b3a b3f b40 b45 b47
b4b b4e b52 b56 b59 b5d b61 b64
b68 b6c b6d b72 b74 b78 b7c b7f
b83 b87 b8a b8e b92 b95 b98 b9d
ba0 ba3 ba6 ba7 bac bad 1 baf
bb4 bb8 bbc bbf bc4 bc9 bcc bd0
bd1 bd6 bd7 bdc be0 be4 be7 bec
bf1 bf4 bf8 bfc bff c00 c05 c08
c0d c0e c13 c16 c1a c1e c21 c22
c27 c28 c2d c2f c33 c36 c3a c3e
c42 c46 c4a c4e c52 c56 c5a c66
c6b c6f c73 c77 c7b c7d c7e c83
1 c87 c8b c8f c92 c96 c9a c9e
ca2 ca5 ca9 cad cb0 cb3 cb8 cbb
cbe cc1 cc2 cc7 cc8 1 cca ccf
cd3 cd7 cda cdf ce4 ce7 ceb cec
cf1 cf2 cf7 cfb cff d02 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d54 d58
d5c d60 d64 d68 d6c d78 d7d d81
d85 d89 d8d d8f d93 d95 da1 da3
da5 da6 dab daf db1 dbd dc1 dc3
dc4 dcd 
3ca
2
0 1 a 6 10 :3 6 10 :3 6
11 :3 6 17 :3 6 14 :3 6 15 :3 6
10 :3 6 e :3 6 c :3 6 b :3 6
10 :3 6 11 :3 6 11 :3 6 16 :3 6
11 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 10 19 18 :2 10 :2 4 11
1a 19 :2 11 :2 4 :2 14 23 14 :2 4
11 1a 19 :2 11 :2 4 12 1b 1a
:2 12 :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :2 c 1b c :2 4 :2 b 1a
b :2 4 :2 10 1f 10 :2 4 :2 e 1d
e :2 4 :2 e 1d e :2 4 :2 13 22
13 :2 4 :2 11 20 11 :2 4 14 1d
1c :2 14 :2 4 f 18 17 :2 f :2 4
:2 14 23 14 :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 54 5a 5d
:2 54 6b 81 8 :2 6b d 10 :2 6b
1a 1d :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 28 2b :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
29 2c :2 6b b e :2 6b 13 16
1f 27 :2 1f 3a :2 16 :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2c
2f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2d 30 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 31 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 2f :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 2e
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 33 :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 34 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
34 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 39 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 34 :2 16
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2f 32 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2a 2d
:2 6b 32 35 :2 6b :2 7 4a :2 4 7
:2 11 23 :2 2d 39 3c 4c 4e 4f
:2 4c :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :2 7 52 :2 4 :4 9 8 7 :4 22
21 20 :2 7 :4 3f 3e 3d :2 7 :4 f
e d :2 7 a :2 14 26 :2 30 3c
3f 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b1 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4f 51 52
:2 4f :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 41
:2 7 2a :3 4 13 :2 4 13 :2 4 14
:2 4 14 :2 4 15 :2 4 17 :2 4 12
:2 4 17 :2 4 10 :2 4 e :2 4 f
:2 4 e :2 4 13 :2 4 11 :2 4 11
:2 4 16 :2 4 14 :2 4 :2 d 19 26
33 40 4e 25 33 42 4c 54
5d 25 32 3d 48 58 25 36
:2 19 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 8d 95 :2 9e :2 8d
a9 :2 84 :2 1e b1 b4 :2 1e bc bf
:2 1e c4 c7 :2 1e d3 d6 :2 1e :2 7
53 :3 4 :2 f 21 :2 2a 34 41 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
3ca
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 2
:4 14 :2 1 :7 16 :7 17
:7 18 :6 19 :7 1a :7 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :7 25 :7 26 :6 27
:7 29 :b 2b :11 2c 2d
:2 2c :2 2d :2 2c :2 2d
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 30 :2 2c :9 30
:2 2c :2 31 :2 2c :2 31
:2 2c :2 31 :2 2c :2 31
:2 2c :2 32 :2 2c :2 32
:2 2c :2 32 :2 2c :2 32
:2 2c :2 33 :2 2c :9 33
:2 2c :2 34 :2 2c :9 34
:2 2c :2 35 :2 2c :9 35
:2 2c :2 36 :2 2c :9 36
:2 2c :2 37 :2 2c :9 37
:2 2c :2 38 :2 2c :9 38
:2 2c :2 39 :2 2c :9 39
:2 2c :2 3a :2 2c :9 3a
:2 2c :2 3b :2 2c :9 3b
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :4 2c :3 2b
:11 40 :b 41 :3 40 :16 46
:6 47 :2 46 :11 48 :20 49
:3 48 :11 4b :b 4c :3 4b
:9 4e 47 :2 46 :3 51
:3 52 :3 53 :3 54 :3 55
:3 56 :3 57 :3 59 :3 5a
:3 5b :3 5c :3 5d :3 5e
:3 5f :3 60 :3 61 :3 62
:8 64 :6 65 :5 66 :2 67
:3 64 :11 69 :30 6a :3 69
:a 6c 2a :3 70 :11 71
:b 72 :17 73 :3 71 :2 75
:3 76 :3 77 78 76
75 76 :3 79 :3 70
:2 7a :5 7c :11 7d :b 7e
:18 7f :3 7d :2 81 82
:3 83 84 82 81
82 :3 85 :2 7b :6 7a
6f :7 1 
dcf
4
:3 0 1 :3 0 2
:a 0 3c5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 4
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 8
:3 0 12 :7 0 39
38 :3 0 8 :3 0
13 :7 0 3d 3c
:3 0 25 :2 0 23
4 :3 0 14 :7 0
41 40 :3 0 4
:3 0 15 :7 0 45
44 :3 0 16 :3 0
17 :3 0 18 :2 0
4 49 4a 0
47 4b 0 3c5
2 4c :2 0 1c
:2 0 39 4 :3 0
1a :2 0 37 4f
51 :6 0 54 52
0 3c3 0 19
:6 0 1c :2 0 3d
4 :3 0 3b 56
58 :6 0 5b 59
0 3c3 0 1b
:6 0 1f :2 0 41
4 :3 0 3f 5d
5f :6 0 62 60
0 3c3 0 1d
:6 0 21 :2 0 43
8 :3 0 64 :7 0
68 65 66 3c3
0 1e :6 0 21
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 3c3
0 20 :6 0 1f
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 3c3
0 22 :6 0 1f
:2 0 4d 8 :3 0
78 :7 0 7c 79
7a 3c3 0 23
:6 0 1f :2 0 4f
8 :3 0 7e :7 0
82 7f 80 3c3
0 24 :6 0 1f
:2 0 51 8 :3 0
84 :7 0 88 85
86 3c3 0 25
:6 0 1f :2 0 53
8 :3 0 8a :7 0
8e 8b 8c 3c3
0 26 :6 0 1f
:2 0 55 8 :3 0
90 :7 0 94 91
92 3c3 0 27
:6 0 1f :2 0 57
8 :3 0 96 :7 0
9a 97 98 3c3
0 28 :6 0 1f
:2 0 59 8 :3 0
9c :7 0 a0 9d
9e 3c3 0 29
:6 0 1f :2 0 5b
8 :3 0 a2 :7 0
a6 a3 a4 3c3
0 2a :6 0 2d
:2 0 5d 8 :3 0
a8 :7 0 ac a9
aa 3c3 0 2b
:6 0 1a :2 0 61
4 :3 0 5f ae
b0 :6 0 b3 b1
0 3c3 0 2c
:6 0 1f :2 0 65
4 :3 0 63 b5
b7 :6 0 ba b8
0 3c3 0 2e
:6 0 c2 c3 0
67 8 :3 0 bc
:7 0 c0 bd be
3c3 0 2f :6 0
c8 c9 0 69
17 :3 0 18 :2 0
4 c4 :7 0 c7
c5 0 3c3 0
30 :6 0 31 :3 0
32 :3 0 31 :3 0
33 :3 0 cb cc
0 2 :4 0 6b
cd cf ca d1
d0 :2 0 34 :3 0
35 :3 0 d3 d4
0 36 :4 0 31
:3 0 37 :3 0 d7
d8 0 2 :4 0
6d d9 db 38
:4 0 39 :2 0 3a
:3 0 6f de e0
:3 0 3b :4 0 39
:2 0 3c :4 0 72
e3 e5 :3 0 39
:2 0 3 :3 0 75
e7 e9 :3 0 39
:2 0 3c :4 0 78
eb ed :3 0 39
:2 0 3d :4 0 7b
ef f1 :3 0 39
:2 0 3c :4 0 7e
f3 f5 :3 0 39
:2 0 5 :3 0 81
f7 f9 :3 0 39
:2 0 3c :4 0 84
fb fd :3 0 39
:2 0 3d :4 0 87
ff 101 :3 0 39
:2 0 3c :4 0 8a
103 105 :3 0 39
:2 0 6 :3 0 8d
107 109 :3 0 39
:2 0 3c :4 0 90
10b 10d :3 0 39
:2 0 3d :4 0 93
10f 111 :3 0 39
:2 0 3e :3 0 3f
:3 0 7 :3 0 96
115 117 40 :4 0
98 114 11a 9b
113 11c :3 0 39
:2 0 3d :4 0 9e
11e 120 :3 0 39
:2 0 3c :4 0 a1
122 124 :3 0 39
:2 0 9 :3 0 a4
126 128 :3 0 39
:2 0 3c :4 0 a7
12a 12c :3 0 39
:2 0 3d :4 0 aa
12e 130 :3 0 39
:2 0 3c :4 0 ad
132 134 :3 0 39
:2 0 a :3 0 b0
136 138 :3 0 39
:2 0 3c :4 0 b3
13a 13c :3 0 39
:2 0 3d :4 0 b6
13e 140 :3 0 39
:2 0 3e :3 0 3f
:3 0 b :3 0 b9
144 146 40 :4 0
bb 143 149 be
142 14b :3 0 39
:2 0 3d :4 0 c1
14d 14f :3 0 39
:2 0 3e :3 0 3f
:3 0 c :3 0 c4
153 155 40 :4 0
c6 152 158 c9
151 15a :3 0 39
:2 0 3d :4 0 cc
15c 15e :3 0 39
:2 0 3e :3 0 3f
:3 0 d :3 0 cf
162 164 40 :4 0
d1 161 167 d4
160 169 :3 0 39
:2 0 3d :4 0 d7
16b 16d :3 0 39
:2 0 3e :3 0 3f
:3 0 e :3 0 da
171 173 40 :4 0
dc 170 176 df
16f 178 :3 0 39
:2 0 3d :4 0 e2
17a 17c :3 0 39
:2 0 3e :3 0 3f
:3 0 f :3 0 e5
180 182 40 :4 0
e7 17f 185 ea
17e 187 :3 0 39
:2 0 3d :4 0 ed
189 18b :3 0 39
:2 0 3e :3 0 3f
:3 0 10 :3 0 f0
18f 191 40 :4 0
f2 18e 194 f5
18d 196 :3 0 39
:2 0 3d :4 0 f8
198 19a :3 0 39
:2 0 3e :3 0 3f
:3 0 11 :3 0 fb
19e 1a0 40 :4 0
fd 19d 1a3 100
19c 1a5 :3 0 39
:2 0 3d :4 0 103
1a7 1a9 :3 0 39
:2 0 3e :3 0 3f
:3 0 12 :3 0 106
1ad 1af 40 :4 0
108 1ac 1b2 10b
1ab 1b4 :3 0 39
:2 0 3d :4 0 10e
1b6 1b8 :3 0 39
:2 0 3e :3 0 3f
:3 0 13 :3 0 111
1bc 1be 40 :4 0
113 1bb 1c1 116
1ba 1c3 :3 0 39
:2 0 3d :4 0 119
1c5 1c7 :3 0 39
:2 0 3c :4 0 11c
1c9 1cb :3 0 39
:2 0 14 :3 0 11f
1cd 1cf :3 0 39
:2 0 3c :4 0 122
1d1 1d3 :3 0 39
:2 0 3d :4 0 125
1d5 1d7 :3 0 39
:2 0 3c :4 0 128
1d9 1db :3 0 39
:2 0 15 :3 0 12b
1dd 1df :3 0 39
:2 0 3c :4 0 12e
1e1 1e3 :3 0 39
:2 0 41 :4 0 131
1e5 1e7 :3 0 134
d5 1e9 :2 0 1eb
139 1ec d2 1eb
0 1ed 13b 0
323 31 :3 0 32
:3 0 1ee 1ef 0
31 :3 0 42 :3 0
1f1 1f2 0 43
:2 0 2 :4 0 44
:2 0 45 :2 0 43
:2 0 13d 1f7 1f9
:3 0 140 1f3 1fb
1f0 1fd 1fc :2 0
34 :3 0 46 :3 0
1ff 200 0 36
:4 0 47 :4 0 39
:2 0 3a :3 0 144
204 206 :3 0 147
201 208 :2 0 20a
14a 20b 1fe 20a
0 20c 14c 0
323 3 :3 0 48
:2 0 14e 20e 20f
:3 0 210 :2 0 211
:2 0 9 :3 0 48
:2 0 150 214 215
:3 0 216 :2 0 217
:2 0 212 219 218
:2 0 a :3 0 48
:2 0 152 21c 21d
:3 0 21e :2 0 21f
:2 0 21a 221 220
:2 0 14 :3 0 48
:2 0 154 224 225
:3 0 226 :2 0 227
:2 0 222 229 228
:2 0 31 :3 0 32
:3 0 22b 22c 0
31 :3 0 42 :3 0
22e 22f 0 49
:2 0 2 :4 0 4a
:2 0 45 :2 0 43
:2 0 156 234 236
:3 0 159 230 238
22d 23a 239 :2 0
34 :3 0 46 :3 0
23c 23d 0 36
:4 0 4b :4 0 39
:2 0 3a :3 0 15d
241 243 :3 0 39
:2 0 4c :4 0 160
245 247 :3 0 39
:2 0 4d :4 0 163
249 24b :3 0 39
:2 0 3e :3 0 3f
:3 0 4e :3 0 4f
:3 0 250 251 0
166 24f 253 40
:4 0 168 24e 256
16b 24d 258 :3 0
16e 23e 25a :2 0
25c 171 25d 23b
25c 0 25e 173
0 287 31 :3 0
32 :3 0 25f 260
0 31 :3 0 42
:3 0 262 263 0
43 :2 0 2 :4 0
50 :2 0 45 :2 0
43 :2 0 175 268
26a :3 0 178 264
26c 261 26e 26d
:2 0 34 :3 0 46
:3 0 270 271 0
36 :4 0 51 :4 0
39 :2 0 3a :3 0
17c 275 277 :3 0
17f 272 279 :2 0
27b 182 27c 26f
27b 0 27d 184
0 287 52 :3 0
53 :3 0 27e 27f
0 4e :3 0 4f
:3 0 281 282 0
54 :3 0 186 280
285 :2 0 287 189
288 22a 287 0
289 18d 0 323
19 :3 0 3 :3 0
28a 28b 0 323
1b :3 0 5 :3 0
28d 28e 0 323
1d :3 0 6 :3 0
290 291 0 323
20 :3 0 9 :3 0
293 294 0 323
22 :3 0 a :3 0
296 297 0 323
2c :3 0 14 :3 0
299 29a 0 323
2e :3 0 15 :3 0
29c 29d 0 323
1e :3 0 7 :3 0
29f 2a0 0 323
23 :3 0 b :3 0
2a2 2a3 0 323
24 :3 0 c :3 0
2a5 2a6 0 323
25 :3 0 d :3 0
2a8 2a9 0 323
26 :3 0 e :3 0
2ab 2ac 0 323
27 :3 0 f :3 0
2ae 2af 0 323
28 :3 0 10 :3 0
2b1 2b2 0 323
29 :3 0 11 :3 0
2b4 2b5 0 323
2a :3 0 12 :3 0
2b7 2b8 0 323
2b :3 0 13 :3 0
2ba 2bb 0 323
17 :3 0 55 :3 0
2bd 2be 0 56
:3 0 19 :3 0 1b
:3 0 1d :3 0 1e
:3 0 20 :3 0 22
:3 0 23 :3 0 24
:3 0 25 :3 0 26
:3 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 2b :3 0 2c
:3 0 2e :3 0 18f
2c0 2d2 2bf 2d3
0 323 31 :3 0
32 :3 0 2d5 2d6
0 31 :3 0 42
:3 0 2d8 2d9 0
57 :2 0 2 :4 0
58 :2 0 45 :2 0
43 :2 0 1a1 2de
2e0 :3 0 1a4 2da
2e2 2d7 2e4 2e3
:2 0 34 :3 0 46
:3 0 2e6 2e7 0
36 :4 0 59 :4 0
39 :2 0 3a :3 0
1a8 2eb 2ed :3 0
39 :2 0 4c :4 0
1ab 2ef 2f1 :3 0
39 :2 0 4d :4 0
1ae 2f3 2f5 :3 0
39 :2 0 3e :3 0
3f :3 0 17 :3 0
55 :3 0 2fa 2fb
0 1b1 2f9 2fd
40 :4 0 1b3 2f8
300 1b6 2f7 302
:3 0 39 :2 0 5a
:4 0 1b9 304 306
:3 0 39 :2 0 3c
:4 0 1bc 308 30a
:3 0 39 :2 0 19
:3 0 1bf 30c 30e
:3 0 39 :2 0 3c
:4 0 1c2 310 312
:3 0 1c5 2e8 314
:2 0 316 1c8 317
2e5 316 0 318
1ca 0 323 52
:3 0 5b :3 0 319
31a 0 17 :3 0
55 :3 0 31c 31d
0 19 :3 0 54
:3 0 1cc 31b 321
:2 0 323 1d0 3c4
17 :3 0 5c :2 0
4 324 325 0
31 :3 0 32 :3 0
327 328 0 31
:3 0 42 :3 0 32a
32b 0 5d :2 0
2 :4 0 5e :2 0
45 :2 0 43 :2 0
1e8 330 332 :3 0
1eb 32c 334 329
336 335 :2 0 34
:3 0 46 :3 0 338
339 0 36 :4 0
5f :4 0 39 :2 0
3a :3 0 1ef 33d
33f :3 0 1f2 33a
341 :2 0 35a 34
:3 0 46 :3 0 343
344 0 36 :4 0
60 :4 0 39 :2 0
17 :3 0 61 :3 0
349 34a 0 1f5
348 34c :3 0 39
:2 0 5a :4 0 1f8
34e 350 :3 0 39
:2 0 17 :3 0 62
:3 0 353 354 0
1fb 352 356 :3 0
1fe 345 358 :2 0
35a 201 35b 337
35a 0 35c 204
0 36c 63 :3 0
30 :3 0 17 :3 0
61 :3 0 64 :3 0
17 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 368
:2 0 36c 35e 366
:2 0 16 :3 0 30
:3 0 36a :2 0 36c
206 36e 20a 36d
36c :2 0 3c2 68
:3 0 17 :3 0 55
:3 0 371 372 0
69 :3 0 373 374
0 3ba 31 :3 0
32 :3 0 376 377
0 31 :3 0 42
:3 0 379 37a 0
5d :2 0 2 :4 0
6a :2 0 45 :2 0
43 :2 0 20c 37f
381 :3 0 20f 37b
383 378 385 384
:2 0 34 :3 0 46
:3 0 387 388 0
36 :4 0 6b :4 0
39 :2 0 3a :3 0
213 38c 38e :3 0
216 389 390 :2 0
3aa 34 :3 0 46
:3 0 392 393 0
36 :4 0 6c :4 0
39 :2 0 69 :3 0
219 397 399 :3 0
39 :2 0 6d :4 0
21c 39b 39d :3 0
39 :2 0 6e :3 0
6f :3 0 43 :2 0
70 :2 0 21f 3a0
3a4 223 39f 3a6
:3 0 226 394 3a8
:2 0 3aa 229 3ab
386 3aa 0 3ac
22c 0 3ba 63
:3 0 30 :3 0 64
:3 0 17 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
3b6 :2 0 3ba 3ae
3b4 :2 0 16 :3 0
30 :3 0 3b8 :2 0
3ba 22e 3bd :3 0
3bd 0 3bd 3bc
3ba 3bb :6 0 3bf
1 :3 0 233 3c1
235 3c0 3bf :2 0
3c2 237 :2 0 3c4
23a 3c4 3c3 323
3c2 :6 0 3c5 :2 0
2 4c 3c4 3c8
:3 0 3c7 3c5 3c9
:8 0 
24e
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 11
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 1 50 1
4e 1 57 1
55 1 5e 1
5c 1 63 1
6b 1 69 1
72 1 70 1
77 1 7d 1
83 1 89 1
8f 1 95 1
9b 1 a1 1
a7 1 af 1
ad 1 b6 1
b4 1 bb 1
c1 1 ce 1
da 2 dd df
2 e2 e4 2
e6 e8 2 ea
ec 2 ee f0
2 f2 f4 2
f6 f8 2 fa
fc 2 fe 100
2 102 104 2
106 108 2 10a
10c 2 10e 110
1 116 2 118
119 2 112 11b
2 11d 11f 2
121 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 135
137 2 139 13b
2 13d 13f 1
145 2 147 148
2 141 14a 2
14c 14e 1 154
2 156 157 2
150 159 2 15b
15d 1 163 2
165 166 2 15f
168 2 16a 16c
1 172 2 174
175 2 16e 177
2 179 17b 1
181 2 183 184
2 17d 186 2
188 18a 1 190
2 192 193 2
18c 195 2 197
199 1 19f 2
1a1 1a2 2 19b
1a4 2 1a6 1a8
1 1ae 2 1b0
1b1 2 1aa 1b3
2 1b5 1b7 1
1bd 2 1bf 1c0
2 1b9 1c2 2
1c4 1c6 2 1c8
1ca 2 1cc 1ce
2 1d0 1d2 2
1d4 1d6 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 4 d6
dc e1 1e8 1
1ea 1 1ec 2
1f6 1f8 3 1f4
1f5 1fa 2 203
205 2 202 207
1 209 1 20b
1 20d 1 213
1 21b 1 223
2 233 235 3
231 232 237 2
240 242 2 244
246 2 248 24a
1 252 2 254
255 2 24c 257
2 23f 259 1
25b 1 25d 2
267 269 3 265
266 26b 2 274
276 2 273 278
1 27a 1 27c
2 283 284 3
25e 27d 286 1
288 11 2c1 2c2
2c3 2c4 2c5 2c6
2c7 2c8 2c9 2ca
2cb 2cc 2cd 2ce
2cf 2d0 2d1 2
2dd 2df 3 2db
2dc 2e1 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 1
2fc 2 2fe 2ff
2 2f6 301 2
303 305 2 307
309 2 30b 30d
2 30f 311 2
2e9 313 1 315
1 317 3 31e
31f 320 17 1ed
20c 289 28c 28f
292 295 298 29b
29e 2a1 2a4 2a7
2aa 2ad 2b0 2b3
2b6 2b9 2bc 2d4
318 322 2 32f
331 3 32d 32e
333 2 33c 33e
2 33b 340 2
347 34b 2 34d
34f 2 351 355
2 346 357 2
342 359 1 35b
3 35c 367 36b
1 326 2 37e
380 3 37c 37d
382 2 38b 38d
2 38a 38f 2
396 398 2 39a
39c 3 3a1 3a2
3a3 2 39e 3a5
2 395 3a7 2
391 3a9 1 3ab
4 375 3ac 3b5
3b9 1 3bd 1
370 2 36e 3c1
13 53 5a 61
67 6e 75 7b
81 87 8d 93
99 9f a5 ab
b2 b9 bf c6

1
4
0 
3c8
0
1
14
2
25
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
43 1 0
2b 1 0
b 1 0
70 1 0
3b 1 0
27 1 0
23 1 0
4e 1 0
f 1 0
bb 1 0
2 0 1
1f 1 0
89 1 0
5c 1 0
77 1 0
a1 1 0
69 1 0
55 1 0
1b 1 0
a7 1 0
95 1 0
3 1 0
33 1 0
13 1 0
83 1 0
7d 1 0
8f 1 0
37 1 0
7 1 0
63 1 0
2f 1 0
b4 1 0
3f 1 0
ad 1 0
9b 1 0
17 1 0
c1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TSKRES2;
ALTER FUNCTION SP_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_ASSIGN_MSP
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_ASSIGN_MSP ==
CREATE OR REPLACE FUNCTION SP_ASSIGN_MSP wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1a2
2 :e:
1FUNCTION:
1SP_ASSIGN_MSP:
1ID:
1VARCHAR2:
1ACTION_TYPE001:
1PLS_INTEGER:
1TASK_ID001:
1START_DT001:
1FINISH_DT001:
1EFFORT001:
1ASSIGN_STRING001:
1WORK_TODATE001:
1PERCENT_COMPLETE001:
1EETC:
1DATA_FLAG:
1UNITS:
1CONTOUR_TYPE001:
1BASELINE_START001:
1BASELINE_FINISH001:
1BASELINE_DURATION001:
1BASELINE_WORK001:
1ACTUAL_START001:
1ACTUAL_FINISH001:
1ACTUAL_EFFORT001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_NAME:
1255:
1H_FULL_NAME:
1H_MESSAGE:
18192:
1H_SUBJECT:
12048:
1H_REVISION:
116:
1H_TEMP_ID:
132:
1H_TEMP_ID2:
1H_WKF_DEF_ID:
1H_UNIQUEID:
1H_RA_ID:
1H_RESOURCE_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_REC_USER:
1H_TYPE_ID:
10:
1H_WORK_LOCATION:
1H_ZERO:
1H_TWO:
12:
1H_WORK:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_UNITS:
1H_PER_DAY:
1480:
1H_IMPEX_ROLLUP:
1H_EFFORT:
1H_COUNT:
1H_TOTAL:
1H_MINUTES:
1H_DATA_FLAG:
1H_WORK_TODATE:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_NULL_STR:
11:
1H_START_DATE:
1TIMESTAMP:
1H_START_DT:
1H_ACTUAL_START:
1H_FINISH_DT:
1H_REC_DT:
1H_LOCK_DT:
1H_ASSIGN_STRING:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_OCCURRENCE:
1H_BIT_MINUTES:
1H_ACTION_TYPE:
1H_ETC:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_PERCENT_UNITS:
1CURSOR:
1C_H_WBS:
1ELEMENT_NAME:
1RTRIM:
1TO_CHAR:
1MAJOR_REVISION:
1MINOR_REVISION:
1TMT_WBS:
1PROJECT_ID:
1ELEMENT_ID:
1REC_DATETIME:
1ROWNUM:
1SELECT * FROM (SELECT ELEMENT_NAME,RTRIM(TO_CHAR(MAJOR_REVISION)) || '.' || R+
1TRIM(TO_CHAR(MINOR_REVISION)):n         FROM TMT_WBS:n         WHERE PROJECT_+
1ID = h_project_id AND ELEMENT_ID = h_task_id:n         ORDER BY REC_DATETIME +
1DESC ) WHERE ROWNUM<=1:
1CAF:
1SCHED_MIN:
1DAY_YEAR:
1ACTUAL_FLAG:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_MIN:
1SELECT SCHED_MIN, DAY_YEAR, ACTUAL_FLAG:n         FROM TASK_DAY_OF_YEAR:n    +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:n         FOR UPDATE OF ACTUAL_MIN,ACTUAL_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ASSIGN_MSP(:
1':
1, :
1COALESCE:
1NULL:
1);:
1CHECK_TRACE:
1123:
1+:
1FPUT:
1               ENTER:: SP_ASSIGN_MSP(124) :: cplan.sql(8094) :: :
1IS NULL:
1<:
1>:
13:
18:
1129:
1      RETURN_INVALID:: SP_ASSIGN_MSP(130) :: cplan.sql(8100) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1132:
1                EXIT:: SP_ASSIGN_MSP(133) :: cplan.sql(8103) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1139:
1      RETURN_INVALID:: SP_ASSIGN_MSP(140) :: cplan.sql(8110) :: :
1142:
1                EXIT:: SP_ASSIGN_MSP(143) :: cplan.sql(8113) :: :
1265:
1LENGTH:
1SC_ASSIGN_STRING_LENGTH:
1=:
1171:
1      RETURN_INVALID:: SP_ASSIGN_MSP(172) :: cplan.sql(8142) :: :
1174:
1                EXIT:: SP_ASSIGN_MSP(175) :: cplan.sql(8145) :: :
1TYPE_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type_id:n            FROM TMT+
1_WBS WHERE ELEMENT_ID = h_task_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
1194:
1           EXCEPTION:: SP_ASSIGN_MSP(195) :: cplan.sql(8165) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1GETTABLE:
1ASSIGNRESOURCE:
1COUNT:
1DUAL:
1PROFILES:
1PROFILE_ID:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL:n               WHERE EXISTS (SEL+
1ECT 'X' FROM PROFILES:n               WHERE PROJECT_ID = h_project_id AND PRO+
1FILE_ID = h_resource_id):
1221:
1           EXCEPTION:: SP_ASSIGN_MSP(222) :: cplan.sql(8192) :: :
1!=:
15:
11*5:
1IS NOT NULL:
1TO_TIMESTAMP:
1PMO_ORASTD:
1DB2TIMESTAMP:
1SELECT TO_TIMESTAMP(PMO_ORASTD.DB2TIMESTAMP(h_start_DT)) + (5 / 1440.0) INTO +
1h_finish_DT FROM DUAL:
1242:
1           EXCEPTION:: SP_ASSIGN_MSP(243) :: cplan.sql(8213) :: :
1ISWBSDELIV:
1TASK_ID:
1RESOURCE_ID:
1WORK_TODATE:
1PROJECT_ASSIGNMENT_ID:
1UNITS_MSP:
1C_EFFORT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TASK_ASSIGNMENTS:
1SELECT PROJECT_ID, TASK_ID, RESOURCE_ID, WORK_TODATE, PROJECT_ASSIGNMENT_ID,+
1:n            UNITS_MSP, C_EFFORT, C_CONTOUR, CONTOUR_TYPE, REC_DATETIME:n   +
1         INTO h_project_id, h_task_id, h_resource_id, h_work_todate, h_prj_as+
1signment_id,:n            h_percent_units, h_work, h_contour, h_contour_type,+
1 h_rec_DT:n            FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_ra_i+
1d:
1271:
1           EXCEPTION:: SP_ASSIGN_MSP(272) :: cplan.sql(8242) :: :
1SC_SQL_SUCCESS:
1282:
1        RETURN_ERROR:: SP_ASSIGN_MSP(283) :: cplan.sql(8253) :: :
1 ID:: :
1285:
1                EXIT:: SP_ASSIGN_MSP(286) :: cplan.sql(8256) :: :
1PMO_RETURN_ERROR_SP:
1295:
1        RETURN_ERROR:: SP_ASSIGN_MSP(296) :: cplan.sql(8266) :: :
1298:
1                EXIT:: SP_ASSIGN_MSP(299) :: cplan.sql(8269) :: :
1307:
1      RETURN_INVALID:: SP_ASSIGN_MSP(308) :: cplan.sql(8278) :: :
1310:
1                EXIT:: SP_ASSIGN_MSP(311) :: cplan.sql(8281) :: :
1SC_BIT_28:
1103079040:
1MINUTE_PER_DAY:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_per_day FROM TMT_WBS WHERE ELEMEN+
1T_ID = h_task_id:
1335:
1           EXCEPTION:: SP_ASSIGN_MSP(336) :: cplan.sql(8306) :: :
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000:
10.49:
1BITAND:
1FC_U_TSKRES2:
1ETC:
1PROPOSED_START:
1SCHED_START:
1PROPOSED_FINISH:
1SCHED_FINISH:
1PROPOSED_WORK:
1SCHED_WORK:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_i+
1d AND RESOURCE_ID = h_resource_id:
1FOUND:
1100:
1406:
1           EXCEPTION:: SP_ASSIGN_MSP(407) :: cplan.sql(8377) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1444:
1           EXCEPTION:: SP_ASSIGN_MSP(445) :: cplan.sql(8415) :: :
1MILESTONE_PERCENT:
1ACTUAL_START:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOS+
1ED_WORK = SCHED_WORK,:n                     ACTUAL_START = h_start_DT, ACTUAL+
1_FINISH = h_finish_DT,:n                     WORK_TODATE = work_todate001,:n +
1                    ETC = eetc:n                     WHERE TSK_ASSIGNMENT_ID +
1= h_ra_id:
1481:
1           EXCEPTION:: SP_ASSIGN_MSP(482) :: cplan.sql(8452) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_ra_id:
1501:
1           EXCEPTION:: SP_ASSIGN_MSP(502) :: cplan.sql(8472) :: :
1LAST_SUBMITTED:
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_DT:n                   +
1  WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1521:
1           EXCEPTION:: SP_ASSIGN_MSP(522) :: cplan.sql(8492) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1542:
1           EXCEPTION:: SP_ASSIGN_MSP(543) :: cplan.sql(8513) :: :
1SC_NOT_32:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND +
1RESOURCE_ID = h_resource_id:
1575:
1           EXCEPTION:: SP_ASSIGN_MSP(576) :: cplan.sql(8546) :: :
1SELECT SUBSTR(h_lock_DT,1,10) || '-' || SUBSTR(h_lock_DT,12,2) || '.' || SUBS+
1TR(h_lock_DT,15,2) || '.' || SUBSTR(h_lock_DT,18,9) INTO h_lock_DT FROM DUAL:
1597:
1           EXCEPTION:: SP_ASSIGN_MSP(598) :: cplan.sql(8568) :: :
1STRNCMP:
119:
1SC_TASK:
1TMT_WORKFLOW_CYCLES:
1PARENT_ID:
1SELECT ELEMENT_ID INTO h_wkf_def_id:n                        FROM TMT_WORKFLO+
1W_CYCLES:n                        WHERE PARENT_ID = 'NOTIFICATION':
1618:
1           EXCEPTION:: SP_ASSIGN_MSP(619) :: cplan.sql(8589) :: :
1FC_A_NOTIFICATION:
1OPEN:
1CLOSE:
1652:
1           EXCEPTION:: SP_ASSIGN_MSP(653) :: cplan.sql(8623) :: :
1FULL_NAME:
1RESOURCES:
1SELECT FULL_NAME INTO h_full_name FROM RESOURCES:n                           +
1WHERE RESOURCE_ID = h_resource_id:
1668:
1           EXCEPTION:: SP_ASSIGN_MSP(669) :: cplan.sql(8639) :: :
1Import of assignment failed.:
1Import cannot modify assignment for resource:: :
1 on the task:::
1. Assignment was modified in Timesheets during the time of export of the proj+
1ect.:
1FC_U_WORKFLOW:
1689:
1        RETURN_ERROR:: SP_ASSIGN_MSP(690) :: cplan.sql(8660) :: :
1692:
1                EXIT:: SP_ASSIGN_MSP(693) :: cplan.sql(8663) :: :
1724:
1           EXCEPTION:: SP_ASSIGN_MSP(725) :: cplan.sql(8695) :: :
1735:
1        RETURN_ERROR:: SP_ASSIGN_MSP(736) :: cplan.sql(8706) :: :
1738:
1                EXIT:: SP_ASSIGN_MSP(739) :: cplan.sql(8709) :: :
1RES_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1RES_ASSIGNMENT_ID = h_ra_id:
1773:
1           EXCEPTION:: SP_ASSIGN_MSP(774) :: cplan.sql(8744) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units,:n                        CONTOUR_TYPE =+
1 h_contour_type:n                        WHERE RES_ASSIGNMENT_ID = h_ra_id:
1795:
1           EXCEPTION:: SP_ASSIGN_MSP(796) :: cplan.sql(8766) :: :
1BASELINE3_START:
1BASELINE3_SCH_FLAG:
1BASELINE3_FINISH:
1BASELINE3_DURATION:
1BASELINE3_WORK:
1BASELINE2_START:
1BASELINE1_START:
1BASELINE2_FINISH:
1BASELINE1_FINISH:
1BASELINE2_DURATION:
1BASELINE1_DURATION:
1BASELINE2_WORK:
1BASELINE1_WORK:
1B_REGULAR_COST:
1REGULAR_COST:
1B_REGULAR_RATE:
1REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE RES_ASSIGNMENT_ID = h_ra_id:
1840:
1           EXCEPTION:: SP_ASSIGN_MSP(841) :: cplan.sql(8811) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1:n    +
1                    WHERE RES_ASSIGNMENT_ID = h_ra_id:
1879:
1           EXCEPTION:: SP_ASSIGN_MSP(880) :: cplan.sql(8850) :: :
1ELSIF:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1           UNITS_MSP = h_units,:n                  CONTOUR_TYPE = h_contour_t+
1ype:n                  WHERE RES_ASSIGNMENT_ID = h_ra_id:
1903:
1           EXCEPTION:: SP_ASSIGN_MSP(904) :: cplan.sql(8874) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1933:
1           EXCEPTION:: SP_ASSIGN_MSP(934) :: cplan.sql(8904) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1955:
1           EXCEPTION:: SP_ASSIGN_MSP(956) :: cplan.sql(8926) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = R+
1EGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n +
1                       :n                        BASELINE3_SCH_FLAG = 1,:n   +
1                     PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FIN+
1ISH,PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actua+
1l_start001,:n                        ACTUAL_FINISH = actual_finish001,:n     +
1                   WORK_TODATE = actual_effort001:n                        WH+
1ERE TSK_ASSIGNMENT_ID = h_ra_id:
11000:
1           EXCEPTION:: SP_ASSIGN_MSP(1001) :: cplan.sql(8971) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        BASEL+
1INE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_star+
1t001) ELSE BASELINE3_START END,:n                        BASELINE3_FINISH = C+
1ASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_finish001) ELSE BA+
1SELINE3_FINISH END,:n                        BASELINE3_DURATION = CASE WHEN B+
1ASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BASELINE3_DURATION END,+
1:n                        BASELINE3_WORK = CASE WHEN BASELINE3_SCH_FLAG = 0 T+
1HEN baseline_work001 ELSE BASELINE3_WORK END,:n                        :n    +
1                    BASELINE2_START = BASELINE1_START,:n                     +
1   BASELINE2_FINISH = BASELINE1_FINISH,:n                        BASELINE2_DU+
1RATION = BASELINE1_DURATION,:n                        BASELINE2_WORK = BASELI+
1NE1_WORK,:n                        :n                        BASELINE1_START +
1= baseline_start001,:n                        BASELINE1_FINISH = baseline_fin+
1ish001,:n                        BASELINE1_DURATION = baseline_duration001,:n+
1                        BASELINE1_WORK = baseline_work001,:n                 +
1       B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE, B_SPECIA+
1L_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n                      +
1  :n                        BASELINE3_SCH_FLAG = 1:n                        W+
1HERE TSK_ASSIGNMENT_ID = h_ra_id:
11039:
1           EXCEPTION:: SP_ASSIGN_MSP(1040) :: cplan.sql(9010) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        ETC =+
1 h_effort - work_todate001:n                        WHERE TSK_ASSIGNMENT_ID =+
1 h_ra_id:
11066:
1           EXCEPTION:: SP_ASSIGN_MSP(1067) :: cplan.sql(9037) :: :
11088:
1           EXCEPTION:: SP_ASSIGN_MSP(1089) :: cplan.sql(9059) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           WORK_TODATE = work_todate001:n                     WHERE TSK_ASSIG+
1NMENT_ID = h_ra_id:
11111:
1           EXCEPTION:: SP_ASSIGN_MSP(1112) :: cplan.sql(9082) :: :
1:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1SELECT TSK_ASSIGNMENT_ID, SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1,+
1 10)), TO_DATE(SubStr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGUL+
1AR_COST, REGULAR_RATE:n                  INTO h_tsk_assignment_id, h_effort, +
1h_task_id, h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale+
1:n                  FROM TASK_ASSIGNMENTS:n                  WHERE RES_ASSIGN+
1MENT_ID = h_ra_id:
11142:
1           EXCEPTION:: SP_ASSIGN_MSP(1143) :: cplan.sql(9113) :: :
1SELECT SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1, 10)), TO_DATE(SubS+
1tr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RA+
1TE:n                  INTO h_effort, h_task_id, h_SD, h_FD, h_billable, h_cap+
1ital_expense, h_reg_cost, h_reg_sale:n                  FROM TASK_ASSIGNMENTS+
1:n                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11161:
1           EXCEPTION:: SP_ASSIGN_MSP(1162) :: cplan.sql(9132) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
11186:
1           EXCEPTION:: SP_ASSIGN_MSP(1187) :: cplan.sql(9157) :: :
1MAX:
1UPDATE TASK_ASSIGNMENTS SET WORK_TODATE = SCHED_WORK,:n                     L+
1AST_SUBMITTED = (SELECT MAX(DAY_YEAR) FROM TASK_DAY_OF_YEAR:n                +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id):n                     WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11208:
1           EXCEPTION:: SP_ASSIGN_MSP(1209) :: cplan.sql(9179) :: :
1LOOP:
1EXIT:
1>=:
1-:
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = h_minutes, ACTUAL_FLAG = 1 WHERE CUR+
1RENT OF CAF:
11267:
1           EXCEPTION:: SP_ASSIGN_MSP(1268) :: cplan.sql(9238) :: :
11290:
1           EXCEPTION:: SP_ASSIGN_MSP(1291) :: cplan.sql(9261) :: :
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_D WHERE TSK_ASSIGNMENT_+
1ID = h_tsk_assignment_id:
11311:
1           EXCEPTION:: SP_ASSIGN_MSP(1312) :: cplan.sql(9282) :: :
1FC_GENERATE_TS_ALL:
1FC_GENERATE_TS_MSP:
14:
11407:
1       RETURN_STATUS:: SP_ASSIGN_MSP(1408) :: cplan.sql(9378) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11415:
1           EXCEPTION:: SP_ASSIGN_MSP(1416) :: cplan.sql(9386) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11427:
1           EXCEPTION:: SP_ASSIGN_MSP(1428) :: cplan.sql(9398) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1e7a
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a0 f4 b4 bf c8 :e a0
12a bd b7 11 a4 b1 a0 f4
b4 bf c8 :a a0 12a bd b7 11
a4 b1 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 4d d a0 4d d a0
51 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d a0 51
d :3 a0 a5 b 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :7 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 b4 2e d :4 a0 51 a5 b
a5 b d :8 a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e 52
10 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d :8 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
a0 51 d a0 6e d a0 7e
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e 5a :3 a0
51 a5 b a5 b 5a 7e 51
b4 2e a 10 a0 51 d b7
19 3c b7 :2 a0 d :17 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 51
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b 51 :2 a0 a5 57 b7 19 3c
b7 :2 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a 52 10 a0
7e b4 2e 5a 52 10 a0 7e
b4 2e 5a 52 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c :3 a0
6b d :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
:6 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :5 a0 a5 b 51 a5 b
7e :3 a0 a5 b 51 a5 b b4
2e 5a 7e 51 b4 2e 5a 7e
51 b4 2e a5 b d :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e a0 51 d a0 51 d
b7 a0 51 d b7 :2 19 3c b7
19 3c a0 4d d :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :12 a0 a5 b d :2 a0
6b 7e 51 b4 2e :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 a0 6b :12 a0 a5 b d b7
:2 19 3c b7 :3 a0 51 a5 b 7e
51 b4 2e d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :12 a0 a5
b d :2 a0 6b 7e 51 b4 2e
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 a0 6b :12 a0 a5
b d b7 :2 19 3c b7 :2 19 3c
:2 a0 6b 7e 51 b4 2e 5a :3 a0
51 a5 b 51 a5 b 5a 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :17 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 19 3c
b7 :4 a0 51 a5 b :2 a0 6b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :12 a0 a5 b d
:2 a0 6b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :f a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 a0 7e b4 2e 5a :2 a0 d
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e :3 a0 6b d a0
51 d :4 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :8 a0 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
a0 4d d a0 4d d a0 4d
d a0 4d d a0 4d d :2 a0
e9 dd b3 :3 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 6e d a0 6e d
:3 a0 7e a0 b4 2e :2 51 a5 b
d :3 a0 7e 6e b4 2e :2 51 a5
b d :3 a0 7e a0 b4 2e :2 51
a5 b d :3 a0 7e 6e b4 2e
:2 51 a5 b d :11 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :2 a0
51 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b 51 :2 a0 a5 57 b7 19
3c b7 19 3c b7 19 3c :3 a0
51 a5 b 7e 51 b4 2e d
:2 a0 6b :12 a0 a5 b d :2 a0 6b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c b7 :2 19 3c :2 a0 6b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 a0 51 d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 51 a5 b 5a
7e 51 b4 2e a0 7e b4 2e
5a a0 7e b4 2e 5a :15 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 a0 7e b4 2e 5a
:40 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :34 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e a0 7e b4 2e 5a a0 7e
b4 2e 5a :15 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
a0 7e b4 2e 5a :40 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :36 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c a0 b7 :2 a0 51
a5 b 7e 51 b4 2e a0 7e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :e a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c b7 :2 19
3c a0 7e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 6e d
a0 4d d a0 51 d a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 d :17 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :8 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :d a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 a0 e9 dd b3 :5 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
7e 51 b4 2e a0 2b b7 19
3c :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b d b7 :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e 7e :2 a0
51 a5 b b4 2e d b7 :2 19
3c b7 19 3c :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 d b7 19
3c :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e a0 2b b7
19 3c b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e :2 5a a 10
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e :4 a0 a5 b d b7 :4 a0
a5 b d b7 :2 19 3c b7 19
3c b7 19 3c b7 19 3c b7
19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
1e7a
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 186
1ac 1b0 1b4 1b8 1bb 1bf 1dc 1c7
1cb 1ce 1cf 1d7 1c6 1f9 1e7 1c3
1eb 1ec 1f4 1e6 216 204 1e3 208
209 211 203 233 221 200 225 226
22e 220 250 23e 21d 242 243 24b
23d 26d 25b 23a 25f 260 268 25a
28a 278 257 27c 27d 285 277 2a7
295 274 299 29a 2a2 294 2c4 2b2
291 2b6 2b7 2bf 2b1 2e1 2cf 2ae
2d3 2d4 2dc 2ce 2fe 2ec 2cb 2f0
2f1 2f9 2eb 31b 309 2e8 30d 30e
316 308 338 326 305 32a 32b 333
325 355 343 322 347 348 350 342
371 360 364 33f 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3cc 3f8 3eb 419 408 40c 3e8
414 407 435 424 428 404 430 423
451 440 444 420 44c 43f 46d 45c
460 43c 468 45b 489 478 47c 458
484 477 4a5 494 498 474 4a0 493
4c1 4b0 4b4 490 4bc 4af 4dd 4cc
4d0 4ac 4d8 4cb 4f9 4e8 4ec 4c8
4f4 4e7 515 504 508 4e4 510 503
531 520 524 52c 500 549 538 53c
544 51f 566 554 51c 558 559 561
553 583 571 550 575 576 57e 570
5a0 58e 56d 592 593 59b 58d 5bc
5ab 5af 5b7 58a 5d4 5c3 5c7 5cf
5aa 5f0 5df 5e3 5eb 5a7 608 5f7
5fb 603 5de 624 613 617 61f 5db
63c 62b 62f 637 612 659 647 60f
64b 64c 654 646 675 664 668 643
670 663 691 680 684 660 68c 67f
6ad 69c 6a0 67c 6a8 69b 6c9 6b8
6bc 698 6c4 6b7 6e5 6d4 6d8 6b4
6e0 6d3 701 6f0 6f4 6d0 6fc 6ef
71d 70c 710 6ec 718 70b 739 728
72c 734 708 751 740 744 74c 727
76d 75c 760 724 768 75b 789 778
77c 758 784 777 7a5 794 798 774
7a0 793 7c1 7b0 7b4 790 7bc 7af
7dd 7cc 7d0 7ac 7d8 7cb 7f9 7e8
7ec 7c8 7f4 7e7 800 804 7e4 815
818 81c 820 824 828 82c 830 834
838 83c 840 844 848 84c 850 854
860 865 867 873 877 879 87d 88e
88f 892 896 89a 89e 8a2 8a6 8aa
8ae 8b2 8b6 8ba 8be 8ca 8cf 8d1
8dd 8e1 8ff 8e7 8eb 8ef 8f2 8fa
8e6 906 90a 8e3 90e 912 916 919
91e 91f 1 921 926 92a 92e 931
936 93a 93e 941 946 947 949 94e
951 955 956 95b 960 963 968 969
96e 971 975 976 97b 97e 983 984
989 98c 991 992 997 99a 99e 9a2
9a6 9a7 9a9 9ae 9af 9b1 9b2 9b7
9ba 9bf 9c0 9c5 9c8 9cd 9ce 9d3
9d6 9da 9db 9e0 9e3 9e8 9e9 9ee
9f1 9f6 9f7 9fc 9ff a04 a05 a0a
a0d a11 a12 a17 a1a a1f a20 a25
a28 a2d a2e a33 a36 a3b a3c a41
a44 a48 a49 a4e a51 a56 a57 a5c
a5f a64 a65 a6a a6d a71 a75 a79
a7a a7c a81 a82 a84 a85 a8a a8d
a92 a93 a98 a9b aa0 aa1 aa6 aa9
aad aae ab3 ab6 abb abc ac1 ac4
ac9 aca acf ad2 ad6 ada ade adf
ae1 ae6 ae7 ae9 aea aef af2 af7
af8 afd b00 b04 b08 b0c b0d b0f
b14 b15 b17 b18 b1d b20 b25 b26
b2b b2e b32 b36 b3a b3b b3d b42
b43 b45 b46 b4b b4e b53 b54 b59
b5c b60 b64 b68 b69 b6b b70 b71
b73 b74 b79 b7c b81 b82 b87 b8a
b8e b92 b96 b97 b99 b9e b9f ba1
ba2 ba7 baa baf bb0 bb5 bb8 bbc
bc0 bc4 bc5 bc7 bcc bcd bcf bd0
bd5 bd8 bdd bde be3 be6 beb bec
bf1 bf4 bf8 bf9 bfe c01 c06 c07
c0c c0f c14 c15 c1a c1d c22 c23
c28 c2b c2f c30 c35 c38 c3d c3e
c43 c46 c4b c4c c51 c54 c58 c5c
c60 c61 c63 c68 c69 c6b c6c c71
c74 c79 c7a c7f c82 c86 c8a c8e
c8f c91 c96 c97 c99 c9a c9f ca2
ca7 ca8 cad cb0 cb5 cb6 cbb cbe
cc2 cc3 cc8 ccb cd0 cd1 cd6 cd9
cde cdf ce4 ce7 cec ced cf2 cf5
cf9 cfa cff d02 d07 d08 d0d d10
d15 d16 d1b d1e d22 d26 d2a d2b
d2d d32 d33 d35 d36 d3b d3e d43
d44 d49 d4c d51 d52 d57 d5a d5e
d5f d64 d67 d6c d6d d72 d75 d7a
d7b d80 d81 d86 d88 d8c d8f d93
d97 d9a d9e da2 da5 da8 dad db0
db3 db6 db7 dbc dbd 1 dbf dc4
dc8 dcc dcf dd4 dd9 ddc de0 de1
de6 de7 dec dee df2 df5 df9 dfc
dfd e02 e05 e08 e0c e10 e13 e14
e16 e19 e1c e1d e22 e25 e29 e2d
e30 e31 e33 e36 e39 e3a e3f 1
e42 e47 1 e4a e4f e53 e57 e5a
e5e e62 e65 e68 e6d e70 e73 e76
e77 e7c e7d 1 e7f e84 e88 e8c
e8f e94 e99 e9c ea0 ea1 ea6 ea9
eae eaf eb4 eb7 ebc ebd ec2 ec5
ec9 ecd ed1 ed5 ed8 ed9 edb ee0
ee1 ee3 ee4 ee9 eea eef ef1 ef5
ef8 efc f00 f03 f07 f0b f0e f11
f16 f19 f1c f1f f20 f25 f26 1
f28 f2d f31 f35 f38 f3d f42 f45
f49 f4a f4f f50 f55 f57 f5b f5e
f62 f66 f69 f6d f71 f74 f78 f79
f7e f80 f84 f87 f8b f8e f8f f94
f97 f9a f9e fa1 fa2 fa7 faa 1
fad fb2 fb6 fb9 fba fbf fc2 1
fc5 fca fce fd2 fd5 fd9 fdd fe0
fe3 fe8 feb fee ff1 ff2 ff7 ff8
1 ffa fff 1003 1007 100a 100f 1014
1017 101b 101c 1021 1024 1029 102a 102f
1032 1037 1038 103d 1040 1044 1048 104c
1050 1053 1054 1056 105b 105c 105e 105f
1064 1065 106a 106c 1070 1073 1077 107b
107e 1082 1086 1089 108c 1091 1094 1097
109a 109b 10a0 10a1 1 10a3 10a8 10ac
10b0 10b3 10b8 10bd 10c0 10c4 10c5 10ca
10cb 10d0 10d2 10d6 10d9 10dd 10e1 10e4
10e8 10ec 10ef 10f3 10f4 10f9 10fb 10ff
1102 1106 1107 110b 110f 1110 1114 1118
111b 111f 1123 1127 112b 112f 1133 1137
113b 113f 1143 1147 114b 114f 1153 1157
115b 115f 1163 1167 116b 116f 1173 1177
117b 117f 1183 1187 118b 118f 1193 1197
119b 119e 11a2 11a6 11aa 11ae 11af 11b1
11b4 11b5 11b7 11bb 11be 11c2 11c5 11c6
11cb 11cf 11d3 11d6 11d7 11d9 11dc 11df
11e0 11e5 11e8 11ec 11f0 11f3 11f4 11f6
11f9 11fc 11fd 1202 1 1205 120a 120e
1211 1212 1217 121a 121e 1222 1225 1229
122d 1230 1233 1238 123b 123e 1241 1242
1247 1248 1 124a 124f 1253 1257 125a
125f 1264 1267 126b 126c 1271 1274 1279
127a 127f 1282 1287 1288 128d 1290 1294
1298 129c 12a0 12a3 12a4 12a6 12ab 12ac
12ae 12af 12b4 12b5 12ba 12bc 12c0 12c3
12c7 12cb 12ce 12d2 12d6 12d9 12dc 12e1
12e4 12e7 12ea 12eb 12f0 12f1 1 12f3
12f8 12fc 1300 1303 1308 130d 1310 1314
1315 131a 131b 1320 1322 1326 1329 132d
1331 1334 1338 133c 133f 1343 1344 1349
134b 134f 1352 1356 135a 135e 1362 1366
136a 136e 1372 1376 137a 137e 1382 1386
138a 138e 1392 139e 13a2 13a6 13a9 13ad
13b1 13b3 13b7 13bb 13bf 13c2 13c6 13ca
13cc 13cd 13d2 1 13d6 13da 13de 13e1
13e5 13e9 13ed 13f1 13f4 13f8 13fc 13ff
1402 1407 140a 140d 1410 1411 1416 1417
1 1419 141e 1422 1426 1429 142e 1433
1436 143a 143b 1440 1443 1448 1449 144e
1451 1456 1457 145c 145f 1463 1464 1469
146c 1471 1472 1477 147a 147e 1482 1485
1488 1489 148b 148c 1491 1492 1497 1499
149d 14a0 14a2 14a6 14a8 14b4 14b6 14b8
14b9 14be 14c2 14c4 14d0 14d2 14d6 14da
14db 14e0 14e4 14e8 14ec 14f0 14f4 14f7
14f8 14fa 14fb 14fd 1501 1505 1509 150d
1511 1515 1519 151d 1521 1522 1524 1528
152c 1530 1533 1534 1536 1539 153c 153d
1542 1546 154a 154d 154e 1550 1553 1556
1557 1 155c 1561 1564 1568 156c 156f
1570 1572 1575 1578 1579 157e 1 1581
1586 158a 158e 1591 1592 1594 1597 159a
159b 15a0 1 15a3 15a8 15ac 15af 15b3
15b7 15bb 15bf 15c3 15c7 15cb 15cf 15d3
15df 15e3 15e7 15ea 15ee 15f2 15f4 15f8
15fc 1600 1603 1607 160b 160d 160e 1613
1 1617 161b 161f 1622 1626 162a 162e
1632 1635 1639 163d 1640 1643 1648 164b
164e 1651 1652 1657 1658 1 165a 165f
1663 1667 166a 166f 1674 1677 167b 167c
1681 1684 1689 168a 168f 1692 1697 1698
169d 16a0 16a4 16a5 16aa 16ad 16b2 16b3
16b8 16bb 16bf 16c3 16c6 16c9 16ca 16cc
16cd 16d2 16d3 16d8 16da 16de 16e1 16e3
16e7 16e9 16f5 16f7 16f9 16fa 16ff 1703
1705 1711 1713 1717 171b 171e 171f 1721
1724 1727 1728 172d 1731 1734 1738 173c
173f 1743 1747 174c 1750 1754 1757 1758
175d 1760 1764 1768 176c 1770 1774 1778
1784 1788 178c 178f 1793 1797 1799 179d
17a1 17a5 17a8 17ac 17b0 17b2 17b3 17b8
1 17bc 17c0 17c4 17c7 17cb 17cf 17d3
17d7 17da 17de 17e2 17e5 17e8 17ed 17f0
17f3 17f6 17f7 17fc 17fd 1 17ff 1804
1808 180c 180f 1814 1819 181c 1820 1821
1826 1829 182e 182f 1834 1837 183c 183d
1842 1845 1849 184a 184f 1852 1857 1858
185d 1860 1864 1868 186b 186e 186f 1871
1872 1877 1878 187d 187f 1883 1886 1888
188c 188e 189a 189c 189e 189f 18a4 18a8
18aa 18b6 18b8 18ba 18be 18c1 18c3 18c7
18ca 18cc 18d0 18d3 18d7 18db 18de 18df
18e1 18e4 18e7 18e8 18ed 18f0 18f4 18f8
18fc 18ff 1900 1902 1903 1905 1908 190b
190e 190f 1 1914 1919 191d 1920 1924
1926 192a 192d 192f 1933 1937 193b 193f
1943 1947 194b 194f 1953 1957 195b 195f
1963 1967 196b 196f 1973 1977 197b 197f
1983 1987 198b 198f 1993 1997 19a3 19a7
19ab 19ae 19b2 19b6 19b8 19bc 19c0 19c4
19c7 19cb 19cf 19d1 19d2 19d7 1 19db
19df 19e3 19e6 19ea 19ee 19f2 19f6 19f9
19fd 1a01 1a04 1a07 1a0c 1a0f 1a12 1a15
1a16 1a1b 1a1c 1 1a1e 1a23 1a27 1a2b
1a2e 1a33 1a38 1a3b 1a3f 1a40 1a45 1a48
1a4d 1a4e 1a53 1a56 1a5b 1a5c 1a61 1a64
1a68 1a69 1a6e 1a71 1a76 1a77 1a7c 1a7f
1a83 1a87 1a8a 1a8d 1a8e 1a90 1a91 1a96
1a97 1a9c 1a9e 1aa2 1aa5 1aa7 1aab 1aad
1ab9 1abb 1abd 1abe 1ac3 1ac7 1ac9 1ad5
1ad7 1adb 1adf 1ae2 1ae6 1ae9 1aed 1af0
1af1 1af6 1af9 1afd 1b01 1b04 1b05 1b07
1b0b 1b0e 1b12 1b15 1b16 1b18 1b19 1b1e
1 1b21 1b26 1b2a 1b2e 1b31 1b35 1b39
1b3c 1b3f 1b44 1b47 1b4a 1b4d 1b4e 1b53
1b54 1 1b56 1b5b 1b5f 1b63 1b66 1b6b
1b70 1b73 1b77 1b78 1b7d 1b80 1b85 1b86
1b8b 1b8e 1b93 1b94 1b99 1b9c 1ba0 1ba4
1ba7 1ba8 1baa 1baf 1bb0 1bb2 1bb3 1bb8
1bbb 1bc0 1bc1 1bc6 1bc9 1bce 1bcf 1bd4
1bd7 1bdb 1bdc 1be1 1be4 1be9 1bea 1bef
1bf0 1bf5 1bf7 1bfb 1bfe 1c02 1c06 1c09
1c0d 1c11 1c14 1c17 1c1c 1c1f 1c22 1c25
1c26 1c2b 1c2c 1 1c2e 1c33 1c37 1c3b
1c3e 1c43 1c48 1c4b 1c4f 1c50 1c55 1c56
1c5b 1c5d 1c61 1c64 1c68 1c6c 1c6f 1c72
1c76 1c7a 1c7b 1c80 1c82 1c86 1c89 1c8b
1c8f 1c93 1c96 1c9a 1c9e 1ca1 1ca2 1ca4
1ca7 1caa 1cab 1cb0 1cb4 1cb8 1cbb 1cbe
1cc1 1cc2 1cc7 1ccb 1ccf 1cd2 1cd6 1cda
1cdd 1ce0 1ce5 1ce8 1ceb 1cee 1cef 1cf4
1cf5 1 1cf7 1cfc 1d00 1d04 1d07 1d0c
1d11 1d14 1d18 1d19 1d1e 1d21 1d26 1d27
1d2c 1d2f 1d34 1d35 1d3a 1d3d 1d41 1d45
1d49 1d4d 1d50 1d51 1d53 1d58 1d59 1d5b
1d5c 1d61 1d64 1d69 1d6a 1d6f 1d72 1d77
1d78 1d7d 1d80 1d84 1d85 1d8a 1d8d 1d92
1d93 1d98 1d99 1d9e 1da0 1da4 1da7 1dab
1daf 1db2 1db6 1dba 1dbd 1dc0 1dc5 1dc8
1dcb 1dce 1dcf 1dd4 1dd5 1 1dd7 1ddc
1de0 1de4 1de7 1dec 1df1 1df4 1df8 1df9
1dfe 1dff 1e04 1e06 1e0a 1e0d 1e11 1e15
1e18 1e1c 1e20 1e23 1e27 1e2b 1e2c 1e31
1e33 1e37 1e3a 1e3e 1e41 1e42 1e47 1e4a
1e4e 1e51 1e52 1e57 1 1e5a 1e5f 1e63
1e66 1e67 1e6c 1 1e6f 1e74 1e78 1e7b
1e7c 1e81 1 1e84 1e89 1e8d 1e91 1e94
1e98 1e9c 1e9f 1ea2 1ea7 1eaa 1ead 1eb0
1eb1 1eb6 1eb7 1 1eb9 1ebe 1ec2 1ec6
1ec9 1ece 1ed3 1ed6 1eda 1edb 1ee0 1ee3
1ee8 1ee9 1eee 1ef1 1ef6 1ef7 1efc 1eff
1f03 1f07 1f0b 1f0f 1f12 1f13 1f15 1f1a
1f1b 1f1d 1f1e 1f23 1f24 1f29 1f2b 1f2f
1f32 1f36 1f3a 1f3d 1f41 1f45 1f48 1f4b
1f50 1f53 1f56 1f59 1f5a 1f5f 1f60 1
1f62 1f67 1f6b 1f6f 1f72 1f77 1f7c 1f7f
1f83 1f84 1f89 1f8a 1f8f 1f91 1f95 1f98
1f9c 1fa0 1fa3 1fa7 1fab 1fae 1fb2 1fb3
1fb8 1fba 1fbe 1fc1 1fc5 1fc9 1fcd 1fd0
1fd4 1fd8 1fdc 1fdf 1fe0 1fe2 1fe5 1fe8
1fe9 1fee 1ff2 1ff5 1ff9 1ffb 1fff 2002
2006 200a 200e 2012 2016 201a 2026 202a
202e 2031 2035 2039 203b 203f 2043 2047
204a 204e 2052 2054 2055 205a 1 205e
2062 2066 2069 206d 2071 2075 2079 207c
2080 2084 2087 208a 208f 2092 2095 2098
2099 209e 209f 1 20a1 20a6 20aa 20ae
20b1 20b6 20bb 20be 20c2 20c3 20c8 20cb
20d0 20d1 20d6 20d9 20de 20df 20e4 20e7
20eb 20ec 20f1 20f4 20f9 20fa 20ff 2102
2106 210a 210d 2110 2111 2113 2114 2119
211a 211f 2121 2125 2128 212a 212e 2130
213c 213e 2140 2141 2146 214a 214c 2158
215a 215e 2162 2165 2166 2168 216b 216e
216f 2174 2178 217c 2180 2184 2188 2189
218b 218e 218f 2191 2194 2198 219c 21a0
21a1 21a3 21a6 21a7 21a9 21aa 21af 21b2
21b5 21b8 21b9 21be 21c1 21c4 21c7 21c8
21cd 21ce 21d0 21d4 21d8 21dc 21df 21e0
21e2 21e6 21e9 21ed 21f0 21f1 21f3 21f4
21f9 21fd 2200 2204 2208 220b 220f 2211
2215 2218 221c 221e 2222 2226 2229 222b
222f 2232 2236 2237 223b 223f 2243 2247
224a 224b 224d 2250 2251 2253 2256 2259
225c 225d 2262 2266 226a 226d 226e 2270
2273 2276 2277 227c 2280 2284 2287 2288
228a 228d 2290 2291 2296 229a 229e 22a1
22a5 22a9 22ad 22b1 22b5 22b9 22bd 22c1
22c5 22c9 22cd 22d1 22d5 22d9 22dd 22e1
22e5 22e9 22ea 22ec 22f0 22f4 22f8 22fb
22fe 2301 2302 2307 230b 230f 2313 2317
231b 231f 2323 2327 232b 232f 2333 2337
233b 233f 2343 234f 2353 2358 235c 235f
2360 2365 2369 236d 2370 2373 2377 2379
237d 2381 2384 2387 238b 238d 2391 2395
2398 239a 239e 23a2 23a6 23a9 23ad 23b1
23b3 23b4 23b9 1 23bd 23c1 23c5 23c8
23cc 23d0 23d4 23d8 23db 23df 23e3 23e6
23e9 23ee 23f1 23f4 23f7 23f8 23fd 23fe
1 2400 2405 2409 240d 2410 2415 241a
241d 2421 2422 2427 242a 242f 2430 2435
2438 243d 243e 2443 2446 244a 244b 2450
2453 2458 2459 245e 2461 2465 2469 246c
246f 2470 2472 2473 2478 2479 247e 2480
2484 2487 2489 248d 248f 249b 249d 249f
24a0 24a5 24a9 24ab 24b7 24b9 24bb 24bf
24c2 24c4 24c8 24cc 24cf 24d3 24d7 24db
24df 24e3 24e7 24eb 24ef 24f3 24f7 24fb
24ff 2503 2507 250b 250f 2513 2517 2518
251a 251e 2520 2524 2528 252b 252d 2531
2535 2539 253c 253d 253f 2542 2545 2546
254b 254f 2553 2557 255a 255b 255d 2560
2563 2564 2569 256d 2571 2574 2578 257c
2580 2584 2588 258c 2590 2594 2598 259c
25a0 25a4 25a8 25ac 25b0 25b4 25b8 25bc
25bd 25bf 25c3 25c7 25cb 25ce 25d1 25d4
25d5 25da 25de 25e2 25e6 25ea 25ee 25f2
25f6 25fa 25fe 2602 2606 2612 2616 261b
261f 2622 2623 2628 262c 2630 2633 2636
263a 263c 2640 2644 2647 264a 264e 2650
2654 2658 265b 265d 2661 2665 2669 266c
2670 2674 2676 2677 267c 1 2680 2684
2688 268b 268f 2693 2697 269b 269e 26a2
26a6 26a9 26ac 26b1 26b4 26b7 26ba 26bb
26c0 26c1 1 26c3 26c8 26cc 26d0 26d3
26d8 26dd 26e0 26e4 26e5 26ea 26ed 26f2
26f3 26f8 26fb 2700 2701 2706 2709 270d
270e 2713 2716 271b 271c 2721 2724 2728
272c 272f 2732 2733 2735 2736 273b 273c
2741 2743 2747 274a 274c 2750 2752 275e
2760 2762 2763 2768 276c 276e 277a 277c
277e 2782 2785 2787 278b 278f 2792 2796
279a 279e 27a2 27a6 27aa 27ae 27b2 27b6
27ba 27be 27c2 27c6 27ca 27ce 27d2 27d6
27da 27db 27dd 27e1 27e3 27e7 27eb 27ee
27f0 27f4 27f8 27fb 27ff 2803 2806 2809
280c 280d 2812 2815 2819 281d 2821 2824
2825 2827 282a 282b 282d 2830 2833 2836
2837 283c 1 283f 2844 2848 284c 284f
2850 2852 2856 2859 285d 2860 2861 2863
2864 2869 286c 2870 2874 2877 2878 287a
287d 2880 2881 2886 1 2889 288e 2892
2896 2899 289a 289c 289f 28a2 28a3 28a8
1 28ab 28b0 28b4 28b8 28bc 28c0 28c4
28c8 28cc 28d0 28d4 28d8 28dc 28e0 28e4
28e8 28ec 28f0 28f4 28f8 28fc 2900 2904
2908 290c 2918 291c 2921 2925 2928 2929
292e 2932 2936 2939 293c 2940 2942 2946
294a 294d 2950 2954 2956 295a 295e 2961
2963 2967 296b 296f 2972 2976 297a 297c
297d 2982 1 2986 298a 298e 2991 2995
2999 299d 29a1 29a4 29a8 29ac 29af 29b2
29b7 29ba 29bd 29c0 29c1 29c6 29c7 1
29c9 29ce 29d2 29d6 29d9 29de 29e3 29e6
29ea 29eb 29f0 29f3 29f8 29f9 29fe 2a01
2a06 2a07 2a0c 2a0f 2a13 2a14 2a19 2a1c
2a21 2a22 2a27 2a2a 2a2e 2a32 2a35 2a38
2a39 2a3b 2a3c 2a41 2a42 2a47 2a49 2a4d
2a50 2a52 2a56 2a58 2a64 2a66 2a68 2a69
2a6e 2a72 2a74 2a80 2a82 2a86 2a8a 2a8e
2a92 2a96 2a9a 2a9e 2aa2 2aae 2ab2 2ab7
2abb 2abe 2abf 2ac4 2ac8 2acc 2acf 2ad2
2ad6 2ad8 2adc 2ae0 2ae3 2ae6 2aea 2aec
2af0 2af4 2af7 2af9 2afd 2b01 2b05 2b08
2b0c 2b10 2b12 2b13 2b18 1 2b1c 2b20
2b24 2b27 2b2b 2b2f 2b33 2b37 2b3a 2b3e
2b42 2b45 2b48 2b4d 2b50 2b53 2b56 2b57
2b5c 2b5d 1 2b5f 2b64 2b68 2b6c 2b6f
2b74 2b79 2b7c 2b80 2b81 2b86 2b89 2b8e
2b8f 2b94 2b97 2b9c 2b9d 2ba2 2ba5 2ba9
2baa 2baf 2bb2 2bb7 2bb8 2bbd 2bc0 2bc4
2bc8 2bcb 2bce 2bcf 2bd1 2bd2 2bd7 2bd8
2bdd 2bdf 2be3 2be6 2be8 2bec 2bee 2bfa
2bfc 2bfe 2bff 2c04 2c08 2c0a 2c16 2c18
2c1c 2c20 2c24 2c28 2c2c 2c38 2c3c 2c41
2c45 2c48 2c49 2c4e 2c52 2c56 2c59 2c5c
2c60 2c62 2c66 2c6a 2c6d 2c70 2c74 2c76
2c7a 2c7e 2c81 2c83 2c87 2c8b 2c8f 2c92
2c96 2c9a 2c9c 2c9d 2ca2 1 2ca6 2caa
2cae 2cb1 2cb5 2cb9 2cbd 2cc1 2cc4 2cc8
2ccc 2ccf 2cd2 2cd7 2cda 2cdd 2ce0 2ce1
2ce6 2ce7 1 2ce9 2cee 2cf2 2cf6 2cf9
2cfe 2d03 2d06 2d0a 2d0b 2d10 2d13 2d18
2d19 2d1e 2d21 2d26 2d27 2d2c 2d2f 2d33
2d34 2d39 2d3c 2d41 2d42 2d47 2d4a 2d4e
2d52 2d55 2d58 2d59 2d5b 2d5c 2d61 2d62
2d67 2d69 2d6d 2d70 2d72 2d76 2d78 2d84
2d86 2d88 2d89 2d8e 2d92 2d94 2da0 2da2
2da4 2da8 2dac 2db0 2db4 2db8 2dbc 2dc0
2dc4 2dc8 2dcc 2dd0 2ddc 2de0 2de5 2de9
2dec 2ded 2df2 2df6 2dfa 2dfd 2e00 2e04
2e06 2e0a 2e0e 2e11 2e14 2e18 2e1a 2e1e
2e22 2e25 2e27 2e2b 2e2f 2e33 2e36 2e3a
2e3e 2e40 2e41 2e46 1 2e4a 2e4e 2e52
2e55 2e59 2e5d 2e61 2e65 2e68 2e6c 2e70
2e73 2e76 2e7b 2e7e 2e81 2e84 2e85 2e8a
2e8b 1 2e8d 2e92 2e96 2e9a 2e9d 2ea2
2ea7 2eaa 2eae 2eaf 2eb4 2eb7 2ebc 2ebd
2ec2 2ec5 2eca 2ecb 2ed0 2ed3 2ed7 2ed8
2edd 2ee0 2ee5 2ee6 2eeb 2eee 2ef2 2ef6
2ef9 2efc 2efd 2eff 2f00 2f05 2f06 2f0b
2f0d 2f11 2f14 2f16 2f1a 2f1c 2f28 2f2a
2f2c 2f2d 2f32 2f36 2f38 2f44 2f46 2f48
2f4c 2f50 2f53 2f55 2f59 2f5c 2f5e 2f62
2f66 2f6a 2f6e 2f71 2f72 2f74 2f78 2f7c
2f7f 2f80 2f82 2f86 2f8a 2f8e 2f91 2f92
2f94 2f97 2f9a 2f9b 2fa0 2fa4 2fa8 2fab
2faf 2fb3 2fb7 2fbb 2fbf 2fc3 2fc7 2fcb
2fcf 2fd3 2fd7 2fdb 2fdf 2fe3 2fe7 2feb
2fef 2ff3 2ff4 2ff6 2ffa 2ffe 3002 3005
3008 300b 300c 3011 3014 3018 301c 301f
3020 3022 3025 3028 3029 302e 1 3031
3036 303a 303e 3041 3042 3044 3047 304a
304b 3050 1 3053 3058 305c 3060 3064
3068 306c 3070 3074 3078 307c 3080 3084
3088 308c 3090 3094 30a0 30a4 30a9 30ad
30b0 30b1 30b6 30ba 30be 30c1 30c4 30c8
30ca 30ce 30d2 30d5 30d8 30dc 30de 30e2
30e6 30e9 30eb 30ef 30f3 30f7 30fa 30fe
3102 3104 3105 310a 1 310e 3112 3116
3119 311d 3121 3125 3129 312c 3130 3134
3137 313a 313f 3142 3145 3148 3149 314e
314f 1 3151 3156 315a 315e 3161 3166
316b 316e 3172 3173 3178 317b 3180 3181
3186 3189 318e 318f 3194 3197 319b 319c
31a1 31a4 31a9 31aa 31af 31b2 31b6 31ba
31bd 31c0 31c1 31c3 31c4 31c9 31ca 31cf
31d1 31d5 31d8 31da 31de 31e0 31ec 31ee
31f0 31f1 31f6 31fa 31fc 3208 320a 320c
3210 3213 3215 3219 321c 321d 3222 3225
3229 322d 3231 3235 3239 323d 3241 3245
3249 324d 3251 3255 3259 3265 3269 326d
3270 3274 3278 327a 327e 3282 3286 3289
328d 3291 3293 3294 3299 1 329d 32a1
32a5 32a8 32ac 32b0 32b4 32b8 32bb 32bf
32c3 32c6 32c9 32ce 32d1 32d4 32d7 32d8
32dd 32de 1 32e0 32e5 32e9 32ed 32f0
32f5 32fa 32fd 3301 3302 3307 330a 330f
3310 3315 3318 331d 331e 3323 3326 332a
332b 3330 3333 3338 3339 333e 3341 3345
3349 334c 334f 3350 3352 3353 3358 3359
335e 3360 3364 3367 3369 336d 336f 337b
337d 337f 3380 3385 3389 338b 3397 3399
339d 33a1 33a4 33a8 33ac 33af 33b0 33b2
33b5 33b8 33b9 33be 33c2 33c6 33ca 33cd
33d1 33d5 33d8 33dc 33e0 33e4 33e8 33ec
33f8 33fc 3400 3403 3407 340b 340d 3411
3415 3419 341c 3420 3424 3426 3427 342c
1 3430 3434 3438 343b 343f 3443 3447
344b 344e 3452 3456 3459 345c 3461 3464
3467 346a 346b 3470 3471 1 3473 3478
347c 3480 3483 3488 348d 3490 3494 3495
349a 349d 34a2 34a3 34a8 34ab 34b0 34b1
34b6 34b9 34bd 34be 34c3 34c6 34cb 34cc
34d1 34d4 34d8 34dc 34df 34e2 34e3 34e5
34e6 34eb 34ec 34f1 34f3 34f7 34fa 34fc
3500 3502 350e 3510 3512 3513 3518 351c
351e 352a 352c 3530 3534 3538 353c 3540
3544 3548 354c 354d 354f 3553 3557 355b
355e 355f 3561 3564 3567 3568 356d 3571
3572 3576 357a 357b 357f 3583 3584 3588
358c 358d 3591 3595 3596 359a 359e 35a2
35a7 35ab 35ac 35b0 35b4 35b8 35bd 35c2
35c6 35ca 35ce 35d3 35d7 35db 35de 35e1
35e5 35e7 35eb 35ef 35f2 35f5 35f9 35fb
35ff 3603 3606 360a 360e 3613 3615 3619
361d 3620 3624 3628 362a 362e 3632 3636
3639 363d 3641 3643 3644 3649 1 364d
3651 3655 3658 365c 3660 3664 3668 366b
366f 3673 3676 3679 367e 3681 3684 3687
3688 368d 368e 1 3690 3695 3699 369d
36a0 36a5 36aa 36ad 36b1 36b2 36b7 36ba
36bf 36c0 36c5 36c8 36cd 36ce 36d3 36d6
36da 36db 36e0 36e3 36e8 36e9 36ee 36f1
36f5 36f9 36fc 36ff 3700 3702 3703 3708
3709 370e 3710 3714 3717 3719 371d 371f
372b 372d 372f 3730 3735 3739 373b 3747
3749 374d 3751 3755 3759 375d 3769 376d
3771 3774 3778 377c 377e 3782 3786 378a
378d 3791 3795 3797 3798 379d 1 37a1
37a5 37a9 37ac 37b0 37b4 37b8 37bc 37bf
37c3 37c7 37ca 37cd 37d2 37d5 37d8 37db
37dc 37e1 37e2 1 37e4 37e9 37ed 37f1
37f4 37f9 37fe 3801 3805 3806 380b 380e
3813 3814 3819 381c 3821 3822 3827 382a
382e 382f 3834 3837 383c 383d 3842 3845
3849 384d 3850 3853 3854 3856 3857 385c
385d 3862 3864 3868 386b 386d 3871 3873
387f 3881 3883 3884 3889 388d 388f 389b
389d 38a1 38a6 38aa 38ae 38b3 38b7 38bb
38bf 38c3 38c6 38ca 38cb 38d0 38d3 38d6
38d7 38d9 38dd 38e1 38e5 38e9 38ec 38f1
38f2 38f7 38fa 38fd 38fe 3900 3904 3908
390c 3910 3913 3917 3918 391d 3920 3923
3924 3926 392a 392e 3932 3936 3939 393e
393f 3944 3947 394a 394b 394d 3951 3955
3959 395d 3961 3965 3969 396d 3971 3975
3979 397d 3981 3985 3989 398d 3991 3995
3996 3998 399c 39a0 39a4 39a7 39ab 39af
39b2 39b5 39ba 39bd 39c0 39c3 39c4 39c9
39ca 1 39cc 39d1 39d5 39d9 39dc 39e1
39e6 39e9 39ed 39ee 39f3 39f6 39fb 39fc
3a01 3a04 3a09 3a0a 3a0f 3a12 3a16 3a1a
3a1d 3a1e 3a20 3a25 3a26 3a28 3a29 3a2e
3a31 3a36 3a37 3a3c 3a3f 3a44 3a45 3a4a
3a4d 3a51 3a52 3a57 3a5a 3a5f 3a60 3a65
3a66 3a6b 3a6d 3a71 3a74 3a78 3a7c 3a7f
3a83 3a87 3a8a 3a8d 3a92 3a95 3a98 3a9b
3a9c 3aa1 3aa2 1 3aa4 3aa9 3aad 3ab1
3ab4 3ab9 3abe 3ac1 3ac5 3ac6 3acb 3acc
3ad1 3ad3 3ad7 3ada 3ade 3ae2 3ae5 3ae8
3aec 3af0 3af1 3af6 3af8 3afc 3aff 3b01
3b05 3b08 3b0a 3b0e 3b11 3b15 3b19 3b1d
3b20 3b21 3b23 3b26 3b29 3b2a 3b2f 3b33
3b37 3b3b 3b3e 3b42 3b46 3b4a 3b4e 3b52
3b56 3b5a 3b5e 3b62 3b66 3b6a 3b6e 3b72
3b76 3b7a 3b7e 3b82 3b86 3b87 3b89 3b8d
3b91 3b95 3b98 3b9b 3b9e 3b9f 3ba4 3ba7
3bab 3baf 3bb2 3bb3 3bb5 3bb8 3bbb 3bbc
3bc1 1 3bc4 3bc9 3bcd 3bd1 3bd4 3bd5
3bd7 3bda 3bdd 3bde 3be3 1 3be6 3beb
3bef 3bf3 3bf7 3bfb 3bff 3c03 3c07 3c0b
3c0f 3c13 3c17 3c23 3c27 3c2c 3c30 3c33
3c34 3c39 3c3d 3c41 3c44 3c47 3c4b 3c4d
3c51 3c55 3c58 3c5b 3c5f 3c61 3c65 3c69
3c6c 3c6e 3c72 3c76 3c7a 3c7d 3c81 3c85
3c87 3c88 3c8d 1 3c91 3c95 3c99 3c9c
3ca0 3ca4 3ca8 3cac 3caf 3cb3 3cb7 3cba
3cbd 3cc2 3cc5 3cc8 3ccb 3ccc 3cd1 3cd2
1 3cd4 3cd9 3cdd 3ce1 3ce4 3ce9 3cee
3cf1 3cf5 3cf6 3cfb 3cfe 3d03 3d04 3d09
3d0c 3d11 3d12 3d17 3d1a 3d1e 3d1f 3d24
3d27 3d2c 3d2d 3d32 3d35 3d39 3d3d 3d40
3d43 3d44 3d46 3d47 3d4c 3d4d 3d52 3d54
3d58 3d5b 3d5d 3d61 3d63 3d6f 3d71 3d73
3d74 3d79 3d7d 3d7f 3d8b 3d8d 3d8f 3d93
3d96 3d98 3d9c 3da0 3da3 3da5 3da9 3dad
3db0 3db4 3db8 3dbb 3dbe 3dc1 3dc2 3dc7
3dcb 3dcf 3dd2 3dd6 3dda 3ddd 3de0 3de5
3de8 3deb 3dee 3def 3df4 3df5 1 3df7
3dfc 3e00 3e04 3e07 3e0c 3e11 3e14 3e18
3e19 3e1e 3e21 3e26 3e27 3e2c 3e2f 3e34
3e35 3e3a 3e3d 3e41 3e45 3e49 3e4d 3e50
3e51 3e53 3e58 3e59 3e5b 3e5c 3e61 3e64
3e69 3e6a 3e6f 3e72 3e77 3e78 3e7d 3e80
3e84 3e85 3e8a 3e8d 3e92 3e93 3e98 3e99
3e9e 3ea0 3ea4 3ea7 3eab 3eaf 3eb2 3eb6
3eba 3ebd 3ec0 3ec5 3ec8 3ecb 3ece 3ecf
3ed4 3ed5 1 3ed7 3edc 3ee0 3ee4 3ee7
3eec 3ef1 3ef4 3ef8 3ef9 3efe 3eff 3f04
3f06 3f0a 3f0d 3f11 3f15 3f18 3f1c 3f20
3f23 3f27 3f2b 3f2c 3f31 3f33 3f37 3f3a
3f3e 3f42 3f46 3f4a 3f4e 3f51 3f52 3f54
3f57 3f5a 3f5b 3f60 3f63 3f67 3f6b 3f6e
3f6f 3f71 3f74 3f77 3f78 3f7d 1 3f80
3f85 3f89 3f8c 3f90 3f92 3f96 3f99 3f9d
3fa1 3fa4 3fa5 3fa7 3faa 3fad 3fae 3fb3
3fb7 3fbb 3fbf 3fc2 3fc3 3fc5 3fc8 3fc9
3fcb 3fce 3fd1 3fd4 3fd5 3fda 3fde 3fe1
3fe2 3fe7 3fea 3fee 3ff1 3ff2 3ff7 3ffa
3ffe 4002 4006 400a 400e 4012 4016 401a
401e 4022 4026 402a 402e 4032 4036 403a
403e 4042 4046 404a 404e 405a 405e 4063
4067 406a 406b 4070 4074 4078 407b 407e
4082 4084 4088 408c 408f 4092 4096 4098
409c 40a0 40a3 40a5 40a9 40ad 40b1 40b4
40b8 40bc 40be 40bf 40c4 1 40c8 40cc
40d0 40d3 40d7 40db 40df 40e3 40e6 40ea
40ee 40f1 40f4 40f9 40fc 40ff 4102 4103
4108 4109 1 410b 4110 4114 4118 411b
4120 4125 4128 412c 412d 4132 4135 413a
413b 4140 4143 4148 4149 414e 4151 4155
4156 415b 415e 4163 4164 4169 416c 4170
4174 4177 417a 417b 417d 417e 4183 4184
4189 418b 418f 4192 4194 4198 419a 41a6
41a8 41aa 41ab 41b0 41b4 41b6 41c2 41c4
41c6 41ca 41ce 41d2 41d6 41da 41de 41e2
41e6 41ea 41f6 41fa 41ff 4203 4206 4207
420c 4210 4214 4217 421a 421e 4220 4224
4228 422b 422e 4232 4234 4238 423c 423f
4241 4245 4249 424d 4250 4254 4258 425a
425b 4260 1 4264 4268 426c 426f 4273
4277 427b 427f 4282 4286 428a 428d 4290
4295 4298 429b 429e 429f 42a4 42a5 1
42a7 42ac 42b0 42b4 42b7 42bc 42c1 42c4
42c8 42c9 42ce 42d1 42d6 42d7 42dc 42df
42e4 42e5 42ea 42ed 42f1 42f2 42f7 42fa
42ff 4300 4305 4308 430c 4310 4313 4316
4317 4319 431a 431f 4320 4325 4327 432b
432e 4330 4334 4336 4342 4344 4346 4347
434c 4350 4352 435e 4360 4362 4366 436a
436d 436f 4373 4376 4377 437c 437f 4383
4387 438b 438f 4393 4397 439b 439f 43a3
43a7 43ab 43af 43b3 43b7 43bb 43bf 43c3
43c7 43cb 43cf 43d3 43d7 43db 43df 43e3
43e7 43eb 43ef 43f3 43f7 43fb 43ff 4403
4407 440b 440f 4413 4417 441b 441f 4423
4427 442b 442f 4433 4437 443b 443f 4443
4447 444b 444f 4453 4457 445b 445f 4463
4467 446b 446f 4473 4477 447b 447f 448b
448f 4494 4498 449b 449c 44a1 44a5 44a9
44ac 44af 44b3 44b5 44b9 44bd 44c0 44c3
44c7 44c9 44cd 44d1 44d4 44d6 44da 44de
44e2 44e5 44e9 44ed 44ef 44f0 44f5 1
44f9 44fd 4501 4504 4508 450c 4510 4514
4517 451b 451f 4522 4525 452a 452d 4530
4533 4534 4539 453a 1 453c 4541 4545
4549 454c 4551 4556 4559 455d 455e 4563
4566 456b 456c 4571 4574 4579 457a 457f
4582 4586 4587 458c 458f 4594 4595 459a
459d 45a1 45a5 45a8 45ab 45ac 45ae 45af
45b4 45b5 45ba 45bc 45c0 45c3 45c5 45c9
45cb 45d7 45d9 45db 45dc 45e1 45e5 45e7
45f3 45f5 45f7 45fb 45ff 4603 4607 460b
460f 4613 4617 461b 461f 4623 4627 462b
462f 4633 4637 463b 463f 4643 4647 464b
464f 4653 4657 465b 465f 4663 4667 466b
466f 4673 4677 467b 467f 4683 4687 468b
468f 4693 4697 469b 469f 46a3 46a7 46ab
46af 46b3 46b7 46bb 46bf 46c3 46c7 46d3
46d7 46dc 46e0 46e3 46e4 46e9 46ed 46f1
46f4 46f7 46fb 46fd 4701 4705 4708 470b
470f 4711 4715 4719 471c 471e 4722 4726
472a 472d 4731 4735 4737 4738 473d 1
4741 4745 4749 474c 4750 4754 4758 475c
475f 4763 4767 476a 476d 4772 4775 4778
477b 477c 4781 4782 1 4784 4789 478d
4791 4794 4799 479e 47a1 47a5 47a6 47ab
47ae 47b3 47b4 47b9 47bc 47c1 47c2 47c7
47ca 47ce 47cf 47d4 47d7 47dc 47dd 47e2
47e5 47e9 47ed 47f0 47f3 47f4 47f6 47f7
47fc 47fd 4802 4804 4808 480b 480d 4811
4813 481f 4821 4823 4824 4829 482d 482f
483b 483d 483f 4843 4847 484a 484c 4850
4854 4857 485b 485d 4861 4865 4868 4869
486b 486e 4871 4872 4877 487b 487f 4883
4887 488b 488f 4893 4897 489b 48a7 48ab
48b0 48b4 48b7 48b8 48bd 48c1 48c5 48c8
48cb 48cf 48d1 48d5 48d9 48dc 48df 48e3
48e5 48e9 48ed 48f0 48f2 48f6 48fa 48fe
4901 4905 4909 490b 490c 4911 1 4915
4919 491d 4920 4924 4928 492c 4930 4933
4937 493b 493e 4941 4946 4949 494c 494f
4950 4955 4956 1 4958 495d 4961 4965
4968 496d 4972 4975 4979 497a 497f 4982
4987 4988 498d 4990 4995 4996 499b 499e
49a2 49a3 49a8 49ab 49b0 49b1 49b6 49b9
49bd 49c1 49c4 49c7 49c8 49ca 49cb 49d0
49d1 49d6 49d8 49dc 49df 49e1 49e5 49e7
49f3 49f5 49f7 49f8 49fd 4a01 4a03 4a0f
4a11 4a13 4a17 4a1b 4a1e 4a20 4a24 4a28
4a2c 4a2f 4a30 4a32 4a35 4a36 4a38 4a3b
4a3e 4a41 4a42 4a47 4a4b 4a4e 4a4f 4a54
4a57 4a5b 4a5e 4a5f 4a64 4a67 4a6b 4a6f
4a73 4a77 4a7b 4a7f 4a83 4a87 4a8b 4a8f
4a93 4a97 4a9b 4a9f 4aa3 4aa7 4aab 4aaf
4ab3 4ab7 4abb 4ac7 4acb 4ad0 4ad4 4ad7
4ad8 4add 4ae1 4ae5 4ae8 4aeb 4aef 4af1
4af5 4af9 4afc 4aff 4b03 4b05 4b09 4b0d
4b10 4b12 4b16 4b1a 4b1e 4b21 4b25 4b29
4b2b 4b2c 4b31 1 4b35 4b39 4b3d 4b40
4b44 4b48 4b4c 4b50 4b53 4b57 4b5b 4b5e
4b61 4b66 4b69 4b6c 4b6f 4b70 4b75 4b76
1 4b78 4b7d 4b81 4b85 4b88 4b8d 4b92
4b95 4b99 4b9a 4b9f 4ba2 4ba7 4ba8 4bad
4bb0 4bb5 4bb6 4bbb 4bbe 4bc2 4bc3 4bc8
4bcb 4bd0 4bd1 4bd6 4bd9 4bdd 4be1 4be4
4be7 4be8 4bea 4beb 4bf0 4bf1 4bf6 4bf8
4bfc 4bff 4c01 4c05 4c07 4c13 4c15 4c17
4c18 4c1d 4c21 4c23 4c2f 4c31 4c33 4c37
4c3b 4c3f 4c43 4c47 4c4b 4c4f 4c53 4c57
4c5b 4c5f 4c6b 4c6f 4c74 4c78 4c7b 4c7c
4c81 4c85 4c89 4c8c 4c8f 4c93 4c95 4c99
4c9d 4ca0 4ca3 4ca7 4ca9 4cad 4cb1 4cb4
4cb6 4cba 4cbe 4cc2 4cc5 4cc9 4ccd 4ccf
4cd0 4cd5 1 4cd9 4cdd 4ce1 4ce4 4ce8
4cec 4cf0 4cf4 4cf7 4cfb 4cff 4d02 4d05
4d0a 4d0d 4d10 4d13 4d14 4d19 4d1a 1
4d1c 4d21 4d25 4d29 4d2c 4d31 4d36 4d39
4d3d 4d3e 4d43 4d46 4d4b 4d4c 4d51 4d54
4d59 4d5a 4d5f 4d62 4d66 4d67 4d6c 4d6f
4d74 4d75 4d7a 4d7d 4d81 4d85 4d88 4d8b
4d8c 4d8e 4d8f 4d94 4d95 4d9a 4d9c 4da0
4da3 4da5 4da9 4dab 4db7 4db9 4dbb 4dbc
4dc1 4dc5 4dc7 4dd3 4dd5 4dd7 4ddb 4ddf
4de2 4de4 4de8 4deb 4dec 4df1 4df4 4df8
4dfc 4e00 4e04 4e08 4e0c 4e10 4e14 4e18
4e1c 4e20 4e24 4e28 4e2c 4e30 4e34 4e38
4e3c 4e40 4e44 4e48 4e4c 4e50 4e54 4e58
4e5c 4e60 4e64 4e68 4e6c 4e70 4e74 4e78
4e7c 4e80 4e84 4e88 4e8c 4e90 4e94 4e98
4e9c 4ea0 4ea4 4ea8 4eac 4eb0 4eb4 4eb8
4ebc 4ec0 4ec4 4ec8 4ecc 4ed0 4ed4 4ed8
4edc 4ee0 4ee4 4ee8 4eec 4ef0 4ef4 4f00
4f04 4f09 4f0d 4f10 4f11 4f16 4f1a 4f1e
4f21 4f24 4f28 4f2a 4f2e 4f32 4f35 4f38
4f3c 4f3e 4f42 4f46 4f49 4f4b 4f4f 4f53
4f57 4f5a 4f5e 4f62 4f64 4f65 4f6a 1
4f6e 4f72 4f76 4f79 4f7d 4f81 4f85 4f89
4f8c 4f90 4f94 4f97 4f9a 4f9f 4fa2 4fa5
4fa8 4fa9 4fae 4faf 1 4fb1 4fb6 4fba
4fbe 4fc1 4fc6 4fcb 4fce 4fd2 4fd3 4fd8
4fdb 4fe0 4fe1 4fe6 4fe9 4fee 4fef 4ff4
4ff7 4ffb 4ffc 5001 5004 5009 500a 500f
5012 5016 501a 501d 5020 5021 5023 5024
5029 502a 502f 5031 5035 5038 503a 503e
5040 504c 504e 5050 5051 5056 505a 505c
5068 506a 506c 5070 5074 5078 507c 5080
5084 5088 508c 5090 5094 5098 509c 50a0
50a4 50a8 50ac 50b0 50b4 50b8 50bc 50c0
50c4 50c8 50cc 50d0 50d4 50d8 50dc 50e0
50e4 50e8 50ec 50f0 50f4 50f8 50fc 5100
5104 5108 510c 5110 5114 5118 511c 5120
5124 5128 512c 5130 5134 5138 513c 5140
5144 5150 5154 5159 515d 5160 5161 5166
516a 516e 5171 5174 5178 517a 517e 5182
5185 5188 518c 518e 5192 5196 5199 519b
519f 51a3 51a7 51aa 51ae 51b2 51b4 51b5
51ba 1 51be 51c2 51c6 51c9 51cd 51d1
51d5 51d9 51dc 51e0 51e4 51e7 51ea 51ef
51f2 51f5 51f8 51f9 51fe 51ff 1 5201
5206 520a 520e 5211 5216 521b 521e 5222
5223 5228 522b 5230 5231 5236 5239 523e
523f 5244 5247 524b 524c 5251 5254 5259
525a 525f 5262 5266 526a 526d 5270 5271
5273 5274 5279 527a 527f 5281 5285 5288
528a 528e 5290 529c 529e 52a0 52a1 52a6
52aa 52ac 52b8 52ba 52bc 52c0 52c4 52c7
52c9 52cd 52d1 52d4 52d8 52da 52de 52e2
52e5 52e6 52e8 52eb 52ee 52ef 52f4 52f8
52fb 52fc 5301 5304 5308 530c 530f 5310
5312 5315 5318 5319 531e 5322 5326 532a
532e 5332 5336 533a 533e 5342 5346 534a
534e 5352 5356 5362 5366 536b 536f 5372
5373 5378 537c 5380 5383 5386 538a 538c
5390 5394 5397 539a 539e 53a0 53a4 53a8
53ab 53ad 53b1 53b5 53b9 53bc 53c0 53c4
53c6 53c7 53cc 1 53d0 53d4 53d8 53db
53df 53e3 53e7 53eb 53ee 53f2 53f6 53f9
53fc 5401 5404 5407 540a 540b 5410 5411
1 5413 5418 541c 5420 5423 5428 542d
5430 5434 5435 543a 543d 5442 5443 5448
544b 5450 5451 5456 5459 545d 545e 5463
5466 546b 546c 5471 5474 5478 547c 547f
5482 5483 5485 5486 548b 548c 5491 5493
5497 549a 549c 54a0 54a2 54ae 54b0 54b2
54b3 54b8 54bc 54be 54ca 54cc 54ce 54d2
54d6 54da 54de 54e2 54e6 54ea 54ee 54f2
54f6 54fa 5506 550a 550f 5513 5516 5517
551c 5520 5524 5527 552a 552e 5530 5534
5538 553b 553e 5542 5544 5548 554c 554f
5551 5555 5559 555d 5560 5564 5568 556a
556b 5570 1 5574 5578 557c 557f 5583
5587 558b 558f 5592 5596 559a 559d 55a0
55a5 55a8 55ab 55ae 55af 55b4 55b5 1
55b7 55bc 55c0 55c4 55c7 55cc 55d1 55d4
55d8 55d9 55de 55e1 55e6 55e7 55ec 55ef
55f4 55f5 55fa 55fd 5601 5602 5607 560a
560f 5610 5615 5618 561c 5620 5623 5626
5627 5629 562a 562f 5630 5635 5637 563b
563e 5640 5644 5646 5652 5654 5656 5657
565c 5660 5662 566e 5670 5672 5676 567a
567d 567f 5683 5687 568b 568f 5693 5697
569b 569f 56a3 56a7 56ab 56b7 56bb 56c0
56c4 56c7 56c8 56cd 56d1 56d5 56d8 56db
56df 56e1 56e5 56e9 56ec 56ef 56f3 56f5
56f9 56fd 5700 5702 5706 570a 570e 5711
5715 5719 571b 571c 5721 1 5725 5729
572d 5730 5734 5738 573c 5740 5743 5747
574b 574e 5751 5756 5759 575c 575f 5760
5765 5766 1 5768 576d 5771 5775 5778
577d 5782 5785 5789 578a 578f 5792 5797
5798 579d 57a0 57a5 57a6 57ab 57ae 57b2
57b3 57b8 57bb 57c0 57c1 57c6 57c9 57cd
57d1 57d4 57d7 57d8 57da 57db 57e0 57e1
57e6 57e8 57ec 57ef 57f1 57f5 57f7 5803
5805 5807 5808 580d 5811 5813 581f 5821
5823 5827 582b 582e 5830 5834 5838 583b
583d 5841 5845 5848 584c 584f 5850 5855
5858 585c 5860 5863 5864 5866 5869 586c
586d 5872 1 5875 587a 587d 5881 5885
5888 5889 588b 588e 5891 5892 5897 1
589a 589f 58a3 58a8 58ac 58b0 58b1 58b5
58b9 58bc 58c0 58c4 58c7 58cb 58cf 58d3
58d6 58d7 58d9 58dc 58df 58e0 58e5 58e9
58ed 58f1 58f5 58f9 58fd 5901 5905 5909
590d 5911 5915 5919 591d 5921 5925 5929
592d 5931 5935 5939 593d 5941 5945 5949
5955 5959 595d 5960 5964 5968 596a 596e
5972 5976 5979 597d 5981 5983 5984 5989
1 598d 5991 5995 5998 599c 59a0 59a4
59a8 59ab 59af 59b3 59b6 59b9 59be 59c1
59c4 59c7 59c8 59cd 59ce 1 59d0 59d5
59d9 59dd 59e0 59e5 59ea 59ed 59f1 59f2
59f7 59fa 59ff 5a00 5a05 5a08 5a0d 5a0e
5a13 5a16 5a1a 5a1b 5a20 5a23 5a28 5a29
5a2e 5a31 5a35 5a39 5a3c 5a3f 5a40 5a42
5a43 5a48 5a49 5a4e 5a50 5a54 5a57 5a59
5a5d 5a5f 5a6b 5a6d 5a6f 5a70 5a75 5a79
5a7b 5a87 5a89 5a8b 5a8f 5a93 5a97 5a9b
5a9f 5aa3 5aa7 5aab 5aaf 5ab3 5ab7 5abb
5abf 5ac3 5ac7 5acb 5acf 5ad3 5ad7 5adb
5adf 5ae3 5ae7 5aeb 5aef 5af3 5aff 5b03
5b07 5b0a 5b0e 5b12 5b14 5b18 5b1c 5b20
5b23 5b27 5b2b 5b2d 5b2e 5b33 1 5b37
5b3b 5b3f 5b42 5b46 5b4a 5b4e 5b52 5b55
5b59 5b5d 5b60 5b63 5b68 5b6b 5b6e 5b71
5b72 5b77 5b78 1 5b7a 5b7f 5b83 5b87
5b8a 5b8f 5b94 5b97 5b9b 5b9c 5ba1 5ba4
5ba9 5baa 5baf 5bb2 5bb7 5bb8 5bbd 5bc0
5bc4 5bc5 5bca 5bcd 5bd2 5bd3 5bd8 5bdb
5bdf 5be3 5be6 5be9 5bea 5bec 5bed 5bf2
5bf3 5bf8 5bfa 5bfe 5c01 5c03 5c07 5c09
5c15 5c17 5c19 5c1a 5c1f 5c23 5c25 5c31
5c33 5c35 5c39 5c3d 5c40 5c44 5c48 5c4b
5c4f 5c52 5c56 5c59 5c5a 5c5f 5c62 5c66
5c6a 5c6d 5c6e 5c70 5c74 5c77 5c7b 5c7e
5c7f 5c81 5c82 5c87 5c8a 5c8e 5c92 5c95
5c96 5c98 5c9b 5c9e 5c9f 5ca4 1 5ca7
5cac 5cb0 5cb4 5cb7 5cb8 5cba 5cbd 5cc0
5cc1 5cc6 1 5cc9 5cce 5cd2 5cd6 5cda
5cde 5ce2 5ce6 5cea 5cee 5cfa 5cfe 5d03
5d07 5d0a 5d0b 5d10 5d14 5d18 5d1b 5d1e
5d22 5d24 5d28 5d2c 5d2f 5d32 5d36 5d38
5d3c 5d40 5d43 5d45 5d49 5d4d 5d51 5d54
5d58 5d5c 5d5e 5d5f 5d64 1 5d68 5d6c
5d70 5d73 5d77 5d7b 5d7f 5d83 5d86 5d8a
5d8e 5d91 5d94 5d99 5d9c 5d9f 5da2 5da3
5da8 5da9 1 5dab 5db0 5db4 5db8 5dbb
5dc0 5dc5 5dc8 5dcc 5dcd 5dd2 5dd5 5dda
5ddb 5de0 5de3 5de8 5de9 5dee 5df1 5df5
5df6 5dfb 5dfe 5e03 5e04 5e09 5e0c 5e10
5e14 5e17 5e1a 5e1b 5e1d 5e1e 5e23 5e24
5e29 5e2b 5e2f 5e32 5e34 5e38 5e3a 5e46
5e48 5e4a 5e4b 5e50 5e54 5e56 5e62 5e64
5e68 5e6c 5e70 5e74 5e78 5e7c 5e80 5e84
5e88 5e8c 5e90 5e94 5e98 5ea4 5ea8 5ead
5eb1 5eb4 5eb5 5eba 5ebe 5ec2 5ec5 5ec8
5ecc 5ece 5ed2 5ed6 5ed9 5edc 5ee0 5ee2
5ee6 5eea 5eed 5eef 5ef3 5ef7 5efb 5efe
5f02 5f06 5f08 5f09 5f0e 1 5f12 5f16
5f1a 5f1d 5f21 5f25 5f29 5f2d 5f30 5f34
5f38 5f3b 5f3e 5f43 5f46 5f49 5f4c 5f4d
5f52 5f53 1 5f55 5f5a 5f5e 5f62 5f65
5f6a 5f6f 5f72 5f76 5f77 5f7c 5f7f 5f84
5f85 5f8a 5f8d 5f92 5f93 5f98 5f9b 5f9f
5fa0 5fa5 5fa8 5fad 5fae 5fb3 5fb6 5fba
5fbe 5fc1 5fc4 5fc5 5fc7 5fc8 5fcd 5fce
5fd3 5fd5 5fd9 5fdc 5fde 5fe2 5fe4 5ff0
5ff2 5ff4 5ff5 5ffa 5ffe 6000 600c 600e
6010 6014 6018 601d 6021 6022 6026 602a
602e 6032 6036 603b 6040 6044 6048 604c
6051 6055 6059 605c 605f 6063 6065 6069
606d 6070 6073 6077 6079 607d 6081 6084
6088 608c 608f 6092 6095 6096 609b 609f
60a5 60a7 60ab 60ae 60b2 60b6 60ba 60bd
60be 60c0 60c3 60c7 60cb 60ce 60cf 60d1
60d2 60d7 60db 60df 60e3 60e6 60e7 60e9
60ec 60ef 60f0 60f5 60f9 60fd 6100 6101
6103 6107 610a 610e 6111 6112 6114 6115
611a 611e 6122 6125 6126 6128 612c 612f
6133 6136 6137 6139 613a 613f 6143 6147
614b 614e 614f 6151 6155 6157 615b 615f
6163 6166 6167 6169 616c 6170 6174 6177
6178 617a 617b 6180 6183 6187 618b 618e
618f 6191 6192 6197 619b 619d 61a1 61a5
61a8 61aa 61ae 61b1 61b5 61b9 61bd 61c1
61c5 61d1 61d5 61da 61de 61e1 61e2 61e7
61eb 61ef 61f2 61f5 61f9 61fb 61ff 6203
6206 6209 620d 620f 6213 6217 621a 621c
6220 6224 6228 622b 622f 6233 6235 6236
623b 1 623f 6243 6247 624a 624e 6252
6256 625a 625d 6261 6265 6268 626b 6270
6273 6276 6279 627a 627f 6280 1 6282
6287 628b 628f 6292 6297 629c 629f 62a3
62a4 62a9 62ac 62b1 62b2 62b7 62ba 62bf
62c0 62c5 62c8 62cc 62cd 62d2 62d5 62da
62db 62e0 62e3 62e7 62eb 62ee 62f1 62f2
62f4 62f5 62fa 62fb 6300 6302 6306 6309
630b 630f 6311 631d 631f 6321 6322 6327
632b 632d 6339 633b 633f 6343 6347 6349
634d 6350 6354 6358 635b 635c 635e 6362
6365 6369 636c 636d 636f 6370 6375 6379
637f 6381 6385 6388 638a 638e 6395 6399
639d 63a2 63a4 63a8 63ac 63af 63b3 63b7
63b9 63bd 63c1 63c5 63c8 63cc 63d0 63d2
63d3 63d8 1 63dc 63e0 63e4 63e7 63eb
63ef 63f3 63f7 63fa 63fe 6402 6405 6408
640d 6410 6413 6416 6417 641c 641d 1
641f 6424 6428 642c 642f 6434 6439 643c
6440 6441 6446 6449 644e 644f 6454 6457
645c 645d 6462 6465 6469 646a 646f 6472
6477 6478 647d 6480 6484 6488 648b 648e
648f 6491 6492 6497 6498 649d 649f 64a3
64a6 64a8 64ac 64ae 64ba 64bc 64be 64bf
64c4 64c8 64ca 64d6 64d8 64dc 64e0 64e3
64e4 64e6 64e9 64ec 64ed 64f2 64f5 64f9
64fc 64fd 6502 6505 1 6508 650d 6511
6515 6519 651d 6521 652d 6531 6536 653a
653d 653e 6543 6547 654b 654e 6551 6555
6557 655b 655f 6562 6565 6569 656b 656f
6573 6576 6578 657c 6580 6584 6587 658b
658f 6591 6592 6597 1 659b 659f 65a3
65a6 65aa 65ae 65b2 65b6 65b9 65bd 65c1
65c4 65c7 65cc 65cf 65d2 65d5 65d6 65db
65dc 1 65de 65e3 65e7 65eb 65ee 65f3
65f8 65fb 65ff 6600 6605 6608 660d 660e
6613 6616 661b 661c 6621 6624 6628 6629
662e 6631 6636 6637 663c 663f 6643 6647
664a 664d 664e 6650 6651 6656 6657 665c
665e 6662 6665 6667 666b 666d 6679 667b
667d 667e 6683 6687 6689 6695 6697 6699
669d 66a0 66a2 66a6 66aa 66ad 66b1 66b5
66b8 66b9 66bb 66be 66c1 66c2 66c7 66cb
66cf 66d3 66d6 66d7 66d9 66dc 66dd 66df
66e2 66e5 66e8 66e9 66ee 66f2 66f6 66fa
66fe 66ff 6701 6705 6707 670b 670f 6713
6717 6718 671a 671e 6720 6724 6728 672b
672d 6731 6734 6736 673a 673d 673f 6743
6746 6748 674c 674f 6753 6757 675a 675d
6760 6761 6766 676a 676e 6771 6774 6778
677a 677e 6781 6783 6787 678a 678e 6792
6795 6799 679d 67a0 67a3 67a8 67ab 67ae
67b1 67b2 67b7 67b8 1 67ba 67bf 67c3
67c7 67ca 67cf 67d4 67d7 67db 67dc 67e1
67e4 67e9 67ea 67ef 67f2 67f7 67f8 67fd
6800 6804 6808 680c 6810 6813 6814 6816
681b 681c 681e 681f 6824 6827 682c 682d
6832 6835 683a 683b 6840 6843 6847 6848
684d 6850 6855 6856 685b 685c 6861 6863
6867 686a 686e 6872 6875 6879 687d 6880
6884 6888 6889 688e 6890 6894 6898 689b
689f 68a3 68a6 68aa 68ae 68b1 68b4 68b9
68bc 68bf 68c2 68c3 68c8 68c9 1 68cb
68d0 68d4 68d8 68db 68e0 68e5 68e8 68ec
68ed 68f2 68f3 68f8 68fc 6900 6903 6908
690d 6910 6914 6918 691b 691c 6921 6924
6929 692a 692f 6932 6936 693a 693d 693e
6943 6944 6949 694b 694f 6952 6956 695a
695e 6962 6966 696a 696e 6972 6976 6982
6987 698b 698f 6993 6997 6999 699a 699f
1 69a3 69a7 69ab 69ae 69b2 69b6 69ba
69be 69c1 69c5 69c9 69cc 69cf 69d4 69d7
69da 69dd 69de 69e3 69e4 1 69e6 69eb
69ef 69f3 69f6 69fb 6a00 6a03 6a07 6a08
6a0d 6a0e 6a13 6a17 6a1b 6a1e 6a23 6a28
6a2b 6a2f 6a30 6a35 6a38 6a3d 6a3e 6a43
6a46 6a4a 6a4e 6a51 6a54 6a55 6a57 6a58
6a5d 6a5e 6a63 6a65 6a69 6a6c 6a70 6a74
6a78 6a7c 6a80 6a84 6a88 6a94 6a99 6a9d
6aa1 6aa5 6aa9 6aab 6aaf 6ab1 6abd 6abf
6ac1 6ac2 6ac7 6acb 6acd 6ad9 6add 6adf
6ae0 6ae9 
1e7a
2
0 1 a 6 9 :3 6 15 :3 6
11 :3 6 12 :3 6 13 :3 6 10 :3 6
17 :3 6 15 :3 6 1a :3 6 b :3 6
10 :3 6 c :3 6 16 :3 6 18 :3 6
19 :3 6 1b :3 6 17 :3 6 16 :3 6
17 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 13 1c 1b
:2 13 :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 e 17 16 :2 e
:2 4 f 18 17 :2 f :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 c 15 14 :2 c :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 :2 b 1a b :2 4 :2 a
19 a :2 4 :2 b 1a b :2 4 :2 e
1d e :2 4 :2 13 22 13 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 13
22 13 :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 12
21 12 :2 4 :3 10 :2 4 :3 f :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :3 11 :2 4
:3 f :2 4 :3 13 :2 4 :3 10 :2 4 :3 d :2 4
:3 e :2 4 14 1d 1c :2 14 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 a
19 a :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 14 23 14 4 7
e 0 :2 7 20 2d 33 3b 56
5c 64 f 10 1d 2e 3b 13
2d a :6 7 e 0 :2 7 11 1c
26 f 10 1d 2e 42 18 23
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 55 5b 5e :2 55
6c 83 8 :2 6c d 10 :2 6c 13
16 :2 6c b e :2 6c 13 16 1f
27 :2 1f 38 :2 16 :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 29 2c
:2 6c b e :2 6c 13 16 :2 6c 1b
1e :2 6c 2a 2d :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 2b 2e
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
38 :2 16 :2 6c b e :2 6c 13 16
1f 27 :2 1f 3d :2 16 :2 6c b e
:2 6c 13 16 1f 27 :2 1f 2e :2 16
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 1f 27 :2 1f 2f :2 16 :2 6c b
e :2 6c 13 16 1f 27 :2 1f 39
:2 16 :2 6c b e :2 6c 13 16 :2 6c
1b 1e :2 6c 30 33 :2 6c b e
:2 6c 13 16 :2 6c 1b 1e :2 6c 31
34 :2 6c b e :2 6c 13 16 1f
27 :2 1f 3e :2 16 :2 6c b e :2 6c
13 16 1f 27 :2 1f 3a :2 16 :2 6c
b e :2 6c 13 16 :2 6c 1b 1e
:2 6c 2e 31 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
3a :2 16 :2 6c b e :2 6c 13 16
:2 6c 1b 1e :2 6c 2a 2d :2 6c 32
35 :2 6c :2 7 4b :2 4 7 :2 11 23
:2 2d 39 3c 4d 50 51 :2 4d :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e :2 7
54 :2 4 :4 9 8 7 27 30 40
:2 27 43 45 :2 43 26 4c a 1a
:2 4c 1d 1f :2 1d 4b :2 26 25 :2 7
a :2 14 26 :2 30 3c 3f 50 53
54 :2 50 :2 26 :3 a :2 10 15 21 61
64 :2 21 71 74 :2 21 78 7b :2 21
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 23 :2 4
:4 9 8 7 :4 1b 1a 19 :2 7 :4 34
33 32 :2 7 a :2 14 26 :2 30 3c
3f 50 53 54 :2 50 :2 26 :3 a :2 10
15 21 61 64 :2 21 71 74 :2 21
78 7b :2 21 85 88 91 99 :2 a2
:2 91 b3 :2 88 :2 21 :2 a 57 :2 7 a
:2 14 26 :2 30 3c 3f 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 57 :3 7 :2 12 28 :2 31 41
:2 7 4a :3 4 16 :2 4 10 :2 4 17
:2 4 12 :2 4 13 :2 4 17 :2 4 12
:2 4 10 :2 4 13 :2 4 15 :2 4 f
:2 4 16 :2 4 15 :2 4 14 4 7
10 17 :2 10 29 :2 7 2e 2c :2 37
:2 2c b 14 23 :2 b 26 28 :2 26
a 2f 38 47 :2 2f 4a 4c :2 4a
2e :2 a :4 e d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 77 7a
:2 27 7e 81 :2 27 8b 8e 97 9f
:2 a8 :2 97 b9 :2 8e :2 27 :2 10 5d :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2e :2 37
47 :2 d 22 :3 a 1b :2 a 17 :2 a
18 a 14 20 2d 3b 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5a 5d 5e :2 5a :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
61 :2 10 :2 d :4 19 :2 d a :3 4f a
:3 15 :2 a 1a 23 2c 37 :2 23 :2 1a
:2 a 1d 2c 3a 45 50 5f 25
:2 1d a e 17 28 :2 e 2b 2d
:2 2b 32 3b 4c :2 32 4f 51 :2 4f
:2 e d 59 10 1f :2 59 22 24
:2 22 58 :2 d 2c 35 3f :2 2c 42
44 :2 42 2b :3 d 1b d 17 27
37 2e 16 23 34 41 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5d 60 61
:2 5d :2 32 :3 16 :2 1c 21 2d 6d 70
:2 2d 7d 80 :2 2d 84 87 :2 2d 93
96 :2 2d 9e a1 :2 2d ad b0 b7
c0 c3 :2 b0 :2 2d :2 16 64 :2 13 :2 10
:4 1c :2 10 d :3 47 10 19 25 :2 10
28 2b :2 28 10 21 :2 10 1c :2 10
23 10 :4 14 13 1d 2a 35 42
63 74 :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 66 67 :2 63 :2 38 :3 1c :2 22
27 33 73 76 :2 33 83 86 :2 33
8a 8d :2 33 99 9c :2 33 a4 a7
:2 33 b3 b6 bd c6 c9 :2 b6 :2 33
:2 1c 6a :2 19 :2 16 :4 22 :2 16 13 :4 2c
:2 10 2d :2 d 47 :2 a e 17 26
:2 e 29 2b :2 29 d 33 3e 47
52 :2 3e :2 33 32 57 5a :2 57 :3 d
1e d 5c :2 a 4f a 15 a
14 20 29 36 43 d 18 22
2d 3b 12 20 2b 3a 49 d
1e 26 31 41 12 29 3d :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5a 5d
5e :2 5a :2 2f :3 13 :2 19 1e 2a 6a
6d :2 2a 7a 7d :2 2a 81 84 :2 2a
90 93 :2 2a 9b 9e :2 2a aa ad
b4 bd c0 :2 ad :2 2a :2 13 61 :2 10
:2 d :4 19 :2 d a :3 7 e :2 17 22
20 :2 2b :2 20 d 40 49 59 :2 40
5f 5c 10 1f :2 5f :2 5c 3f :2 d
10 :2 1a 2c :2 36 42 46 57 5a
5b :2 57 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 97 a3 :2 8e :2 27
ab ae :2 27 b6 b9 :2 27 be c1
:2 27 c9 cc :2 27 :2 10 5e :2 d 10
:2 1a 2c :2 36 42 45 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 :2 10 5d :3 d :2 18 2c 2f 38
:2 d 23 :2 a :4 7 a 13 22 :2 a
25 28 :2 25 d :2 16 1f 22 :2 1f
10 :2 1a 2c :2 36 42 46 57 5a
5b :2 57 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b3 :2 8e
:2 27 bb be :2 27 c6 c9 :2 27 ce
d1 :2 27 d9 dc :2 27 :2 10 5e :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2c :2 35
3f 48 :2 d 24 :2 a :4 e d :4 26
25 :2 d :4 3f 3e :2 d :4 14 13 :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8b 8e 97 9f :2 a8 :2 97 b9 :2 8e
:2 27 :2 10 5d :2 d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 :2 10 5d
:3 d :2 18 2e :2 37 47 :2 d 2d :3 a
1c :2 25 a d 16 1f :2 d 22
24 :2 22 d 18 d 2e :2 a 14
1d 37 46 54 61 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5a 5d 5e :2 5a
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 61 :2 10 :2 d :4 19
:2 d a :3 2a d 16 1e :2 d 21
23 :2 21 d 1b 23 2c 36 :2 2c
3f :2 23 42 44 4d 57 :2 4d 63
:2 44 :2 23 22 67 69 :2 22 21 20
22 :2 21 :2 1b d 10 19 22 :2 10
28 25 31 3d :2 28 :2 25 10 1a
:2 10 1d 10 40 10 1b 10 :4 d
25 :3 a 18 a e 15 1e 29
:2 15 2d :2 e d 32 34 :2 32 10
19 28 :2 10 2b 2d :2 2b 13 1c
2c :2 13 2f 31 :2 2f 13 :2 1c 28
35 3e 4a 56 67 25 32 3c
44 4c 54 25 35 40 50 25
36 :2 28 13 16 :2 1f 28 2a :2 28
20 35 3b 19 2a 36 48 55
65 1f 2c 3d 47 55 63 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :4 2c
:2 13 33 13 :2 1c 28 35 3e 4a
56 67 25 32 3c 44 4c 54
25 35 40 50 25 36 :2 28 13
:4 10 2f 10 22 2b 3b :2 22 3e
40 :2 22 10 13 1c 2c :2 13 2f
31 :2 2f 13 :2 1c 28 35 3e 4a
56 67 25 32 3c 44 4c 54
25 35 40 50 25 36 :2 28 13
16 :2 1f 28 2a :2 28 20 35 3b
19 2a 36 48 55 65 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 66 69 6a :2 66 :2 3b :3 1f
:2 25 2a 36 76 79 :2 36 86 89
:2 36 8d 90 :2 36 9c 9f :2 36 a7
aa :2 36 b6 b9 c0 c9 cc :2 b9
:2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19 16
:4 2c :2 13 33 13 :2 1c 28 35 3e
4a 56 67 25 32 3c 44 4c
54 25 35 40 50 25 36 :2 28
13 :4 10 :4 d 11 :2 1a 23 25 :2 23
10 2e 35 3e 49 :2 35 4d :2 2e
2d 51 53 :2 51 2c :2 10 14 1d
2d :2 14 32 30 3b 46 :2 32 :2 30
13 4f 58 5e :2 4f 61 63 :2 61
4e :2 13 6b 2c 41 :2 6b 44 46
:2 44 6a :2 13 1d 32 46 16 22
2b 3a 16 27 33 45 52 62
16 25 31 41 16 24 16 :2 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :3 4d 1d 32 3f 4a 1c 29
3a 4e 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 66 67 :2 63
:2 38 :3 1c :2 22 27 33 73 76 :2 33
83 86 :2 33 8a 8d :2 33 99 9c
:2 33 a4 a7 :2 33 b3 b6 bd c6
c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22
:2 16 13 :3 4d 1d 32 43 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 63 66 67 :2 63 :2 38 :3 1c
:2 22 27 33 73 76 :2 33 83 86
:2 33 8a 8d :2 33 99 9c :2 33 a4
a7 :2 33 b3 b6 bd c6 c9 :2 b6
:2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16 13
:4 4d 1d 32 38 16 27 33 45
52 62 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 66
67 :2 63 :2 38 :3 1c :2 22 27 33 73
76 :2 33 83 86 :2 33 8a 8d :2 33
99 9c :2 33 a4 a7 :2 33 b3 b6
bd c6 c9 :2 b6 :2 33 :2 1c 6a :2 19
:2 16 :4 22 :2 16 13 :7 10 56 :2 d 37
d 1c 23 2c 39 :2 23 3d :2 46
:2 1c d 10 19 28 :2 10 2b 2d
:2 2b 10 :2 19 25 32 3b 47 53
64 25 32 3c 44 4c 54 25
35 40 50 25 36 :2 25 10 14
:2 1d 26 28 :2 26 13 30 39 44
:2 30 47 49 :2 47 2f :2 13 51 5a
63 :2 51 66 68 :2 66 50 :2 13 1d
32 38 16 27 33 45 52 62
1c 29 3a 44 52 60 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 99 9c :2 33 a4 a7 :2 33
b3 b6 bd c6 c9 :2 b6 :2 33 :2 1c
6a :2 19 :2 16 :4 22 :2 16 13 :4 6b :2 10
2f :4 14 :2 13 20 13 1d 24 3e
45 5f 66 80 87 9c ab :2 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 66
67 :2 63 :2 38 :3 1c :2 22 27 33 73
76 :2 33 83 86 :2 33 8a 8d :2 33
99 9c :2 33 a4 a7 :2 33 b3 b6
bd c6 c9 :2 b6 :2 33 :2 1c 6a :2 19
:2 16 :4 22 :2 16 13 :3 33 16 :2 21 29
34 3e :2 16 42 44 :2 42 16 23
:2 2c :2 16 26 16 20 30 1e 1f
:2 19 :2 22 2e 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
69 6a :2 66 :2 3b :3 1f :2 25 2a 36
76 79 :2 36 86 89 :2 36 8d 90
:2 36 9c 9f :2 36 a7 aa :2 36 b6
b9 c0 c9 cc :2 b9 :2 36 :2 1f 6d
:2 1c :2 19 :4 25 :2 19 16 :3 46 16 29
3b 49 54 62 6d 28 :2 29 16
19 22 33 :2 19 36 38 :2 36 19
26 :2 19 27 :2 19 2b :2 19 27 :2 19
28 :2 19 1e :3 19 1f 2c 3c :3 19
1c 24 :2 1c :2 25 31 1c 2a 1c
:2 25 31 1c :4 19 1c 22 :3 1c :2 25
31 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 69 6c 6d
:2 69 :2 3e :3 22 :2 28 2d 39 79 7c
:2 39 89 8c :2 39 90 93 :2 39 9f
a2 :2 39 aa ad :2 39 b9 bc c3
cc cf :2 bc :2 39 :2 22 70 :2 1f :2 1c
:4 28 :2 1c 19 :3 3a 23 32 43 22
30 :2 1c :2 25 31 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
69 6c 6d :2 69 :2 3e :3 22 :2 28 2d
39 79 7c :2 39 89 8c :2 39 90
93 :2 39 9f a2 :2 39 aa ad :2 39
b9 bc c3 cc cf :2 bc :2 39 :2 22
70 :2 1f :2 1c :4 28 :2 1c 19 :3 3a 19
26 :2 19 26 :2 19 26 2d 37 3a
:2 2d 47 4a :2 26 :2 19 26 2d 37
3a :2 2d 4b 4e :2 26 :2 19 26 2d
37 3a :2 2d 4a 4d :2 26 :2 19 26
2d 37 22 :2 2d 24 27 :2 26 :2 19
2c 3a 46 52 5a 62 6e 24
2f 3a 46 52 5e 24 2f 3b
:2 2c 19 1c :2 26 38 :2 42 4e 52
63 66 67 :2 63 :2 38 :3 1c :2 22 27
33 73 76 :2 33 83 86 :2 33 8a
8d :2 33 97 9a a3 ab :2 a3 af
:2 9a :2 33 b7 ba :2 33 c2 c5 :2 33
ca cd :2 33 d5 d8 :2 33 :2 1c 6a
:2 19 1c :2 26 38 :2 42 4e 51 62
65 66 :2 62 :2 38 :3 1c :2 22 27 33
73 76 :2 33 :2 1c 69 :3 19 :2 24 38
3b 44 :2 19 3a :2 16 46 :2 13 33
:3 10 22 2b 3b :2 22 3e 40 :2 22
:2 10 :2 19 25 32 3b 47 53 64
25 32 3c 44 4c 54 25 35
40 50 25 36 :2 25 10 14 :2 1d
26 28 :2 26 13 30 39 44 :2 30
47 49 :2 47 2f :2 13 51 5a 63
:2 51 66 68 :2 66 50 :2 13 1d 32
38 16 27 33 45 52 62 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :4 6b :2 10 :4 d :4 a d :2 16 1f
22 :2 1f 10 :2 1a 2c :2 36 42 46
57 5a 5b :2 57 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8b 8e 97 9f :2 a8 :2 97
b3 :2 8e :2 27 bb be :2 27 c6 c9
:2 27 ce d1 :2 27 d9 dc :2 27 :2 10
5e :2 d 10 :2 1a 2c :2 36 42 45
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 :2 10 5d :3 d :2 18
2c :2 35 3f 48 :2 d 24 :3 a 1c
a e 17 20 :2 e 23 26 :2 23
d 32 3b 4b :2 32 4e 50 :2 4e
31 :3 d 1f d 53 :2 a d 16
25 :2 d 28 2a :2 28 11 18 21
2c :2 18 30 :2 11 10 35 37 :2 35
:4 14 13 :4 17 16 20 35 49 19
25 2e 3d 19 2a 36 48 55
65 19 28 19 29 19 27 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 66 69 6a :2 66 :2 3b
:3 1f :2 25 2a 36 76 79 :2 36 86
89 :2 36 8d 90 :2 36 9c 9f :2 36
a7 aa :2 36 b6 b9 c0 c9 cc
:2 b9 :2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19
16 :4 33 20 35 49 19 25 19
28 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 2f :4 17 16 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
:2 19 2a 36 48 55 65 19 28
19 29 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 69 6a :2 66 :2 3b :3 1f :2 25 2a
36 76 79 :2 36 86 89 :2 36 8d
90 :2 36 9c 9f :2 36 a7 aa :2 36
b6 b9 c0 c9 cc :2 b9 :2 36 :2 1f
6d :2 1c :2 19 :4 25 :2 19 16 :4 33 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
19 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 :4 10 d 3a 13
1c 25 :2 13 28 2a :2 28 1a 2f
43 13 1f 13 22 19 2d 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 60 63 64 :2 60 :2 35 :3 19 :2 1f
24 30 70 73 :2 30 80 83 :2 30
87 8a :2 30 96 99 :2 30 a1 a4
:2 30 b0 b3 ba c3 c6 :2 b3 :2 30
:2 19 67 :2 16 :2 13 :4 1f :2 13 10 :4 2c
3a :2 d 2c 11 18 21 2c :2 18
30 :2 11 10 35 37 :2 35 :4 14 13
:4 17 16 20 35 49 19 25 2e
3d 19 2a 36 48 55 65 19
28 19 29 19 27 1f 33 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 69 6a :2 66 :2 3b :3 1f :2 25
2a 36 76 79 :2 36 86 89 :2 36
8d 90 :2 36 9c 9f :2 36 a7 aa
:2 36 b6 b9 c0 c9 cc :2 b9 :2 36
:2 1f 6d :2 1c :2 19 :4 25 :2 19 16 :4 33
20 35 49 19 25 2e 3d 19
27 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :7 13 2f :4 17 16 20
35 49 19 25 2e 3d 19 35
51 5e 76 19 36 52 5f 78
19 38 54 6e 19 34 50 66
19 2b 19 2c 19 2e 19 2a
19 2b 19 2c 19 2e 19 2a
19 2a 38 49 57 68 76 87
:2 19 2a 36 48 55 65 19 28
19 29 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 6a 6b :2 66 :2 3b :3 1f :2 25 2a
36 77 7a :2 36 87 8a :2 36 8e
91 :2 36 9d a0 :2 36 a8 ab :2 36
b7 ba c1 ca cd :2 ba :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :4 33 20
35 49 19 25 2e 3d 19 27
19 35 51 5e 76 19 36 52
5f 78 19 38 54 6e 19 34
50 66 19 2b 19 2c 19 2e
19 2a 19 2b 19 2c 19 2e
19 2a 19 2a 38 49 57 68
76 87 19 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
6a 6b :2 66 :2 3b :3 1f :2 25 2a 36
77 7a :2 36 87 8a :2 36 8e 91
:2 36 9d a0 :2 36 a8 ab :2 36 b7
ba c1 ca cd :2 ba :2 36 :2 1f 6e
:2 1c :2 19 :4 25 :2 19 16 :7 13 :4 10 d
3a 13 1c 25 :2 13 28 2a :2 28
:4 14 13 16 1f 25 :2 16 28 2a
:2 28 20 35 49 19 25 2e 3d
19 27 19 1f 2a 1f 33 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 66 6a 6b :2 66 :2 3b :3 1f :2 25
2a 36 77 7a :2 36 87 8a :2 36
8e 91 :2 36 9d a0 :2 36 a8 ab
:2 36 b7 ba c1 ca cd :2 ba :2 36
:2 1f 6e :2 1c :2 19 :4 25 :2 19 16 :4 2c
20 35 49 19 25 2e 3d 19
27 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 6a 6b
:2 66 :2 3b :3 1f :2 25 2a 36 77 7a
:2 36 87 8a :2 36 8e 91 :2 36 9d
a0 :2 36 a8 ab :2 36 b7 ba c1
ca cd :2 ba :2 36 :2 1f 6e :2 1c :2 19
:4 25 :2 19 16 :7 13 31 1d 32 46
16 22 2b 3a 16 24 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 63 67 68 :2 63 :2 38 :3 1c
:2 22 27 33 74 77 :2 33 84 87
:2 33 8b 8e :2 33 9a 9d :2 33 a5
a8 :2 33 b4 b7 be c7 ca :2 b7
:2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16 13
:7 10 2c 3a :2 d :4 a :4 f e 30
39 4b :2 30 4e 50 :2 4e 2f :2 e
d 58 10 20 :2 58 23 25 :2 23
57 :3 d 1b :2 d 1b :2 d 18 :2 d
18 d 10 19 28 :2 10 2b 2d
:2 2b 1a 2d 39 42 4a 51 67
6f 76 8d 97 a8 b6 18 2d
37 42 48 4e 5a 6d 79 18
19 2d :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 71 74 :2 30 81 84 :2 30
88 8b :2 30 97 9a :2 30 a2 a5
:2 30 b1 b4 bb c4 c7 :2 b4 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :4 2f
10 27 10 1a 26 2f 37 3e
54 5c 63 7a 84 95 a3 18
22 2d 33 39 45 58 64 18
19 2d :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 71 74 :2 30 81 84 :2 30
88 8b :2 30 97 9a :2 30 a2 a5
:2 30 b1 b4 bb c4 c7 :2 b4 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :7 d
11 :2 1a 25 23 :2 2e :2 23 10 14
1d 2d :2 14 32 30 3b 46 :2 32
:2 30 13 4f 58 5e :2 4f 61 63
:2 61 4e :2 13 6b 2c 41 :2 6b 44
46 :2 44 6a :2 13 1d 32 3f 4a
1c 29 3a 4e 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 67
68 :2 63 :2 38 :3 1c :2 22 27 33 74
77 :2 33 84 87 :2 33 8b 8e :2 33
9a 9d :2 33 a5 a8 :2 33 b4 b7
be c7 ca :2 b7 :2 33 :2 1c 6b :2 19
:2 16 :4 22 :2 16 13 :3 4d 1d 32 40
16 2f 33 42 1c 29 3a 4e
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 67 68 :2 63
:2 38 :3 1c :2 22 27 33 74 77 :2 33
84 87 :2 33 8b 8e :2 33 9a 9d
:2 33 a5 a8 :2 33 b4 b7 be c7
ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :4 4d 13 18 :4 13 1c 25
30 3d :3 16 19 1d :2 19 :2 22 2e
19 23 19 :2 22 2e 19 :4 16 19
:2 22 2b 2e :2 2b :2 19 30 :3 16 21
2a 33 :2 21 36 38 41 4c :2 38
:2 21 16 19 22 2b :2 19 2e 30
:2 2e 1c 25 2e :2 1c 33 31 3c
4b :2 33 :2 31 1f 28 33 :2 1f 39
36 42 51 :2 39 :2 36 1f 2c 35
44 :2 2c 1f 54 1f 2c 35 44
:2 2c 47 49 52 5b :2 49 :2 2c 5e
60 69 74 :2 60 :2 2c 1f :4 1c 4e
:2 19 23 38 45 50 71 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
69 6d 6e :2 69 :2 3e :3 22 :2 28 2d
39 7a 7d :2 39 8a 8d :2 39 91
94 :2 39 a0 a3 :2 39 ab ae :2 39
ba bd c4 cd d0 :2 bd :2 39 :2 22
71 :2 1f :2 1c :4 28 :2 1c 19 :3 32 19
27 19 32 :2 16 19 22 2b :2 19
31 2e 3a 49 :2 31 :2 2e :2 19 4c
:2 16 13 17 10 16 1c :3 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 63 67 68
:2 63 :2 38 :3 1c :2 22 27 33 74 77
:2 33 84 87 :2 33 8b 8e :2 33 9a
9d :2 33 a5 a8 :2 33 b4 b7 be
c7 ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16
:4 22 :2 16 13 :3 10 17 20 29 :2 17
2c 2e :2 2c 16 :4 37 36 35 :2 16
20 35 46 57 6b 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 66
6a 6b :2 66 :2 3b :3 1f :2 25 2a 36
77 7a :2 36 87 8a :2 36 8e 91
:2 36 9d a0 :2 36 a8 ab :2 36 b7
ba c1 ca cd :2 ba :2 36 :2 1f 6e
:2 1c :2 19 :4 25 :2 19 16 :4 50 :2 13 :4 10
13 1c 2b :2 13 2e 30 :2 2e 17
1e 27 32 :2 1e 36 :2 17 16 3b
3d :2 3b 16 29 3c 51 :2 29 16
40 16 29 3c 51 :2 29 16 :4 13
32 :2 10 3e :2 d 28 :2 a 2a :2 7
a :2 13 1c 1e :2 1c a :2 13 1f
a 22 :2 7 4f :2 4 7 :2 11 23
:2 2d 39 3c 4d 51 52 :2 4d :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 a0 :2 8f ab :2 86 :2 1e b3 b6
:2 1e be c1 :2 1e c6 c9 :2 1e cc
cf :2 1e :2 7 55 :3 4 :2 f 21 :2 2a
34 38 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 51 55 56
:2 51 :2 26 :3 a :2 10 15 21 62 65
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 59 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4e 52 53
:2 4e :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 56 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
1e7a
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 2
:4 18 :2 1 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:5 38 :5 39 :7 3a :7 3b
:7 3c :5 3d :5 3e :5 3f
:5 40 :5 41 :5 42 :7 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :5 4b
:5 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :2 54
0 :2 54 :7 55 56
:4 57 :2 58 55 :5 54
:2 5a 0 :2 5a :3 5b
5c :4 5d :2 5e 5b
:5 5a :7 60 :b 62 :11 63
64 :2 63 :2 64 :2 63
:2 64 :2 63 :2 65 :2 63
:9 65 :2 63 :2 66 :2 63
:2 66 :2 63 :2 66 :2 63
:2 66 :2 63 :2 67 :2 63
:2 67 :2 63 :2 67 :2 63
:2 67 :2 63 :2 68 :2 63
:2 68 :2 63 :2 68 :2 63
:2 68 :2 63 :2 69 :2 63
:9 69 :2 63 :2 6a :2 63
:2 6a :2 63 :2 6a :2 63
:2 6a :2 63 :2 6b :2 63
:9 6b :2 63 :2 6c :2 63
:9 6c :2 63 :2 6d :2 63
:9 6d :2 63 :2 6e :2 63
:9 6e :2 63 :2 6f :2 63
:9 6f :2 63 :2 70 :2 63
:9 70 :2 63 :2 71 :2 63
:2 71 :2 63 :2 71 :2 63
:2 71 :2 63 :2 72 :2 63
:2 72 :2 63 :2 72 :2 63
:2 72 :2 63 :2 73 :2 63
:9 73 :2 63 :2 74 :2 63
:9 74 :2 63 :2 75 :2 63
:2 75 :2 63 :2 75 :2 63
:2 75 :2 63 :2 76 :2 63
:2 76 :2 63 :2 76 :2 63
:2 76 :2 63 :2 77 :2 63
:9 77 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :4 63
:3 62 :11 7b :b 7c :3 7b
:11 7f :2 80 :2 7f :4 80
:6 7f :11 81 :20 82 :3 81
:11 84 :b 85 :3 84 :9 87
80 :2 7f :16 8a :11 8b
:20 8c :3 8b :11 8e :b 8f
:3 8e :9 91 :3 8a :3 96
:3 97 :3 98 :3 99 :3 9a
:3 9b :3 9c :3 9d :3 9e
:3 9f :3 a0 :3 a1 :3 a2
:3 a3 :e a7 :16 a8 :5 aa
:11 ab :20 ac :3 ab :11 ae
:b af :3 ae :9 b1 :3 aa
:3 b4 :3 b5 :3 b6 :4 b9
:3 ba b9 :5 bb b8
bd :5 be :3 bd :2 bf
:5 c1 :11 c2 :24 c3 :3 c2
:2 c0 :6 bf bc :3 a8
:5 c8 :a c9 :7 cb cc
:3 cb :16 cf :2 d0 :2 cf
:4 d0 :3 cf :a d0 :2 cf
:3 d1 :3 d3 d4 :4 d5
d3 :5 d6 d2 d8
:5 d9 :3 d8 :2 da :5 dc
:11 dd :24 de :3 dd :2 db
:6 da d7 :3 d0 :9 e3
:3 e4 :3 e5 :3 e6 :5 e8
:7 ea :5 eb e9 ed
:5 ee :3 ed :2 ef :5 f1
:11 f2 :24 f3 :3 f2 :2 f0
:6 ef ec :6 e8 :3 e3
d0 :2 cf :19 fc :3 fd
:3 fc a8 :3 100 :5 103
:5 104 :5 105 :5 106 :3 107
103 :5 108 102 10a
:5 10b :3 10a :2 10c :5 10e
:11 10f :24 110 :3 10f :2 10d
:6 10c 109 :3 ff :11 116
:2 117 :7 116 :11 11a :2e 11b
:3 11a :11 11d :b 11e :3 11d
:8 120 117 :2 116 ff
:3 a8 :9 125 :7 126 :11 127
:30 128 :3 127 :11 12a :b 12b
:3 12a :a 12d :3 126 :13 131
:5 132 :2 131 :11 133 :20 134
:3 133 :11 136 :b 137 :3 136
:9 139 132 :2 131 :5 13c
:9 13f :3 140 :3 13f :7 147
:5 148 146 14a :5 14b
:3 14a :2 14c :5 14e :11 14f
:24 150 :3 14f :2 14d :6 14c
149 :3 125 :9 155 :1b 157
:2 158 :5 157 :d 15a :3 15b
:3 15c 15a :3 15e 15d
:3 15a :3 155 :3 17b :e 17d
:9 17e :9 17f :9 180 :6 181
:4 182 :2 183 :3 180 :7 186
:3 188 :6 189 :6 18a 188
:6 18b :5 18c 18b :5 18e
18d :3 18b 187 191
:5 192 :3 191 :2 193 :5 195
:11 196 :24 197 :3 196 :2 194
:6 193 190 :6 186 17f
:9 19d :6 19e :4 19f :2 1a0
:3 19d 19c :3 17f 17e
:b 1a4 :9 1a5 :9 1a6 :6 1a7
:4 1a8 :2 1a9 :3 1a6 :7 1ac
:3 1ae :6 1af :2 1b0 1ae
:6 1b1 :5 1b2 1b1 :5 1b4
1b3 :3 1b1 1ad 1b7
:5 1b8 :3 1b7 :2 1b9 :5 1bb
:11 1bc :24 1bd :3 1bc :2 1ba
:6 1b9 1b6 :6 1ac 1a5
:9 1c3 :6 1c4 :4 1c5 :2 1c6
:3 1c3 1c2 :3 1a5 1a3
:3 17e :19 1cb :1b 1cc :2 1cd
:2 1cc :4 1cd :3 1cc :3 1cf
:4 1d0 :6 1d1 :4 1d2 :2 1d3
:2 1d4 :2 1d5 1cf :6 1d6
:5 1d7 1d6 :5 1d9 1d8
:3 1d6 1ce 1dc :5 1dd
:3 1dc :2 1de :5 1e0 :11 1e1
:24 1e2 :3 1e1 :2 1df :6 1de
1db :3 1cd :4 1e8 :4 1e9
1e8 :6 1ea :5 1eb 1ea
:5 1ed 1ec :3 1ea 1e7
1f0 :5 1f1 :3 1f0 :2 1f2
:5 1f4 :11 1f5 :24 1f6 :3 1f5
:2 1f3 :6 1f2 1ef :3 1cd
:3 1fc :2 1fd 1fc :6 1fe
:5 1ff 1fe :5 201 200
:3 1fe 1fb 204 :5 205
:3 204 :2 206 :5 208 :11 209
:24 20a :3 209 :2 207 :6 206
203 :4 1cd :3 210 :6 211
:2 212 210 :6 213 :5 214
213 :5 216 215 :3 213
20f 219 :5 21a :3 219
:2 21b :5 21d :11 21e :24 21f
:3 21e :2 21c :6 21b 218
:4 20e :3 1cc :3 1cb 17d
:d 226 :9 228 :9 229 :6 22a
:4 22b :2 22c :3 229 :20 22f
:3 231 :6 232 :6 233 231
:6 234 :5 235 234 :5 237
236 :3 234 230 23a
:5 23b :3 23a :2 23c :5 23e
:11 23f :24 240 :3 23f :2 23d
:6 23c 239 :6 22f 228
:5 246 :3 247 :b 24d :5 24e
24c 250 :5 251 :3 250
:2 252 :5 254 :11 255 :24 256
:3 255 :2 253 :6 252 24f
:3 246 :c 25b :5 25c :3 25d
:2 260 261 262 260
:5 263 25f 265 :5 266
:3 265 :2 267 :5 269 :11 26a
:24 26b :3 26a :2 268 :6 267
264 :3 25b :7 270 271
:3 270 :9 273 :3 274 :3 275
:3 276 :3 277 :3 278 :5 27a
:6 27c :3 27d :5 27e 27d
:5 280 27f :3 27d :4 284
:5 285 283 287 :5 288
:3 287 :2 289 :5 28b :11 28c
:24 28d :3 28c :2 28a :6 289
286 :3 273 :3 293 :2 294
293 :5 295 292 297
:5 298 :3 297 :2 299 :5 29b
:11 29c :24 29d :3 29c :2 29a
:6 299 296 :3 273 :3 2a3
:3 2a5 :c 2a6 :c 2a7 :c 2a8
:4 2a9 2aa :2 2a9 :2 2ab
:3 2a9 :8 2ad :6 2ae :3 2af
:3 2ad :11 2b1 :2e 2b2 :3 2b1
:11 2b4 :b 2b5 :3 2b4 :8 2b7
:3 273 :3 25b :3 246 :b 2bc
:9 2bd :6 2be :4 2bf :2 2c0
:3 2bd :20 2c4 :3 2c6 :6 2c7
:2 2c8 2c6 :6 2c9 :5 2ca
2c9 :5 2cc 2cb :3 2c9
2c5 2cf :5 2d0 :3 2cf
:2 2d1 :5 2d3 :11 2d4 :24 2d5
:3 2d4 :2 2d2 :6 2d1 2ce
:6 2c4 245 :3 228 225
:3 17d :7 2de :11 2df :30 2e0
:3 2df :11 2e2 :b 2e3 :3 2e2
:a 2e5 :3 2de :3 2e8 :16 2e9
:3 2ea :3 2e9 :9 2ed :e 2ee
:5 2ef :5 2f1 :3 2f3 :4 2f4
:6 2f5 :2 2f6 :2 2f7 :2 2f8
:2 2f9 2f3 :6 2fa :5 2fb
2fa :5 2fd 2fc :3 2fa
2f2 300 :5 301 :3 300
:2 302 :5 304 :11 305 :24 306
:3 305 :2 303 :6 302 2ff
:4 2f1 :3 30c :2 30d :2 30e
:2 30f 30c :6 310 :5 311
310 :5 313 312 :3 310
30b 316 :5 317 :3 316
:2 318 :5 31a :11 31b :24 31c
:3 31b :2 319 :6 318 315
:4 30a :3 2f1 2ef :5 323
:3 325 :4 326 :5 327 :5 328
:4 329 :4 32a :2 32c :2 32d
:2 32e :2 32f :2 331 :2 332
:2 333 :2 334 :8 335 337
:6 338 :2 339 :2 33a :2 33b
:2 33c 325 :6 33d :5 33e
33d :5 340 33f :3 33d
324 343 :5 344 :3 343
:2 345 :5 347 :11 348 :24 349
:3 348 :2 346 :6 345 342
:4 323 :3 350 :4 351 :5 352
:5 353 :4 354 :4 355 :2 357
:2 358 :2 359 :2 35a :2 35c
:2 35d :2 35e :2 35f :8 360
362 :2 363 350 :6 364
:5 365 364 :5 367 366
:3 364 34f 36a :5 36b
:3 36a :2 36c :5 36e :11 36f
:24 370 :3 36f :2 36d :6 36c
369 :4 34e :3 323 321
:3 2ef 376 2ee :9 376
:3 378 :2 379 :2 37a :2 37b
378 :6 37c :5 37d 37c
:5 37f 37e :3 37c 377
382 :5 383 :3 382 :2 384
:5 386 :11 387 :24 388 :3 387
:2 385 :6 384 381 :4 376
:3 2ee 2ed :e 38e :5 38f
:5 391 :3 393 :4 394 :6 395
:2 396 :2 397 :2 398 :2 399
393 :6 39a :5 39b 39a
:5 39d 39c :3 39a 392
3a0 :5 3a1 :3 3a0 :2 3a2
:5 3a4 :11 3a5 :24 3a6 :3 3a5
:2 3a3 :6 3a2 39f :4 391
:3 3ac :4 3ad :2 3ae :2 3af
3ac :6 3b0 :5 3b1 3b0
:5 3b3 3b2 :3 3b0 3ab
3b6 :5 3b7 :3 3b6 :2 3b8
:5 3ba :11 3bb :24 3bc :3 3bb
:2 3b9 :6 3b8 3b5 :4 3aa
:3 391 38f :5 3c3 :3 3c5
:4 3c6 :5 3c7 :5 3c8 :4 3c9
:4 3ca :2 3cc :2 3cd :2 3ce
:2 3cf :2 3d1 :2 3d2 :2 3d3
:2 3d4 :8 3d5 3d7 :6 3d8
:2 3d9 :2 3da :2 3db :2 3dc
3c5 :6 3dd :5 3de 3dd
:5 3e0 3df :3 3dd 3c4
3e3 :5 3e4 :3 3e3 :2 3e5
:5 3e7 :11 3e8 :24 3e9 :3 3e8
:2 3e6 :6 3e5 3e2 :4 3c3
:3 3ef :4 3f0 :2 3f1 :5 3f2
:5 3f3 :4 3f4 :4 3f5 :2 3f7
:2 3f8 :2 3f9 :2 3fa :2 3fc
:2 3fd :2 3fe :2 3ff :8 400
402 :2 403 3ef :6 404
:5 405 404 :5 407 406
:3 404 3ee 40a :5 40b
:3 40a :2 40c :5 40e :11 40f
:24 410 :3 40f :2 40d :6 40c
409 :4 3ed :3 3c3 3c1
:3 38f 416 38e :9 416
:5 417 :9 418 :3 41a :4 41b
:2 41c :3 41d :2 41e 41a
:6 41f :5 420 41f :5 422
421 :3 41f 419 425
:5 426 :3 425 :2 427 :5 429
:11 42a :24 42b :3 42a :2 428
:6 427 424 :4 418 :3 431
:4 432 :2 433 :2 434 431
:6 435 :5 436 435 :5 438
437 :3 435 430 43b
:5 43c :3 43b :2 43d :5 43f
:11 440 :24 441 :3 440 :2 43e
:6 43d 43a :4 42f :3 418
417 :3 448 :4 449 :2 44a
:2 44b 448 :6 44c :5 44d
44c :5 44f 44e :3 44c
447 452 :5 453 :3 452
:2 454 :5 456 :11 457 :24 458
:3 457 :2 455 :6 454 451
:4 446 :3 417 416 :3 38e
38d :3 2ed :13 462 :2 463
:2 462 :4 463 :3 462 :3 464
:3 465 :3 466 :3 467 :9 469
:d 46b :9 46c 46d :2 46e
46b :5 46f 46a 471
:5 472 :3 471 :2 473 :5 475
:11 476 :24 477 :3 476 :2 474
:6 473 470 :4 469 :3 47c
:c 47e :8 47f 480 :2 481
47e :5 482 47d 484
:5 485 :3 484 :2 486 :5 488
:11 489 :24 48a :3 489 :2 487
:6 486 483 :4 47b :3 469
:a 491 :1b 492 :2 493 :2 492
:4 493 :3 492 :4 495 :4 496
495 :6 497 :5 498 497
:5 49a 499 :3 497 494
49d :5 49e :3 49d :2 49f
:5 4a1 :11 4a2 :24 4a3 :3 4a2
:2 4a0 :6 49f 49c :3 493
:3 4a9 :4 4aa :4 4ab :2 4ac
4a9 :6 4ad :5 4ae 4ad
:5 4b0 4af :3 4ad 4a8
4b3 :5 4b4 :3 4b3 :2 4b5
:5 4b7 :11 4b8 :24 4b9 :3 4b8
:2 4b6 :6 4b5 4b2 :4 493
:5 4cd 4cf :7 4d0 :3 4d1
:5 4d2 4d1 :5 4d4 4d3
:3 4d1 :7 4d6 :2 4d7 :3 4d6
:f 4db :9 4dd :d 4de :d 4df
:7 4e0 4df :17 4e2 4e1
:3 4df :3 4de :6 4e7 :6 4e8
:5 4e9 4e8 :5 4eb 4ea
:3 4e8 4e6 4ee :5 4ef
:3 4ee :2 4f0 :5 4f2 :11 4f3
:24 4f4 :3 4f3 :2 4f1 :6 4f0
4ed :3 4dd :3 4f9 :3 4dd
:d 4fc :2 4fd :3 4fc 4cf
4ff 4cc :4 502 :5 503
501 505 :5 506 :3 505
:2 507 :5 509 :11 50a :24 50b
:3 50a :2 508 :6 507 504
:3 4cc :12 511 :6 513 :6 514
:5 515 514 :5 517 516
:3 514 512 51a :5 51b
:3 51a :2 51c :5 51e :11 51f
:24 520 :3 51f :2 51d :6 51c
519 :6 511 4cc :3 492
:9 56d :e 56e :7 56f 56e
:7 571 570 :3 56e :3 56d
:3 491 463 :2 462 :3 125
:7 578 :5 579 :3 578 :3 a7
:11 57f :30 580 :3 57f :a 582
61 :3 586 :11 587 :b 588
:17 589 :3 587 :2 58b :3 58c
:3 58d 58e 58c 58b
58c :3 58f :3 586 :2 590
:5 592 :11 593 :b 594 :18 595
:3 593 :2 597 598 :3 599
59a 598 597 598
:3 59b :2 591 :6 590 585
:7 1 
6aeb
4
:3 0 1 :3 0 2
:a 0 1e75 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 4 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 8
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 6
:3 0 a :7 0 19
18 :3 0 4 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 6 :3 0 c
:7 0 21 20 :3 0
6 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 6
:3 0 e :7 0 29
28 :3 0 6 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 6 :3 0 10
:7 0 31 30 :3 0
6 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 6 :3 0 14
:7 0 41 40 :3 0
6 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d :2 0 2b
6 :3 0 18 :7 0
51 50 :3 0 4
:3 0 19 :7 0 55
54 :3 0 1a :3 0
1b :3 0 1c :2 0
4 59 5a 0
57 5b 0 1e75
2 5c :2 0 1e
:2 0 45 4 :3 0
1e :2 0 43 5f
61 :6 0 64 62
0 1e73 0 1d
:6 0 21 :2 0 49
4 :3 0 47 66
68 :6 0 6b 69
0 1e73 0 1f
:6 0 23 :2 0 4d
4 :3 0 4b 6d
6f :6 0 72 70
0 1e73 0 20
:6 0 25 :2 0 51
4 :3 0 4f 74
76 :6 0 79 77
0 1e73 0 22
:6 0 27 :2 0 55
4 :3 0 53 7b
7d :6 0 80 7e
0 1e73 0 24
:6 0 27 :2 0 59
4 :3 0 57 82
84 :6 0 87 85
0 1e73 0 26
:6 0 27 :2 0 5d
4 :3 0 5b 89
8b :6 0 8e 8c
0 1e73 0 28
:6 0 27 :2 0 61
4 :3 0 5f 90
92 :6 0 95 93
0 1e73 0 29
:6 0 27 :2 0 65
4 :3 0 63 97
99 :6 0 9c 9a
0 1e73 0 2a
:6 0 27 :2 0 69
4 :3 0 67 9e
a0 :6 0 a3 a1
0 1e73 0 2b
:6 0 27 :2 0 6d
4 :3 0 6b a5
a7 :6 0 aa a8
0 1e73 0 2c
:6 0 27 :2 0 71
4 :3 0 6f ac
ae :6 0 b1 af
0 1e73 0 2d
:6 0 27 :2 0 75
4 :3 0 73 b3
b5 :6 0 b8 b6
0 1e73 0 2e
:6 0 31 :2 0 79
4 :3 0 77 ba
bc :6 0 bf bd
0 1e73 0 2f
:6 0 31 :2 0 7b
6 :3 0 c1 :7 0
c5 c2 c3 1e73
0 30 :6 0 31
:2 0 7d 6 :3 0
c7 :7 0 cb c8
c9 1e73 0 32
:6 0 35 :2 0 7f
6 :3 0 cd :7 0
d1 ce cf 1e73
0 33 :6 0 31
:2 0 81 6 :3 0
d3 :7 0 d7 d4
d5 1e73 0 34
:6 0 31 :2 0 83
6 :3 0 d9 :7 0
dd da db 1e73
0 36 :6 0 31
:2 0 85 6 :3 0
df :7 0 e3 e0
e1 1e73 0 37
:6 0 31 :2 0 87
6 :3 0 e5 :7 0
e9 e6 e7 1e73
0 38 :6 0 3b
:2 0 89 6 :3 0
eb :7 0 ef ec
ed 1e73 0 39
:6 0 31 :2 0 8b
6 :3 0 f1 :7 0
f5 f2 f3 1e73
0 3a :6 0 31
:2 0 8d 6 :3 0
f7 :7 0 fb f8
f9 1e73 0 3c
:6 0 31 :2 0 8f
6 :3 0 fd :7 0
101 fe ff 1e73
0 3d :6 0 31
:2 0 91 6 :3 0
103 :7 0 107 104
105 1e73 0 3e
:6 0 31 :2 0 93
6 :3 0 109 :7 0
10d 10a 10b 1e73
0 3f :6 0 31
:2 0 95 6 :3 0
10f :7 0 113 110
111 1e73 0 40
:6 0 31 :2 0 97
6 :3 0 115 :7 0
119 116 117 1e73
0 41 :6 0 9b
51c 0 99 6
:3 0 11b :7 0 11f
11c 11d 1e73 0
42 :6 0 27 :2 0
9d 44 :3 0 121
:7 0 124 122 0
1e73 0 43 :6 0
44 :3 0 126 :7 0
129 127 0 1e73
0 45 :6 0 27
:2 0 a1 4 :3 0
9f 12b 12d :6 0
130 12e 0 1e73
0 46 :6 0 49
:2 0 a5 4 :3 0
a3 132 134 :6 0
137 135 0 1e73
0 47 :6 0 ab
5a7 0 a9 4
:3 0 a7 139 13b
:6 0 13e 13c 0
1e73 0 48 :6 0
af 5db 0 ad
4b :3 0 140 :7 0
143 141 0 1e73
0 4a :6 0 4b
:3 0 145 :7 0 148
146 0 1e73 0
4c :6 0 b3 60f
0 b1 4b :3 0
14a :7 0 14d 14b
0 1e73 0 4d
:6 0 4b :3 0 14f
:7 0 152 150 0
1e73 0 4e :6 0
21 :2 0 b5 4b
:3 0 154 :7 0 157
155 0 1e73 0
4f :6 0 4b :3 0
159 :7 0 15c 15a
0 1e73 0 50
:6 0 31 :2 0 b9
4 :3 0 b7 15e
160 :6 0 163 161
0 1e73 0 51
:6 0 31 :2 0 bb
6 :3 0 165 :7 0
169 166 167 1e73
0 52 :6 0 31
:2 0 bd 6 :3 0
16b :7 0 16f 16c
16d 1e73 0 53
:6 0 31 :2 0 bf
6 :3 0 171 :7 0
175 172 173 1e73
0 54 :6 0 31
:2 0 c1 6 :3 0
177 :7 0 17b 178
179 1e73 0 55
:6 0 31 :2 0 c3
6 :3 0 17d :7 0
181 17e 17f 1e73
0 56 :6 0 31
:2 0 c5 6 :3 0
183 :7 0 187 184
185 1e73 0 57
:6 0 c9 724 0
c7 6 :3 0 189
:7 0 18d 18a 18b
1e73 0 58 :6 0
31 :2 0 cb 44
:3 0 18f :7 0 192
190 0 1e73 0
59 :6 0 44 :3 0
194 :7 0 197 195
0 1e73 0 5a
:6 0 31 :2 0 cd
5c :3 0 199 :7 0
19d 19a 19b 1e73
0 5b :6 0 31
:2 0 cf 5c :3 0
19f :7 0 1a3 1a0
1a1 1e73 0 5d
:6 0 31 :2 0 d1
6 :3 0 1a5 :7 0
1a9 1a6 1a7 1e73
0 5e :6 0 31
:2 0 d3 6 :3 0
1ab :7 0 1af 1ac
1ad 1e73 0 5f
:6 0 31 :2 0 d5
6 :3 0 1b1 :7 0
1b5 1b2 1b3 1e73
0 60 :9 0 d7
6 :3 0 1b7 :7 0
1bb 1b8 1b9 1e73
0 61 :6 0 62
:3 0 63 :a 0 2
1d0 :4 0 1bd 1c0
0 1be :3 0 64
:3 0 65 :3 0 66
:3 0 67 :3 0 65
:3 0 66 :3 0 68
:3 0 69 :3 0 6a
:3 0 2d :3 0 6b
:3 0 2e :3 0 6c
:3 0 6d :4 0 6e
1 :8 0 1d1 1bd
1c0 1d2 0 1e73
d9 1d2 1d4 1d1
1d3 :6 0 1d0 :7 0
1d2 62 :3 0 6f
:a 0 3 1e5 :5 0
1d6 1d9 0 1d7
:3 0 70 :3 0 71
:3 0 72 :3 0 73
:3 0 6a :3 0 2d
:3 0 74 :3 0 46
:3 0 75 :3 0 72
:4 0 76 1 :8 0
1e6 1d6 1d9 1e7
0 1e73 db 1e7
1e9 1e6 1e8 :6 0
1e5 :7 0 1e7 1f1
1f2 0 dd 1b
:3 0 1c :2 0 4
1eb 1ec 0 1ed
:7 0 1f0 1ee 0
1e73 0 77 :6 0
78 :3 0 79 :3 0
78 :3 0 7a :3 0
1f4 1f5 0 2
:4 0 df 1f6 1f8
1f3 1fa 1f9 :2 0
7b :3 0 7c :3 0
1fc 1fd 0 7d
:4 0 78 :3 0 7e
:3 0 200 201 0
2 :4 0 e1 202
204 7f :4 0 80
:2 0 81 :3 0 e3
207 209 :3 0 82
:4 0 80 :2 0 83
:4 0 e6 20c 20e
:3 0 80 :2 0 3
:3 0 e9 210 212
:3 0 80 :2 0 83
:4 0 ec 214 216
:3 0 80 :2 0 84
:4 0 ef 218 21a
:3 0 80 :2 0 85
:3 0 66 :3 0 5
:3 0 f2 21e 220
86 :4 0 f4 21d
223 f7 21c 225
:3 0 80 :2 0 84
:4 0 fa 227 229
:3 0 80 :2 0 83
:4 0 fd 22b 22d
:3 0 80 :2 0 7
:3 0 100 22f 231
:3 0 80 :2 0 83
:4 0 103 233 235
:3 0 80 :2 0 84
:4 0 106 237 239
:3 0 80 :2 0 83
:4 0 109 23b 23d
:3 0 80 :2 0 8
:3 0 10c 23f 241
:3 0 80 :2 0 83
:4 0 10f 243 245
:3 0 80 :2 0 84
:4 0 112 247 249
:3 0 80 :2 0 83
:4 0 115 24b 24d
:3 0 80 :2 0 9
:3 0 118 24f 251
:3 0 80 :2 0 83
:4 0 11b 253 255
:3 0 80 :2 0 84
:4 0 11e 257 259
:3 0 80 :2 0 85
:3 0 66 :3 0 a
:3 0 121 25d 25f
86 :4 0 123 25c
262 126 25b 264
:3 0 80 :2 0 84
:4 0 129 266 268
:3 0 80 :2 0 83
:4 0 12c 26a 26c
:3 0 80 :2 0 b
:3 0 12f 26e 270
:3 0 80 :2 0 83
:4 0 132 272 274
:3 0 80 :2 0 84
:4 0 135 276 278
:3 0 80 :2 0 85
:3 0 66 :3 0 c
:3 0 138 27c 27e
86 :4 0 13a 27b
281 13d 27a 283
:3 0 80 :2 0 84
:4 0 140 285 287
:3 0 80 :2 0 85
:3 0 66 :3 0 d
:3 0 143 28b 28d
86 :4 0 145 28a
290 148 289 292
:3 0 80 :2 0 84
:4 0 14b 294 296
:3 0 80 :2 0 85
:3 0 66 :3 0 e
:3 0 14e 29a 29c
86 :4 0 150 299
29f 153 298 2a1
:3 0 80 :2 0 84
:4 0 156 2a3 2a5
:3 0 80 :2 0 85
:3 0 66 :3 0 f
:3 0 159 2a9 2ab
86 :4 0 15b 2a8
2ae 15e 2a7 2b0
:3 0 80 :2 0 84
:4 0 161 2b2 2b4
:3 0 80 :2 0 85
:3 0 66 :3 0 10
:3 0 164 2b8 2ba
86 :4 0 166 2b7
2bd 169 2b6 2bf
:3 0 80 :2 0 84
:4 0 16c 2c1 2c3
:3 0 80 :2 0 85
:3 0 66 :3 0 11
:3 0 16f 2c7 2c9
86 :4 0 171 2c6
2cc 174 2c5 2ce
:3 0 80 :2 0 84
:4 0 177 2d0 2d2
:3 0 80 :2 0 83
:4 0 17a 2d4 2d6
:3 0 80 :2 0 12
:3 0 17d 2d8 2da
:3 0 80 :2 0 83
:4 0 180 2dc 2de
:3 0 80 :2 0 84
:4 0 183 2e0 2e2
:3 0 80 :2 0 83
:4 0 186 2e4 2e6
:3 0 80 :2 0 13
:3 0 189 2e8 2ea
:3 0 80 :2 0 83
:4 0 18c 2ec 2ee
:3 0 80 :2 0 84
:4 0 18f 2f0 2f2
:3 0 80 :2 0 85
:3 0 66 :3 0 14
:3 0 192 2f6 2f8
86 :4 0 194 2f5
2fb 197 2f4 2fd
:3 0 80 :2 0 84
:4 0 19a 2ff 301
:3 0 80 :2 0 85
:3 0 66 :3 0 15
:3 0 19d 305 307
86 :4 0 19f 304
30a 1a2 303 30c
:3 0 80 :2 0 84
:4 0 1a5 30e 310
:3 0 80 :2 0 83
:4 0 1a8 312 314
:3 0 80 :2 0 16
:3 0 1ab 316 318
:3 0 80 :2 0 83
:4 0 1ae 31a 31c
:3 0 80 :2 0 84
:4 0 1b1 31e 320
:3 0 80 :2 0 83
:4 0 1b4 322 324
:3 0 80 :2 0 17
:3 0 1b7 326 328
:3 0 80 :2 0 83
:4 0 1ba 32a 32c
:3 0 80 :2 0 84
:4 0 1bd 32e 330
:3 0 80 :2 0 85
:3 0 66 :3 0 18
:3 0 1c0 334 336
86 :4 0 1c2 333
339 1c5 332 33b
:3 0 80 :2 0 84
:4 0 1c8 33d 33f
:3 0 80 :2 0 83
:4 0 1cb 341 343
:3 0 80 :2 0 19
:3 0 1ce 345 347
:3 0 80 :2 0 83
:4 0 1d1 349 34b
:3 0 80 :2 0 87
:4 0 1d4 34d 34f
:3 0 1d7 1fe 351
:2 0 353 1dc 354
1fb 353 0 355
1de 0 1dd3 78
:3 0 79 :3 0 356
357 0 78 :3 0
88 :3 0 359 35a
0 49 :2 0 2
:4 0 89 :2 0 8a
:2 0 49 :2 0 1e0
35f 361 :3 0 1e3
35b 363 358 365
364 :2 0 7b :3 0
8b :3 0 367 368
0 7d :4 0 8c
:4 0 80 :2 0 81
:3 0 1e7 36c 36e
:3 0 1ea 369 370
:2 0 372 1ed 373
366 372 0 374
1ef 0 1dd3 5
:3 0 8d :2 0 1f1
376 377 :3 0 378
:2 0 379 :2 0 85
:3 0 5 :3 0 31
:2 0 1f3 37b 37e
8e :2 0 49 :2 0
1f8 380 382 :3 0
383 :2 0 85 :3 0
5 :3 0 31 :2 0
1fb 385 388 8f
:2 0 90 :2 0 200
38a 38c :3 0 38d
:2 0 384 38f 38e
:2 0 390 :2 0 37a
392 391 :2 0 78
:3 0 79 :3 0 394
395 0 78 :3 0
88 :3 0 397 398
0 91 :2 0 2
:4 0 92 :2 0 8a
:2 0 49 :2 0 203
39d 39f :3 0 206
399 3a1 396 3a3
3a2 :2 0 7b :3 0
8b :3 0 3a5 3a6
0 7d :4 0 93
:4 0 80 :2 0 81
:3 0 20a 3aa 3ac
:3 0 80 :2 0 94
:4 0 20d 3ae 3b0
:3 0 80 :2 0 95
:4 0 210 3b2 3b4
:3 0 80 :2 0 85
:3 0 66 :3 0 96
:3 0 97 :3 0 3b9
3ba 0 213 3b8
3bc 86 :4 0 215
3b7 3bf 218 3b6
3c1 :3 0 21b 3a7
3c3 :2 0 3c5 21e
3c6 3a4 3c5 0
3c7 220 0 3f0
78 :3 0 79 :3 0
3c8 3c9 0 78
:3 0 88 :3 0 3cb
3cc 0 49 :2 0
2 :4 0 98 :2 0
8a :2 0 49 :2 0
222 3d1 3d3 :3 0
225 3cd 3d5 3ca
3d7 3d6 :2 0 7b
:3 0 8b :3 0 3d9
3da 0 7d :4 0
99 :4 0 80 :2 0
81 :3 0 229 3de
3e0 :3 0 22c 3db
3e2 :2 0 3e4 22f
3e5 3d8 3e4 0
3e6 231 0 3f0
9a :3 0 9b :3 0
3e7 3e8 0 96
:3 0 97 :3 0 3ea
3eb 0 9c :3 0
233 3e9 3ee :2 0
3f0 236 3f1 393
3f0 0 3f2 23a
0 1dd3 3 :3 0
8d :2 0 23c 3f4
3f5 :3 0 3f6 :2 0
3f7 :2 0 f :3 0
8d :2 0 23e 3fa
3fb :3 0 3fc :2 0
3fd :2 0 3f8 3ff
3fe :2 0 19 :3 0
8d :2 0 240 402
403 :3 0 404 :2 0
405 :2 0 400 407
406 :2 0 78 :3 0
79 :3 0 409 40a
0 78 :3 0 88
:3 0 40c 40d 0
91 :2 0 2 :4 0
9d :2 0 8a :2 0
49 :2 0 242 412
414 :3 0 245 40e
416 40b 418 417
:2 0 7b :3 0 8b
:3 0 41a 41b 0
7d :4 0 9e :4 0
80 :2 0 81 :3 0
249 41f 421 :3 0
80 :2 0 94 :4 0
24c 423 425 :3 0
80 :2 0 95 :4 0
24f 427 429 :3 0
80 :2 0 85 :3 0
66 :3 0 96 :3 0
97 :3 0 42e 42f
0 252 42d 431
86 :4 0 254 42c
434 257 42b 436
:3 0 25a 41c 438
:2 0 43a 25d 43b
419 43a 0 43c
25f 0 465 78
:3 0 79 :3 0 43d
43e 0 78 :3 0
88 :3 0 440 441
0 49 :2 0 2
:4 0 9f :2 0 8a
:2 0 49 :2 0 261
446 448 :3 0 264
442 44a 43f 44c
44b :2 0 7b :3 0
8b :3 0 44e 44f
0 7d :4 0 a0
:4 0 80 :2 0 81
:3 0 268 453 455
:3 0 26b 450 457
:2 0 459 26e 45a
44d 459 0 45b
270 0 465 9a
:3 0 9b :3 0 45c
45d 0 96 :3 0
97 :3 0 45f 460
0 9c :3 0 272
45e 463 :2 0 465
275 466 408 465
0 467 279 0
1dd3 4d :4 0 468
469 0 1dd3 4f
:4 0 46b 46c 0
1dd3 32 :3 0 a1
:2 0 46e 46f 0
1dd3 4c :3 0 8
:3 0 471 472 0
1dd3 4e :3 0 9
:3 0 474 475 0
1dd3 51 :3 0 b
:3 0 477 478 0
1dd3 2f :3 0 19
:3 0 47a 47b 0
1dd3 3d :3 0 a
:3 0 47d 47e 0
1dd3 41 :3 0 f
:3 0 480 481 0
1dd3 57 :3 0 5
:3 0 483 484 0
1dd3 39 :3 0 10
:3 0 486 487 0
1dd3 4d :3 0 16
:3 0 489 48a 0
1dd3 42 :3 0 c
:3 0 48c 48d 0
1dd3 55 :3 0 31
:2 0 48f 490 0
1dd3 85 :3 0 a2
:3 0 51 :3 0 27b
493 495 31 :2 0
27d 492 498 96
:3 0 8e :2 0 a3
:3 0 49a 49c 0
282 49b 49e :3 0
85 :3 0 57 :3 0
31 :2 0 285 4a0
4a3 a4 :2 0 49
:2 0 28a 4a5 4a7
:3 0 4a8 :2 0 85
:3 0 57 :3 0 31
:2 0 28d 4aa 4ad
a4 :2 0 90 :2 0
292 4af 4b1 :3 0
4b2 :2 0 4a9 4b4
4b3 :2 0 7 :3 0
8d :2 0 295 4b7
4b8 :3 0 4b9 :2 0
78 :3 0 79 :3 0
4bb 4bc 0 78
:3 0 88 :3 0 4be
4bf 0 91 :2 0
2 :4 0 a5 :2 0
8a :2 0 49 :2 0
297 4c4 4c6 :3 0
29a 4c0 4c8 4bd
4ca 4c9 :2 0 7b
:3 0 8b :3 0 4cc
4cd 0 7d :4 0
a6 :4 0 80 :2 0
81 :3 0 29e 4d1
4d3 :3 0 80 :2 0
94 :4 0 2a1 4d5
4d7 :3 0 80 :2 0
95 :4 0 2a4 4d9
4db :3 0 80 :2 0
85 :3 0 66 :3 0
96 :3 0 97 :3 0
4e0 4e1 0 2a7
4df 4e3 86 :4 0
2a9 4de 4e6 2ac
4dd 4e8 :3 0 2af
4ce 4ea :2 0 4ec
2b2 4ed 4cb 4ec
0 4ee 2b4 0
517 78 :3 0 79
:3 0 4ef 4f0 0
78 :3 0 88 :3 0
4f2 4f3 0 49
:2 0 2 :4 0 a7
:2 0 8a :2 0 49
:2 0 2b6 4f8 4fa
:3 0 2b9 4f4 4fc
4f1 4fe 4fd :2 0
7b :3 0 8b :3 0
500 501 0 7d
:4 0 a8 :4 0 80
:2 0 81 :3 0 2bd
505 507 :3 0 2c0
502 509 :2 0 50b
2c3 50c 4ff 50b
0 50d 2c5 0
517 9a :3 0 9b
:3 0 50e 50f 0
96 :3 0 97 :3 0
511 512 0 9c
:3 0 2c7 510 515
:2 0 517 2ca 518
4ba 517 0 519
2ce 0 6d2 2c
:3 0 3 :3 0 51a
51b 0 6d2 2e
:3 0 7 :3 0 51d
51e 0 6d2 2f
:3 0 19 :3 0 520
521 0 6d2 6a
:3 0 a9 :3 0 2d
:3 0 30 :3 0 69
:3 0 6b :3 0 2e
:4 0 aa 1 :8 0
530 1b :3 0 ab
:3 0 52b 52c 0
ac :3 0 52d 52e
0 530 2d0 583
ad :3 0 1b :3 0
ab :3 0 532 533
0 ac :3 0 534
535 0 537 2d3
539 2d5 538 537
:2 0 581 ae :3 0
1b :3 0 ab :3 0
53c 53d 0 ac
:3 0 53e 53f 0
579 78 :3 0 79
:3 0 541 542 0
78 :3 0 88 :3 0
544 545 0 25
:2 0 2 :4 0 af
:2 0 8a :2 0 49
:2 0 2d7 54a 54c
:3 0 2da 546 54e
543 550 54f :2 0
7b :3 0 8b :3 0
552 553 0 7d
:4 0 b0 :4 0 80
:2 0 81 :3 0 2de
557 559 :3 0 80
:2 0 94 :4 0 2e1
55b 55d :3 0 80
:2 0 b1 :4 0 2e4
55f 561 :3 0 80
:2 0 ac :3 0 2e7
563 565 :3 0 80
:2 0 b2 :4 0 2ea
567 569 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 2ed 56c 570
2f1 56b 572 :3 0
2f4 554 574 :2 0
576 2f7 577 551
576 0 578 2f9
0 579 2fb 57c
:3 0 57c 0 57c
57b 579 57a :6 0
57e 4 :3 0 2fe
580 300 57f 57e
:2 0 581 302 :2 0
583 0 583 582
530 581 :6 0 6d2
1 :3 0 2b :3 0
b6 :4 0 586 587
:3 0 585 588 0
6d2 52 :3 0 b7
:3 0 85 :3 0 30
:3 0 31 :2 0 305
58c 58f 308 58b
591 58a 592 0
6d2 54 :3 0 b8
:3 0 52 :3 0 30
:3 0 2e :3 0 2c
:3 0 2f :3 0 2b
:3 0 30a 595 59c
594 59d 0 6d2
85 :3 0 54 :3 0
31 :2 0 311 59f
5a2 a4 :2 0 31
:2 0 316 5a4 5a6
:3 0 85 :3 0 54
:3 0 31 :2 0 319
5a8 5ab a4 :2 0
49 :2 0 31e 5ad
5af :3 0 5a7 5b1
5b0 :2 0 5b2 :2 0
85 :3 0 57 :3 0
31 :2 0 321 5b4
5b7 a4 :2 0 90
:2 0 326 5b9 5bb
:3 0 5bc :2 0 5b3
5be 5bd :2 0 85
:3 0 3d :3 0 31
:2 0 329 5c0 5c3
a4 :2 0 31 :2 0
32e 5c5 5c7 :3 0
5c8 :2 0 5bf 5ca
5c9 :2 0 53 :3 0
31 :2 0 5cc 5cd
0 6b0 b9 :3 0
53 :3 0 ba :3 0
bb :3 0 6a :3 0
2d :3 0 bc :3 0
2c :4 0 bd 1
:8 0 5dd 1b :3 0
ab :3 0 5d8 5d9
0 ac :3 0 5da
5db 0 5dd 331
630 ad :3 0 1b
:3 0 ab :3 0 5df
5e0 0 ac :3 0
5e1 5e2 0 5e4
334 5e6 336 5e5
5e4 :2 0 62e ae
:3 0 1b :3 0 ab
:3 0 5e9 5ea 0
ac :3 0 5eb 5ec
0 626 78 :3 0
79 :3 0 5ee 5ef
0 78 :3 0 88
:3 0 5f1 5f2 0
25 :2 0 2 :4 0
be :2 0 8a :2 0
49 :2 0 338 5f7
5f9 :3 0 33b 5f3
5fb 5f0 5fd 5fc
:2 0 7b :3 0 8b
:3 0 5ff 600 0
7d :4 0 bf :4 0
80 :2 0 81 :3 0
33f 604 606 :3 0
80 :2 0 94 :4 0
342 608 60a :3 0
80 :2 0 b1 :4 0
345 60c 60e :3 0
80 :2 0 ac :3 0
348 610 612 :3 0
80 :2 0 b2 :4 0
34b 614 616 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 34e 619
61d 352 618 61f
:3 0 355 601 621
:2 0 623 358 624
5fe 623 0 625
35a 0 626 35c
629 :3 0 629 0
629 628 626 627
:6 0 62b 6 :3 0
35f 62d 361 62c
62b :2 0 62e 363
:2 0 630 0 630
62f 5dd 62e :6 0
6b0 1 :3 0 85
:3 0 53 :3 0 31
:2 0 366 632 635
c0 :2 0 31 :2 0
36b 637 639 :3 0
57 :3 0 49 :2 0
63b 63c 0 6ad
3d :3 0 c1 :2 0
63e 63f 0 6ad
51 :3 0 c2 :4 0
641 642 0 6ad
4c :3 0 c3 :2 0
36e 645 646 :3 0
647 :2 0 c4 :3 0
c5 :3 0 c6 :3 0
4c :3 0 4e :3 0
ba :4 0 c7 1
:8 0 655 1b :3 0
ab :3 0 650 651
0 ac :3 0 652
653 0 655 370
6a8 ad :3 0 1b
:3 0 ab :3 0 657
658 0 ac :3 0
659 65a 0 65c
373 65e 375 65d
65c :2 0 6a6 ae
:3 0 1b :3 0 ab
:3 0 661 662 0
ac :3 0 663 664
0 69e 78 :3 0
79 :3 0 666 667
0 78 :3 0 88
:3 0 669 66a 0
25 :2 0 2 :4 0
c8 :2 0 8a :2 0
49 :2 0 377 66f
671 :3 0 37a 66b
673 668 675 674
:2 0 7b :3 0 8b
:3 0 677 678 0
7d :4 0 c9 :4 0
80 :2 0 81 :3 0
37e 67c 67e :3 0
80 :2 0 94 :4 0
381 680 682 :3 0
80 :2 0 b1 :4 0
384 684 686 :3 0
80 :2 0 ac :3 0
387 688 68a :3 0
80 :2 0 b2 :4 0
38a 68c 68e :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 38d 691
695 391 690 697
:3 0 394 679 699
:2 0 69b 397 69c
676 69b 0 69d
399 0 69e 39b
6a1 :3 0 6a1 0
6a1 6a0 69e 69f
:6 0 6a3 8 :3 0
39e 6a5 3a0 6a4
6a3 :2 0 6a6 3a2
:2 0 6a8 0 6a8
6a7 655 6a6 :6 0
6aa 1 :3 0 3a5
6ab 648 6aa 0
6ac 3a7 0 6ad
3a9 6ae 63a 6ad
0 6af 3ae 0
6b0 3b0 6b1 5cb
6b0 0 6b2 3b4
0 6d2 85 :3 0
57 :3 0 31 :2 0
3b6 6b3 6b6 a4
:2 0 49 :2 0 3bb
6b8 6ba :3 0 6bb
:2 0 ca :3 0 85
:3 0 30 :3 0 31
:2 0 3be 6be 6c1
3c1 6bd 6c3 6c4
:2 0 c0 :2 0 31
:2 0 3c5 6c6 6c8
:3 0 6bc 6ca 6c9
:2 0 57 :3 0 90
:2 0 6cc 6cd 0
6cf 3c8 6d0 6cb
6cf 0 6d1 3ca
0 6d2 3cc 7cf
2b :3 0 3 :3 0
6d3 6d4 0 7ce
6a :3 0 cb :3 0
cc :3 0 cd :3 0
ce :3 0 cf :3 0
d0 :3 0 d1 :3 0
d2 :3 0 6c :3 0
2d :3 0 2e :3 0
2c :3 0 42 :3 0
47 :3 0 61 :3 0
36 :3 0 37 :3 0
38 :3 0 4f :3 0
d3 :3 0 74 :3 0
2b :4 0 d4 1
:8 0 6f3 1b :3 0
ab :3 0 6ee 6ef
0 ac :3 0 6f0
6f1 0 6f3 3d7
746 ad :3 0 1b
:3 0 ab :3 0 6f5
6f6 0 ac :3 0
6f7 6f8 0 6fa
3da 6fc 3dc 6fb
6fa :2 0 744 ae
:3 0 1b :3 0 ab
:3 0 6ff 700 0
ac :3 0 701 702
0 73c 78 :3 0
79 :3 0 704 705
0 78 :3 0 88
:3 0 707 708 0
25 :2 0 2 :4 0
d5 :2 0 8a :2 0
49 :2 0 3de 70d
70f :3 0 3e1 709
711 706 713 712
:2 0 7b :3 0 8b
:3 0 715 716 0
7d :4 0 d6 :4 0
80 :2 0 81 :3 0
3e5 71a 71c :3 0
80 :2 0 94 :4 0
3e8 71e 720 :3 0
80 :2 0 b1 :4 0
3eb 722 724 :3 0
80 :2 0 ac :3 0
3ee 726 728 :3 0
80 :2 0 b2 :4 0
3f1 72a 72c :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 3f4 72f
733 3f8 72e 735
:3 0 3fb 717 737
:2 0 739 3fe 73a
714 739 0 73b
400 0 73c 402
73f :3 0 73f 0
73f 73e 73c 73d
:6 0 741 a :3 0
405 743 407 742
741 :2 0 744 409
:2 0 746 0 746
745 6f3 744 :6 0
7ce 1 :3 0 1b
:3 0 ab :3 0 748
749 0 1b :3 0
a4 :2 0 d7 :3 0
74b 74d 0 40e
74c 74f :3 0 750
:2 0 85 :3 0 c
:3 0 31 :2 0 411
752 755 85 :3 0
c0 :2 0 42 :3 0
31 :2 0 414 757
75b 419 758 75d
:3 0 75e :2 0 751
760 75f :2 0 78
:3 0 79 :3 0 762
763 0 78 :3 0
88 :3 0 765 766
0 27 :2 0 2
:4 0 d8 :2 0 8a
:2 0 49 :2 0 41c
76b 76d :3 0 41f
767 76f 764 771
770 :2 0 7b :3 0
8b :3 0 773 774
0 7d :4 0 d9
:4 0 80 :2 0 81
:3 0 423 778 77a
:3 0 80 :2 0 94
:4 0 426 77c 77e
:3 0 80 :2 0 95
:4 0 429 780 782
:3 0 80 :2 0 85
:3 0 66 :3 0 31
:2 0 42c 786 788
86 :4 0 42e 785
78b 431 784 78d
:3 0 80 :2 0 da
:4 0 434 78f 791
:3 0 80 :2 0 83
:4 0 437 793 795
:3 0 80 :2 0 2b
:3 0 43a 797 799
:3 0 80 :2 0 83
:4 0 43d 79b 79d
:3 0 440 775 79f
:2 0 7a1 443 7a2
772 7a1 0 7a3
445 0 7cb 78
:3 0 79 :3 0 7a4
7a5 0 78 :3 0
88 :3 0 7a7 7a8
0 49 :2 0 2
:4 0 db :2 0 8a
:2 0 49 :2 0 447
7ad 7af :3 0 44a
7a9 7b1 7a6 7b3
7b2 :2 0 7b :3 0
8b :3 0 7b5 7b6
0 7d :4 0 dc
:4 0 80 :2 0 81
:3 0 44e 7ba 7bc
:3 0 451 7b7 7be
:2 0 7c0 454 7c1
7b4 7c0 0 7c2
456 0 7cb 9a
:3 0 dd :3 0 7c3
7c4 0 31 :2 0
2b :3 0 9c :3 0
458 7c5 7c9 :2 0
7cb 45c 7cc 761
7cb 0 7cd 460
0 7ce 462 7d0
4b5 6d2 0 7d1
0 7ce 0 7d1
466 0 1d82 85
:3 0 57 :3 0 31
:2 0 469 7d2 7d5
c0 :2 0 90 :2 0
46e 7d7 7d9 :3 0
1b :3 0 ab :3 0
7db 7dc 0 c0
:2 0 31 :2 0 473
7de 7e0 :3 0 78
:3 0 79 :3 0 7e2
7e3 0 78 :3 0
88 :3 0 7e5 7e6
0 27 :2 0 2
:4 0 de :2 0 8a
:2 0 49 :2 0 476
7eb 7ed :3 0 479
7e7 7ef 7e4 7f1
7f0 :2 0 7b :3 0
8b :3 0 7f3 7f4
0 7d :4 0 df
:4 0 80 :2 0 81
:3 0 47d 7f8 7fa
:3 0 80 :2 0 94
:4 0 480 7fc 7fe
:3 0 80 :2 0 95
:4 0 483 800 802
:3 0 80 :2 0 85
:3 0 66 :3 0 1b
:3 0 ab :3 0 807
808 0 486 806
80a 86 :4 0 488
805 80d 48b 804
80f :3 0 80 :2 0
da :4 0 48e 811
813 :3 0 80 :2 0
83 :4 0 491 815
817 :3 0 80 :2 0
2b :3 0 494 819
81b :3 0 80 :2 0
83 :4 0 497 81d
81f :3 0 49a 7f5
821 :2 0 823 49d
824 7f2 823 0
825 49f 0 84f
78 :3 0 79 :3 0
826 827 0 78
:3 0 88 :3 0 829
82a 0 49 :2 0
2 :4 0 e0 :2 0
8a :2 0 49 :2 0
4a1 82f 831 :3 0
4a4 82b 833 828
835 834 :2 0 7b
:3 0 8b :3 0 837
838 0 7d :4 0
e1 :4 0 80 :2 0
81 :3 0 4a8 83c
83e :3 0 4ab 839
840 :2 0 842 4ae
843 836 842 0
844 4b0 0 84f
9a :3 0 dd :3 0
845 846 0 1b
:3 0 ab :3 0 848
849 0 2b :3 0
9c :3 0 4b2 847
84d :2 0 84f 4b6
850 7e1 84f 0
851 4ba 0 1d70
4c :3 0 8d :2 0
4bc 853 854 :3 0
855 :2 0 4e :3 0
8d :2 0 4be 858
859 :3 0 85a :2 0
856 85c 85b :2 0
3d :3 0 8d :2 0
4c0 85f 860 :3 0
861 :2 0 85d 863
862 :2 0 51 :3 0
8d :2 0 4c2 866
867 :3 0 868 :2 0
864 86a 869 :2 0
78 :3 0 79 :3 0
86c 86d 0 78
:3 0 88 :3 0 86f
870 0 91 :2 0
2 :4 0 e2 :2 0
8a :2 0 49 :2 0
4c4 875 877 :3 0
4c7 871 879 86e
87b 87a :2 0 7b
:3 0 8b :3 0 87d
87e 0 7d :4 0
e3 :4 0 80 :2 0
81 :3 0 4cb 882
884 :3 0 80 :2 0
94 :4 0 4ce 886
888 :3 0 80 :2 0
95 :4 0 4d1 88a
88c :3 0 80 :2 0
85 :3 0 66 :3 0
96 :3 0 97 :3 0
891 892 0 4d4
890 894 86 :4 0
4d6 88f 897 4d9
88e 899 :3 0 4dc
87f 89b :2 0 89d
4df 89e 87c 89d
0 89f 4e1 0
8c8 78 :3 0 79
:3 0 8a0 8a1 0
78 :3 0 88 :3 0
8a3 8a4 0 49
:2 0 2 :4 0 e4
:2 0 8a :2 0 49
:2 0 4e3 8a9 8ab
:3 0 4e6 8a5 8ad
8a2 8af 8ae :2 0
7b :3 0 8b :3 0
8b1 8b2 0 7d
:4 0 e5 :4 0 80
:2 0 81 :3 0 4ea
8b6 8b8 :3 0 4ed
8b3 8ba :2 0 8bc
4f0 8bd 8b0 8bc
0 8be 4f2 0
8c8 9a :3 0 9b
:3 0 8bf 8c0 0
96 :3 0 97 :3 0
8c2 8c3 0 9c
:3 0 4f4 8c1 8c6
:2 0 8c8 4f7 8c9
86b 8c8 0 8ca
4fb 0 1d70 3c
:3 0 96 :3 0 e6
:3 0 8cc 8cd 0
8cb 8ce 0 1d70
85 :3 0 39 :3 0
31 :2 0 4fd 8d0
8d3 8f :2 0 e7
:2 0 502 8d5 8d7
:3 0 39 :3 0 e7
:2 0 8d9 8da 0
8dc 505 8dd 8d8
8dc 0 8de 507
0 1d70 85 :3 0
e8 :3 0 3a :3 0
69 :3 0 6b :3 0
2e :4 0 e9 1
:8 0 8eb 1b :3 0
ab :3 0 8e6 8e7
0 ac :3 0 8e8
8e9 0 8eb 509
93e ad :3 0 1b
:3 0 ab :3 0 8ed
8ee 0 ac :3 0
8ef 8f0 0 8f2
50c 8f4 50e 8f3
8f2 :2 0 93c ae
:3 0 1b :3 0 ab
:3 0 8f7 8f8 0
ac :3 0 8f9 8fa
0 934 78 :3 0
79 :3 0 8fc 8fd
0 78 :3 0 88
:3 0 8ff 900 0
25 :2 0 2 :4 0
ea :2 0 8a :2 0
49 :2 0 510 905
907 :3 0 513 901
909 8fe 90b 90a
:2 0 7b :3 0 8b
:3 0 90d 90e 0
7d :4 0 eb :4 0
80 :2 0 81 :3 0
517 912 914 :3 0
80 :2 0 94 :4 0
51a 916 918 :3 0
80 :2 0 b1 :4 0
51d 91a 91c :3 0
80 :2 0 ac :3 0
520 91e 920 :3 0
80 :2 0 b2 :4 0
523 922 924 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 526 927
92b 52a 926 92d
:3 0 52d 90f 92f
:2 0 931 530 932
90c 931 0 933
532 0 934 534
937 :3 0 937 0
937 936 934 935
:6 0 939 c :3 0
537 93b 539 93a
939 :2 0 93c 53b
:2 0 93e 0 93e
93d 8eb 93c :6 0
1d70 1 :3 0 85
:3 0 36 :3 0 31
:2 0 53e 940 943
8f :2 0 31 :2 0
543 945 947 :3 0
53 :3 0 ec :3 0
85 :3 0 ed :3 0
36 :3 0 546 94c
94e 31 :2 0 548
94b 951 ee :2 0
85 :3 0 ed :3 0
3a :3 0 54b 955
957 31 :2 0 54d
954 95a 550 953
95c :3 0 95d :2 0
ef :2 0 f0 :2 0
553 95f 961 :3 0
962 :2 0 8a :2 0
f1 :2 0 556 964
966 :3 0 559 94a
968 949 969 0
986 85 :3 0 39
:3 0 31 :2 0 55b
96b 96e 85 :3 0
c0 :2 0 53 :3 0
31 :2 0 55e 970
974 563 971 976
:3 0 36 :3 0 31
:2 0 978 979 0
97e 37 :3 0 31
:2 0 97b 97c 0
97e 566 983 39
:3 0 31 :2 0 97f
980 0 982 569
984 977 97e 0
985 0 982 0
985 56b 0 986
56e 987 948 986
0 988 571 0
1d70 48 :4 0 989
98a 0 1d70 f2
:3 0 85 :3 0 f
:3 0 31 :2 0 573
98d 990 25 :2 0
576 98c 993 994
:2 0 a4 :2 0 25
:2 0 57b 996 998
:3 0 85 :3 0 57
:3 0 31 :2 0 57e
99a 99d a4 :2 0
49 :2 0 583 99f
9a1 :3 0 85 :3 0
c :3 0 31 :2 0
586 9a3 9a6 8f
:2 0 31 :2 0 58b
9a8 9aa :3 0 1b
:3 0 ab :3 0 9ac
9ad 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
34 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 58e 9af
9c1 9ae 9c2 0
a48 1b :3 0 ab
:3 0 9c4 9c5 0
a4 :2 0 31 :2 0
5a2 9c7 9c9 :3 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 6a :3 0
2d :3 0 cb :3 0
2e :3 0 cc :3 0
2c :4 0 fb 1
:8 0 9f0 fc :4 0
9db :3 0 9c :3 0
a4 :2 0 5a7 9de
9df :3 0 1b :3 0
ab :3 0 9e1 9e2
0 31 :2 0 9e3
9e4 0 9e6 5aa
9ed 1b :3 0 ab
:3 0 9e7 9e8 0
fd :2 0 9e9 9ea
0 9ec 5ac 9ee
9e0 9e6 0 9ef
0 9ec 0 9ef
5ae 0 9f0 5b1
a43 ad :3 0 1b
:3 0 ab :3 0 9f2
9f3 0 ac :3 0
9f4 9f5 0 9f7
5b4 9f9 5b6 9f8
9f7 :2 0 a41 ae
:3 0 1b :3 0 ab
:3 0 9fc 9fd 0
ac :3 0 9fe 9ff
0 a39 78 :3 0
79 :3 0 a01 a02
0 78 :3 0 88
:3 0 a04 a05 0
25 :2 0 2 :4 0
fe :2 0 8a :2 0
49 :2 0 5b8 a0a
a0c :3 0 5bb a06
a0e a03 a10 a0f
:2 0 7b :3 0 8b
:3 0 a12 a13 0
7d :4 0 ff :4 0
80 :2 0 81 :3 0
5bf a17 a19 :3 0
80 :2 0 94 :4 0
5c2 a1b a1d :3 0
80 :2 0 b1 :4 0
5c5 a1f a21 :3 0
80 :2 0 ac :3 0
5c8 a23 a25 :3 0
80 :2 0 b2 :4 0
5cb a27 a29 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 5ce a2c
a30 5d2 a2b a32
:3 0 5d5 a14 a34
:2 0 a36 5d8 a37
a11 a36 0 a38
5da 0 a39 5dc
a3c :3 0 a3c 0
a3c a3b a39 a3a
:6 0 a3e e :3 0
5df a40 5e1 a3f
a3e :2 0 a41 5e3
:2 0 a43 0 a43
a42 9f0 a41 :6 0
a45 1 :3 0 5e6
a46 9ca a45 0
a47 5e8 0 a48
5ea a62 1b :3 0
ab :3 0 a49 a4a
0 f3 :3 0 2b
:3 0 48 :3 0 48
:3 0 32 :3 0 4c
:3 0 4e :3 0 3d
:3 0 36 :3 0 33
:3 0 33 :3 0 33
:3 0 3c :3 0 37
:3 0 38 :3 0 55
:3 0 51 :3 0 2f
:3 0 5ed a4c a5e
a4b a5f 0 a61
5ff a63 9ab a48
0 a64 0 a61
0 a64 601 0
a65 604 b30 3c
:3 0 85 :3 0 3c
:3 0 31 :2 0 606
a67 a6a 8a :2 0
49 :2 0 609 a6c
a6e :3 0 a66 a6f
0 b2f 85 :3 0
c :3 0 31 :2 0
60c a71 a74 8f
:2 0 31 :2 0 611
a76 a78 :3 0 1b
:3 0 ab :3 0 a7a
a7b 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
34 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 614 a7d
a8f a7c a90 0
b12 1b :3 0 ab
:3 0 a92 a93 0
a4 :2 0 31 :2 0
628 a95 a97 :3 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 74 :3 0
2b :4 0 100 1
:8 0 aba fc :4 0
aa5 :3 0 9c :3 0
a4 :2 0 62d aa8
aa9 :3 0 1b :3 0
ab :3 0 aab aac
0 31 :2 0 aad
aae 0 ab0 630
ab7 1b :3 0 ab
:3 0 ab1 ab2 0
fd :2 0 ab3 ab4
0 ab6 632 ab8
aaa ab0 0 ab9
0 ab6 0 ab9
634 0 aba 637
b0d ad :3 0 1b
:3 0 ab :3 0 abc
abd 0 ac :3 0
abe abf 0 ac1
63a ac3 63c ac2
ac1 :2 0 b0b ae
:3 0 1b :3 0 ab
:3 0 ac6 ac7 0
ac :3 0 ac8 ac9
0 b03 78 :3 0
79 :3 0 acb acc
0 78 :3 0 88
:3 0 ace acf 0
25 :2 0 2 :4 0
101 :2 0 8a :2 0
49 :2 0 63e ad4
ad6 :3 0 641 ad0
ad8 acd ada ad9
:2 0 7b :3 0 8b
:3 0 adc add 0
7d :4 0 102 :4 0
80 :2 0 81 :3 0
645 ae1 ae3 :3 0
80 :2 0 94 :4 0
648 ae5 ae7 :3 0
80 :2 0 b1 :4 0
64b ae9 aeb :3 0
80 :2 0 ac :3 0
64e aed aef :3 0
80 :2 0 b2 :4 0
651 af1 af3 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 654 af6
afa 658 af5 afc
:3 0 65b ade afe
:2 0 b00 65e b01
adb b00 0 b02
660 0 b03 662
b06 :3 0 b06 0
b06 b05 b03 b04
:6 0 b08 10 :3 0
665 b0a 667 b09
b08 :2 0 b0b 669
:2 0 b0d 0 b0d
b0c aba b0b :6 0
b0f 1 :3 0 66c
b10 a98 b0f 0
b11 66e 0 b12
670 b2c 1b :3 0
ab :3 0 b13 b14
0 f3 :3 0 2b
:3 0 48 :3 0 48
:3 0 32 :3 0 4c
:3 0 4e :3 0 3d
:3 0 36 :3 0 33
:3 0 33 :3 0 33
:3 0 3c :3 0 37
:3 0 38 :3 0 55
:3 0 51 :3 0 2f
:3 0 673 b16 b28
b15 b29 0 b2b
685 b2d a79 b12
0 b2e 0 b2b
0 b2e 687 0
b2f 68a b31 9a2
a65 0 b32 0
b2f 0 b32 68d
0 d55 1b :3 0
ab :3 0 b33 b34
0 a4 :2 0 31
:2 0 692 b36 b38
:3 0 b39 :2 0 f2
:3 0 85 :3 0 f
:3 0 31 :2 0 695
b3c b3f 35 :2 0
698 b3b b42 b43
:2 0 a4 :2 0 35
:2 0 69d b45 b47
:3 0 b48 :2 0 b3a
b4a b49 :2 0 85
:3 0 c :3 0 31
:2 0 6a0 b4c b4f
85 :3 0 a4 :2 0
a :3 0 31 :2 0
6a3 b51 b55 6a8
b52 b57 :3 0 b58
:2 0 85 :3 0 e
:3 0 31 :2 0 6ab
b5a b5d a4 :2 0
31 :2 0 6b0 b5f
b61 :3 0 b62 :2 0
b59 b64 b63 :2 0
85 :3 0 d :3 0
31 :2 0 6b3 b66
b69 a4 :2 0 f0
:2 0 6b8 b6b b6d
:3 0 b6e :2 0 b65
b70 b6f :2 0 d3
:3 0 103 :3 0 d
:3 0 cf :3 0 39
:3 0 d2 :3 0 38
:3 0 f5 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 104 :3 0 4c
:3 0 105 :3 0 4e
:3 0 cd :3 0 c
:3 0 f4 :3 0 e
:3 0 74 :3 0 2b
:4 0 106 1 :8 0
b9f fc :4 0 b8a
:3 0 9c :3 0 a4
:2 0 6bd b8d b8e
:3 0 1b :3 0 ab
:3 0 b90 b91 0
31 :2 0 b92 b93
0 b95 6c0 b9c
1b :3 0 ab :3 0
b96 b97 0 fd
:2 0 b98 b99 0
b9b 6c2 b9d b8f
b95 0 b9e 0
b9b 0 b9e 6c4
0 b9f 6c7 bf2
ad :3 0 1b :3 0
ab :3 0 ba1 ba2
0 ac :3 0 ba3
ba4 0 ba6 6ca
ba8 6cc ba7 ba6
:2 0 bf0 ae :3 0
1b :3 0 ab :3 0
bab bac 0 ac
:3 0 bad bae 0
be8 78 :3 0 79
:3 0 bb0 bb1 0
78 :3 0 88 :3 0
bb3 bb4 0 25
:2 0 2 :4 0 107
:2 0 8a :2 0 49
:2 0 6ce bb9 bbb
:3 0 6d1 bb5 bbd
bb2 bbf bbe :2 0
7b :3 0 8b :3 0
bc1 bc2 0 7d
:4 0 108 :4 0 80
:2 0 81 :3 0 6d5
bc6 bc8 :3 0 80
:2 0 94 :4 0 6d8
bca bcc :3 0 80
:2 0 b1 :4 0 6db
bce bd0 :3 0 80
:2 0 ac :3 0 6de
bd2 bd4 :3 0 80
:2 0 b2 :4 0 6e1
bd6 bd8 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 6e4 bdb bdf
6e8 bda be1 :3 0
6eb bc3 be3 :2 0
be5 6ee be6 bc0
be5 0 be7 6f0
0 be8 6f2 beb
:3 0 beb 0 beb
bea be8 be9 :6 0
bed 12 :3 0 6f5
bef 6f7 bee bed
:2 0 bf0 6f9 :2 0
bf2 0 bf2 bf1
b9f bf0 :6 0 cd7
1 :3 0 73 :3 0
75 :3 0 70 :3 0
72 :3 0 6a :3 0
2d :3 0 74 :3 0
2b :4 0 109 1
:8 0 c12 fc :4 0
bfd :3 0 9c :3 0
a4 :2 0 6fe c00
c01 :3 0 1b :3 0
ab :3 0 c03 c04
0 31 :2 0 c05
c06 0 c08 701
c0f 1b :3 0 ab
:3 0 c09 c0a 0
fd :2 0 c0b c0c
0 c0e 703 c10
c02 c08 0 c11
0 c0e 0 c11
705 0 c12 708
c65 ad :3 0 1b
:3 0 ab :3 0 c14
c15 0 ac :3 0
c16 c17 0 c19
70b c1b 70d c1a
c19 :2 0 c63 ae
:3 0 1b :3 0 ab
:3 0 c1e c1f 0
ac :3 0 c20 c21
0 c5b 78 :3 0
79 :3 0 c23 c24
0 78 :3 0 88
:3 0 c26 c27 0
25 :2 0 2 :4 0
10a :2 0 8a :2 0
49 :2 0 70f c2c
c2e :3 0 712 c28
c30 c25 c32 c31
:2 0 7b :3 0 8b
:3 0 c34 c35 0
7d :4 0 10b :4 0
80 :2 0 81 :3 0
716 c39 c3b :3 0
80 :2 0 94 :4 0
719 c3d c3f :3 0
80 :2 0 b1 :4 0
71c c41 c43 :3 0
80 :2 0 ac :3 0
71f c45 c47 :3 0
80 :2 0 b2 :4 0
722 c49 c4b :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 725 c4e
c52 729 c4d c54
:3 0 72c c36 c56
:2 0 c58 72f c59
c33 c58 0 c5a
731 0 c5b 733
c5e :3 0 c5e 0
c5e c5d c5b c5c
:6 0 c60 14 :3 0
736 c62 738 c61
c60 :2 0 c63 73a
:2 0 c65 0 c65
c64 c12 c63 :6 0
cd7 1 :3 0 d3
:3 0 10c :3 0 4e
:3 0 74 :3 0 2b
:4 0 10d 1 :8 0
c82 fc :4 0 c6d
:3 0 9c :3 0 a4
:2 0 73f c70 c71
:3 0 1b :3 0 ab
:3 0 c73 c74 0
31 :2 0 c75 c76
0 c78 742 c7f
1b :3 0 ab :3 0
c79 c7a 0 fd
:2 0 c7b c7c 0
c7e 744 c80 c72
c78 0 c81 0
c7e 0 c81 746
0 c82 749 cd5
ad :3 0 1b :3 0
ab :3 0 c84 c85
0 ac :3 0 c86
c87 0 c89 74c
c8b 74e c8a c89
:2 0 cd3 ae :3 0
1b :3 0 ab :3 0
c8e c8f 0 ac
:3 0 c90 c91 0
ccb 78 :3 0 79
:3 0 c93 c94 0
78 :3 0 88 :3 0
c96 c97 0 25
:2 0 2 :4 0 10e
:2 0 8a :2 0 49
:2 0 750 c9c c9e
:3 0 753 c98 ca0
c95 ca2 ca1 :2 0
7b :3 0 8b :3 0
ca4 ca5 0 7d
:4 0 10f :4 0 80
:2 0 81 :3 0 757
ca9 cab :3 0 80
:2 0 94 :4 0 75a
cad caf :3 0 80
:2 0 b1 :4 0 75d
cb1 cb3 :3 0 80
:2 0 ac :3 0 760
cb5 cb7 :3 0 80
:2 0 b2 :4 0 763
cb9 cbb :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 766 cbe cc2
76a cbd cc4 :3 0
76d ca6 cc6 :2 0
cc8 770 cc9 ca3
cc8 0 cca 772
0 ccb 774 cce
:3 0 cce 0 cce
ccd ccb ccc :6 0
cd0 16 :3 0 777
cd2 779 cd1 cd0
:2 0 cd3 77b :2 0
cd5 0 cd5 cd4
c82 cd3 :6 0 cd7
1 :3 0 77e d4f
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 74 :3 0
2b :4 0 110 1
:8 0 cf9 fc :4 0
ce4 :3 0 9c :3 0
a4 :2 0 784 ce7
ce8 :3 0 1b :3 0
ab :3 0 cea ceb
0 31 :2 0 cec
ced 0 cef 787
cf6 1b :3 0 ab
:3 0 cf0 cf1 0
fd :2 0 cf2 cf3
0 cf5 789 cf7
ce9 cef 0 cf8
0 cf5 0 cf8
78b 0 cf9 78e
d4c ad :3 0 1b
:3 0 ab :3 0 cfb
cfc 0 ac :3 0
cfd cfe 0 d00
791 d02 793 d01
d00 :2 0 d4a ae
:3 0 1b :3 0 ab
:3 0 d05 d06 0
ac :3 0 d07 d08
0 d42 78 :3 0
79 :3 0 d0a d0b
0 78 :3 0 88
:3 0 d0d d0e 0
25 :2 0 2 :4 0
111 :2 0 8a :2 0
49 :2 0 795 d13
d15 :3 0 798 d0f
d17 d0c d19 d18
:2 0 7b :3 0 8b
:3 0 d1b d1c 0
7d :4 0 112 :4 0
80 :2 0 81 :3 0
79c d20 d22 :3 0
80 :2 0 94 :4 0
79f d24 d26 :3 0
80 :2 0 b1 :4 0
7a2 d28 d2a :3 0
80 :2 0 ac :3 0
7a5 d2c d2e :3 0
80 :2 0 b2 :4 0
7a8 d30 d32 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 7ab d35
d39 7af d34 d3b
:3 0 7b2 d1d d3d
:2 0 d3f 7b5 d40
d1a d3f 0 d41
7b7 0 d42 7b9
d45 :3 0 d45 0
d45 d44 d42 d43
:6 0 d47 18 :3 0
7bc d49 7be d48
d47 :2 0 d4a 7c0
:2 0 d4c 0 d4c
d4b cf9 d4a :6 0
d4e 1 :3 0 7c3
d50 b71 cd7 0
d51 0 d4e 0
d51 7c5 0 d52
7c8 d53 b4b d52
0 d54 7ca 0
d55 7cc 117d 41
:3 0 f2 :3 0 85
:3 0 41 :3 0 31
:2 0 7cf d58 d5b
96 :3 0 113 :3 0
d5d d5e 0 7d2
d57 d60 d56 d61
0 117c 85 :3 0
57 :3 0 31 :2 0
7d5 d63 d66 a4
:2 0 49 :2 0 7da
d68 d6a :3 0 1b
:3 0 ab :3 0 d6c
d6d 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
41 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 7dd d6f
d81 d6e d82 0
e21 1b :3 0 ab
:3 0 d84 d85 0
a4 :2 0 31 :2 0
7f1 d87 d89 :3 0
d8a :2 0 85 :3 0
f :3 0 31 :2 0
7f4 d8c d8f a4
:2 0 35 :2 0 7f9
d91 d93 :3 0 d94
:2 0 d8b d96 d95
:2 0 85 :3 0 3e
:3 0 31 :2 0 7fc
d98 d9b a4 :2 0
31 :2 0 801 d9d
d9f :3 0 da0 :2 0
d97 da2 da1 :2 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 6a :3 0
2d :3 0 cb :3 0
2e :3 0 cc :3 0
2c :4 0 114 1
:8 0 dc9 fc :4 0
db4 :3 0 9c :3 0
a4 :2 0 806 db7
db8 :3 0 1b :3 0
ab :3 0 dba dbb
0 31 :2 0 dbc
dbd 0 dbf 809
dc6 1b :3 0 ab
:3 0 dc0 dc1 0
fd :2 0 dc2 dc3
0 dc5 80b dc7
db9 dbf 0 dc8
0 dc5 0 dc8
80d 0 dc9 810
e1c ad :3 0 1b
:3 0 ab :3 0 dcb
dcc 0 ac :3 0
dcd dce 0 dd0
813 dd2 815 dd1
dd0 :2 0 e1a ae
:3 0 1b :3 0 ab
:3 0 dd5 dd6 0
ac :3 0 dd7 dd8
0 e12 78 :3 0
79 :3 0 dda ddb
0 78 :3 0 88
:3 0 ddd dde 0
25 :2 0 2 :4 0
115 :2 0 8a :2 0
49 :2 0 817 de3
de5 :3 0 81a ddf
de7 ddc de9 de8
:2 0 7b :3 0 8b
:3 0 deb dec 0
7d :4 0 116 :4 0
80 :2 0 81 :3 0
81e df0 df2 :3 0
80 :2 0 94 :4 0
821 df4 df6 :3 0
80 :2 0 b1 :4 0
824 df8 dfa :3 0
80 :2 0 ac :3 0
827 dfc dfe :3 0
80 :2 0 b2 :4 0
82a e00 e02 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 82d e05
e09 831 e04 e0b
:3 0 834 ded e0d
:2 0 e0f 837 e10
dea e0f 0 e11
839 0 e12 83b
e15 :3 0 e15 0
e15 e14 e12 e13
:6 0 e17 1a :3 0
83e e19 840 e18
e17 :2 0 e1a 842
:2 0 e1c 0 e1c
e1b dc9 e1a :6 0
e1e 1 :3 0 845
e1f da3 e1e 0
e20 847 0 e21
849 1179 12 :3 0
c3 :2 0 84c e23
e24 :3 0 e25 :2 0
50 :3 0 12 :3 0
e27 e28 0 10b9
b3 :3 0 50 :3 0
b3 :3 0 50 :3 0
b3 :3 0 50 :3 0
b3 :3 0 50 :3 0
50 :3 0 ba :4 0
117 1 :8 0 e3a
1b :3 0 ab :3 0
e35 e36 0 ac
:3 0 e37 e38 0
e3a 84e e8d ad
:3 0 1b :3 0 ab
:3 0 e3c e3d 0
ac :3 0 e3e e3f
0 e41 851 e43
853 e42 e41 :2 0
e8b ae :3 0 1b
:3 0 ab :3 0 e46
e47 0 ac :3 0
e48 e49 0 e83
78 :3 0 79 :3 0
e4b e4c 0 78
:3 0 88 :3 0 e4e
e4f 0 25 :2 0
2 :4 0 118 :2 0
8a :2 0 49 :2 0
855 e54 e56 :3 0
858 e50 e58 e4d
e5a e59 :2 0 7b
:3 0 8b :3 0 e5c
e5d 0 7d :4 0
119 :4 0 80 :2 0
81 :3 0 85c e61
e63 :3 0 80 :2 0
94 :4 0 85f e65
e67 :3 0 80 :2 0
b1 :4 0 862 e69
e6b :3 0 80 :2 0
ac :3 0 865 e6d
e6f :3 0 80 :2 0
b2 :4 0 868 e71
e73 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
86b e76 e7a 86f
e75 e7c :3 0 872
e5e e7e :2 0 e80
875 e81 e5b e80
0 e82 877 0
e83 879 e86 :3 0
e86 0 e86 e85
e83 e84 :6 0 e88
1c :3 0 87c e8a
87e e89 e88 :2 0
e8b 880 :2 0 e8d
0 e8d e8c e3a
e8b :6 0 10b9 1
:3 0 c5 :3 0 11a
:3 0 e8f e90 0
50 :3 0 4f :3 0
11b :2 0 883 e91
e95 8e :2 0 31
:2 0 889 e97 e99
:3 0 30 :3 0 96
:3 0 11c :3 0 e9c
e9d 0 e9b e9e
0 10b6 52 :3 0
49 :2 0 ea0 ea1
0 10b6 6b :3 0
29 :3 0 11d :3 0
11e :4 0 11f 1
:8 0 ead 1b :3 0
ab :3 0 ea8 ea9
0 ac :3 0 eaa
eab 0 ead 88c
f00 ad :3 0 1b
:3 0 ab :3 0 eaf
eb0 0 ac :3 0
eb1 eb2 0 eb4
88f eb6 891 eb5
eb4 :2 0 efe ae
:3 0 1b :3 0 ab
:3 0 eb9 eba 0
ac :3 0 ebb ebc
0 ef6 78 :3 0
79 :3 0 ebe ebf
0 78 :3 0 88
:3 0 ec1 ec2 0
25 :2 0 2 :4 0
120 :2 0 8a :2 0
49 :2 0 893 ec7
ec9 :3 0 896 ec3
ecb ec0 ecd ecc
:2 0 7b :3 0 8b
:3 0 ecf ed0 0
7d :4 0 121 :4 0
80 :2 0 81 :3 0
89a ed4 ed6 :3 0
80 :2 0 94 :4 0
89d ed8 eda :3 0
80 :2 0 b1 :4 0
8a0 edc ede :3 0
80 :2 0 ac :3 0
8a3 ee0 ee2 :3 0
80 :2 0 b2 :4 0
8a6 ee4 ee6 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 8a9 ee9
eed 8ad ee8 eef
:3 0 8b0 ed1 ef1
:2 0 ef3 8b3 ef4
ece ef3 0 ef5
8b5 0 ef6 8b7
ef9 :3 0 ef9 0
ef9 ef8 ef6 ef7
:6 0 efb 1e :3 0
8ba efd 8bc efc
efb :2 0 efe 8be
:2 0 f00 0 f00
eff ead efe :6 0
10b6 1 :3 0 54
:3 0 122 :3 0 52
:3 0 2e :3 0 29
:3 0 30 :3 0 2f
:3 0 2a :3 0 8c1
f03 f0a f02 f0b
0 10b6 85 :3 0
54 :3 0 31 :2 0
8c8 f0d f10 a4
:2 0 31 :2 0 8cd
f12 f14 :3 0 26
:4 0 f16 f17 0
10b3 28 :4 0 f19
f1a 0 10b3 1d
:4 0 f1c f1d 0
10b3 24 :4 0 f1f
f20 0 10b3 1f
:4 0 f22 f23 0
10b3 123 :3 0 63
:4 0 f28 :2 0 10b3
f26 f29 :3 0 63
:3 0 1d :3 0 24
:4 0 f2e :2 0 10b3
f2a f2f :3 0 8d0
:3 0 63 :3 0 fc
:3 0 f30 f31 :3 0
1b :3 0 ab :3 0
f33 f34 0 31
:2 0 f35 f36 0
f38 8d3 f3f 1b
:3 0 ab :3 0 f39
f3a 0 fd :2 0
f3b f3c 0 f3e
8d5 f40 f32 f38
0 f41 0 f3e
0 f41 8d7 0
10b3 124 :3 0 63
:4 0 f45 :2 0 f4b
f43 0 1b :3 0
ab :3 0 f46 f47
0 ac :3 0 f48
f49 0 f4b 8da
f9e ad :3 0 1b
:3 0 ab :3 0 f4d
f4e 0 ac :3 0
f4f f50 0 f52
8dd f54 8df f53
f52 :2 0 f9c ae
:3 0 1b :3 0 ab
:3 0 f57 f58 0
ac :3 0 f59 f5a
0 f94 78 :3 0
79 :3 0 f5c f5d
0 78 :3 0 88
:3 0 f5f f60 0
25 :2 0 2 :4 0
125 :2 0 8a :2 0
49 :2 0 8e1 f65
f67 :3 0 8e4 f61
f69 f5e f6b f6a
:2 0 7b :3 0 8b
:3 0 f6d f6e 0
7d :4 0 126 :4 0
80 :2 0 81 :3 0
8e8 f72 f74 :3 0
80 :2 0 94 :4 0
8eb f76 f78 :3 0
80 :2 0 b1 :4 0
8ee f7a f7c :3 0
80 :2 0 ac :3 0
8f1 f7e f80 :3 0
80 :2 0 b2 :4 0
8f4 f82 f84 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 8f7 f87
f8b 8fb f86 f8d
:3 0 8fe f6f f8f
:2 0 f91 901 f92
f6c f91 0 f93
903 0 f94 905
f97 :3 0 f97 0
f97 f96 f94 f95
:6 0 f99 20 :3 0
908 f9b 90a f9a
f99 :2 0 f9c 90c
:2 0 f9e 0 f9e
f9d f4b f9c :6 0
10b3 1 :3 0 127
:3 0 1f :3 0 128
:3 0 cc :3 0 2c
:4 0 129 1 :8 0
fab 1b :3 0 ab
:3 0 fa6 fa7 0
ac :3 0 fa8 fa9
0 fab 90f ffe
ad :3 0 1b :3 0
ab :3 0 fad fae
0 ac :3 0 faf
fb0 0 fb2 912
fb4 914 fb3 fb2
:2 0 ffc ae :3 0
1b :3 0 ab :3 0
fb7 fb8 0 ac
:3 0 fb9 fba 0
ff4 78 :3 0 79
:3 0 fbc fbd 0
78 :3 0 88 :3 0
fbf fc0 0 25
:2 0 2 :4 0 12a
:2 0 8a :2 0 49
:2 0 916 fc5 fc7
:3 0 919 fc1 fc9
fbe fcb fca :2 0
7b :3 0 8b :3 0
fcd fce 0 7d
:4 0 12b :4 0 80
:2 0 81 :3 0 91d
fd2 fd4 :3 0 80
:2 0 94 :4 0 920
fd6 fd8 :3 0 80
:2 0 b1 :4 0 923
fda fdc :3 0 80
:2 0 ac :3 0 926
fde fe0 :3 0 80
:2 0 b2 :4 0 929
fe2 fe4 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 92c fe7 feb
930 fe6 fed :3 0
933 fcf fef :2 0
ff1 936 ff2 fcc
ff1 0 ff3 938
0 ff4 93a ff7
:3 0 ff7 0 ff7
ff6 ff4 ff5 :6 0
ff9 22 :3 0 93d
ffb 93f ffa ff9
:2 0 ffc 941 :2 0
ffe 0 ffe ffd
fab ffc :6 0 10b3
1 :3 0 22 :3 0
12c :4 0 1000 1001
0 10b3 20 :3 0
12d :4 0 1003 1004
0 10b3 20 :3 0
b3 :3 0 20 :3 0
80 :2 0 1f :3 0
944 1009 100b :3 0
49 :2 0 21 :2 0
947 1007 100f 1006
1010 0 10b3 20
:3 0 b3 :3 0 20
:3 0 80 :2 0 12e
:4 0 94b 1015 1017
:3 0 49 :2 0 21
:2 0 94e 1013 101b
1012 101c 0 10b3
20 :3 0 b3 :3 0
20 :3 0 80 :2 0
1d :3 0 952 1021
1023 :3 0 49 :2 0
21 :2 0 955 101f
1027 101e 1028 0
10b3 20 :3 0 b3
:3 0 20 :3 0 80
:2 0 12f :4 0 959
102d 102f :3 0 49
:2 0 21 :2 0 95c
102b 1033 102a 1034
0 10b3 54 :3 0
130 :3 0 2a :3 0
24 :3 0 33 :3 0
33 :3 0 48 :3 0
33 :3 0 22 :3 0
20 :3 0 2f :3 0
48 :3 0 48 :3 0
33 :3 0 26 :3 0
28 :3 0 2f :3 0
960 1037 1047 1036
1048 0 10b3 78
:3 0 79 :3 0 104a
104b 0 78 :3 0
88 :3 0 104d 104e
0 27 :2 0 2
:4 0 131 :2 0 8a
:2 0 49 :2 0 970
1053 1055 :3 0 973
104f 1057 104c 1059
1058 :2 0 7b :3 0
8b :3 0 105b 105c
0 7d :4 0 132
:4 0 80 :2 0 81
:3 0 977 1060 1062
:3 0 80 :2 0 94
:4 0 97a 1064 1066
:3 0 80 :2 0 95
:4 0 97d 1068 106a
:3 0 80 :2 0 85
:3 0 66 :3 0 31
:2 0 980 106e 1070
86 :4 0 982 106d
1073 985 106c 1075
:3 0 80 :2 0 da
:4 0 988 1077 1079
:3 0 80 :2 0 83
:4 0 98b 107b 107d
:3 0 80 :2 0 2b
:3 0 98e 107f 1081
:3 0 80 :2 0 83
:4 0 991 1083 1085
:3 0 994 105d 1087
:2 0 1089 997 108a
105a 1089 0 108b
999 0 10b3 78
:3 0 79 :3 0 108c
108d 0 78 :3 0
88 :3 0 108f 1090
0 49 :2 0 2
:4 0 133 :2 0 8a
:2 0 49 :2 0 99b
1095 1097 :3 0 99e
1091 1099 108e 109b
109a :2 0 7b :3 0
8b :3 0 109d 109e
0 7d :4 0 134
:4 0 80 :2 0 81
:3 0 9a2 10a2 10a4
:3 0 9a5 109f 10a6
:2 0 10a8 9a8 10a9
109c 10a8 0 10aa
9aa 0 10b3 9a
:3 0 dd :3 0 10ab
10ac 0 31 :2 0
2b :3 0 9c :3 0
9ac 10ad 10b1 :2 0
10b3 9b0 10b4 f15
10b3 0 10b5 9c5
0 10b6 9c7 10b7
e9a 10b6 0 10b8
9cd 0 10b9 9cf
10ba e26 10b9 0
10bb 9d3 0 1178
3c :3 0 85 :3 0
3c :3 0 31 :2 0
9d5 10bd 10c0 8a
:2 0 49 :2 0 9d8
10c2 10c4 :3 0 10bc
10c5 0 1178 1b
:3 0 ab :3 0 10c7
10c8 0 f3 :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
41 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 9db 10ca
10dc 10c9 10dd 0
1178 1b :3 0 ab
:3 0 10df 10e0 0
a4 :2 0 31 :2 0
9ef 10e2 10e4 :3 0
10e5 :2 0 85 :3 0
f :3 0 31 :2 0
9f2 10e7 10ea a4
:2 0 35 :2 0 9f7
10ec 10ee :3 0 10ef
:2 0 10e6 10f1 10f0
:2 0 85 :3 0 3e
:3 0 31 :2 0 9fa
10f3 10f6 a4 :2 0
31 :2 0 9ff 10f8
10fa :3 0 10fb :2 0
10f2 10fd 10fc :2 0
d3 :3 0 f4 :3 0
e :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 74 :3 0
2b :4 0 110 1
:8 0 1120 fc :4 0
110b :3 0 9c :3 0
a4 :2 0 a04 110e
110f :3 0 1b :3 0
ab :3 0 1111 1112
0 31 :2 0 1113
1114 0 1116 a07
111d 1b :3 0 ab
:3 0 1117 1118 0
fd :2 0 1119 111a
0 111c a09 111e
1110 1116 0 111f
0 111c 0 111f
a0b 0 1120 a0e
1173 ad :3 0 1b
:3 0 ab :3 0 1122
1123 0 ac :3 0
1124 1125 0 1127
a11 1129 a13 1128
1127 :2 0 1171 ae
:3 0 1b :3 0 ab
:3 0 112c 112d 0
ac :3 0 112e 112f
0 1169 78 :3 0
79 :3 0 1131 1132
0 78 :3 0 88
:3 0 1134 1135 0
25 :2 0 2 :4 0
135 :2 0 8a :2 0
49 :2 0 a15 113a
113c :3 0 a18 1136
113e 1133 1140 113f
:2 0 7b :3 0 8b
:3 0 1142 1143 0
7d :4 0 136 :4 0
80 :2 0 81 :3 0
a1c 1147 1149 :3 0
80 :2 0 94 :4 0
a1f 114b 114d :3 0
80 :2 0 b1 :4 0
a22 114f 1151 :3 0
80 :2 0 ac :3 0
a25 1153 1155 :3 0
80 :2 0 b2 :4 0
a28 1157 1159 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 a2b 115c
1160 a2f 115b 1162
:3 0 a32 1144 1164
:2 0 1166 a35 1167
1141 1166 0 1168
a37 0 1169 a39
116c :3 0 116c 0
116c 116b 1169 116a
:6 0 116e 24 :3 0
a3c 1170 a3e 116f
116e :2 0 1171 a40
:2 0 1173 0 1173
1172 1120 1171 :6 0
1175 1 :3 0 a43
1176 10fe 1175 0
1177 a45 0 1178
a47 117a d6b e21
0 117b 0 1178
0 117b a4c 0
117c a4f 117e 999
d55 0 117f 0
117c 0 117f a52
0 1d70 1b :3 0
ab :3 0 1180 1181
0 c0 :2 0 31
:2 0 a57 1183 1185
:3 0 78 :3 0 79
:3 0 1187 1188 0
78 :3 0 88 :3 0
118a 118b 0 27
:2 0 2 :4 0 137
:2 0 8a :2 0 49
:2 0 a5a 1190 1192
:3 0 a5d 118c 1194
1189 1196 1195 :2 0
7b :3 0 8b :3 0
1198 1199 0 7d
:4 0 138 :4 0 80
:2 0 81 :3 0 a61
119d 119f :3 0 80
:2 0 94 :4 0 a64
11a1 11a3 :3 0 80
:2 0 95 :4 0 a67
11a5 11a7 :3 0 80
:2 0 85 :3 0 66
:3 0 1b :3 0 ab
:3 0 11ac 11ad 0
a6a 11ab 11af 86
:4 0 a6c 11aa 11b2
a6f 11a9 11b4 :3 0
80 :2 0 da :4 0
a72 11b6 11b8 :3 0
80 :2 0 83 :4 0
a75 11ba 11bc :3 0
80 :2 0 2b :3 0
a78 11be 11c0 :3 0
80 :2 0 83 :4 0
a7b 11c2 11c4 :3 0
a7e 119a 11c6 :2 0
11c8 a81 11c9 1197
11c8 0 11ca a83
0 11f4 78 :3 0
79 :3 0 11cb 11cc
0 78 :3 0 88
:3 0 11ce 11cf 0
49 :2 0 2 :4 0
139 :2 0 8a :2 0
49 :2 0 a85 11d4
11d6 :3 0 a88 11d0
11d8 11cd 11da 11d9
:2 0 7b :3 0 8b
:3 0 11dc 11dd 0
7d :4 0 13a :4 0
80 :2 0 81 :3 0
a8c 11e1 11e3 :3 0
a8f 11de 11e5 :2 0
11e7 a92 11e8 11db
11e7 0 11e9 a94
0 11f4 9a :3 0
dd :3 0 11ea 11eb
0 1b :3 0 ab
:3 0 11ed 11ee 0
2b :3 0 9c :3 0
a96 11ec 11f2 :2 0
11f4 a9a 11f5 1186
11f4 0 11f6 a9e
0 1d70 38 :3 0
11 :3 0 11f7 11f8
0 1d70 85 :3 0
39 :3 0 31 :2 0
aa0 11fa 11fd c0
:2 0 f0 :2 0 aa5
11ff 1201 :3 0 1202
:2 0 85 :3 0 38
:3 0 31 :2 0 aa8
1204 1207 a4 :2 0
31 :2 0 aad 1209
120b :3 0 120c :2 0
1203 120e 120d :2 0
38 :3 0 49 :2 0
1210 1211 0 1213
ab0 1214 120f 1213
0 1215 ab2 0
1d70 85 :3 0 57
:3 0 31 :2 0 ab4
1216 1219 a4 :2 0
49 :2 0 ab9 121b
121d :3 0 f2 :3 0
85 :3 0 f :3 0
31 :2 0 abc 1220
1223 25 :2 0 abf
121f 1226 1227 :2 0
a4 :2 0 25 :2 0
ac4 1229 122b :3 0
12 :3 0 8d :2 0
ac7 122e 122f :3 0
1230 :2 0 4d :3 0
c3 :2 0 ac9 1233
1234 :3 0 1235 :2 0
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 104 :3 0
16 :3 0 105 :3 0
17 :3 0 cd :3 0
18 :3 0 13b :3 0
2b :4 0 13c 1
:8 0 1262 fc :4 0
124d :3 0 9c :3 0
a4 :2 0 acd 1250
1251 :3 0 1b :3 0
ab :3 0 1253 1254
0 31 :2 0 1255
1256 0 1258 ad0
125f 1b :3 0 ab
:3 0 1259 125a 0
fd :2 0 125b 125c
0 125e ad2 1260
1252 1258 0 1261
0 125e 0 1261
ad4 0 1262 ad7
12b5 ad :3 0 1b
:3 0 ab :3 0 1264
1265 0 ac :3 0
1266 1267 0 1269
ada 126b adc 126a
1269 :2 0 12b3 ae
:3 0 1b :3 0 ab
:3 0 126e 126f 0
ac :3 0 1270 1271
0 12ab 78 :3 0
79 :3 0 1273 1274
0 78 :3 0 88
:3 0 1276 1277 0
25 :2 0 2 :4 0
13d :2 0 8a :2 0
49 :2 0 ade 127c
127e :3 0 ae1 1278
1280 1275 1282 1281
:2 0 7b :3 0 8b
:3 0 1284 1285 0
7d :4 0 13e :4 0
80 :2 0 81 :3 0
ae5 1289 128b :3 0
80 :2 0 94 :4 0
ae8 128d 128f :3 0
80 :2 0 b1 :4 0
aeb 1291 1293 :3 0
80 :2 0 ac :3 0
aee 1295 1297 :3 0
80 :2 0 b2 :4 0
af1 1299 129b :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 af4 129e
12a2 af8 129d 12a4
:3 0 afb 1286 12a6
:2 0 12a8 afe 12a9
1283 12a8 0 12aa
b00 0 12ab b02
12ae :3 0 12ae 0
12ae 12ad 12ab 12ac
:6 0 12b0 26 :3 0
b05 12b2 b07 12b1
12b0 :2 0 12b3 b09
:2 0 12b5 0 12b5
12b4 1262 12b3 :6 0
12b7 1 :3 0 b0c
132d d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 13b
:3 0 2b :4 0 13f
1 :8 0 12d7 fc
:4 0 12c2 :3 0 9c
:3 0 a4 :2 0 b10
12c5 12c6 :3 0 1b
:3 0 ab :3 0 12c8
12c9 0 31 :2 0
12ca 12cb 0 12cd
b13 12d4 1b :3 0
ab :3 0 12ce 12cf
0 fd :2 0 12d0
12d1 0 12d3 b15
12d5 12c7 12cd 0
12d6 0 12d3 0
12d6 b17 0 12d7
b1a 132a ad :3 0
1b :3 0 ab :3 0
12d9 12da 0 ac
:3 0 12db 12dc 0
12de b1d 12e0 b1f
12df 12de :2 0 1328
ae :3 0 1b :3 0
ab :3 0 12e3 12e4
0 ac :3 0 12e5
12e6 0 1320 78
:3 0 79 :3 0 12e8
12e9 0 78 :3 0
88 :3 0 12eb 12ec
0 25 :2 0 2
:4 0 140 :2 0 8a
:2 0 49 :2 0 b21
12f1 12f3 :3 0 b24
12ed 12f5 12ea 12f7
12f6 :2 0 7b :3 0
8b :3 0 12f9 12fa
0 7d :4 0 141
:4 0 80 :2 0 81
:3 0 b28 12fe 1300
:3 0 80 :2 0 94
:4 0 b2b 1302 1304
:3 0 80 :2 0 b1
:4 0 b2e 1306 1308
:3 0 80 :2 0 ac
:3 0 b31 130a 130c
:3 0 80 :2 0 b2
:4 0 b34 130e 1310
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 b37
1313 1317 b3b 1312
1319 :3 0 b3e 12fb
131b :2 0 131d b41
131e 12f8 131d 0
131f b43 0 1320
b45 1323 :3 0 1323
0 1323 1322 1320
1321 :6 0 1325 28
:3 0 b48 1327 b4a
1326 1325 :2 0 1328
b4c :2 0 132a 0
132a 1329 12d7 1328
:6 0 132c 1 :3 0
b4f 132e 1236 12b7
0 132f 0 132c
0 132f b51 0
1330 b54 1486 4d
:3 0 c3 :2 0 b56
1332 1333 :3 0 1334
:2 0 d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 142
:3 0 143 :3 0 c4
:3 0 12 :3 0 142
:3 0 144 :3 0 143
:3 0 c4 :3 0 13
:3 0 144 :3 0 145
:3 0 143 :3 0 14
:3 0 145 :3 0 146
:3 0 143 :3 0 15
:3 0 146 :3 0 147
:3 0 148 :3 0 149
:3 0 14a :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 148
:3 0 12 :3 0 14a
:3 0 13 :3 0 14c
:3 0 14 :3 0 14e
:3 0 15 :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 153
:3 0 154 :3 0 155
:3 0 156 :3 0 143
:3 0 f5 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 104 :3 0 16
:3 0 105 :3 0 17
:3 0 cd :3 0 18
:3 0 13b :3 0 2b
:4 0 157 1 :8 0
138c fc :4 0 1377
:3 0 9c :3 0 a4
:2 0 b5a 137a 137b
:3 0 1b :3 0 ab
:3 0 137d 137e 0
31 :2 0 137f 1380
0 1382 b5d 1389
1b :3 0 ab :3 0
1383 1384 0 fd
:2 0 1385 1386 0
1388 b5f 138a 137c
1382 0 138b 0
1388 0 138b b61
0 138c b64 13df
ad :3 0 1b :3 0
ab :3 0 138e 138f
0 ac :3 0 1390
1391 0 1393 b67
1395 b69 1394 1393
:2 0 13dd ae :3 0
1b :3 0 ab :3 0
1398 1399 0 ac
:3 0 139a 139b 0
13d5 78 :3 0 79
:3 0 139d 139e 0
78 :3 0 88 :3 0
13a0 13a1 0 25
:2 0 2 :4 0 158
:2 0 8a :2 0 49
:2 0 b6b 13a6 13a8
:3 0 b6e 13a2 13aa
139f 13ac 13ab :2 0
7b :3 0 8b :3 0
13ae 13af 0 7d
:4 0 159 :4 0 80
:2 0 81 :3 0 b72
13b3 13b5 :3 0 80
:2 0 94 :4 0 b75
13b7 13b9 :3 0 80
:2 0 b1 :4 0 b78
13bb 13bd :3 0 80
:2 0 ac :3 0 b7b
13bf 13c1 :3 0 80
:2 0 b2 :4 0 b7e
13c3 13c5 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 b81 13c8 13cc
b85 13c7 13ce :3 0
b88 13b0 13d0 :2 0
13d2 b8b 13d3 13ad
13d2 0 13d4 b8d
0 13d5 b8f 13d8
:3 0 13d8 0 13d8
13d7 13d5 13d6 :6 0
13da 2a :3 0 b92
13dc b94 13db 13da
:2 0 13dd b96 :2 0
13df 0 13df 13de
138c 13dd :6 0 13e1
1 :3 0 b99 1482
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 142 :3 0
143 :3 0 c4 :3 0
12 :3 0 142 :3 0
144 :3 0 143 :3 0
c4 :3 0 13 :3 0
144 :3 0 145 :3 0
143 :3 0 14 :3 0
145 :3 0 146 :3 0
143 :3 0 15 :3 0
146 :3 0 147 :3 0
148 :3 0 149 :3 0
14a :3 0 14b :3 0
14c :3 0 14d :3 0
14e :3 0 148 :3 0
12 :3 0 14a :3 0
13 :3 0 14c :3 0
14 :3 0 14e :3 0
15 :3 0 14f :3 0
150 :3 0 151 :3 0
152 :3 0 153 :3 0
154 :3 0 155 :3 0
156 :3 0 143 :3 0
13b :3 0 2b :4 0
15a 1 :8 0 142c
fc :4 0 1417 :3 0
9c :3 0 a4 :2 0
b9d 141a 141b :3 0
1b :3 0 ab :3 0
141d 141e 0 31
:2 0 141f 1420 0
1422 ba0 1429 1b
:3 0 ab :3 0 1423
1424 0 fd :2 0
1425 1426 0 1428
ba2 142a 141c 1422
0 142b 0 1428
0 142b ba4 0
142c ba7 147f ad
:3 0 1b :3 0 ab
:3 0 142e 142f 0
ac :3 0 1430 1431
0 1433 baa 1435
bac 1434 1433 :2 0
147d ae :3 0 1b
:3 0 ab :3 0 1438
1439 0 ac :3 0
143a 143b 0 1475
78 :3 0 79 :3 0
143d 143e 0 78
:3 0 88 :3 0 1440
1441 0 25 :2 0
2 :4 0 15b :2 0
8a :2 0 49 :2 0
bae 1446 1448 :3 0
bb1 1442 144a 143f
144c 144b :2 0 7b
:3 0 8b :3 0 144e
144f 0 7d :4 0
15c :4 0 80 :2 0
81 :3 0 bb5 1453
1455 :3 0 80 :2 0
94 :4 0 bb8 1457
1459 :3 0 80 :2 0
b1 :4 0 bbb 145b
145d :3 0 80 :2 0
ac :3 0 bbe 145f
1461 :3 0 80 :2 0
b2 :4 0 bc1 1463
1465 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
bc4 1468 146c bc8
1467 146e :3 0 bcb
1450 1470 :2 0 1472
bce 1473 144d 1472
0 1474 bd0 0
1475 bd2 1478 :3 0
1478 0 1478 1477
1475 1476 :6 0 147a
2c :3 0 bd5 147c
bd7 147b 147a :2 0
147d bd9 :2 0 147f
0 147f 147e 142c
147d :6 0 1481 1
:3 0 bdc 1483 1335
13e1 0 1484 0
1481 0 1484 bde
0 1485 be1 1487
1231 1330 0 1488
0 1485 0 1488
be3 0 148a 15d
:3 0 be6 150a 85
:3 0 3e :3 0 31
:2 0 be8 148b 148e
a4 :2 0 31 :2 0
bed 1490 1492 :3 0
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 13b :3 0
2b :4 0 15e 1
:8 0 14b3 fc :4 0
149e :3 0 9c :3 0
a4 :2 0 bf2 14a1
14a2 :3 0 1b :3 0
ab :3 0 14a4 14a5
0 31 :2 0 14a6
14a7 0 14a9 bf5
14b0 1b :3 0 ab
:3 0 14aa 14ab 0
fd :2 0 14ac 14ad
0 14af bf7 14b1
14a3 14a9 0 14b2
0 14af 0 14b2
bf9 0 14b3 bfc
1506 ad :3 0 1b
:3 0 ab :3 0 14b5
14b6 0 ac :3 0
14b7 14b8 0 14ba
bff 14bc c01 14bb
14ba :2 0 1504 ae
:3 0 1b :3 0 ab
:3 0 14bf 14c0 0
ac :3 0 14c1 14c2
0 14fc 78 :3 0
79 :3 0 14c4 14c5
0 78 :3 0 88
:3 0 14c7 14c8 0
25 :2 0 2 :4 0
15f :2 0 8a :2 0
49 :2 0 c03 14cd
14cf :3 0 c06 14c9
14d1 14c6 14d3 14d2
:2 0 7b :3 0 8b
:3 0 14d5 14d6 0
7d :4 0 160 :4 0
80 :2 0 81 :3 0
c0a 14da 14dc :3 0
80 :2 0 94 :4 0
c0d 14de 14e0 :3 0
80 :2 0 b1 :4 0
c10 14e2 14e4 :3 0
80 :2 0 ac :3 0
c13 14e6 14e8 :3 0
80 :2 0 b2 :4 0
c16 14ea 14ec :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 c19 14ef
14f3 c1d 14ee 14f5
:3 0 c20 14d7 14f7
:2 0 14f9 c23 14fa
14d4 14f9 0 14fb
c25 0 14fc c27
14ff :3 0 14ff 0
14ff 14fe 14fc 14fd
:6 0 1501 2e :3 0
c2a 1503 c2c 1502
1501 :2 0 1504 c2e
:2 0 1506 0 1506
1505 14b3 1504 :6 0
1508 1 :3 0 c31
1509 1493 1508 0
150b 122c 148a 0
150b c33 0 150c
c36 1908 f2 :3 0
85 :3 0 f :3 0
31 :2 0 c38 150e
1511 25 :2 0 c3b
150d 1514 1515 :2 0
a4 :2 0 25 :2 0
c40 1517 1519 :3 0
12 :3 0 8d :2 0
c43 151c 151d :3 0
151e :2 0 4d :3 0
c3 :2 0 c45 1521
1522 :3 0 1523 :2 0
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 104 :3 0
16 :3 0 105 :3 0
17 :3 0 cd :3 0
18 :3 0 74 :3 0
2b :4 0 161 1
:8 0 1550 fc :4 0
153b :3 0 9c :3 0
a4 :2 0 c49 153e
153f :3 0 1b :3 0
ab :3 0 1541 1542
0 31 :2 0 1543
1544 0 1546 c4c
154d 1b :3 0 ab
:3 0 1547 1548 0
fd :2 0 1549 154a
0 154c c4e 154e
1540 1546 0 154f
0 154c 0 154f
c50 0 1550 c53
15a3 ad :3 0 1b
:3 0 ab :3 0 1552
1553 0 ac :3 0
1554 1555 0 1557
c56 1559 c58 1558
1557 :2 0 15a1 ae
:3 0 1b :3 0 ab
:3 0 155c 155d 0
ac :3 0 155e 155f
0 1599 78 :3 0
79 :3 0 1561 1562
0 78 :3 0 88
:3 0 1564 1565 0
25 :2 0 2 :4 0
162 :2 0 8a :2 0
49 :2 0 c5a 156a
156c :3 0 c5d 1566
156e 1563 1570 156f
:2 0 7b :3 0 8b
:3 0 1572 1573 0
7d :4 0 163 :4 0
80 :2 0 81 :3 0
c61 1577 1579 :3 0
80 :2 0 94 :4 0
c64 157b 157d :3 0
80 :2 0 b1 :4 0
c67 157f 1581 :3 0
80 :2 0 ac :3 0
c6a 1583 1585 :3 0
80 :2 0 b2 :4 0
c6d 1587 1589 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 c70 158c
1590 c74 158b 1592
:3 0 c77 1574 1594
:2 0 1596 c7a 1597
1571 1596 0 1598
c7c 0 1599 c7e
159c :3 0 159c 0
159c 159b 1599 159a
:6 0 159e 30 :3 0
c81 15a0 c83 159f
159e :2 0 15a1 c85
:2 0 15a3 0 15a3
15a2 1550 15a1 :6 0
15a5 1 :3 0 c88
161d d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 cd
:3 0 c :3 0 74
:3 0 2b :4 0 164
1 :8 0 15c7 fc
:4 0 15b2 :3 0 9c
:3 0 a4 :2 0 c8c
15b5 15b6 :3 0 1b
:3 0 ab :3 0 15b8
15b9 0 31 :2 0
15ba 15bb 0 15bd
c8f 15c4 1b :3 0
ab :3 0 15be 15bf
0 fd :2 0 15c0
15c1 0 15c3 c91
15c5 15b7 15bd 0
15c6 0 15c3 0
15c6 c93 0 15c7
c96 161a ad :3 0
1b :3 0 ab :3 0
15c9 15ca 0 ac
:3 0 15cb 15cc 0
15ce c99 15d0 c9b
15cf 15ce :2 0 1618
ae :3 0 1b :3 0
ab :3 0 15d3 15d4
0 ac :3 0 15d5
15d6 0 1610 78
:3 0 79 :3 0 15d8
15d9 0 78 :3 0
88 :3 0 15db 15dc
0 25 :2 0 2
:4 0 165 :2 0 8a
:2 0 49 :2 0 c9d
15e1 15e3 :3 0 ca0
15dd 15e5 15da 15e7
15e6 :2 0 7b :3 0
8b :3 0 15e9 15ea
0 7d :4 0 166
:4 0 80 :2 0 81
:3 0 ca4 15ee 15f0
:3 0 80 :2 0 94
:4 0 ca7 15f2 15f4
:3 0 80 :2 0 b1
:4 0 caa 15f6 15f8
:3 0 80 :2 0 ac
:3 0 cad 15fa 15fc
:3 0 80 :2 0 b2
:4 0 cb0 15fe 1600
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 cb3
1603 1607 cb7 1602
1609 :3 0 cba 15eb
160b :2 0 160d cbd
160e 15e8 160d 0
160f cbf 0 1610
cc1 1613 :3 0 1613
0 1613 1612 1610
1611 :6 0 1615 32
:3 0 cc4 1617 cc6
1616 1615 :2 0 1618
cc8 :2 0 161a 0
161a 1619 15c7 1618
:6 0 161c 1 :3 0
ccb 161e 1524 15a5
0 161f 0 161c
0 161f ccd 0
1620 cd0 1778 4d
:3 0 c3 :2 0 cd2
1622 1623 :3 0 1624
:2 0 d3 :3 0 103
:3 0 d :3 0 cf
:3 0 39 :3 0 d2
:3 0 38 :3 0 142
:3 0 143 :3 0 c4
:3 0 12 :3 0 142
:3 0 144 :3 0 143
:3 0 c4 :3 0 13
:3 0 144 :3 0 145
:3 0 143 :3 0 14
:3 0 145 :3 0 146
:3 0 143 :3 0 15
:3 0 146 :3 0 147
:3 0 148 :3 0 149
:3 0 14a :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 148
:3 0 12 :3 0 14a
:3 0 13 :3 0 14c
:3 0 14 :3 0 14e
:3 0 15 :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 153
:3 0 154 :3 0 155
:3 0 156 :3 0 143
:3 0 f5 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 104 :3 0 16
:3 0 105 :3 0 17
:3 0 cd :3 0 18
:3 0 74 :3 0 2b
:4 0 167 1 :8 0
167c fc :4 0 1667
:3 0 9c :3 0 a4
:2 0 cd6 166a 166b
:3 0 1b :3 0 ab
:3 0 166d 166e 0
31 :2 0 166f 1670
0 1672 cd9 1679
1b :3 0 ab :3 0
1673 1674 0 fd
:2 0 1675 1676 0
1678 cdb 167a 166c
1672 0 167b 0
1678 0 167b cdd
0 167c ce0 16cf
ad :3 0 1b :3 0
ab :3 0 167e 167f
0 ac :3 0 1680
1681 0 1683 ce3
1685 ce5 1684 1683
:2 0 16cd ae :3 0
1b :3 0 ab :3 0
1688 1689 0 ac
:3 0 168a 168b 0
16c5 78 :3 0 79
:3 0 168d 168e 0
78 :3 0 88 :3 0
1690 1691 0 25
:2 0 2 :4 0 168
:2 0 8a :2 0 49
:2 0 ce7 1696 1698
:3 0 cea 1692 169a
168f 169c 169b :2 0
7b :3 0 8b :3 0
169e 169f 0 7d
:4 0 169 :4 0 80
:2 0 81 :3 0 cee
16a3 16a5 :3 0 80
:2 0 94 :4 0 cf1
16a7 16a9 :3 0 80
:2 0 b1 :4 0 cf4
16ab 16ad :3 0 80
:2 0 ac :3 0 cf7
16af 16b1 :3 0 80
:2 0 b2 :4 0 cfa
16b3 16b5 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 cfd 16b8 16bc
d01 16b7 16be :3 0
d04 16a0 16c0 :2 0
16c2 d07 16c3 169d
16c2 0 16c4 d09
0 16c5 d0b 16c8
:3 0 16c8 0 16c8
16c7 16c5 16c6 :6 0
16ca 34 :3 0 d0e
16cc d10 16cb 16ca
:2 0 16cd d12 :2 0
16cf 0 16cf 16ce
167c 16cd :6 0 16d1
1 :3 0 d15 1774
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 cd :3 0
c :3 0 142 :3 0
143 :3 0 c4 :3 0
12 :3 0 142 :3 0
144 :3 0 143 :3 0
c4 :3 0 13 :3 0
144 :3 0 145 :3 0
143 :3 0 14 :3 0
145 :3 0 146 :3 0
143 :3 0 15 :3 0
146 :3 0 147 :3 0
148 :3 0 149 :3 0
14a :3 0 14b :3 0
14c :3 0 14d :3 0
14e :3 0 148 :3 0
12 :3 0 14a :3 0
13 :3 0 14c :3 0
14 :3 0 14e :3 0
15 :3 0 14f :3 0
150 :3 0 151 :3 0
152 :3 0 153 :3 0
154 :3 0 155 :3 0
156 :3 0 143 :3 0
74 :3 0 2b :4 0
16a 1 :8 0 171e
fc :4 0 1709 :3 0
9c :3 0 a4 :2 0
d19 170c 170d :3 0
1b :3 0 ab :3 0
170f 1710 0 31
:2 0 1711 1712 0
1714 d1c 171b 1b
:3 0 ab :3 0 1715
1716 0 fd :2 0
1717 1718 0 171a
d1e 171c 170e 1714
0 171d 0 171a
0 171d d20 0
171e d23 1771 ad
:3 0 1b :3 0 ab
:3 0 1720 1721 0
ac :3 0 1722 1723
0 1725 d26 1727
d28 1726 1725 :2 0
176f ae :3 0 1b
:3 0 ab :3 0 172a
172b 0 ac :3 0
172c 172d 0 1767
78 :3 0 79 :3 0
172f 1730 0 78
:3 0 88 :3 0 1732
1733 0 25 :2 0
2 :4 0 16b :2 0
8a :2 0 49 :2 0
d2a 1738 173a :3 0
d2d 1734 173c 1731
173e 173d :2 0 7b
:3 0 8b :3 0 1740
1741 0 7d :4 0
16c :4 0 80 :2 0
81 :3 0 d31 1745
1747 :3 0 80 :2 0
94 :4 0 d34 1749
174b :3 0 80 :2 0
b1 :4 0 d37 174d
174f :3 0 80 :2 0
ac :3 0 d3a 1751
1753 :3 0 80 :2 0
b2 :4 0 d3d 1755
1757 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
d40 175a 175e d44
1759 1760 :3 0 d47
1742 1762 :2 0 1764
d4a 1765 173f 1764
0 1766 d4c 0
1767 d4e 176a :3 0
176a 0 176a 1769
1767 1768 :6 0 176c
36 :3 0 d51 176e
d53 176d 176c :2 0
176f d55 :2 0 1771
0 1771 1770 171e
176f :6 0 1773 1
:3 0 d58 1775 1625
16d1 0 1776 0
1773 0 1776 d5a
0 1777 d5d 1779
151f 1620 0 177a
0 1777 0 177a
d5f 0 177c 15d
:3 0 d62 1905 85
:3 0 3e :3 0 31
:2 0 d64 177d 1780
a4 :2 0 31 :2 0
d69 1782 1784 :3 0
47 :3 0 8d :2 0
d6c 1787 1788 :3 0
1789 :2 0 85 :3 0
e :3 0 31 :2 0
d6e 178b 178e a4
:2 0 31 :2 0 d73
1790 1792 :3 0 d3
:3 0 103 :3 0 d
:3 0 cf :3 0 39
:3 0 d2 :3 0 38
:3 0 cd :3 0 c
:3 0 f4 :3 0 3d
:3 0 c :3 0 74
:3 0 2b :4 0 16d
1 :8 0 17b8 fc
:4 0 17a3 :3 0 9c
:3 0 a4 :2 0 d78
17a6 17a7 :3 0 1b
:3 0 ab :3 0 17a9
17aa 0 31 :2 0
17ab 17ac 0 17ae
d7b 17b5 1b :3 0
ab :3 0 17af 17b0
0 fd :2 0 17b1
17b2 0 17b4 d7d
17b6 17a8 17ae 0
17b7 0 17b4 0
17b7 d7f 0 17b8
d82 180b ad :3 0
1b :3 0 ab :3 0
17ba 17bb 0 ac
:3 0 17bc 17bd 0
17bf d85 17c1 d87
17c0 17bf :2 0 1809
ae :3 0 1b :3 0
ab :3 0 17c4 17c5
0 ac :3 0 17c6
17c7 0 1801 78
:3 0 79 :3 0 17c9
17ca 0 78 :3 0
88 :3 0 17cc 17cd
0 25 :2 0 2
:4 0 16e :2 0 8a
:2 0 49 :2 0 d89
17d2 17d4 :3 0 d8c
17ce 17d6 17cb 17d8
17d7 :2 0 7b :3 0
8b :3 0 17da 17db
0 7d :4 0 16f
:4 0 80 :2 0 81
:3 0 d90 17df 17e1
:3 0 80 :2 0 94
:4 0 d93 17e3 17e5
:3 0 80 :2 0 b1
:4 0 d96 17e7 17e9
:3 0 80 :2 0 ac
:3 0 d99 17eb 17ed
:3 0 80 :2 0 b2
:4 0 d9c 17ef 17f1
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 d9f
17f4 17f8 da3 17f3
17fa :3 0 da6 17dc
17fc :2 0 17fe da9
17ff 17d9 17fe 0
1800 dab 0 1801
dad 1804 :3 0 1804
0 1804 1803 1801
1802 :6 0 1806 38
:3 0 db0 1808 db2
1807 1806 :2 0 1809
db4 :2 0 180b 0
180b 180a 17b8 1809
:6 0 180d 1 :3 0
db7 1885 d3 :3 0
103 :3 0 d :3 0
cf :3 0 39 :3 0
d2 :3 0 38 :3 0
cd :3 0 c :3 0
74 :3 0 2b :4 0
164 1 :8 0 182f
fc :4 0 181a :3 0
9c :3 0 a4 :2 0
dbb 181d 181e :3 0
1b :3 0 ab :3 0
1820 1821 0 31
:2 0 1822 1823 0
1825 dbe 182c 1b
:3 0 ab :3 0 1826
1827 0 fd :2 0
1828 1829 0 182b
dc0 182d 181f 1825
0 182e 0 182b
0 182e dc2 0
182f dc5 1882 ad
:3 0 1b :3 0 ab
:3 0 1831 1832 0
ac :3 0 1833 1834
0 1836 dc8 1838
dca 1837 1836 :2 0
1880 ae :3 0 1b
:3 0 ab :3 0 183b
183c 0 ac :3 0
183d 183e 0 1878
78 :3 0 79 :3 0
1840 1841 0 78
:3 0 88 :3 0 1843
1844 0 25 :2 0
2 :4 0 170 :2 0
8a :2 0 49 :2 0
dcc 1849 184b :3 0
dcf 1845 184d 1842
184f 184e :2 0 7b
:3 0 8b :3 0 1851
1852 0 7d :4 0
171 :4 0 80 :2 0
81 :3 0 dd3 1856
1858 :3 0 80 :2 0
94 :4 0 dd6 185a
185c :3 0 80 :2 0
b1 :4 0 dd9 185e
1860 :3 0 80 :2 0
ac :3 0 ddc 1862
1864 :3 0 80 :2 0
b2 :4 0 ddf 1866
1868 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
de2 186b 186f de6
186a 1871 :3 0 de9
1853 1873 :2 0 1875
dec 1876 1850 1875
0 1877 dee 0
1878 df0 187b :3 0
187b 0 187b 187a
1878 1879 :6 0 187d
3a :3 0 df3 187f
df5 187e 187d :2 0
1880 df7 :2 0 1882
0 1882 1881 182f
1880 :6 0 1884 1
:3 0 dfa 1886 1793
180d 0 1887 0
1884 0 1887 dfc
0 1888 dff 1900
d3 :3 0 103 :3 0
d :3 0 cf :3 0
39 :3 0 d2 :3 0
38 :3 0 cd :3 0
c :3 0 74 :3 0
2b :4 0 172 1
:8 0 18aa fc :4 0
1895 :3 0 9c :3 0
a4 :2 0 e03 1898
1899 :3 0 1b :3 0
ab :3 0 189b 189c
0 31 :2 0 189d
189e 0 18a0 e06
18a7 1b :3 0 ab
:3 0 18a1 18a2 0
fd :2 0 18a3 18a4
0 18a6 e08 18a8
189a 18a0 0 18a9
0 18a6 0 18a9
e0a 0 18aa e0d
18fd ad :3 0 1b
:3 0 ab :3 0 18ac
18ad 0 ac :3 0
18ae 18af 0 18b1
e10 18b3 e12 18b2
18b1 :2 0 18fb ae
:3 0 1b :3 0 ab
:3 0 18b6 18b7 0
ac :3 0 18b8 18b9
0 18f3 78 :3 0
79 :3 0 18bb 18bc
0 78 :3 0 88
:3 0 18be 18bf 0
25 :2 0 2 :4 0
173 :2 0 8a :2 0
49 :2 0 e14 18c4
18c6 :3 0 e17 18c0
18c8 18bd 18ca 18c9
:2 0 7b :3 0 8b
:3 0 18cc 18cd 0
7d :4 0 174 :4 0
80 :2 0 81 :3 0
e1b 18d1 18d3 :3 0
80 :2 0 94 :4 0
e1e 18d5 18d7 :3 0
80 :2 0 b1 :4 0
e21 18d9 18db :3 0
80 :2 0 ac :3 0
e24 18dd 18df :3 0
80 :2 0 b2 :4 0
e27 18e1 18e3 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 e2a 18e6
18ea e2e 18e5 18ec
:3 0 e31 18ce 18ee
:2 0 18f0 e34 18f1
18cb 18f0 0 18f2
e36 0 18f3 e38
18f6 :3 0 18f6 0
18f6 18f5 18f3 18f4
:6 0 18f8 3c :3 0
e3b 18fa e3d 18f9
18f8 :2 0 18fb e3f
:2 0 18fd 0 18fd
18fc 18aa 18fb :6 0
18ff 1 :3 0 e42
1901 178a 1888 0
1902 0 18ff 0
1902 e44 0 1903
e47 1904 1785 1903
0 1906 151a 177c
0 1906 e49 0
1907 e4c 1909 121e
150c 0 190a 0
1907 0 190a e4e
0 1d70 4d :3 0
c3 :2 0 e51 190c
190d :3 0 190e :2 0
85 :3 0 18 :3 0
31 :2 0 e53 1910
1913 8f :2 0 31
:2 0 e58 1915 1917
:3 0 1918 :2 0 190f
191a 1919 :2 0 191b
:2 0 85 :3 0 c
:3 0 31 :2 0 e5b
191d 1920 8f :2 0
31 :2 0 e60 1922
1924 :3 0 1925 :2 0
191c 1927 1926 :2 0
45 :3 0 175 :4 0
1929 192a 0 1d6d
45 :4 0 192c 192d
0 1d6d 3f :3 0
31 :2 0 192f 1930
0 1d6d 3e :3 0
31 :2 0 1932 1933
0 1d6d 85 :3 0
57 :3 0 31 :2 0
e63 1935 1938 a4
:2 0 49 :2 0 e68
193a 193c :3 0 74
:3 0 fa :3 0 cb
:3 0 176 :3 0 b3
:3 0 f6 :3 0 176
:3 0 b3 :3 0 f8
:3 0 177 :3 0 178
:3 0 150 :3 0 152
:3 0 46 :3 0 3d
:3 0 2e :3 0 59
:3 0 5a :3 0 5e
:3 0 5f :3 0 5b
:3 0 5d :3 0 d3
:3 0 13b :3 0 2b
:4 0 179 1 :8 0
195d 1b :3 0 ab
:3 0 1958 1959 0
ac :3 0 195a 195b
0 195d e6b 19b0
ad :3 0 1b :3 0
ab :3 0 195f 1960
0 ac :3 0 1961
1962 0 1964 e6e
1966 e70 1965 1964
:2 0 19ae ae :3 0
1b :3 0 ab :3 0
1969 196a 0 ac
:3 0 196b 196c 0
19a6 78 :3 0 79
:3 0 196e 196f 0
78 :3 0 88 :3 0
1971 1972 0 25
:2 0 2 :4 0 17a
:2 0 8a :2 0 49
:2 0 e72 1977 1979
:3 0 e75 1973 197b
1970 197d 197c :2 0
7b :3 0 8b :3 0
197f 1980 0 7d
:4 0 17b :4 0 80
:2 0 81 :3 0 e79
1984 1986 :3 0 80
:2 0 94 :4 0 e7c
1988 198a :3 0 80
:2 0 b1 :4 0 e7f
198c 198e :3 0 80
:2 0 ac :3 0 e82
1990 1992 :3 0 80
:2 0 b2 :4 0 e85
1994 1996 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 e88 1999 199d
e8c 1998 199f :3 0
e8f 1981 19a1 :2 0
19a3 e92 19a4 197e
19a3 0 19a5 e94
0 19a6 e96 19a9
:3 0 19a9 0 19a9
19a8 19a6 19a7 :6 0
19ab 3e :3 0 e99
19ad e9b 19ac 19ab
:2 0 19ae e9d :2 0
19b0 0 19b0 19af
195d 19ae :6 0 19b2
1 :3 0 ea0 1a29
46 :3 0 2b :3 0
19b3 19b4 0 1a28
fa :3 0 cb :3 0
176 :3 0 b3 :3 0
f6 :3 0 176 :3 0
b3 :3 0 f8 :3 0
177 :3 0 178 :3 0
150 :3 0 152 :3 0
3d :3 0 2e :3 0
59 :3 0 5a :3 0
5e :3 0 5f :3 0
5b :3 0 5d :3 0
d3 :3 0 74 :3 0
46 :4 0 17c 1
:8 0 19d3 1b :3 0
ab :3 0 19ce 19cf
0 ac :3 0 19d0
19d1 0 19d3 ea2
1a26 ad :3 0 1b
:3 0 ab :3 0 19d5
19d6 0 ac :3 0
19d7 19d8 0 19da
ea5 19dc ea7 19db
19da :2 0 1a24 ae
:3 0 1b :3 0 ab
:3 0 19df 19e0 0
ac :3 0 19e1 19e2
0 1a1c 78 :3 0
79 :3 0 19e4 19e5
0 78 :3 0 88
:3 0 19e7 19e8 0
25 :2 0 2 :4 0
17d :2 0 8a :2 0
49 :2 0 ea9 19ed
19ef :3 0 eac 19e9
19f1 19e6 19f3 19f2
:2 0 7b :3 0 8b
:3 0 19f5 19f6 0
7d :4 0 17e :4 0
80 :2 0 81 :3 0
eb0 19fa 19fc :3 0
80 :2 0 94 :4 0
eb3 19fe 1a00 :3 0
80 :2 0 b1 :4 0
eb6 1a02 1a04 :3 0
80 :2 0 ac :3 0
eb9 1a06 1a08 :3 0
80 :2 0 b2 :4 0
ebc 1a0a 1a0c :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 ebf 1a0f
1a13 ec3 1a0e 1a15
:3 0 ec6 19f7 1a17
:2 0 1a19 ec9 1a1a
19f4 1a19 0 1a1b
ecb 0 1a1c ecd
1a1f :3 0 1a1f 0
1a1f 1a1e 1a1c 1a1d
:6 0 1a21 40 :3 0
ed0 1a23 ed2 1a22
1a21 :2 0 1a24 ed4
:2 0 1a26 0 1a26
1a25 19d3 1a24 :6 0
1a28 1 :3 0 ed7
1a2a 193d 19b2 0
1a2b 0 1a28 0
1a2b eda 0 1d6d
1b :3 0 ab :3 0
1a2c 1a2d 0 1b
:3 0 a4 :2 0 d7
:3 0 1a2f 1a31 0
edf 1a30 1a33 :3 0
1a34 :2 0 85 :3 0
c :3 0 31 :2 0
ee2 1a36 1a39 85
:3 0 a4 :2 0 a
:3 0 31 :2 0 ee5
1a3b 1a3f eea 1a3c
1a41 :3 0 1a42 :2 0
85 :3 0 e :3 0
31 :2 0 eed 1a44
1a47 a4 :2 0 31
:2 0 ef2 1a49 1a4b
:3 0 1a4c :2 0 1a43
1a4e 1a4d :2 0 85
:3 0 d :3 0 31
:2 0 ef5 1a50 1a53
a4 :2 0 f0 :2 0
efa 1a55 1a57 :3 0
1a58 :2 0 1a4f 1a5a
1a59 :2 0 73 :3 0
75 :3 0 70 :3 0
72 :3 0 6a :3 0
2d :3 0 74 :3 0
46 :4 0 17f 1
:8 0 1a7a fc :4 0
1a65 :3 0 9c :3 0
a4 :2 0 eff 1a68
1a69 :3 0 1b :3 0
ab :3 0 1a6b 1a6c
0 31 :2 0 1a6d
1a6e 0 1a70 f02
1a77 1b :3 0 ab
:3 0 1a71 1a72 0
fd :2 0 1a73 1a74
0 1a76 f04 1a78
1a6a 1a70 0 1a79
0 1a76 0 1a79
f06 0 1a7a f09
1acd ad :3 0 1b
:3 0 ab :3 0 1a7c
1a7d 0 ac :3 0
1a7e 1a7f 0 1a81
f0c 1a83 f0e 1a82
1a81 :2 0 1acb ae
:3 0 1b :3 0 ab
:3 0 1a86 1a87 0
ac :3 0 1a88 1a89
0 1ac3 78 :3 0
79 :3 0 1a8b 1a8c
0 78 :3 0 88
:3 0 1a8e 1a8f 0
25 :2 0 2 :4 0
180 :2 0 8a :2 0
49 :2 0 f10 1a94
1a96 :3 0 f13 1a90
1a98 1a8d 1a9a 1a99
:2 0 7b :3 0 8b
:3 0 1a9c 1a9d 0
7d :4 0 181 :4 0
80 :2 0 81 :3 0
f17 1aa1 1aa3 :3 0
80 :2 0 94 :4 0
f1a 1aa5 1aa7 :3 0
80 :2 0 b1 :4 0
f1d 1aa9 1aab :3 0
80 :2 0 ac :3 0
f20 1aad 1aaf :3 0
80 :2 0 b2 :4 0
f23 1ab1 1ab3 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 f26 1ab6
1aba f2a 1ab5 1abc
:3 0 f2d 1a9e 1abe
:2 0 1ac0 f30 1ac1
1a9b 1ac0 0 1ac2
f32 0 1ac3 f34
1ac6 :3 0 1ac6 0
1ac6 1ac5 1ac3 1ac4
:6 0 1ac8 42 :3 0
f37 1aca f39 1ac9
1ac8 :2 0 1acb f3b
:2 0 1acd 0 1acd
1acc 1a7a 1acb :6 0
1b47 1 :3 0 d3
:3 0 cd :3 0 fa
:3 0 10c :3 0 182
:3 0 71 :3 0 73
:3 0 6a :3 0 2d
:3 0 74 :3 0 46
:3 0 74 :3 0 46
:4 0 183 1 :8 0
1af2 fc :4 0 1add
:3 0 9c :3 0 a4
:2 0 f40 1ae0 1ae1
:3 0 1b :3 0 ab
:3 0 1ae3 1ae4 0
31 :2 0 1ae5 1ae6
0 1ae8 f43 1aef
1b :3 0 ab :3 0
1ae9 1aea 0 fd
:2 0 1aeb 1aec 0
1aee f45 1af0 1ae2
1ae8 0 1af1 0
1aee 0 1af1 f47
0 1af2 f4a 1b45
ad :3 0 1b :3 0
ab :3 0 1af4 1af5
0 ac :3 0 1af6
1af7 0 1af9 f4d
1afb f4f 1afa 1af9
:2 0 1b43 ae :3 0
1b :3 0 ab :3 0
1afe 1aff 0 ac
:3 0 1b00 1b01 0
1b3b 78 :3 0 79
:3 0 1b03 1b04 0
78 :3 0 88 :3 0
1b06 1b07 0 25
:2 0 2 :4 0 184
:2 0 8a :2 0 49
:2 0 f51 1b0c 1b0e
:3 0 f54 1b08 1b10
1b05 1b12 1b11 :2 0
7b :3 0 8b :3 0
1b14 1b15 0 7d
:4 0 185 :4 0 80
:2 0 81 :3 0 f58
1b19 1b1b :3 0 80
:2 0 94 :4 0 f5b
1b1d 1b1f :3 0 80
:2 0 b1 :4 0 f5e
1b21 1b23 :3 0 80
:2 0 ac :3 0 f61
1b25 1b27 :3 0 80
:2 0 b2 :4 0 f64
1b29 1b2b :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 f67 1b2e 1b32
f6b 1b2d 1b34 :3 0
f6e 1b16 1b36 :2 0
1b38 f71 1b39 1b13
1b38 0 1b3a f73
0 1b3b f75 1b3e
:3 0 1b3e 0 1b3e
1b3d 1b3b 1b3c :6 0
1b40 44 :3 0 f78
1b42 f7a 1b41 1b40
:2 0 1b43 f7c :2 0
1b45 0 1b45 1b44
1af2 1b43 :6 0 1b47
1 :3 0 f7f 1d3a
123 :3 0 6f :4 0
1b4b :2 0 1d39 1b49
1b4c :3 0 186 :3 0
6f :3 0 40 :3 0
43 :3 0 3e :4 0
1b53 :2 0 1c53 1b4e
1b54 :3 0 f82 :3 0
6f :3 0 fc :3 0
1b55 1b56 :3 0 1b
:3 0 ab :3 0 1b58
1b59 0 31 :2 0
1b5a 1b5b 0 1b5d
f86 1b64 1b :3 0
ab :3 0 1b5e 1b5f
0 fd :2 0 1b60
1b61 0 1b63 f88
1b65 1b57 1b5d 0
1b66 0 1b63 0
1b66 f8a 0 1c53
1b :3 0 ab :3 0
1b67 1b68 0 c0
:2 0 31 :2 0 f8f
1b6a 1b6c :3 0 187
:8 0 1b70 f92 1b71
1b6d 1b70 0 1b72
f94 0 1c53 3f
:3 0 85 :3 0 3f
:3 0 31 :2 0 f96
1b74 1b77 8a :2 0
85 :3 0 40 :3 0
31 :2 0 f99 1b7a
1b7d f9c 1b79 1b7f
:3 0 1b73 1b80 0
1c53 85 :3 0 3e
:3 0 31 :2 0 f9f
1b82 1b85 a4 :2 0
31 :2 0 fa4 1b87
1b89 :3 0 85 :3 0
3f :3 0 31 :2 0
fa7 1b8b 1b8e 85
:3 0 8f :2 0 42
:3 0 31 :2 0 faa
1b90 1b94 faf 1b91
1b96 :3 0 85 :3 0
40 :3 0 31 :2 0
fb2 1b98 1b9b 85
:3 0 188 :2 0 42
:3 0 31 :2 0 fb5
1b9d 1ba1 fba 1b9e
1ba3 :3 0 40 :3 0
85 :3 0 42 :3 0
31 :2 0 fbd 1ba6
1ba9 1ba5 1baa 0
1bac fc0 1bc5 40
:3 0 85 :3 0 42
:3 0 31 :2 0 fc2
1bae 1bb1 189 :2 0
85 :3 0 3f :3 0
31 :2 0 fc5 1bb4
1bb7 fc8 1bb3 1bb9
:3 0 8a :2 0 85
:3 0 40 :3 0 31
:2 0 fcb 1bbc 1bbf
fce 1bbb 1bc1 :3 0
1bad 1bc2 0 1bc4
fd1 1bc6 1ba4 1bac
0 1bc7 0 1bc4
0 1bc7 fd3 0
1bc8 fd6 1bc9 1b97
1bc8 0 1bca fd8
0 1c3e 73 :3 0
75 :3 0 40 :3 0
72 :3 0 6f :4 0
18a 1 :8 0 1be6
fc :4 0 1bd1 :3 0
9c :3 0 a4 :2 0
fdc 1bd4 1bd5 :3 0
1b :3 0 ab :3 0
1bd7 1bd8 0 31
:2 0 1bd9 1bda 0
1bdc fdf 1be3 1b
:3 0 ab :3 0 1bdd
1bde 0 fd :2 0
1bdf 1be0 0 1be2
fe1 1be4 1bd6 1bdc
0 1be5 0 1be2
0 1be5 fe3 0
1be6 fe6 1c39 ad
:3 0 1b :3 0 ab
:3 0 1be8 1be9 0
ac :3 0 1bea 1beb
0 1bed fe9 1bef
feb 1bee 1bed :2 0
1c37 ae :3 0 1b
:3 0 ab :3 0 1bf2
1bf3 0 ac :3 0
1bf4 1bf5 0 1c2f
78 :3 0 79 :3 0
1bf7 1bf8 0 78
:3 0 88 :3 0 1bfa
1bfb 0 25 :2 0
2 :4 0 18b :2 0
8a :2 0 49 :2 0
fed 1c00 1c02 :3 0
ff0 1bfc 1c04 1bf9
1c06 1c05 :2 0 7b
:3 0 8b :3 0 1c08
1c09 0 7d :4 0
18c :4 0 80 :2 0
81 :3 0 ff4 1c0d
1c0f :3 0 80 :2 0
94 :4 0 ff7 1c11
1c13 :3 0 80 :2 0
b1 :4 0 ffa 1c15
1c17 :3 0 80 :2 0
ac :3 0 ffd 1c19
1c1b :3 0 80 :2 0
b2 :4 0 1000 1c1d
1c1f :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
1003 1c22 1c26 1007
1c21 1c28 :3 0 100a
1c0a 1c2a :2 0 1c2c
100d 1c2d 1c07 1c2c
0 1c2e 100f 0
1c2f 1011 1c32 :3 0
1c32 0 1c32 1c31
1c2f 1c30 :6 0 1c34
47 :3 0 1014 1c36
1016 1c35 1c34 :2 0
1c37 1018 :2 0 1c39
0 1c39 1c38 1be6
1c37 :6 0 1c3e 46
:3 0 45 :3 0 43
:3 0 1c3b 1c3c 0
1c3e 101b 1c3f 1b8a
1c3e 0 1c40 101f
0 1c53 85 :3 0
3f :3 0 31 :2 0
1021 1c41 1c44 85
:3 0 188 :2 0 42
:3 0 31 :2 0 1024
1c46 1c4a 1029 1c47
1c4c :3 0 187 :8 0
1c50 102c 1c51 1c4d
1c50 0 1c52 102e
0 1c53 1030 1c55
186 :4 0 1c53 :4 0
1d39 124 :3 0 6f
:4 0 1c59 :2 0 1c5f
1c57 0 1b :3 0
ab :3 0 1c5a 1c5b
0 ac :3 0 1c5c
1c5d 0 1c5f 1037
1cb2 ad :3 0 1b
:3 0 ab :3 0 1c61
1c62 0 ac :3 0
1c63 1c64 0 1c66
103a 1c68 103c 1c67
1c66 :2 0 1cb0 ae
:3 0 1b :3 0 ab
:3 0 1c6b 1c6c 0
ac :3 0 1c6d 1c6e
0 1ca8 78 :3 0
79 :3 0 1c70 1c71
0 78 :3 0 88
:3 0 1c73 1c74 0
25 :2 0 2 :4 0
18d :2 0 8a :2 0
49 :2 0 103e 1c79
1c7b :3 0 1041 1c75
1c7d 1c72 1c7f 1c7e
:2 0 7b :3 0 8b
:3 0 1c81 1c82 0
7d :4 0 18e :4 0
80 :2 0 81 :3 0
1045 1c86 1c88 :3 0
80 :2 0 94 :4 0
1048 1c8a 1c8c :3 0
80 :2 0 b1 :4 0
104b 1c8e 1c90 :3 0
80 :2 0 ac :3 0
104e 1c92 1c94 :3 0
80 :2 0 b2 :4 0
1051 1c96 1c98 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 1054 1c9b
1c9f 1058 1c9a 1ca1
:3 0 105b 1c83 1ca3
:2 0 1ca5 105e 1ca6
1c80 1ca5 0 1ca7
1060 0 1ca8 1062
1cab :3 0 1cab 0
1cab 1caa 1ca8 1ca9
:6 0 1cad 49 :3 0
1065 1caf 1067 1cae
1cad :2 0 1cb0 1069
:2 0 1cb2 0 1cb2
1cb1 1c5f 1cb0 :6 0
1d39 1 :3 0 85
:3 0 3f :3 0 31
:2 0 106c 1cb4 1cb7
8f :2 0 31 :2 0
1071 1cb9 1cbb :3 0
1cbc :2 0 45 :3 0
c3 :2 0 1074 1cbf
1cc0 :3 0 1cc1 :2 0
1cc2 :2 0 1cbd 1cc4
1cc3 :2 0 d3 :3 0
10c :3 0 45 :3 0
74 :3 0 46 :4 0
18f 1 :8 0 1ce1
fc :4 0 1ccc :3 0
9c :3 0 a4 :2 0
1078 1ccf 1cd0 :3 0
1b :3 0 ab :3 0
1cd2 1cd3 0 31
:2 0 1cd4 1cd5 0
1cd7 107b 1cde 1b
:3 0 ab :3 0 1cd8
1cd9 0 fd :2 0
1cda 1cdb 0 1cdd
107d 1cdf 1cd1 1cd7
0 1ce0 0 1cdd
0 1ce0 107f 0
1ce1 1082 1d34 ad
:3 0 1b :3 0 ab
:3 0 1ce3 1ce4 0
ac :3 0 1ce5 1ce6
0 1ce8 1085 1cea
1087 1ce9 1ce8 :2 0
1d32 ae :3 0 1b
:3 0 ab :3 0 1ced
1cee 0 ac :3 0
1cef 1cf0 0 1d2a
78 :3 0 79 :3 0
1cf2 1cf3 0 78
:3 0 88 :3 0 1cf5
1cf6 0 25 :2 0
2 :4 0 190 :2 0
8a :2 0 49 :2 0
1089 1cfb 1cfd :3 0
108c 1cf7 1cff 1cf4
1d01 1d00 :2 0 7b
:3 0 8b :3 0 1d03
1d04 0 7d :4 0
191 :4 0 80 :2 0
81 :3 0 1090 1d08
1d0a :3 0 80 :2 0
94 :4 0 1093 1d0c
1d0e :3 0 80 :2 0
b1 :4 0 1096 1d10
1d12 :3 0 80 :2 0
ac :3 0 1099 1d14
1d16 :3 0 80 :2 0
b2 :4 0 109c 1d18
1d1a :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
109f 1d1d 1d21 10a3
1d1c 1d23 :3 0 10a6
1d05 1d25 :2 0 1d27
10a9 1d28 1d02 1d27
0 1d29 10ab 0
1d2a 10ad 1d2d :3 0
1d2d 0 1d2d 1d2c
1d2a 1d2b :6 0 1d2f
4b :3 0 10b0 1d31
10b2 1d30 1d2f :2 0
1d32 10b4 :2 0 1d34
0 1d34 1d33 1ce1
1d32 :6 0 1d36 1
:3 0 10b7 1d37 1cc5
1d36 0 1d38 10b9
0 1d39 10bb 1d3b
1a5b 1b47 0 1d3c
0 1d39 0 1d3c
10c0 0 1d6a 85
:3 0 57 :3 0 31
:2 0 10c3 1d3d 1d40
a4 :2 0 49 :2 0
10c8 1d42 1d44 :3 0
f2 :3 0 85 :3 0
f :3 0 31 :2 0
10cb 1d47 1d4a 27
:2 0 10ce 1d46 1d4d
1d4e :2 0 a4 :2 0
27 :2 0 10d3 1d50
1d52 :3 0 54 :3 0
192 :3 0 46 :3 0
2f :3 0 10d6 1d55
1d58 1d54 1d59 0
1d5b 10d9 1d64 54
:3 0 193 :3 0 46
:3 0 2f :3 0 10db
1d5d 1d60 1d5c 1d61
0 1d63 10de 1d65
1d53 1d5b 0 1d66
0 1d63 0 1d66
10e0 0 1d67 10e3
1d68 1d45 1d67 0
1d69 10e5 0 1d6a
10e7 1d6b 1a35 1d6a
0 1d6c 10ea 0
1d6d 10ec 1d6e 1928
1d6d 0 1d6f 10f3
0 1d70 10f5 1d71
7da 1d70 0 1d72
1103 0 1d82 1b
:3 0 ab :3 0 1d73
1d74 0 a4 :2 0
fd :2 0 1107 1d76
1d78 :3 0 1b :3 0
ab :3 0 1d7a 1d7b
0 31 :2 0 1d7c
1d7d 0 1d7f 110a
1d80 1d79 1d7f 0
1d81 110c 0 1d82
110e 1d83 49f 1d82
0 1d84 1112 0
1dd3 78 :3 0 79
:3 0 1d85 1d86 0
78 :3 0 88 :3 0
1d88 1d89 0 194
:2 0 2 :4 0 195
:2 0 8a :2 0 49
:2 0 1114 1d8e 1d90
:3 0 1117 1d8a 1d92
1d87 1d94 1d93 :2 0
7b :3 0 8b :3 0
1d96 1d97 0 7d
:4 0 196 :4 0 80
:2 0 81 :3 0 111b
1d9b 1d9d :3 0 80
:2 0 94 :4 0 111e
1d9f 1da1 :3 0 80
:2 0 95 :4 0 1121
1da3 1da5 :3 0 80
:2 0 85 :3 0 66
:3 0 1b :3 0 ab
:3 0 1daa 1dab 0
1124 1da9 1dad 86
:4 0 1126 1da8 1db0
1129 1da7 1db2 :3 0
80 :2 0 da :4 0
112c 1db4 1db6 :3 0
80 :2 0 83 :4 0
112f 1db8 1dba :3 0
80 :2 0 3 :3 0
1132 1dbc 1dbe :3 0
80 :2 0 83 :4 0
1135 1dc0 1dc2 :3 0
1138 1d98 1dc4 :2 0
1dc6 113b 1dc7 1d95
1dc6 0 1dc8 113d
0 1dd3 9a :3 0
197 :3 0 1dc9 1dca
0 1b :3 0 ab
:3 0 1dcc 1dcd 0
3 :3 0 9c :3 0
113f 1dcb 1dd1 :2 0
1dd3 1143 1e74 1b
:3 0 198 :2 0 4
1dd4 1dd5 0 78
:3 0 79 :3 0 1dd7
1dd8 0 78 :3 0
88 :3 0 1dda 1ddb
0 25 :2 0 2
:4 0 199 :2 0 8a
:2 0 49 :2 0 1159
1de0 1de2 :3 0 115c
1ddc 1de4 1dd9 1de6
1de5 :2 0 7b :3 0
8b :3 0 1de8 1de9
0 7d :4 0 19a
:4 0 80 :2 0 81
:3 0 1160 1ded 1def
:3 0 1163 1dea 1df1
:2 0 1e0a 7b :3 0
8b :3 0 1df3 1df4
0 7d :4 0 19b
:4 0 80 :2 0 1b
:3 0 19c :3 0 1df9
1dfa 0 1166 1df8
1dfc :3 0 80 :2 0
da :4 0 1169 1dfe
1e00 :3 0 80 :2 0
1b :3 0 19d :3 0
1e03 1e04 0 116c
1e02 1e06 :3 0 116f
1df5 1e08 :2 0 1e0a
1172 1e0b 1de7 1e0a
0 1e0c 1175 0
1e1c 123 :3 0 77
:3 0 1b :3 0 19c
:3 0 19e :3 0 1b
:3 0 19d :3 0 3
:3 0 ba :4 0 19f
1 :a 0 1e18 :2 0
1e1c 1e0e 1e16 :2 0
1a :3 0 77 :3 0
1e1a :2 0 1e1c 1177
1e1e 117b 1e1d 1e1c
:2 0 1e72 ae :3 0
1b :3 0 ab :3 0
1e21 1e22 0 ac
:3 0 1e23 1e24 0
1e6a 78 :3 0 79
:3 0 1e26 1e27 0
78 :3 0 88 :3 0
1e29 1e2a 0 25
:2 0 2 :4 0 1a0
:2 0 8a :2 0 49
:2 0 117d 1e2f 1e31
:3 0 1180 1e2b 1e33
1e28 1e35 1e34 :2 0
7b :3 0 8b :3 0
1e37 1e38 0 7d
:4 0 1a1 :4 0 80
:2 0 81 :3 0 1184
1e3c 1e3e :3 0 1187
1e39 1e40 :2 0 1e5a
7b :3 0 8b :3 0
1e42 1e43 0 7d
:4 0 b1 :4 0 80
:2 0 ac :3 0 118a
1e47 1e49 :3 0 80
:2 0 b2 :4 0 118d
1e4b 1e4d :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 1190 1e50 1e54
1194 1e4f 1e56 :3 0
1197 1e44 1e58 :2 0
1e5a 119a 1e5b 1e36
1e5a 0 1e5c 119d
0 1e6a 123 :3 0
77 :3 0 19e :3 0
1b :3 0 19d :3 0
3 :3 0 ba :4 0
1a2 1 :a 0 1e66
:2 0 1e6a 1e5e 1e64
:2 0 1a :3 0 77
:3 0 1e68 :2 0 1e6a
119f 1e6d :3 0 1e6d
0 1e6d 1e6c 1e6a
1e6b :6 0 1e6f 1
:3 0 11a4 1e71 11a6
1e70 1e6f :2 0 1e72
11a8 :2 0 1e74 11ab
1e74 1e73 1dd3 1e72
:6 0 1e75 :2 0 2
5c 1e74 1e78 :3 0
1e77 1e75 1e79 :8 0

11e8
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 15
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 1 60 1
5e 1 67 1
65 1 6e 1
6c 1 75 1
73 1 7c 1
7a 1 83 1
81 1 8a 1
88 1 91 1
8f 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b4 1
b2 1 bb 1
b9 1 c0 1
c6 1 cc 1
d2 1 d8 1
de 1 e4 1
ea 1 f0 1
f6 1 fc 1
102 1 108 1
10e 1 114 1
11a 1 120 1
125 1 12c 1
12a 1 133 1
131 1 13a 1
138 1 13f 1
144 1 149 1
14e 1 153 1
158 1 15f 1
15d 1 164 1
16a 1 170 1
176 1 17c 1
182 1 188 1
18e 1 193 1
198 1 19e 1
1a4 1 1aa 1
1b0 1 1b6 1
1cf 1 1e4 1
1ea 1 1f7 1
203 2 206 208
2 20b 20d 2
20f 211 2 213
215 2 217 219
1 21f 2 221
222 2 21b 224
2 226 228 2
22a 22c 2 22e
230 2 232 234
2 236 238 2
23a 23c 2 23e
240 2 242 244
2 246 248 2
24a 24c 2 24e
250 2 252 254
2 256 258 1
25e 2 260 261
2 25a 263 2
265 267 2 269
26b 2 26d 26f
2 271 273 2
275 277 1 27d
2 27f 280 2
279 282 2 284
286 1 28c 2
28e 28f 2 288
291 2 293 295
1 29b 2 29d
29e 2 297 2a0
2 2a2 2a4 1
2aa 2 2ac 2ad
2 2a6 2af 2
2b1 2b3 1 2b9
2 2bb 2bc 2
2b5 2be 2 2c0
2c2 1 2c8 2
2ca 2cb 2 2c4
2cd 2 2cf 2d1
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 2
2e7 2e9 2 2eb
2ed 2 2ef 2f1
1 2f7 2 2f9
2fa 2 2f3 2fc
2 2fe 300 1
306 2 308 309
2 302 30b 2
30d 30f 2 311
313 2 315 317
2 319 31b 2
31d 31f 2 321
323 2 325 327
2 329 32b 2
32d 32f 1 335
2 337 338 2
331 33a 2 33c
33e 2 340 342
2 344 346 2
348 34a 2 34c
34e 4 1ff 205
20a 350 1 352
1 354 2 35e
360 3 35c 35d
362 2 36b 36d
2 36a 36f 1
371 1 373 1
375 2 37c 37d
1 381 2 37f
381 2 386 387
1 38b 2 389
38b 2 39c 39e
3 39a 39b 3a0
2 3a9 3ab 2
3ad 3af 2 3b1
3b3 1 3bb 2
3bd 3be 2 3b5
3c0 2 3a8 3c2
1 3c4 1 3c6
2 3d0 3d2 3
3ce 3cf 3d4 2
3dd 3df 2 3dc
3e1 1 3e3 1
3e5 2 3ec 3ed
3 3c7 3e6 3ef
1 3f1 1 3f3
1 3f9 1 401
2 411 413 3
40f 410 415 2
41e 420 2 422
424 2 426 428
1 430 2 432
433 2 42a 435
2 41d 437 1
439 1 43b 2
445 447 3 443
444 449 2 452
454 2 451 456
1 458 1 45a
2 461 462 3
43c 45b 464 1
466 1 494 2
496 497 1 49d
2 499 49d 2
4a1 4a2 1 4a6
2 4a4 4a6 2
4ab 4ac 1 4b0
2 4ae 4b0 1
4b6 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4d4 4d6 2 4d8
4da 1 4e2 2
4e4 4e5 2 4dc
4e7 2 4cf 4e9
1 4eb 1 4ed
2 4f7 4f9 3
4f5 4f6 4fb 2
504 506 2 503
508 1 50a 1
50c 2 513 514
3 4ee 50d 516
1 518 2 52a
52f 1 536 1
531 2 549 54b
3 547 548 54d
2 556 558 2
55a 55c 2 55e
560 2 562 564
2 566 568 3
56d 56e 56f 2
56a 571 2 555
573 1 575 1
577 2 540 578
1 57c 1 53b
2 539 580 2
58d 58e 1 590
6 596 597 598
599 59a 59b 2
5a0 5a1 1 5a5
2 5a3 5a5 2
5a9 5aa 1 5ae
2 5ac 5ae 2
5b5 5b6 1 5ba
2 5b8 5ba 2
5c1 5c2 1 5c6
2 5c4 5c6 2
5d7 5dc 1 5e3
1 5de 2 5f6
5f8 3 5f4 5f5
5fa 2 603 605
2 607 609 2
60b 60d 2 60f
611 2 613 615
3 61a 61b 61c
2 617 61e 2
602 620 1 622
1 624 2 5ed
625 1 629 1
5e8 2 5e6 62d
2 633 634 1
638 2 636 638
1 644 2 64f
654 1 65b 1
656 2 66e 670
3 66c 66d 672
2 67b 67d 2
67f 681 2 683
685 2 687 689
2 68b 68d 3
692 693 694 2
68f 696 2 67a
698 1 69a 1
69c 2 665 69d
1 6a1 1 660
2 65e 6a5 1
6a8 1 6ab 4
63d 640 643 6ac
1 6ae 3 5ce
630 6af 1 6b1
2 6b4 6b5 1
6b9 2 6b7 6b9
2 6bf 6c0 1
6c2 1 6c7 2
6c5 6c7 1 6ce
1 6d0 a 519
51c 51f 522 583
589 593 59e 6b2
6d1 2 6ed 6f2
1 6f9 1 6f4
2 70c 70e 3
70a 70b 710 2
719 71b 2 71d
71f 2 721 723
2 725 727 2
729 72b 3 730
731 732 2 72d
734 2 718 736
1 738 1 73a
2 703 73b 1
73f 1 6fe 2
6fc 743 1 74e
2 74a 74e 2
753 754 2 759
75a 1 75c 2
756 75c 2 76a
76c 3 768 769
76e 2 777 779
2 77b 77d 2
77f 781 1 787
2 789 78a 2
783 78c 2 78e
790 2 792 794
2 796 798 2
79a 79c 2 776
79e 1 7a0 1
7a2 2 7ac 7ae
3 7aa 7ab 7b0
2 7b9 7bb 2
7b8 7bd 1 7bf
1 7c1 3 7c6
7c7 7c8 3 7a3
7c2 7ca 1 7cc
3 6d5 746 7cd
2 7cf 7d0 2
7d3 7d4 1 7d8
2 7d6 7d8 1
7df 2 7dd 7df
2 7ea 7ec 3
7e8 7e9 7ee 2
7f7 7f9 2 7fb
7fd 2 7ff 801
1 809 2 80b
80c 2 803 80e
2 810 812 2
814 816 2 818
81a 2 81c 81e
2 7f6 820 1
822 1 824 2
82e 830 3 82c
82d 832 2 83b
83d 2 83a 83f
1 841 1 843
3 84a 84b 84c
3 825 844 84e
1 850 1 852
1 857 1 85e
1 865 2 874
876 3 872 873
878 2 881 883
2 885 887 2
889 88b 1 893
2 895 896 2
88d 898 2 880
89a 1 89c 1
89e 2 8a8 8aa
3 8a6 8a7 8ac
2 8b5 8b7 2
8b4 8b9 1 8bb
1 8bd 2 8c4
8c5 3 89f 8be
8c7 1 8c9 2
8d1 8d2 1 8d6
2 8d4 8d6 1
8db 1 8dd 2
8e5 8ea 1 8f1
1 8ec 2 904
906 3 902 903
908 2 911 913
2 915 917 2
919 91b 2 91d
91f 2 921 923
3 928 929 92a
2 925 92c 2
910 92e 1 930
1 932 2 8fb
933 1 937 1
8f6 2 8f4 93b
2 941 942 1
946 2 944 946
1 94d 2 94f
950 1 956 2
958 959 2 952
95b 2 95e 960
2 963 965 1
967 2 96c 96d
2 972 973 1
975 2 96f 975
2 97a 97d 1
981 2 983 984
2 96a 985 1
987 2 98e 98f
2 991 992 1
997 2 995 997
2 99b 99c 1
9a0 2 99e 9a0
2 9a4 9a5 1
9a9 2 9a7 9a9
11 9b0 9b1 9b2
9b3 9b4 9b5 9b6
9b7 9b8 9b9 9ba
9bb 9bc 9bd 9be
9bf 9c0 1 9c8
2 9c6 9c8 1
9dd 2 9dc 9dd
1 9e5 1 9eb
2 9ed 9ee 2
9da 9ef 1 9f6
1 9f1 2 a09
a0b 3 a07 a08
a0d 2 a16 a18
2 a1a a1c 2
a1e a20 2 a22
a24 2 a26 a28
3 a2d a2e a2f
2 a2a a31 2
a15 a33 1 a35
1 a37 2 a00
a38 1 a3c 1
9fb 2 9f9 a40
1 a43 1 a46
2 9c3 a47 11
a4d a4e a4f a50
a51 a52 a53 a54
a55 a56 a57 a58
a59 a5a a5b a5c
a5d 1 a60 2
a62 a63 1 a64
2 a68 a69 2
a6b a6d 2 a72
a73 1 a77 2
a75 a77 11 a7e
a7f a80 a81 a82
a83 a84 a85 a86
a87 a88 a89 a8a
a8b a8c a8d a8e
1 a96 2 a94
a96 1 aa7 2
aa6 aa7 1 aaf
1 ab5 2 ab7
ab8 2 aa4 ab9
1 ac0 1 abb
2 ad3 ad5 3
ad1 ad2 ad7 2
ae0 ae2 2 ae4
ae6 2 ae8 aea
2 aec aee 2
af0 af2 3 af7
af8 af9 2 af4
afb 2 adf afd
1 aff 1 b01
2 aca b02 1
b06 1 ac5 2
ac3 b0a 1 b0d
1 b10 2 a91
b11 11 b17 b18
b19 b1a b1b b1c
b1d b1e b1f b20
b21 b22 b23 b24
b25 b26 b27 1
b2a 2 b2c b2d
2 a70 b2e 2
b30 b31 1 b37
2 b35 b37 2
b3d b3e 2 b40
b41 1 b46 2
b44 b46 2 b4d
b4e 2 b53 b54
1 b56 2 b50
b56 2 b5b b5c
1 b60 2 b5e
b60 2 b67 b68
1 b6c 2 b6a
b6c 1 b8c 2
b8b b8c 1 b94
1 b9a 2 b9c
b9d 2 b89 b9e
1 ba5 1 ba0
2 bb8 bba 3
bb6 bb7 bbc 2
bc5 bc7 2 bc9
bcb 2 bcd bcf
2 bd1 bd3 2
bd5 bd7 3 bdc
bdd bde 2 bd9
be0 2 bc4 be2
1 be4 1 be6
2 baf be7 1
beb 1 baa 2
ba8 bef 1 bff
2 bfe bff 1
c07 1 c0d 2
c0f c10 2 bfc
c11 1 c18 1
c13 2 c2b c2d
3 c29 c2a c2f
2 c38 c3a 2
c3c c3e 2 c40
c42 2 c44 c46
2 c48 c4a 3
c4f c50 c51 2
c4c c53 2 c37
c55 1 c57 1
c59 2 c22 c5a
1 c5e 1 c1d
2 c1b c62 1
c6f 2 c6e c6f
1 c77 1 c7d
2 c7f c80 2
c6c c81 1 c88
1 c83 2 c9b
c9d 3 c99 c9a
c9f 2 ca8 caa
2 cac cae 2
cb0 cb2 2 cb4
cb6 2 cb8 cba
3 cbf cc0 cc1
2 cbc cc3 2
ca7 cc5 1 cc7
1 cc9 2 c92
cca 1 cce 1
c8d 2 c8b cd2
3 bf2 c65 cd5
1 ce6 2 ce5
ce6 1 cee 1
cf4 2 cf6 cf7
2 ce3 cf8 1
cff 1 cfa 2
d12 d14 3 d10
d11 d16 2 d1f
d21 2 d23 d25
2 d27 d29 2
d2b d2d 2 d2f
d31 3 d36 d37
d38 2 d33 d3a
2 d1e d3c 1
d3e 1 d40 2
d09 d41 1 d45
1 d04 2 d02
d49 1 d4c 2
d4f d50 1 d51
1 d53 2 b32
d54 2 d59 d5a
2 d5c d5f 2
d64 d65 1 d69
2 d67 d69 11
d70 d71 d72 d73
d74 d75 d76 d77
d78 d79 d7a d7b
d7c d7d d7e d7f
d80 1 d88 2
d86 d88 2 d8d
d8e 1 d92 2
d90 d92 2 d99
d9a 1 d9e 2
d9c d9e 1 db6
2 db5 db6 1
dbe 1 dc4 2
dc6 dc7 2 db3
dc8 1 dcf 1
dca 2 de2 de4
3 de0 de1 de6
2 def df1 2
df3 df5 2 df7
df9 2 dfb dfd
2 dff e01 3
e06 e07 e08 2
e03 e0a 2 dee
e0c 1 e0e 1
e10 2 dd9 e11
1 e15 1 dd4
2 dd2 e19 1
e1c 1 e1f 2
d83 e20 1 e22
2 e34 e39 1
e40 1 e3b 2
e53 e55 3 e51
e52 e57 2 e60
e62 2 e64 e66
2 e68 e6a 2
e6c e6e 2 e70
e72 3 e77 e78
e79 2 e74 e7b
2 e5f e7d 1
e7f 1 e81 2
e4a e82 1 e86
1 e45 2 e43
e8a 3 e92 e93
e94 1 e98 2
e96 e98 2 ea7
eac 1 eb3 1
eae 2 ec6 ec8
3 ec4 ec5 eca
2 ed3 ed5 2
ed7 ed9 2 edb
edd 2 edf ee1
2 ee3 ee5 3
eea eeb eec 2
ee7 eee 2 ed2
ef0 1 ef2 1
ef4 2 ebd ef5
1 ef9 1 eb8
2 eb6 efd 6
f04 f05 f06 f07
f08 f09 2 f0e
f0f 1 f13 2
f11 f13 2 f2b
f2c 1 f37 1
f3d 2 f3f f40
2 f44 f4a 1
f51 1 f4c 2
f64 f66 3 f62
f63 f68 2 f71
f73 2 f75 f77
2 f79 f7b 2
f7d f7f 2 f81
f83 3 f88 f89
f8a 2 f85 f8c
2 f70 f8e 1
f90 1 f92 2
f5b f93 1 f97
1 f56 2 f54
f9b 2 fa5 faa
1 fb1 1 fac
2 fc4 fc6 3
fc2 fc3 fc8 2
fd1 fd3 2 fd5
fd7 2 fd9 fdb
2 fdd fdf 2
fe1 fe3 3 fe8
fe9 fea 2 fe5
fec 2 fd0 fee
1 ff0 1 ff2
2 fbb ff3 1
ff7 1 fb6 2
fb4 ffb 2 1008
100a 3 100c 100d
100e 2 1014 1016
3 1018 1019 101a
2 1020 1022 3
1024 1025 1026 2
102c 102e 3 1030
1031 1032 f 1038
1039 103a 103b 103c
103d 103e 103f 1040
1041 1042 1043 1044
1045 1046 2 1052
1054 3 1050 1051
1056 2 105f 1061
2 1063 1065 2
1067 1069 1 106f
2 1071 1072 2
106b 1074 2 1076
1078 2 107a 107c
2 107e 1080 2
1082 1084 2 105e
1086 1 1088 1
108a 2 1094 1096
3 1092 1093 1098
2 10a1 10a3 2
10a0 10a5 1 10a7
1 10a9 3 10ae
10af 10b0 14 f18
f1b f1e f21 f24
f27 f2d f41 f9e
ffe 1002 1005 1011
101d 1029 1035 1049
108b 10aa 10b2 1
10b4 5 e9f ea2
f00 f0c 10b5 1
10b7 3 e29 e8d
10b8 1 10ba 2
10be 10bf 2 10c1
10c3 11 10cb 10cc
10cd 10ce 10cf 10d0
10d1 10d2 10d3 10d4
10d5 10d6 10d7 10d8
10d9 10da 10db 1
10e3 2 10e1 10e3
2 10e8 10e9 1
10ed 2 10eb 10ed
2 10f4 10f5 1
10f9 2 10f7 10f9
1 110d 2 110c
110d 1 1115 1
111b 2 111d 111e
2 110a 111f 1
1126 1 1121 2
1139 113b 3 1137
1138 113d 2 1146
1148 2 114a 114c
2 114e 1150 2
1152 1154 2 1156
1158 3 115d 115e
115f 2 115a 1161
2 1145 1163 1
1165 1 1167 2
1130 1168 1 116c
1 112b 2 1129
1170 1 1173 1
1176 4 10bb 10c6
10de 1177 2 1179
117a 2 d62 117b
2 117d 117e 1
1184 2 1182 1184
2 118f 1191 3
118d 118e 1193 2
119c 119e 2 11a0
11a2 2 11a4 11a6
1 11ae 2 11b0
11b1 2 11a8 11b3
2 11b5 11b7 2
11b9 11bb 2 11bd
11bf 2 11c1 11c3
2 119b 11c5 1
11c7 1 11c9 2
11d3 11d5 3 11d1
11d2 11d7 2 11e0
11e2 2 11df 11e4
1 11e6 1 11e8
3 11ef 11f0 11f1
3 11ca 11e9 11f3
1 11f5 2 11fb
11fc 1 1200 2
11fe 1200 2 1205
1206 1 120a 2
1208 120a 1 1212
1 1214 2 1217
1218 1 121c 2
121a 121c 2 1221
1222 2 1224 1225
1 122a 2 1228
122a 1 122d 1
1232 1 124f 2
124e 124f 1 1257
1 125d 2 125f
1260 2 124c 1261
1 1268 1 1263
2 127b 127d 3
1279 127a 127f 2
1288 128a 2 128c
128e 2 1290 1292
2 1294 1296 2
1298 129a 3 129f
12a0 12a1 2 129c
12a3 2 1287 12a5
1 12a7 1 12a9
2 1272 12aa 1
12ae 1 126d 2
126b 12b2 1 12b5
1 12c4 2 12c3
12c4 1 12cc 1
12d2 2 12d4 12d5
2 12c1 12d6 1
12dd 1 12d8 2
12f0 12f2 3 12ee
12ef 12f4 2 12fd
12ff 2 1301 1303
2 1305 1307 2
1309 130b 2 130d
130f 3 1314 1315
1316 2 1311 1318
2 12fc 131a 1
131c 1 131e 2
12e7 131f 1 1323
1 12e2 2 12e0
1327 1 132a 2
132d 132e 1 132f
1 1331 1 1379
2 1378 1379 1
1381 1 1387 2
1389 138a 2 1376
138b 1 1392 1
138d 2 13a5 13a7
3 13a3 13a4 13a9
2 13b2 13b4 2
13b6 13b8 2 13ba
13bc 2 13be 13c0
2 13c2 13c4 3
13c9 13ca 13cb 2
13c6 13cd 2 13b1
13cf 1 13d1 1
13d3 2 139c 13d4
1 13d8 1 1397
2 1395 13dc 1
13df 1 1419 2
1418 1419 1 1421
1 1427 2 1429
142a 2 1416 142b
1 1432 1 142d
2 1445 1447 3
1443 1444 1449 2
1452 1454 2 1456
1458 2 145a 145c
2 145e 1460 2
1462 1464 3 1469
146a 146b 2 1466
146d 2 1451 146f
1 1471 1 1473
2 143c 1474 1
1478 1 1437 2
1435 147c 1 147f
2 1482 1483 1
1484 2 1486 1487
1 1488 2 148c
148d 1 1491 2
148f 1491 1 14a0
2 149f 14a0 1
14a8 1 14ae 2
14b0 14b1 2 149d
14b2 1 14b9 1
14b4 2 14cc 14ce
3 14ca 14cb 14d0
2 14d9 14db 2
14dd 14df 2 14e1
14e3 2 14e5 14e7
2 14e9 14eb 3
14f0 14f1 14f2 2
14ed 14f4 2 14d8
14f6 1 14f8 1
14fa 2 14c3 14fb
1 14ff 1 14be
2 14bc 1503 1
1506 2 150a 1509
1 150b 2 150f
1510 2 1512 1513
1 1518 2 1516
1518 1 151b 1
1520 1 153d 2
153c 153d 1 1545
1 154b 2 154d
154e 2 153a 154f
1 1556 1 1551
2 1569 156b 3
1567 1568 156d 2
1576 1578 2 157a
157c 2 157e 1580
2 1582 1584 2
1586 1588 3 158d
158e 158f 2 158a
1591 2 1575 1593
1 1595 1 1597
2 1560 1598 1
159c 1 155b 2
1559 15a0 1 15a3
1 15b4 2 15b3
15b4 1 15bc 1
15c2 2 15c4 15c5
2 15b1 15c6 1
15cd 1 15c8 2
15e0 15e2 3 15de
15df 15e4 2 15ed
15ef 2 15f1 15f3
2 15f5 15f7 2
15f9 15fb 2 15fd
15ff 3 1604 1605
1606 2 1601 1608
2 15ec 160a 1
160c 1 160e 2
15d7 160f 1 1613
1 15d2 2 15d0
1617 1 161a 2
161d 161e 1 161f
1 1621 1 1669
2 1668 1669 1
1671 1 1677 2
1679 167a 2 1666
167b 1 1682 1
167d 2 1695 1697
3 1693 1694 1699
2 16a2 16a4 2
16a6 16a8 2 16aa
16ac 2 16ae 16b0
2 16b2 16b4 3
16b9 16ba 16bb 2
16b6 16bd 2 16a1
16bf 1 16c1 1
16c3 2 168c 16c4
1 16c8 1 1687
2 1685 16cc 1
16cf 1 170b 2
170a 170b 1 1713
1 1719 2 171b
171c 2 1708 171d
1 1724 1 171f
2 1737 1739 3
1735 1736 173b 2
1744 1746 2 1748
174a 2 174c 174e
2 1750 1752 2
1754 1756 3 175b
175c 175d 2 1758
175f 2 1743 1761
1 1763 1 1765
2 172e 1766 1
176a 1 1729 2
1727 176e 1 1771
2 1774 1775 1
1776 2 1778 1779
1 177a 2 177e
177f 1 1783 2
1781 1783 1 1786
2 178c 178d 1
1791 2 178f 1791
1 17a5 2 17a4
17a5 1 17ad 1
17b3 2 17b5 17b6
2 17a2 17b7 1
17be 1 17b9 2
17d1 17d3 3 17cf
17d0 17d5 2 17de
17e0 2 17e2 17e4
2 17e6 17e8 2
17ea 17ec 2 17ee
17f0 3 17f5 17f6
17f7 2 17f2 17f9
2 17dd 17fb 1
17fd 1 17ff 2
17c8 1800 1 1804
1 17c3 2 17c1
1808 1 180b 1
181c 2 181b 181c
1 1824 1 182a
2 182c 182d 2
1819 182e 1 1835
1 1830 2 1848
184a 3 1846 1847
184c 2 1855 1857
2 1859 185b 2
185d 185f 2 1861
1863 2 1865 1867
3 186c 186d 186e
2 1869 1870 2
1854 1872 1 1874
1 1876 2 183f
1877 1 187b 1
183a 2 1838 187f
1 1882 2 1885
1886 1 1887 1
1897 2 1896 1897
1 189f 1 18a5
2 18a7 18a8 2
1894 18a9 1 18b0
1 18ab 2 18c3
18c5 3 18c1 18c2
18c7 2 18d0 18d2
2 18d4 18d6 2
18d8 18da 2 18dc
18de 2 18e0 18e2
3 18e7 18e8 18e9
2 18e4 18eb 2
18cf 18ed 1 18ef
1 18f1 2 18ba
18f2 1 18f6 1
18b5 2 18b3 18fa
1 18fd 2 1900
1901 1 1902 2
1905 1904 1 1906
2 1908 1909 1
190b 2 1911 1912
1 1916 2 1914
1916 2 191e 191f
1 1923 2 1921
1923 2 1936 1937
1 193b 2 1939
193b 2 1957 195c
1 1963 1 195e
2 1976 1978 3
1974 1975 197a 2
1983 1985 2 1987
1989 2 198b 198d
2 198f 1991 2
1993 1995 3 199a
199b 199c 2 1997
199e 2 1982 19a0
1 19a2 1 19a4
2 196d 19a5 1
19a9 1 1968 2
1966 19ad 1 19b0
2 19cd 19d2 1
19d9 1 19d4 2
19ec 19ee 3 19ea
19eb 19f0 2 19f9
19fb 2 19fd 19ff
2 1a01 1a03 2
1a05 1a07 2 1a09
1a0b 3 1a10 1a11
1a12 2 1a0d 1a14
2 19f8 1a16 1
1a18 1 1a1a 2
19e3 1a1b 1 1a1f
1 19de 2 19dc
1a23 2 19b5 1a26
2 1a29 1a2a 1
1a32 2 1a2e 1a32
2 1a37 1a38 2
1a3d 1a3e 1 1a40
2 1a3a 1a40 2
1a45 1a46 1 1a4a
2 1a48 1a4a 2
1a51 1a52 1 1a56
2 1a54 1a56 1
1a67 2 1a66 1a67
1 1a6f 1 1a75
2 1a77 1a78 2
1a64 1a79 1 1a80
1 1a7b 2 1a93
1a95 3 1a91 1a92
1a97 2 1aa0 1aa2
2 1aa4 1aa6 2
1aa8 1aaa 2 1aac
1aae 2 1ab0 1ab2
3 1ab7 1ab8 1ab9
2 1ab4 1abb 2
1a9f 1abd 1 1abf
1 1ac1 2 1a8a
1ac2 1 1ac6 1
1a85 2 1a83 1aca
1 1adf 2 1ade
1adf 1 1ae7 1
1aed 2 1aef 1af0
2 1adc 1af1 1
1af8 1 1af3 2
1b0b 1b0d 3 1b09
1b0a 1b0f 2 1b18
1b1a 2 1b1c 1b1e
2 1b20 1b22 2
1b24 1b26 2 1b28
1b2a 3 1b2f 1b30
1b31 2 1b2c 1b33
2 1b17 1b35 1
1b37 1 1b39 2
1b02 1b3a 1 1b3e
1 1afd 2 1afb
1b42 2 1acd 1b45
3 1b4f 1b50 1b51
1 1b5c 1 1b62
2 1b64 1b65 1
1b6b 2 1b69 1b6b
1 1b6f 1 1b71
2 1b75 1b76 2
1b7b 1b7c 2 1b78
1b7e 2 1b83 1b84
1 1b88 2 1b86
1b88 2 1b8c 1b8d
2 1b92 1b93 1
1b95 2 1b8f 1b95
2 1b99 1b9a 2
1b9f 1ba0 1 1ba2
2 1b9c 1ba2 2
1ba7 1ba8 1 1bab
2 1baf 1bb0 2
1bb5 1bb6 2 1bb2
1bb8 2 1bbd 1bbe
2 1bba 1bc0 1
1bc3 2 1bc5 1bc6
1 1bc7 1 1bc9
1 1bd3 2 1bd2
1bd3 1 1bdb 1
1be1 2 1be3 1be4
2 1bd0 1be5 1
1bec 1 1be7 2
1bff 1c01 3 1bfd
1bfe 1c03 2 1c0c
1c0e 2 1c10 1c12
2 1c14 1c16 2
1c18 1c1a 2 1c1c
1c1e 3 1c23 1c24
1c25 2 1c20 1c27
2 1c0b 1c29 1
1c2b 1 1c2d 2
1bf6 1c2e 1 1c32
1 1bf1 2 1bef
1c36 3 1bca 1c39
1c3d 1 1c3f 2
1c42 1c43 2 1c48
1c49 1 1c4b 2
1c45 1c4b 1 1c4f
1 1c51 6 1b52
1b66 1b72 1b81 1c40
1c52 2 1c58 1c5e
1 1c65 1 1c60
2 1c78 1c7a 3
1c76 1c77 1c7c 2
1c85 1c87 2 1c89
1c8b 2 1c8d 1c8f
2 1c91 1c93 2
1c95 1c97 3 1c9c
1c9d 1c9e 2 1c99
1ca0 2 1c84 1ca2
1 1ca4 1 1ca6
2 1c6f 1ca7 1
1cab 1 1c6a 2
1c68 1caf 2 1cb5
1cb6 1 1cba 2
1cb8 1cba 1 1cbe
1 1cce 2 1ccd
1cce 1 1cd6 1
1cdc 2 1cde 1cdf
2 1ccb 1ce0 1
1ce7 1 1ce2 2
1cfa 1cfc 3 1cf8
1cf9 1cfe 2 1d07
1d09 2 1d0b 1d0d
2 1d0f 1d11 2
1d13 1d15 2 1d17
1d19 3 1d1e 1d1f
1d20 2 1d1b 1d22
2 1d06 1d24 1
1d26 1 1d28 2
1cf1 1d29 1 1d2d
1 1cec 2 1cea
1d31 1 1d34 1
1d37 4 1b4a 1c55
1cb2 1d38 2 1d3a
1d3b 2 1d3e 1d3f
1 1d43 2 1d41
1d43 2 1d48 1d49
2 1d4b 1d4c 1
1d51 2 1d4f 1d51
2 1d56 1d57 1
1d5a 2 1d5e 1d5f
1 1d62 2 1d64
1d65 1 1d66 1
1d68 2 1d3c 1d69
1 1d6b 6 192b
192e 1931 1934 1a2b
1d6c 1 1d6e d
851 8ca 8cf 8de
93e 988 98b 117f
11f6 11f9 1215 190a
1d6f 1 1d71 1
1d77 2 1d75 1d77
1 1d7e 1 1d80
3 7d1 1d72 1d81
1 1d83 2 1d8d
1d8f 3 1d8b 1d8c
1d91 2 1d9a 1d9c
2 1d9e 1da0 2
1da2 1da4 1 1dac
2 1dae 1daf 2
1da6 1db1 2 1db3
1db5 2 1db7 1db9
2 1dbb 1dbd 2
1dbf 1dc1 2 1d99
1dc3 1 1dc5 1
1dc7 3 1dce 1dcf
1dd0 15 355 374
3f2 467 46a 46d
470 473 476 479
47c 47f 482 485
488 48b 48e 491
1d84 1dc8 1dd2 2
1ddf 1de1 3 1ddd
1dde 1de3 2 1dec
1dee 2 1deb 1df0
2 1df7 1dfb 2
1dfd 1dff 2 1e01
1e05 2 1df6 1e07
2 1df2 1e09 1
1e0b 3 1e0c 1e17
1e1b 1 1dd6 2
1e2e 1e30 3 1e2c
1e2d 1e32 2 1e3b
1e3d 2 1e3a 1e3f
2 1e46 1e48 2
1e4a 1e4c 3 1e51
1e52 1e53 2 1e4e
1e55 2 1e45 1e57
2 1e41 1e59 1
1e5b 4 1e25 1e5c
1e65 1e69 1 1e6d
1 1e20 2 1e1e
1e71 3c 63 6a
71 78 7f 86
8d 94 9b a2
a9 b0 b7 be
c4 ca d0 d6
dc e2 e8 ee
f4 fa 100 106
10c 112 118 11e
123 128 12f 136
13d 142 147 14c
151 156 15b 162
168 16e 174 17a
180 186 18c 191
196 19c 1a2 1a8
1ae 1b4 1ba 1d0
1e5 1ef 
1
4
0 
1e78
0
1
50
4d
52
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 1 42 1 44 1 46 47
1 49 1 4b 1 0 0 0

d2 1 0
53 1 0
1bd 1 2
3b 1 0
23 1 0
13 1 0
7a 1 0
a4 1 0
16a 1 0
182 1 0
43 1 0
f6 1 0
3 1 0
12a 1 0
1b0 1 0
131 1 0
188 1 0
2f 1 0
102 1 0
19e 1 0
88 1 0
114 1 0
37 1 0
120 1 0
170 1 0
10e 1 0
c0 1 0
81 1 0
1b6 1 0
17c 1 0
1f 1 0
2 0 1
144 1 0
fc 1 0
e4 1 0
f 1 0
13f 1 0
4b 1 0
17 1 0
8f 1 0
176 1 0
158 1 0
1a4 1 0
96 1 0
5e 1 0
153 1 0
47 1 0
b 1 0
cc 1 0
27 1 0
193 1 0
14e 1 0
7 1 0
108 1 0
73 1 0
1aa 1 0
1d6 1 3
2b 1 0
b2 1 0
149 1 0
11a 1 0
4f 1 0
9d 1 0
ea 1 0
d8 1 0
33 1 0
164 1 0
ab 1 0
f0 1 0
c6 1 0
3f 1 0
198 1 0
18e 1 0
125 1 0
6c 1 0
65 1 0
b9 1 0
1b 1 0
15d 1 0
de 1 0
1ea 1 0
138 1 0
0

/
SHOW ERRORS FUNCTION SP_ASSIGN_MSP;
ALTER FUNCTION SP_ASSIGN_MSP COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_RESTOPROF
#Short Description :Replace a profile with a resource
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_RESTOPROF ==
CREATE OR REPLACE FUNCTION SP_A_RESTOPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
363
2 :e:
1FUNCTION:
1SP_A_RESTOPROF:
1PRJ_ID:
1VARCHAR2:
1PROFILE_ID001:
1RES_ID001:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_ID:
132:
1H_SECURITY_ID:
1H_REC_USER:
1H_ASSIGN_ID:
1H_PRJ_ASSIGN_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TMP_ASSIGNMENT_ID:
1H_CUR_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_RES_ID:
1H_PROJECT_ID:
1H_PROFILE_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_BIT_FLAG:
11:
1H_NULL_STR:
1H_DAYOFYEAR:
1DATE:
1H_START_D:
1H_FINISH_D:
1H_RES_TYPE:
1H_RANK:
1200:
1H_START_DT:
1H_FINISH_DT:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_IN:
1H_PROFILE_NAME:
1H_LABOR_CODE:
150:
1H_RES_AVAILABLE:
10:
1H_PARTICIPANT:
1H_EVERY:
1H_EFFORT:
1H_CRI:
1H_TYPE:
1H_TYPE_ID:
1H_TOTAL:
1H_WORK:
1H_OCCURRENCE:
1H_EUNIT:
1H_UNIT:
1H_CONTOUR:
1H_DURATION:
1H_WORK_TYPE:
1H_PASSED:
1H_ASSIGNED:
1H_REMAINING:
1H_BITFLAG:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_CONSIDER:
1H_PRIORITY:
1H_DAYS:
1H_OWNER:
1H_COUNT:
1H_AVAILABLE:
1H_CONTOUR_CHANGED:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_RATE_ECHANGE:
1H_CURRENCY_ID:
1H_DONOT_REPLACE_BITS:
1H_DONOT_REPLACE_RATE:
1H_DONOT_REPLACE_COST:
1H_FROM_PRJ:
1H_SAME_LABOR:
1H_FS_PROJECT:
1H_MINUTES:
1H_TA_EXISTS:
1H_AND_ROLES:
14000:
1H_AND_SKILLS:
1H_TEMP_RES_COST:
1H_TEMP_VAR:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_PA_TIMEPHASE:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_SD:
1H_FD:
1H_OLD_COST:
1H_OLD_SALE:
1H_PA_COUNT:
1H_TA_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_TABLE_TYPE:
1H_PLANNED_EFFORT:
1H_TASK_TYPE:
1H_PERCENT_UNITS:
1H_TIMECODE_1_ID:
1H_TIMECODE_2_ID:
1H_OLD_PRJ_ASSIGN_ID:
1I_RETURN:
1I_ISTASK:
1ISWBSTASK:
1COALESCE:
1L_DATA_FLAG:
1I_MANY:
1PA_CONTINUE:
1PA_ASSIGN:
1CURSOR:
1CRCAL1:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1ROWNUM:
1ELEMENT_ID:
1SELECT AVAILABLE_MIN FROM CALENDAR_DAY_OF_YEAR:n         WHERE  ROWNUM <= 1 A+
1ND  ELEMENT_ID = h_res_id:
1CSA1:
1BAK_WORK:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT BAK_WORK FROM TASK_ASSIGNMENTS:n         WHERE  ROWNUM <= 1 AND  PROJE+
1CT_ID = h_project_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0' AND:n+
1         PROJECT_ASSIGNMENT_ID IS NuLL:
1C6A:
1R:
1RES_ASSIGNMENT_ID:
1T:
1TSK_ASSIGNMENT_ID:
1TASK_ID:
1ELEMENT_TYPE:
1PLANNED_WORK:
1UNITS_MSP:
1PLANNED_START:
1TO_DATE:
1SUBSTR:
1PLANNED_FINISH:
1W:
1TASK_TYPE:
1PLANNED_DURATION:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TMT_WBS:
1RESOURCE_ASSIGNMENTS:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1RANK:
1SELECT r.RES_ASSIGNMENT_ID, t.TSK_ASSIGNMENT_ID, t.TASK_ID, r.ELEMENT_TYPE, t+
1.PLANNED_WORK, t.UNITS_MSP,:n         t.PLANNED_START, TO_DATE(SubStr(t.PLANN+
1ED_START, 1, 10)), TO_DATE(SubStr(t.PLANNED_FINISH, 1, 10)), w.TASK_TYPE, CAS+
1E WHEN t.PLANNED_DURATION = 0 THEN w.PLANNED_DURATION ELSE t.PLANNED_DURATION+
1 END,:n         t.PROJECT_ASSIGNMENT_ID, t.BILLABLE, t.CAPITAL_EXPENSE, t.REG+
1ULAR_COST, t.REGULAR_RATE,:n         t.C_EFFORT, t.T_UNIT, t.C_UNIT, t.C_CONT+
1OUR, t.CONTOUR_TYPE:n         FROM TMT_WBS w, RESOURCE_ASSIGNMENTS r, TASK_AS+
1SIGNMENTS t:n         WHERE r.PROJECT_ID = h_project_id AND r.RESOURCE_ID = h+
1_profile_id AND r.RESOURCE_TYPE = '1' :n         AND t.RES_ASSIGNMENT_ID = r.+
1RES_ASSIGNMENT_ID AND r.ELEMENT_ID = w.ELEMENT_ID :n         AND r.ELEMENT_TY+
1PE IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE2,pmo_cns+
1t.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_cnst.SC_A+
1CTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_REQUEST_T+
1ASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_cnst.SC_WB+
1S_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT_TASK,pmo+
1_cnst.SC_WBS_SERVICE_REQUEST_TASK) AND w.RANK LIKE h_rank:n         ORDER BY +
1t.PLANNED_START:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_RESTOPROF(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1171:
1+:
1FPUT:
1               ENTER:: SP_A_RESTOPROF(172) :: cplan.sql(9594) :: :
1BITAND:
1SC_1FFFFFFF:
1=:
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
14:
1:
1OPEN:
1FOUND:
1SC_STATE:
1100:
1CLOSE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1222:
1           EXCEPTION:: SP_A_RESTOPROF(223) :: cplan.sql(9645) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1229:
1        RETURN_ERROR:: SP_A_RESTOPROF(230) :: cplan.sql(9652) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1232:
1                EXIT:: SP_A_RESTOPROF(233) :: cplan.sql(9655) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1TYPE_ID:
1TIMECODE_1_ID:
1TIMECODE_2_ID:
1UNRESOLVED_DURATION:
1SELECT TYPE_ID, RANK, PROJECT_ID, TIMECODE_1_ID, TIMECODE_2_ID, UNRESOLVED_DU+
1RATION:n      INTO h_type_id, h_rank, h_project_id, h_timecode_1_id, h_timeco+
1de_2_id, h_duration:n      FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1249:
1           EXCEPTION:: SP_A_RESTOPROF(250) :: cplan.sql(9672) :: :
1SC_SQL_NO_DATA:
1257:
1        RETURN_ERROR:: SP_A_RESTOPROF(258) :: cplan.sql(9680) :: :
1260:
1                EXIT:: SP_A_RESTOPROF(261) :: cplan.sql(9683) :: :
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n      FROM PROJECT_DETAILS:n      WHERE PR+
1OJECT_ID = h_project_id:
1278:
1           EXCEPTION:: SP_A_RESTOPROF(279) :: cplan.sql(9701) :: :
1>:
1285:
1        RETURN_ERROR:: SP_A_RESTOPROF(286) :: cplan.sql(9708) :: :
1LEV_LOCKED_BY_LEVEL:
1288:
1                EXIT:: SP_A_RESTOPROF(289) :: cplan.sql(9711) :: :
1TW:
1FS_CODE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1CURRENCY_ID:
1PMO_ORASTD:
1TODECIMAL:
1TD:
1ELEMENT_NAME:
1JOIN:
1TMT_DATAFIELDS:
1SELECT tw.TYPE_ID, CASE WHEN tw.FS_CODE IS NuLL THEN 0 ELSE 1 END, COALESCE(t+
1w.MINUTE_PER_DAY, 480), COALESCE(tw.MINUTE_PER_WEEK, 2400), tw.PRIORITY, tw.C+
1URRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4):n      INTO h_type, h_+
1fs_project, h_per_day, h_per_week, h_priority, h_currency_id, h_rate_echange+
1:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURRENCY_ID = td.ELEMENT+
1_ID WHERE tw.ELEMENT_ID = h_project_id:
1305:
1           EXCEPTION:: SP_A_RESTOPROF(306) :: cplan.sql(9728) :: :
1312:
1        RETURN_ERROR:: SP_A_RESTOPROF(313) :: cplan.sql(9735) :: :
1315:
1                EXIT:: SP_A_RESTOPROF(316) :: cplan.sql(9738) :: :
1NICK_NAME:
1FS_LABOR_CODE:
1RESOURCES:
1SELECT NICK_NAME,FS_LABOR_CODE INTO h_full_name,h_labor_code FROM RESOURCES W+
1HERE RESOURCE_ID = h_res_id:
1330:
1           EXCEPTION:: SP_A_RESTOPROF(331) :: cplan.sql(9753) :: :
1337:
1        RETURN_ERROR:: SP_A_RESTOPROF(338) :: cplan.sql(9760) :: :
1340:
1                EXIT:: SP_A_RESTOPROF(341) :: cplan.sql(9763) :: :
1ROLE_ID:
1PROFILES:
1PROFILE_ID:
1SELECT ROLE_ID INTO h_role_id FROM PROFILES WHERE PROFILE_ID = h_profile_id:
1355:
1           EXCEPTION:: SP_A_RESTOPROF(356) :: cplan.sql(9778) :: :
1STRCMP:
1DEFAULTLEVEL:
1366:
1        RETURN_ERROR:: SP_A_RESTOPROF(367) :: cplan.sql(9789) :: :
1369:
1                EXIT:: SP_A_RESTOPROF(370) :: cplan.sql(9792) :: :
12:
1COUNT:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_ta_count :n      FROM TASK_ASSIGNMENTS+
1:n      WHERE PROJECT_ID = h_project_id AND PROJECT_ID <> TASK_ID AND RESOURC+
1E_ID = h_profile_id AND RESOURCE_TYPE = '1':
1403:
1           EXCEPTION:: SP_A_RESTOPROF(404) :: cplan.sql(9826) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_pa_count :n      FROM TASK_ASSIGNMENTS+
1:n      WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOUR+
1CE_ID = h_profile_id AND RESOURCE_TYPE = '1':
1420:
1           EXCEPTION:: SP_A_RESTOPROF(421) :: cplan.sql(9843) :: :
1!=:
1DUAL:
1SELECT COUNT('X') INTO h_ta_exists FROM DUAL WHERE EXISTS (SELECT 'X' FROM TA+
1SK_ASSIGNMENTS  :n            WHERE PROJECT_ID = h_project_id AND TASK_ID = h+
1_project_id AND RESOURCE_ID = h_res_id):
1440:
1           EXCEPTION:: SP_A_RESTOPROF(441) :: cplan.sql(9863) :: :
1NOT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n               WHERE PROJECT_ID = h_project_id AND TASK_ID <+
1> PROJECT_ID AND RESOURCE_ID = h_res_id):
1459:
1           EXCEPTION:: SP_A_RESTOPROF(460) :: cplan.sql(9882) :: :
1466:
1        RETURN_ERROR:: SP_A_RESTOPROF(467) :: cplan.sql(9889) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1469:
1                EXIT:: SP_A_RESTOPROF(470) :: cplan.sql(9892) :: :
1ELSIF:
1ISPROJECTTYPE:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n         WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h+
1_res_id AND RESOURCE_TYPE = '0':n         AND PROJECT_ASSIGNMENT_ID IS NuLL):
1492:
1           EXCEPTION:: SP_A_RESTOPROF(493) :: cplan.sql(9915) :: :
1499:
1        RETURN_ERROR:: SP_A_RESTOPROF(500) :: cplan.sql(9922) :: :
1502:
1                EXIT:: SP_A_RESTOPROF(503) :: cplan.sql(9925) :: :
1SC_SQL_SUCCESS:
1547:
1           EXCEPTION:: SP_A_RESTOPROF(548) :: cplan.sql(9970) :: :
1PROFILE_NAME:
1SELECT PROFILE_NAME INTO h_profile_name FROM PROFILES WHERE PROFILE_ID = h_pr+
1ofile_id:
1568:
1           EXCEPTION:: SP_A_RESTOPROF(569) :: cplan.sql(9991) :: :
1PARTICIPANT:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_prj_assign_id, h_owner:n      FR+
1OM RESOURCE_ASSIGNMENTS:n      WHERE ELEMENT_ID = h_project_id :n      AND RE+
1SOURCE_TYPE = h_res_type :n      AND RESOURCE_ID = h_res_id:
1587:
1           EXCEPTION:: SP_A_RESTOPROF(588) :: cplan.sql(10010) :: :
1SYS_GUID:
1SECURITY_ID:
1SELECT PARTICIPANT, SECURITY_ID INTO h_owner, h_temp_security_id:n         FR+
1OM RESOURCE_ASSIGNMENTS:n         WHERE ELEMENT_ID = h_project_id :n         +
1AND RESOURCE_TYPE = '1' :n         AND RESOURCE_ID = h_profile_id:
1610:
1           EXCEPTION:: SP_A_RESTOPROF(611) :: cplan.sql(10033) :: :
1PMO_FUNC:
1BIT_OR:
1SC_AFFECTED:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1FC_BEFORE_I_RES_ASSIGN:
1GETTABLE:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PROFILE_ID, PARTICIPANT, S+
1ECURITY_ID, TABLE_TYPE,:n         REC_USER, REC_DATETIME):n         VALUES (h+
1_prj_assign_id, h_project_id, h_project_id, h_type,:n         h_res_type, h_r+
1es_id, h_profile_id, h_temp_participant, h_temp_security_id, h_table_type,:n +
1        rec_user001, SYSTIMESTAMP):
1648:
1           EXCEPTION:: SP_A_RESTOPROF(649) :: cplan.sql(10071) :: :
1BIT_FLAG:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_total FROM TASK_ASSIGNMENTS:n         +
1   WHERE PROJECT_ID = h_project_id AND TASK_ID <> h_task_id :n            AND+
1 RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1' AND BIT_FLAG = '0':
1668:
1           EXCEPTION:: SP_A_RESTOPROF(669) :: cplan.sql(10091) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name):n            WHERE ELEMENT_ID = h_project_id AND PROJECT_ID = h_proj+
1ect_id:
1691:
1           EXCEPTION:: SP_A_RESTOPROF(692) :: cplan.sql(10114) :: :
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE PROJECT_ID = h_project_+
1id AND ELEMENT_ID = h_project_id:
1720:
1           EXCEPTION:: SP_A_RESTOPROF(721) :: cplan.sql(10143) :: :
1749:
1           EXCEPTION:: SP_A_RESTOPROF(750) :: cplan.sql(10172) :: :
1LOCATE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = CASE WHEN PMO_ORASTD.LOCATE(h_full_name, AS+
1SIGN_NAMES) > 0 THEN REPLACE(ASSIGN_NAMES, h_profile_name || ';', '') ELSE RE+
1PLACE (ASSIGN_NAMES, h_profile_name, h_full_name) END:n         WHERE ELEMENT+
1_ID = h_project_id AND PROJECT_ID = h_project_id:
1771:
1           EXCEPTION:: SP_A_RESTOPROF(772) :: cplan.sql(10194) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id  :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG = '0':
1789:
1           EXCEPTION:: SP_A_RESTOPROF(790) :: cplan.sql(10212) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id  :n            FROM TASK_AS+
1SIGNMENTS:n            WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG+
1 = '2':
1807:
1           EXCEPTION:: SP_A_RESTOPROF(808) :: cplan.sql(10230) :: :
1SC_PARTICIPANT:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT = pmo_cnst.SC_AFFECTED, SECURITY_ID = h_temp_security_id:n         +
1      WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1836:
1           EXCEPTION:: SP_A_RESTOPROF(837) :: cplan.sql(10259) :: :
1FC_AFTER_U_RES_ASSIGN:
1PMO_STPU:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, pmo_cnst.SC_AFFECTED):n               +
1WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1859:
1           EXCEPTION:: SP_A_RESTOPROF(860) :: cplan.sql(10282) :: :
1SC_TEAMMEMBER:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, pmo_cnst.SC_TEAMMEMBER):n             +
1  WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1882:
1           EXCEPTION:: SP_A_RESTOPROF(883) :: cplan.sql(10305) :: :
1RS:
1SELECT CASE WHEN h_currency_id = rs.CURRENCY_ID THEN 1:n      ELSE h_rate_ech+
1ange / PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) END:n      INTO h_rate_echa+
1nge:n      FROM RESOURCES rs JOIN TMT_DATAFIELDS td ON rs.CURRENCY_ID = td.EL+
1EMENT_ID AND rs.CURRENCY_ID > 0:n      WHERE RESOURCE_ID=h_res_id:
1906:
1           EXCEPTION:: SP_A_RESTOPROF(907) :: cplan.sql(10329) :: :
11.00:
1FC_DECLARE_PMO_TMP_SEARCH:
1FC_GET_RES_RATES:
1*:
1MAX:
1SELECT MAX(AVAILABLE_MIN) INTO h_res_available:n      FROM CALENDAR_DAY_OF_YE+
1AR:n      WHERE ELEMENT_ID = h_res_id:
1950:
1           EXCEPTION:: SP_A_RESTOPROF(951) :: cplan.sql(10373) :: :
1SELECT TSK_ASSIGNMENT_ID, BILLABLE INTO h_old_prj_assign_id, h_billable:n    +
1  FROM TASK_ASSIGNMENTS:n      WHERE PROJECT_ID = h_project_id AND TASK_ID = +
1h_project_id :n      AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
1970:
1           EXCEPTION:: SP_A_RESTOPROF(971) :: cplan.sql(10393) :: :
1ASSIGNMENT_BILLABLE_FLAG:
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT ASSIGNMENT_BILLABLE_FLAG, TIMEPHASE_PROJECT_ASSIGNMENT INTO h_billable+
1, h_pa_timephase:n      FROM PROJECT_DETAILS WHERE PROJECT_ID = h_project_id:
1986:
1           EXCEPTION:: SP_A_RESTOPROF(987) :: cplan.sql(10409) :: :
1IS NOT NULL:
1SELECT RES_ASSIGNMENT_ID,PLANNED_WORK, TO_DATE(SubStr(PLANNED_START, 1, 10)),+
1 TO_DATE(SubStr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n        +
1    REGULAR_COST, REGULAR_RATE, TASK_ID, UNITS_MSP, C_EFFORT, T_UNIT, C_UNIT,+
1 C_CONTOUR:n            INTO h_id, h_planned_effort, h_start_D, h_finish_D, h+
1_billable, h_capital_expense,:n            h_old_cost, h_old_sale, h_task_id,+
1 h_percent_units, h_work, h_eunit, h_unit, h_contour:n            FROM TASK_A+
1SSIGNMENTS:n            WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
11010:
1           EXCEPTION:: SP_A_RESTOPROF(1011) :: cplan.sql(10433) :: :
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SC_0000FFFF:
11027:
1        RETURN_ERROR:: SP_A_RESTOPROF(1028) :: cplan.sql(10450) :: :
1TASK_ASSIGNMENT_ERROR:
11030:
1                EXIT:: SP_A_RESTOPROF(1031) :: cplan.sql(10453) :: :
1Y:
1FINISH_DT:
1SELECT RES_ASSIGNMENT_ID, TO_DATE(SubStr(FINISH_DT, 1, 10)),BILLABLE, CAPITAL+
1_EXPENSE, PLANNED_WORK, :n                  C_EFFORT, C_UNIT, C_CONTOUR, TIME+
1CODE_1_ID, TIMECODE_2_ID, TABLE_TYPE:n                  INTO h_assign_id, h_s+
1tart_D, h_billable, h_capital_expense, h_planned_effort, :n                  +
1h_work, h_unit, h_contour, h_timecode_1_id, h_timecode_2_id, h_table_type:n  +
1                FROM TASK_ASSIGNMENTS:n                  WHERE TSK_ASSIGNMENT+
1_ID = h_prj_assignment_id:
11083:
1           EXCEPTION:: SP_A_RESTOPROF(1084) :: cplan.sql(10506) :: :
11094:
1        RETURN_ERROR:: SP_A_RESTOPROF(1095) :: cplan.sql(10517) :: :
11097:
1                EXIT:: SP_A_RESTOPROF(1098) :: cplan.sql(10520) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1PARENT_ID:
1SELECT SUM(SCHED_MIN) INTO h_planned_effort :n                              F+
1ROM TASK_DAY_OF_YEAR :n                              WHERE PROJECT_ID = h_pro+
1ject_id :n                              AND TSK_ASSIGNMENT_ID <> h_old_prj_as+
1sign_id AND PARENT_ID = h_old_prj_assign_id:
11123:
1           EXCEPTION:: SP_A_RESTOPROF(1124) :: cplan.sql(10546) :: :
1SELECT SUM(SCHED_MIN) INTO h_planned_effort :n                              F+
1ROM TASK_DAY_OF_YEAR :n                              WHERE PROJECT_ID = h_pro+
1ject_id AND RESOURCE_ID = h_profile_id:
11140:
1           EXCEPTION:: SP_A_RESTOPROF(1141) :: cplan.sql(10563) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id :n              +
1             AND TSK_ASSIGNMENT_ID <> h_old_prj_assign_id AND PARENT_ID = h_o+
1ld_prj_assign_id:
11163:
1           EXCEPTION:: SP_A_RESTOPROF(1164) :: cplan.sql(10586) :: :
1PROJECT_ASSIGNMENTS:
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_profile_id:
11182:
1           EXCEPTION:: SP_A_RESTOPROF(1183) :: cplan.sql(10605) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_id:
11201:
1           EXCEPTION:: SP_A_RESTOPROF(1202) :: cplan.sql(10624) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
11220:
1           EXCEPTION:: SP_A_RESTOPROF(1221) :: cplan.sql(10643) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_old_prj_assign_id:
11239:
1           EXCEPTION:: SP_A_RESTOPROF(1240) :: cplan.sql(10662) :: :
11252:
1        RETURN_ERROR:: SP_A_RESTOPROF(1253) :: cplan.sql(10675) :: :
11255:
1                EXIT:: SP_A_RESTOPROF(1256) :: cplan.sql(10678) :: :
1SPECIAL_COST:
1SPECIAL_RATE:
1ESTIMATION_LABOR_COST:
1SCHED_WORK:
1ROLLUP_BITS:
1SC_SET_ALL_BITS:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BI+
1TS, pmo_cnst.SC_SET_ALL_BITS):n                        WHERE TSK_ASSIGNMENT_I+
1D = h_prj_assignment_id:
11288:
1           EXCEPTION:: SP_A_RESTOPROF(1289) :: cplan.sql(10711) :: :
1ESTIMATION_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_COST = h_reg_cost,:n                        SPECIAL_COST = h_sp+
1ec_cost,:n                        REGULAR_RATE = h_reg_sale,:n               +
1         SPECIAL_RATE = h_spec_sale,:n                        UNITS_MSP = CAS+
1E WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_percent_units END,:n      +
1                  ESTIMATION_LABOR_COST = ((PLANNED_WORK+SCHED_WORK)/60.00) *+
1 h_reg_cost,:n                        ESTIMATION_LABOR_REVENUE = ((PLANNED_WO+
1RK+PLANNED_WORK)/60.00) * h_reg_sale,:n                        ROLLUP_BITS = +
1PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n                     +
1   WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11317:
1           EXCEPTION:: SP_A_RESTOPROF(1318) :: cplan.sql(10740) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                     +
1REGULAR_COST = h_reg_cost,:n                     SPECIAL_COST = h_spec_cost,+
1:n                     UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS+
1_MSP ELSE h_percent_units END,:n                     ESTIMATION_LABOR_COST = +
1((PLANNED_WORK+SCHED_WORK)/60.00) * h_reg_cost,:n                     ROLLUP_+
1BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n              +
1       WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11344:
1           EXCEPTION:: SP_A_RESTOPROF(1345) :: cplan.sql(10767) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ROLLUP_BIT+
1S = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n                 +
1       WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11370:
1           EXCEPTION:: SP_A_RESTOPROF(1371) :: cplan.sql(10793) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1             RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',:n                  +
1      REGULAR_RATE = h_reg_sale,:n                        SPECIAL_RATE = h_sp+
1ec_sale,:n                        UNITS_MSP = CASE WHEN h_contour_changed = 0+
1 THEN UNITS_MSP ELSE h_percent_units END,:n                        ESTIMATION+
1_LABOR_REVENUE = ((PLANNED_WORK+PLANNED_WORK)/60.00) * h_reg_sale,:n         +
1               ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL+
1_BITS):n                        WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11396:
1           EXCEPTION:: SP_A_RESTOPROF(1397) :: cplan.sql(10819) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1          UNITS_MSP = CASE WHEN h_contour_changed = 0 THEN UNITS_MSP ELSE h_p+
1ercent_units END,:n                     RESOURCE_ID = h_res_id, RESOURCE_TYPE+
1 = '0':n                     WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
11419:
1           EXCEPTION:: SP_A_RESTOPROF(1420) :: cplan.sql(10842) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_prj_assignment_id:
11439:
1           EXCEPTION:: SP_A_RESTOPROF(1440) :: cplan.sql(10862) :: :
11458:
1           EXCEPTION:: SP_A_RESTOPROF(1459) :: cplan.sql(10881) :: :
11477:
1           EXCEPTION:: SP_A_RESTOPROF(1478) :: cplan.sql(10900) :: :
1SC_BIT_27:
1<:
1ASSIGNLONG:
1FC_CALC_DURATION:
1INVALID_PARAMS:
18:
11516:
1      RETURN_INVALID:: SP_A_RESTOPROF(1517) :: cplan.sql(10939) :: :
11519:
1                EXIT:: SP_A_RESTOPROF(1520) :: cplan.sql(10942) :: :
1PMO_RETURN_INVALID_SP:
11524:
1        RETURN_ERROR:: SP_A_RESTOPROF(1525) :: cplan.sql(10947) :: :
11527:
1                EXIT:: SP_A_RESTOPROF(1528) :: cplan.sql(10950) :: :
10.00:
1FC_SEARCH_2:
1110:
11542:
1        RETURN_ERROR:: SP_A_RESTOPROF(1543) :: cplan.sql(10965) :: :
1RESOURCE_UNAVAILABLE:
11545:
1                EXIT:: SP_A_RESTOPROF(1546) :: cplan.sql(10968) :: :
11550:
1        RETURN_ERROR:: SP_A_RESTOPROF(1551) :: cplan.sql(10973) :: :
11553:
1                EXIT:: SP_A_RESTOPROF(1554) :: cplan.sql(10976) :: :
1U_ASSIGN_STRING:
1DAY_YEAR:
1SELECT MAX(DAY_YEAR) INTO h_start_date :n               FROM TASK_DAY_OF_YEAR+
1 :n               WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_p+
1rj_assignment_id:
11577:
1           EXCEPTION:: SP_A_RESTOPROF(1578) :: cplan.sql(11000) :: :
1%:
11602:
1           EXCEPTION:: SP_A_RESTOPROF(1603) :: cplan.sql(11025) :: :
1LOOP:
1EXIT:
1FC_BEFORE_D_RES_ASSIGN:
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11662:
1           EXCEPTION:: SP_A_RESTOPROF(1663) :: cplan.sql(11085) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11681:
1           EXCEPTION:: SP_A_RESTOPROF(1682) :: cplan.sql(11104) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11700:
1           EXCEPTION:: SP_A_RESTOPROF(1701) :: cplan.sql(11123) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
11719:
1           EXCEPTION:: SP_A_RESTOPROF(1720) :: cplan.sql(11142) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_tsk_assignment_+
1id:
11738:
1           EXCEPTION:: SP_A_RESTOPROF(1739) :: cplan.sql(11161) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
11757:
1           EXCEPTION:: SP_A_RESTOPROF(1758) :: cplan.sql(11180) :: :
1SUMMARY_TIMESHEETS:
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id :n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id :n            AND PROJECT_ID = h_project_+
1id :n            AND RESOURCE_ID = h_profile_id:
11782:
1           EXCEPTION:: SP_A_RESTOPROF(1783) :: cplan.sql(11205) :: :
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG INTO h_tmp_assignment_id, h_bit_flag :n   +
1         FROM TASK_ASSIGNMENTS:n            WHERE PROJECT_ID = h_project_id A+
1ND TASK_ID = h_task_id AND RESOURCE_ID = h_res_id:n            AND RESOURCE_T+
1YPE ='0':
11805:
1           EXCEPTION:: SP_A_RESTOPROF(1806) :: cplan.sql(11228) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_id, h_participant, +
1h_security_id:n               FROM RESOURCE_ASSIGNMENTS :n               WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE='0':
11826:
1           EXCEPTION:: SP_A_RESTOPROF(1827) :: cplan.sql(11249) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PROFILE_ID		= h_profil+
1e_id,:n                     RESOURCE_ID		= h_res_id, :n                     R+
1ESOURCE_TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11852:
1           EXCEPTION:: SP_A_RESTOPROF(1853) :: cplan.sql(11275) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= pmo_cns+
1t.SC_TEAMMEMBER, :n                     SECURITY_ID		= h_temp_security_id, :n+
1                     PROFILE_ID		= h_profile_id,:n                     RESOUR+
1CE_ID		= h_res_id, :n                     RESOURCE_TYPE	= '0':n              +
1       WHERE RES_ASSIGNMENT_ID = h_assign_id:
11880:
1           EXCEPTION:: SP_A_RESTOPROF(1881) :: cplan.sql(11303) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                     PARTICIPANT		= PMO_STP+
1U.BIT_OR(h_participant,pmo_cnst.SC_TEAMMEMBER), :n                     SECURI+
1TY_ID		= h_security_id, :n                     PROFILE_ID		= h_profile_id,:n +
1                    RESOURCE_ID		= h_res_id, :n                     RESOURCE_+
1TYPE	= '0':n                     WHERE RES_ASSIGNMENT_ID = h_assign_id:
11905:
1           EXCEPTION:: SP_A_RESTOPROF(1906) :: cplan.sql(11328) :: :
11926:
1           EXCEPTION:: SP_A_RESTOPROF(1927) :: cplan.sql(11349) :: :
1RA:
1CREATED_BY:
1TA:
1SELECT ra.RES_ASSIGNMENT_ID, SUBSTR(tw.ASSIGN_NAMES,1,InStr(tw.ASSIGN_NAMES, +
1';') - 1):n                  INTO h_id,h_in FROM TMT_WBS tw, RESOURCE_ASSIGNM+
1ENTS ra:n                  WHERE tw.ELEMENT_ID = h_task_id AND tw.ELEMENT_ID +
1= ra.ELEMENT_ID AND ra.PARTICIPANT = 32 :n                  AND ra.RESOURCE_I+
1D = tw.CREATED_BY AND NOT EXISTS(:n                  SELECT TSK_ASSIGNMENT_ID+
1 FROM TASK_ASSIGNMENTS ta WHERE ta.RES_ASSIGNMENT_ID = ra.RES_ASSIGNMENT_ID):
11946:
1           EXCEPTION:: SP_A_RESTOPROF(1947) :: cplan.sql(11369) :: :
1SC_RESPONSIBLE_GROUP:
11969:
1           EXCEPTION:: SP_A_RESTOPROF(1970) :: cplan.sql(11392) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0',:n +
1                    PROFILE_ID = h_profile_id, PARTICIPANT = 48, SECURITY_ID=+
1h_temp_security_id:n                     WHERE RES_ASSIGNMENT_ID = h_assign_i+
1d:
11990:
1           EXCEPTION:: SP_A_RESTOPROF(1991) :: cplan.sql(11413) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_in, h_full_name) +
1:n                     WHERE ELEMENT_ID = h_task_id:
12010:
1           EXCEPTION:: SP_A_RESTOPROF(2011) :: cplan.sql(11433) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name) :n                     WHERE ELEMENT_ID = h_task_id:
12030:
1           EXCEPTION:: SP_A_RESTOPROF(2031) :: cplan.sql(11453) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0' +
1:n                     WHERE RES_ASSIGNMENT_ID = h_assign_id:
12050:
1           EXCEPTION:: SP_A_RESTOPROF(2051) :: cplan.sql(11473) :: :
12071:
1           EXCEPTION:: SP_A_RESTOPROF(2072) :: cplan.sql(11494) :: :
12094:
1           EXCEPTION:: SP_A_RESTOPROF(2095) :: cplan.sql(11517) :: :
12113:
1           EXCEPTION:: SP_A_RESTOPROF(2114) :: cplan.sql(11536) :: :
12131:
1           EXCEPTION:: SP_A_RESTOPROF(2132) :: cplan.sql(11554) :: :
1SELECT CASE WHEN FS_LABOR_CODE IS NuLL THEN 0 WHEN FS_LABOR_CODE = h_labor_co+
1de THEN 1 ELSE 2 END:n                  INTO h_same_labor FROM TMT_WBS WHERE +
1ELEMENT_ID=h_task_id:
12157:
1           EXCEPTION:: SP_A_RESTOPROF(2158) :: cplan.sql(11580) :: :
1UPDATE TMT_WBS SET FS_LABOR_CODE = h_labor_code WHERE ELEMENT_ID=h_task_id:
12177:
1           EXCEPTION:: SP_A_RESTOPROF(2178) :: cplan.sql(11600) :: :
12192:
1           EXCEPTION:: SP_A_RESTOPROF(2193) :: cplan.sql(11615) :: :
12198:
1        RETURN_ERROR:: SP_A_RESTOPROF(2199) :: cplan.sql(11621) :: :
1CANNOT_ASSIGN_LABOR_CODE:
12201:
1                EXIT:: SP_A_RESTOPROF(2202) :: cplan.sql(11624) :: :
1SC_FIXED_DURATION:
1SC_FD_EFFORT_DRIVEN:
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLNF_0001:
1PMO_TMP_CPLNF_0001:
1INSERT INTO PMO_TMP_CPLNF_0001:n                     SELECT r.DAY_YEAR, 0 FRO+
1M CALENDAR_DAY_OF_YEAR r :n                     WHERE r.ELEMENT_ID = h_res_id+
1 AND r.DAY_YEAR BETWEEN TO_DATE(SubStr(h_SD, 1, 10)) AND TO_DATE(SubStr(h_FD,+
1 1, 10)):
12231:
1           EXCEPTION:: SP_A_RESTOPROF(2232) :: cplan.sql(11654) :: :
1TDY:
1INSERT INTO PMO_TMP_CPLNF_0001 SELECT r.DAY_YEAR, 0 :n                     FR+
1OM CALENDAR_DAY_OF_YEAR r, TASK_DAY_OF_YEAR tdy :n                     WHERE +
1r.ELEMENT_ID = h_res_id AND r.DAY_YEAR BETWEEN TO_DATE(SubStr(h_SD, 1, 10)) A+
1ND TO_DATE(SubStr(h_FD, 1, 10)) :n                     AND tdy.PROJECT_ID = h+
1_project_id AND tdy.TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n                +
1     AND r.DAY_YEAR = tdy.DAY_YEAR:
12254:
1           EXCEPTION:: SP_A_RESTOPROF(2255) :: cplan.sql(11677) :: :
1MIN:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) INTO h_temp_var, h_dayofyear :n        +
1             FROM PMO_TMP_CPLNF_0001:
12273:
1           EXCEPTION:: SP_A_RESTOPROF(2274) :: cplan.sql(11696) :: :
1CONTINUE0000:
1DELETE FROM TASK_DAY_OF_YEAR :n                        WHERE PROJECT_ID = h_p+
1roject_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12296:
1           EXCEPTION:: SP_A_RESTOPROF(2297) :: cplan.sql(11719) :: :
1TRUNC:
1TO_NUMBER:
1/:
10.49:
1BIT_SCHED:
1SELECT AVAILABLE_MIN, BIT_SCHED INTO h_available, h_bitID:n                  +
1      FROM CALENDAR_DAY_OF_YEAR:n                        WHERE ELEMENT_ID = h+
1_project_id AND DAY_YEAR = h_dayofyear:
12315:
1           EXCEPTION:: SP_A_RESTOPROF(2316) :: cplan.sql(11738) :: :
1SKIPFIRSTBITSCLEARTOLAST:
1ACTUAL_FLAG:
1INSERT INTO TASK_DAY_OF_YEAR (:n                        PROJECT_ID,:n        +
1                RESOURCE_ID,:n                        TSK_ASSIGNMENT_ID,:n   +
1                     DAY_YEAR,:n                        BIT_FLAG,:n          +
1              SCHED_MIN,:n                        BIT_SCHED,:n               +
1         PARENT_ID,:n                        ACTUAL_FLAG,:n                  +
1      TASK_ID ):n                        SELECT:n                        h_pr+
1oject_id,:n                        h_res_id,:n                        h_tsk_a+
1ssignment_id,:n                        DAY_YEAR,:n                        '0'+
1,:n                        h_minutes,:n                        h_bitID,:n    +
1                    CASE WHEN h_assigned = 0 THEN h_tsk_assignment_id ELSE h_+
1prj_assignment_id END,:n                        0,:n                        h+
1_task_id:n                        FROM PMO_TMP_CPLNF_0001:
12360:
1           EXCEPTION:: SP_A_RESTOPROF(2361) :: cplan.sql(11783) :: :
1UPDATE TASK_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0', :n    +
1                 PROJECT_ASSIGNMENT_ID = CASE WHEN h_assigned = 0 THEN NuLL E+
1LSE h_prj_assignment_id END,:n                     REGULAR_COST = CASE WHEN h+
1_donot_replace_cost = 0 THEN h_reg_cost  ELSE REGULAR_COST END,:n            +
1         SPECIAL_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost E+
1LSE SPECIAL_COST END,:n                     REGULAR_RATE = CASE WHEN h_donot_+
1replace_rate = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n                   +
1  SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPE+
1CIAL_RATE END,:n                     ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BI+
1TS, pmo_cnst.SC_SET_ALL_BITS):n                     WHERE TSK_ASSIGNMENT_ID =+
1 h_tsk_assignment_id:
12387:
1           EXCEPTION:: SP_A_RESTOPROF(2388) :: cplan.sql(11810) :: :
110000.00:
1SC_BIT_30:
110000:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET:n                        ROLLUP_BITS  = PMO_STPU.+
1BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS), ETC = ETC + h_effort:n        +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12430:
1           EXCEPTION:: SP_A_RESTOPROF(2431) :: cplan.sql(11853) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                              RESOURCE_ID = h_re+
1s_id, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           +
1   CASE WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n        +
1                      REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN +
1h_reg_cost  ELSE REGULAR_COST END,:n                              SPECIAL_COS+
1T = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END+
1,:n                              REGULAR_RATE = CASE WHEN h_donot_replace_rat+
1e = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n                              +
1SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECI+
1AL_RATE END,:n                              UNITS_MSP    = work001, ETC = h_e+
1ffort,:n                              C_CONTOUR    = contour001,:n           +
1                   ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SE+
1T_ALL_BITS):n                              WHERE TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
12475:
1           EXCEPTION:: SP_A_RESTOPROF(2476) :: cplan.sql(11898) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                              RESOURCE_ID = h_re+
1s_id, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           +
1   CASE WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n        +
1                      REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN +
1h_reg_cost  ELSE REGULAR_COST END,:n                              SPECIAL_COS+
1T = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END+
1,:n                              REGULAR_RATE = CASE WHEN h_donot_replace_rat+
1e = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n                              +
1SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECI+
1AL_RATE END,:n                              C_EFFORT     = work001, ETC = h_e+
1ffort,:n                              C_UNIT       = unit,:n                 +
1             C_CONTOUR    = contour001,:n                              ROLLUP+
1_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n            +
1                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12505:
1           EXCEPTION:: SP_A_RESTOPROF(2506) :: cplan.sql(11928) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           RESOURCE_ID = h_res_i+
1d, RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                           CAS+
1E WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n              +
1             REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cos+
1t  ELSE REGULAR_COST END,:n                           SPECIAL_COST = CASE WHE+
1N h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n         +
1                  REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_re+
1g_sale  ELSE REGULAR_RATE END,:n                           SPECIAL_RATE = CAS+
1E WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n    +
1                       ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.S+
1C_SET_ALL_BITS), ETC = h_effort:n                           WHERE TSK_ASSIGNM+
1ENT_ID = h_tsk_assignment_id:
12533:
1           EXCEPTION:: SP_A_RESTOPROF(2534) :: cplan.sql(11956) :: :
12562:
1           EXCEPTION:: SP_A_RESTOPROF(2563) :: cplan.sql(11985) :: :
12568:
1      RETURN_INVALID:: SP_A_RESTOPROF(2569) :: cplan.sql(11991) :: :
12571:
1                EXIT:: SP_A_RESTOPROF(2572) :: cplan.sql(11994) :: :
12585:
1           EXCEPTION:: SP_A_RESTOPROF(2586) :: cplan.sql(12008) :: :
12591:
1        RETURN_ERROR:: SP_A_RESTOPROF(2592) :: cplan.sql(12014) :: :
12594:
1                EXIT:: SP_A_RESTOPROF(2595) :: cplan.sql(12017) :: :
130:
11.5:
12637:
1           EXCEPTION:: SP_A_RESTOPROF(2638) :: cplan.sql(12060) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        RESOURCE_ID = h_res_id, +
1RESOURCE_TYPE='0', PROJECT_ASSIGNMENT_ID =:n                        CASE WHEN+
1 h_assigned = 0 THEN NuLL ELSE h_prj_assignment_id END,:n                    +
1    REGULAR_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cost  ELSE R+
1EGULAR_COST END,:n                        SPECIAL_COST = CASE WHEN h_donot_re+
1place_cost = 0 THEN h_spec_cost ELSE SPECIAL_COST END,:n                     +
1   REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_sale  ELSE RE+
1GULAR_RATE END,:n                        SPECIAL_RATE = CASE WHEN h_donot_rep+
1lace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RATE END,:n                      +
1  ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS), ETC +
1= h_effort:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_assignmen+
1t_id:
12664:
1           EXCEPTION:: SP_A_RESTOPROF(2665) :: cplan.sql(12087) :: :
13:
12721:
1           EXCEPTION:: SP_A_RESTOPROF(2722) :: cplan.sql(12144) :: :
12727:
1        RETURN_ERROR:: SP_A_RESTOPROF(2728) :: cplan.sql(12150) :: :
12730:
1                EXIT:: SP_A_RESTOPROF(2731) :: cplan.sql(12153) :: :
12744:
1           EXCEPTION:: SP_A_RESTOPROF(2745) :: cplan.sql(12167) :: :
12750:
1        RETURN_ERROR:: SP_A_RESTOPROF(2751) :: cplan.sql(12173) :: :
12753:
1                EXIT:: SP_A_RESTOPROF(2754) :: cplan.sql(12176) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1'') WHERE ELEMENT_ID=h_task_id:
12779:
1           EXCEPTION:: SP_A_RESTOPROF(2780) :: cplan.sql(12202) :: :
1C:
1PROFICIENCY_LEVEL_ID:
1EXPERIENCE_ID:
1PREFERENCE_LEVEL_ID:
1LAST_USED_DATETIME:
1TMT_COMPETENCIES:
1P:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_tsk_assignment_id,+
1 c.ELEMENT_ID, c.PROFICIENCY_LEVEL_ID, c.EXPERIENCE_ID, c.PREFERENCE_LEVEL_ID+
1, c.LAST_USED_DATETIME, '0':n               FROM TMT_COMPETENCIES c JOIN PROF+
1ILES p ON c.ELEMENT_ID = p.ROLE_ID WHERE p.PROFILE_ID = h_profile_id:
12801:
1           EXCEPTION:: SP_A_RESTOPROF(2802) :: cplan.sql(12224) :: :
1PRIMARY_ROLE:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_tsk_assignment_id,+
1 ROLE_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST_USED+
1_DATETIME, PRIMARY_ROLE:n               FROM RESOURCE_ASSIGN_ROLES WHERE RES_+
1ASSIGNMENT_ID = h_profile_id:
12823:
1           EXCEPTION:: SP_A_RESTOPROF(2824) :: cplan.sql(12246) :: :
1SKILL_ID:
1PRIMARY_SKILL:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n               SELECT h_tsk_assignment_id+
1, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST_US+
1ED_DATETIME, PRIMARY_SKILL:n               FROM RESOURCE_ASSIGN_SKILLS WHERE +
1RES_ASSIGNMENT_ID = h_profile_id:
12844:
1           EXCEPTION:: SP_A_RESTOPROF(2845) :: cplan.sql(12267) :: :
1FC_AFTER_REPLACE_RES_ASSIGN:
1UPDATE EFFORT_WEEK SET RESOURCE_ID = h_res_id:n               WHERE PROJECT_I+
1D = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12873:
1           EXCEPTION:: SP_A_RESTOPROF(2874) :: cplan.sql(12296) :: :
1ACTUAL_REGULAR_COST:
1ACTUAL_SPECIAL_COST:
1ACTUAL_REGULAR_RATE:
1ACTUAL_SPECIAL_RATE:
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  ACTU+
1AL_REGULAR_COST = h_reg_cost  ,:n                  ACTUAL_SPECIAL_COST = h_sp+
1ec_cost ,:n                  ACTUAL_REGULAR_RATE = h_reg_sale  ,:n           +
1       ACTUAL_SPECIAL_RATE = h_spec_sale ,:n                  REC_USER = h_re+
1c_user, REC_DATETIME = SYSTIMESTAMP:n                  WHERE TSK_ASSIGNMENT_I+
1D = h_id:
12900:
1           EXCEPTION:: SP_A_RESTOPROF(2901) :: cplan.sql(12323) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  ACTU+
1AL_REGULAR_COST = h_reg_cost  ,:n                  ACTUAL_SPECIAL_COST = h_sp+
1ec_cost ,:n                  REC_USER = h_rec_user, REC_DATETIME = SYSTIMESTA+
1MP:n                  WHERE TSK_ASSIGNMENT_ID = h_id:
12923:
1           EXCEPTION:: SP_A_RESTOPROF(2924) :: cplan.sql(12346) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  ACTU+
1AL_REGULAR_RATE = h_reg_sale  ,:n                  ACTUAL_SPECIAL_RATE = h_sp+
1ec_sale ,:n                  REC_USER = h_rec_user, REC_DATETIME = SYSTIMESTA+
1MP:n                  WHERE TSK_ASSIGNMENT_ID = h_id:
12948:
1           EXCEPTION:: SP_A_RESTOPROF(2949) :: cplan.sql(12371) :: :
1UPDATE SUMMARY_TIMESHEETS SET RESOURCE_ID = h_res_id,:n                  REC_+
1USER = h_rec_user, REC_DATETIME = SYSTIMESTAMP:n                  WHERE TSK_A+
1SSIGNMENT_ID = h_id:
12971:
1           EXCEPTION:: SP_A_RESTOPROF(2972) :: cplan.sql(12394) :: :
1FC_D_RA_AFTER_REPLACE:
12998:
1           EXCEPTION:: SP_A_RESTOPROF(2999) :: cplan.sql(12421) :: :
1>=:
13038:
1      RETURN_INVALID:: SP_A_RESTOPROF(3039) :: cplan.sql(12461) :: :
13041:
1                EXIT:: SP_A_RESTOPROF(3042) :: cplan.sql(12464) :: :
13046:
1        RETURN_ERROR:: SP_A_RESTOPROF(3047) :: cplan.sql(12469) :: :
13049:
1                EXIT:: SP_A_RESTOPROF(3050) :: cplan.sql(12472) :: :
1DELETE FROM PMO_TMP_PA_SUM:
1PMO_TMP_PA_SUM:
1INSERT INTO PMO_TMP_PA_SUM SELECT DAY_YEAR, SUM(SCHED_MIN):n               FR+
1OM TASK_DAY_OF_YEAR:n               WHERE PROJECT_ID = h_project_id AND PAREN+
1T_ID = h_prj_assignment_id:n               GROUP BY DAY_YEAR:
13075:
1           EXCEPTION:: SP_A_RESTOPROF(3076) :: cplan.sql(12498) :: :
13105:
1        RETURN_ERROR:: SP_A_RESTOPROF(3106) :: cplan.sql(12528) :: :
13108:
1                EXIT:: SP_A_RESTOPROF(3109) :: cplan.sql(12531) :: :
13113:
1        RETURN_ERROR:: SP_A_RESTOPROF(3114) :: cplan.sql(12536) :: :
13116:
1                EXIT:: SP_A_RESTOPROF(3117) :: cplan.sql(12539) :: :
1UPDATE TASK_ASSIGNMENTS SET RES_ASSIGNMENT_ID = h_prj_assign_id,:n           +
1       RESOURCE_ID  = h_res_id, RESOURCE_TYPE = '0',:n                  REGUL+
1AR_COST = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_cost  * h_rate_echang+
1e ELSE REGULAR_COST END,:n                  SPECIAL_COST = CASE WHEN h_donot_+
1replace_rate = 0 THEN h_spec_cost * h_rate_echange ELSE SPECIAL_COST END,:n  +
1                REGULAR_RATE = CASE WHEN h_donot_replace_cost = 0 THEN h_reg_+
1sale  * h_rate_echange ELSE REGULAR_RATE END,:n                  SPECIAL_RATE+
1 = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_sale * h_rate_echange ELSE +
1SPECIAL_RATE END:n                  WHERE TSK_ASSIGNMENT_ID = h_prj_assignmen+
1t_id:
13141:
1           EXCEPTION:: SP_A_RESTOPROF(3142) :: cplan.sql(12564) :: :
1UPDATE TASK_DAY_OF_YEAR:n            SET PARENT_ID = h_prj_assignment_id:n   +
1         WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assign+
1ment_id:
13164:
1           EXCEPTION:: SP_A_RESTOPROF(3165) :: cplan.sql(12587) :: :
1SELECT COUNT(*) INTO h_count FROM RESOURCE_ASSIGNMENTS:n         WHERE ELEMEN+
1T_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
13181:
1           EXCEPTION:: SP_A_RESTOPROF(3182) :: cplan.sql(12604) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1''):n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_i+
1d:
13203:
1           EXCEPTION:: SP_A_RESTOPROF(3204) :: cplan.sql(12626) :: :
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_ASS+
1IGNMENT_BIT) WHERE ELEMENT_ID = h_project_id:
13228:
1           EXCEPTION:: SP_A_RESTOPROF(3229) :: cplan.sql(12651) :: :
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS:n            WHERE PROJECT+
1_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_old_prj_assign_id:
13246:
1           EXCEPTION:: SP_A_RESTOPROF(3247) :: cplan.sql(12669) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND:n       +
1        ELEMENT_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE+
1_TYPE = '1':
13268:
1           EXCEPTION:: SP_A_RESTOPROF(3269) :: cplan.sql(12691) :: :
13287:
1           EXCEPTION:: SP_A_RESTOPROF(3288) :: cplan.sql(12710) :: :
1BEST:
1BAK_START_DT:
1BAK_FINISH_DT:
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n            INTO h_start_DT, h_finish_DT, h_effort, h_s+
1tart_D, h_finish_D, h_billable, h_capital_expense, h_old_cost, h_old_sale:n  +
1          FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
13311:
1           EXCEPTION:: SP_A_RESTOPROF(3312) :: cplan.sql(12734) :: :
1ESTIMATED_PLANNED_START:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_PLANNED_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = 0.00:n                  WHERE PROJECT_ID = h_project_id AND +
1RESOURCE_ID = h_profile_id:
13337:
1           EXCEPTION:: SP_A_RESTOPROF(3338) :: cplan.sql(12760) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                  ESTIMATED_PLANNED_START = h+
1_start_DT,:n                  ESTIMATED_PLANNED_FINISH = h_finish_DT,:n      +
1            ESTIMATED_PLANNED_EFFORT = h_effort,:n                  ESTIMATED+
1_PLANNED_COST = (h_effort/60.00) * h_old_cost,:n                  ESTIMATED_P+
1LANNED_REVENUE = (h_effort/60.00) * h_old_sale:n                  WHERE PROJE+
1CT_ID = h_project_id AND RESOURCE_ID = h_profile_id:
13362:
1           EXCEPTION:: SP_A_RESTOPROF(3363) :: cplan.sql(12785) :: :
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n         INTO h_start_DT, h_finish_DT, h_effort, h_star+
1t_D, h_finish_D, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n     +
1    FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
13401:
1           EXCEPTION:: SP_A_RESTOPROF(3402) :: cplan.sql(12824) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n            ESTIMATED_PLANNED_START  = h_star+
1t_DT,:n            ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            ESTIM+
1ATED_PLANNED_EFFORT = h_effort,:n            ESTIMATED_PLANNED_COST   = (h_ef+
1fort/60.00) * h_reg_cost,:n            ESTIMATED_PLANNED_REVENUE = 0.00:n    +
1        WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_res_id:
13428:
1           EXCEPTION:: SP_A_RESTOPROF(3429) :: cplan.sql(12851) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n            ESTIMATED_PLANNED_START  = h_star+
1t_DT,:n            ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            ESTIM+
1ATED_PLANNED_EFFORT = h_effort,:n            ESTIMATED_PLANNED_COST   = (h_ef+
1fort/60.00) * h_reg_cost,:n            ESTIMATED_PLANNED_REVENUE = (h_effort/+
160.00) * h_reg_sale:n            WHERE PROJECT_ID = h_project_id AND RESOURCE+
1_ID = h_res_id:
13453:
1           EXCEPTION:: SP_A_RESTOPROF(3454) :: cplan.sql(12876) :: :
1FC_ROLLUP:
13476:
1       RETURN_STATUS:: SP_A_RESTOPROF(3477) :: cplan.sql(12899) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
13483:
1           EXCEPTION:: SP_A_RESTOPROF(3484) :: cplan.sql(12906) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
13495:
1           EXCEPTION:: SP_A_RESTOPROF(3496) :: cplan.sql(12918) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
5293
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c :3 a0 51 a5 b a5
b 5a 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a0 f4 b4 bf c8 :5 a0
12a bd b7 11 a4 b1 a0 f4
b4 bf c8 :9 a0 12a bd b7 11
a4 b1 a0 f4 b4 bf c8 :6d a0
12a bd b7 11 a4 b1 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :4 a0 51 a5 b
:2 a0 6b a5 b d :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a 52 10 a0 51 d
b7 19 3c :2 a0 d a0 6e d
a0 6e d a0 51 d a0 6e
d a0 4d d a0 4d d :2 a0
e9 dd b3 :2 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :3 a0 6b d :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :f a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 51 d :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:25 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :7 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e a0 6e
d b7 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d :4 a0 51 a5 b 51 a5 b
d :b a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :b a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e 7e b4 2e a0
51 d :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 19
3c b7 19 3c a0 b7 :3 a0 51
a5 b a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
52 10 5a a 10 a0 51 d
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 19 3c a0
6e d a0 6e d a0 6e d
a0 4d d a0 4d d a0 4d
d :2 a0 e9 dd b3 :2 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
51 d b7 a0 51 d b7 :2 19
3c :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 19 3c :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :b a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 7e b4 2e a 10 a0
6e d :2 a0 b4 2e d :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b d b7 :2 a0 51 :2 a0
51 a5 b :2 a0 6b a0 a5 b
d :3 a0 6b d b7 :2 19 3c a0
6e d a0 51 d :9 a0 a5 b
d :4 a0 51 a5 b a5 b d
:19 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 a5 b 7e 51 b4
2e a0 51 d b7 :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :11 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :11 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a :11 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e d :6 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :6 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 6e d b7 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e 7e b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :a a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 a5 b d
a0 b7 :3 a0 51 a5 b :2 a0 6b
a5 b 5a a0 7e a0 6b b4
2e :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 a5 b d a0 b7 19
:3 a0 51 a5 b :2 a0 6b a5 b
5a a0 7e a0 6b b4 2e :b a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
a5 b d b7 :2 19 3c b7 19
3c b7 :2 19 3c :16 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
51 d b7 19 3c a0 6e d
a0 6e d a0 6e d :2 a0 b4
2e d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :c a0 a5
b d :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
b7 19 3c a0 51 d a0 51
d :6 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 4d d :c a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:7 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 a5 b 7e
51 b4 2e 7e b4 2e a0 7e
b4 2e 5a a0 51 d :23 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
a0 7e 51 b4 2e d :2 a0 6b
:b a0 a5 b d b7 19 3c a0
51 d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 52 10 :3 a0 51 a5 b
:2 a0 6b a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c b7 :2 19 3c b7 19 3c :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d b7 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 51 d
a0 51 d a0 7e b4 2e 5a
:2 a0 :2 51 a5 b 7e 6e b4 2e
a0 7e 51 b4 2e d :2 a0 6b
:b a0 a5 b d b7 19 3c :1b a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :3 a0 :2 51
a5 b 7e 6e b4 2e 51 a6
122 51 122 124 d :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :8 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :7 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c b7 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e 7e b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c a0 7e 51 b4 2e :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 51 a5 b
7e 51 b4 2e :1e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :22 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :1a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :16 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :1a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 :c a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c a0 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d b7 :3 a0 6b :2 a0 51 a5 b
:2 a0 6b a5 b d b7 :2 19 3c
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b d b7 19 3c a0
51 d a0 51 d :2 a0 6b a0
51 a5 b 7e 51 b4 2e a0
51 d b7 a0 51 d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 19 3c :6 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :3 a0
a5 b d :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 :2 19
3c a0 51 d :1e a0 :5 51 a5 b
d a0 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 a0
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 a0 51 d
:7 a0 51 a5 b :2 a0 51 a5 b
a5 b d b7 :2 19 3c b7 19
3c b7 19 3c :3 a0 6b d :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 19 3c a0
51 d b7 19 3c :3 a0 7e 6e
b4 2e :2 51 a5 b d a0 6e
d :2 a0 d :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
a0 51 d a0 51 d :2 a0 d
:2 a0 e9 dd b3 :17 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c a0 51 d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b d :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d b7
19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 7e 51 b4 2e d
:2 a0 6b :b a0 a5 b d :c a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :3 a0
51 a5 b :2 a0 6b a5 b 5a
a0 7e a0 6b b4 2e a0 51
d :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 :2 a0
51 a5 b :2 a0 6b a0 a5 b
d :d a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :3 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :22 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a a 10
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 51 d :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
:2 51 a5 b 7e 6e b4 2e a0
51 d b7 19 3c :2 a0 d b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :7 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 b7 :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 52 10 :2 a0 6e 11e 11d
:2 a0 6b 51 d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :1c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 51 d :7 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
a0 3b b7 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :5 a0 a5 b 51 a5
b 7e :3 a0 a5 b 51 a5 b
b4 2e 5a 7e 51 b4 2e a5
b d :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 6b :2 a0 51 a5 b a0 a5
57 b7 19 3c :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :1f a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
a5 b 51 a5 b 7e :3 a0 a5
b 51 a5 b b4 2e 5a 7e
51 b4 2e a5 b d :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d :7 a0 51 a5 b :2 a0 51 a5
b a5 b d b7 a0 3b b7
:2 19 3c b7 a0 6e d a0 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
51 a5 b 7e 51 b4 2e a
10 a0 51 d :3 a0 51 a5 b
d b7 19 3c :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :3 a0
51 a5 b :2 a0 6b a5 b 5a
7e 51 b4 2e 5a :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 52 10 5a
a 10 :2 a0 51 a5 b 7e 51
b4 2e :25 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :27 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :21 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 51
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :3 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 :2 19 3c b7 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 51 a5 b 7e 51 b4
2e a 10 a0 51 d :3 a0 51
a5 b d b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a 52 10 :3 a0 51
a5 b d b7 :4 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e a5
b d b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e 51 b4 2e d b7 :5 a0
51 a5 b a5 b 7e 51 b4
2e a5 b d b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:21 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c a0 51
d :2 a0 51 a5 b a0 7e a0
6b b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
b7 :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b d b7 :2 19 3c a0
51 d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :4 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a 7e 51
b4 2e 5a 7e 51 b4 2e a5
b d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :3 a0 51
a5 b d :4 a0 51 a5 b 7e
51 b4 2e 5a 7e :2 a0 51 a5
b b4 2e 7e 51 b4 2e a5
b d b7 19 3c a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :3 a0 51 a5 b d
b7 :2 19 3c b7 19 3c :1e a0 :5 51
a5 b d a0 7e 51 b4 2e
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 a0 b7 a0 7e 51 b4
2e :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 :2 19
3c :7 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :18 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b 7e 51 b4
2e d :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d a0 6e
d :5 a0 a5 b d a0 6e d
:5 a0 a5 b d :7 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:11 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :d a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b d a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :d a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b d b7
19 :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b d :3 a0 51
a5 b d b7 :2 19 3c b7 19
3c b7 :2 19 3c :2 a0 6b :4 a0 a5
b d 93 4f b0 46 b7 a0
47 :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 a0 7e b4
2e :2 5a a 10 :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
a0 51 d a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 :2 19 3c :6 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :3 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :a a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
6e d a0 51 d a0 51 d
a0 51 d a0 51 d :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d a0 51 d b7 a0 51 d
b7 :2 19 3c a0 51 d :1e a0 :5 51
a5 b d a0 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 a0
b7 a0 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 :1c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c a0 b7 a0
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 a0 7e
b4 2e 5a a 10 :7 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:8 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
a0 51 d a0 7e b4 2e 5a
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:7 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d :5 a0 :2 51 a5 b d
:19 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e 5a
a0 51 d :2 a0 6b :b a0 a5 b
d b7 19 3c b7 19 3c a0
7e b4 2e :2 5a :2 a0 6b :2 a0 a5
b 7e 51 b4 2e 5a a 10
a0 51 d b7 19 3c b7 19
3c b7 19 3c a0 7e b4 2e
5a a0 51 d :5 a0 :2 51 a5 b
d :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 51 d :2 a0 6b
:b a0 a5 b d b7 19 3c b7
19 3c :3 a0 a5 b d :2 a0 6b
7e 51 b4 2e :2 a0 6b 51 d
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
5293
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 175 155
159 15c 15d 165 169 16d 170 154
192 180 151 184 185 18d 17f 1af
19d 17c 1a1 1a2 1aa 19c 1cc 1ba
199 1be 1bf 1c7 1b9 1e9 1d7 1b6
1db 1dc 1e4 1d6 206 1f4 1d3 1f8
1f9 201 1f3 223 211 1f0 215 216
21e 210 240 22e 20d 232 233 23b
22d 25d 24b 22a 24f 250 258 24a
27a 268 247 26c 26d 275 267 297
285 264 289 28a 292 284 2b4 2a2
281 2a6 2a7 2af 2a1 2d1 2bf 29e
2c3 2c4 2cc 2be 2ee 2dc 2bb 2e0
2e1 2e9 2db 30a 2f9 2fd 305 2d8
322 311 315 31d 2f8 33e 32d 331
339 2f5 356 345 349 351 32c 373
361 329 365 366 36e 360 390 37e
35d 382 383 38b 37d 3ac 39b 39f
3a7 37a 3c4 3b3 3b7 3bf 39a 3e0
3cf 3d3 3db 397 3fc 3e7 3eb 3ee
3ef 3f7 3ce 419 407 3cb 40b 40c
414 406 435 424 428 430 403 44d
43c 440 448 423 469 458 45c 464
420 481 470 474 47c 457 49e 48c
454 490 491 499 48b 4bb 4a9 488
4ad 4ae 4b6 4a8 4d8 4c6 4a5 4ca
4cb 4d3 4c5 4f5 4e3 4c2 4e7 4e8
4f0 4e2 512 500 4df 504 505 50d
4ff 52e 51d 521 4fc 529 51c 54a
539 53d 519 545 538 566 555 559
535 561 554 582 571 575 551 57d
570 59e 58d 591 56d 599 58c 5ba
5a9 5ad 589 5b5 5a8 5d6 5c5 5c9
5a5 5d1 5c4 5f2 5e1 5e5 5c1 5ed
5e0 60e 5fd 601 5dd 609 5fc 62a
619 61d 5f9 625 618 646 635 639
615 641 634 662 651 655 631 65d
650 67e 66d 671 64d 679 66c 69a
689 68d 669 695 688 6b6 6a5 6a9
685 6b1 6a4 6d2 6c1 6c5 6a1 6cd
6c0 6ee 6dd 6e1 6bd 6e9 6dc 70a
6f9 6fd 6d9 705 6f8 726 715 719
6f5 721 714 742 731 735 711 73d
730 75e 74d 751 72d 759 74c 77a
769 76d 749 775 768 796 785 789
765 791 784 7b2 7a1 7a5 781 7ad
7a0 7ce 7bd 7c1 79d 7c9 7bc 7ea
7d9 7dd 7b9 7e5 7d8 806 7f5 7f9
7d5 801 7f4 822 811 815 7f1 81d
810 83e 82d 831 80d 839 82c 85a
849 84d 829 855 848 876 865 869
845 871 864 892 881 885 861 88d
880 8ae 89d 8a1 87d 8a9 89c 8ca
8b9 8bd 899 8c5 8b8 8e6 8d5 8d9
8b5 8e1 8d4 902 8f1 8f5 8d1 8fd
8f0 91e 90d 911 8ed 919 90c 93a
929 92d 909 935 928 956 945 949
925 951 944 972 961 965 941 96d
960 98e 97d 981 95d 989 97c 9aa
999 99d 979 9a5 998 9c6 9b5 9b9
995 9c1 9b4 9e3 9d1 9b1 9d5 9d6
9de 9d0 a00 9ee 9cd 9f2 9f3 9fb
9ed a1c a0b a0f 9ea a17 a0a a38
a27 a2b a07 a33 a26 a55 a43 a23
a47 a48 a50 a42 a71 a60 a64 a3f
a6c a5f a8e a7c a5c a80 a81 a89
a7b aab a99 a78 a9d a9e aa6 a98
ac7 ab6 aba a95 ac2 ab5 ae3 ad2
ad6 ab2 ade ad1 aff aee af2 afa
ace b17 b06 b0a b12 aed b33 b22
b26 aea b2e b21 b4f b3e b42 b1e
b4a b3d b6b b5a b5e b3a b66 b59
b87 b76 b7a b56 b82 b75 ba3 b92
b96 b72 b9e b91 bbf bae bb2 b8e
bba bad bdb bca bce baa bd6 bc9
bf7 be6 bea bc6 bf2 be5 c13 c02
c06 be2 c0e c01 c2f c1e c22 bfe
c2a c1d c4b c3a c3e c1a c46 c39
c68 c56 c36 c5a c5b c63 c55 c85
c73 c52 c77 c78 c80 c72 ca2 c90
c6f c94 c95 c9d c8f cbe cad cb1
c8c cb9 cac cef cc9 ccd cd5 cd9
cdd ca9 ce1 ce2 ce4 ce5 ce7 cea
cc8 d0b cfa cfe cc5 d06 cf9 d27
d16 d1a cf6 d22 d15 d43 d32 d36
d3e d12 d5b d4a d4e d56 d31 d62
d66 d2e d77 d7a d7e d82 d86 d8a
d8e d92 d9e da3 da5 db1 db5 db7
dbb dcc dcd dd0 dd4 dd8 ddc de0
de4 de8 dec df0 df4 df8 e04 e09
e0b e17 e1b e1d e21 e32 e33 e36
e3a e3e e42 e46 e4a e4e e52 e56
e5a e5e e62 e66 e6a e6e e72 e76
e7a e7e e82 e86 e8a e8e e92 e96
e9a e9e ea2 ea6 eaa eae eb2 eb6
eba ebe ec2 ec6 eca ece ed2 ed6
eda ede ee2 ee6 eea eee ef2 ef6
efa efe f02 f06 f0a f0e f12 f16
f1a f1e f22 f26 f2a f2e f32 f36
f3a f3e f42 f46 f4a f4e f52 f56
f5a f5e f62 f66 f6a f6e f72 f76
f7a f7e f82 f86 f8a f8e f92 f96
f9a f9e fa2 fa6 faa fae fb2 fb6
fba fbe fc2 fc6 fca fce fd2 fd6
fda fde fe2 fe6 fea fee ffa fff
1001 100d 1011 102f 1017 101b 101f 1022
102a 1016 1036 103a 1013 103e 1042 1046
1049 104e 104f 1 1051 1056 105a 105e
1061 1066 106a 106e 1071 1076 1077 1079
107e 1081 1085 1086 108b 1090 1093 1098
1099 109e 10a1 10a5 10a6 10ab 10ae 10b3
10b4 10b9 10bc 10c1 10c2 10c7 10ca 10cf
10d0 10d5 10d8 10dc 10dd 10e2 10e5 10ea
10eb 10f0 10f3 10f8 10f9 10fe 1101 1106
1107 110c 110f 1113 1114 1119 111c 1121
1122 1127 112a 112f 1130 1135 1138 113d
113e 1143 1146 114a 114b 1150 1153 1158
1159 115e 1161 1166 1167 116c 116f 1174
1175 117a 117d 1181 1182 1187 118a 118f
1190 1195 1198 119d 119e 11a3 11a6 11aa
11ae 11b2 11b3 11b5 11ba 11bb 11bd 11be
11c3 11c6 11cb 11cc 11d1 11d4 11d8 11dc
11e0 11e1 11e3 11e8 11e9 11eb 11ec 11f1
11f4 11f9 11fa 11ff 1202 1206 120a 120e
120f 1211 1216 1217 1219 121a 121f 1222
1227 1228 122d 1230 1234 1238 123c 123d
123f 1244 1245 1247 1248 124d 1250 1255
1256 125b 125e 1262 1266 126a 126b 126d
1272 1273 1275 1276 127b 127e 1283 1284
1289 128c 1290 1294 1298 1299 129b 12a0
12a1 12a3 12a4 12a9 12ac 12b1 12b2 12b7
12ba 12be 12c2 12c6 12c7 12c9 12ce 12cf
12d1 12d2 12d7 12da 12df 12e0 12e5 12e8
12ec 12f0 12f4 12f5 12f7 12fc 12fd 12ff
1300 1305 1308 130d 130e 1313 1316 131a
131e 1322 1323 1325 132a 132b 132d 132e
1333 1336 133b 133c 1341 1344 1349 134a
134f 1352 1356 1357 135c 135f 1364 1365
136a 136d 1372 1373 1378 1379 137e 1380
1384 1387 138b 138f 1392 1396 139a 139d
13a0 13a5 13a8 13ab 13ae 13af 13b4 13b5
1 13b7 13bc 13c0 13c4 13c7 13cc 13d1
13d4 13d8 13d9 13de 13df 13e4 13e6 13ea
13ed 13f1 13f5 13f9 13fd 1401 1405 1409
140d 1411 1415 1419 141d 1421 1425 1429
142d 1431 1435 1439 143d 1441 1445 1448
1449 144b 144f 1453 1456 1457 1459 145d
1461 1465 1468 1469 146b 146f 1472 1476
1479 147a 147f 1482 1486 148a 148d 148e
1490 1494 1497 149b 149e 149f 14a4 1
14a7 14ac 14b0 14b3 14b7 14b9 14bd 14c0
14c4 14c8 14cc 14d0 14d5 14d9 14dd 14e2
14e6 14ea 14ed 14f1 14f5 14fa 14fe 1502
1503 1507 150b 150c 1510 1514 1518 151d
1521 1522 1526 152a 152f 1534 1538 153c
1541 1545 1549 154c 154f 1553 1555 1559
155d 1560 1563 1567 1569 156d 1571 1574
1578 157c 1580 1583 1587 158b 158f 1594
1596 159a 159e 15a1 15a5 15a9 15ab 15af
15b3 15b7 15ba 15be 15c2 15c4 15c5 15ca
1 15ce 15d2 15d6 15d9 15dd 15e1 15e5
15e9 15ec 15f0 15f4 15f7 15fa 15ff 1602
1605 1608 1609 160e 160f 1 1611 1616
161a 161e 1621 1626 162b 162e 1632 1633
1638 163b 1640 1641 1646 1649 164e 164f
1654 1657 165b 165c 1661 1664 1669 166a
166f 1672 1676 167a 167d 1680 1681 1683
1684 1689 168a 168f 1691 1695 1698 169a
169e 16a0 16ac 16ae 16b0 16b1 16b6 16ba
16bc 16c8 16ca 16ce 16d2 16d5 16d6 16d8
16db 16de 16df 16e4 16e8 16ec 16ef 16f3
16f7 16fa 16fd 1702 1705 1708 170b 170c
1711 1712 1 1714 1719 171d 1721 1724
1729 172e 1731 1735 1736 173b 173e 1743
1744 1749 174c 1751 1752 1757 175a 175e
1762 1766 176a 176d 176e 1770 1775 1776
1778 1779 177e 1781 1786 1787 178c 178f
1794 1795 179a 179d 17a1 17a2 17a7 17aa
17af 17b0 17b5 17b6 17bb 17bd 17c1 17c4
17c8 17cc 17cf 17d3 17d7 17da 17dd 17e2
17e5 17e8 17eb 17ec 17f1 17f2 1 17f4
17f9 17fd 1801 1804 1809 180e 1811 1815
1816 181b 181c 1821 1823 1827 182a 182e
1832 1835 1839 183d 1840 1844 1848 1849
184e 1850 1854 1857 185b 185f 1863 1867
186b 186f 1873 1877 187b 187f 1883 1887
188b 188f 1893 189f 18a3 18a7 18aa 18ae
18b2 18b4 18b8 18bc 18c0 18c3 18c7 18cb
18cd 18ce 18d3 1 18d7 18db 18df 18e2
18e6 18ea 18ee 18f2 18f5 18f9 18fd 1900
1903 1908 190b 190e 1911 1912 1917 1918
1 191a 191f 1923 1927 192a 192f 1934
1937 193b 193c 1941 1944 1949 194a 194f
1952 1957 1958 195d 1960 1964 1965 196a
196d 1972 1973 1978 197b 197f 1983 1986
1989 198a 198c 198d 1992 1993 1998 199a
199e 19a1 19a3 19a7 19a9 19b5 19b7 19b9
19ba 19bf 19c3 19c5 19d1 19d3 19d7 19db
19de 19e2 19e5 19e9 19ec 19ed 19f2 19f5
19f9 19fd 1a00 1a04 1a08 1a0b 1a0e 1a13
1a16 1a19 1a1c 1a1d 1a22 1a23 1 1a25
1a2a 1a2e 1a32 1a35 1a3a 1a3f 1a42 1a46
1a47 1a4c 1a4f 1a54 1a55 1a5a 1a5d 1a62
1a63 1a68 1a6b 1a6f 1a73 1a77 1a7b 1a7e
1a7f 1a81 1a86 1a87 1a89 1a8a 1a8f 1a92
1a97 1a98 1a9d 1aa0 1aa5 1aa6 1aab 1aae
1ab2 1ab3 1ab8 1abb 1ac0 1ac1 1ac6 1ac7
1acc 1ace 1ad2 1ad5 1ad9 1add 1ae0 1ae4
1ae8 1aeb 1aee 1af3 1af6 1af9 1afc 1afd
1b02 1b03 1 1b05 1b0a 1b0e 1b12 1b15
1b1a 1b1f 1b22 1b26 1b27 1b2c 1b2d 1b32
1b34 1b38 1b3b 1b3f 1b43 1b46 1b4a 1b4e
1b51 1b55 1b59 1b5a 1b5f 1b61 1b65 1b68
1b6c 1b6f 1b73 1b77 1b7b 1b7f 1b83 1b87
1b93 1b97 1b9b 1b9e 1ba2 1ba6 1ba8 1bac
1bb0 1bb4 1bb7 1bbb 1bbf 1bc1 1bc2 1bc7
1 1bcb 1bcf 1bd3 1bd6 1bda 1bde 1be2
1be6 1be9 1bed 1bf1 1bf4 1bf7 1bfc 1bff
1c02 1c05 1c06 1c0b 1c0c 1 1c0e 1c13
1c17 1c1b 1c1e 1c23 1c28 1c2b 1c2f 1c30
1c35 1c38 1c3d 1c3e 1c43 1c46 1c4b 1c4c
1c51 1c54 1c58 1c59 1c5e 1c61 1c66 1c67
1c6c 1c6f 1c73 1c77 1c7a 1c7d 1c7e 1c80
1c81 1c86 1c87 1c8c 1c8e 1c92 1c95 1c97
1c9b 1c9d 1ca9 1cab 1cad 1cae 1cb3 1cb7
1cb9 1cc5 1cc7 1ccb 1ccf 1cd2 1cd3 1cd5
1cd8 1cdb 1cdc 1ce1 1ce5 1ce9 1cec 1cf0
1cf4 1cf7 1cfa 1cff 1d02 1d05 1d08 1d09
1d0e 1d0f 1 1d11 1d16 1d1a 1d1e 1d21
1d26 1d2b 1d2e 1d32 1d33 1d38 1d3b 1d40
1d41 1d46 1d49 1d4e 1d4f 1d54 1d57 1d5b
1d5f 1d63 1d67 1d6a 1d6b 1d6d 1d72 1d73
1d75 1d76 1d7b 1d7e 1d83 1d84 1d89 1d8c
1d91 1d92 1d97 1d9a 1d9e 1d9f 1da4 1da7
1dac 1dad 1db2 1db3 1db8 1dba 1dbe 1dc1
1dc5 1dc9 1dcc 1dd0 1dd4 1dd7 1dda 1ddf
1de2 1de5 1de8 1de9 1dee 1def 1 1df1
1df6 1dfa 1dfe 1e01 1e06 1e0b 1e0e 1e12
1e13 1e18 1e19 1e1e 1e20 1e24 1e27 1e2b
1e2f 1e32 1e36 1e3a 1e3d 1e41 1e45 1e46
1e4b 1e4d 1e51 1e54 1e58 1e5c 1e60 1e64
1e68 1e6c 1e70 1e74 1e78 1e7c 1e80 1e84
1e88 1e8c 1e90 1e94 1e98 1e9c 1ea0 1ea4
1ea8 1eac 1eb0 1eb4 1eb8 1ebc 1ec0 1ec4
1ec8 1ecc 1ed0 1ed4 1ed8 1edc 1ee0 1ee4
1ee8 1ef4 1ef8 1efc 1eff 1f03 1f07 1f09
1f0d 1f11 1f15 1f18 1f1c 1f20 1f22 1f23
1f28 1 1f2c 1f30 1f34 1f37 1f3b 1f3f
1f43 1f47 1f4a 1f4e 1f52 1f55 1f58 1f5d
1f60 1f63 1f66 1f67 1f6c 1f6d 1 1f6f
1f74 1f78 1f7c 1f7f 1f84 1f89 1f8c 1f90
1f91 1f96 1f99 1f9e 1f9f 1fa4 1fa7 1fac
1fad 1fb2 1fb5 1fb9 1fba 1fbf 1fc2 1fc7
1fc8 1fcd 1fd0 1fd4 1fd8 1fdb 1fde 1fdf
1fe1 1fe2 1fe7 1fe8 1fed 1fef 1ff3 1ff6
1ff8 1ffc 1ffe 200a 200c 200e 200f 2014
2018 201a 2026 2028 202c 2030 2033 2037
203a 203e 2041 2042 2047 204a 204e 2052
2055 2059 205d 2060 2063 2068 206b 206e
2071 2072 2077 2078 1 207a 207f 2083
2087 208a 208f 2094 2097 209b 209c 20a1
20a4 20a9 20aa 20af 20b2 20b7 20b8 20bd
20c0 20c4 20c8 20cc 20d0 20d3 20d4 20d6
20db 20dc 20de 20df 20e4 20e7 20ec 20ed
20f2 20f5 20fa 20fb 2100 2103 2107 2108
210d 2110 2115 2116 211b 211c 2121 2123
2127 212a 212e 2132 2135 2139 213d 2140
2143 2148 214b 214e 2151 2152 2157 2158
1 215a 215f 2163 2167 216a 216f 2174
2177 217b 217c 2181 2182 2187 2189 218d
2190 2194 2198 219b 219f 21a3 21a6 21aa
21ae 21af 21b4 21b6 21ba 21bd 21c1 21c5
21c9 21cd 21d1 21d5 21d9 21e5 21e9 21ed
21f0 21f4 21f8 21fa 21fe 2202 2206 2209
220d 2211 2213 2214 2219 1 221d 2221
2225 2228 222c 2230 2234 2238 223b 223f
2243 2246 2249 224e 2251 2254 2257 2258
225d 225e 1 2260 2265 2269 226d 2270
2275 227a 227d 2281 2282 2287 228a 228f
2290 2295 2298 229d 229e 22a3 22a6 22aa
22ab 22b0 22b3 22b8 22b9 22be 22c1 22c5
22c9 22cc 22cf 22d0 22d2 22d3 22d8 22d9
22de 22e0 22e4 22e7 22e9 22ed 22ef 22fb
22fd 22ff 2300 2305 2309 230b 2317 2319
231d 2321 2324 2328 232b 232f 2332 2333
2338 233b 233f 2343 2346 234a 234e 2351
2354 2359 235c 235f 2362 2363 2368 2369
1 236b 2370 2374 2378 237b 2380 2385
2388 238c 238d 2392 2395 239a 239b 23a0
23a3 23a8 23a9 23ae 23b1 23b5 23b9 23bd
23c1 23c4 23c5 23c7 23cc 23cd 23cf 23d0
23d5 23d8 23dd 23de 23e3 23e6 23eb 23ec
23f1 23f4 23f8 23f9 23fe 2401 2406 2407
240c 240d 2412 2414 2418 241b 241f 2423
2426 242a 242e 2431 2434 2439 243c 243f
2442 2443 2448 2449 1 244b 2450 2454
2458 245b 2460 2465 2468 246c 246d 2472
2473 2478 247a 247e 2481 2485 2489 248c
2490 2494 2497 249b 249f 24a0 24a5 24a7
24ab 24ae 24b2 24b6 24ba 24be 24c2 24ce
24d2 24d6 24d9 24dd 24e1 24e3 24e7 24eb
24ef 24f2 24f6 24fa 24fc 24fd 2502 1
2506 250a 250e 2511 2515 2519 251d 2521
2524 2528 252c 252f 2532 2537 253a 253d
2540 2541 2546 2547 1 2549 254e 2552
2556 2559 255e 2563 2566 256a 256b 2570
2573 2578 2579 257e 2581 2586 2587 258c
258f 2593 2594 2599 259c 25a1 25a2 25a7
25aa 25ae 25b2 25b5 25b8 25b9 25bb 25bc
25c1 25c2 25c7 25c9 25cd 25d0 25d2 25d6
25d8 25e4 25e6 25e8 25e9 25ee 25f2 25f4
2600 2602 2606 260a 260d 2611 2616 2617
2619 261c 261f 2620 2625 2629 262e 2632
2634 2638 263b 263f 2643 2646 264a 264d
2651 2654 2655 265a 265d 2661 2665 2668
266c 2670 2673 2676 267b 267e 2681 2684
2685 268a 268b 1 268d 2692 2696 269a
269d 26a2 26a7 26aa 26ae 26af 26b4 26b7
26bc 26bd 26c2 26c5 26ca 26cb 26d0 26d3
26d7 26db 26df 26e3 26e6 26e7 26e9 26ee
26ef 26f1 26f2 26f7 26fa 26ff 2700 2705
2708 270d 270e 2713 2716 271a 271b 2720
2723 2728 2729 272e 272f 2734 2736 273a
273d 2741 2745 2748 274c 2750 2753 2756
275b 275e 2761 2764 2765 276a 276b 1
276d 2772 2776 277a 277d 2782 2787 278a
278e 278f 2794 2795 279a 279c 27a0 27a3
27a7 27ab 27ae 27b2 27b6 27b9 27bd 27c1
27c2 27c7 27c9 27cd 27d0 27d4 27d8 27dc
27e0 27e4 27e8 27ec 27ef 27f0 27f2 27f5
27f6 27f8 27fc 2800 2804 2808 280c 280f
2810 2812 2815 2816 2818 281c 2820 2824
2828 282c 282f 2830 2832 2835 2836 2838
283c 2840 2844 2848 284c 2850 2854 2858
285c 2860 2864 2868 2874 2878 287c 287f
2883 2887 2889 288d 2891 2895 2898 289c
28a0 28a2 28a3 28a8 1 28ac 28b0 28b4
28b7 28bb 28bf 28c3 28c7 28ca 28ce 28d2
28d5 28d8 28dd 28e0 28e3 28e6 28e7 28ec
28ed 1 28ef 28f4 28f8 28fc 28ff 2904
2909 290c 2910 2911 2916 2919 291e 291f
2924 2927 292c 292d 2932 2935 2939 293a
293f 2942 2947 2948 294d 2950 2954 2958
295b 295e 295f 2961 2962 2967 2968 296d
296f 2973 2976 2978 297c 297e 298a 298c
298e 298f 2994 2998 299a 29a6 29a8 29ac
29b0 29b4 29b8 29bc 29c0 29c4 29c8 29cc
29d0 29d4 29e0 29e4 29e8 29eb 29ef 29f3
29f5 29f9 29fd 2a01 2a04 2a08 2a0c 2a0e
2a0f 2a14 1 2a18 2a1c 2a20 2a23 2a27
2a2b 2a2f 2a33 2a36 2a3a 2a3e 2a41 2a44
2a49 2a4c 2a4f 2a52 2a53 2a58 2a59 1
2a5b 2a60 2a64 2a68 2a6b 2a70 2a75 2a78
2a7c 2a7d 2a82 2a85 2a8a 2a8b 2a90 2a93
2a98 2a99 2a9e 2aa1 2aa5 2aa6 2aab 2aae
2ab3 2ab4 2ab9 2abc 2ac0 2ac4 2ac7 2aca
2acb 2acd 2ace 2ad3 2ad4 2ad9 2adb 2adf
2ae2 2ae4 2ae8 2aea 2af6 2af8 2afa 2afb
2b00 2b04 2b06 2b12 2b14 2b18 2b1b 2b1e
2b1f 2b24 2b28 2b2c 2b2f 2b30 2b32 2b35
2b38 2b39 2b3e 2b42 2b46 2b4a 2b4e 2b52
2b56 2b5a 2b5e 2b62 2b66 2b72 2b76 2b7a
2b7d 2b81 2b85 2b87 2b8b 2b8f 2b93 2b96
2b9a 2b9e 2ba0 2ba1 2ba6 1 2baa 2bae
2bb2 2bb5 2bb9 2bbd 2bc1 2bc5 2bc8 2bcc
2bd0 2bd3 2bd6 2bdb 2bde 2be1 2be4 2be5
2bea 2beb 1 2bed 2bf2 2bf6 2bfa 2bfd
2c02 2c07 2c0a 2c0e 2c0f 2c14 2c17 2c1c
2c1d 2c22 2c25 2c2a 2c2b 2c30 2c33 2c37
2c38 2c3d 2c40 2c45 2c46 2c4b 2c4e 2c52
2c56 2c59 2c5c 2c5d 2c5f 2c60 2c65 2c66
2c6b 2c6d 2c71 2c74 2c76 2c7a 2c7c 2c88
2c8a 2c8c 2c8d 2c92 2c96 2c98 2ca4 2ca6
2caa 2cae 2cb1 2cb2 2cb4 2cb7 2cba 2cbb
2cc0 2cc3 2cc4 2cc9 2ccd 2cd0 2cd4 2cd8
2cdc 2ce0 2ce4 2ce8 2cec 2cf0 2cf4 2cf8
2cfc 2d08 2d0c 2d10 2d13 2d17 2d1b 2d1d
2d21 2d25 2d29 2d2c 2d30 2d34 2d36 2d37
2d3c 1 2d40 2d44 2d48 2d4b 2d4f 2d53
2d57 2d5b 2d5e 2d62 2d66 2d69 2d6c 2d71
2d74 2d77 2d7a 2d7b 2d80 2d81 1 2d83
2d88 2d8c 2d90 2d93 2d98 2d9d 2da0 2da4
2da5 2daa 2dad 2db2 2db3 2db8 2dbb 2dc0
2dc1 2dc6 2dc9 2dcd 2dce 2dd3 2dd6 2ddb
2ddc 2de1 2de4 2de8 2dec 2def 2df2 2df3
2df5 2df6 2dfb 2dfc 2e01 2e03 2e07 2e0a
2e0c 2e10 2e12 2e1e 2e20 2e22 2e23 2e28
2e2c 2e2e 2e3a 2e3c 2e40 2e44 2e47 2e48
2e4a 2e4d 2e50 2e51 2e56 2e5a 2e5e 2e61
2e65 2e69 2e6c 2e6f 2e74 2e77 2e7a 2e7d
2e7e 2e83 2e84 1 2e86 2e8b 2e8f 2e93
2e96 2e9b 2ea0 2ea3 2ea7 2ea8 2ead 2eb0
2eb5 2eb6 2ebb 2ebe 2ec3 2ec4 2ec9 2ecc
2ed0 2ed4 2ed8 2edc 2edf 2ee0 2ee2 2ee7
2ee8 2eea 2eeb 2ef0 2ef3 2ef8 2ef9 2efe
2f01 2f06 2f07 2f0c 2f0f 2f13 2f14 2f19
2f1c 2f21 2f22 2f27 2f28 2f2d 2f2f 2f33
2f36 2f3a 2f3e 2f41 2f45 2f49 2f4c 2f4f
2f54 2f57 2f5a 2f5d 2f5e 2f63 2f64 1
2f66 2f6b 2f6f 2f73 2f76 2f7b 2f80 2f83
2f87 2f88 2f8d 2f8e 2f93 2f95 2f99 2f9c
2fa0 2fa4 2fa7 2fab 2faf 2fb2 2fb6 2fba
2fbb 2fc0 2fc2 2fc6 2fc9 2fcb 2fcf 2fd2
2fd4 2fd8 2fdb 2fdf 2fe1 2fe5 2fe9 2fed
2ff0 2ff1 2ff3 2ff4 2ff6 2ff9 2ffc 2ffd
3002 3006 300a 300d 300e 3010 3013 3016
3017 301c 3020 3024 3027 3028 302a 302d
3030 3031 1 3036 303b 1 303e 3043
3047 304a 304e 3052 3056 305a 305e 3062
3066 306a 306e 3072 3076 3082 3086 308a
308d 3091 3095 3097 309b 309f 30a3 30a6
30aa 30ae 30b0 30b1 30b6 1 30ba 30be
30c2 30c5 30c9 30cd 30d1 30d5 30d8 30dc
30e0 30e3 30e6 30eb 30ee 30f1 30f4 30f5
30fa 30fb 1 30fd 3102 3106 310a 310d
3112 3117 311a 311e 311f 3124 3127 312c
312d 3132 3135 313a 313b 3140 3143 3147
3148 314d 3150 3155 3156 315b 315e 3162
3166 3169 316c 316d 316f 3170 3175 3176
317b 317d 3181 3184 3186 318a 318c 3198
319a 319c 319d 31a2 31a6 31a8 31b4 31b6
31ba 31be 31c1 31c2 31c4 31c7 31ca 31cb
31d0 31d4 31d8 31db 31df 31e3 31e6 31e9
31ee 31f1 31f4 31f7 31f8 31fd 31fe 1
3200 3205 3209 320d 3210 3215 321a 321d
3221 3222 3227 322a 322f 3230 3235 3238
323d 323e 3243 3246 324a 324e 3252 3256
3259 325a 325c 3261 3262 3264 3265 326a
326d 3272 3273 3278 327b 3280 3281 3286
3289 328d 328e 3293 3296 329b 329c 32a1
32a2 32a7 32a9 32ad 32b0 32b4 32b8 32bb
32bf 32c3 32c6 32c9 32ce 32d1 32d4 32d7
32d8 32dd 32de 1 32e0 32e5 32e9 32ed
32f0 32f5 32fa 32fd 3301 3302 3307 3308
330d 330f 3313 3316 331a 331e 3321 3325
3329 332c 3330 3334 3335 333a 333c 3340
3343 3345 3349 334d 3350 3354 3359 335d
3361 3366 336a 336e 3373 3377 337b 337c
3380 3384 3385 3389 338d 338e 3392 3396
339a 339f 33a3 33a4 33a8 33ac 33b1 33b6
33ba 33be 33c3 33c7 33cb 33ce 33d1 33d5
33d7 33db 33df 33e2 33e5 33e9 33eb 33ef
33f3 33f6 33fa 33fe 3401 3405 3408 340c
340f 3410 3415 3418 341c 341f 3423 3425
3429 342c 3430 3432 3436 343a 343d 3441
3445 344a 344c 3450 3454 3457 345b 345f
3461 3465 3469 346d 3470 3474 3478 347a
347b 3480 1 3484 3488 348c 348f 3493
3497 349b 349f 34a2 34a6 34aa 34ad 34b0
34b5 34b8 34bb 34be 34bf 34c4 34c5 1
34c7 34cc 34d0 34d4 34d7 34dc 34e1 34e4
34e8 34e9 34ee 34f1 34f6 34f7 34fc 34ff
3504 3505 350a 350d 3511 3512 3517 351a
351f 3520 3525 3528 352c 3530 3533 3536
3537 3539 353a 353f 3540 3545 3547 354b
354e 3550 3554 3556 3562 3564 3566 3567
356c 3570 3572 357e 3580 3584 3588 358b
358c 358e 3591 3594 3595 359a 359e 35a2
35a5 35a6 35a8 35ab 35ae 35af 35b4 35b8
35bb 35bf 35c1 35c5 35c8 35ca 35ce 35d1
35d5 35d9 35dd 35e1 35e5 35f1 35f5 35f9
35fc 3600 3604 3606 360a 360e 3612 3615
3619 361d 361f 3620 3625 1 3629 362d
3631 3634 3638 363c 3640 3644 3647 364b
364f 3652 3655 365a 365d 3660 3663 3664
3669 366a 1 366c 3671 3675 3679 367c
3681 3686 3689 368d 368e 3693 3696 369b
369c 36a1 36a4 36a9 36aa 36af 36b2 36b6
36b7 36bc 36bf 36c4 36c5 36ca 36cd 36d1
36d5 36d8 36db 36dc 36de 36df 36e4 36e5
36ea 36ec 36f0 36f3 36f5 36f9 36fb 3707
3709 370b 370c 3711 3715 3717 3723 3725
3729 372d 3731 3735 3739 373d 3741 3745
3749 374d 3751 375d 3761 3765 3768 376c
3770 3772 3776 377a 377e 3781 3785 3789
378b 378c 3791 1 3795 3799 379d 37a0
37a4 37a8 37ac 37b0 37b3 37b7 37bb 37be
37c1 37c6 37c9 37cc 37cf 37d0 37d5 37d6
1 37d8 37dd 37e1 37e5 37e8 37ed 37f2
37f5 37f9 37fa 37ff 3802 3807 3808 380d
3810 3815 3816 381b 381e 3822 3823 3828
382b 3830 3831 3836 3839 383d 3841 3844
3847 3848 384a 384b 3850 3851 3856 3858
385c 385f 3861 3865 3867 3873 3875 3877
3878 387d 3881 3883 388f 3891 3895 3899
389c 38a0 38a3 38a7 38aa 38ab 38b0 38b3
38b7 38bb 38be 38bf 38c1 38c4 38c7 38c8
38cd 38d0 38d1 1 38d6 38db 38df 38e4
38e8 38ec 38f0 38f1 38f6 38fa 38fe 3902
3906 390a 390e 3912 3916 391a 391e 3922
392e 3932 3936 3939 393d 3941 3943 3947
394b 394f 3952 3956 395a 395c 395d 3962
1 3966 396a 396e 3971 3975 3979 397d
3981 3984 3988 398c 398f 3992 3997 399a
399d 39a0 39a1 39a6 39a7 1 39a9 39ae
39b2 39b6 39b9 39be 39c3 39c6 39ca 39cb
39d0 39d3 39d8 39d9 39de 39e1 39e6 39e7
39ec 39ef 39f3 39f4 39f9 39fc 3a01 3a02
3a07 3a0a 3a0e 3a12 3a15 3a18 3a19 3a1b
3a1c 3a21 3a22 3a27 3a29 3a2d 3a30 3a32
3a36 3a38 3a44 3a46 3a48 3a49 3a4e 3a52
3a54 3a60 3a62 3a66 3a6a 3a6d 3a71 3a74
3a78 3a7b 3a7c 3a81 3a84 3a88 3a8c 3a90
3a93 3a97 3a9b 3a9e 3a9f 3aa1 3aa5 3aa9
3aac 3aad 3aaf 3ab3 3ab5 3ab9 3abd 3ac0
3ac4 3ac8 3acb 3acc 3ace 3ad2 3ad6 3ad9
3add 3ade 3ae0 3ae4 3ae8 3aec 3af0 3af3
3af7 3af9 3afd 3b01 3b04 3b08 3b0d 3b11
3b15 3b18 3b1c 3b20 3b24 3b28 3b2c 3b30
3b34 3b38 3b3c 3b40 3b41 3b43 3b47 3b4b
3b4f 3b53 3b57 3b5a 3b5b 3b5d 3b5e 3b60
3b64 3b68 3b6c 3b70 3b74 3b78 3b7c 3b80
3b84 3b88 3b8c 3b90 3b94 3b98 3b9c 3ba0
3ba4 3ba8 3bac 3bb0 3bb4 3bb8 3bbc 3bc0
3bc4 3bc8 3bd4 3bd8 3bdd 3be1 3be4 3be5
3bea 3bee 3bf2 3bf5 3bf8 3bfc 3bfe 3c02
3c06 3c09 3c0c 3c10 3c12 3c16 3c1a 3c1d
3c1f 3c23 3c27 3c2b 3c2e 3c32 3c36 3c38
3c39 3c3e 1 3c42 3c46 3c4a 3c4d 3c51
3c55 3c59 3c5d 3c60 3c64 3c68 3c6b 3c6e
3c73 3c76 3c79 3c7c 3c7d 3c82 3c83 1
3c85 3c8a 3c8e 3c92 3c95 3c9a 3c9f 3ca2
3ca6 3ca7 3cac 3caf 3cb4 3cb5 3cba 3cbd
3cc2 3cc3 3cc8 3ccb 3ccf 3cd0 3cd5 3cd8
3cdd 3cde 3ce3 3ce6 3cea 3cee 3cf1 3cf4
3cf5 3cf7 3cf8 3cfd 3cfe 3d03 3d05 3d09
3d0c 3d0e 3d12 3d14 3d20 3d22 3d24 3d25
3d2a 3d2e 3d30 3d3c 3d3e 3d42 3d46 3d49
3d4d 3d51 3d52 3d54 3d57 3d5a 3d5b 3d60
3d64 3d67 3d6b 3d6d 3d71 3d75 3d79 3d7d
3d81 3d85 3d89 3d8d 3d91 3d95 3d99 3d9d
3da9 3dad 3db1 3db4 3db8 3dbc 3dbe 3dc2
3dc6 3dca 3dcd 3dd1 3dd5 3dd7 3dd8 3ddd
1 3de1 3de5 3de9 3dec 3df0 3df4 3df8
3dfc 3dff 3e03 3e07 3e0a 3e0d 3e12 3e15
3e18 3e1b 3e1c 3e21 3e22 1 3e24 3e29
3e2d 3e31 3e34 3e39 3e3e 3e41 3e45 3e46
3e4b 3e4e 3e53 3e54 3e59 3e5c 3e61 3e62
3e67 3e6a 3e6e 3e6f 3e74 3e77 3e7c 3e7d
3e82 3e85 3e89 3e8d 3e90 3e93 3e94 3e96
3e97 3e9c 3e9d 3ea2 3ea4 3ea8 3eab 3ead
3eb1 3eb3 3ebf 3ec1 3ec3 3ec4 3ec9 3ecd
3ecf 3edb 3edd 3edf 3ee3 3ee7 3eea 3eee
3ef2 3ef5 3ef6 3ef8 3efb 3efe 3eff 3f04
3f08 3f0c 3f10 3f14 3f18 3f1c 3f20 3f24
3f28 3f2c 3f38 3f3c 3f41 3f45 3f48 3f49
3f4e 3f52 3f56 3f59 3f5c 3f60 3f62 3f66
3f6a 3f6d 3f70 3f74 3f76 3f7a 3f7e 3f81
3f83 3f87 3f8b 3f8f 3f92 3f96 3f9a 3f9c
3f9d 3fa2 1 3fa6 3faa 3fae 3fb1 3fb5
3fb9 3fbd 3fc1 3fc4 3fc8 3fcc 3fcf 3fd2
3fd7 3fda 3fdd 3fe0 3fe1 3fe6 3fe7 1
3fe9 3fee 3ff2 3ff6 3ff9 3ffe 4003 4006
400a 400b 4010 4013 4018 4019 401e 4021
4026 4027 402c 402f 4033 4034 4039 403c
4041 4042 4047 404a 404e 4052 4055 4058
4059 405b 405c 4061 4062 4067 4069 406d
4070 4072 4076 4078 4084 4086 4088 4089
408e 4092 4094 40a0 40a2 40a6 40aa 40ae
40b2 40b6 40ba 40be 40c2 40c6 40ca 40ce
40d2 40d6 40da 40de 40e2 40e6 40f2 40f6
40fb 40ff 4102 4103 4108 410c 4110 4113
4116 411a 411c 4120 4124 4127 412a 412e
4130 4134 4138 413b 413d 4141 4145 4149
414c 4150 4154 4156 4157 415c 1 4160
4164 4168 416b 416f 4173 4177 417b 417e
4182 4186 4189 418c 4191 4194 4197 419a
419b 41a0 41a1 1 41a3 41a8 41ac 41b0
41b3 41b8 41bd 41c0 41c4 41c5 41ca 41cd
41d2 41d3 41d8 41db 41e0 41e1 41e6 41e9
41ed 41ee 41f3 41f6 41fb 41fc 4201 4204
4208 420c 420f 4212 4213 4215 4216 421b
421c 4221 4223 4227 422a 422c 4230 4232
423e 4240 4242 4243 4248 424c 424e 425a
425c 425e 4262 4266 426a 426e 4272 4276
427a 427e 4282 4286 428a 428e 4292 4296
429a 429e 42a2 42ae 42b2 42b7 42bb 42be
42bf 42c4 42c8 42cc 42cf 42d2 42d6 42d8
42dc 42e0 42e3 42e6 42ea 42ec 42f0 42f4
42f7 42f9 42fd 4301 4305 4308 430c 4310
4312 4313 4318 1 431c 4320 4324 4327
432b 432f 4333 4337 433a 433e 4342 4345
4348 434d 4350 4353 4356 4357 435c 435d
1 435f 4364 4368 436c 436f 4374 4379
437c 4380 4381 4386 4389 438e 438f 4394
4397 439c 439d 43a2 43a5 43a9 43aa 43af
43b2 43b7 43b8 43bd 43c0 43c4 43c8 43cb
43ce 43cf 43d1 43d2 43d7 43d8 43dd 43df
43e3 43e6 43e8 43ec 43ee 43fa 43fc 43fe
43ff 4404 4408 440a 4416 4418 441a 441e
4422 4425 4429 442b 442f 4433 4436 443a
443d 4441 4444 4445 444a 444d 4451 4455
4459 445d 4461 4465 4469 446d 4471 4475
4479 447d 4481 4485 4489 448d 4491 449d
44a1 44a6 44aa 44ad 44ae 44b3 44b7 44bb
44be 44c1 44c5 44c7 44cb 44cf 44d2 44d5
44d9 44db 44df 44e3 44e6 44e8 44ec 44f0
44f4 44f7 44fb 44ff 4501 4502 4507 1
450b 450f 4513 4516 451a 451e 4522 4526
4529 452d 4531 4534 4537 453c 453f 4542
4545 4546 454b 454c 1 454e 4553 4557
455b 455e 4563 4568 456b 456f 4570 4575
4578 457d 457e 4583 4586 458b 458c 4591
4594 4598 4599 459e 45a1 45a6 45a7 45ac
45af 45b3 45b7 45ba 45bd 45be 45c0 45c1
45c6 45c7 45cc 45ce 45d2 45d5 45d7 45db
45dd 45e9 45eb 45ed 45ee 45f3 45f7 45f9
4605 4607 460b 4610 4614 4618 461c 4620
4624 4628 462c 4638 463c 4640 4643 4647
464b 464d 4651 4655 4659 465c 4660 4664
4666 4667 466c 1 4670 4674 4678 467b
467f 4683 4687 468b 468e 4692 4696 4699
469c 46a1 46a4 46a7 46aa 46ab 46b0 46b1
1 46b3 46b8 46bc 46c0 46c3 46c8 46cd
46d0 46d4 46d5 46da 46dd 46e2 46e3 46e8
46eb 46f0 46f1 46f6 46f9 46fd 46fe 4703
4706 470b 470c 4711 4714 4718 471c 471f
4722 4723 4725 4726 472b 472c 4731 4733
4737 473a 473c 4740 4742 474e 4750 4752
4753 4758 475c 475e 476a 476c 4770 4774
4777 477b 477e 4782 4785 4786 478b 478e
4792 4796 479a 479e 47a2 47a6 47b2 47b6
47ba 47bd 47c1 47c5 47c7 47cb 47cf 47d3
47d6 47da 47de 47e0 47e1 47e6 1 47ea
47ee 47f2 47f5 47f9 47fd 4801 4805 4808
480c 4810 4813 4816 481b 481e 4821 4824
4825 482a 482b 1 482d 4832 4836 483a
483d 4842 4847 484a 484e 484f 4854 4857
485c 485d 4862 4865 486a 486b 4870 4873
4877 4878 487d 4880 4885 4886 488b 488e
4892 4896 4899 489c 489d 489f 48a0 48a5
48a6 48ab 48ad 48b1 48b4 48b6 48ba 48bc
48c8 48ca 48cc 48cd 48d2 48d6 48d8 48e4
48e6 48ea 48ee 48f1 48f5 48f8 48fc 48ff
4900 4905 4908 490c 4911 4915 4917 491b
491e 4920 4924 4927 492b 492f 4932 4933
4935 4938 493b 493c 4941 4944 4945 494a
494e 4952 4955 4956 4958 495c 495f 4963
4966 4967 496c 4970 4974 4977 497b 497f
4982 4983 4985 4989 498d 4990 4994 4995
4997 499b 499f 49a3 49a7 49ab 49af 49b3
49b7 49bb 49bf 49c3 49cf 49d3 49d8 49dc
49df 49e0 49e5 49e9 49ed 49f0 49f3 49f7
49f9 49fd 4a01 4a04 4a07 4a0b 4a0d 4a11
4a15 4a18 4a1a 4a1e 4a22 4a26 4a29 4a2d
4a31 4a33 4a34 4a39 1 4a3d 4a41 4a45
4a48 4a4c 4a50 4a54 4a58 4a5b 4a5f 4a63
4a66 4a69 4a6e 4a71 4a74 4a77 4a78 4a7d
4a7e 1 4a80 4a85 4a89 4a8d 4a90 4a95
4a9a 4a9d 4aa1 4aa2 4aa7 4aaa 4aaf 4ab0
4ab5 4ab8 4abd 4abe 4ac3 4ac6 4aca 4acb
4ad0 4ad3 4ad8 4ad9 4ade 4ae1 4ae5 4ae9
4aec 4aef 4af0 4af2 4af3 4af8 4af9 4afe
4b00 4b04 4b07 4b09 4b0d 4b0f 4b1b 4b1d
4b1f 4b20 4b25 4b29 4b2b 4b37 4b39 4b3d
4b41 4b45 4b46 4b48 4b4c 4b50 4b52 4b56
4b5a 4b5e 4b61 4b62 4b64 4b68 4b6c 4b6f
4b70 4b72 4b75 4b79 4b7c 4b80 4b83 4b84
4b89 4b8d 4b91 4b95 4b99 4b9d 4ba1 4ba5
4ba9 4bad 4bb1 4bb5 4bc1 4bc5 4bca 4bce
4bd1 4bd2 4bd7 4bdb 4bdf 4be2 4be5 4be9
4beb 4bef 4bf3 4bf6 4bf9 4bfd 4bff 4c03
4c07 4c0a 4c0c 4c10 4c14 4c18 4c1b 4c1f
4c23 4c25 4c26 4c2b 1 4c2f 4c33 4c37
4c3a 4c3e 4c42 4c46 4c4a 4c4d 4c51 4c55
4c58 4c5b 4c60 4c63 4c66 4c69 4c6a 4c6f
4c70 1 4c72 4c77 4c7b 4c7f 4c82 4c87
4c8c 4c8f 4c93 4c94 4c99 4c9c 4ca1 4ca2
4ca7 4caa 4caf 4cb0 4cb5 4cb8 4cbc 4cbd
4cc2 4cc5 4cca 4ccb 4cd0 4cd3 4cd7 4cdb
4cde 4ce1 4ce2 4ce4 4ce5 4cea 4ceb 4cf0
4cf2 4cf6 4cf9 4cfb 4cff 4d01 4d0d 4d0f
4d11 4d12 4d17 4d1b 4d1d 4d29 4d2b 4d2f
4d33 4d37 4d38 4d3a 4d3e 4d42 4d44 4d48
4d4c 4d50 4d54 4d57 4d58 4d5a 4d5e 4d62
4d65 4d66 4d68 4d6b 4d6f 4d72 4d76 4d79
4d7a 4d7f 4d83 4d87 4d8b 4d8f 4d93 4d97
4d9b 4d9f 4da3 4da7 4dab 4db7 4dbb 4dc0
4dc4 4dc7 4dc8 4dcd 4dd1 4dd5 4dd8 4ddb
4ddf 4de1 4de5 4de9 4dec 4def 4df3 4df5
4df9 4dfd 4e00 4e02 4e06 4e0a 4e0e 4e11
4e15 4e19 4e1b 4e1c 4e21 1 4e25 4e29
4e2d 4e30 4e34 4e38 4e3c 4e40 4e43 4e47
4e4b 4e4e 4e51 4e56 4e59 4e5c 4e5f 4e60
4e65 4e66 1 4e68 4e6d 4e71 4e75 4e78
4e7d 4e82 4e85 4e89 4e8a 4e8f 4e92 4e97
4e98 4e9d 4ea0 4ea5 4ea6 4eab 4eae 4eb2
4eb3 4eb8 4ebb 4ec0 4ec1 4ec6 4ec9 4ecd
4ed1 4ed4 4ed7 4ed8 4eda 4edb 4ee0 4ee1
4ee6 4ee8 4eec 4eef 4ef1 4ef5 4ef7 4f03
4f05 4f07 4f08 4f0d 4f11 4f13 4f1f 4f21
4f25 4f29 4f2d 4f2e 4f30 4f34 4f36 4f3a
4f3e 4f41 4f43 4f47 4f4a 4f4c 4f50 4f54
4f57 4f5b 4f5f 4f63 4f67 4f6b 4f6f 4f73
4f77 4f7b 4f7f 4f83 4f87 4f8b 4f8f 4f93
4f97 4f9b 4f9f 4fa3 4fa7 4fab 4faf 4fbb
4fbf 4fc3 4fc6 4fca 4fce 4fd0 4fd4 4fd8
4fdc 4fdf 4fe3 4fe7 4fe9 4fea 4fef 1
4ff3 4ff7 4ffb 4ffe 5002 5006 500a 500e
5011 5015 5019 501c 501f 5024 5027 502a
502d 502e 5033 5034 1 5036 503b 503f
5043 5046 504b 5050 5053 5057 5058 505d
5060 5065 5066 506b 506e 5073 5074 5079
507c 5080 5081 5086 5089 508e 508f 5094
5097 509b 509f 50a2 50a5 50a6 50a8 50a9
50ae 50af 50b4 50b6 50ba 50bd 50bf 50c3
50c5 50d1 50d3 50d5 50d6 50db 50df 50e1
50ed 50ef 50f3 50f7 50fa 50fe 5101 5105
5108 5109 510e 5111 5115 5118 511c 511e
5122 5125 5129 512e 5132 5136 513b 513f
5143 5148 514c 5150 5154 5155 515a 515e
5162 5166 5169 516a 516c 516f 5172 5173
5178 517b 517f 5183 5186 5187 5189 518c
518f 5190 5195 1 5198 519d 51a1 51a5
51a9 51ad 51b1 51b5 51b9 51bd 51c1 51c5
51c9 51cd 51ce 51d0 51d4 51d8 51dc 51df
51e0 51e2 51e5 51e8 51e9 51ee 51f2 51f6
51fa 51fd 51fe 5200 5203 5207 520b 520e
520f 5211 5212 5217 521b 521f 5223 5227
522a 522b 522d 5230 5234 5238 523b 523c
523e 523f 5244 5248 524a 524e 5251 5255
5259 525c 525d 525f 5262 5265 5266 526b
526f 5273 5277 527a 527b 527d 5280 5284
5288 528b 528c 528e 528f 5294 5298 529c
52a0 52a4 52a7 52a8 52aa 52ad 52b1 52b5
52b8 52b9 52bb 52bc 52c1 52c5 52c7 52cb
52ce 52d0 52d4 52d7 52db 52de 52e2 52e6
52e9 52ed 52f1 52f5 52f9 52fd 5301 5305
5311 5315 5319 531c 5320 5324 5326 532a
532e 5332 5335 5339 533d 533f 5340 5345
1 5349 534d 5351 5354 5358 535c 5360
5364 5367 536b 536f 5372 5375 537a 537d
5380 5383 5384 5389 538a 1 538c 5391
5395 5399 539c 53a1 53a6 53a9 53ad 53ae
53b3 53b6 53bb 53bc 53c1 53c4 53c9 53ca
53cf 53d2 53d6 53d7 53dc 53df 53e4 53e5
53ea 53ed 53f1 53f5 53f8 53fb 53fc 53fe
53ff 5404 5405 540a 540c 5410 5413 5415
5419 541b 5427 5429 542b 542c 5431 5435
5437 5443 5445 5449 544a 544e 5452 5456
545a 545e 5462 5466 546a 546e 5472 5476
547a 547e 548a 548e 5492 5495 5499 549d
549f 54a3 54a7 54ab 54ae 54b2 54b6 54b8
54b9 54be 1 54c2 54c6 54ca 54cd 54d1
54d5 54d9 54dd 54e0 54e4 54e8 54eb 54ee
54f3 54f6 54f9 54fc 54fd 5502 5503 1
5505 550a 550e 5512 5515 551a 551f 5522
5526 5527 552c 552f 5534 5535 553a 553d
5542 5543 5548 554b 554f 5550 5555 5558
555d 555e 5563 5566 556a 556e 5571 5574
5575 5577 5578 557d 557e 5583 5585 5589
558c 558e 5592 5594 55a0 55a2 55a4 55a5
55aa 55ae 55b0 55bc 55be 55c2 55c6 55ca
55ce 55d2 55d6 55da 55e6 55ea 55ee 55f1
55f5 55f9 55fb 55ff 5603 5607 560a 560e
5612 5614 5615 561a 1 561e 5622 5626
5629 562d 5631 5635 5639 563c 5640 5644
5647 564a 564f 5652 5655 5658 5659 565e
565f 1 5661 5666 566a 566e 5671 5676
567b 567e 5682 5683 5688 568b 5690 5691
5696 5699 569e 569f 56a4 56a7 56ab 56ac
56b1 56b4 56b9 56ba 56bf 56c2 56c6 56ca
56cd 56d0 56d1 56d3 56d4 56d9 56da 56df
56e1 56e5 56e8 56ea 56ee 56f0 56fc 56fe
5700 5701 5706 570a 570c 5718 571a 571e
5722 5725 5729 572d 572e 5730 5733 5736
5737 573c 573f 5740 5745 5749 574c 574d
5752 5755 5759 575c 5760 5764 5768 576c
5770 5774 5778 577c 5780 5784 5788 578c
5790 5794 5798 579c 57a0 57a4 57a8 57ac
57b0 57b4 57b8 57bc 57c0 57c4 57c8 57cc
57d0 57d4 57d8 57dc 57e0 57e4 57e8 57ec
57f8 57fc 5800 5803 5807 580b 580d 5811
5815 5819 581c 5820 5824 5826 5827 582c
1 5830 5834 5838 583b 583f 5843 5847
584b 584e 5852 5856 5859 585c 5861 5864
5867 586a 586b 5870 5871 1 5873 5878
587c 5880 5883 5888 588d 5890 5894 5895
589a 589d 58a2 58a3 58a8 58ab 58b0 58b1
58b6 58b9 58bd 58be 58c3 58c6 58cb 58cc
58d1 58d4 58d8 58dc 58df 58e2 58e3 58e5
58e6 58eb 58ec 58f1 58f3 58f7 58fa 58fc
5900 5902 590e 5910 5912 5913 5918 591c
591e 592a 592c 5930 5934 5937 593b 593e
5942 5945 5946 594b 594e 5952 5955 5956
595b 595e 1 5961 5966 596a 596d 5970
5971 5976 597a 597e 5982 5985 5989 598d
5991 5995 5999 599d 59a1 59a5 59a9 59ad
59b1 59b2 59b4 59b8 59ba 59be 59c1 59c5
59c8 59cc 59d0 59d4 59d7 59d8 59da 59dd
59e0 59e1 59e6 59ea 59ee 59f1 59f2 59f4
59f8 59fb 59ff 5a02 5a03 5a05 5a06 5a0b
5a0f 5a13 5a16 5a17 5a19 5a1d 5a20 5a24
5a27 5a28 5a2a 5a2b 1 5a30 5a35 5a39
5a3d 5a41 5a44 5a45 5a47 5a4b 5a4f 5a52
5a53 5a55 5a58 5a5b 5a5c 5a61 5a65 5a69
5a6c 5a70 5a74 5a77 5a7a 5a7f 5a82 5a85
5a88 5a89 5a8e 5a8f 1 5a91 5a96 5a9a
5a9e 5aa1 5aa6 5aab 5aae 5ab2 5ab3 5ab8
5abb 5ac0 5ac1 5ac6 5ac9 5ace 5acf 5ad4
5ad7 5adb 5adf 5ae3 5ae7 5aea 5aeb 5aed
5af2 5af3 5af5 5af6 5afb 5afe 5b03 5b04
5b09 5b0c 5b11 5b12 5b17 5b1a 5b1e 5b1f
5b24 5b27 5b2c 5b2d 5b32 5b33 5b38 5b3a
5b3e 5b41 5b45 5b49 5b4c 5b50 5b54 5b57
5b5a 5b5f 5b62 5b65 5b68 5b69 5b6e 5b6f
1 5b71 5b76 5b7a 5b7e 5b81 5b86 5b8b
5b8e 5b92 5b93 5b98 5b99 5b9e 5ba0 5ba4
5ba7 5bab 5baf 5bb2 5bb6 5bba 5bbd 5bc1
5bc5 5bc6 5bcb 5bcd 5bd1 5bd4 5bd8 5bdc
5be0 5be3 5be4 5be6 5be9 5bec 5bed 5bf2
5bf6 5bf9 5bfd 5bff 5c03 5c06 5c08 5c0c
5c10 5c13 5c15 5c19 5c1c 5c20 5c24 5c28
5c2c 5c30 5c34 5c38 5c3c 5c40 5c44 5c48
5c4c 5c50 5c54 5c58 5c5c 5c60 5c64 5c68
5c6c 5c70 5c74 5c78 5c7c 5c80 5c84 5c88
5c8a 5c8e 5c91 5c95 5c99 5c9c 5ca0 5ca3
5ca7 5caa 5cab 5cb0 5cb3 5cb7 5cba 5cbe
5cc2 5cc5 5cc9 5ccd 5cd0 5cd1 5cd6 5cd9
5cdd 5ce1 5ce4 5ce7 5ce8 5cea 5ced 5cf2
5cf3 5cf8 5cfc 5cff 5d02 5d03 5d08 5d0c
5d10 5d14 5d17 5d1b 5d1f 5d23 5d27 5d2b
5d2f 5d33 5d37 5d3b 5d3f 5d43 5d44 5d46
5d4a 5d4c 5d50 5d53 5d57 5d5b 5d5f 5d63
5d67 5d6b 5d6f 5d73 5d77 5d7b 5d7f 5d83
5d87 5d8b 5d8f 5d93 5d97 5d9b 5d9f 5da3
5da7 5dab 5daf 5db3 5db7 5dbb 5dbf 5dcb
5dcf 5dd3 5dd6 5dda 5dde 5de0 5de4 5de8
5dec 5def 5df3 5df7 5df9 5dfa 5dff 1
5e03 5e07 5e0b 5e0e 5e12 5e16 5e1a 5e1e
5e21 5e25 5e29 5e2c 5e2f 5e34 5e37 5e3a
5e3d 5e3e 5e43 5e44 1 5e46 5e4b 5e4f
5e53 5e56 5e5b 5e60 5e63 5e67 5e68 5e6d
5e70 5e75 5e76 5e7b 5e7e 5e83 5e84 5e89
5e8c 5e90 5e91 5e96 5e99 5e9e 5e9f 5ea4
5ea7 5eab 5eaf 5eb2 5eb5 5eb6 5eb8 5eb9
5ebe 5ebf 5ec4 5ec6 5eca 5ecd 5ecf 5ed3
5ed5 5ee1 5ee3 5ee5 5ee6 5eeb 5eef 5ef1
5efd 5eff 5f03 5f07 5f0a 5f0e 5f11 5f15
5f18 5f19 5f1e 5f21 5f25 5f29 5f2c 5f2d
5f2f 5f33 5f36 5f3a 5f3d 5f3e 5f40 5f41
5f46 5f4a 5f4e 5f51 5f52 5f54 5f58 5f5b
5f5f 5f62 5f63 5f65 5f66 1 5f6b 5f70
5f74 5f78 5f7b 5f7f 5f83 5f86 5f89 5f8e
5f91 5f94 5f97 5f98 5f9d 5f9e 1 5fa0
5fa5 5fa9 5fad 5fb0 5fb5 5fba 5fbd 5fc1
5fc2 5fc7 5fca 5fcf 5fd0 5fd5 5fd8 5fdd
5fde 5fe3 5fe6 5fea 5fee 5ff2 5ff6 5ff9
5ffa 5ffc 6001 6002 6004 6005 600a 600d
6012 6013 6018 601b 6020 6021 6026 6029
602d 602e 6033 6036 603b 603c 6041 6042
6047 6049 604d 6050 6054 6058 605b 605f
6063 6066 6069 606e 6071 6074 6077 6078
607d 607e 1 6080 6085 6089 608d 6090
6095 609a 609d 60a1 60a2 60a7 60a8 60ad
60af 60b3 60b6 60ba 60be 60c1 60c5 60c9
60cc 60d0 60d4 60d5 60da 60dc 60e0 60e3
60e7 60eb 60ef 60f2 60f5 60f6 60f8 60fb
6100 6101 6106 6109 610a 610c 610f 6111
6115 6119 611d 6121 6124 6125 6127 612a
612d 612e 6133 6137 613a 613e 6142 6145
6149 614d 6151 6154 6155 6157 615a 615d
615e 6163 6167 616b 616e 616f 6171 6174
6177 6178 617d 6181 6185 6189 618d 6191
6195 6199 619d 61a1 61a5 61b1 61b5 61b9
61bc 61c0 61c4 61c6 61ca 61ce 61d2 61d5
61d9 61dd 61df 61e0 61e5 1 61e9 61ed
61f1 61f4 61f8 61fc 6200 6204 6207 620b
620f 6212 6215 621a 621d 6220 6223 6224
6229 622a 1 622c 6231 6235 6239 623c
6241 6246 6249 624d 624e 6253 6256 625b
625c 6261 6264 6269 626a 626f 6272 6276
6277 627c 627f 6284 6285 628a 628d 6291
6295 6298 629b 629c 629e 629f 62a4 62a5
62aa 62ac 62b0 62b3 62b5 62b9 62bb 62c7
62c9 62cb 62cc 62d1 62d5 62d7 62e3 62e5
62e7 62eb 62ef 62f3 62f7 62fb 62ff 6303
6307 6313 6317 631b 631e 6322 6326 6328
632c 6330 6334 6337 633b 633f 6341 6342
6347 1 634b 634f 6353 6356 635a 635e
6362 6366 6369 636d 6371 6374 6377 637c
637f 6382 6385 6386 638b 638c 1 638e
6393 6397 639b 639e 63a3 63a8 63ab 63af
63b0 63b5 63b8 63bd 63be 63c3 63c6 63cb
63cc 63d1 63d4 63d8 63d9 63de 63e1 63e6
63e7 63ec 63ef 63f3 63f7 63fa 63fd 63fe
6400 6401 6406 6407 640c 640e 6412 6415
6417 641b 641d 6429 642b 642d 642e 6433
6437 6439 6445 6447 6449 644d 6451 6454
6456 645a 645d 6461 6465 6468 6469 646b
646e 6471 6472 6477 647b 647f 6483 6487
648b 648f 6493 649f 64a3 64a8 64ac 64af
64b0 64b5 64b9 64bd 64c0 64c3 64c7 64c9
64cd 64d1 64d4 64d7 64db 64dd 64e1 64e5
64e8 64ea 64ee 64f2 64f6 64f9 64fd 6501
6503 6504 6509 1 650d 6511 6515 6518
651c 6520 6524 6528 652b 652f 6533 6536
6539 653e 6541 6544 6547 6548 654d 654e
1 6550 6555 6559 655d 6560 6565 656a
656d 6571 6572 6577 657a 657f 6580 6585
6588 658d 658e 6593 6596 659a 659b 65a0
65a3 65a8 65a9 65ae 65b1 65b5 65b9 65bc
65bf 65c0 65c2 65c3 65c8 65c9 65ce 65d0
65d4 65d7 65d9 65dd 65df 65eb 65ed 65ef
65f0 65f5 65f9 65fb 6607 6609 660b 660f
6613 6617 661b 661f 662b 662f 6634 6638
663b 663c 6641 6645 6649 664c 664f 6653
6655 6659 665d 6660 6663 6667 6669 666d
6671 6674 6676 667a 667e 6682 6685 6689
668d 668f 6690 6695 1 6699 669d 66a1
66a4 66a8 66ac 66b0 66b4 66b7 66bb 66bf
66c2 66c5 66ca 66cd 66d0 66d3 66d4 66d9
66da 1 66dc 66e1 66e5 66e9 66ec 66f1
66f6 66f9 66fd 66fe 6703 6706 670b 670c
6711 6714 6719 671a 671f 6722 6726 6727
672c 672f 6734 6735 673a 673d 6741 6745
6748 674b 674c 674e 674f 6754 6755 675a
675c 6760 6763 6765 6769 676b 6777 6779
677b 677c 6781 6785 6787 6793 6795 6799
679d 67a1 67ad 67b1 67b6 67ba 67bd 67be
67c3 67c7 67cb 67ce 67d1 67d5 67d7 67db
67df 67e2 67e5 67e9 67eb 67ef 67f3 67f6
67f8 67fc 6800 6804 6807 680b 680f 6811
6812 6817 1 681b 681f 6823 6826 682a
682e 6832 6836 6839 683d 6841 6844 6847
684c 684f 6852 6855 6856 685b 685c 1
685e 6863 6867 686b 686e 6873 6878 687b
687f 6880 6885 6888 688d 688e 6893 6896
689b 689c 68a1 68a4 68a8 68a9 68ae 68b1
68b6 68b7 68bc 68bf 68c3 68c7 68ca 68cd
68ce 68d0 68d1 68d6 68d7 68dc 68de 68e2
68e5 68e7 68eb 68ed 68f9 68fb 68fd 68fe
6903 6907 6909 6915 6917 691b 691f 6923
692f 6933 6938 693c 693f 6940 6945 6949
694d 6950 6953 6957 6959 695d 6961 6964
6967 696b 696d 6971 6975 6978 697a 697e
6982 6986 6989 698d 6991 6993 6994 6999
1 699d 69a1 69a5 69a8 69ac 69b0 69b4
69b8 69bb 69bf 69c3 69c6 69c9 69ce 69d1
69d4 69d7 69d8 69dd 69de 1 69e0 69e5
69e9 69ed 69f0 69f5 69fa 69fd 6a01 6a02
6a07 6a0a 6a0f 6a10 6a15 6a18 6a1d 6a1e
6a23 6a26 6a2a 6a2b 6a30 6a33 6a38 6a39
6a3e 6a41 6a45 6a49 6a4c 6a4f 6a50 6a52
6a53 6a58 6a59 6a5e 6a60 6a64 6a67 6a69
6a6d 6a6f 6a7b 6a7d 6a7f 6a80 6a85 6a89
6a8b 6a97 6a99 6a9d 6aa1 6aa5 6aa9 6aad
6ab9 6abd 6ac2 6ac6 6ac9 6aca 6acf 6ad3
6ad7 6ada 6add 6ae1 6ae3 6ae7 6aeb 6aee
6af1 6af5 6af7 6afb 6aff 6b02 6b04 6b08
6b0c 6b10 6b13 6b17 6b1b 6b1d 6b1e 6b23
1 6b27 6b2b 6b2f 6b32 6b36 6b3a 6b3e
6b42 6b45 6b49 6b4d 6b50 6b53 6b58 6b5b
6b5e 6b61 6b62 6b67 6b68 1 6b6a 6b6f
6b73 6b77 6b7a 6b7f 6b84 6b87 6b8b 6b8c
6b91 6b94 6b99 6b9a 6b9f 6ba2 6ba7 6ba8
6bad 6bb0 6bb4 6bb5 6bba 6bbd 6bc2 6bc3
6bc8 6bcb 6bcf 6bd3 6bd6 6bd9 6bda 6bdc
6bdd 6be2 6be3 6be8 6bea 6bee 6bf1 6bf3
6bf7 6bf9 6c05 6c07 6c09 6c0a 6c0f 6c13
6c15 6c21 6c23 6c25 6c29 6c2d 6c30 6c32
6c36 6c39 6c3b 6c3f 6c42 6c46 6c48 6c4c
6c50 6c53 6c54 6c56 6c59 6c5c 6c5d 6c62
6c65 6c66 6c6b 6c6f 6c73 6c76 6c77 6c79
6c7c 6c7f 6c80 1 6c85 6c8a 6c8e 6c92
6c95 6c99 6c9d 6ca0 6ca3 6ca8 6cab 6cae
6cb1 6cb2 6cb7 6cb8 1 6cba 6cbf 6cc3
6cc7 6cca 6ccf 6cd4 6cd7 6cdb 6cdc 6ce1
6ce4 6ce9 6cea 6cef 6cf2 6cf7 6cf8 6cfd
6d00 6d04 6d08 6d0c 6d10 6d13 6d14 6d16
6d1b 6d1c 6d1e 6d1f 6d24 6d27 6d2c 6d2d
6d32 6d35 6d3a 6d3b 6d40 6d43 6d47 6d48
6d4d 6d50 6d55 6d56 6d5b 6d5c 6d61 6d63
6d67 6d6a 6d6e 6d72 6d75 6d79 6d7d 6d80
6d83 6d88 6d8b 6d8e 6d91 6d92 6d97 6d98
1 6d9a 6d9f 6da3 6da7 6daa 6daf 6db4
6db7 6dbb 6dbc 6dc1 6dc2 6dc7 6dc9 6dcd
6dd0 6dd4 6dd8 6ddb 6ddf 6de3 6de6 6dea
6dee 6def 6df4 6df6 6dfa 6dfe 6e01 6e05
6e08 6e0b 6e0c 6e11 6e15 6e19 6e1d 6e21
6e25 6e28 6e29 6e2b 6e2e 6e31 6e32 6e37
6e3a 6e3e 6e42 6e45 6e46 6e48 6e4b 6e4e
6e4f 6e54 1 6e57 6e5c 6e60 6e64 6e67
6e68 6e6a 6e6d 6e70 6e71 6e76 6e7a 6e7e
6e82 6e86 6e8a 6e8e 6e92 6e96 6e9a 6e9e
6ea2 6ea6 6eaa 6eae 6eb2 6eb6 6eba 6ebe
6ec2 6ec6 6eca 6ece 6ed2 6ed6 6eda 6ede
6ee2 6ee6 6eea 6eee 6efa 6efe 6f03 6f07
6f0a 6f0b 6f10 6f14 6f18 6f1b 6f1e 6f22
6f24 6f28 6f2c 6f2f 6f32 6f36 6f38 6f3c
6f40 6f43 6f45 6f49 6f4d 6f51 6f54 6f58
6f5c 6f5e 6f5f 6f64 1 6f68 6f6c 6f70
6f73 6f77 6f7b 6f7f 6f83 6f86 6f8a 6f8e
6f91 6f94 6f99 6f9c 6f9f 6fa2 6fa3 6fa8
6fa9 1 6fab 6fb0 6fb4 6fb8 6fbb 6fc0
6fc5 6fc8 6fcc 6fcd 6fd2 6fd5 6fda 6fdb
6fe0 6fe3 6fe8 6fe9 6fee 6ff1 6ff5 6ff6
6ffb 6ffe 7003 7004 7009 700c 7010 7014
7017 701a 701b 701d 701e 7023 7024 7029
702b 702f 7032 7034 7038 703a 7046 7048
704a 704b 7050 7054 7056 7062 7064 7066
706a 706e 7072 7076 707a 707e 7082 7086
708a 708e 7092 7096 709a 709e 70a2 70a6
70aa 70ae 70b2 70b6 70ba 70be 70c2 70c6
70ca 70ce 70d2 70d6 70da 70de 70e2 70e6
70ea 70ee 70fa 70fe 7103 7107 710a 710b
7110 7114 7118 711b 711e 7122 7124 7128
712c 712f 7132 7136 7138 713c 7140 7143
7145 7149 714d 7151 7154 7158 715c 715e
715f 7164 1 7168 716c 7170 7173 7177
717b 717f 7183 7186 718a 718e 7191 7194
7199 719c 719f 71a2 71a3 71a8 71a9 1
71ab 71b0 71b4 71b8 71bb 71c0 71c5 71c8
71cc 71cd 71d2 71d5 71da 71db 71e0 71e3
71e8 71e9 71ee 71f1 71f5 71f6 71fb 71fe
7203 7204 7209 720c 7210 7214 7217 721a
721b 721d 721e 7223 7224 7229 722b 722f
7232 7234 7238 723a 7246 7248 724a 724b
7250 7254 7256 7262 7264 7266 726a 726e
7271 7275 7277 727b 727f 7282 7283 7285
7288 728b 728c 7291 7295 7299 729d 72a1
72a5 72a9 72ad 72b1 72b5 72b9 72bd 72c1
72c5 72c9 72cd 72d1 72d5 72d9 72dd 72e1
72e5 72e9 72ed 72f1 72f5 72f9 7305 7309
730e 7312 7315 7316 731b 731f 7323 7326
7329 732d 732f 7333 7337 733a 733d 7341
7343 7347 734b 734e 7350 7354 7358 735c
735f 7363 7367 7369 736a 736f 1 7373
7377 737b 737e 7382 7386 738a 738e 7391
7395 7399 739c 739f 73a4 73a7 73aa 73ad
73ae 73b3 73b4 1 73b6 73bb 73bf 73c3
73c6 73cb 73d0 73d3 73d7 73d8 73dd 73e0
73e5 73e6 73eb 73ee 73f3 73f4 73f9 73fc
7400 7401 7406 7409 740e 740f 7414 7417
741b 741f 7422 7425 7426 7428 7429 742e
742f 7434 7436 743a 743d 743f 7443 7445
7451 7453 7455 7456 745b 745f 7461 746d
746f 7473 7475 7479 747d 7481 7484 7485
7487 748a 748d 748e 7493 7497 749b 749e
749f 74a1 74a4 74a7 74a8 74ad 74b1 74b5
74b9 74bd 74c1 74c5 74c9 74cd 74d1 74d5
74d9 74dd 74e1 74e5 74e9 74ed 74f1 74f5
74f9 74fd 7501 7505 7511 7515 751a 751e
7521 7522 7527 752b 752f 7532 7535 7539
753b 753f 7543 7546 7549 754d 754f 7553
7557 755a 755c 7560 7564 7568 756b 756f
7573 7575 7576 757b 1 757f 7583 7587
758a 758e 7592 7596 759a 759d 75a1 75a5
75a8 75ab 75b0 75b3 75b6 75b9 75ba 75bf
75c0 1 75c2 75c7 75cb 75cf 75d2 75d7
75dc 75df 75e3 75e4 75e9 75ec 75f1 75f2
75f7 75fa 75ff 7600 7605 7608 760c 760d
7612 7615 761a 761b 7620 7623 7627 762b
762e 7631 7632 7634 7635 763a 763b 7640
7642 7646 7649 764b 764f 7651 765d 765f
7661 7662 7667 766b 766d 7679 767b 767d
7681 7685 7689 768d 7691 7695 7699 769d
76a1 76a5 76a9 76ad 76b1 76b5 76b9 76bd
76c1 76c5 76c9 76cd 76d1 76d5 76d9 76dd
76e1 76e5 76f1 76f5 76fa 76fe 7701 7702
7707 770b 770f 7712 7715 7719 771b 771f
7723 7726 7729 772d 772f 7733 7737 773a
773c 7740 7744 7748 774b 774f 7753 7755
7756 775b 1 775f 7763 7767 776a 776e
7772 7776 777a 777d 7781 7785 7788 778b
7790 7793 7796 7799 779a 779f 77a0 1
77a2 77a7 77ab 77af 77b2 77b7 77bc 77bf
77c3 77c4 77c9 77cc 77d1 77d2 77d7 77da
77df 77e0 77e5 77e8 77ec 77ed 77f2 77f5
77fa 77fb 7800 7803 7807 780b 780e 7811
7812 7814 7815 781a 781b 7820 7822 7826
7829 782b 782f 7831 783d 783f 7841 7842
7847 784b 784d 7859 785b 785d 7861 7865
7868 786a 786e 7872 7876 787a 787e 7882
7886 788a 788e 7892 7896 789a 789e 78aa
78ae 78b3 78b7 78ba 78bb 78c0 78c4 78c8
78cb 78ce 78d2 78d4 78d8 78dc 78df 78e2
78e6 78e8 78ec 78f0 78f3 78f5 78f9 78fd
7901 7904 7908 790c 790e 790f 7914 1
7918 791c 7920 7923 7927 792b 792f 7933
7936 793a 793e 7941 7944 7949 794c 794f
7952 7953 7958 7959 1 795b 7960 7964
7968 796b 7970 7975 7978 797c 797d 7982
7985 798a 798b 7990 7993 7998 7999 799e
79a1 79a5 79a6 79ab 79ae 79b3 79b4 79b9
79bc 79c0 79c4 79c7 79ca 79cb 79cd 79ce
79d3 79d4 79d9 79db 79df 79e2 79e4 79e8
79ea 79f6 79f8 79fa 79fb 7a00 7a04 7a06
7a12 7a14 7a16 7a1a 7a1e 7a21 7a25 7a29
7a2d 7a31 7a35 7a41 7a45 7a4a 7a4e 7a51
7a52 7a57 7a5b 7a5f 7a62 7a65 7a69 7a6b
7a6f 7a73 7a76 7a79 7a7d 7a7f 7a83 7a87
7a8a 7a8c 7a90 7a94 7a98 7a9b 7a9f 7aa3
7aa5 7aa6 7aab 1 7aaf 7ab3 7ab7 7aba
7abe 7ac2 7ac6 7aca 7acd 7ad1 7ad5 7ad8
7adb 7ae0 7ae3 7ae6 7ae9 7aea 7aef 7af0
1 7af2 7af7 7afb 7aff 7b02 7b07 7b0c
7b0f 7b13 7b14 7b19 7b1c 7b21 7b22 7b27
7b2a 7b2f 7b30 7b35 7b38 7b3c 7b3d 7b42
7b45 7b4a 7b4b 7b50 7b53 7b57 7b5b 7b5e
7b61 7b62 7b64 7b65 7b6a 7b6b 7b70 7b72
7b76 7b79 7b7b 7b7f 7b81 7b8d 7b8f 7b91
7b92 7b97 7b9b 7b9d 7ba9 7bab 7baf 7bb3
7bb7 7bc3 7bc7 7bcc 7bd0 7bd3 7bd4 7bd9
7bdd 7be1 7be4 7be7 7beb 7bed 7bf1 7bf5
7bf8 7bfb 7bff 7c01 7c05 7c09 7c0c 7c0e
7c12 7c16 7c1a 7c1d 7c21 7c25 7c27 7c28
7c2d 1 7c31 7c35 7c39 7c3c 7c40 7c44
7c48 7c4c 7c4f 7c53 7c57 7c5a 7c5d 7c62
7c65 7c68 7c6b 7c6c 7c71 7c72 1 7c74
7c79 7c7d 7c81 7c84 7c89 7c8e 7c91 7c95
7c96 7c9b 7c9e 7ca3 7ca4 7ca9 7cac 7cb1
7cb2 7cb7 7cba 7cbe 7cbf 7cc4 7cc7 7ccc
7ccd 7cd2 7cd5 7cd9 7cdd 7ce0 7ce3 7ce4
7ce6 7ce7 7cec 7ced 7cf2 7cf4 7cf8 7cfb
7cfd 7d01 7d03 7d0f 7d11 7d13 7d14 7d19
7d1d 7d1f 7d2b 7d2d 7d31 7d35 7d39 7d3d
7d41 7d4d 7d51 7d56 7d5a 7d5d 7d5e 7d63
7d67 7d6b 7d6e 7d71 7d75 7d77 7d7b 7d7f
7d82 7d85 7d89 7d8b 7d8f 7d93 7d96 7d98
7d9c 7da0 7da4 7da7 7dab 7daf 7db1 7db2
7db7 1 7dbb 7dbf 7dc3 7dc6 7dca 7dce
7dd2 7dd6 7dd9 7ddd 7de1 7de4 7de7 7dec
7def 7df2 7df5 7df6 7dfb 7dfc 1 7dfe
7e03 7e07 7e0b 7e0e 7e13 7e18 7e1b 7e1f
7e20 7e25 7e28 7e2d 7e2e 7e33 7e36 7e3b
7e3c 7e41 7e44 7e48 7e49 7e4e 7e51 7e56
7e57 7e5c 7e5f 7e63 7e67 7e6a 7e6d 7e6e
7e70 7e71 7e76 7e77 7e7c 7e7e 7e82 7e85
7e87 7e8b 7e8d 7e99 7e9b 7e9d 7e9e 7ea3
7ea7 7ea9 7eb5 7eb7 7eb9 7ebd 7ec0 7ec4
7ec7 7eca 7ecb 7ed0 7ed4 7ed8 7edb 7edc
7ede 7ee1 7ee4 7ee5 7eea 7eee 7ef2 7ef6
7ef9 7efd 7eff 7f03 7f07 7f0b 7f0e 7f12
7f16 7f19 7f1a 7f1c 7f20 7f24 7f27 7f28
7f2a 7f2e 7f30 7f34 7f38 7f3b 7f3f 7f42
7f46 7f4a 7f4e 7f51 7f52 7f54 7f57 7f5a
7f5b 7f60 7f64 7f68 7f6b 7f6c 7f6e 7f72
7f75 7f79 7f7c 7f7d 7f7f 7f80 7f85 7f89
7f8d 7f91 7f94 7f95 7f97 7f9b 7f9d 7fa1
7fa4 7fa8 7fab 7faf 7fb3 7fb6 7fba 7fbe
7fc2 7fc5 7fc9 7fcc 7fcd 7fcf 7fd2 7fd5
7fd6 7fdb 7fdf 7fe2 7fe6 7fe8 7fec 7fef
7ff3 7ff5 7ff9 7ffd 8000 8004 8008 800b
800c 800e 8011 8014 8015 801a 801e 8021
8025 8027 802b 802e 8032 8036 803a 803e
8042 8046 8049 804a 804c 8050 8054 8057
8058 805a 805e 8062 8065 8066 8068 806c
8070 8073 8074 8076 807a 807e 8081 8082
8084 8088 808c 808f 8090 8092 8096 809a
809d 809e 80a0 80a4 80a8 80ab 80ac 80ae
80b2 80b6 80ba 80bb 80bd 80c1 80c5 80c9
80cc 80cd 80cf 80d3 80d6 80da 80dd 80de
80e3 80e7 80eb 80ee 80f2 80f6 80f9 80fc
8101 8104 8107 810a 810b 8110 8111 1
8113 8118 811c 8120 8123 8128 812d 8130
8134 8135 813a 813d 8142 8143 8148 814b
8150 8151 8156 8159 815d 8161 8165 8169
816c 816d 816f 8174 8175 8177 8178 817d
817e 8183 8185 8189 818c 8190 8194 8197
819b 819f 81a2 81a5 81aa 81ad 81b0 81b3
81b4 81b9 81ba 1 81bc 81c1 81c5 81c9
81cc 81d1 81d6 81d9 81dd 81de 81e3 81e4
81e9 81eb 81ef 81f2 81f6 81fa 81fd 8201
8205 8208 820c 820d 8212 8216 8218 821c
8220 8223 8224 8226 8229 822c 822d 8232
8236 823a 823d 8241 8245 8248 824b 8250
8253 8256 8259 825a 825f 8260 1 8262
8267 826b 826f 8272 8277 827c 827f 8283
8284 8289 828c 8291 8292 8297 829a 829f
82a0 82a5 82a8 82ac 82b0 82b4 82b5 82b7
82bc 82bd 82bf 82c0 82c5 82c8 82cd 82ce
82d3 82d6 82db 82dc 82e1 82e4 82e8 82e9
82ee 82f1 82f6 82f7 82fc 82fd 8302 8304
8308 830b 830f 8313 8316 831a 831e 8321
8324 8329 832c 832f 8332 8333 8338 8339
1 833b 8340 8344 8348 834b 8350 8355
8358 835c 835d 8362 8363 8368 836a 836e
8371 8375 8379 837c 8380 8384 8387 8388
838a 838e 8392 8393 8398 839a 839e 83a2
83a5 83a9 83ac 83b0 83b4 83b8 83bc 83c0
83c4 83c8 83cc 83d0 83d4 83d8 83dc 83e0
83e4 83e8 83ec 83f0 83f4 83f8 83fc 8400
8404 8408 840c 8410 8414 8418 841c 8420
8424 8428 842b 842e 8431 8434 8437 8438
843a 843e 8442 8445 8448 8449 844e 8452
8456 8459 845d 8461 8464 8467 846c 846f
8472 8475 8476 847b 847c 1 847e 8483
8487 848b 848e 8493 8498 849b 849f 84a0
84a5 84a8 84ad 84ae 84b3 84b6 84bb 84bc
84c1 84c4 84c8 84cc 84d0 84d4 84d7 84d8
84da 84df 84e0 84e2 84e3 84e8 84eb 84f0
84f1 84f6 84f9 84fe 84ff 8504 8507 850b
850c 8511 8514 8519 851a 851f 8520 8525
8527 852b 852e 8532 8536 8539 853d 8541
8544 8547 854c 854f 8552 8555 8556 855b
855c 1 855e 8563 8567 856b 856e 8573
8578 857b 857f 8580 8585 8586 858b 858d
8591 8594 8598 859c 859f 85a3 85a7 85aa
85ae 85b2 85b3 85b8 85bc 85be 85c2 85c5
85c8 85c9 85ce 85d2 85d6 85d9 85dd 85e1
85e4 85e7 85ec 85ef 85f2 85f5 85f6 85fb
85fc 1 85fe 8603 8607 860b 860e 8613
8618 861b 861f 8620 8625 8628 862d 862e
8633 8636 863b 863c 8641 8644 8648 864c
8650 8654 8657 8658 865a 865f 8660 8662
8663 8668 866b 8670 8671 8676 8679 867e
867f 8684 8687 868b 868c 8691 8694 8699
869a 869f 86a0 86a5 86a7 86ab 86ae 86b2
86b6 86b9 86bd 86c1 86c4 86c7 86cc 86cf
86d2 86d5 86d6 86db 86dc 1 86de 86e3
86e7 86eb 86ee 86f3 86f8 86fb 86ff 8700
8705 8706 870b 870d 8711 8714 8718 871c
871f 8723 8727 872a 872e 8732 8733 8738
873a 873e 8742 8745 8749 874d 8751 8755
8759 875d 8761 8765 8768 8769 876b 876f
8773 8776 8777 8779 877a 877c 8780 8782
8786 878a 878d 878f 8793 8796 8798 879c
879f 87a3 87a7 87ab 87ae 87b2 87b6 87ba
87be 87c2 87c6 87ca 87ce 87d2 87de 87e2
87e6 87e9 87ed 87f1 87f3 87f7 87fb 87ff
8802 8806 880a 880c 880d 8812 1 8816
881a 881e 8821 8825 8829 882d 8831 8834
8838 883c 883f 8842 8847 884a 884d 8850
8851 8856 8857 1 8859 885e 8862 8866
8869 886e 8873 8876 887a 887b 8880 8883
8888 8889 888e 8891 8896 8897 889c 889f
88a3 88a4 88a9 88ac 88b1 88b2 88b7 88ba
88be 88c2 88c5 88c8 88c9 88cb 88cc 88d1
88d2 88d7 88d9 88dd 88e0 88e2 88e6 88e8
88f4 88f6 88f8 88f9 88fe 8902 8904 8910
8912 8914 8918 891b 891d 8921 8924 8928
892b 892f 8931 8935 8938 893c 8940 8944
8947 894c 894d 8952 8955 8958 8959 895b
895f 8963 8968 896c 8970 8974 8978 897c
8980 8984 8988 898c 8998 899c 89a0 89a3
89a7 89ab 89ad 89b1 89b5 89b9 89bc 89c0
89c4 89c6 89c7 89cc 1 89d0 89d4 89d8
89db 89df 89e3 89e7 89eb 89ee 89f2 89f6
89f9 89fc 8a01 8a04 8a07 8a0a 8a0b 8a10
8a11 1 8a13 8a18 8a1c 8a20 8a23 8a28
8a2d 8a30 8a34 8a35 8a3a 8a3d 8a42 8a43
8a48 8a4b 8a50 8a51 8a56 8a59 8a5d 8a5e
8a63 8a66 8a6b 8a6c 8a71 8a74 8a78 8a7c
8a7f 8a82 8a83 8a85 8a86 8a8b 8a8c 8a91
8a93 8a97 8a9a 8a9c 8aa0 8aa2 8aae 8ab0
8ab2 8ab3 8ab8 8abc 8abe 8aca 8acc 8ad0
8ad3 8ad7 8adb 8ade 8ae2 8ae6 8ae9 8aed
8af1 8af5 8af9 8afd 8b01 8b06 8b0a 8b0b
8b0f 8b13 8b17 8b1b 8b1f 8b23 8b27 8b2b
8b2f 8b33 8b37 8b3b 8b3f 8b43 8b47 8b4b
8b4f 8b53 8b57 8b5b 8b5f 8b63 8b67 8b6c
8b71 8b75 8b79 8b7d 8b82 8b86 8b8a 8b8d
8b90 8b94 8b96 8b9a 8b9e 8ba1 8ba4 8ba8
8baa 8bae 8bb2 8bb5 8bb9 8bbd 8bc0 8bc4
8bc7 8bcb 8bce 8bcf 8bd4 8bd7 8bdb 8be1
8be3 8be7 8bea 8bee 8bf1 8bf5 8bf9 8bfd
8c00 8c01 8c03 8c06 8c09 8c0a 8c0f 8c13
8c17 8c1b 8c1e 8c1f 8c21 8c25 8c29 8c2d
8c31 8c3d 8c41 8c46 8c4a 8c4d 8c4e 8c53
8c57 8c5b 8c5e 8c61 8c65 8c67 8c6b 8c6f
8c72 8c75 8c79 8c7b 8c7f 8c83 8c86 8c88
8c8c 8c90 8c94 8c97 8c9b 8c9f 8ca1 8ca2
8ca7 1 8cab 8caf 8cb3 8cb6 8cba 8cbe
8cc2 8cc6 8cc9 8ccd 8cd1 8cd4 8cd7 8cdc
8cdf 8ce2 8ce5 8ce6 8ceb 8cec 1 8cee
8cf3 8cf7 8cfb 8cfe 8d03 8d08 8d0b 8d0f
8d10 8d15 8d18 8d1d 8d1e 8d23 8d26 8d2b
8d2c 8d31 8d34 8d38 8d39 8d3e 8d41 8d46
8d47 8d4c 8d4f 8d53 8d57 8d5a 8d5d 8d5e
8d60 8d61 8d66 8d67 8d6c 8d6e 8d72 8d75
8d77 8d7b 8d7d 8d89 8d8b 8d8d 8d8e 8d93
8d97 8d99 8da5 8da7 8dab 8daf 8db3 8dbf
8dc3 8dc8 8dcc 8dcf 8dd0 8dd5 8dd9 8ddd
8de0 8de3 8de7 8de9 8ded 8df1 8df4 8df7
8dfb 8dfd 8e01 8e05 8e08 8e0a 8e0e 8e12
8e16 8e19 8e1d 8e21 8e23 8e24 8e29 1
8e2d 8e31 8e35 8e38 8e3c 8e40 8e44 8e48
8e4b 8e4f 8e53 8e56 8e59 8e5e 8e61 8e64
8e67 8e68 8e6d 8e6e 1 8e70 8e75 8e79
8e7d 8e80 8e85 8e8a 8e8d 8e91 8e92 8e97
8e9a 8e9f 8ea0 8ea5 8ea8 8ead 8eae 8eb3
8eb6 8eba 8ebb 8ec0 8ec3 8ec8 8ec9 8ece
8ed1 8ed5 8ed9 8edc 8edf 8ee0 8ee2 8ee3
8ee8 8ee9 8eee 8ef0 8ef4 8ef7 8ef9 8efd
8eff 8f0b 8f0d 8f0f 8f10 8f15 8f19 8f1b
8f27 8f29 8f2d 8f31 8f35 8f41 8f45 8f4a
8f4e 8f51 8f52 8f57 8f5b 8f5f 8f62 8f65
8f69 8f6b 8f6f 8f73 8f76 8f79 8f7d 8f7f
8f83 8f87 8f8a 8f8c 8f90 8f94 8f98 8f9b
8f9f 8fa3 8fa5 8fa6 8fab 1 8faf 8fb3
8fb7 8fba 8fbe 8fc2 8fc6 8fca 8fcd 8fd1
8fd5 8fd8 8fdb 8fe0 8fe3 8fe6 8fe9 8fea
8fef 8ff0 1 8ff2 8ff7 8ffb 8fff 9002
9007 900c 900f 9013 9014 9019 901c 9021
9022 9027 902a 902f 9030 9035 9038 903c
903d 9042 9045 904a 904b 9050 9053 9057
905b 905e 9061 9062 9064 9065 906a 906b
9070 9072 9076 9079 907b 907f 9081 908d
908f 9091 9092 9097 909b 909d 90a9 90ab
90af 90b3 90b7 90bb 90bf 90cb 90cf 90d4
90d8 90db 90dc 90e1 90e5 90e9 90ec 90ef
90f3 90f5 90f9 90fd 9100 9103 9107 9109
910d 9111 9114 9116 911a 911e 9122 9125
9129 912d 912f 9130 9135 1 9139 913d
9141 9144 9148 914c 9150 9154 9157 915b
915f 9162 9165 916a 916d 9170 9173 9174
9179 917a 1 917c 9181 9185 9189 918c
9191 9196 9199 919d 919e 91a3 91a6 91ab
91ac 91b1 91b4 91b9 91ba 91bf 91c2 91c6
91c7 91cc 91cf 91d4 91d5 91da 91dd 91e1
91e5 91e8 91eb 91ec 91ee 91ef 91f4 91f5
91fa 91fc 9200 9203 9205 9209 920b 9217
9219 921b 921c 9221 9225 9227 9233 9235
9239 923d 9241 924d 9251 9256 925a 925d
925e 9263 9267 926b 926e 9271 9275 9277
927b 927f 9282 9285 9289 928b 928f 9293
9296 9298 929c 92a0 92a4 92a7 92ab 92af
92b1 92b2 92b7 1 92bb 92bf 92c3 92c6
92ca 92ce 92d2 92d6 92d9 92dd 92e1 92e4
92e7 92ec 92ef 92f2 92f5 92f6 92fb 92fc
1 92fe 9303 9307 930b 930e 9313 9318
931b 931f 9320 9325 9328 932d 932e 9333
9336 933b 933c 9341 9344 9348 9349 934e
9351 9356 9357 935c 935f 9363 9367 936a
936d 936e 9370 9371 9376 9377 937c 937e
9382 9385 9387 938b 938d 9399 939b 939d
939e 93a3 93a7 93a9 93b5 93b7 93bb 93bf
93c3 93cf 93d3 93d8 93dc 93df 93e0 93e5
93e9 93ed 93f0 93f3 93f7 93f9 93fd 9401
9404 9407 940b 940d 9411 9415 9418 941a
941e 9422 9426 9429 942d 9431 9433 9434
9439 1 943d 9441 9445 9448 944c 9450
9454 9458 945b 945f 9463 9466 9469 946e
9471 9474 9477 9478 947d 947e 1 9480
9485 9489 948d 9490 9495 949a 949d 94a1
94a2 94a7 94aa 94af 94b0 94b5 94b8 94bd
94be 94c3 94c6 94ca 94cb 94d0 94d3 94d8
94d9 94de 94e1 94e5 94e9 94ec 94ef 94f0
94f2 94f3 94f8 94f9 94fe 9500 9504 9507
9509 950d 950f 951b 951d 951f 9520 9525
9529 952b 9537 9539 953b 953f 9543 9546
9547 9549 954c 954f 9550 9555 9559 955d
9561 9563 9567 956a 956e 9572 9576 957a
957e 9582 9586 958a 958e 959a 959e 95a3
95a7 95aa 95ab 95b0 95b4 95b8 95bb 95be
95c2 95c4 95c8 95cc 95cf 95d2 95d6 95d8
95dc 95e0 95e3 95e5 95e9 95ed 95f1 95f4
95f8 95fc 95fe 95ff 9604 1 9608 960c
9610 9613 9617 961b 961f 9623 9626 962a
962e 9631 9634 9639 963c 963f 9642 9643
9648 9649 1 964b 9650 9654 9658 965b
9660 9665 9668 966c 966d 9672 9675 967a
967b 9680 9683 9688 9689 968e 9691 9695
9696 969b 969e 96a3 96a4 96a9 96ac 96b0
96b4 96b7 96ba 96bb 96bd 96be 96c3 96c4
96c9 96cb 96cf 96d2 96d4 96d8 96da 96e6
96e8 96ea 96eb 96f0 96f4 96f6 9702 9704
9708 970b 970e 970f 9714 9718 971c 9720
9723 9727 972b 972f 9733 9737 973b 973f
9743 9747 974b 974f 9750 9752 9756 975a
975e 9762 9766 976a 976e 9772 9776 977a
977e 9782 9786 9792 9796 979a 979d 97a1
97a5 97a7 97ab 97af 97b3 97b6 97ba 97be
97c0 97c1 97c6 1 97ca 97ce 97d2 97d5
97d9 97dd 97e1 97e5 97e8 97ec 97f0 97f3
97f6 97fb 97fe 9801 9804 9805 980a 980b
1 980d 9812 9816 981a 981d 9822 9827
982a 982e 982f 9834 9837 983c 983d 9842
9845 984a 984b 9850 9853 9857 9858 985d
9860 9865 9866 986b 986e 9872 9876 9879
987c 987d 987f 9880 9885 9886 988b 988d
9891 9894 9896 989a 989c 98a8 98aa 98ac
98ad 98b2 98b6 98b8 98c4 98c6 98ca 98ce
98d1 98d5 98d8 98dc 98df 98e0 98e5 98e8
98ec 98ef 98f3 98f7 98fb 98ff 9903 9907
990b 990f 9913 9917 991b 991f 9923 992f
9933 9937 993a 993e 9942 9944 9948 994c
9950 9953 9957 995b 995d 995e 9963 1
9967 996b 996f 9972 9976 997a 997e 9982
9985 9989 998d 9990 9993 9998 999b 999e
99a1 99a2 99a7 99a8 1 99aa 99af 99b3
99b7 99ba 99bf 99c4 99c7 99cb 99cc 99d1
99d4 99d9 99da 99df 99e2 99e7 99e8 99ed
99f0 99f4 99f5 99fa 99fd 9a02 9a03 9a08
9a0b 9a0f 9a13 9a16 9a19 9a1a 9a1c 9a1d
9a22 9a23 9a28 9a2a 9a2e 9a31 9a33 9a37
9a39 9a45 9a47 9a49 9a4a 9a4f 9a53 9a55
9a61 9a63 9a67 9a6b 9a6e 9a72 9a75 9a79
9a7c 9a7d 9a82 9a85 9a89 9a8d 9a91 9a94
9a95 9a97 9a9b 9a9f 9aa2 9aa3 9aa5 9aa8
9aac 9aaf 9ab3 9ab6 9ab7 9abc 9ac0 9ac3
9ac7 9acb 9acf 9ad3 9ad7 9adb 9adf 9ae3
9ae7 9af3 9af7 9afc 9b00 9b03 9b04 9b09
9b0d 9b11 9b14 9b17 9b1b 9b1d 9b21 9b25
9b28 9b2b 9b2f 9b31 9b35 9b39 9b3c 9b3e
9b42 9b46 9b4a 9b4d 9b51 9b55 9b57 9b58
9b5d 1 9b61 9b65 9b69 9b6c 9b70 9b74
9b78 9b7c 9b7f 9b83 9b87 9b8a 9b8d 9b92
9b95 9b98 9b9b 9b9c 9ba1 9ba2 1 9ba4
9ba9 9bad 9bb1 9bb4 9bb9 9bbe 9bc1 9bc5
9bc6 9bcb 9bce 9bd3 9bd4 9bd9 9bdc 9be1
9be2 9be7 9bea 9bee 9bef 9bf4 9bf7 9bfc
9bfd 9c02 9c05 9c09 9c0d 9c10 9c13 9c14
9c16 9c17 9c1c 9c1d 9c22 9c24 9c28 9c2b
9c2d 9c31 9c33 9c3f 9c41 9c43 9c44 9c49
9c4d 9c4f 9c5b 9c5d 9c61 9c63 9c67 9c6b
9c6e 9c6f 9c71 9c75 9c78 9c7c 9c7f 9c80
9c85 9c89 9c8d 9c90 9c94 9c98 9c9b 9c9c
9c9e 9ca2 9ca6 9ca9 9cad 9cae 9cb0 9cb4
9cb8 9cbc 9cc0 9cc4 9cc8 9ccc 9cd0 9cd4
9cd8 9cdc 9ce0 9ce4 9ce8 9cf4 9cf8 9cfd
9d01 9d04 9d05 9d0a 9d0e 9d12 9d15 9d18
9d1c 9d1e 9d22 9d26 9d29 9d2c 9d30 9d32
9d36 9d3a 9d3d 9d3f 9d43 9d47 9d4b 9d4e
9d52 9d56 9d58 9d59 9d5e 1 9d62 9d66
9d6a 9d6d 9d71 9d75 9d79 9d7d 9d80 9d84
9d88 9d8b 9d8e 9d93 9d96 9d99 9d9c 9d9d
9da2 9da3 1 9da5 9daa 9dae 9db2 9db5
9dba 9dbf 9dc2 9dc6 9dc7 9dcc 9dcf 9dd4
9dd5 9dda 9ddd 9de2 9de3 9de8 9deb 9def
9df0 9df5 9df8 9dfd 9dfe 9e03 9e06 9e0a
9e0e 9e11 9e14 9e15 9e17 9e18 9e1d 9e1e
9e23 9e25 9e29 9e2c 9e2e 9e32 9e34 9e40
9e42 9e44 9e45 9e4a 9e4e 9e50 9e5c 9e5e
9e60 9e64 9e68 9e6c 9e70 9e74 9e78 9e7c
9e80 9e84 9e88 9e8c 9e90 9e94 9e98 9e9c
9ea0 9ea4 9eb0 9eb4 9eb9 9ebd 9ec0 9ec1
9ec6 9eca 9ece 9ed1 9ed4 9ed8 9eda 9ede
9ee2 9ee5 9ee8 9eec 9eee 9ef2 9ef6 9ef9
9efb 9eff 9f03 9f07 9f0a 9f0e 9f12 9f14
9f15 9f1a 1 9f1e 9f22 9f26 9f29 9f2d
9f31 9f35 9f39 9f3c 9f40 9f44 9f47 9f4a
9f4f 9f52 9f55 9f58 9f59 9f5e 9f5f 1
9f61 9f66 9f6a 9f6e 9f71 9f76 9f7b 9f7e
9f82 9f83 9f88 9f8b 9f90 9f91 9f96 9f99
9f9e 9f9f 9fa4 9fa7 9fab 9fac 9fb1 9fb4
9fb9 9fba 9fbf 9fc2 9fc6 9fca 9fcd 9fd0
9fd1 9fd3 9fd4 9fd9 9fda 9fdf 9fe1 9fe5
9fe8 9fea 9fee 9ff0 9ffc 9ffe a000 a001
a006 a00a a00c a018 a01a a01c a020 a024
a027 a02b a02f a032 a036 a039 a03d a040
a041 a046 a049 a04d a051 a054 a055 a057
a05a a05d a05e a063 1 a066 a06b a06f
a073 a077 a083 a087 a08c a090 a093 a094
a099 a09d a0a1 a0a4 a0a7 a0ab a0ad a0b1
a0b5 a0b8 a0bb a0bf a0c1 a0c5 a0c9 a0cc
a0ce a0d2 a0d6 a0da a0dd a0e1 a0e5 a0e7
a0e8 a0ed 1 a0f1 a0f5 a0f9 a0fc a100
a104 a108 a10c a10f a113 a117 a11a a11d
a122 a125 a128 a12b a12c a131 a132 1
a134 a139 a13d a141 a144 a149 a14e a151
a155 a156 a15b a15e a163 a164 a169 a16c
a171 a172 a177 a17a a17e a17f a184 a187
a18c a18d a192 a195 a199 a19d a1a0 a1a3
a1a4 a1a6 a1a7 a1ac a1ad a1b2 a1b4 a1b8
a1bb a1bd a1c1 a1c3 a1cf a1d1 a1d3 a1d4
a1d9 a1dd a1df a1eb a1ed a1ef a1f3 a1f6
a1f8 a1fc a200 a204 a208 a20c a210 a214
a218 a21c a220 a224 a228 a22c a230 a234
a238 a23c a240 a244 a248 a24c a250 a254
a258 a25c a260 a264 a268 a26c a270 a274
a278 a27c a280 a28c a290 a294 a297 a29b
a29f a2a1 a2a5 a2a9 a2ad a2b0 a2b4 a2b8
a2ba a2bb a2c0 1 a2c4 a2c8 a2cc a2cf
a2d3 a2d7 a2db a2df a2e2 a2e6 a2ea a2ed
a2f0 a2f5 a2f8 a2fb a2fe a2ff a304 a305
1 a307 a30c a310 a314 a317 a31c a321
a324 a328 a329 a32e a331 a336 a337 a33c
a33f a344 a345 a34a a34d a351 a352 a357
a35a a35f a360 a365 a368 a36c a370 a373
a376 a377 a379 a37a a37f a380 a385 a387
a38b a38e a390 a394 a396 a3a2 a3a4 a3a6
a3a7 a3ac a3b0 a3b2 a3be a3c0 a3c4 a3c8
a3cb a3cf a3d2 a3d6 a3d9 a3da a3df a3e2
a3e6 a3e9 a3ea a3ef a3f2 1 a3f5 a3fa
a3fe a402 a405 a409 a40d a410 a411 a413
a417 a41b a41e a422 a423 a425 a429 a42d
a431 a435 a441 a445 a44a a44e a451 a452
a457 a45b a45f a462 a465 a469 a46b a46f
a473 a476 a479 a47d a47f a483 a487 a48a
a48c a490 a494 a498 a49b a49f a4a3 a4a5
a4a6 a4ab 1 a4af a4b3 a4b7 a4ba a4be
a4c2 a4c6 a4ca a4cd a4d1 a4d5 a4d8 a4db
a4e0 a4e3 a4e6 a4e9 a4ea a4ef a4f0 1
a4f2 a4f7 a4fb a4ff a502 a507 a50c a50f
a513 a514 a519 a51c a521 a522 a527 a52a
a52f a530 a535 a538 a53c a53d a542 a545
a54a a54b a550 a553 a557 a55b a55e a561
a562 a564 a565 a56a a56b a570 a572 a576
a579 a57b a57f a581 a58d a58f a591 a592
a597 a59b a59d a5a9 a5ab a5af a5b3 a5b7
a5bb a5bf a5c3 a5c7 a5cb a5cf a5d3 a5d7
a5e3 a5e7 a5ec a5f0 a5f3 a5f4 a5f9 a5fd
a601 a604 a607 a60b a60d a611 a615 a618
a61b a61f a621 a625 a629 a62c a62e a632
a636 a63a a63d a641 a645 a647 a648 a64d
1 a651 a655 a659 a65c a660 a664 a668
a66c a66f a673 a677 a67a a67d a682 a685
a688 a68b a68c a691 a692 1 a694 a699
a69d a6a1 a6a4 a6a9 a6ae a6b1 a6b5 a6b6
a6bb a6be a6c3 a6c4 a6c9 a6cc a6d1 a6d2
a6d7 a6da a6de a6df a6e4 a6e7 a6ec a6ed
a6f2 a6f5 a6f9 a6fd a700 a703 a704 a706
a707 a70c a70d a712 a714 a718 a71b a71d
a721 a723 a72f a731 a733 a734 a739 a73d
a73f a74b a74d a751 a755 a759 a75d a761
a765 a769 a76d a779 a77d a782 a786 a789
a78a a78f a793 a797 a79a a79d a7a1 a7a3
a7a7 a7ab a7ae a7b1 a7b5 a7b7 a7bb a7bf
a7c2 a7c4 a7c8 a7cc a7d0 a7d3 a7d7 a7db
a7dd a7de a7e3 1 a7e7 a7eb a7ef a7f2
a7f6 a7fa a7fe a802 a805 a809 a80d a810
a813 a818 a81b a81e a821 a822 a827 a828
1 a82a a82f a833 a837 a83a a83f a844
a847 a84b a84c a851 a854 a859 a85a a85f
a862 a867 a868 a86d a870 a874 a875 a87a
a87d a882 a883 a888 a88b a88f a893 a896
a899 a89a a89c a89d a8a2 a8a3 a8a8 a8aa
a8ae a8b1 a8b3 a8b7 a8b9 a8c5 a8c7 a8c9
a8ca a8cf a8d3 a8d5 a8e1 a8e3 a8e5 a8e9
a8ed a8f1 a8f5 a8f9 a8fd a901 a905 a911
a915 a91a a91e a921 a922 a927 a92b a92f
a932 a935 a939 a93b a93f a943 a946 a949
a94d a94f a953 a957 a95a a95c a960 a964
a968 a96b a96f a973 a975 a976 a97b 1
a97f a983 a987 a98a a98e a992 a996 a99a
a99d a9a1 a9a5 a9a8 a9ab a9b0 a9b3 a9b6
a9b9 a9ba a9bf a9c0 1 a9c2 a9c7 a9cb
a9cf a9d2 a9d7 a9dc a9df a9e3 a9e4 a9e9
a9ec a9f1 a9f2 a9f7 a9fa a9ff aa00 aa05
aa08 aa0c aa0d aa12 aa15 aa1a aa1b aa20
aa23 aa27 aa2b aa2e aa31 aa32 aa34 aa35
aa3a aa3b aa40 aa42 aa46 aa49 aa4b aa4f
aa51 aa5d aa5f aa61 aa62 aa67 aa6b aa6d
aa79 aa7b aa7f aa83 aa87 aa8b aa8f aa93
aa9f aaa3 aaa8 aaac aaaf aab0 aab5 aab9
aabd aac0 aac3 aac7 aac9 aacd aad1 aad4
aad7 aadb aadd aae1 aae5 aae8 aaea aaee
aaf2 aaf6 aaf9 aafd ab01 ab03 ab04 ab09
1 ab0d ab11 ab15 ab18 ab1c ab20 ab24
ab28 ab2b ab2f ab33 ab36 ab39 ab3e ab41
ab44 ab47 ab48 ab4d ab4e 1 ab50 ab55
ab59 ab5d ab60 ab65 ab6a ab6d ab71 ab72
ab77 ab7a ab7f ab80 ab85 ab88 ab8d ab8e
ab93 ab96 ab9a ab9b aba0 aba3 aba8 aba9
abae abb1 abb5 abb9 abbc abbf abc0 abc2
abc3 abc8 abc9 abce abd0 abd4 abd7 abd9
abdd abdf abeb abed abef abf0 abf5 abf9
abfb ac07 ac09 ac0b ac0f ac13 ac16 ac18
ac1c ac20 ac23 ac27 ac2b ac2f ac33 ac37
ac43 ac47 ac4c ac50 ac53 ac54 ac59 ac5d
ac61 ac64 ac67 ac6b ac6d ac71 ac75 ac78
ac7b ac7f ac81 ac85 ac89 ac8c ac8e ac92
ac96 ac9a ac9d aca1 aca5 aca7 aca8 acad
1 acb1 acb5 acb9 acbc acc0 acc4 acc8
accc accf acd3 acd7 acda acdd ace2 ace5
ace8 aceb acec acf1 acf2 1 acf4 acf9
acfd ad01 ad04 ad09 ad0e ad11 ad15 ad16
ad1b ad1e ad23 ad24 ad29 ad2c ad31 ad32
ad37 ad3a ad3e ad3f ad44 ad47 ad4c ad4d
ad52 ad55 ad59 ad5d ad60 ad63 ad64 ad66
ad67 ad6c ad6d ad72 ad74 ad78 ad7b ad7d
ad81 ad83 ad8f ad91 ad93 ad94 ad99 ad9d
ad9f adab adad adaf adb3 adb6 adba adbe
adc2 adc6 add2 add6 addb addf ade2 ade3
ade8 adec adf0 adf3 adf6 adfa adfc ae00
ae04 ae07 ae0a ae0e ae10 ae14 ae18 ae1b
ae1d ae21 ae25 ae29 ae2c ae30 ae34 ae36
ae37 ae3c 1 ae40 ae44 ae48 ae4b ae4f
ae53 ae57 ae5b ae5e ae62 ae66 ae69 ae6c
ae71 ae74 ae77 ae7a ae7b ae80 ae81 1
ae83 ae88 ae8c ae90 ae93 ae98 ae9d aea0
aea4 aea5 aeaa aead aeb2 aeb3 aeb8 aebb
aec0 aec1 aec6 aec9 aecd aece aed3 aed6
aedb aedc aee1 aee4 aee8 aeec aeef aef2
aef3 aef5 aef6 aefb aefc af01 af03 af07
af0a af0c af10 af12 af1e af20 af22 af23
af28 af2c af2e af3a af3c af40 af44 af48
af54 af58 af5d af61 af64 af65 af6a af6e
af72 af75 af78 af7c af7e af82 af86 af89
af8c af90 af92 af96 af9a af9d af9f afa3
afa7 afab afae afb2 afb6 afb8 afb9 afbe
1 afc2 afc6 afca afcd afd1 afd5 afd9
afdd afe0 afe4 afe8 afeb afee aff3 aff6
aff9 affc affd b002 b003 1 b005 b00a
b00e b012 b015 b01a b01f b022 b026 b027
b02c b02f b034 b035 b03a b03d b042 b043
b048 b04b b04f b050 b055 b058 b05d b05e
b063 b066 b06a b06e b071 b074 b075 b077
b078 b07d b07e b083 b085 b089 b08c b08e
b092 b094 b0a0 b0a2 b0a4 b0a5 b0aa b0ae
b0b0 b0bc b0be b0c2 b0c6 b0ca b0ce b0d2
b0de b0e2 b0e7 b0eb b0ee b0ef b0f4 b0f8
b0fc b0ff b102 b106 b108 b10c b110 b113
b116 b11a b11c b120 b124 b127 b129 b12d
b131 b135 b138 b13c b140 b142 b143 b148
1 b14c b150 b154 b157 b15b b15f b163
b167 b16a b16e b172 b175 b178 b17d b180
b183 b186 b187 b18c b18d 1 b18f b194
b198 b19c b19f b1a4 b1a9 b1ac b1b0 b1b1
b1b6 b1b9 b1be b1bf b1c4 b1c7 b1cc b1cd
b1d2 b1d5 b1d9 b1da b1df b1e2 b1e7 b1e8
b1ed b1f0 b1f4 b1f8 b1fb b1fe b1ff b201
b202 b207 b208 b20d b20f b213 b216 b218
b21c b21e b22a b22c b22e b22f b234 b238
b23a b246 b248 b24c b250 b253 b256 b257
b259 b25c b261 b262 b267 b26b b26e b272
b274 b278 b27b b27f b283 b287 b289 b28d
b291 b294 b298 b29c b29f b2a0 b2a2 b2a5
b2a8 b2a9 b2ae b2b2 b2b6 b2b9 b2ba b2bc
b2bf b2c2 b2c3 b2c8 b2cb b2cf b2d2 b2d3
b2d8 b2db 1 b2de b2e3 b2e7 b2eb b2ef
b2f3 b2f7 b2fb b2ff b30b b30f b313 b316
b31a b31e b320 b324 b328 b32c b32f b333
b337 b339 b33a b33f 1 b343 b347 b34b
b34e b352 b356 b35a b35e b361 b365 b369
b36c b36f b374 b377 b37a b37d b37e b383
b384 1 b386 b38b b38f b393 b396 b39b
b3a0 b3a3 b3a7 b3a8 b3ad b3b0 b3b5 b3b6
b3bb b3be b3c3 b3c4 b3c9 b3cc b3d0 b3d1
b3d6 b3d9 b3de b3df b3e4 b3e7 b3eb b3ef
b3f2 b3f5 b3f6 b3f8 b3f9 b3fe b3ff b404
b406 b40a b40d b40f b413 b415 b421 b423
b425 b426 b42b b42f b431 b43d b43f b443
b447 b44a b44e b451 b455 b458 b459 b45e
b461 b465 b469 b46c b46d b46f b472 b475
b476 b47b 1 b47e b483 b487 b48b b48f
b493 b497 b4a3 b4a7 b4ac b4b0 b4b3 b4b4
b4b9 b4bd b4c1 b4c4 b4c7 b4cb b4cd b4d1
b4d5 b4d8 b4db b4df b4e1 b4e5 b4e9 b4ec
b4ee b4f2 b4f6 b4fa b4fd b501 b505 b507
b508 b50d 1 b511 b515 b519 b51c b520
b524 b528 b52c b52f b533 b537 b53a b53d
b542 b545 b548 b54b b54c b551 b552 1
b554 b559 b55d b561 b564 b569 b56e b571
b575 b576 b57b b57e b583 b584 b589 b58c
b591 b592 b597 b59a b59e b59f b5a4 b5a7
b5ac b5ad b5b2 b5b5 b5b9 b5bd b5c0 b5c3
b5c4 b5c6 b5c7 b5cc b5cd b5d2 b5d4 b5d8
b5db b5dd b5e1 b5e3 b5ef b5f1 b5f3 b5f4
b5f9 b5fd b5ff b60b b60d b611 b613 b617
b61b b61e b622 b625 b629 b62c b62d b632
b635 b639 b63d b640 b641 b643 b646 b649
b64a b64f 1 b652 b657 b65b b65f b664
b666 b66a b66e b671 b675 b679 b67b b67f
b683 b687 b68a b68e b692 b694 b695 b69a
1 b69e b6a2 b6a6 b6a9 b6ad b6b1 b6b5
b6b9 b6bc b6c0 b6c4 b6c7 b6ca b6cf b6d2
b6d5 b6d8 b6d9 b6de b6df 1 b6e1 b6e6
b6ea b6ee b6f1 b6f6 b6fb b6fe b702 b703
b708 b70b b710 b711 b716 b719 b71e b71f
b724 b727 b72b b72c b731 b734 b739 b73a
b73f b742 b746 b74a b74d b750 b751 b753
b754 b759 b75a b75f b761 b765 b768 b76a
b76e b770 b77c b77e b780 b781 b786 b78a
b78c b798 b79a b79e b7a2 b7a5 b7a9 b7ad
b7b0 b7b3 b7b8 b7bb b7be b7c1 b7c2 b7c7
b7c8 1 b7ca b7cf b7d3 b7d7 b7da b7df
b7e4 b7e7 b7eb b7ec b7f1 b7f4 b7f9 b7fa
b7ff b802 b807 b808 b80d b810 b814 b818
b81c b820 b823 b824 b826 b82b b82c b82e
b82f b834 b837 b83c b83d b842 b845 b84a
b84b b850 b853 b857 b858 b85d b860 b865
b866 b86b b86c b871 b873 b877 b87a b87e
b882 b885 b889 b88d b890 b893 b898 b89b
b89e b8a1 b8a2 b8a7 b8a8 1 b8aa b8af
b8b3 b8b7 b8ba b8bf b8c4 b8c7 b8cb b8cc
b8d1 b8d2 b8d7 b8d9 b8dd b8e0 b8e4 b8e8
b8eb b8ef b8f3 b8f6 b8fa b8fe b8ff b904
b906 b90a b90e b911 b913 b917 b91a b91e
b922 b925 b926 b928 b92c b92f b933 b936
b937 b93c b940 b944 b947 b948 b94a b94e
b951 b955 b958 b959 1 b95e b963 b967
b96b b970 b975 b979 b97d b981 b984 b987
b98b b98f b993 b996 b997 b999 b99c b99f
b9a0 b9a5 b9a9 b9ad b9b0 b9b1 b9b3 b9b6
b9b9 b9ba 1 b9bf b9c4 b9c8 b9cc b9d0
b9d4 b9d8 b9dc b9e0 b9e4 b9e8 b9ec b9f0
b9f4 b9f8 b9fc ba00 ba04 ba10 ba14 ba19
ba1d ba20 ba21 ba26 ba2a ba2e ba31 ba34
ba38 ba3a ba3e ba42 ba45 ba48 ba4c ba4e
ba52 ba56 ba59 ba5b ba5f ba63 ba67 ba6a
ba6e ba72 ba74 ba75 ba7a 1 ba7e ba82
ba86 ba89 ba8d ba91 ba95 ba99 ba9c baa0
baa4 baa7 baaa baaf bab2 bab5 bab8 bab9
babe babf 1 bac1 bac6 baca bace bad1
bad6 badb bade bae2 bae3 bae8 baeb baf0
baf1 baf6 baf9 bafe baff bb04 bb07 bb0b
bb0c bb11 bb14 bb19 bb1a bb1f bb22 bb26
bb2a bb2d bb30 bb31 bb33 bb34 bb39 bb3a
bb3f bb41 bb45 bb48 bb4a bb4e bb50 bb5c
bb5e bb60 bb61 bb66 bb6a bb6c bb78 bb7a
bb7c bb80 bb84 bb88 bb8c bb90 bb94 bb98
bb9c bba0 bba4 bba8 bbac bbb0 bbb4 bbb8
bbbc bbc0 bbc4 bbc8 bbcc bbd0 bbd4 bbd8
bbdc bbe0 bbe4 bbe8 bbec bbf8 bbfc bc01
bc05 bc08 bc09 bc0e bc12 bc16 bc19 bc1c
bc20 bc22 bc26 bc2a bc2d bc30 bc34 bc36
bc3a bc3e bc41 bc43 bc47 bc4b bc4f bc52
bc56 bc5a bc5c bc5d bc62 1 bc66 bc6a
bc6e bc71 bc75 bc79 bc7d bc81 bc84 bc88
bc8c bc8f bc92 bc97 bc9a bc9d bca0 bca1
bca6 bca7 1 bca9 bcae bcb2 bcb6 bcb9
bcbe bcc3 bcc6 bcca bccb bcd0 bcd3 bcd8
bcd9 bcde bce1 bce6 bce7 bcec bcef bcf3
bcf4 bcf9 bcfc bd01 bd02 bd07 bd0a bd0e
bd12 bd15 bd18 bd19 bd1b bd1c bd21 bd22
bd27 bd29 bd2d bd30 bd32 bd36 bd38 bd44
bd46 bd48 bd49 bd4e bd52 bd54 bd60 bd62
bd64 bd68 bd6c bd6f bd73 bd77 bd7a bd7e
bd81 bd85 bd88 bd89 bd8e bd91 bd95 bd98
bd9c bda0 bda4 bda8 bdac bdb0 bdb4 bdb8
bdc4 bdc8 bdcc bdcf bdd3 bdd7 bdd9 bddd
bde1 bde5 bde8 bdec bdf0 bdf2 bdf3 bdf8
1 bdfc be00 be04 be07 be0b be0f be13
be17 be1a be1e be22 be25 be28 be2d be30
be33 be36 be37 be3c be3d 1 be3f be44
be48 be4c be4f be54 be59 be5c be60 be61
be66 be69 be6e be6f be74 be77 be7c be7d
be82 be85 be89 be8a be8f be92 be97 be98
be9d bea0 bea4 bea8 beab beae beaf beb1
beb2 beb7 beb8 bebd bebf bec3 bec6 bec8
becc bece beda bedc bede bedf bee4 bee8
beea bef6 bef8 befc bf00 bf03 bf04 bf06
bf09 bf0c bf0d bf12 bf16 bf1c bf1e bf22
bf26 bf2a bf2e bf32 bf3e bf42 bf47 bf4b
bf4e bf4f bf54 bf58 bf5c bf5f bf62 bf66
bf68 bf6c bf70 bf73 bf76 bf7a bf7c bf80
bf84 bf87 bf89 bf8d bf91 bf95 bf98 bf9c
bfa0 bfa2 bfa3 bfa8 1 bfac bfb0 bfb4
bfb7 bfbb bfbf bfc3 bfc7 bfca bfce bfd2
bfd5 bfd8 bfdd bfe0 bfe3 bfe6 bfe7 bfec
bfed 1 bfef bff4 bff8 bffc bfff c004
c009 c00c c010 c011 c016 c019 c01e c01f
c024 c027 c02c c02d c032 c035 c039 c03a
c03f c042 c047 c048 c04d c050 c054 c058
c05b c05e c05f c061 c062 c067 c068 c06d
c06f c073 c076 c078 c07c c07e c08a c08c
c08e c08f c094 c098 c09a c0a6 c0a8 c0ac
c0b0 c0b4 c0b8 c0bc c0bd c0bf c0c2 c0c3
c0c5 c0c8 c0cc c0d0 c0d4 c0d5 c0d7 c0da
c0db c0dd c0de c0e3 c0e6 c0e9 c0ec c0ed
c0f2 c0f3 c0f5 c0f9 c0fd c101 c105 c109
c10d c111 c115 c119 c11d c129 c12d c131
c134 c138 c13c c13e c142 c146 c14a c14d
c151 c155 c157 c158 c15d 1 c161 c165
c169 c16c c170 c174 c178 c17c c17f c183
c187 c18a c18d c192 c195 c198 c19b c19c
c1a1 c1a2 1 c1a4 c1a9 c1ad c1b1 c1b4
c1b9 c1be c1c1 c1c5 c1c6 c1cb c1ce c1d3
c1d4 c1d9 c1dc c1e1 c1e2 c1e7 c1ea c1ee
c1ef c1f4 c1f7 c1fc c1fd c202 c205 c209
c20d c210 c213 c214 c216 c217 c21c c21d
c222 c224 c228 c22b c22d c231 c233 c23f
c241 c243 c244 c249 c24d c24f c25b c25d
c261 c265 c268 c269 c26b c26f c272 c276
c279 c27a c27c c27d c282 c286 c28a c28d
c291 c295 c298 c299 c29b c29f c2a0 c2a5
c2a7 c2ab c2ae c2b2 c2b6 c2ba c2be c2c2
c2c6 c2ca c2ce c2d2 c2d6 c2da c2de c2e2
c2e6 c2ea c2ee c2f2 c2f6 c2fa c2fe c302
c306 c312 c316 c31b c31f c322 c323 c328
c32c c330 c333 c336 c33a c33c c340 c344
c347 c34a c34e c350 c354 c358 c35b c35d
c361 c365 c369 c36c c370 c374 c376 c377
c37c 1 c380 c384 c388 c38b c38f c393
c397 c39b c39e c3a2 c3a6 c3a9 c3ac c3b1
c3b4 c3b7 c3ba c3bb c3c0 c3c1 1 c3c3
c3c8 c3cc c3d0 c3d3 c3d8 c3dd c3e0 c3e4
c3e5 c3ea c3ed c3f2 c3f3 c3f8 c3fb c400
c401 c406 c409 c40d c40e c413 c416 c41b
c41c c421 c424 c428 c42c c42f c432 c433
c435 c436 c43b c43c c441 c443 c447 c44a
c44c c450 c452 c45e c460 c462 c463 c468
c46c c46e c47a c47c c47e c482 c486 c489
c48d c491 c495 c499 c49d c4a1 c4a5 c4a9
c4ad c4b1 c4b5 c4b9 c4bd c4c1 c4c5 c4c9
c4cd c4d1 c4d5 c4d9 c4dd c4e1 c4e5 c4e9
c4ed c4f1 c4f5 c4f9 c4fd c501 c505 c511
c515 c51a c51e c521 c522 c527 c52b c52f
c532 c535 c539 c53b c53f c543 c546 c549
c54d c54f c553 c557 c55a c55c c560 c564
c568 c56b c56f c573 c575 c576 c57b 1
c57f c583 c587 c58a c58e c592 c596 c59a
c59d c5a1 c5a5 c5a8 c5ab c5b0 c5b3 c5b6
c5b9 c5ba c5bf c5c0 1 c5c2 c5c7 c5cb
c5cf c5d2 c5d7 c5dc c5df c5e3 c5e4 c5e9
c5ec c5f1 c5f2 c5f7 c5fa c5ff c600 c605
c608 c60c c60d c612 c615 c61a c61b c620
c623 c627 c62b c62e c631 c632 c634 c635
c63a c63b c640 c642 c646 c649 c64b c64f
c651 c65d c65f c661 c662 c667 c66b c66d
c679 c67b c67f c683 c687 c68b c68f c690
c692 c695 c696 c698 c69b c69f c6a3 c6a7
c6a8 c6aa c6ad c6ae c6b0 c6b1 c6b6 c6b9
c6bc c6bf c6c0 c6c5 c6c6 c6c8 c6cc c6d0
c6d4 c6d8 c6db c6df c6e3 c6e6 c6e7 c6e9
c6ed c6f1 c6f4 c6f5 c6f7 c6fb c6ff c703
c707 c70b c70f c713 c717 c71a c71b c71d
c721 c725 c728 c729 c72b c72c c72e c732
c734 c738 c73e c740 c744 c748 c74b c74d
c751 c756 c75a c75e c761 c764 c765 c76a
c76e c772 c775 c776 c778 c77b c77e c77f
c784 c788 c78c c790 c794 c798 c79b c79c
c79e c7a1 c7a4 c7a5 c7aa c7ae c7b2 c7b5
c7b6 c7b8 c7bb c7be c7bf 1 c7c4 c7c9
c7cd c7d1 c7d4 c7d5 c7d7 c7da c7dd c7de
1 c7e3 c7e8 c7ec c7ef c7f3 c7f7 c7fb
c7ff c802 c803 c805 c809 c80b c80f c812
c816 c81a c81e c822 c826 c82a c82e c832
c836 c83a c83e c842 c84e c852 c857 c85b
c85e c85f c864 c868 c86c c86f c872 c876
c878 c87c c880 c883 c886 c88a c88c c890
c894 c897 c899 c89d c8a1 c8a5 c8a8 c8ac
c8b0 c8b2 c8b3 c8b8 1 c8bc c8c0 c8c4
c8c7 c8cb c8cf c8d3 c8d7 c8da c8de c8e2
c8e5 c8e8 c8ed c8f0 c8f3 c8f6 c8f7 c8fc
c8fd 1 c8ff c904 c908 c90c c90f c914
c919 c91c c920 c921 c926 c929 c92e c92f
c934 c937 c93c c93d c942 c945 c949 c94a
c94f c952 c957 c958 c95d c960 c964 c968
c96b c96e c96f c971 c972 c977 c978 c97d
c97f c983 c986 c988 c98c c98e c99a c99c
c99e c99f c9a4 c9a8 c9aa c9b6 c9b8 c9ba
c9be c9c2 c9c6 c9ca c9ce c9d2 c9d6 c9da
c9de c9e2 c9e6 c9ea c9ee c9f2 c9f6 c9fa
c9fe ca02 ca06 ca0a ca0e ca12 ca16 ca1a
ca1e ca22 ca26 ca2a ca2e ca32 ca35 ca36
ca38 ca3c ca40 ca43 ca44 ca46 ca49 ca4c
ca4f ca50 ca55 ca58 ca5c ca60 ca63 ca64
ca66 ca6a ca6d ca71 ca74 ca75 ca77 ca78
ca7d ca81 ca85 ca88 ca89 ca8b ca8f ca92
ca96 ca99 ca9a ca9c ca9d 1 caa2 caa7
1 caaa caaf cab3 cab7 caba cabb cabd
cac0 cac3 cac4 cac9 cacd cad1 cad5 cad9
cadd cae1 cae5 cae9 caed caf1 caf5 caf9
cafd cb01 cb05 cb09 cb0d cb11 cb15 cb19
cb1d cb21 cb25 cb29 cb2d cb31 cb35 cb39
cb3d cb41 cb45 cb49 cb4d cb51 cb55 cb59
cb5d cb69 cb6d cb72 cb76 cb79 cb7a cb7f
cb83 cb87 cb8a cb8d cb91 cb93 cb97 cb9b
cb9e cba1 cba5 cba7 cbab cbaf cbb2 cbb4
cbb8 cbbc cbc0 cbc3 cbc7 cbcb cbcd cbce
cbd3 1 cbd7 cbdb cbdf cbe2 cbe6 cbea
cbee cbf2 cbf5 cbf9 cbfd cc00 cc03 cc08
cc0b cc0e cc11 cc12 cc17 cc18 1 cc1a
cc1f cc23 cc27 cc2a cc2f cc34 cc37 cc3b
cc3c cc41 cc44 cc49 cc4a cc4f cc52 cc57
cc58 cc5d cc60 cc64 cc65 cc6a cc6d cc72
cc73 cc78 cc7b cc7f cc83 cc86 cc89 cc8a
cc8c cc8d cc92 cc93 cc98 cc9a cc9e cca1
cca3 cca7 cca9 ccb5 ccb7 ccb9 ccba ccbf
ccc3 ccc5 ccd1 ccd3 ccd5 ccd9 ccdd cce1
cce5 cce9 cced ccf1 ccf5 ccf9 ccfd cd01
cd05 cd09 cd0d cd11 cd15 cd19 cd1d cd21
cd25 cd29 cd2d cd31 cd35 cd39 cd3d cd41
cd45 cd49 cd4d cd51 cd55 cd59 cd5d cd61
cd65 cd69 cd6d cd71 cd7d cd81 cd86 cd8a
cd8d cd8e cd93 cd97 cd9b cd9e cda1 cda5
cda7 cdab cdaf cdb2 cdb5 cdb9 cdbb cdbf
cdc3 cdc6 cdc8 cdcc cdd0 cdd4 cdd7 cddb
cddf cde1 cde2 cde7 1 cdeb cdef cdf3
cdf6 cdfa cdfe ce02 ce06 ce09 ce0d ce11
ce14 ce17 ce1c ce1f ce22 ce25 ce26 ce2b
ce2c 1 ce2e ce33 ce37 ce3b ce3e ce43
ce48 ce4b ce4f ce50 ce55 ce58 ce5d ce5e
ce63 ce66 ce6b ce6c ce71 ce74 ce78 ce79
ce7e ce81 ce86 ce87 ce8c ce8f ce93 ce97
ce9a ce9d ce9e cea0 cea1 cea6 cea7 ceac
ceae ceb2 ceb5 ceb7 cebb cebd cec9 cecb
cecd cece ced3 ced7 ced9 cee5 cee7 cee9
ceed cef1 cef4 cef6 cefa cefe cf02 cf06
cf0a cf0e cf12 cf16 cf1a cf1e cf22 cf26
cf2a cf2e cf32 cf36 cf3a cf3e cf42 cf46
cf4a cf4e cf52 cf56 cf5a cf5e cf62 cf66
cf6a cf6e cf72 cf76 cf7a cf86 cf8a cf8f
cf93 cf96 cf97 cf9c cfa0 cfa4 cfa7 cfaa
cfae cfb0 cfb4 cfb8 cfbb cfbe cfc2 cfc4
cfc8 cfcc cfcf cfd1 cfd5 cfd9 cfdd cfe0
cfe4 cfe8 cfea cfeb cff0 1 cff4 cff8
cffc cfff d003 d007 d00b d00f d012 d016
d01a d01d d020 d025 d028 d02b d02e d02f
d034 d035 1 d037 d03c d040 d044 d047
d04c d051 d054 d058 d059 d05e d061 d066
d067 d06c d06f d074 d075 d07a d07d d081
d082 d087 d08a d08f d090 d095 d098 d09c
d0a0 d0a3 d0a6 d0a7 d0a9 d0aa d0af d0b0
d0b5 d0b7 d0bb d0be d0c0 d0c4 d0c6 d0d2
d0d4 d0d6 d0d7 d0dc d0e0 d0e2 d0ee d0f0
d0f2 d0f6 d0fa d0fd d101 d105 d108 d109
d10b d10e d111 d112 d117 d11a d11e d122
d125 d126 d128 d12b d12e d12f d134 1
d137 d13c d140 d143 d147 d14b d14d d151
d155 d158 d159 d15b d15e d161 d162 d167
d16b d16f d173 d176 d177 d179 d17d d17f
d183 d187 d18a d18c d190 d194 d197 d19b
d19f d1a3 d1a7 d1ab d1af d1b2 d1b3 d1b5
d1b9 d1bd d1c0 d1c1 d1c3 d1c7 d1cb d1ce
d1cf d1d1 d1d5 d1d9 d1dc d1dd d1df d1e3
d1e7 d1ea d1eb d1ed d1f1 d1f5 d1f8 d1f9
d1fb d1ff d203 d206 d207 d209 d20d d211
d214 d215 d217 d21b d21f d223 d224 d226
d22a d22e d232 d235 d236 d238 d23c d23f
d243 d246 d247 d24c d250 d254 d259 d25b
d25f d263 d266 d26a d26e d270 d274 d278
d27c d27f d283 d287 d289 d28a d28f 1
d293 d297 d29b d29e d2a2 d2a6 d2aa d2ae
d2b1 d2b5 d2b9 d2bc d2bf d2c4 d2c7 d2ca
d2cd d2ce d2d3 d2d4 1 d2d6 d2db d2df
d2e3 d2e6 d2eb d2f0 d2f3 d2f7 d2f8 d2fd
d300 d305 d306 d30b d30e d313 d314 d319
d31c d320 d321 d326 d329 d32e d32f d334
d337 d33b d33f d342 d345 d346 d348 d349
d34e d34f d354 d356 d35a d35d d35f d363
d365 d371 d373 d375 d376 d37b d37f d381
d38d d38f d393 d397 d39a d39e d3a2 d3a5
d3a8 d3ad d3b0 d3b3 d3b6 d3b7 d3bc d3bd
1 d3bf d3c4 d3c8 d3cc d3cf d3d4 d3d9
d3dc d3e0 d3e1 d3e6 d3e9 d3ee d3ef d3f4
d3f7 d3fc d3fd d402 d405 d409 d40d d411
d415 d418 d419 d41b d420 d421 d423 d424
d429 d42a d42f d431 d435 d438 d43c d440
d443 d447 d44b d44e d451 d456 d459 d45c
d45f d460 d465 d466 1 d468 d46d d471
d475 d478 d47d d482 d485 d489 d48a d48f
d490 d495 d497 d49b d49e d4a2 d4a6 d4a9
d4ad d4b1 d4b4 d4b8 d4b9 d4be d4c2 d4c4
d4c8 d4cc d4cf d4d0 d4d2 d4d5 d4d8 d4d9
d4de d4e2 d4e6 d4eb d4ed d4f1 d4f5 d4f8
d4fc d500 d502 d506 d50a d50e d511 d515
d519 d51b d51c d521 1 d525 d529 d52d
d530 d534 d538 d53c d540 d543 d547 d54b
d54e d551 d556 d559 d55c d55f d560 d565
d566 1 d568 d56d d571 d575 d578 d57d
d582 d585 d589 d58a d58f d592 d597 d598
d59d d5a0 d5a5 d5a6 d5ab d5ae d5b2 d5b3
d5b8 d5bb d5c0 d5c1 d5c6 d5c9 d5cd d5d1
d5d4 d5d7 d5d8 d5da d5db d5e0 d5e1 d5e6
d5e8 d5ec d5ef d5f1 d5f5 d5f7 d603 d605
d607 d608 d60d d611 d613 d61f d621 d625
d629 d62c d630 d634 d637 d63a d63f d642
d645 d648 d649 d64e d64f 1 d651 d656
d65a d65e d661 d666 d66b d66e d672 d673
d678 d67b d680 d681 d686 d689 d68e d68f
d694 d697 d69b d69f d6a3 d6a4 d6a6 d6ab
d6ac d6ae d6af d6b4 d6b7 d6bc d6bd d6c2
d6c5 d6ca d6cb d6d0 d6d3 d6d7 d6d8 d6dd
d6e0 d6e5 d6e6 d6eb d6ec d6f1 d6f3 d6f7
d6fa d6fe d702 d705 d709 d70d d710 d713
d718 d71b d71e d721 d722 d727 d728 1
d72a d72f d733 d737 d73a d73f d744 d747
d74b d74c d751 d752 d757 d759 d75d d760
d764 d768 d76b d76f d773 d776 d777 d779
d77d d781 d782 d787 d789 d78d d791 d794
d796 d79a d79e d7a1 d7a2 d7a4 d7a7 d7aa
d7ab d7b0 d7b4 d7b8 d7bb d7bc d7be d7c1
d7c4 d7c5 1 d7ca d7cf d7d3 d7d7 d7da
d7db d7dd d7e0 d7e3 d7e4 1 d7e9 d7ee
d7f2 d7f5 d7f9 d7fd d801 d805 d808 d809
d80b d80f d811 d815 d818 d81c d820 d823
d824 d826 d829 d82c d82d d832 d835 d839
d83d d840 d841 d843 d847 d84a d84e d851
d852 d854 d855 d85a 1 d85d d862 d866
d86a d86e d871 d872 d874 d878 d87a d87e
d882 d886 d88a d88d d88e d890 d893 d897
d89b d89e d89f d8a1 d8a2 d8a7 d8a8 d8aa
d8ae d8b0 d8b4 d8b8 d8bb d8bf d8c3 d8c6
d8c7 d8c9 d8cc d8cf d8d0 d8d5 d8d9 d8dd
d8e1 d8e4 d8e5 d8e7 d8ea d8ed d8ee d8f3
d8f7 d8f9 d8fd d901 d905 d909 d90d d910
d911 d913 d914 d916 d919 d91c d91d d922
d923 d925 d929 d92b d92f d933 d936 d93a
d93e d941 d942 d944 d947 d94a d94b d950
d954 d958 d95c d960 d964 d968 d96c d970
d974 d978 d97c d980 d98c d990 d995 d999
d99c d99d d9a2 d9a6 d9aa d9ad d9b0 d9b4
d9b6 d9ba d9be d9c1 d9c4 d9c8 d9ca d9ce
d9d2 d9d5 d9d7 d9db d9df d9e3 d9e6 d9ea
d9ee d9f0 d9f1 d9f6 1 d9fa d9fe da02
da05 da09 da0d da11 da15 da18 da1c da20
da23 da26 da2b da2e da31 da34 da35 da3a
da3b 1 da3d da42 da46 da4a da4d da52
da57 da5a da5e da5f da64 da67 da6c da6d
da72 da75 da7a da7b da80 da83 da87 da88
da8d da90 da95 da96 da9b da9e daa2 daa6
daa9 daac daad daaf dab0 dab5 dab6 dabb
dabd dac1 dac4 dac6 daca dacc dad8 dada
dadc dadd dae2 dae6 dae8 daf4 daf6 daf8
dafc db00 db04 db08 db0c db10 db14 db18
db1c db20 db24 db28 db2c db30 db34 db38
db3c db40 db44 db48 db4c db50 db54 db58
db5c db60 db64 db68 db6c db70 db74 db78
db7c db88 db8c db91 db95 db98 db99 db9e
dba2 dba6 dba9 dbac dbb0 dbb2 dbb6 dbba
dbbd dbc0 dbc4 dbc6 dbca dbce dbd1 dbd3
dbd7 dbdb dbdf dbe2 dbe6 dbea dbec dbed
dbf2 1 dbf6 dbfa dbfe dc01 dc05 dc09
dc0d dc11 dc14 dc18 dc1c dc1f dc22 dc27
dc2a dc2d dc30 dc31 dc36 dc37 1 dc39
dc3e dc42 dc46 dc49 dc4e dc53 dc56 dc5a
dc5b dc60 dc63 dc68 dc69 dc6e dc71 dc76
dc77 dc7c dc7f dc83 dc84 dc89 dc8c dc91
dc92 dc97 dc9a dc9e dca2 dca5 dca8 dca9
dcab dcac dcb1 dcb2 dcb7 dcb9 dcbd dcc0
dcc2 dcc6 dcc8 dcd4 dcd6 dcd8 dcd9 dcde
dce2 dce4 dcf0 dcf2 dcf4 dcf8 dcfc dcff
dd01 dd05 dd09 dd0c dd10 dd13 dd17 dd1b
dd1f dd22 dd23 dd25 dd29 dd2c dd30 dd33
dd34 dd39 dd3d dd40 dd44 dd46 dd4a dd4d
dd51 dd53 dd57 dd5b dd5e dd62 dd66 dd69
dd6a dd6c dd6f dd72 dd73 dd78 dd7c dd80
dd84 dd87 dd8b dd8d dd91 dd95 dd99 dd9c
dda0 dda4 dda7 dda8 ddaa ddae ddb2 ddb5
ddb6 ddb8 ddbc ddbe ddc2 ddc6 ddc9 ddcd
ddd0 ddd4 ddd8 dddc dddf dde0 dde2 dde5
dde8 dde9 ddee ddf2 ddf6 ddf9 ddfa ddfc
ddff de02 de03 de08 de0c de10 de14 de18
de1b de1c de1e de21 de25 de29 de2c de2d
de2f de30 de35 de38 de3b de3e de3f de44
de47 de4a de4d de4e de53 de54 de56 de5a
de5e de62 de65 de66 de68 de6c de6f de73
de76 de77 de79 de7a de7f de83 de87 de8b
de8e de8f de91 de95 de99 de9d dea1 dea5
dea8 dea9 deab deae deb1 deb2 deb7 deba
debd dec1 dec5 dec8 dec9 decb decc ded1
ded4 ded7 ded8 dedd dede dee0 dee4 dee6
deea deed def1 def3 def7 defb defe deff
df01 df05 df08 df0c df0f df10 df12 df13
df18 df1c df20 df24 df27 df28 df2a df2e
df30 df34 df38 df3b df3d df41 df44 df48
df4c df50 df54 df58 df5c df60 df64 df68
df6c df70 df74 df78 df7c df80 df84 df88
df8c df90 df94 df98 df9c dfa0 dfa4 dfa8
dfac dfb0 dfb4 dfb8 dfbc dfbf dfc2 dfc5
dfc8 dfcb dfcc dfce dfd2 dfd6 dfd9 dfdc
dfdd dfe2 dfe6 dfea dfef dff1 dff5 dff9
dffc e000 e004 e006 e00a e00e e012 e015
e019 e01d e01f e020 e025 1 e029 e02d
e031 e034 e038 e03c e040 e044 e047 e04b
e04f e052 e055 e05a e05d e060 e063 e064
e069 e06a 1 e06c e071 e075 e079 e07c
e081 e086 e089 e08d e08e e093 e096 e09b
e09c e0a1 e0a4 e0a9 e0aa e0af e0b2 e0b6
e0b7 e0bc e0bf e0c4 e0c5 e0ca e0cd e0d1
e0d5 e0d8 e0db e0dc e0de e0df e0e4 e0e5
e0ea e0ec e0f0 e0f3 e0f5 e0f9 e0fb e107
e109 e10b e10c e111 e115 e117 e123 e125
e129 e12d e130 e134 e138 e13b e13e e143
e146 e149 e14c e14d e152 e153 1 e155
e15a e15e e162 e165 e16a e16f e172 e176
e177 e17c e17f e184 e185 e18a e18d e192
e193 e198 e19b e19f e1a3 e1a7 e1ab e1ae
e1af e1b1 e1b6 e1b7 e1b9 e1ba e1bf e1c2
e1c7 e1c8 e1cd e1d0 e1d5 e1d6 e1db e1de
e1e2 e1e3 e1e8 e1eb e1f0 e1f1 e1f6 e1f7
e1fc e1fe e202 e205 e209 e20d e210 e214
e218 e21b e21e e223 e226 e229 e22c e22d
e232 e233 1 e235 e23a e23e e242 e245
e24a e24f e252 e256 e257 e25c e25d e262
e264 e268 e26b e26f e273 e276 e27a e27e
e281 e285 e289 e28a e28f e293 e295 e299
e29c e29f e2a0 e2a5 e2a9 e2ad e2b2 e2b4
e2b8 e2bc e2bf e2c3 e2c7 e2c9 e2cd e2d1
e2d5 e2d8 e2dc e2e0 e2e2 e2e3 e2e8 1
e2ec e2f0 e2f4 e2f7 e2fb e2ff e303 e307
e30a e30e e312 e315 e318 e31d e320 e323
e326 e327 e32c e32d 1 e32f e334 e338
e33c e33f e344 e349 e34c e350 e351 e356
e359 e35e e35f e364 e367 e36c e36d e372
e375 e379 e37a e37f e382 e387 e388 e38d
e390 e394 e398 e39b e39e e39f e3a1 e3a2
e3a7 e3a8 e3ad e3af e3b3 e3b6 e3b8 e3bc
e3be e3ca e3cc e3ce e3cf e3d4 e3d8 e3da
e3e6 e3e8 e3ec e3f0 e3f3 e3f7 e3fb e3fe
e401 e406 e409 e40c e40f e410 e415 e416
1 e418 e41d e421 e425 e428 e42d e432
e435 e439 e43a e43f e442 e447 e448 e44d
e450 e455 e456 e45b e45e e462 e466 e46a
e46e e471 e472 e474 e479 e47a e47c e47d
e482 e485 e48a e48b e490 e493 e498 e499
e49e e4a1 e4a5 e4a6 e4ab e4ae e4b3 e4b4
e4b9 e4ba e4bf e4c1 e4c5 e4c8 e4cc e4d0
e4d3 e4d7 e4db e4de e4e1 e4e6 e4e9 e4ec
e4ef e4f0 e4f5 e4f6 1 e4f8 e4fd e501
e505 e508 e50d e512 e515 e519 e51a e51f
e520 e525 e527 e52b e52e e532 e536 e539
e53d e541 e544 e548 e54c e54d e552 e554
e558 e55c e55f e561 e565 e569 e56c e570
e574 e578 e57c e580 e584 e588 e594 e598
e59d e5a1 e5a4 e5a5 e5aa e5ae e5b2 e5b5
e5b8 e5bc e5be e5c2 e5c6 e5c9 e5cc e5d0
e5d2 e5d6 e5da e5dd e5df e5e3 e5e7 e5eb
e5ee e5f2 e5f6 e5f8 e5f9 e5fe 1 e602
e606 e60a e60d e611 e615 e619 e61d e620
e624 e628 e62b e62e e633 e636 e639 e63c
e63d e642 e643 1 e645 e64a e64e e652
e655 e65a e65f e662 e666 e667 e66c e66f
e674 e675 e67a e67d e682 e683 e688 e68b
e68f e690 e695 e698 e69d e69e e6a3 e6a6
e6aa e6ae e6b1 e6b4 e6b5 e6b7 e6b8 e6bd
e6be e6c3 e6c5 e6c9 e6cc e6ce e6d2 e6d4
e6e0 e6e2 e6e4 e6e5 e6ea e6ee e6f0 e6fc
e6fe e702 e706 e70a e70e e712 e716 e71a
e71e e722 e726 e72a e72e e732 e736 e73a
e73e e742 e746 e74a e74e e752 e756 e75a
e75e e76a e76e e773 e777 e77a e77b e780
e784 e788 e78b e78e e792 e794 e798 e79c
e79f e7a2 e7a6 e7a8 e7ac e7b0 e7b3 e7b5
e7b9 e7bd e7c1 e7c4 e7c8 e7cc e7ce e7cf
e7d4 1 e7d8 e7dc e7e0 e7e3 e7e7 e7eb
e7ef e7f3 e7f6 e7fa e7fe e801 e804 e809
e80c e80f e812 e813 e818 e819 1 e81b
e820 e824 e828 e82b e830 e835 e838 e83c
e83d e842 e845 e84a e84b e850 e853 e858
e859 e85e e861 e865 e866 e86b e86e e873
e874 e879 e87c e880 e884 e887 e88a e88b
e88d e88e e893 e894 e899 e89b e89f e8a2
e8a4 e8a8 e8aa e8b6 e8b8 e8ba e8bb e8c0
e8c4 e8c6 e8d2 e8d4 e8d8 e8dc e8e0 e8e4
e8e8 e8ec e8f0 e8f4 e8f8 e8fc e900 e90c
e910 e915 e919 e91c e91d e922 e926 e92a
e92d e930 e934 e936 e93a e93e e941 e944
e948 e94a e94e e952 e955 e957 e95b e95f
e963 e966 e96a e96e e970 e971 e976 1
e97a e97e e982 e985 e989 e98d e991 e995
e998 e99c e9a0 e9a3 e9a6 e9ab e9ae e9b1
e9b4 e9b5 e9ba e9bb 1 e9bd e9c2 e9c6
e9ca e9cd e9d2 e9d7 e9da e9de e9df e9e4
e9e7 e9ec e9ed e9f2 e9f5 e9fa e9fb ea00
ea03 ea07 ea08 ea0d ea10 ea15 ea16 ea1b
ea1e ea22 ea26 ea29 ea2c ea2d ea2f ea30
ea35 ea36 ea3b ea3d ea41 ea44 ea46 ea4a
ea4c ea58 ea5a ea5c ea5d ea62 ea66 ea68
ea74 ea76 ea7a ea7e ea82 ea86 ea8a ea8e
ea92 ea96 ea9a ea9e eaa2 eaae eab2 eab7
eabb eabe eabf eac4 eac8 eacc eacf ead2
ead6 ead8 eadc eae0 eae3 eae6 eaea eaec
eaf0 eaf4 eaf7 eaf9 eafd eb01 eb05 eb08
eb0c eb10 eb12 eb13 eb18 1 eb1c eb20
eb24 eb27 eb2b eb2f eb33 eb37 eb3a eb3e
eb42 eb45 eb48 eb4d eb50 eb53 eb56 eb57
eb5c eb5d 1 eb5f eb64 eb68 eb6c eb6f
eb74 eb79 eb7c eb80 eb81 eb86 eb89 eb8e
eb8f eb94 eb97 eb9c eb9d eba2 eba5 eba9
ebaa ebaf ebb2 ebb7 ebb8 ebbd ebc0 ebc4
ebc8 ebcb ebce ebcf ebd1 ebd2 ebd7 ebd8
ebdd ebdf ebe3 ebe6 ebe8 ebec ebee ebfa
ebfc ebfe ebff ec04 ec08 ec0a ec16 ec18
ec1c ec20 ec24 ec27 ec28 ec2a ec2d ec30
ec31 ec36 ec3a ec3e ec42 ec46 ec49 ec4a
ec4c ec4f ec53 ec57 ec5a ec5b ec5d ec5e
ec63 ec67 ec6b ec70 ec74 ec78 ec7c ec80
ec84 ec88 ec89 ec8b ec8f ec93 ec98 ec9c
eca0 eca4 eca8 ecac ecb0 ecb1 ecb3 ecb7
ecbb ecbf ecc3 ecc7 eccb eccf ecd3 ecdf
ece3 ece8 ecec ecef ecf0 ecf5 ecf9 ecfd
ed00 ed03 ed07 ed09 ed0d ed11 ed14 ed17
ed1b ed1d ed21 ed25 ed28 ed2a ed2e ed32
ed36 ed39 ed3d ed41 ed43 ed44 ed49 1
ed4d ed51 ed55 ed58 ed5c ed60 ed64 ed68
ed6b ed6f ed73 ed76 ed79 ed7e ed81 ed84
ed87 ed88 ed8d ed8e 1 ed90 ed95 ed99
ed9d eda0 eda5 edaa edad edb1 edb2 edb7
edba edbf edc0 edc5 edc8 edcd edce edd3
edd6 edda eddb ede0 ede3 ede8 ede9 edee
edf1 edf5 edf9 edfc edff ee00 ee02 ee03
ee08 ee09 ee0e ee10 ee14 ee17 ee19 ee1d
ee1f ee2b ee2d ee2f ee30 ee35 ee39 ee3b
ee47 ee49 ee4d ee51 ee54 ee55 ee57 ee5a
ee5d ee5e ee63 ee66 ee6a ee6e ee71 ee72
ee74 ee77 ee7a ee7b ee80 1 ee83 ee88
ee8c ee90 ee94 ee98 ee9c eea0 eea4 eea8
eeac eeb0 eeb4 eeb8 eebc eec0 eec4 eec8
eecc eed8 eedc eee1 eee5 eee8 eee9 eeee
eef2 eef6 eef9 eefc ef00 ef02 ef06 ef0a
ef0d ef10 ef14 ef16 ef1a ef1e ef21 ef23
ef27 ef2b ef2f ef32 ef36 ef3a ef3c ef3d
ef42 1 ef46 ef4a ef4e ef51 ef55 ef59
ef5d ef61 ef64 ef68 ef6c ef6f ef72 ef77
ef7a ef7d ef80 ef81 ef86 ef87 1 ef89
ef8e ef92 ef96 ef99 ef9e efa3 efa6 efaa
efab efb0 efb3 efb8 efb9 efbe efc1 efc6
efc7 efcc efcf efd3 efd4 efd9 efdc efe1
efe2 efe7 efea efee eff2 eff5 eff8 eff9
effb effc f001 f002 f007 f009 f00d f010
f012 f016 f018 f024 f026 f028 f029 f02e
f032 f034 f040 f042 f046 f048 f04c f050
f053 f054 f056 f059 f05c f05d f062 f066
f06a f06e f072 f076 f07a f07e f082 f086
f08a f08e f092 f096 f0a2 f0a6 f0ab f0af
f0b2 f0b3 f0b8 f0bc f0c0 f0c3 f0c6 f0ca
f0cc f0d0 f0d4 f0d7 f0da f0de f0e0 f0e4
f0e8 f0eb f0ed f0f1 f0f5 f0f9 f0fc f100
f104 f106 f107 f10c 1 f110 f114 f118
f11b f11f f123 f127 f12b f12e f132 f136
f139 f13c f141 f144 f147 f14a f14b f150
f151 1 f153 f158 f15c f160 f163 f168
f16d f170 f174 f175 f17a f17d f182 f183
f188 f18b f190 f191 f196 f199 f19d f19e
f1a3 f1a6 f1ab f1ac f1b1 f1b4 f1b8 f1bc
f1bf f1c2 f1c3 f1c5 f1c6 f1cb f1cc f1d1
f1d3 f1d7 f1da f1dc f1e0 f1e2 f1ee f1f0
f1f2 f1f3 f1f8 f1fc f1fe f20a f20c f210
f214 f218 f21b f21c f21e f222 f226 f228
f22c f230 f234 f237 f238 f23a f23d f240
f241 f246 f24a f24e f252 f256 f25a f25e
f262 f266 f26a f26e f272 f276 f27a f286
f28a f28f f293 f296 f297 f29c f2a0 f2a4
f2a7 f2aa f2ae f2b0 f2b4 f2b8 f2bb f2be
f2c2 f2c4 f2c8 f2cc f2cf f2d1 f2d5 f2d9
f2dd f2e0 f2e4 f2e8 f2ea f2eb f2f0 1
f2f4 f2f8 f2fc f2ff f303 f307 f30b f30f
f312 f316 f31a f31d f320 f325 f328 f32b
f32e f32f f334 f335 1 f337 f33c f340
f344 f347 f34c f351 f354 f358 f359 f35e
f361 f366 f367 f36c f36f f374 f375 f37a
f37d f381 f382 f387 f38a f38f f390 f395
f398 f39c f3a0 f3a3 f3a6 f3a7 f3a9 f3aa
f3af f3b0 f3b5 f3b7 f3bb f3be f3c0 f3c4
f3c6 f3d2 f3d4 f3d6 f3d7 f3dc f3e0 f3e2
f3ee f3f0 f3f4 f3f8 f3fc f3ff f400 f402
f406 f408 f40c f410 f414 f418 f41c f420
f424 f428 f42c f430 f43c f440 f445 f449
f44c f44d f452 f456 f45a f45d f460 f464
f466 f46a f46e f471 f474 f478 f47a f47e
f482 f485 f487 f48b f48f f493 f496 f49a
f49e f4a0 f4a1 f4a6 1 f4aa f4ae f4b2
f4b5 f4b9 f4bd f4c1 f4c5 f4c8 f4cc f4d0
f4d3 f4d6 f4db f4de f4e1 f4e4 f4e5 f4ea
f4eb 1 f4ed f4f2 f4f6 f4fa f4fd f502
f507 f50a f50e f50f f514 f517 f51c f51d
f522 f525 f52a f52b f530 f533 f537 f538
f53d f540 f545 f546 f54b f54e f552 f556
f559 f55c f55d f55f f560 f565 f566 f56b
f56d f571 f574 f576 f57a f57c f588 f58a
f58c f58d f592 f596 f598 f5a4 f5a6 f5aa
f5ae f5b2 f5b5 f5b6 f5b8 f5bc f5c0 f5c4
f5c8 f5cb f5cc f5ce f5d2 f5d4 f5d8 f5dc
f5df f5e1 f5e5 f5e8 f5ea f5ee f5f2 f5f5
f5f9 f5fd f600 f604 f608 f60c f610 f611
f613 f617 f61f f621 f622 f625 f627 f62b
f632 f636 f63a f63f f641 f645 f649 f64c
f650 f654 f656 f65a f65e f662 f665 f669
f66d f66f f670 f675 1 f679 f67d f681
f684 f688 f68c f690 f694 f697 f69b f69f
f6a2 f6a5 f6aa f6ad f6b0 f6b3 f6b4 f6b9
f6ba 1 f6bc f6c1 f6c5 f6c9 f6cc f6d1
f6d6 f6d9 f6dd f6de f6e3 f6e6 f6eb f6ec
f6f1 f6f4 f6f9 f6fa f6ff f702 f706 f707
f70c f70f f714 f715 f71a f71d f721 f725
f728 f72b f72c f72e f72f f734 f735 f73a
f73c f740 f743 f745 f749 f74b f757 f759
f75b f75c f761 f765 f767 f773 f775 f779
f77c f780 f784 f788 f78b f78c f78e f791
f794 f795 f79a f79e f7a2 f7a6 f7aa f7ae
f7b1 f7b2 f7b4 f7b8 f7bb f7bf f7c2 f7c3
f7c5 f7c6 f7cb f7cf f7d3 f7d7 f7da f7db
f7dd f7e0 f7e4 f7e8 f7eb f7ec f7ee f7ef
f7f4 f7f8 f7fc f800 f803 f804 f806 f809
f80c f80d f812 f815 f819 f81d f820 f821
f823 f826 f829 f82a f82f 1 f832 f837
f83b f83e f83f f844 f847 1 f84a f84f
f853 f857 f85b f85f f863 f867 f86b f86f
f873 f877 f87b f87f f883 f887 f88b f88f
f893 f897 f89b f89f f8a3 f8a7 f8ab f8af
f8b3 f8b7 f8ba f8bb f8bd f8c0 f8c3 f8c4
f8c9 f8cc f8d0 f8d4 f8d7 f8d8 f8da f8dd
f8e0 f8e1 f8e6 1 f8e9 f8ee f8f2 f8f5
f8f9 f8fd f8ff f903 f907 f90a f90b f90d
f910 f913 f914 f919 f91d f921 f925 f928
f929 f92b f92f f931 f935 f939 f93c f940
f944 f948 f94c f950 f954 f957 f958 f95a
f95e f962 f965 f966 f968 f96c f970 f973
f974 f976 f97a f97e f981 f982 f984 f988
f98c f98f f990 f992 f996 f99a f99d f99e
f9a0 f9a4 f9a8 f9ab f9ac f9ae f9b2 f9b6
f9b9 f9ba f9bc f9c0 f9c4 f9c8 f9c9 f9cb
f9cf f9d3 f9d7 f9da f9db f9dd f9e1 f9e4
f9e8 f9eb f9ec f9f1 f9f5 f9f9 f9fc fa00
fa04 fa07 fa0a fa0f fa12 fa15 fa18 fa19
fa1e fa1f 1 fa21 fa26 fa2a fa2e fa31
fa36 fa3b fa3e fa42 fa43 fa48 fa4b fa50
fa51 fa56 fa59 fa5e fa5f fa64 fa67 fa6b
fa6f fa73 fa77 fa7a fa7b fa7d fa82 fa83
fa85 fa86 fa8b fa8c fa91 fa93 fa97 fa9a
fa9e faa2 faa5 faa9 faad fab0 fab3 fab8
fabb fabe fac1 fac2 fac7 fac8 1 faca
facf fad3 fad7 fada fadf fae4 fae7 faeb
faec faf1 faf2 faf7 faf9 fafd fb00 fb04
fb08 fb0b fb0f fb13 fb16 fb1a fb1b fb20
fb24 fb26 fb2a fb2e fb31 fb32 fb34 fb37
fb3a fb3b fb40 fb44 fb48 fb4b fb4f fb53
fb56 fb59 fb5e fb61 fb64 fb67 fb68 fb6d
fb6e 1 fb70 fb75 fb79 fb7d fb80 fb85
fb8a fb8d fb91 fb92 fb97 fb9a fb9f fba0
fba5 fba8 fbad fbae fbb3 fbb6 fbba fbbe
fbc2 fbc3 fbc5 fbca fbcb fbcd fbce fbd3
fbd6 fbdb fbdc fbe1 fbe4 fbe9 fbea fbef
fbf2 fbf6 fbf7 fbfc fbff fc04 fc05 fc0a
fc0b fc10 fc12 fc16 fc19 fc1d fc21 fc24
fc28 fc2c fc2f fc32 fc37 fc3a fc3d fc40
fc41 fc46 fc47 1 fc49 fc4e fc52 fc56
fc59 fc5e fc63 fc66 fc6a fc6b fc70 fc71
fc76 fc78 fc7c fc7f fc83 fc87 fc8a fc8e
fc92 fc95 fc96 fc98 fc9c fca0 fca1 fca6
fca8 fcac fcb0 fcb3 fcb7 fcbb fcc0 fcc5
fcc9 fccd fcd1 fcd4 fcd7 fcdb fcdf fce3
fce7 fceb fcef fcf3 fcf7 fcfb fcff fd03
fd0f fd13 fd18 fd1c fd1f fd20 fd25 fd29
fd2d fd30 fd33 fd37 fd39 fd3d fd41 fd44
fd47 fd4b fd4d fd51 fd55 fd58 fd5a fd5e
fd62 fd66 fd69 fd6d fd71 fd73 fd74 fd79
1 fd7d fd81 fd85 fd88 fd8c fd90 fd94
fd98 fd9b fd9f fda3 fda6 fda9 fdae fdb1
fdb4 fdb7 fdb8 fdbd fdbe 1 fdc0 fdc5
fdc9 fdcd fdd0 fdd5 fdda fddd fde1 fde2
fde7 fdea fdef fdf0 fdf5 fdf8 fdfd fdfe
fe03 fe06 fe0a fe0b fe10 fe13 fe18 fe19
fe1e fe21 fe25 fe29 fe2c fe2f fe30 fe32
fe33 fe38 fe39 fe3e fe40 fe44 fe47 fe49
fe4d fe4f fe5b fe5d fe5f fe60 fe65 fe69
fe6b fe77 fe79 fe7d fe82 fe86 fe8a fe8d
fe91 fe95 fe98 fe9c fea0 fea3 fea7 feab
feae feb2 feb6 feba febd febe fec0 fec3
fec6 fec7 fecc fed0 fed4 fed8 fedb fedf
fee3 fee6 fee7 fee9 feed fef1 fef4 fef5
fef7 fefb feff ff02 ff06 ff08 ff0c ff0f
ff13 ff15 ff19 ff1d ff20 ff24 ff27 ff2b
ff2f ff33 ff37 ff3b ff3f ff43 ff47 ff4b
ff4f ff53 ff57 ff5b ff5f ff63 ff67 ff6b
ff6f ff73 ff77 ff7b ff7f ff83 ff87 ff8b
ff8f ff93 ff97 ff9b ff9f ffa3 ffa6 ffa9
ffac ffaf ffb2 ffb3 ffb5 ffb9 ffbd ffc0
ffc3 ffc4 ffc9 ffcd ffd1 ffd4 ffd8 ffdc
ffdf ffe2 ffe7 ffea ffed fff0 fff1 fff6
fff7 1 fff9 fffe 10002 10006 10009 1000e
10013 10016 1001a 1001b 10020 10023 10028 10029
1002e 10031 10036 10037 1003c 1003f 10043 10047
1004b 1004f 10052 10053 10055 1005a 1005b 1005d
1005e 10063 10066 1006b 1006c 10071 10074 10079
1007a 1007f 10082 10086 10087 1008c 1008f 10094
10095 1009a 1009b 100a0 100a2 100a6 100a9 100ad
100b1 100b4 100b8 100bc 100bf 100c2 100c7 100ca
100cd 100d0 100d1 100d6 100d7 1 100d9 100de
100e2 100e6 100e9 100ee 100f3 100f6 100fa 100fb
10100 10101 10106 10108 1010c 1010f 10113 10117
1011a 1011e 10122 10125 10129 1012d 1012e 10133
10137 10139 1013d 10140 10143 10144 10149 1014d
10151 10154 10158 1015c 1015f 10162 10167 1016a
1016d 10170 10171 10176 10177 1 10179 1017e
10182 10186 10189 1018e 10193 10196 1019a 1019b
101a0 101a3 101a8 101a9 101ae 101b1 101b6 101b7
101bc 101bf 101c3 101c7 101cb 101cf 101d2 101d3
101d5 101da 101db 101dd 101de 101e3 101e6 101eb
101ec 101f1 101f4 101f9 101fa 101ff 10202 10206
10207 1020c 1020f 10214 10215 1021a 1021b 10220
10222 10226 10229 1022d 10231 10234 10238 1023c
1023f 10242 10247 1024a 1024d 10250 10251 10256
10257 1 10259 1025e 10262 10266 10269 1026e
10273 10276 1027a 1027b 10280 10281 10286 10288
1028c 1028f 10293 10297 1029a 1029e 102a2 102a5
102a9 102ad 102ae 102b3 102b5 102b9 102bd 102c1
102c5 102c9 102cd 102d1 102d5 102d9 102dd 102e1
102e5 102e9 102ed 102f1 102f5 102f9 102fd 10301
10305 10309 1030d 10311 10315 10319 1031d 10321
10325 10329 10335 10339 1033e 10342 10345 10346
1034b 1034f 10353 10356 10359 1035d 1035f 10363
10367 1036a 1036d 10371 10373 10377 1037b 1037e
10380 10384 10388 1038c 1038f 10393 10397 10399
1039a 1039f 1 103a3 103a7 103ab 103ae 103b2
103b6 103ba 103be 103c1 103c5 103c9 103cc 103cf
103d4 103d7 103da 103dd 103de 103e3 103e4 1
103e6 103eb 103ef 103f3 103f6 103fb 10400 10403
10407 10408 1040d 10410 10415 10416 1041b 1041e
10423 10424 10429 1042c 10430 10431 10436 10439
1043e 1043f 10444 10447 1044b 1044f 10452 10455
10456 10458 10459 1045e 1045f 10464 10466 1046a
1046d 1046f 10473 10475 10481 10483 10485 10486
1048b 1048f 10491 1049d 1049f 104a1 104a5 104a9
104ac 104ae 104b2 104b5 104b9 104bb 104bf 104c2
104c5 104c6 104cb 104cf 104d3 104d6 104d7 104d9
104dc 104df 104e0 1 104e5 104ea 104ee 104f1
104f2 104f7 1 104fa 104ff 10503 10507 1050b
1050f 10513 10517 1051b 10527 1052b 10530 10534
10537 10538 1053d 10541 10545 10548 1054b 1054f
10551 10555 10559 1055c 1055f 10563 10565 10569
1056d 10570 10572 10576 1057a 1057e 10581 10585
10589 1058b 1058c 10591 1 10595 10599 1059d
105a0 105a4 105a8 105ac 105b0 105b3 105b7 105bb
105be 105c1 105c6 105c9 105cc 105cf 105d0 105d5
105d6 1 105d8 105dd 105e1 105e5 105e8 105ed
105f2 105f5 105f9 105fa 105ff 10602 10607 10608
1060d 10610 10615 10616 1061b 1061e 10622 10623
10628 1062b 10630 10631 10636 10639 1063d 10641
10644 10647 10648 1064a 1064b 10650 10651 10656
10658 1065c 1065f 10661 10665 10667 10673 10675
10677 10678 1067d 10681 10683 1068f 10691 10693
10697 1069b 1069e 106a2 106a6 106aa 106ae 106b2
106b6 106ba 106be 106ca 106ce 106d2 106d5 106d9
106dd 106df 106e3 106e7 106eb 106ee 106f2 106f6
106f8 106f9 106fe 1 10702 10706 1070a 1070d
10711 10715 10719 1071d 10720 10724 10728 1072b
1072e 10733 10736 10739 1073c 1073d 10742 10743
1 10745 1074a 1074e 10752 10755 1075a 1075f
10762 10766 10767 1076c 1076f 10774 10775 1077a
1077d 10782 10783 10788 1078b 1078f 10790 10795
10798 1079d 1079e 107a3 107a6 107aa 107ae 107b1
107b4 107b5 107b7 107b8 107bd 107be 107c3 107c5
107c9 107cc 107ce 107d2 107d4 107e0 107e2 107e4
107e5 107ea 107ee 107f0 107fc 107fe 10802 10806
10809 1080a 1080c 1080f 10812 10813 10818 1081c
10820 10824 10828 1082c 10830 10834 10838 1083c
10848 1084c 10851 10855 10858 10859 1085e 10862
10866 10869 1086c 10870 10872 10876 1087a 1087d
10880 10884 10886 1088a 1088e 10891 10893 10897
1089b 1089f 108a2 108a6 108aa 108ac 108ad 108b2
1 108b6 108ba 108be 108c1 108c5 108c9 108cd
108d1 108d4 108d8 108dc 108df 108e2 108e7 108ea
108ed 108f0 108f1 108f6 108f7 1 108f9 108fe
10902 10906 10909 1090e 10913 10916 1091a 1091b
10920 10923 10928 10929 1092e 10931 10936 10937
1093c 1093f 10943 10944 10949 1094c 10951 10952
10957 1095a 1095e 10962 10965 10968 10969 1096b
1096c 10971 10972 10977 10979 1097d 10980 10982
10986 10988 10994 10996 10998 10999 1099e 109a2
109a4 109b0 109b2 109b4 109b8 109bb 109bd 109c1
109c4 109c8 109cb 109cf 109d3 109d6 109d7 109dc
109df 109e3 109e7 109eb 109ef 109f3 109f7 109fb
109ff 10a03 10a0f 10a13 10a18 10a1c 10a1f 10a20
10a25 10a29 10a2d 10a30 10a33 10a37 10a39 10a3d
10a41 10a44 10a47 10a4b 10a4d 10a51 10a55 10a58
10a5a 10a5e 10a62 10a66 10a69 10a6d 10a71 10a73
10a74 10a79 1 10a7d 10a81 10a85 10a88 10a8c
10a90 10a94 10a98 10a9b 10a9f 10aa3 10aa6 10aa9
10aae 10ab1 10ab4 10ab7 10ab8 10abd 10abe 1
10ac0 10ac5 10ac9 10acd 10ad0 10ad5 10ada 10add
10ae1 10ae2 10ae7 10aea 10aef 10af0 10af5 10af8
10afd 10afe 10b03 10b06 10b0a 10b0b 10b10 10b13
10b18 10b19 10b1e 10b21 10b25 10b29 10b2c 10b2f
10b30 10b32 10b33 10b38 10b39 10b3e 10b40 10b44
10b47 10b49 10b4d 10b4f 10b5b 10b5d 10b5f 10b60
10b65 10b69 10b6b 10b77 10b79 10b7d 10b81 10b84
10b85 10b87 10b8a 10b8d 10b8e 10b93 10b97 10b9b
10b9f 10ba3 10ba7 10bab 10baf 10bbb 10bbf 10bc3
10bc6 10bca 10bce 10bd0 10bd4 10bd8 10bdc 10bdf
10be3 10be7 10be9 10bea 10bef 1 10bf3 10bf7
10bfb 10bfe 10c02 10c06 10c0a 10c0e 10c11 10c15
10c19 10c1c 10c1f 10c24 10c27 10c2a 10c2d 10c2e
10c33 10c34 1 10c36 10c3b 10c3f 10c43 10c46
10c4b 10c50 10c53 10c57 10c58 10c5d 10c60 10c65
10c66 10c6b 10c6e 10c73 10c74 10c79 10c7c 10c80
10c81 10c86 10c89 10c8e 10c8f 10c94 10c97 10c9b
10c9f 10ca2 10ca5 10ca6 10ca8 10ca9 10cae 10caf
10cb4 10cb6 10cba 10cbd 10cbf 10cc3 10cc5 10cd1
10cd3 10cd5 10cd6 10cdb 10cdf 10ce1 10ced 10cef
10cf3 10cf7 10cfa 10cfb 10cfd 10d00 10d03 10d04
10d09 10d0d 10d11 10d15 10d19 10d1d 10d21 10d25
10d29 10d35 10d39 10d3e 10d42 10d45 10d46 10d4b
10d4f 10d53 10d56 10d59 10d5d 10d5f 10d63 10d67
10d6a 10d6d 10d71 10d73 10d77 10d7b 10d7e 10d80
10d84 10d88 10d8c 10d8f 10d93 10d97 10d99 10d9a
10d9f 1 10da3 10da7 10dab 10dae 10db2 10db6
10dba 10dbe 10dc1 10dc5 10dc9 10dcc 10dcf 10dd4
10dd7 10dda 10ddd 10dde 10de3 10de4 1 10de6
10deb 10def 10df3 10df6 10dfb 10e00 10e03 10e07
10e08 10e0d 10e10 10e15 10e16 10e1b 10e1e 10e23
10e24 10e29 10e2c 10e30 10e31 10e36 10e39 10e3e
10e3f 10e44 10e47 10e4b 10e4f 10e52 10e55 10e56
10e58 10e59 10e5e 10e5f 10e64 10e66 10e6a 10e6d
10e6f 10e73 10e75 10e81 10e83 10e85 10e86 10e8b
10e8f 10e91 10e9d 10e9f 10ea3 10ea7 10eab 10eaf
10eb3 10ebf 10ec3 10ec8 10ecc 10ecf 10ed0 10ed5
10ed9 10edd 10ee0 10ee3 10ee7 10ee9 10eed 10ef1
10ef4 10ef7 10efb 10efd 10f01 10f05 10f08 10f0a
10f0e 10f12 10f16 10f19 10f1d 10f21 10f23 10f24
10f29 1 10f2d 10f31 10f35 10f38 10f3c 10f40
10f44 10f48 10f4b 10f4f 10f53 10f56 10f59 10f5e
10f61 10f64 10f67 10f68 10f6d 10f6e 1 10f70
10f75 10f79 10f7d 10f80 10f85 10f8a 10f8d 10f91
10f92 10f97 10f9a 10f9f 10fa0 10fa5 10fa8 10fad
10fae 10fb3 10fb6 10fba 10fbb 10fc0 10fc3 10fc8
10fc9 10fce 10fd1 10fd5 10fd9 10fdc 10fdf 10fe0
10fe2 10fe3 10fe8 10fe9 10fee 10ff0 10ff4 10ff7
10ff9 10ffd 10fff 1100b 1100d 1100f 11010 11015
11019 1101b 11027 11029 1102b 1102f 11032 11034
11038 1103b 1103f 11043 11046 11047 11049 1104c
1104f 11050 11055 11059 1105c 11060 11064 11068
1106c 11070 11074 11077 1107a 1107b 1107d 11081
11085 11089 1108d 11091 11095 11099 1109d 110a1
110a5 110a9 110ad 110b1 110b5 110b9 110bd 110c1
110c5 110c9 110cd 110d1 110d5 110d9 110dd 110e1
110e5 110f1 110f5 110f9 110fc 11100 11104 11106
1110a 1110e 11112 11115 11119 1111d 1111f 11120
11125 1 11129 1112d 11131 11134 11138 1113c
11140 11144 11147 1114b 1114f 11152 11155 1115a
1115d 11160 11163 11164 11169 1116a 1 1116c
11171 11175 11179 1117c 11181 11186 11189 1118d
1118e 11193 11196 1119b 1119c 111a1 111a4 111a9
111aa 111af 111b2 111b6 111b7 111bc 111bf 111c4
111c5 111ca 111cd 111d1 111d5 111d8 111db 111dc
111de 111df 111e4 111e5 111ea 111ec 111f0 111f3
111f5 111f9 111fb 11207 11209 1120b 1120c 11211
11215 11217 11223 11225 11229 1122d 11230 11234
11237 1123b 1123e 1123f 11244 11247 1124b 1124f
11252 11253 11255 11258 1125b 1125c 11261 11265
11269 1126d 11271 11275 11279 1127d 11281 11285
11289 1128d 11291 11295 11299 1129d 112a9 112ad
112b2 112b6 112b9 112ba 112bf 112c3 112c7 112ca
112cd 112d1 112d3 112d7 112db 112de 112e1 112e5
112e7 112eb 112ef 112f2 112f4 112f8 112fc 11300
11303 11307 1130b 1130d 1130e 11313 1 11317
1131b 1131f 11322 11326 1132a 1132e 11332 11335
11339 1133d 11340 11343 11348 1134b 1134e 11351
11352 11357 11358 1 1135a 1135f 11363 11367
1136a 1136f 11374 11377 1137b 1137c 11381 11384
11389 1138a 1138f 11392 11397 11398 1139d 113a0
113a4 113a5 113aa 113ad 113b2 113b3 113b8 113bb
113bf 113c3 113c6 113c9 113ca 113cc 113cd 113d2
113d3 113d8 113da 113de 113e1 113e3 113e7 113e9
113f5 113f7 113f9 113fa 113ff 11403 11405 11411
11413 11415 11419 1141d 11421 11425 11429 1142d
11431 11435 11439 1143d 11441 11445 11449 1144d
11451 11455 11459 11465 11469 1146e 11472 11475
11476 1147b 1147f 11483 11486 11489 1148d 1148f
11493 11497 1149a 1149d 114a1 114a3 114a7 114ab
114ae 114b0 114b4 114b8 114bc 114bf 114c3 114c7
114c9 114ca 114cf 1 114d3 114d7 114db 114de
114e2 114e6 114ea 114ee 114f1 114f5 114f9 114fc
114ff 11504 11507 1150a 1150d 1150e 11513 11514
1 11516 1151b 1151f 11523 11526 1152b 11530
11533 11537 11538 1153d 11540 11545 11546 1154b
1154e 11553 11554 11559 1155c 11560 11561 11566
11569 1156e 1156f 11574 11577 1157b 1157f 11582
11585 11586 11588 11589 1158e 1158f 11594 11596
1159a 1159d 1159f 115a3 115a5 115b1 115b3 115b5
115b6 115bb 115bf 115c1 115cd 115cf 115d1 115d5
115d9 115dc 115e0 115e4 115e7 115ea 115eb 115ed
115f0 115f5 115f6 115fb 115fe 11602 11605 11609
1160d 11611 11614 11618 1161c 11620 11624 11628
1162c 11630 11634 11638 1163c 11640 11641 11643
11647 11649 1164d 11650 11652 11656 11659 1165d
11660 11661 11666 11669 1166c 11670 11674 11677
1167b 1167f 11680 11682 11685 11688 11689 1168e
1 11691 11696 1169a 1169d 116a1 116a3 116a7
116aa 116ac 116b0 116b3 116b5 116b9 116bc 116c0
116c3 116c4 116c9 116cc 116d0 116d3 116d7 116db
116df 116e3 116e7 116eb 116ee 116f1 116f2 116f4
116f8 116fc 11700 11704 11708 1170c 11710 11714
11718 1171c 11720 11724 11728 1172c 11730 11734
11738 1173c 11740 11744 11748 1174c 11750 11754
11758 1175c 11768 1176c 11770 11773 11777 1177b
1177d 11781 11785 11789 1178c 11790 11794 11796
11797 1179c 1 117a0 117a4 117a8 117ab 117af
117b3 117b7 117bb 117be 117c2 117c6 117c9 117cc
117d1 117d4 117d7 117da 117db 117e0 117e1 1
117e3 117e8 117ec 117f0 117f3 117f8 117fd 11800
11804 11805 1180a 1180d 11812 11813 11818 1181b
11820 11821 11826 11829 1182d 1182e 11833 11836
1183b 1183c 11841 11844 11848 1184c 1184f 11852
11853 11855 11856 1185b 1185c 11861 11863 11867
1186a 1186c 11870 11872 1187e 11880 11882 11883
11888 1188c 1188e 1189a 1189c 118a0 118a4 118a7
118a8 118aa 118ad 118b0 118b1 118b6 118ba 118be
118c2 118c6 118ca 118ce 118d2 118d6 118da 118de
118e2 118e6 118ea 118ee 118f2 118fe 11902 11907
1190b 1190e 1190f 11914 11918 1191c 1191f 11922
11926 11928 1192c 11930 11933 11936 1193a 1193c
11940 11944 11947 11949 1194d 11951 11955 11958
1195c 11960 11962 11963 11968 1 1196c 11970
11974 11977 1197b 1197f 11983 11987 1198a 1198e
11992 11995 11998 1199d 119a0 119a3 119a6 119a7
119ac 119ad 1 119af 119b4 119b8 119bc 119bf
119c4 119c9 119cc 119d0 119d1 119d6 119d9 119de
119df 119e4 119e7 119ec 119ed 119f2 119f5 119f9
119fa 119ff 11a02 11a07 11a08 11a0d 11a10 11a14
11a18 11a1b 11a1e 11a1f 11a21 11a22 11a27 11a28
11a2d 11a2f 11a33 11a36 11a38 11a3c 11a3e 11a4a
11a4c 11a4e 11a4f 11a54 11a58 11a5a 11a66 11a68
11a6a 11a6e 11a72 11a76 11a7a 11a7e 11a82 11a86
11a8a 11a8e 11a92 11a96 11a9a 11a9e 11aa2 11aa6
11aaa 11aae 11aba 11abe 11ac3 11ac7 11aca 11acb
11ad0 11ad4 11ad8 11adb 11ade 11ae2 11ae4 11ae8
11aec 11aef 11af2 11af6 11af8 11afc 11b00 11b03
11b05 11b09 11b0d 11b11 11b14 11b18 11b1c 11b1e
11b1f 11b24 1 11b28 11b2c 11b30 11b33 11b37
11b3b 11b3f 11b43 11b46 11b4a 11b4e 11b51 11b54
11b59 11b5c 11b5f 11b62 11b63 11b68 11b69 1
11b6b 11b70 11b74 11b78 11b7b 11b80 11b85 11b88
11b8c 11b8d 11b92 11b95 11b9a 11b9b 11ba0 11ba3
11ba8 11ba9 11bae 11bb1 11bb5 11bb6 11bbb 11bbe
11bc3 11bc4 11bc9 11bcc 11bd0 11bd4 11bd7 11bda
11bdb 11bdd 11bde 11be3 11be4 11be9 11beb 11bef
11bf2 11bf4 11bf8 11bfa 11c06 11c08 11c0a 11c0b
11c10 11c14 11c16 11c22 11c24 11c26 11c2a 11c2e
11c31 11c35 11c39 11c3c 11c3f 11c40 11c42 11c45
11c4a 11c4b 11c50 11c53 11c57 11c5b 11c5e 11c5f
11c61 11c64 11c67 11c68 11c6d 1 11c70 11c75
11c79 11c7c 11c80 11c84 11c88 11c8b 11c8f 11c93
11c97 11c9b 11c9f 11ca3 11ca7 11cab 11caf 11cb3
11cb7 11cb8 11cba 11cbe 11cc0 11cc4 11cc7 11cc9
11ccd 11cd0 11cd4 11cd8 11cdc 11cdd 11cdf 11ce3
11ce7 11ceb 11cee 11cf1 11cf4 11cf5 11cfa 11cfe
11d02 11d05 11d08 11d0c 11d0e 11d12 11d15 11d19
11d1d 11d20 11d24 11d28 11d2b 11d2e 11d33 11d36
11d39 11d3c 11d3d 11d42 11d43 1 11d45 11d4a
11d4e 11d52 11d55 11d5a 11d5f 11d62 11d66 11d67
11d6c 11d6f 11d74 11d75 11d7a 11d7d 11d82 11d83
11d88 11d8b 11d8f 11d93 11d97 11d9b 11d9e 11d9f
11da1 11da6 11da7 11da9 11daa 11daf 11db2 11db7
11db8 11dbd 11dc0 11dc5 11dc6 11dcb 11dce 11dd2
11dd3 11dd8 11ddb 11de0 11de1 11de6 11de7 11dec
11dee 11df2 11df5 11df9 11dfd 11e00 11e04 11e08
11e0b 11e0f 11e13 11e14 11e19 11e1b 11e1f 11e23
11e26 11e2a 11e2e 11e31 11e35 11e39 11e3c 11e3f
11e44 11e47 11e4a 11e4d 11e4e 11e53 11e54 1
11e56 11e5b 11e5f 11e63 11e66 11e6b 11e70 11e73
11e77 11e78 11e7d 11e7e 11e83 11e87 11e8b 11e8e
11e93 11e98 11e9b 11e9f 11ea3 11ea6 11ea7 11eac
11eaf 11eb4 11eb5 11eba 11ebd 11ec1 11ec5 11ec8
11ec9 11ece 11ecf 11ed4 11ed6 11eda 11edd 11ee1
11ee5 11ee9 11eed 11ef1 11ef5 11ef9 11efd 11f01
11f0d 11f12 11f16 11f1a 11f1e 11f22 11f24 11f25
11f2a 1 11f2e 11f32 11f36 11f39 11f3d 11f41
11f45 11f49 11f4c 11f50 11f54 11f57 11f5a 11f5f
11f62 11f65 11f68 11f69 11f6e 11f6f 1 11f71
11f76 11f7a 11f7e 11f81 11f86 11f8b 11f8e 11f92
11f93 11f98 11f99 11f9e 11fa2 11fa6 11fa9 11fae
11fb3 11fb6 11fba 11fbb 11fc0 11fc3 11fc8 11fc9
11fce 11fd1 11fd5 11fd9 11fdc 11fdf 11fe0 11fe2
11fe3 11fe8 11fe9 11fee 11ff0 11ff4 11ff7 11ffb
11fff 12003 12007 1200b 1200f 12013 1201f 12024
12028 1202c 12030 12034 12036 1203a 1203c 12048
1204a 1204c 1204d 12052 12056 12058 12064 12068
1206a 1206b 12074 
5293
2
0 1 a 6 d :3 6 14 :3 6
10 :3 6 14 :3 6 15 :3 6 10 :3 6
e :3 6 11 :3 6 c :3 6 b :3 6
11 :3 6 11 :3 6 1d :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 c 10 f c 20 :2 29 c
:2 4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 14 1d 1c
:2 14 :2 4 18 21 20 :2 18 :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 e 17
16 :2 e :2 4 d 16 15 :2 d :2 4
11 1a 19 :2 11 :2 4 11 1a 19
:2 11 :2 4 :3 11 :2 4 :3 12 :2 4 :3 14 :2 4
:3 15 :2 4 f 18 17 :2 f :2 4 f
18 17 :2 f :2 4 :3 10 :2 4 :3 e :2 4
:3 f :2 4 f 18 17 :2 f :2 4 b
14 13 :2 b :2 4 :3 f :2 4 :3 10 :2 4
:3 12 :2 4 :3 13 :2 4 e 17 16 :2 e
:2 4 10 19 18 :2 10 :2 4 9 12
11 :2 9 :2 4 13 1c 1b :2 13 :2 4
11 1a 19 :2 11 :2 4 :2 14 23 14
:2 4 :2 12 21 12 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 11 20 11 :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 10 1f 10
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 10 1f 10 :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 b 1a b
:2 4 :2 c 1b c :2 4 :2 c 1b c
:2 4 :2 10 1f 10 :2 4 :2 16 25 16
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :2 10 1a 10 :2 4 :2 10 1a 10
:2 4 :2 13 1d 13 :2 4 :2 12 21 12
:2 4 :2 19 28 19 :2 4 :2 19 28 19
:2 4 :2 19 28 19 :2 4 :2 f 1e f
:2 4 :2 11 20 11 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 10 1f 10
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 :2 14 1e 14 :2 4 :2 f
1e f :2 4 14 1d 1c :2 14 :2 4
:2 17 26 17 :2 4 17 20 1f :2 17
:2 4 13 1c 1b :2 13 :2 4 :2 13 22
13 :2 4 :2 14 23 14 :2 4 :3 9 :2 4
:3 9 :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 f 1e f :2 4 :2 f 1e
f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :2 11 20
11 :2 4 :2 15 24 15 :2 4 :2 10 1f
10 :2 4 :2 14 23 14 :2 4 14 1d
1c :2 14 :2 4 14 1d 1c :2 14 :2 4
18 21 20 :2 18 :2 4 :2 d 25 d
:2 4 :2 d 26 30 39 44 :2 30 :2 26
25 d :2 4 :2 10 28 10 :2 4 :2 b
23 b :2 4 :3 10 :2 4 :3 e 4 7
e 0 :2 7 11 24 11 22 2f
a :6 7 e 0 :2 7 11 1f 11
22 2f 40 4e 5b :2 a :6 7 e
0 :2 7 11 13 26 28 3b 3d
46 48 56 58 66 68 a c
1b 23 2a 2c 44 4c 53 55
6e 70 85 87 a1 a3 b9 bb
a c 23 25 2f 31 42 44
52 54 a c 16 18 20 22
2a 2c 37 39 f 17 1a 2f
32 43 10 12 1f 30 32 40
51 53 e 10 24 26 3c 3e
4b 4d e 10 21 2a 32 3b
49 52 60 69 77 80 8d 96
a7 b0 c3 cc e1 ea 105 10e
126 12f 140 149 15b 164 17c 185
198 1a1 1c2 1c4 1ce 13 15 a
:5 7 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 56 5c 5f :2 56 6d
85 8 :2 6d d 10 :2 6d 17 1a
:2 6d b e :2 6d 13 16 :2 6d 1b
1e :2 6d 2c 2f :2 6d b e :2 6d
13 16 :2 6d 1b 1e :2 6d 28 2b
:2 6d b e :2 6d 13 16 :2 6d 1b
1e :2 6d 2c 2f :2 6d b e :2 6d
13 16 :2 6d 1b 1e :2 6d 2d 30
:2 6d b e :2 6d 13 16 1f 27
:2 1f 33 :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 31 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 34
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 2f :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 2e :2 16 :2 6d
b e :2 6d 13 16 1f 27 :2 1f
34 :2 16 :2 6d b e :2 6d 13 16
1f 27 :2 1f 34 :2 16 :2 6d b e
:2 6d 13 16 1f 27 :2 1f 40 :2 16
:2 6d b e :2 6d 13 16 1f 27
:2 1f 33 :2 16 :2 6d b e :2 6d 13
16 :2 6d 1b 1e :2 6d 2a 2d :2 6d
32 35 :2 6d :2 7 4c :2 4 7 :2 11
23 :2 2d 39 3c 4e 51 52 :2 4e
:2 23 :3 7 :2 d 12 1e 5f 62 :2 1e
:2 7 55 :3 4 11 :2 4 14 :2 4 10
:2 4 12 :2 4 12 :2 4 12 :2 4 12
19 22 2e :2 19 32 :2 3b :2 12 4
8 11 1d :2 8 22 20 :2 2b :2 20
7 40 e 1a :2 40 1f 1d :2 28
:2 1d 3f :3 7 15 7 3e :3 4 13
:2 4 14 :2 4 12 :2 4 14 :2 4 15
:2 4 15 :2 4 16 :2 4 9 :3 4 a
16 :2 4 7 e :2 7 :2 10 1c 7
14 7 :2 10 1c 7 :5 4 f :2 18
4 7 d :3 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 65 68 :2 24 75 78
:2 24 7c 7f :2 24 8b 8e :2 24 96
99 :2 24 a5 a8 af b8 bb :2 a8
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 19 :2 7 1c 1e :2 1c
a :2 14 26 :2 30 3c 40 52 55
56 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b6 :2 89
:2 21 be c1 :2 21 c9 cc :2 21 d1
d4 :2 21 dd e0 :2 21 :2 a 59 :2 7
a :2 14 26 :2 30 3c 3f 51 54
55 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 :2 a 58 :3 7 :2 12 26 :2 2f
41 4b :2 7 22 :2 4 e 17 1d
29 38 47 c 17 1f 2d 3e
4f c 1a 27 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 8b 8e :2 24
96 99 :2 24 a5 a8 af b8 bb
:2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 52
55 56 :2 52 :2 26 :3 a :2 10 15 21
62 65 :2 21 72 75 :2 21 79 7c
:2 21 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 21 be c1 :2 21 c9 cc :2 21
d1 d4 :2 21 de e1 :2 21 :2 a 59
:2 7 a :2 14 26 :2 30 3c 3f 51
54 55 :2 51 :2 26 :3 a :2 10 15 21
62 65 :2 21 :2 a 58 :3 7 :2 12 26
:2 2f 41 4c :2 7 35 :3 4 12 4
e 1e c d 1a :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 7 10 1c :2 7 1f
21 :2 1f a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b9 :2 89 :2 21 c1 c4 :2 21 cc cf
:2 21 d4 d7 :2 21 e4 e7 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 44 52 :2 7 23 :2 4 e
11 24 27 4a 53 56 6c 75
78 90 93 9d a0 ad b8 c2
c5 c 14 22 2d 39 45 54
c 14 17 1c 2b 31 34 42
45 56 59 66 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 8b 8e :2 24
96 99 :2 24 a5 a8 af b8 bb
:2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 52
55 56 :2 52 :2 26 :3 a :2 10 15 21
62 65 :2 21 72 75 :2 21 79 7c
:2 21 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 21 be c1 :2 21 c9 cc :2 21
d1 d4 :2 21 de e1 :2 21 :2 a 59
:2 7 a :2 14 26 :2 30 3c 3f 51
54 55 :2 51 :2 26 :3 a :2 10 15 21
62 65 :2 21 :2 a 58 :3 7 :2 12 26
:2 2f 41 4c :2 7 35 :2 4 e 18
2b 37 49 59 67 :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
52 55 56 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 72 75 :2 21 79
7c :2 21 86 89 92 9a :2 a3 :2 92
b6 :2 89 :2 21 be c1 :2 21 c9 cc
:2 21 d1 d4 :2 21 dd e0 :2 21 :2 a
59 :2 7 a :2 14 26 :2 30 3c 3f
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 58 :3 7 :2 12
26 :2 2f 41 4b :2 7 35 :2 4 e
1b 2a 39 46 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 8b 8e :2 24
96 99 :2 24 a5 a8 af b8 bb
:2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 7 :2 12 19 24 :2 7 34
36 :2 34 7 14 7 38 :2 4 8
:2 11 1c 1a :2 25 :2 1a 7 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 62 65 :2 21
72 75 :2 21 79 7c :2 21 86 89
92 9a :2 a3 :2 92 b6 :2 89 :2 21 be
c1 :2 21 c9 cc :2 21 d1 d4 :2 21
e1 e4 :2 21 :2 a 59 :2 7 a :2 14
26 :2 30 3c 3f 51 54 55 :2 51
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 58 :3 7 :2 12 26 :2 2f 41 4f
:2 7 35 :3 4 1c :2 4 1c 23 2c
42 :2 23 46 :2 1c :2 4 12 19 22
38 :2 19 3c :2 12 :2 4 1c 23 2c
42 :2 23 46 :2 1c 4 e 14 2c
c d 1a 2b 39 45 53 64
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 e 14
2c c d 1a 2b 35 46 54
65 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 58 59 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 8b 8e :2 24 96 99 :2 24
a5 a8 af b8 bb :2 a8 :2 24 :2 d
5c :2 a :2 7 :4 13 :2 7 4 :3 1 7
10 13 :2 10 a 13 1f :2 a 22
24 :2 22 14 24 35 58 13 20
31 3b 4c 5a :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5e 5f :2 5b :2 2f
:3 13 :2 19 1e 2a 6b 6e :2 2a 7b
7e :2 2a 82 85 :2 2a 91 94 :2 2a
9c 9f :2 2a ab ae b5 be c1
:2 ae :2 2a :2 13 62 :2 10 :2 d :4 19 :2 d
a :3 26 11 1a 27 :2 11 2a 2d
:2 2a :4 d 1b d 17 27 37 5a
16 23 34 3f 4e 5c :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 61 62
:2 5e :2 32 :3 16 :2 1c 21 2d 6e 71
:2 2d 7e 81 :2 2d 85 88 :2 2d 94
97 :2 2d 9f a2 :2 2d ae b1 b8
c1 c4 :2 b1 :2 2d :2 16 65 :2 13 :2 10
:4 1c :2 10 d :3 2f 10 19 25 :2 10
28 2b :2 28 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6b 6e :2 2a 7b 7e :2 2a
82 85 :2 2a 8f 92 9b a3 :2 ac
:2 9b cd :2 92 :2 2a d5 d8 :2 2a e0
e3 :2 2a e8 eb :2 2a f4 f7 :2 2a
:2 13 62 :2 10 13 :2 1d 2f :2 39 45
48 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6b 6e :2 2a :2 13 61 :3 10
:2 1b 2f :2 38 58 18 :2 10 2d :2 d
2f :2 a 26 :2 7 4 15 a 18
21 2c :2 18 :2 a 30 33 :2 30 3a
43 4f :2 3a 52 54 :2 52 59 a
16 :2 59 19 1b :2 19 :2 3a 39 :2 a
7 15 7 11 21 31 54 10
1d 2e 3c 49 e :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
78 7b :2 27 7f 82 :2 27 8e 91
:2 27 99 9c :2 27 a8 ab b2 bb
be :2 ab :2 27 :2 10 5f :2 d :2 a :4 16
:2 a 7 :3 1e a 13 1f :2 a 22
24 :2 22 d :2 17 29 :2 33 3f 43
55 58 59 :2 55 :2 29 :3 d :2 13 18
24 65 68 :2 24 75 78 :2 24 7c
7f :2 24 89 8c 95 9d :2 a6 :2 95
c7 :2 8c :2 24 cf d2 :2 24 da dd
:2 24 e2 e5 :2 24 ee f1 :2 24 :2 d
5c :2 a d :2 17 29 :2 33 3f 42
54 57 58 :2 54 :2 29 :3 d :2 13 18
24 65 68 :2 24 :2 d 5b :3 a :2 15
29 :2 32 52 12 :2 a 26 :2 7 1e
15 :3 4 12 :2 4 13 :2 4 17 :2 4
1b :2 4 1b :2 4 14 :2 4 9 :3 4
a 14 :2 4 7 c :2 7 :2 10 1c
7 12 7 :2 10 1c 7 :4 4 8
:2 11 1c 1a :2 25 :2 1a :2 7 15 7
35 7 15 7 :4 4 7 d :3 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
8b 8e :2 24 96 99 :2 24 a5 a8
af b8 bb :2 a8 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1c
:2 7 1f 21 :2 1f a 13 1f :2 a
22 24 :2 22 a 18 a 26 :2 7
23 :2 4 e 20 34 43 50 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
8b 8e :2 24 96 99 :2 24 a5 a8
af b8 bb :2 a8 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 e 21 32
43 c d 1a b 1b b 19
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
66 69 :2 24 76 79 :2 24 7d 80
:2 24 8c 8f :2 24 97 9a :2 24 a6
a9 b0 b9 bc :2 a9 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 3d 46 52
:2 3d 55 58 :2 55 :3 39 :3 7 1a :2 7
:3 1a 7 11 1e 2f 38 f 10
1d :2 e 1c :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 79 7c
:2 27 80 83 :2 27 8f 92 :2 27 9a
9d :2 27 a9 ac b3 bc bf :2 ac
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 5a b :2 14 1f 1d :2 28 :2 1d :2 a
20 :2 29 30 39 42 :2 30 46 :2 4f
:2 20 a 38 a 1d 2b 2e 37
3f :2 2e 43 :2 4c 24 :2 1d :2 a 20
:2 29 a :5 7 1a :2 7 19 :2 7 1a
31 3f 49 51 2d 41 52 :2 1a
:2 7 17 20 29 31 :2 20 :2 17 7
16 2b 3e 4a 56 a 19 26
32 3f 4c a 14 12 23 31
3f a 16 20 2e 42 56 a
17 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 5a a :2 15 1c 2a :2 a 35
37 :2 35 a 15 a 39 14 1a
32 3f 13 20 31 3c 11 1f
30 48 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6c 6f :2 2a 7c 7f :2 2a
83 86 :2 2a 92 95 :2 2a 9d a0
:2 2a ac af b6 bf c2 :2 af :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :7 7
a 13 1c :2 a 1f 21 :2 1f 14
20 2f 38 46 56 13 20 31
3e d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5e 5f :2 5b :2 2f
:3 13 :2 19 1e 2a 6c 6f :2 2a 7c
7f :2 2a 83 86 :2 2a 92 95 :2 2a
9d a0 :2 2a ac af b6 bf c2
:2 af :2 2a :2 13 62 :2 10 :2 d :4 19 :2 d
a :3 23 14 20 12 19 27 44
12 19 28 2f 49 12 22 13
20 31 3e d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :4 23 14 20 12 19
27 44 12 19 28 2f 49 12
22 13 20 31 3e d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5e 5f :2 5b :2 2f :3 13 :2 19 1e 2a
6c 6f :2 2a 7c 7f :2 2a 83 86
:2 2a 92 95 :2 2a 9d a0 :2 2a ac
af b6 bf c2 :2 af :2 2a :2 13 62
:2 10 :2 d :4 19 :2 d a :7 7 4 5a
b :2 14 1f 1d :2 28 :2 1d a 11
1d 36 41 48 55 6c 74 82
a2 ab b9 c9 10 1d 2e 3b
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 79 7c
:2 27 80 83 :2 27 8f 92 :2 27 9a
9d :2 27 a9 ac b3 bc bf :2 ac
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 38 7 15 7 11 28 f 10
24 38 :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 58 5b 5c :2 58 :2 2c :3 10 :2 16
1b 27 69 6c :2 27 79 7c :2 27
80 83 :2 27 8f 92 :2 27 9a 9d
:2 27 a9 ac b3 bc bf :2 ac :2 27
:2 10 5f :2 d :2 a :4 16 :2 a 7 :3 38
b :2 14 1f 1d :2 28 :2 1d a 14
2b 12 13 27 3b :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
7c 7f :2 2a 83 86 :2 2a 92 95
:2 2a 9d a0 :2 2a ac af b6 bf
c2 :2 af :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 38 e :2 17 22 20 :2 2b
:2 20 :2 d 1b d 3b :2 a 38 :2 7
e 17 23 :2 e 26 29 :2 26 :3 a
d 16 1f :2 d 24 22 :2 2d :2 22
d 20 2e 31 3a 42 :2 31 46
:2 4f 24 :2 20 d 17 30 3d 10
1e 27 34 42 16 2a 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :3 3c d
20 36 :2 20 d a 3c 11 18
21 2a :2 18 2e :2 37 :2 11 10 48
45 :2 51 :2 45 17 30 3d 10 1c
25 2c 39 42 16 2a 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :3 5d d
20 36 :2 20 d a 5d 3c 11
18 21 2a :2 18 2e :2 37 :2 11 10
4a 47 :2 53 :2 47 17 30 3d 10
1c 25 2c 39 42 16 2a 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 61
d 20 36 :2 20 d 61 3c :2 a
2b :2 7 38 5a :2 4 18 28 2b
c 1d 28 32 35 :2 c 16 19
1e 2d 33 36 44 47 56 59
d 19 :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 55 58 59 :2 55 :2 29 :3 d :2 13
18 24 66 69 :2 24 76 79 :2 24
7d 80 :2 24 8c 8f :2 24 97 9a
:2 24 a6 a9 b0 b9 bc :2 a9 :2 24
:2 d 5c :2 a :2 7 :4 13 :2 7 4 :3 1
8 :2 11 1d 1a :2 26 :2 1a :2 7 19
7 36 :3 4 13 :2 4 14 :2 4 15
:2 4 :3 17 4 8 11 27 :2 8 2a
2c :2 2a 7 33 3c 52 :2 33 55
57 :2 55 32 :3 7 1a 2b 39 43
4f 5c 27 34 40 4d 59 :2 1a
7 a 13 29 :2 a 2c 2e :2 2c
a 18 21 2d :2 18 30 32 3b
4b :2 32 :2 18 :2 a 19 22 2f :2 19
32 34 3d 4d :2 34 :2 19 a 30
:2 7 a 13 29 :2 a 2c 2e :2 2c
a 18 21 2d :2 18 30 32 3b
4b :2 32 :2 18 :2 a 19 22 2f :2 19
32 34 3d 4d :2 34 :2 19 a 30
:2 7 5a :3 4 10 :2 4 f 4 e
12 26 c d 1a :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 66 69 :2 24
76 79 :2 24 7d 80 :2 24 8c 8f
:2 24 97 9a :2 24 a6 a9 b0 b9
bc :2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 4 1b 4 e 21
2f 44 c d 1a 2b 35 b
19 2a :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 55 58 59 :2 55 :2 29 :3 d :2 13
18 24 66 69 :2 24 76 79 :2 24
7d 80 :2 24 8c 8f :2 24 97 9a
:2 24 a6 a9 b0 b9 bc :2 a9 :2 24
:2 d 5c :2 a :2 7 :4 13 :2 7 4 :3 1
e 28 4a 56 c 22 2f :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 66
69 :2 24 76 79 :2 24 7d 80 :2 24
8c 8f :2 24 97 9a :2 24 a6 a9
b0 b9 bc :2 a9 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 b :2 16 1d
2b :2 b 36 39 :2 36 :3 7 :4 b :2 a
19 a 14 26 34 3c 43 5b
63 6a 83 8d d 1b 29 32
3d 47 4f 57 12 18 2a 35
41 4d d 19 25 30 41 49
52 5a 12 13 27 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :3 2c e :2 17 22 20 :2 2b
:2 20 d :4 41 40 3f :3 d 1d 1e
:2 1d :2 d :2 16 22 39 47 55 2f
3a 46 52 2f 3d 50 :2 22 d
63 :3 a 1f a d 16 22 :2 d
25 27 :2 25 10 19 24 :2 10 2a
27 33 3f :2 2a :2 27 45 4e 56
:2 45 5c 59 27 30 :2 5c :2 59 :2 10
13 1a 23 2f :2 1a 33 :2 3c :2 13
49 4c :2 49 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 94 97 a0 a8 :2 b1
:2 a0 c9 :2 97 :2 2d d1 d4 :2 2d dc
df :2 2d e4 e7 :2 2d f0 f3 :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d :2 16 65 :3 13
:2 1e 32 :2 3b 52 5c :2 13 4e 13
28 13 16 1f 2b :2 16 2e 30
:2 2e 16 29 16 32 :2 13 :4 10 33
:3 d 19 :2 d 1d :2 d 1e :2 d 17
:2 d 1d :2 d 18 :2 d 17 :2 d 1a
:2 d 1a d 29 :2 a e :2 17 22
20 :2 2b :2 20 :2 d 1c :2 d 1a d
:4 11 10 13 1a 2a 2d :2 13 30
32 :2 30 13 23 24 :2 23 :2 13 :2 1c
28 3f 4d 5b 2f 3a 46 52
2f 3d 50 :2 28 13 36 :2 10 1a
2d 35 3c 4f 59 6a 13 1d
25 30 3f 4e 18 25 30 3c
4f 13 1b 23 2e 3f 50 18
19 2d :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 32
14 :2 1d 28 26 :2 31 :2 26 13 16
1f 2a :2 16 30 2d 39 45 :2 30
:2 2d 4b 54 5c :2 4b 62 5f 27
30 :2 62 :2 5f :2 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 97 9a a3 ab
:2 b4 :2 a3 cc :2 9a :2 30 d4 d7 :2 30
df e2 :2 30 e7 ea :2 30 f3 f6
:2 30 :2 19 69 :2 16 19 :2 23 35 :2 3f
4b 4e 60 64 65 :2 60 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 :2 19 68
:3 16 :2 21 35 :2 3e 55 5f :2 16 33
:3 13 2c 33 3f 42 :2 2c 45 47
:2 45 50 :2 27 57 :2 22 13 16 1f
2b :2 16 2e 31 :2 2e 16 21 :2 16
25 16 19 22 2e :2 19 31 34
:2 31 1c 25 31 :2 1c 34 37 :2 34
26 2a 3a 24 25 32 23 38
50 5c :2 1f :2 28 34 1f 1c 24
22 :2 2b 37 22 32 :2 1f :2 24 22
:2 2b 37 22 25 :2 2f 41 :2 4b 57
5b 6d 71 72 :2 6d :2 41 :3 25 :2 2b
30 3c 7f 82 :2 3c 8f 92 :2 3c
96 99 :2 3c a5 a8 :2 3c b0 b3
:2 3c bf c2 c9 d2 d5 :2 c2 :2 3c
:2 25 75 :2 22 :2 1f :4 2b :2 1f 1c :4 39
26 2a 3a 24 25 32 43 51
:2 1f :2 28 34 1f 1c 24 22 :2 2b
37 22 32 :2 1f :2 24 22 :2 2b 37
22 25 :2 2f 41 :2 4b 57 5b 6d
71 72 :2 6d :2 41 :3 25 :2 2b 30 3c
7f 82 :2 3c 8f 92 :2 3c 96 99
:2 3c a5 a8 :2 3c b0 b3 :2 3c bf
c2 c9 d2 d5 :2 c2 :2 3c :2 25 75
:2 22 :2 1f :4 2b :2 1f 1c :7 19 36 :2 16
19 22 2e :2 19 31 34 :2 31 28
3f 4c 20 35 4d 59 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6a 6e 6f :2 6a :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :4 36 28
42 4f 60 6e 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6a 6e
6f :2 6a :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :3 16 28 43 57
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:3 16 28 3f 53 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6a 6e
6f :2 6a :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :3 16 28 3f 4c
5d 71 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 21 1f :2 28 34 1f 2f
:2 1c :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6e 6f :2 6a
:2 3e :3 22 :2 28 2d 39 7c 7f :2 39
8c 8f :2 39 93 96 :2 39 a2 a5
:2 39 ad b0 :2 39 bc bf c6 cf
d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28
:2 1c 19 :7 16 33 :2 13 41 :2 10 d
32 17 20 2c :2 17 2f 32 :2 2f
:3 13 38 41 4d :2 38 50 53 :2 50
:3 13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
91 94 9d a5 :2 ae :2 9d cf :2 94
:2 2a d7 da :2 2a e2 e5 :2 2a ea
ed :2 2a f6 f9 :2 2a :2 13 63 :2 10
13 :2 1d 2f :2 39 45 48 5a 5e
5f :2 5a :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a :2 13 62 :3 10 :2 1b 2f :2 38
58 18 :2 10 55 32 :2 d 10 1c
1f :2 1c 10 27 10 14 1d 33
:2 14 36 38 :2 36 13 40 49 5f
:2 40 62 64 :2 62 3f :2 13 16 1f
2b :2 16 2e 30 :2 2e 20 35 49
19 27 31 19 28 19 28 19
28 19 28 19 2f 4a 59 19
33 40 55 19 27 30 37 44
4d 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 67 6b 6c
:2 67 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :4 32 20 35 49 19
27 31 19 28 19 28 19 28
19 28 19 2f 4a 59 19 33
40 55 19 36 43 5a 19 27
30 37 44 4d 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6b 6c :2 67 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :7 13 10
67 16 1f 35 :2 16 38 3a :2 38
1d 32 46 16 24 2e 16 25
16 25 16 2c 47 56 16 30
3d 52 16 24 2d 34 41 4a
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 3c 10 3c 67 16 1f
35 :2 16 38 3a :2 38 16 1f 2b
:2 16 2e 30 :2 2e 20 35 49 19
27 31 19 28 19 28 19 2f
4a 59 19 27 30 37 44 4d
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :4 32 20 35 49 19 27
31 19 28 19 28 19 2f 4a
59 19 36 43 5a 19 27 30
37 44 4d 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 3c 67
1d 32 46 16 2c 47 56 16
24 2e 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :7 10 1f 36 43
54 68 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 21 1f 3a 4e 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 99 9c :2 30 a4 a7 :2 30
b3 b6 bd c6 c9 :2 b6 :2 30 :2 19
69 :2 16 :2 13 :4 1f :2 13 10 :3 21 1f
39 46 57 65 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :4 21 :2 d 10 1a
1d :2 1a 13 1c 24 :2 13 27 29
:2 27 13 20 :2 29 13 2b 13 20
:2 29 30 39 44 :2 30 48 :2 51 :2 20
13 :5 10 1b 10 13 1c 28 :2 13
2b 2d :2 2b 16 1f 29 :2 16 2e
2c 37 49 :2 2e :2 2c 16 22 2b
3d :2 22 16 4c :3 13 22 :2 13 1c
13 16 :2 1f 2a 3d :2 16 40 43
:2 40 16 22 16 45 16 22 16
:4 13 16 1f 2b :2 16 2e 30 :2 2e
16 20 16 32 :3 13 21 32 3e
4b 54 5d :2 4b 61 6a 72 :2 61
22 2b 37 :2 22 3b 44 4f :2 3b
53 20 2b :2 53 2f 38 46 :2 2f
4a 53 5e :2 4a 22 2b 37 :2 22
3b 43 4d :2 21 13 16 1f 2b
:2 16 30 2e :2 39 :2 2e 19 :2 23 35
:2 3f 4b 4e 60 64 65 :2 60 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 97 9a a3
ab :2 b4 :2 a3 c5 :2 9a :2 30 :2 19 68
:2 16 19 :2 23 35 :2 3f 4b 4e 60
64 65 :2 60 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 :2 19 68 :3 16 :2 21 37
:2 40 50 :2 16 13 48 19 22 2e
:2 19 31 34 :2 31 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 97 9a a3 ab
:2 a3 b8 :2 9a :2 30 c0 c3 :2 30 cb
ce :2 30 d3 d6 :2 30 e3 e6 :2 30
:2 19 69 :2 16 19 :2 23 35 :2 3f 4b
4e 60 64 65 :2 60 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 :2 19 68 :3 16
:2 21 35 3e 4a :2 35 4e 5c :2 16
36 48 :3 13 26 :2 13 1f 2b 40
4e 5c 66 1b 23 2f 3b 47
53 1b 2a 36 40 48 51 59
1b 27 33 40 4b 56 1b 25
30 3c 48 4b 4e 54 5a :2 1f
13 16 1f 21 :2 1f 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 97 9a a3
ab :2 b4 :2 a3 cb :2 9a :2 30 d3 d6
:2 30 de e1 :2 30 e6 e9 :2 30 f2
f5 :2 30 :2 19 69 :2 16 19 :2 23 35
:2 3f 4b 4e 60 64 65 :2 60 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 :2 19
68 :3 16 :2 21 35 :2 3e 54 5e :2 16
13 25 19 22 25 :2 22 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 97 9a
a3 ab :2 b4 :2 a3 cc :2 9a :2 30 d4
d7 :2 30 df e2 :2 30 e7 ea :2 30
fa fd :2 30 :2 19 69 :2 16 19 :2 23
35 :2 3f 4b 4e 60 64 65 :2 60
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
:2 19 68 :3 16 :2 21 35 :2 3e 55 1e
:2 16 27 25 16 24 :2 16 24 34
42 57 63 6c 77 :2 63 21 2a
34 :2 21 :2 24 16 :4 13 2f :2 10 1f
:3 d 1b :2 24 d 17 1b 2a 15
16 23 34 48 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :4 3b :2 a 2c :3 7 12 7 3b
:3 4 e 15 1c 1f :2 15 24 27
:2 e :2 4 1b :2 4 10 4 e 20
34 43 50 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 59 5a :2 55 :2 29 :3 d
:2 13 18 24 67 6a :2 24 77 7a
:2 24 7e 81 :2 24 8d 90 :2 24 98
9b :2 24 a7 aa b1 ba bd :2 aa
:2 24 :2 d 5d :2 a :2 7 :4 13 :2 7 4
:3 1 4 12 :2 4 12 :2 4 f :2 4
14 :2 4 9 :4 4 d 16 23 38
43 4b 55 7 15 1b 21 2e
7 1c 27 39 44 7 f 18
20 2b :3 7 a e :2 a :2 13 1f
a 14 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :3 7
16 7 a 13 1d :2 a 20 22
:2 20 a 1d 34 41 :2 1d a 19
34 48 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :3 24 19 30 44 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 24 19
2b 3f d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :3 24 19 30 3d 4e 62
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 24 19 35 49 d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 24 19 36 4a
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5f 60 :2 5b :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:4 24 d 16 22 :2 d 25 27 :2 25
d 24 d 29 :2 a 14 2b 39
13 27 11 1e 11 1f d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 7 a
1a 1b :2 1a :2 a :2 13 1f 36 44
4f 64 6a 2f 3b 47 2f 42
:2 1f a 14 27 35 4a 12 13
20 31 3b 49 57 11 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 93
96 :2 2a 9e a1 :2 2a ad b0 b7
c0 c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d
:4 19 :2 d a :3 7 e :2 17 22 20
:2 2b :2 20 :2 d 1c d 17 2a 37
48 4e 5d 15 16 23 31 3f
4c :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :3 3b 11
:2 1a 25 23 :2 2e :2 23 10 14 1b
24 33 :2 1b 37 :2 40 :2 14 13 52
50 :2 5b :2 50 13 1f 13 1d 16
24 16 25 16 1c 30 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 69 10
69 16 1f 2e :2 16 33 31 :2 3c
:2 31 13 26 34 37 40 48 :2 37
4c :2 55 24 :2 26 13 1d 16 25
2e 16 25 16 24 16 25 16
1c 30 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :4 4b 69 1d 16 25 2e
35 43 4c 16 25 16 24 16
25 16 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :7 10 14 :2 1d 28
26 :2 31 :2 26 13 46 4f 59 :2 46
5c 5e :2 5c 45 :2 13 22 3d 51
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:4 61 :2 10 3e 1a 1d 30 37 3a
49 4f 52 18 1d 27 2f 33
48 19 1c 29 37 3a 47 4a
59 5c 17 1a 28 2b 1a 31
42 4b 4e 62 65 :2 13 :2 1c 28
13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 d 14 :2 1d 28 26 :2 31
:2 26 13 :4 47 46 45 :3 13 26 34
37 40 48 :2 37 4c :2 55 24 :2 26
13 22 3d 51 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 5a 1d 36 44
4e 16 23 31 43 4f 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 5a 1d 29 38 41 4f 55 1c
29 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :4 5a 1d 29 38 41 4f 5f
1c 29 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 10 1d 36 44 4e 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 d 1c 33 40 51 65
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:4 3b d 1c d 1c 37 4b 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 33 47 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 a 1c 33 40 51
65 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :3 a 10 17 23 26 :2 10 29
2b :2 29 10 1f 10 2f :3 d 24
d :4 a d 16 20 :2 d 23 25
:2 23 11 1a 28 :2 11 2b 2d :2 2b
10 :4 36 35 34 :2 10 24 46 56
18 2a 38 43 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :3 51 14 :2 1d 28 26 :2 31 :2 26
13 46 4f 5d :2 46 60 62 :2 60
45 :2 13 1d 29 39 4c 57 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 65
10 65 17 :2 20 2b 29 :2 34 :2 29
16 49 52 60 :2 49 63 65 :2 63
48 :3 16 1c :3 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 68 16 :2 20 32 :2 3c 48 4c 5e
62 63 :2 5e :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 94 97 a0 a8 :2 b1 :2 a0 cc
:2 97 :2 2d d4 d7 :2 2d df e2 :2 2d
e7 ea :2 2d f4 f7 :2 2d :2 16 66
:2 13 16 :2 20 32 :2 3c 48 4b 5d
61 62 :2 5d :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d :2 16 65 :3 13 :2 1e 32
:2 3b 55 1b :2 13 68 65 :2 10 51
:2 d 10 19 26 :2 10 2b 29 :2 34
:2 29 49 13 20 :2 49 25 23 :2 2e
:2 23 :3 10 18 22 :3 10 :2 19 25 10
13 1c 27 :2 13 2a 2c :2 2a 32
3b 43 :2 32 46 48 :2 46 :2 13 22
1d 1f 30 45 1c 1e 2b 38
3a 4b 53 5a 6c 74 7b 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :4 4a
22 3c 3e 1b 30 33 44 1c
1e 2b 38 3a 4b 53 5a 6c
74 7b 1a 1e 2b 3c 40 54
1a 1c 27 2b 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :7 10 14 :2 1d 28
26 :2 31 :2 26 :2 13 21 13 1d 23
2e 32 41 4d 1b :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 41 16 1f 2b :2 16 2e
30 :2 2e 1b 16 32 25 1f 2c
3d 51 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :3 13 16 23 2a 33 3d
:2 33 48 :2 2a 4b 4d 56 60 :2 56
6d :2 4d :2 2a 29 71 73 :2 29 :2 23
16 20 2f 3e 4b 1e 1f 2c
3d 48 :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :3 13
19 22 2f :2 19 34 32 3d 48
:2 34 :2 32 19 :2 22 3b 44 4f :2 3b
53 :2 19 4b :2 16 25 :10 19 23 37
50 19 1e 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 67 6b 6c
:2 67 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :7 13 1d 32 40 4a
16 38 56 16 2f 4d 5e 16
2f 4d 5e 16 2f 4d 5e 16
2f 4d 5e 16 25 2e 35 42
4b 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :3 41 13 26 2d 36
40 :2 36 4c :2 2d 4f 51 5a 64
:2 5a 70 :2 51 :2 2d 2c 24 26 :2 2c
:2 26 :2 13 21 :2 2a 31 3a 4b :2 31
4f :2 58 :2 21 :2 13 26 36 44 59
65 24 2f :2 65 33 3c 46 :2 33
:2 26 13 41 18 13 :4 10 42 10
21 10 13 1c 1f :2 1c 16 1f
2c :2 16 2f 32 :2 2f 16 22 16
19 22 2a :2 19 2d 2f :2 2d 35
3e 4f :2 35 52 55 :2 52 :2 19 5f
1c 2d :2 5f 30 33 :2 30 :3 19 23
:2 19 23 2c 3d :2 23 19 35 :2 16
20 19 28 31 38 45 4e 60
66 6c 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6b
6c :2 67 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 34 16 22 :2 16
26 :2 16 27 :2 16 20 :2 16 26 :2 16
21 :2 16 20 :2 16 23 :2 16 23 16
1b 22 2b 37 :2 22 3b :2 44 :2 1b
1a 52 55 :2 52 19 5d 1c 27
:2 5d 2d 2a 36 42 :2 2d :2 2a 48
1c 24 :2 48 2a 27 33 3c :2 2a
:2 27 :2 5d 5c :2 19 1c 25 2b :2 1c
2e 30 :2 2e 26 1f 2d 37 4a
29 47 1f 38 56 67 1f 38
56 67 1f 38 56 67 1f 38
56 67 1f 2e 37 3d 1f 2e
1f 2e 37 3e 4b 54 25 39
1f 26 22 2e :3 2c 22 :2 2b 37
22 33 22 :2 2b 37 22 :4 1f 1c
24 22 :2 2b 37 22 32 :2 1f :2 24
22 :2 2b 37 22 25 :2 2f 41 :2 4b
57 5b 6d 71 72 :2 6d :2 41 :3 25
:2 2b 30 3c 7f 82 :2 3c 8f 92
:2 3c 96 99 :2 3c a5 a8 :2 3c b0
b3 :2 3c bf c2 c9 d2 d5 :2 c2
:2 3c :2 25 75 :2 22 :2 1f :4 2b :2 1f 1c
:4 34 26 1f 2d 37 4a 29 47
1f 38 56 67 1f 38 56 67
1f 38 56 67 1f 38 56 67
1f 2e 37 3d 1f 2e 1f 2e
1f 2e 37 3e 4b 54 25 39
1f 26 22 2e :3 2c 22 :2 2b 37
22 33 22 :2 2b 37 22 :4 1f 1c
24 22 :2 2b 37 22 32 :2 1f :2 24
22 :2 2b 37 22 25 :2 2f 41 :2 4b
57 5b 6d 71 72 :2 6d :2 41 :3 25
:2 2b 30 3c 7f 82 :2 3c 8f 92
:2 3c 96 99 :2 3c a5 a8 :2 3c b0
b3 :2 3c bf c2 c9 d2 d5 :2 c2
:2 3c :2 25 75 :2 22 :2 1f :4 2b :2 1f 1c
:7 19 40 23 1c 2a 34 47 26
44 1c 35 53 64 1c 35 53
64 1c 35 53 64 1c 35 53
64 1c 2b 34 3b 48 51 63
69 22 36 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6a 6e 6f
:2 6a :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :7 16 1a 23 2e :2 1a
31 33 :2 31 19 3b 44 4c :2 3b
4f 52 :2 4f 3a :3 19 23 19 16
57 1c 25 2d :2 1c 30 32 :2 30
19 2c 35 3d :2 2c 19 36 57
:2 16 :5 13 21 32 3e 4b 54 5d
:2 4b 61 6a 72 :2 61 22 2b 37
:2 22 3b 44 4f :2 3b 53 20 2b
:2 53 2f 38 46 :2 2f 4a 53 5e
:2 4a 22 2b 37 :2 22 3b 43 4d
:2 21 13 16 1f 2b :2 16 30 2e
:2 39 :2 2e 19 1f :3 19 :2 22 2e 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :3 48 19 :2 23 35 :2 3f 4b 4e
60 64 65 :2 60 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 97 9a a3 ab :2 b4 :2 a3
c5 :2 9a :2 30 :2 19 68 :2 16 19 :2 23
35 :2 3f 4b 4e 60 64 65 :2 60
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
:2 19 68 :3 16 :2 21 37 :2 40 50 :2 16
13 48 19 22 2e :2 19 31 34
:2 31 19 1f :3 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:3 36 19 :2 23 35 :2 3f 4b 4f 61
65 66 :2 61 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 97 9a a3 ab :2 a3 b8 :2 9a
:2 30 c0 c3 :2 30 cb ce :2 30 d3
d6 :2 30 e3 e6 :2 30 :2 19 69 :2 16
19 :2 23 35 :2 3f 4b 4e 60 64
65 :2 60 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 :2 19 68 :3 16 :2 21 35 3e
4a :2 35 4e 5c :2 16 36 48 :2 13
21 16 1f 27 :2 16 2a 2c :2 2a
32 3b 4c :2 32 4f 52 :2 4f :2 16
5c 19 2a :2 5c 2d 30 :2 2d :3 16
20 :2 16 20 29 3a :2 20 16 32
:2 13 17 20 2c :2 17 2f 31 :2 2f
16 38 41 4d :2 38 52 50 5b
66 :2 52 :2 50 37 :3 16 24 2d 38
:2 24 16 6a 16 24 2a 33 3f
:2 2a 42 44 4d 58 :2 44 :2 2a :2 24
16 :4 13 16 1f 2b :2 16 2e 30
:2 2e 16 24 2d 39 :2 24 3c 3e
:2 24 16 33 16 24 2a 34 3d
49 :2 34 :2 2a 4d 4f :2 2a :2 24 16
:4 13 16 1f 2c :2 16 2f 32 :2 2f
20 19 28 31 38 45 4e 60
66 6c 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6b
6c :2 67 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 34 20 19 27
31 44 23 41 19 32 50 61
19 32 50 61 19 32 50 61
19 32 50 61 19 28 31 38
45 4e 60 66 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6b 6c :2 67 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :7 13 :5 10
19 10 13 1c 28 :2 13 2d 2b
:2 36 :2 2b 13 1f 13 4b 13 1f
13 :4 10 13 1c 24 :2 13 27 29
:2 27 13 20 :2 29 13 2b 13 20
:2 29 30 39 44 :2 30 48 :2 51 :2 20
13 :5 10 20 10 13 1c 24 :2 13
27 29 :2 27 16 1f 27 :2 16 2a
2c :2 2a 16 24 2c 35 40 :2 2c
43 45 4e 56 :2 45 :2 2c 2b 5a
5c :2 2b 2a 66 68 :2 2a :2 24 16
19 22 33 :2 19 38 36 41 4d
:2 38 :2 36 19 27 30 41 :2 27 :2 19
23 2a 33 3f :2 2a 42 44 :2 2a
29 4e 50 59 64 :2 50 :2 29 67
69 :2 29 :2 23 19 50 :2 16 13 30
19 22 33 :2 19 38 36 41 49
:2 38 :2 36 16 20 29 3a :2 20 16
4c 30 :2 13 2b :3 10 1c 28 3d
4b 56 60 1b 23 2f 3b 47
53 1b 2a 36 40 48 51 59
1b 27 33 40 4b 56 1b 25
30 3c 48 4b 4e 54 5a :2 1c
10 13 1c 1e :2 1c 16 1c :3 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 22 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 94 97 a0
a8 :2 b1 :2 a0 c8 :2 97 :2 2d d0 d3
:2 2d db de :2 2d e3 e6 :2 2d ef
f2 :2 2d :2 16 66 :2 13 16 :2 20 32
:2 3c 48 4b 5d 61 62 :2 5d :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d :2 16
65 :3 13 :2 1e 32 :2 3b 51 5b :2 13
10 22 16 1f 22 :2 1f 16 1c
:3 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 24 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 94 97
a0 a8 :2 b1 :2 a0 c9 :2 97 :2 2d d1
d4 :2 2d dc df :2 2d e4 e7 :2 2d
f7 fa :2 2d :2 16 66 :2 13 16 :2 20
32 :2 3c 48 4b 5d 61 62 :2 5d
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
:2 16 65 :3 13 :2 1e 32 :2 3b 52 1b
:2 13 24 22 :2 10 :4 d 17 23 32
3a 47 67 72 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :3 27 1c 17 2c
2e 3a 3c 52 54 63 65 7a
7c 15 26 28 2d 36 3b 3d
4a 4c 5a 5c 69 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
62 63 :2 5e :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :3 27 1c 17
2c 35 4b 5a 6f 83 15 31
45 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :3 27 1c 17 2c 36 4c 5b
70 84 15 32 46 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
62 63 :2 5e :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :3 27 d 19
22 2c :2 19 2f 31 :2 19 :2 d 18
21 2a :2 18 2d 2f 38 42 :2 2f
:2 18 :2 d 20 :2 d 20 3c 4a 58
:2 20 :2 d 20 :2 d 20 3c 4a 54
:2 20 d 17 27 35 16 23 34
48 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :3 27 11 1a 30 :2 11 33 35
:2 33 10 3d 46 5c :2 3d 5f 61
:2 5f 3c :2 10 1a 31 3f 13 29
13 29 13 29 13 29 13 1e
2a 39 19 2d 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :3 64 d 64 13
1c 32 :2 13 35 37 :2 35 1a 31
3f 13 29 13 29 13 1e 2a
39 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :3 39 10 1e 27 33
:2 1e 10 d 39 64 13 1c 32
:2 13 35 37 :2 35 1a 31 3f 13
29 13 29 13 1e 2a 39 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :3 39 10 1e 27 33 :2 1e 10
39 64 1a 31 3f 13 1e 2a
39 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :3 d 10 1e 27 33
:2 1e :2 10 1e 27 33 :2 1e 10 :4 d
27 :2 a :5 7 :2 10 1c 32 40 4e
:2 1c 7 9 7 :3 4 8 1 7
d :3 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 59 5a :2 55 :2 29 :3 d :2 13 18
24 67 6a :2 24 77 7a :2 24 7e
81 :2 24 8d 90 :2 24 98 9b :2 24
a7 aa b1 ba bd :2 aa :2 24 :2 d
5d :2 a :2 7 :4 13 :2 7 4 :3 1 4
f 4 7 10 1a :2 7 1d 1f
:2 1d 7 13 7 a 13 1d :2 a
23 20 2c 35 :2 23 :2 20 a 16
1f 29 :2 16 2c 2e 37 40 :2 2e
:2 16 a e 17 21 :2 e 24 26
:2 24 d 2e 37 43 :2 2e 46 48
:2 46 2d :2 d :4 16 15 14 :3 d 1d
:2 d 1e :2 d 17 :2 d 1d :2 d 18
:2 d 17 :2 d 1a :2 d 1a d 11
1a 25 :2 11 28 2a :2 28 10 32
3b 43 :2 32 46 49 :2 46 31 :3 10
1a 10 d 4e 13 1c 24 :2 13
27 29 :2 27 10 23 2c 34 :2 23
10 2d 4e :3 d 1b 2c 38 45
4e 57 :2 45 5b 64 6c :2 5b 22
2b 37 :2 22 3b 44 4f :2 3b 53
20 2b :2 53 2f 38 46 :2 2f 4a
53 5e :2 4a 22 2b 37 :2 22 3b
43 4d :2 1b d 10 19 25 :2 10
2a 28 :2 33 :2 28 13 :2 1d 2f :2 39
45 48 5a 5e 5f :2 5a :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 91 94 9d a5
:2 ae :2 9d bf :2 94 :2 2a :2 13 62 :2 10
13 :2 1d 2f :2 39 45 48 5a 5e
5f :2 5a :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a :2 13 62 :3 10 :2 1b 31 :2 3a
4a :2 10 d 42 13 1c 28 :2 13
2b 2e :2 2b 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 91 94 9d a5 :2 9d
b2 :2 94 :2 2a ba bd :2 2a c5 c8
:2 2a cd d0 :2 2a dd e0 :2 2a :2 13
63 :2 10 13 :2 1d 2f :2 39 45 48
5a 5e 5f :2 5a :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a :2 13 62 :3 10 :2 1b
2f 38 44 :2 2f 48 56 :2 10 30
42 :3 d 15 1f :3 d :2 16 22 d
1c 32 3c 40 15 16 23 34
40 19 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :3 38 d 1e :2 d 1c :2 d
19 :2 d 16 :2 d 17 d 10 19
21 :2 10 24 26 :2 24 10 1a :2 23
2a 33 3b :2 2a 3f :2 48 :2 1a :2 10
1d 10 28 10 1d 10 :5 d 20
:2 d 19 25 36 44 52 5c 1b
23 2f 3b 47 53 1b 2a 36
40 48 51 59 1b 27 33 40
4b 56 1b 25 30 3c 48 4b
4e 54 5a :2 19 d 10 19 1b
:2 19 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 91 94 9d a5 :2 ae :2 9d c5
:2 94 :2 2a cd d0 :2 2a d8 db :2 2a
e0 e3 :2 2a ec ef :2 2a :2 13 63
:2 10 13 :2 1d 2f :2 39 45 48 5a
5e 5f :2 5a :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a :2 13 62 :3 10 :2 1b 2f
:2 38 4e 58 :2 10 d 1f 13 1c
1f :2 1c 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 91 94 9d a5 :2 ae :2 9d
c6 :2 94 :2 2a ce d1 :2 2a d9 dc
:2 2a e1 e4 :2 2a f4 f7 :2 2a :2 13
63 :2 10 13 :2 1d 2f :2 39 45 48
5a 5e 5f :2 5a :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a :2 13 62 :3 10 :2 1b
2f :2 38 4f 18 :2 10 21 1f 1a
2f 43 13 22 2c 13 2c 4a
58 6c 13 2c 4a 58 6c 13
2c 4a 58 6c 13 2c 4a 58
6c 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :7 d 38 :2 a 7 38
d 16 19 :2 16 1f 28 34 :2 1f
37 39 :2 37 :2 d :4 40 3f :2 d 14
11 1d 13 20 31 45 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :4 61 38
:2 7 11 1f 2c 10 1d 2e 3c
4d :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5c 5d :2 58 :2 2c :3 10 :2 16 1b
27 6a 6d :2 27 7a 7d :2 27 81
84 :2 27 90 93 :2 27 9b 9e :2 27
aa ad b4 bd c0 :2 ad :2 27 :2 10
60 :2 d :2 a :4 16 :2 a 7 :3 21 a
13 1c :2 a 1f 21 :2 1f 14 20
2f 37 44 13 20 31 3e d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5f 60 :2 5b :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :4 23
:2 7 21 :3 4 12 4 :4 8 7 11
1d 2b 34 3b 48 51 6a 77
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5c 5d :2 58 :2 2c :3 10
:2 16 1b 27 6a 6d :2 27 7a 7d
:2 27 81 84 :2 27 90 93 :2 27 9b
9e :2 27 aa ad b4 bd c0 :2 ad
:2 27 :2 10 60 :2 d :2 a :4 16 :2 a 7
:3 29 a 13 1f :2 a 22 24 :2 22
14 22 2f 13 20 31 49 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :3 26 d 16 1f
:2 d 22 24 :2 22 1c 37 44 10
1d 2e 3c 4d 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :3 26 1c 36 43
54 62 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :4 26 :2 a 26 :2 7 a 13
1c :2 a 1f 21 :2 1f a 18 :2 a
1d 2d 3b 50 5c 5f :2 1d a
14 23 33 39 41 48 5f 67
6e 86 90 a1 af 12 1e 2b
35 40 4c 58 6b 77 12 29
3d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 23 e
:2 17 22 20 :2 2b :2 20 d 10 19
25 :2 10 28 2a :2 28 1a 13 2d
13 2e 13 2e 13 2d 3f 13
19 26 37 45 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :4 2c 1a 13 2d
13 2e 13 2e 13 2d 3f 13
30 42 19 26 37 45 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 99 9c :2 30 a4 a7 :2 30
b3 b6 bd c6 c9 :2 b6 :2 30 :2 19
69 :2 16 :2 13 :4 1f :2 13 10 :7 d 11
18 28 2b :2 11 2e 30 :2 2e :2 10
20 :2 10 :2 19 25 3c 4a 58 2f
3a 46 52 2f 3d 50 :2 25 10
35 :2 d 3b :2 a :4 f e d 36
:2 41 48 12 :2 36 27 29 :2 27 35
:3 d 1b d 2c :2 a 23 :2 7 29
:2 4 :4 8 :2 7 15 :2 7 1a 2a 38
4d 59 5c :2 1a 7 11 20 30
36 3e 45 5c 64 6b 83 8d
9e ac f 1b 28 32 3d 49
55 68 74 f 26 3a :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5c 5d
:2 58 :2 2c :3 10 :2 16 1b 27 6a 6d
:2 27 7a 7d :2 27 81 84 :2 27 90
93 :2 27 9b 9e :2 27 aa ad b4
bd c0 :2 ad :2 27 :2 10 60 :2 d :2 a
:4 16 :2 a 7 :3 29 a 13 1f :2 a
22 24 :2 22 14 d 28 d 28
d 28 d 29 3b d 13 20
31 3f d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :4 26 14 d 28 d 28
d 28 d 29 3b d 2a 3c
13 20 31 3f d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :7 7 b 12 22
25 :2 b 28 2a :2 28 a 34 3d
49 :2 34 4c 4e :2 4c 33 :3 a 1a
:2 a :2 13 1f 36 44 52 2f 3a
46 52 2f 3d 50 :2 1f a 51
:2 7 29 :3 4 17 21 :2 17 4 7
:2 10 19 1b :2 19 7 :2 10 1c 7
1f :2 4 7 :2 11 23 :2 2d 39 3c
4e 52 53 :2 4e :2 23 :3 7 :2 d 12
1e 61 64 :2 1e 71 74 :2 1e 78
7b :2 1e 85 88 91 99 :2 a2 :2 91
ad :2 88 :2 1e b5 b8 :2 1e c0 c3
:2 1e c8 cb :2 1e df e2 :2 1e :2 7
56 :3 4 :2 f 21 :2 2a 34 49 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 52 56 57 :2 52 :2 26 :3 a
:2 10 15 21 64 67 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 5a :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4f 53 54 :2 4f :2 23 :3 7
:2 d 12 1e 61 64 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
57 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
5293
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:a 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :5 22 :5 23
:5 24 :5 25 :7 26 :7 27
:5 28 :5 29 :5 2a :7 2b
:7 2c :5 2d :5 2e :5 2f
:5 30 :7 31 :7 32 :7 33
:7 34 :7 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :7 61 :7 62 :6 63
:6 64 :7 65 :6 66 :7 67
:7 68 :6 69 :6 6a :5 6b
:5 6c :6 6d :6 6e :6 6f
:6 70 :6 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:7 78 :7 79 :7 7a :6 7b
:e 7c :6 7d :6 7e :5 7f
:5 80 :2 82 0 :2 82
:2 83 :3 84 83 :5 82
:2 86 0 :2 86 :2 87
:6 88 89 87 :5 86
:2 8b 0 :2 8b :c 8c
:12 8d :a 8e :a 8f :6 90
:8 91 :8 92 :23 93 :2 94
8c :5 8b :7 96 :b 98
:11 99 9a :2 99 :2 9a
:2 99 :2 9a :2 99 :2 9b
:2 99 :2 9b :2 99 :2 9b
:2 99 :2 9b :2 99 :2 9c
:2 99 :2 9c :2 99 :2 9c
:2 99 :2 9c :2 99 :2 9d
:2 99 :2 9d :2 99 :2 9d
:2 99 :2 9d :2 99 :2 9e
:2 99 :2 9e :2 99 :2 9e
:2 99 :2 9e :2 99 :2 9f
:2 99 :9 9f :2 99 :2 a0
:2 99 :9 a0 :2 99 :2 a1
:2 99 :9 a1 :2 99 :2 a2
:2 99 :9 a2 :2 99 :2 a3
:2 99 :9 a3 :2 99 :2 a4
:2 99 :9 a4 :2 99 :2 a5
:2 99 :9 a5 :2 99 :2 a6
:2 99 :9 a6 :2 99 :2 a7
:2 99 :9 a7 :2 99 :2 a8
:2 99 :2 a8 :2 99 :2 a8
:2 99 :2 a8 :2 99 :2 a8
:4 99 :3 98 :11 ab :b ac
:3 ab :3 b3 :3 b4 :3 b5
:3 b6 :3 b7 :3 b8 :d b9
:d ba :2 bb :2 ba :6 bb
:3 ba :3 bc bb :2 ba
:3 bf :3 c0 :3 c2 :3 c3
:3 c5 :3 c7 :3 c8 :5 ca
:4 cc :3 cd :5 ce cd
:5 d0 cf :3 cd :5 d3
:4 d6 :5 d7 d5 d9
:5 da :3 d9 :2 db :5 dd
:11 de :24 df :3 de :2 dc
:6 db d8 :3 97 :9 e4
:11 e5 :30 e6 :3 e5 :11 e8
:b e9 :3 e8 :a eb :3 e4
:6 ef :6 f0 :3 f1 ef
:5 f2 ee f4 :5 f5
:3 f4 :2 f6 :5 f8 :11 f9
:24 fa :3 f9 :2 f7 :6 f6
f3 :3 97 :a 100 :11 101
:30 102 :3 101 :11 104 :b 105
:3 104 :a 107 :3 100 :3 10a
:2 10c 10d :2 10e 10c
:5 10f 10b 111 :5 112
:3 111 :2 113 :5 115 :11 116
:24 117 :3 116 :2 114 :6 113
110 :3 97 :9 11c :11 11d
:30 11e :3 11d :11 120 :b 121
:3 120 :a 123 :3 11c :12 127
:7 128 :c 129 127 :5 12a
126 12c :5 12d :3 12c
:2 12e :5 130 :11 131 :24 132
:3 131 :2 12f :6 12e 12b
:3 97 :a 137 :11 138 :30 139
:3 138 :11 13b :b 13c :3 13b
:a 13e :3 137 :8 142 :5 143
141 145 :5 146 :3 145
:2 147 :5 149 :11 14a :24 14b
:3 14a :2 148 :6 147 144
:3 97 :a 150 :11 151 :30 152
:3 151 :11 154 :b 155 :3 154
:a 157 :3 150 :6 15b :5 15c
15a 15e :5 15f :3 15e
:2 160 :5 162 :11 163 :24 164
:3 163 :2 161 :6 160 15d
:3 97 :b 169 :3 16a :3 169
:a 16d :11 16e :30 16f :3 16e
:11 171 :b 172 :3 171 :a 174
:3 16d :3 177 :b 184 :b 185
:b 186 :3 189 18a :7 18b
189 :5 18c 188 18e
:5 18f :3 18e :2 190 :5 192
:11 193 :24 194 :3 193 :2 191
:6 190 18d :3 97 :3 19a
19b :7 19c 19a :5 19d
199 19f :5 1a0 :3 19f
:2 1a1 :5 1a3 :11 1a4 :24 1a5
:3 1a4 :2 1a2 :6 1a1 19e
:3 97 :5 1aa :9 1ac :4 1af
:6 1b0 1af :5 1b1 1ae
1b3 :5 1b4 :3 1b3 :2 1b5
:5 1b7 :11 1b8 :24 1b9 :3 1b8
:2 1b6 :6 1b5 1b2 :3 1ac
:c 1be :3 1c0 :4 1c2 :6 1c3
1c2 :5 1c4 1c1 1c6
:5 1c7 :3 1c6 :2 1c8 :5 1ca
:11 1cb :24 1cc :3 1cb :2 1c9
:6 1c8 1c5 :3 1be :9 1d1
:11 1d2 :30 1d3 :3 1d2 :11 1d5
:b 1d6 :3 1d5 :7 1d8 1d9
:2 1d8 :3 1d1 :3 1be :3 1ac
1dd 1aa :16 1dd :2 1de
:2 1dd :4 1de :5 1dd :3 1e0
:4 1e2 :5 1e3 1e4 1e2
:5 1e5 1e1 1e7 :5 1e8
:3 1e7 :2 1e9 :5 1eb :11 1ec
:24 1ed :3 1ec :2 1ea :6 1e9
1e6 :3 1de :9 1f2 :11 1f3
:30 1f4 :3 1f3 :11 1f6 :b 1f7
:3 1f6 :7 1f9 1fa :2 1f9
:3 1f2 1de :3 1aa :3 1fe
:3 1ff :3 200 :3 201 :3 202
:3 203 :5 20b :4 20d :3 20e
:5 20f 20e :5 211 210
:3 20e :a 214 :3 215 214
:3 217 216 :3 214 :4 21b
:5 21c 21a 21e :5 21f
:3 21e :2 220 :5 222 :11 223
:24 224 :3 223 :2 221 :6 220
21d :3 97 :9 229 :9 22a
:3 22b :3 22a :3 229 :6 230
:5 231 22f 233 :5 234
:3 233 :2 235 :5 237 :11 238
:24 239 :3 238 :2 236 :6 235
232 :3 97 :4 23f 240
:2 241 :2 242 :2 243 23f
:5 244 23e 246 :5 247
:3 246 :2 248 :5 24a :11 24b
:24 24c :3 24b :2 249 :6 248
245 :3 97 :18 251 :3 252
:5 253 :4 256 257 :2 258
259 :2 25a 256 :5 25b
255 25d :5 25e :3 25d
:2 25f :5 261 :11 262 :24 263
:3 262 :2 260 :6 25f 25c
:3 251 :a 268 :f 269 268
:b 26b 26c :3 26b :5 26d
26a :3 268 :3 26f :3 270
:6 272 :3 273 :3 272 :a 275
:5 277 :6 278 :2 279 :4 27a
:6 27b :2 27c 277 :6 27d
:5 27e 27d :5 280 27f
:3 27d 276 283 :5 284
:3 283 :2 285 :5 287 :11 288
:24 289 :3 288 :2 286 :6 285
282 :3 251 :b 28e :3 28f
28e :4 292 :4 293 :4 294
292 :5 295 291 297
:5 298 :3 297 :2 299 :5 29b
:11 29c :24 29d :3 29c :2 29a
:6 299 296 :4 290 :3 28e
:9 2a3 :6 2a6 :4 2a7 2a6
:6 2a8 :5 2a9 2a8 :5 2ab
2aa :3 2a8 2a5 2ae
:5 2af :3 2ae :2 2b0 :5 2b2
:11 2b3 :24 2b4 :3 2b3 :2 2b1
:6 2b0 2ad :3 2a3 :2 2bb
:4 2bd :5 2c0 :2 2c1 :4 2c4
2bb :6 2c5 :5 2c6 2c5
:5 2c8 2c7 :3 2c5 2ba
2cb :5 2cc :3 2cb :2 2cd
:5 2cf :11 2d0 :24 2d1 :3 2d0
:2 2ce :6 2cd 2ca :4 2a3
:2 2d8 :4 2da :5 2dd :2 2de
:4 2e1 2d8 :6 2e2 :5 2e3
2e2 :5 2e5 2e4 :3 2e2
2d7 2e8 :5 2e9 :3 2e8
:2 2ea :5 2ec :11 2ed :24 2ee
:3 2ed :2 2eb :6 2ea 2e7
:4 2d5 :3 2a3 2f3 251
:a 2f3 :d 2f6 :4 2f7 2f6
:6 2f8 :5 2f9 2f8 :5 2fb
2fa :3 2f8 2f5 2fe
:5 2ff :3 2fe :2 300 :5 302
:11 303 :24 304 :3 303 :2 301
:6 300 2fd :3 2f3 :3 309
:2 30b 30c :3 30d 30b
:5 30e 30a 310 :5 311
:3 310 :2 312 :5 314 :11 315
:24 316 :3 315 :2 313 :6 312
30f :3 2f3 :a 31b :2 31d
31e :3 31f 31d :5 320
31c 322 :5 323 :3 322
:2 324 :5 326 :11 327 :24 328
:3 327 :2 325 :6 324 321
:3 31b :a 32c :3 32d :3 32c
:3 31b :c 331 :b 332 :b 333
334 :3 333 :3 336 :5 337
:2 338 336 :6 339 :5 33a
339 :5 33c 33b :3 339
335 33f :5 340 :3 33f
:2 341 :5 343 :11 344 :24 345
:3 344 :2 342 :6 341 33e
:3 332 :6 34a 34b 332
:12 34b :3 34d :6 34e :2 34f
34d :6 350 :5 351 350
:5 353 352 :3 350 34c
356 :5 357 :3 356 :2 358
:5 35a :11 35b :24 35c :3 35b
:2 359 :6 358 355 :3 34b
:6 361 362 34b 332
:12 362 :3 364 :6 365 :2 366
364 :6 367 :5 368 367
:5 36a 369 :3 367 363
36d :5 36e :3 36d :2 36f
:5 371 :11 372 :24 373 :3 372
:2 370 :6 36f 36c :3 362
:6 378 362 :3 332 :3 331
2f3 :3 251 :3 37e :5 37f
380 :b 381 :2 382 37e
:5 383 37d 385 :5 386
:3 385 :2 387 :5 389 :11 38a
:24 38b :3 38a :2 388 :6 387
384 :3 97 :a 390 :3 391
:3 390 :3 394 :3 395 :3 396
:5 398 :16 39a :7 39b :5 39c
:3 39b :9 39e :f 39f :f 3a0
:3 39e :9 3a3 :f 3a4 :f 3a5
:3 3a3 :3 39a :3 3a9 :3 3aa
:3 3ac 3ad :2 3ae 3ac
:5 3af 3ab 3b1 :5 3b2
:3 3b1 :2 3b3 :5 3b5 :11 3b6
:24 3b7 :3 3b6 :2 3b4 :6 3b3
3b0 :3 97 :3 3bd :4 3bf
3c0 :4 3c1 :3 3c2 3bf
:5 3c3 3be 3c5 :5 3c6
:3 3c5 :2 3c7 :5 3c9 :11 3ca
:24 3cb :3 3ca :2 3c8 :6 3c7
3c4 :3 97 :4 3d1 :3 3d2
3d1 :5 3d3 3d0 3d5
:5 3d6 :3 3d5 :2 3d7 :5 3d9
:11 3da :24 3db :3 3da :2 3d8
:6 3d7 3d4 :3 97 :e 3e0
:5 3e2 :3 3e3 :a 3e5 :8 3e6
:6 3e7 :8 3e8 3e9 :2 3ea
3e5 :5 3eb 3e4 3ed
:5 3ee :3 3ed :2 3ef :5 3f1
:11 3f2 :24 3f3 :3 3f2 :2 3f0
:6 3ef 3ec :3 3e2 :12 3f7
:6 3f8 :7 3f9 :4 3fa :3 3fb
:3 3f9 :3 3f7 :3 3fe :9 3ff
:14 400 :2 401 :6 400 :f 402
:11 403 :30 404 :3 403 :11 406
:b 407 :3 406 :a 409 402
:3 40b :9 40d :3 40e :3 40d
40a :3 402 401 :2 400
:3 413 :3 414 :3 415 :3 416
:3 418 :3 41a :3 41b :3 41c
:3 41d :3 3ff :a 420 :3 422
:3 423 :5 425 :a 426 :6 427
:7 428 :4 429 :3 42a :3 428
:3 426 :7 42e :6 42f :5 430
:6 431 432 :2 433 42e
:5 434 42d 436 :5 437
:3 436 :2 438 :5 43a :11 43b
:24 43c :3 43b :2 439 :6 438
435 :3 425 :a 441 :14 443
:2 444 :6 443 :11 446 :30 447
:3 446 :11 449 :b 44a :3 449
:a 44c 444 :2 443 :12 44f
:9 450 :3 452 :3 453 :9 455
:9 456 :3 458 459 :2 45a
:4 45b 458 :5 45c 457
45e :5 45f :3 45e :2 460
:5 462 :11 463 :24 464 :3 463
:2 461 :6 460 45d :4 456
:3 46a 46b :4 46c 46a
:5 46d 469 46f :5 470
:3 46f :2 471 :5 473 :11 474
:24 475 :3 474 :2 472 :6 471
46e :4 468 :3 456 :3 455
:9 47c :3 47e :4 47f 47e
:6 480 :5 481 480 :5 483
482 :3 480 47d 486
:5 487 :3 486 :2 488 :5 48a
:11 48b :24 48c :3 48b :2 489
:6 488 485 :4 47c :6 492
:6 493 :5 494 493 :5 496
495 :3 493 491 499
:5 49a :3 499 :2 49b :5 49d
:11 49e :24 49f :3 49e :2 49c
:6 49b 498 :3 490 :4 4a5
:6 4a6 :5 4a7 4a6 :5 4a9
4a8 :3 4a6 4a4 4ac
:5 4ad :3 4ac :2 4ae :5 4b0
:11 4b1 :24 4b2 :3 4b1 :2 4af
:6 4ae 4ab :3 490 :4 4b8
:6 4b9 :5 4ba 4b9 :5 4bc
4bb :3 4b9 4b7 4bf
:5 4c0 :3 4bf :2 4c1 :5 4c3
:11 4c4 :24 4c5 :3 4c4 :2 4c2
:6 4c1 4be :3 490 :6 4cb
:6 4cc :5 4cd 4cc :5 4cf
4ce :3 4cc 4ca 4d2
:5 4d3 :3 4d2 :2 4d4 :5 4d6
:11 4d7 :24 4d8 :3 4d7 :2 4d5
:6 4d4 4d1 :4 490 :3 47c
:3 450 :3 441 4e3 425
:17 4e3 :11 4e4 :30 4e5 :3 4e4
:11 4e7 :b 4e8 :3 4e7 :7 4ea
4eb :2 4ea 4e3 :3 425
:5 4ee :3 4ef :16 4f0 :9 4f1
:3 4f3 :3 4f4 :2 4f5 :2 4f6
:2 4f7 :2 4f8 :4 4f9 :4 4fa
:6 4fb :2 4fc 4f3 :6 4fd
:5 4fe 4fd :5 500 4ff
:3 4fd 4f2 503 :5 504
:3 503 :2 505 :5 507 :11 508
:24 509 :3 508 :2 506 :6 505
502 :4 4f1 :3 50f :3 510
:2 511 :2 512 :2 513 :2 514
:4 515 :4 516 :4 517 :6 518
:2 519 50f :6 51a :5 51b
51a :5 51d 51c :3 51a
50e 520 :5 521 :3 520
:2 522 :5 524 :11 525 :24 526
:3 525 :2 523 :6 522 51f
:4 50d :3 4f1 52b 4f0
:9 52b :3 52d :3 52e :2 52f
:2 530 :4 531 :4 532 :6 533
:2 534 52d :6 535 :5 536
535 :5 538 537 :3 535
52c 53b :5 53c :3 53b
:2 53d :5 53f :11 540 :24 541
:3 540 :2 53e :6 53d 53a
:3 52b 545 52b 4f0
:9 545 :9 546 :3 548 :3 549
:2 54a :2 54b :4 54c :6 54d
:2 54e 548 :6 54f :5 550
54f :5 552 551 :3 54f
547 555 :5 556 :3 555
:2 557 :5 559 :11 55a :24 55b
:3 55a :2 558 :6 557 554
:4 546 :3 561 :3 562 :2 563
:2 564 :4 565 :4 566 :6 567
:2 568 561 :6 569 :5 56a
569 :5 56c 56b :3 569
560 56f :5 570 :3 56f
:2 571 :5 573 :11 574 :24 575
:3 574 :2 572 :6 571 56e
:4 55f :3 546 545 4f0
:3 57c :4 57d :3 57e :2 57f
57c :6 580 :5 581 580
:5 583 582 :3 580 57b
586 :5 587 :3 586 :2 588
:5 58a :11 58b :24 58c :3 58b
:2 589 :6 588 585 :4 57a
:3 4f0 :6 593 :6 594 :5 595
594 :5 597 596 :3 594
592 59a :5 59b :3 59a
:2 59c :5 59e :11 59f :24 5a0
:3 59f :2 59d :6 59c 599
:3 4ee :4 5a6 :6 5a7 :5 5a8
5a7 :5 5aa 5a9 :3 5a7
5a5 5ad :5 5ae :3 5ad
:2 5af :5 5b1 :11 5b2 :24 5b3
:3 5b2 :2 5b0 :6 5af 5ac
:3 4ee :6 5b9 :6 5ba :5 5bb
5ba :5 5bd 5bc :3 5ba
5b8 5c0 :5 5c1 :3 5c0
:2 5c2 :5 5c4 :11 5c5 :24 5c6
:3 5c5 :2 5c3 :6 5c2 5bf
:6 4ee :5 5cc :9 5cd :5 5ce
5cd :f 5d0 5cf :3 5cd
:3 5d3 :9 5d5 :d 5d6 :7 5d7
:3 5d6 :3 5da :3 5db :b 5dc
:3 5dd 5dc :3 5df 5de
:3 5dc :9 5e2 :3 5e3 :3 5e2
:e 5e6 :b 5e7 :2 5e8 :2 5e7
:a 5e8 :8 5e9 :3 5e6 :b 5eb
:11 5ec :20 5ed :3 5ec :11 5ef
:b 5f0 :3 5ef :9 5f2 5f3
5eb :9 5f3 :11 5f4 :2e 5f5
:3 5f4 :11 5f7 :b 5f8 :3 5f7
:c 5fa 5f3 :3 5eb :3 5fe
:7 5ff :6 600 :7 601 :6 602
:9 603 :3 5ff :5 605 :11 606
:30 607 :3 606 :11 609 :b 60a
:3 609 :a 60c 60d 605
:5 60d :11 60e :30 60f :3 60e
:11 611 :b 612 :3 611 :7 614
615 :2 614 60d 605
:3 617 :a 618 :5 619 :3 618
616 :3 605 :3 5d5 :3 5cc
:5 61d :3 61f 620 :4 621
61f :5 622 61e 624
:5 625 :3 624 :2 626 :5 628
:11 629 :24 62a :3 629 :2 627
:6 626 623 :6 420 :3 3e2
:3 631 :3 3e0 :c 634 :3 635
:3 636 :6 63a :5 63b 639
63d :5 63e :3 63d :2 63f
:5 641 :11 642 :24 643 :3 642
:2 640 :6 63f 63c :3 97
:3 648 :3 649 :3 64a :3 658
:5 65c 65e :7 65f :5 660
:5 661 :5 662 :3 65f :3 663
:5 664 663 :5 666 665
:3 663 :a 669 :2 66a :3 669
:3 66c :9 66e :7 66f :4 672
:6 673 :5 674 673 :5 676
675 :3 673 671 679
:5 67a :3 679 :2 67b :5 67d
:11 67e :24 67f :3 67e :2 67c
:6 67b 678 :3 66e :4 685
:6 686 :5 687 686 :5 689
688 :3 686 684 68c
:5 68d :3 68c :2 68e :5 690
:11 691 :24 692 :3 691 :2 68f
:6 68e 68b :3 66e :4 698
:6 699 :5 69a 699 :5 69c
69b :3 699 697 69f
:5 6a0 :3 69f :2 6a1 :5 6a3
:11 6a4 :24 6a5 :3 6a4 :2 6a2
:6 6a1 69e :3 66e :6 6ab
:6 6ac :5 6ad 6ac :5 6af
6ae :3 6ac 6aa 6b2
:5 6b3 :3 6b2 :2 6b4 :5 6b6
:11 6b7 :24 6b8 :3 6b7 :2 6b5
:6 6b4 6b1 :3 66e :4 6be
:6 6bf :5 6c0 6bf :5 6c2
6c1 :3 6bf 6bd 6c5
:5 6c6 :3 6c5 :2 6c7 :5 6c9
:11 6ca :24 6cb :3 6ca :2 6c8
:6 6c7 6c4 :3 66e :4 6d1
:6 6d2 :5 6d3 6d2 :5 6d5
6d4 :3 6d2 6d0 6d8
:5 6d9 :3 6d8 :2 6da :5 6dc
:11 6dd :24 6de :3 6dd :2 6db
:6 6da 6d7 :4 66e :9 6e3
:3 6e4 :3 6e3 :3 6e7 :2 6e8
:2 6e9 :2 6ea 6e7 :6 6eb
:5 6ec 6eb :5 6ee 6ed
:3 6eb 6e6 6f1 :5 6f2
:3 6f1 :2 6f3 :5 6f5 :11 6f6
:24 6f7 :3 6f6 :2 6f4 :6 6f3
6f0 :3 6e2 :6 6fc :9 6fd
:3 6fe :2 6ff :3 6fd :4 702
703 :6 704 705 702
:5 706 701 708 :5 709
:3 708 :2 70a :5 70c :11 70d
:24 70e :3 70d :2 70b :6 70a
707 :3 6e2 :a 713 :3 714
:6 718 719 :5 71a 718
:5 71b 717 71d :5 71e
:3 71d :2 71f :5 721 :11 722
:24 723 :3 722 :2 720 :6 71f
71c :3 713 :a 728 :12 729
:3 72a 72c :2 72d :2 72e
72f :2 730 72c :6 731
:5 732 731 :5 734 733
:3 731 72b 737 :5 738
:3 737 :2 739 :5 73b :11 73c
:24 73d :3 73c :2 73a :6 739
736 :3 729 741 729
:b 741 :b 742 743 :3 742
746 :3 747 :2 748 :2 749
:2 74a 74b :2 74c 746
:6 74d :5 74e 74d :5 750
74f :3 74d 745 753
:5 754 :3 753 :2 755 :5 757
:11 758 :24 759 :3 758 :2 756
:6 755 752 :4 741 729
75f :6 760 :2 761 :2 762
:2 763 764 :2 765 75f
:6 766 :5 767 766 :5 769
768 :3 766 75e 76c
:5 76d :3 76c :2 76e :5 770
:11 771 :24 772 :3 771 :2 76f
:6 76e 76b :4 75d :3 729
:16 778 :4 77a :6 77b :5 77c
77b :5 77e 77d :3 77b
779 781 :5 782 :3 781
:2 783 :5 785 :11 786 :24 787
:3 786 :2 784 :6 783 780
:6 778 728 :8 78e :6 78f
:9 790 :4 791 :7 792 78e
:5 793 78d 795 :5 796
:3 795 :2 797 :5 799 :11 79a
:24 79b :3 79a :2 798 :6 797
794 :3 78c :12 7a0 :b 7a1
7a2 :3 7a1 :4 7a5 :6 7a6
:5 7a7 7a6 :5 7a9 7a8
:3 7a6 7a4 7ac :5 7ad
:3 7ac :2 7ae :5 7b0 :11 7b1
:24 7b2 :3 7b1 :2 7af :6 7ae
7ab :3 7a0 :4 7b8 :5 7b9
:2 7ba 7b8 :6 7bb :5 7bc
7bb :5 7be 7bd :3 7bb
7b7 7c1 :5 7c2 :3 7c1
:2 7c3 :5 7c5 :11 7c6 :24 7c7
:3 7c6 :2 7c4 :6 7c3 7c0
:3 7a0 :6 7cd :2 7ce 7cd
:6 7cf :5 7d0 7cf :5 7d2
7d1 :3 7cf 7cc 7d5
:5 7d6 :3 7d5 :2 7d7 :5 7d9
:11 7da :24 7db :3 7da :2 7d8
:6 7d7 7d4 :4 7a0 :6 7e1
:2 7e2 7e1 :6 7e3 :5 7e4
7e3 :5 7e6 7e5 :3 7e3
7e0 7e9 :5 7ea :3 7e9
:2 7eb :5 7ed :11 7ee :24 7ef
:3 7ee :2 7ec :6 7eb 7e8
:3 7df :4 7f5 :2 7f6 7f5
:6 7f7 :5 7f8 7f7 :5 7fa
7f9 :3 7f7 7f4 7fd
:5 7fe :3 7fd :2 7ff :5 801
:11 802 :24 803 :3 802 :2 800
:6 7ff 7fc :4 7df :3 7a0
78c :3 728 :6 80b :6 80c
:5 80d 80c :5 80f 80e
:3 80c 80a 812 :5 813
:3 812 :2 814 :5 816 :11 817
:24 818 :3 817 :2 815 :6 814
811 :4 713 :3 81e :4 822
:6 823 :5 824 823 :5 826
825 :3 823 821 829
:5 82a :3 829 :2 82b :5 82d
:11 82e :24 82f :3 82e :2 82c
:6 82b 828 :3 81c :4 835
:6 836 :5 837 836 :5 839
838 :3 836 834 83c
:5 83d :3 83c :2 83e :5 840
:11 841 :24 842 :3 841 :2 83f
:6 83e 83b :3 81c :6 847
:6 848 :5 849 848 :5 84b
84a :3 848 846 84e
:5 84f :3 84e :2 850 :5 852
:11 853 :24 854 :3 853 :2 851
:6 850 84d :3 81c :a 859
:3 85b :3 859 :3 85e 81c
:3 713 :9 861 :12 862 :3 864
:4 865 864 :5 866 863
868 :5 869 :3 868 :2 86a
:5 86c :11 86d :24 86e :3 86d
:2 86b :6 86a 867 :3 862
:16 873 :6 875 :6 876 :5 877
876 :5 879 878 :3 876
874 87c :5 87d :3 87c
:2 87e :5 880 :11 881 :24 882
:3 881 :2 87f :6 87e 87b
:3 873 886 873 :16 886
:4 888 :5 889 887 88b
:5 88c :3 88b :2 88d :5 88f
:11 890 :24 891 :3 890 :2 88e
:6 88d 88a :3 886 :11 896
:30 897 :3 896 :11 899 :b 89a
:3 899 :7 89c 89d :2 89c
886 :3 873 :3 862 :c 8a1
:2 8a2 :2 8a1 :6 8a2 :2 8a1
:5 8a4 :5 8a5 :14 8a7 8a9
:4 8aa :b 8ab 8a9 :6 8ac
:5 8ad 8ac :5 8af 8ae
:3 8ac 8a8 8b2 :5 8b3
:3 8b2 :2 8b4 :5 8b6 :11 8b7
:24 8b8 :3 8b7 :2 8b5 :6 8b4
8b1 :4 8a7 :3 8be :4 8bf
:b 8c0 :6 8c1 :4 8c2 8be
:6 8c3 :5 8c4 8c3 :5 8c6
8c5 :3 8c3 8bd 8c9
:5 8ca :3 8c9 :2 8cb :5 8cd
:11 8ce :24 8cf :3 8ce :2 8cc
:6 8cb 8c8 :4 8bc :3 8a7
:a 8d5 :3 8d6 :6 8d8 8d9
8d8 :5 8da 8d7 8dc
:5 8dd :3 8dc :2 8de :5 8e0
:11 8e1 :24 8e2 :3 8e1 :2 8df
:6 8de 8db :3 8d5 :9 8e7
:2 8e8 8e7 8eb :4 8ec
8eb :6 8ed :5 8ee 8ed
:5 8f0 8ef :3 8ed 8ea
8f3 :5 8f4 :3 8f3 :2 8f5
:5 8f7 :11 8f8 :24 8f9 :3 8f8
:2 8f6 :6 8f5 8f2 :3 8e9
:1d 8fe :4 901 902 :4 903
901 :5 904 900 906
:5 907 :3 906 :2 908 :5 90a
:11 90b :24 90c :3 90b :2 909
:6 908 905 :3 8e9 :d 911
:b 912 :3 911 916 917
918 919 91a 91b
91c 91d 91e 91f
920 922 923 924
925 927 928 :3 929
92b 92c 916 :6 92d
:5 92e 92d :5 930 92f
:3 92d 915 933 :5 934
:3 933 :2 935 :5 937 :11 938
:24 939 :3 938 :2 936 :6 935
932 :4 8e9 :3 8e7 :4 940
:3 941 :4 942 :4 943 :4 944
:4 945 :6 946 :2 947 940
:6 948 :5 949 948 :5 94b
94a :3 948 93f 94e
:5 94f :3 94e :2 950 :5 952
:11 953 :24 954 :3 953 :2 951
:6 950 94d :3 8d5 :16 959
:2 95a :5 959 :f 95c :6 95d
:2 95e :2 95d :5 95e :3 95d
8d5 :2 960 95f :3 8d5
8a2 :3 963 :5 965 :9 967
:3 968 :15 969 :2 96a :2 969
:4 96a :2 969 :3 96b :7 96c
96a :2 969 970 :9 971
:2 972 970 :6 973 :5 974
973 :5 976 975 :3 973
96f 979 :5 97a :3 979
:2 97b :5 97d :11 97e :24 97f
:3 97e :2 97c :6 97b 978
:4 967 :3 984 :3 985 :3 986
:3 987 :3 989 :3 98b :3 98c
:3 98d :3 98e :12 990 :2 991
:2 990 :9 991 :2 992 :2 991
:8 992 :5 990 :9 993 995
:4 996 :2 997 :4 998 :4 999
:4 99a :4 99b :4 99c :2 99d
:6 99e :2 99f 995 :6 9a0
:5 9a1 9a0 :5 9a3 9a2
:3 9a0 994 9a6 :5 9a7
:3 9a6 :2 9a8 :5 9aa :11 9ab
:24 9ac :3 9ab :2 9a9 :6 9a8
9a5 :4 993 9b2 :4 9b3
:2 9b4 :4 9b5 :4 9b6 :4 9b7
:4 9b8 :4 9b9 :2 9ba :2 9bb
:6 9bc :2 9bd 9b2 :6 9be
:5 9bf 9be :5 9c1 9c0
:3 9be 9b1 9c4 :5 9c5
:3 9c4 :2 9c6 :5 9c8 :11 9c9
:24 9ca :3 9c9 :2 9c7 :6 9c6
9c3 :4 9b0 :3 993 992
9d1 :4 9d2 :2 9d3 :4 9d4
:4 9d5 :4 9d6 :4 9d7 :8 9d8
:2 9d9 9d1 :6 9da :5 9db
9da :5 9dd 9dc :3 9da
9d0 9e0 :5 9e1 :3 9e0
:2 9e2 :5 9e4 :11 9e5 :24 9e6
:3 9e5 :2 9e3 :6 9e2 9df
:4 9cf :3 990 :16 9ec :3 9ed
9ee 9ec :9 9ee :7 9ef
9ee :3 9ec 983 :3 967
:e 9f3 :b 9f4 :2 9f5 :2 9f4
:a 9f5 :8 9f6 :3 9f3 :b 9f8
:4 9fa :5 9fb 9f9 9fd
:5 9fe :3 9fd :2 9ff :5 a01
:11 a02 :24 a03 :3 a02 :2 a00
:6 9ff 9fc :3 9f8 :11 a08
:20 a09 :3 a08 :11 a0b :b a0c
:3 a0b :9 a0e a0f 9f8
:9 a0f :4 a11 :5 a12 a10
a14 :5 a15 :3 a14 :2 a16
:5 a18 :11 a19 :24 a1a :3 a19
:2 a17 :6 a16 a13 :3 a0f
:11 a1f :2e a20 :3 a1f :11 a22
:b a23 :3 a22 :c a25 a0f
:3 9f8 965 :15 a2b :2 a2c
:2 a2b :4 a2c :2 a2b :3 a2d
:7 a2e a2c :2 a2b :1a a31
:7 a32 a31 :12 a34 a33
:3 a31 :9 a37 :b a38 a37
:11 a3a a39 :3 a37 :9 a3d
a3f :9 a40 :2 a41 a3f
:6 a42 :5 a43 a42 :5 a45
a44 :3 a42 a3e a48
:5 a49 :3 a48 :2 a4a :5 a4c
:11 a4d :24 a4e :3 a4d :2 a4b
:6 a4a a47 :4 a3d a54
:4 a55 :2 a56 :4 a57 :4 a58
:4 a59 :4 a5a :8 a5b :2 a5c
a54 :6 a5d :5 a5e a5d
:5 a60 a5f :3 a5d a53
a63 :5 a64 :3 a63 :2 a65
:5 a67 :11 a68 :24 a69 :3 a68
:2 a66 :6 a65 a62 :4 a52
:3 a3d a27 :3 965 :3 a70
:b a72 :3 a73 a72 :3 a75
a74 :3 a72 :9 a78 :5 a79
a78 :f a7b a7a :3 a78
:3 a7e :9 a82 :9 a83 :1c a84
:d a85 :7 a86 :1b a87 :3 a85
a89 a83 :d a89 :7 a8a
a89 :3 a83 :3 a82 :7 a8f
:6 a90 :7 a91 :6 a92 :9 a93
:3 a8f :5 a97 :4 a99 :5 a9a
a98 a9c :5 a9d :3 a9c
:2 a9e :5 aa0 :11 aa1 :24 aa2
:3 aa1 :2 a9f :6 a9e a9b
:3 a97 :11 aa7 :30 aa8 :3 aa7
:11 aaa :b aab :3 aaa :a aad
aae a97 :5 aae :4 ab0
:5 ab1 aaf ab3 :5 ab4
:3 ab3 :2 ab5 :5 ab7 :11 ab8
:24 ab9 :3 ab8 :2 ab6 :6 ab5
ab2 :3 aae :11 abe :30 abf
:3 abe :11 ac1 :b ac2 :3 ac1
:7 ac4 ac5 :2 ac4 aae
:3 a97 962 :3 8a1 :8 acf
:6 ad0 :5 ad1 ad0 :5 ad3
ad2 :3 ad0 ace ad6
:5 ad7 :3 ad6 :2 ad8 :5 ada
:11 adb :24 adc :3 adb :2 ad9
:6 ad8 ad5 :3 861 ae3
:b ae4 :c ae5 ae3 :6 ae6
:5 ae7 ae6 :5 ae9 ae8
:3 ae6 ae2 aec :5 aed
:3 aec :2 aee :5 af0 :11 af1
:24 af2 :3 af1 :2 aef :6 aee
aeb :3 861 af9 :7 afa
:3 afb af9 :6 afc :5 afd
afc :5 aff afe :3 afc
af8 b02 :5 b03 :3 b02
:2 b04 :5 b06 :11 b07 :24 b08
:3 b07 :2 b05 :6 b04 b01
:3 861 b0e :7 b0f :3 b10
b0e :6 b11 :5 b12 b11
:5 b14 b13 :3 b11 b0d
b17 :5 b18 :3 b17 :2 b19
:5 b1b :11 b1c :24 b1d :3 b1c
:2 b1a :6 b19 b16 :3 861
:b b22 :f b23 :3 b25 :8 b26
:3 b28 :8 b29 :3 b2c :4 b2d
b2c :6 b2e :5 b2f b2e
:5 b31 b30 :3 b2e b2b
b34 :5 b35 :3 b34 :2 b36
:5 b38 :11 b39 :24 b3a :3 b39
:2 b37 :6 b36 b33 :3 861
:16 b40 :3 b42 :2 b43 :2 b44
:2 b45 :2 b46 :4 b47 :2 b48
b42 :6 b49 :5 b4a b49
:5 b4c b4b :3 b49 b41
b4f :5 b50 :3 b4f :2 b51
:5 b53 :11 b54 :24 b55 :3 b54
:2 b52 :6 b51 b4e :3 b40
b59 b40 :9 b59 :3 b5b
:2 b5c :2 b5d :4 b5e :2 b5f
b5b :6 b60 :5 b61 b60
:5 b63 b62 :3 b60 b5a
b66 :5 b67 :3 b66 :2 b68
:5 b6a :11 b6b :24 b6c :3 b6b
:2 b69 :6 b68 b65 :3 b59
:7 b71 b72 b59 b40
:9 b72 :3 b74 :2 b75 :2 b76
:4 b77 :2 b78 b74 :6 b79
:5 b7a b79 :5 b7c b7b
:3 b79 b73 b7f :5 b80
:3 b7f :2 b81 :5 b83 :11 b84
:24 b85 :3 b84 :2 b82 :6 b81
b7e :3 b72 :7 b8a b72
b40 :3 b8d :4 b8e :2 b8f
b8d :6 b90 :5 b91 b90
:5 b93 b92 :3 b90 b8c
b96 :5 b97 :3 b96 :2 b98
:5 b9a :11 b9b :24 b9c :3 b9b
:2 b99 :6 b98 b95 :3 b8b
:7 ba1 :7 ba2 b8b :3 b40
:3 861 6e2 :3 66e :a ba7
ba8 ba9 :3 65e baa
97 :4 bae :5 baf bad
bb1 :5 bb2 :3 bb1 :2 bb3
:5 bb5 :11 bb6 :24 bb7 :3 bb6
:2 bb4 :6 bb3 bb0 :3 97
:3 bbd :9 bbe :3 bbf :d bc2
:f bc3 :16 bc5 :6 bc6 :2 bc5
:3 bc7 :3 bc8 :3 bc9 :3 bcb
:3 bcd :3 bce :3 bcf :3 bd0
:16 bd2 :3 bd3 bd4 bd2
:9 bd4 :7 bd5 bd4 :3 bd2
:e bd8 :b bd9 :2 bda :2 bd9
:a bda :8 bdb :3 bd8 :b bdd
:11 bde :20 bdf :3 bde :11 be1
:b be2 :3 be1 :9 be4 be5
bdd :9 be5 :11 be6 :2e be7
:3 be6 :11 be9 :b bea :3 be9
:c bec be5 :3 bdd :5 bf0
:5 bf1 :4 bf4 bf5 :4 bf6
bf7 bf4 :6 bf8 :5 bf9
bf8 :5 bfb bfa :3 bf8
bf3 bfe :5 bff :3 bfe
:2 c00 :5 c02 :11 c03 :24 c04
:3 c03 :2 c01 :6 c00 bfd
:3 bc6 :3 c09 :3 c0a :3 c0b
:3 c0c :3 c0d :9 c0f :f c10
:3 c11 c0f :3 c13 c12
:3 c0f :3 c17 :7 c18 :6 c19
:7 c1a :6 c1b :9 c1c :3 c18
:5 c20 :11 c21 :30 c22 :3 c21
:11 c24 :b c25 :3 c24 :a c27
c28 c20 :5 c28 :11 c29
:30 c2a :3 c29 :11 c2c :b c2d
:3 c2c :7 c2f c30 :2 c2f
c28 c20 :3 c33 :3 c34
:5 c35 :5 c36 :5 c37 :5 c38
:2 c39 c33 :6 c3a :5 c3b
c3a :5 c3d c3c :3 c3a
c32 c40 :5 c41 :3 c40
:2 c42 :5 c44 :11 c45 :24 c46
:3 c45 :2 c43 :6 c42 c3f
:4 c31 :3 c20 bc6 :2 bc5
c4c bc2 :17 c4c c4e
:2 c4f :4 c50 c4e :6 c51
:5 c52 c51 :5 c54 c53
:3 c51 c4d c57 :5 c58
:3 c57 :2 c59 :5 c5b :11 c5c
:24 c5d :3 c5c :2 c5a :6 c59
c56 :4 c4c :3 bc2 :3 c64
:5 c65 c64 :5 c66 c63
c68 :5 c69 :3 c68 :2 c6a
:5 c6c :11 c6d :24 c6e :3 c6d
:2 c6b :6 c6a c67 :3 bbe
:9 c74 :5 c76 :4 c77 c76
:6 c78 :5 c79 c78 :5 c7b
c7a :3 c78 c75 c7e
:5 c7f :3 c7e :2 c80 :5 c82
:11 c83 :24 c84 :3 c83 :2 c81
:6 c80 c7d :6 c74 :3 bbe
:3 c8b :5 c8e :a c90 :6 c91
:5 c92 c91 :5 c94 c93
:3 c91 c8f c97 :5 c98
:3 c97 :2 c99 :5 c9b :11 c9c
:24 c9d :3 c9c :2 c9a :6 c99
c96 :3 c8e :9 ca3 :3 ca5
:4 ca6 ca5 :5 ca7 ca4
ca9 :5 caa :3 ca9 :2 cab
:5 cad :11 cae :24 caf :3 cae
:2 cac :6 cab ca8 :3 ca3
:9 cb5 :3 cb7 :5 cb8 cb7
:6 cb9 :5 cba cb9 :5 cbc
cbb :3 cb9 cb6 cbf
:5 cc0 :3 cbf :2 cc1 :5 cc3
:11 cc4 :24 cc5 :3 cc4 :2 cc2
:6 cc1 cbe :3 cb5 :6 ccb
:6 ccc :5 ccd ccc :5 ccf
cce :3 ccc cca cd2
:5 cd3 :3 cd2 :2 cd4 :5 cd6
:11 cd7 :24 cd8 :3 cd7 :2 cd5
:6 cd4 cd1 :6 cb5 :3 ca3
:9 cdf :3 ce1 :a ce2 :d ce5
:9 ce6 :3 ce7 ce5 :5 ce8
ce4 cea :5 ceb :3 cea
:2 cec :5 cee :11 cef :24 cf0
:3 cef :2 ced :6 cec ce9
:3 cdf :a cf4 :9 cf5 cf7
:2 cf8 :2 cf9 :2 cfa :3 cfb
cfc :4 cfd cf7 :6 cfe
:5 cff cfe :5 d01 d00
:3 cfe cf6 d04 :5 d05
:3 d04 :2 d06 :5 d08 :11 d09
:24 d0a :3 d09 :2 d07 :6 d06
d03 :4 cf5 d10 :2 d11
:2 d12 :2 d13 :3 d14 :3 d15
:4 d16 d10 :6 d17 :5 d18
d17 :5 d1a d19 :3 d17
d0f d1d :5 d1e :3 d1d
:2 d1f :5 d21 :11 d22 :24 d23
:3 d22 :2 d20 :6 d1f d1c
:4 d0e :3 cf5 :b d2a :3 d2b
:7 d2c :4 d2d :3 d2e :3 d2c
:3 d2a :3 cf4 :a d32 d33
:2 d32 :4 d33 :3 d32 :3 d34
d33 :2 d32 :3 cdf :3 c8e
:5 d39 :3 d3b :a d3c :d d3f
:9 d40 :3 d41 d3f :5 d42
d3e d44 :5 d45 :3 d44
:2 d46 :5 d48 :11 d49 :24 d4a
:3 d49 :2 d47 :6 d46 d43
:3 d39 :9 d50 d52 :2 d53
:2 d54 :2 d55 :3 d56 d57
:4 d58 d52 :6 d59 :5 d5a
d59 :5 d5c d5b :3 d59
d51 d5f :5 d60 :3 d5f
:2 d61 :5 d63 :11 d64 :24 d65
:3 d64 :2 d62 :6 d61 d5e
:4 d50 d6b :2 d6c :2 d6d
:2 d6e :3 d6f :3 d70 :4 d71
d6b :6 d72 :5 d73 d72
:5 d75 d74 :3 d72 d6a
d78 :5 d79 :3 d78 :2 d7a
:5 d7c :11 d7d :24 d7e :3 d7d
:2 d7b :6 d7a d77 :4 d69
:3 d50 :17 d84 :3 d85 :7 d86
:4 d87 :3 d88 :3 d86 :3 d84
:3 d39 :6 d8c :7 d8f :5 d90
:3 d8f :11 d94 :30 d95 :3 d94
:a d97 97 :3 d9a :11 d9b
:b d9c :17 d9d :3 d9b :2 d9f
:3 da0 :3 da1 da2 da0
d9f da0 :3 da3 :3 d9a
:2 da4 :5 da6 :11 da7 :b da8
:18 da9 :3 da7 :2 dab dac
:3 dad dae dac dab
dac :3 daf :2 da5 :6 da4
d99 :7 1 
12076
4
:3 0 1 :3 0 2
:a 0 528e 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 9 :7 0 19
18 :3 0 a :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 a :3 0 c
:7 0 21 20 :3 0
a :3 0 d :7 0
25 24 :3 0 19
ee 0 17 a
:3 0 e :7 0 29
28 :3 0 a :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b a :3 0 10
:7 0 31 30 :3 0
a :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f a :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 528e 2 44
:2 0 1d :2 0 33
18 :3 0 19 :2 0
31 47 49 2
:5 0 1a :3 0 1b
:3 0 4b 4c 0
4f 4a 4d 528c
0 17 :6 0 1d
:2 0 37 4 :3 0
35 51 53 :6 0
56 54 0 528c
0 1c :6 0 1d
:2 0 3b 4 :3 0
39 58 5a :6 0
5d 5b 0 528c
0 1e :6 0 1d
:2 0 3f 4 :3 0
3d 5f 61 :6 0
64 62 0 528c
0 1f :6 0 1d
:2 0 43 4 :3 0
41 66 68 :6 0
6b 69 0 528c
0 20 :6 0 1d
:2 0 47 4 :3 0
45 6d 6f :6 0
72 70 0 528c
0 21 :6 0 1d
:2 0 4b 4 :3 0
49 74 76 :6 0
79 77 0 528c
0 22 :6 0 1d
:2 0 4f 4 :3 0
4d 7b 7d :6 0
80 7e 0 528c
0 23 :6 0 1d
:2 0 53 4 :3 0
51 82 84 :6 0
87 85 0 528c
0 24 :6 0 1d
:2 0 57 4 :3 0
55 89 8b :6 0
8e 8c 0 528c
0 25 :6 0 1d
:2 0 5b 4 :3 0
59 90 92 :6 0
95 93 0 528c
0 26 :6 0 1d
:2 0 5f 4 :3 0
5d 97 99 :6 0
9c 9a 0 528c
0 27 :6 0 1d
:2 0 63 4 :3 0
61 9e a0 :6 0
a3 a1 0 528c
0 28 :6 0 69
2f5 0 67 4
:3 0 65 a5 a7
:6 0 aa a8 0
528c 0 29 :6 0
6d 329 0 6b
2b :3 0 ac :7 0
af ad 0 528c
0 2a :6 0 2b
:3 0 b1 :7 0 b4
b2 0 528c 0
2c :6 0 30 :2 0
6f 2b :3 0 b6
:7 0 b9 b7 0
528c 0 2d :6 0
2b :3 0 bb :7 0
be bc 0 528c
0 2e :6 0 30
:2 0 73 4 :3 0
71 c0 c2 :6 0
c5 c3 0 528c
0 2f :6 0 79
397 0 77 4
:3 0 75 c7 c9
:6 0 cc ca 0
528c 0 31 :6 0
7d 3cb 0 7b
33 :3 0 ce :7 0
d1 cf 0 528c
0 32 :6 0 33
:3 0 d3 :7 0 d6
d4 0 528c 0
34 :6 0 38 :2 0
81 33 :3 0 d8
:7 0 db d9 0
528c 0 35 :6 0
4 :3 0 30 :2 0
7f dd df :6 0
e2 e0 0 528c
0 36 :6 0 87
420 0 85 4
:3 0 83 e4 e6
:6 0 e9 e7 0
528c 0 37 :6 0
8b 454 0 89
2b :3 0 eb :7 0
ee ec 0 528c
0 39 :6 0 2b
:3 0 f0 :7 0 f3
f1 0 528c 0
3a :6 0 1d :2 0
8d 2b :3 0 f5
:7 0 f8 f6 0
528c 0 3b :6 0
2b :3 0 fa :7 0
fd fb 0 528c
0 3c :6 0 3f
:2 0 91 4 :3 0
8f ff 101 :6 0
104 102 0 528c
0 3d :6 0 3f
:2 0 95 4 :3 0
93 106 108 :6 0
10b 109 0 528c
0 3e :6 0 3f
:2 0 99 4 :3 0
97 10d 10f :6 0
112 110 0 528c
0 40 :6 0 43
:2 0 9d 4 :3 0
9b 114 116 :6 0
119 117 0 528c
0 41 :6 0 45
:2 0 a1 4 :3 0
9f 11b 11d :6 0
120 11e 0 528c
0 42 :6 0 45
:2 0 a3 a :3 0
122 :7 0 126 123
124 528c 0 44
:6 0 45 :2 0 a5
a :3 0 128 :7 0
12c 129 12a 528c
0 46 :6 0 45
:2 0 a7 a :3 0
12e :7 0 132 12f
130 528c 0 47
:6 0 45 :2 0 a9
a :3 0 134 :7 0
138 135 136 528c
0 48 :6 0 45
:2 0 ab a :3 0
13a :7 0 13e 13b
13c 528c 0 49
:6 0 45 :2 0 ad
a :3 0 140 :7 0
144 141 142 528c
0 4a :6 0 45
:2 0 af a :3 0
146 :7 0 14a 147
148 528c 0 4b
:6 0 45 :2 0 b1
a :3 0 14c :7 0
150 14d 14e 528c
0 4c :6 0 45
:2 0 b3 a :3 0
152 :7 0 156 153
154 528c 0 4d
:6 0 45 :2 0 b5
a :3 0 158 :7 0
15c 159 15a 528c
0 4e :6 0 45
:2 0 b7 a :3 0
15e :7 0 162 15f
160 528c 0 4f
:6 0 45 :2 0 b9
a :3 0 164 :7 0
168 165 166 528c
0 50 :6 0 45
:2 0 bb a :3 0
16a :7 0 16e 16b
16c 528c 0 51
:6 0 45 :2 0 bd
a :3 0 170 :7 0
174 171 172 528c
0 52 :6 0 45
:2 0 bf a :3 0
176 :7 0 17a 177
178 528c 0 53
:6 0 45 :2 0 c1
a :3 0 17c :7 0
180 17d 17e 528c
0 54 :6 0 45
:2 0 c3 a :3 0
182 :7 0 186 183
184 528c 0 55
:6 0 45 :2 0 c5
a :3 0 188 :7 0
18c 189 18a 528c
0 56 :6 0 45
:2 0 c7 a :3 0
18e :7 0 192 18f
190 528c 0 57
:6 0 45 :2 0 c9
a :3 0 194 :7 0
198 195 196 528c
0 58 :6 0 45
:2 0 cb a :3 0
19a :7 0 19e 19b
19c 528c 0 59
:6 0 45 :2 0 cd
a :3 0 1a0 :7 0
1a4 1a1 1a2 528c
0 5a :6 0 45
:2 0 cf a :3 0
1a6 :7 0 1aa 1a7
1a8 528c 0 5b
:6 0 45 :2 0 d1
a :3 0 1ac :7 0
1b0 1ad 1ae 528c
0 5c :6 0 45
:2 0 d3 a :3 0
1b2 :7 0 1b6 1b3
1b4 528c 0 5d
:6 0 45 :2 0 d5
a :3 0 1b8 :7 0
1bc 1b9 1ba 528c
0 5e :6 0 45
:2 0 d7 a :3 0
1be :7 0 1c2 1bf
1c0 528c 0 5f
:6 0 45 :2 0 d9
a :3 0 1c4 :7 0
1c8 1c5 1c6 528c
0 60 :6 0 45
:2 0 db a :3 0
1ca :7 0 1ce 1cb
1cc 528c 0 61
:6 0 45 :2 0 dd
63 :3 0 1d0 :7 0
1d4 1d1 1d2 528c
0 62 :6 0 45
:2 0 df 63 :3 0
1d6 :7 0 1da 1d7
1d8 528c 0 64
:6 0 45 :2 0 e1
63 :3 0 1dc :7 0
1e0 1dd 1de 528c
0 65 :6 0 45
:2 0 e3 63 :3 0
1e2 :7 0 1e6 1e3
1e4 528c 0 66
:6 0 45 :2 0 e5
63 :3 0 1e8 :7 0
1ec 1e9 1ea 528c
0 67 :6 0 45
:2 0 e7 a :3 0
1ee :7 0 1f2 1ef
1f0 528c 0 68
:6 0 45 :2 0 e9
a :3 0 1f4 :7 0
1f8 1f5 1f6 528c
0 69 :6 0 45
:2 0 eb a :3 0
1fa :7 0 1fe 1fb
1fc 528c 0 6a
:6 0 45 :2 0 ed
a :3 0 200 :7 0
204 201 202 528c
0 6b :6 0 45
:2 0 ef a :3 0
206 :7 0 20a 207
208 528c 0 6c
:6 0 45 :2 0 f1
a :3 0 20c :7 0
210 20d 20e 528c
0 6d :6 0 45
:2 0 f3 a :3 0
212 :7 0 216 213
214 528c 0 6e
:6 0 45 :2 0 f5
a :3 0 218 :7 0
21c 219 21a 528c
0 6f :6 0 72
:2 0 f7 a :3 0
21e :7 0 222 21f
220 528c 0 70
:6 0 72 :2 0 fb
4 :3 0 f9 224
226 :6 0 229 227
0 528c 0 71
:6 0 45 :2 0 ff
4 :3 0 fd 22b
22d :6 0 230 22e
0 528c 0 73
:6 0 45 :2 0 101
63 :3 0 232 :7 0
236 233 234 528c
0 74 :6 0 30
:2 0 103 a :3 0
238 :7 0 23c 239
23a 528c 0 75
:6 0 45 :2 0 107
4 :3 0 105 23e
240 :6 0 243 241
0 528c 0 76
:6 0 1d :2 0 109
a :3 0 245 :7 0
249 246 247 528c
0 77 :6 0 30
:2 0 10d 4 :3 0
10b 24b 24d :6 0
250 24e 0 528c
0 78 :6 0 45
:2 0 111 4 :3 0
10f 252 254 :6 0
257 255 0 528c
0 79 :6 0 45
:2 0 113 a :3 0
259 :7 0 25d 25a
25b 528c 0 7a
:6 0 117 aea 0
115 a :3 0 25f
:7 0 263 260 261
528c 0 7b :6 0
45 :2 0 119 33
:3 0 265 :7 0 268
266 0 528c 0
7c :6 0 33 :3 0
26a :7 0 26d 26b
0 528c 0 7d
:6 0 45 :2 0 11b
63 :3 0 26f :7 0
273 270 271 528c
0 7e :6 0 45
:2 0 11d 63 :3 0
275 :7 0 279 276
277 528c 0 7f
:6 0 45 :2 0 11f
a :3 0 27b :7 0
27f 27c 27d 528c
0 80 :6 0 45
:2 0 121 a :3 0
281 :7 0 285 282
283 528c 0 81
:6 0 45 :2 0 123
a :3 0 287 :7 0
28b 288 289 528c
0 82 :6 0 45
:2 0 125 a :3 0
28d :7 0 291 28e
28f 528c 0 83
:6 0 45 :2 0 127
a :3 0 293 :7 0
297 294 295 528c
0 84 :6 0 45
:2 0 129 a :3 0
299 :7 0 29d 29a
29b 528c 0 85
:6 0 45 :2 0 12b
a :3 0 29f :7 0
2a3 2a0 2a1 528c
0 86 :6 0 45
:2 0 12d a :3 0
2a5 :7 0 2a9 2a6
2a7 528c 0 87
:6 0 1d :2 0 12f
a :3 0 2ab :7 0
2af 2ac 2ad 528c
0 88 :6 0 1d
:2 0 133 4 :3 0
131 2b1 2b3 :6 0
2b6 2b4 0 528c
0 89 :6 0 1d
:2 0 137 4 :3 0
135 2b8 2ba :6 0
2bd 2bb 0 528c
0 8a :6 0 45
:2 0 13b 4 :3 0
139 2bf 2c1 :6 0
2c4 2c2 0 528c
0 8b :6 0 45
:2 0 13d a :3 0
2c6 0 2 :5 0
2ca 2c7 2c8 528c
0 8c :6 0 45
:2 0 144 a :3 0
2cc 0 2 :5 0
8e :3 0 8f :3 0
4b :3 0 13f 2cf
2d2 142 2ce 2d4
2d5 :2 0 2d8 2cd
2d6 528c 0 8d
:6 0 45 :2 0 146
a :3 0 2da 0
2 :5 0 2de 2db
2dc 528c 0 90
:6 0 14a d2e 0
148 a :3 0 2e0
0 2 :5 0 2e4
2e1 2e2 528c 0
91 :9 0 14c a
:3 0 2e6 :7 0 2e9
2e7 0 528c 0
92 :6 0 a :3 0
2eb :7 0 2ee 2ec
0 528c 0 93
:6 0 94 :3 0 95
:a 0 2 2fa :4 0
2f0 2f3 0 2f1
:3 0 96 :3 0 97
:3 0 98 :3 0 99
:3 0 27 :4 0 9a
1 :8 0 2fb 2f0
2f3 2fc 0 528c
14e 2fc 2fe 2fb
2fd :6 0 2fa :7 0
2fc 94 :3 0 9b
:a 0 3 30e :5 0
300 303 0 301
:3 0 9c :3 0 9d
:3 0 98 :3 0 9e
:3 0 28 :3 0 9f
:3 0 27 :3 0 a0
:3 0 a1 :4 0 a2
1 :8 0 30f 300
303 310 0 528c
150 310 312 30f
311 :6 0 30e :7 0
310 94 :3 0 a3
:a 0 4 386 :5 0
314 317 0 315
:3 0 a4 :3 0 a5
:3 0 a6 :3 0 a7
:3 0 a6 :3 0 a8
:3 0 a4 :3 0 a9
:3 0 a6 :3 0 aa
:3 0 a6 :3 0 ab
:3 0 a6 :3 0 ac
:3 0 ad :3 0 ae
:3 0 a6 :3 0 ac
:3 0 ad :3 0 ae
:3 0 a6 :3 0 af
:3 0 b0 :3 0 b1
:3 0 a6 :3 0 b2
:3 0 b0 :3 0 b2
:3 0 a6 :3 0 b2
:3 0 a6 :3 0 a1
:3 0 a6 :3 0 b3
:3 0 a6 :3 0 b4
:3 0 a6 :3 0 b5
:3 0 a6 :3 0 b6
:3 0 a6 :3 0 b7
:3 0 a6 :3 0 b8
:3 0 a6 :3 0 b9
:3 0 a6 :3 0 ba
:3 0 a6 :3 0 bb
:3 0 bc :3 0 b0
:3 0 bd :3 0 a4
:3 0 9d :3 0 a6
:3 0 a4 :3 0 9e
:3 0 28 :3 0 a4
:3 0 9f :3 0 29
:3 0 a4 :3 0 a0
:3 0 a6 :3 0 a5
:3 0 a4 :3 0 a5
:3 0 a4 :3 0 99
:3 0 b0 :3 0 99
:3 0 a4 :3 0 a9
:3 0 1a :3 0 be
:3 0 1a :3 0 bf
:3 0 1a :3 0 c0
:3 0 1a :3 0 c1
:3 0 1a :3 0 c2
:3 0 1a :3 0 c3
:3 0 1a :3 0 c4
:3 0 1a :3 0 c5
:3 0 1a :3 0 c6
:3 0 1a :3 0 c7
:3 0 1a :3 0 c8
:3 0 1a :3 0 c9
:3 0 1a :3 0 ca
:3 0 1a :3 0 cb
:3 0 1a :3 0 cc
:3 0 b0 :3 0 cd
:3 0 37 :3 0 a6
:3 0 ac :4 0 ce
1 :8 0 387 314
317 388 0 528c
152 388 38a 387
389 :6 0 386 :7 0
388 392 393 0
154 15 :3 0 16
:2 0 4 38c 38d
0 38e :7 0 391
38f 0 528c 0
cf :6 0 d0 :3 0
d1 :3 0 d0 :3 0
d2 :3 0 395 396
0 2 :4 0 156
397 399 394 39b
39a :2 0 d3 :3 0
d4 :3 0 39d 39e
0 d5 :4 0 d0
:3 0 d6 :3 0 3a1
3a2 0 2 :4 0
158 3a3 3a5 d7
:4 0 d8 :2 0 d9
:3 0 15a 3a8 3aa
:3 0 da :4 0 d8
:2 0 db :4 0 15d
3ad 3af :3 0 d8
:2 0 3 :3 0 160
3b1 3b3 :3 0 d8
:2 0 db :4 0 163
3b5 3b7 :3 0 d8
:2 0 dc :4 0 166
3b9 3bb :3 0 d8
:2 0 db :4 0 169
3bd 3bf :3 0 d8
:2 0 5 :3 0 16c
3c1 3c3 :3 0 d8
:2 0 db :4 0 16f
3c5 3c7 :3 0 d8
:2 0 dc :4 0 172
3c9 3cb :3 0 d8
:2 0 db :4 0 175
3cd 3cf :3 0 d8
:2 0 6 :3 0 178
3d1 3d3 :3 0 d8
:2 0 db :4 0 17b
3d5 3d7 :3 0 d8
:2 0 dc :4 0 17e
3d9 3db :3 0 d8
:2 0 db :4 0 181
3dd 3df :3 0 d8
:2 0 7 :3 0 184
3e1 3e3 :3 0 d8
:2 0 db :4 0 187
3e5 3e7 :3 0 d8
:2 0 dc :4 0 18a
3e9 3eb :3 0 d8
:2 0 db :4 0 18d
3ed 3ef :3 0 d8
:2 0 8 :3 0 190
3f1 3f3 :3 0 d8
:2 0 db :4 0 193
3f5 3f7 :3 0 d8
:2 0 dc :4 0 196
3f9 3fb :3 0 d8
:2 0 8f :3 0 dd
:3 0 9 :3 0 199
3ff 401 de :4 0
19b 3fe 404 19e
3fd 406 :3 0 d8
:2 0 dc :4 0 1a1
408 40a :3 0 d8
:2 0 8f :3 0 dd
:3 0 b :3 0 1a4
40e 410 de :4 0
1a6 40d 413 1a9
40c 415 :3 0 d8
:2 0 dc :4 0 1ac
417 419 :3 0 d8
:2 0 8f :3 0 dd
:3 0 c :3 0 1af
41d 41f de :4 0
1b1 41c 422 1b4
41b 424 :3 0 d8
:2 0 dc :4 0 1b7
426 428 :3 0 d8
:2 0 8f :3 0 dd
:3 0 d :3 0 1ba
42c 42e de :4 0
1bc 42b 431 1bf
42a 433 :3 0 d8
:2 0 dc :4 0 1c2
435 437 :3 0 d8
:2 0 8f :3 0 dd
:3 0 e :3 0 1c5
43b 43d de :4 0
1c7 43a 440 1ca
439 442 :3 0 d8
:2 0 dc :4 0 1cd
444 446 :3 0 d8
:2 0 8f :3 0 dd
:3 0 f :3 0 1d0
44a 44c de :4 0
1d2 449 44f 1d5
448 451 :3 0 d8
:2 0 dc :4 0 1d8
453 455 :3 0 d8
:2 0 8f :3 0 dd
:3 0 10 :3 0 1db
459 45b de :4 0
1dd 458 45e 1e0
457 460 :3 0 d8
:2 0 dc :4 0 1e3
462 464 :3 0 d8
:2 0 8f :3 0 dd
:3 0 11 :3 0 1e6
468 46a de :4 0
1e8 467 46d 1eb
466 46f :3 0 d8
:2 0 dc :4 0 1ee
471 473 :3 0 d8
:2 0 8f :3 0 dd
:3 0 12 :3 0 1f1
477 479 de :4 0
1f3 476 47c 1f6
475 47e :3 0 d8
:2 0 dc :4 0 1f9
480 482 :3 0 d8
:2 0 db :4 0 1fc
484 486 :3 0 d8
:2 0 13 :3 0 1ff
488 48a :3 0 d8
:2 0 db :4 0 202
48c 48e :3 0 d8
:2 0 df :4 0 205
490 492 :3 0 208
39f 494 :2 0 496
20d 497 39c 496
0 498 20f 0
51ec d0 :3 0 d1
:3 0 499 49a 0
d0 :3 0 e0 :3 0
49c 49d 0 30
:2 0 2 :4 0 e1
:2 0 e2 :2 0 30
:2 0 211 4a2 4a4
:3 0 214 49e 4a6
49b 4a8 4a7 :2 0
d3 :3 0 e3 :3 0
4aa 4ab 0 d5
:4 0 e4 :4 0 d8
:2 0 d9 :3 0 218
4af 4b1 :3 0 21b
4ac 4b3 :2 0 4b5
21e 4b6 4a9 4b5
0 4b7 220 0
51ec 26 :3 0 3
:3 0 4b8 4b9 0
51ec 29 :3 0 5
:3 0 4bb 4bc 0
51ec 27 :3 0 6
:3 0 4be 4bf 0
51ec 1f :3 0 13
:3 0 4c1 4c2 0
51ec 39 :3 0 7
:3 0 4c4 4c5 0
51ec 5b :3 0 11
:3 0 4c7 4c8 0
51ec 5b :3 0 e5
:3 0 8f :3 0 5b
:3 0 45 :2 0 222
4cc 4cf 1a :3 0
e6 :3 0 4d1 4d2
0 225 4cb 4d4
4ca 4d5 0 51ec
8f :3 0 5b :3 0
45 :2 0 228 4d7
4da 1a :3 0 e7
:2 0 e8 :3 0 4dc
4de 0 22d 4dd
4e0 :3 0 4e1 :2 0
8f :3 0 5b :3 0
45 :2 0 230 4e3
4e6 1a :3 0 e7
:2 0 e9 :3 0 4e8
4ea 0 235 4e9
4ec :3 0 4ed :2 0
4e2 4ef 4ee :2 0
5b :3 0 ea :2 0
4f1 4f2 0 4f4
238 4f5 4f0 4f4
0 4f6 23a 0
51ec 3a :3 0 39
:3 0 4f7 4f8 0
51ec 42 :3 0 eb
:4 0 4fa 4fb 0
51ec 31 :3 0 eb
:4 0 4fd 4fe 0
51ec 4e :3 0 45
:2 0 500 501 0
51ec 2c :3 0 eb
:4 0 503 504 0
51ec 3b :4 0 506
507 0 51ec 3c
:4 0 509 50a 0
51ec ec :3 0 95
:4 0 50f :2 0 51ec
50d 510 :3 0 95
:3 0 5f :4 0 514
:2 0 51ec 511 512
:3 0 95 :3 0 ed
:3 0 515 516 :3 0
15 :3 0 ee :3 0
518 519 0 45
:2 0 51a 51b 0
51d 23c 524 15
:3 0 ee :3 0 51e
51f 0 ef :2 0
520 521 0 523
23e 525 517 51d
0 526 0 523
0 526 240 0
51ec 5f :3 0 15
:3 0 ee :3 0 528
529 0 527 52a
0 51ec f0 :3 0
95 :4 0 52f :2 0
535 52d 0 15
:3 0 ee :3 0 530
531 0 f1 :3 0
532 533 0 535
243 588 f2 :3 0
15 :3 0 ee :3 0
537 538 0 f1
:3 0 539 53a 0
53c 246 53e 248
53d 53c :2 0 586
f3 :3 0 15 :3 0
ee :3 0 541 542
0 f1 :3 0 543
544 0 57e d0
:3 0 d1 :3 0 546
547 0 d0 :3 0
e0 :3 0 549 54a
0 f4 :2 0 2
:4 0 f5 :2 0 e2
:2 0 30 :2 0 24a
54f 551 :3 0 24d
54b 553 548 555
554 :2 0 d3 :3 0
e3 :3 0 557 558
0 d5 :4 0 f6
:4 0 d8 :2 0 d9
:3 0 251 55c 55e
:3 0 d8 :2 0 f7
:4 0 254 560 562
:3 0 d8 :2 0 f8
:4 0 257 564 566
:3 0 d8 :2 0 f1
:3 0 25a 568 56a
:3 0 d8 :2 0 f9
:4 0 25d 56c 56e
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 260
571 575 264 570
577 :3 0 267 559
579 :2 0 57b 26a
57c 556 57b 0
57d 26c 0 57e
26e 581 :3 0 581
0 581 580 57e
57f :6 0 583 5
:3 0 271 585 273
584 583 :2 0 586
275 :2 0 588 0
588 587 535 586
:6 0 51ec 1 :3 0
8f :3 0 5f :3 0
45 :2 0 278 58a
58d e7 :2 0 ef
:2 0 27d 58f 591
:3 0 d0 :3 0 d1
:3 0 593 594 0
d0 :3 0 e0 :3 0
596 597 0 1d
:2 0 2 :4 0 fc
:2 0 e2 :2 0 30
:2 0 280 59c 59e
:3 0 283 598 5a0
595 5a2 5a1 :2 0
d3 :3 0 e3 :3 0
5a4 5a5 0 d5
:4 0 fd :4 0 d8
:2 0 d9 :3 0 287
5a9 5ab :3 0 d8
:2 0 f7 :4 0 28a
5ad 5af :3 0 d8
:2 0 fe :4 0 28d
5b1 5b3 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 ff
:3 0 5b8 5b9 0
290 5b7 5bb de
:4 0 292 5b6 5be
295 5b5 5c0 :3 0
d8 :2 0 100 :4 0
298 5c2 5c4 :3 0
d8 :2 0 db :4 0
29b 5c6 5c8 :3 0
d8 :2 0 27 :3 0
29e 5ca 5cc :3 0
d8 :2 0 db :4 0
2a1 5ce 5d0 :3 0
2a4 5a6 5d2 :2 0
5d4 2a7 5d5 5a3
5d4 0 5d6 2a9
0 600 d0 :3 0
d1 :3 0 5d7 5d8
0 d0 :3 0 e0
:3 0 5da 5db 0
30 :2 0 2 :4 0
101 :2 0 e2 :2 0
30 :2 0 2ab 5e0
5e2 :3 0 2ae 5dc
5e4 5d9 5e6 5e5
:2 0 d3 :3 0 e3
:3 0 5e8 5e9 0
d5 :4 0 102 :4 0
d8 :2 0 d9 :3 0
2b2 5ed 5ef :3 0
2b5 5ea 5f1 :2 0
5f3 2b8 5f4 5e7
5f3 0 5f5 2ba
0 600 103 :3 0
104 :3 0 5f6 5f7
0 1a :3 0 ff
:3 0 5f9 5fa 0
27 :3 0 105 :3 0
2bc 5f8 5fe :2 0
600 2c0 601 592
600 0 602 2c4
0 51ec 106 :3 0
cd :3 0 9e :3 0
107 :3 0 108 :3 0
109 :3 0 4b :3 0
37 :3 0 28 :3 0
89 :3 0 8a :3 0
52 :3 0 bc :3 0
99 :3 0 26 :4 0
10a 1 :8 0 618
15 :3 0 ee :3 0
613 614 0 f1
:3 0 615 616 0
618 2c6 66b f2
:3 0 15 :3 0 ee
:3 0 61a 61b 0
f1 :3 0 61c 61d
0 61f 2c9 621
2cb 620 61f :2 0
669 f3 :3 0 15
:3 0 ee :3 0 624
625 0 f1 :3 0
626 627 0 661
d0 :3 0 d1 :3 0
629 62a 0 d0
:3 0 e0 :3 0 62c
62d 0 f4 :2 0
2 :4 0 10b :2 0
e2 :2 0 30 :2 0
2cd 632 634 :3 0
2d0 62e 636 62b
638 637 :2 0 d3
:3 0 e3 :3 0 63a
63b 0 d5 :4 0
10c :4 0 d8 :2 0
d9 :3 0 2d4 63f
641 :3 0 d8 :2 0
f7 :4 0 2d7 643
645 :3 0 d8 :2 0
f8 :4 0 2da 647
649 :3 0 d8 :2 0
f1 :3 0 2dd 64b
64d :3 0 d8 :2 0
f9 :4 0 2e0 64f
651 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2e3 654 658 2e7
653 65a :3 0 2ea
63c 65c :2 0 65e
2ed 65f 639 65e
0 660 2ef 0
661 2f1 664 :3 0
664 0 664 663
661 662 :6 0 666
7 :3 0 2f4 668
2f6 667 666 :2 0
669 2f8 :2 0 66b
0 66b 66a 618
669 :6 0 51ec 1
:3 0 15 :3 0 ee
:3 0 66d 66e 0
15 :3 0 e7 :2 0
10d :3 0 670 672
0 2fd 671 674
:3 0 675 :2 0 d0
:3 0 d1 :3 0 677
678 0 d0 :3 0
e0 :3 0 67a 67b
0 1d :2 0 2
:4 0 10e :2 0 e2
:2 0 30 :2 0 300
680 682 :3 0 303
67c 684 679 686
685 :2 0 d3 :3 0
e3 :3 0 688 689
0 d5 :4 0 10f
:4 0 d8 :2 0 d9
:3 0 307 68d 68f
:3 0 d8 :2 0 f7
:4 0 30a 691 693
:3 0 d8 :2 0 fe
:4 0 30d 695 697
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 ff :3 0 69c
69d 0 310 69b
69f de :4 0 312
69a 6a2 315 699
6a4 :3 0 d8 :2 0
100 :4 0 318 6a6
6a8 :3 0 d8 :2 0
db :4 0 31b 6aa
6ac :3 0 d8 :2 0
26 :3 0 31e 6ae
6b0 :3 0 d8 :2 0
db :4 0 321 6b2
6b4 :3 0 324 68a
6b6 :2 0 6b8 327
6b9 687 6b8 0
6ba 329 0 6e4
d0 :3 0 d1 :3 0
6bb 6bc 0 d0
:3 0 e0 :3 0 6be
6bf 0 30 :2 0
2 :4 0 110 :2 0
e2 :2 0 30 :2 0
32b 6c4 6c6 :3 0
32e 6c0 6c8 6bd
6ca 6c9 :2 0 d3
:3 0 e3 :3 0 6cc
6cd 0 d5 :4 0
111 :4 0 d8 :2 0
d9 :3 0 332 6d1
6d3 :3 0 335 6ce
6d5 :2 0 6d7 338
6d8 6cb 6d7 0
6d9 33a 0 6e4
103 :3 0 104 :3 0
6da 6db 0 1a
:3 0 ff :3 0 6dd
6de 0 26 :3 0
105 :3 0 33c 6dc
6e2 :2 0 6e4 340
6e5 676 6e4 0
6e6 344 0 51ec
75 :3 0 45 :2 0
6e7 6e8 0 51ec
112 :3 0 75 :3 0
113 :3 0 9e :3 0
28 :4 0 114 1
:8 0 6f5 15 :3 0
ee :3 0 6f0 6f1
0 f1 :3 0 6f2
6f3 0 6f5 346
748 f2 :3 0 15
:3 0 ee :3 0 6f7
6f8 0 f1 :3 0
6f9 6fa 0 6fc
349 6fe 34b 6fd
6fc :2 0 746 f3
:3 0 15 :3 0 ee
:3 0 701 702 0
f1 :3 0 703 704
0 73e d0 :3 0
d1 :3 0 706 707
0 d0 :3 0 e0
:3 0 709 70a 0
f4 :2 0 2 :4 0
115 :2 0 e2 :2 0
30 :2 0 34d 70f
711 :3 0 350 70b
713 708 715 714
:2 0 d3 :3 0 e3
:3 0 717 718 0
d5 :4 0 116 :4 0
d8 :2 0 d9 :3 0
354 71c 71e :3 0
d8 :2 0 f7 :4 0
357 720 722 :3 0
d8 :2 0 f8 :4 0
35a 724 726 :3 0
d8 :2 0 f1 :3 0
35d 728 72a :3 0
d8 :2 0 f9 :4 0
360 72c 72e :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 363 731
735 367 730 737
:3 0 36a 719 739
:2 0 73b 36d 73c
716 73b 0 73d
36f 0 73e 371
741 :3 0 741 0
741 740 73e 73f
:6 0 743 9 :3 0
374 745 376 744
743 :2 0 746 378
:2 0 748 0 748
747 6f5 746 :6 0
51ec 1 :3 0 8f
:3 0 75 :3 0 45
:2 0 37b 74a 74d
117 :2 0 45 :2 0
380 74f 751 :3 0
d0 :3 0 d1 :3 0
753 754 0 d0
:3 0 e0 :3 0 756
757 0 1d :2 0
2 :4 0 118 :2 0
e2 :2 0 30 :2 0
383 75c 75e :3 0
386 758 760 755
762 761 :2 0 d3
:3 0 e3 :3 0 764
765 0 d5 :4 0
119 :4 0 d8 :2 0
d9 :3 0 38a 769
76b :3 0 d8 :2 0
f7 :4 0 38d 76d
76f :3 0 d8 :2 0
fe :4 0 390 771
773 :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 11a :3 0
778 779 0 393
777 77b de :4 0
395 776 77e 398
775 780 :3 0 d8
:2 0 100 :4 0 39b
782 784 :3 0 d8
:2 0 db :4 0 39e
786 788 :3 0 d8
:2 0 28 :3 0 3a1
78a 78c :3 0 d8
:2 0 db :4 0 3a4
78e 790 :3 0 3a7
766 792 :2 0 794
3aa 795 763 794
0 796 3ac 0
7c0 d0 :3 0 d1
:3 0 797 798 0
d0 :3 0 e0 :3 0
79a 79b 0 30
:2 0 2 :4 0 11b
:2 0 e2 :2 0 30
:2 0 3ae 7a0 7a2
:3 0 3b1 79c 7a4
799 7a6 7a5 :2 0
d3 :3 0 e3 :3 0
7a8 7a9 0 d5
:4 0 11c :4 0 d8
:2 0 d9 :3 0 3b5
7ad 7af :3 0 3b8
7aa 7b1 :2 0 7b3
3bb 7b4 7a7 7b3
0 7b5 3bd 0
7c0 103 :3 0 104
:3 0 7b6 7b7 0
1a :3 0 11a :3 0
7b9 7ba 0 28
:3 0 105 :3 0 3bf
7b8 7be :2 0 7c0
3c3 7c1 752 7c0
0 7c2 3c7 0
51ec 11d :3 0 106
:3 0 11d :3 0 11e
:3 0 8f :3 0 11d
:3 0 11f :3 0 8f
:3 0 11d :3 0 120
:3 0 11d :3 0 121
:3 0 11d :3 0 122
:3 0 123 :3 0 124
:3 0 125 :3 0 126
:3 0 4a :3 0 6e
:3 0 58 :3 0 59
:3 0 5c :3 0 68
:3 0 67 :3 0 bc
:3 0 11d :3 0 127
:3 0 128 :3 0 125
:3 0 11d :3 0 122
:3 0 125 :3 0 99
:3 0 11d :3 0 99
:3 0 28 :4 0 129
1 :8 0 7ee 15
:3 0 ee :3 0 7e9
7ea 0 f1 :3 0
7eb 7ec 0 7ee
3c9 841 f2 :3 0
15 :3 0 ee :3 0
7f0 7f1 0 f1
:3 0 7f2 7f3 0
7f5 3cc 7f7 3ce
7f6 7f5 :2 0 83f
f3 :3 0 15 :3 0
ee :3 0 7fa 7fb
0 f1 :3 0 7fc
7fd 0 837 d0
:3 0 d1 :3 0 7ff
800 0 d0 :3 0
e0 :3 0 802 803
0 f4 :2 0 2
:4 0 12a :2 0 e2
:2 0 30 :2 0 3d0
808 80a :3 0 3d3
804 80c 801 80e
80d :2 0 d3 :3 0
e3 :3 0 810 811
0 d5 :4 0 12b
:4 0 d8 :2 0 d9
:3 0 3d7 815 817
:3 0 d8 :2 0 f7
:4 0 3da 819 81b
:3 0 d8 :2 0 f8
:4 0 3dd 81d 81f
:3 0 d8 :2 0 f1
:3 0 3e0 821 823
:3 0 d8 :2 0 f9
:4 0 3e3 825 827
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 3e6
82a 82e 3ea 829
830 :3 0 3ed 812
832 :2 0 834 3f0
835 80f 834 0
836 3f2 0 837
3f4 83a :3 0 83a
0 83a 839 837
838 :6 0 83c b
:3 0 3f7 83e 3f9
83d 83c :2 0 83f
3fb :2 0 841 0
841 840 7ee 83f
:6 0 51ec 1 :3 0
15 :3 0 ee :3 0
843 844 0 15
:3 0 e7 :2 0 10d
:3 0 846 848 0
400 847 84a :3 0
84b :2 0 d0 :3 0
d1 :3 0 84d 84e
0 d0 :3 0 e0
:3 0 850 851 0
1d :2 0 2 :4 0
12c :2 0 e2 :2 0
30 :2 0 403 856
858 :3 0 406 852
85a 84f 85c 85b
:2 0 d3 :3 0 e3
:3 0 85e 85f 0
d5 :4 0 12d :4 0
d8 :2 0 d9 :3 0
40a 863 865 :3 0
d8 :2 0 f7 :4 0
40d 867 869 :3 0
d8 :2 0 fe :4 0
410 86b 86d :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
ff :3 0 872 873
0 413 871 875
de :4 0 415 870
878 418 86f 87a
:3 0 d8 :2 0 100
:4 0 41b 87c 87e
:3 0 d8 :2 0 db
:4 0 41e 880 882
:3 0 d8 :2 0 26
:3 0 421 884 886
:3 0 d8 :2 0 db
:4 0 424 888 88a
:3 0 427 860 88c
:2 0 88e 42a 88f
85d 88e 0 890
42c 0 8ba d0
:3 0 d1 :3 0 891
892 0 d0 :3 0
e0 :3 0 894 895
0 30 :2 0 2
:4 0 12e :2 0 e2
:2 0 30 :2 0 42e
89a 89c :3 0 431
896 89e 893 8a0
89f :2 0 d3 :3 0
e3 :3 0 8a2 8a3
0 d5 :4 0 12f
:4 0 d8 :2 0 d9
:3 0 435 8a7 8a9
:3 0 438 8a4 8ab
:2 0 8ad 43b 8ae
8a1 8ad 0 8af
43d 0 8ba 103
:3 0 104 :3 0 8b0
8b1 0 1a :3 0
ff :3 0 8b3 8b4
0 26 :3 0 105
:3 0 43f 8b2 8b8
:2 0 8ba 443 8bb
84c 8ba 0 8bc
447 0 51ec 130
:3 0 131 :3 0 3e
:3 0 42 :3 0 132
:3 0 9f :3 0 27
:4 0 133 1 :8 0
8ca 15 :3 0 ee
:3 0 8c5 8c6 0
f1 :3 0 8c7 8c8
0 8ca 449 91d
f2 :3 0 15 :3 0
ee :3 0 8cc 8cd
0 f1 :3 0 8ce
8cf 0 8d1 44c
8d3 44e 8d2 8d1
:2 0 91b f3 :3 0
15 :3 0 ee :3 0
8d6 8d7 0 f1
:3 0 8d8 8d9 0
913 d0 :3 0 d1
:3 0 8db 8dc 0
d0 :3 0 e0 :3 0
8de 8df 0 f4
:2 0 2 :4 0 134
:2 0 e2 :2 0 30
:2 0 450 8e4 8e6
:3 0 453 8e0 8e8
8dd 8ea 8e9 :2 0
d3 :3 0 e3 :3 0
8ec 8ed 0 d5
:4 0 135 :4 0 d8
:2 0 d9 :3 0 457
8f1 8f3 :3 0 d8
:2 0 f7 :4 0 45a
8f5 8f7 :3 0 d8
:2 0 f8 :4 0 45d
8f9 8fb :3 0 d8
:2 0 f1 :3 0 460
8fd 8ff :3 0 d8
:2 0 f9 :4 0 463
901 903 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 466 906 90a
46a 905 90c :3 0
46d 8ee 90e :2 0
910 470 911 8eb
910 0 912 472
0 913 474 916
:3 0 916 0 916
915 913 914 :6 0
918 d :3 0 477
91a 479 919 918
:2 0 91b 47b :2 0
91d 0 91d 91c
8ca 91b :6 0 51ec
1 :3 0 15 :3 0
ee :3 0 91f 920
0 15 :3 0 e7
:2 0 10d :3 0 922
924 0 480 923
926 :3 0 927 :2 0
d0 :3 0 d1 :3 0
929 92a 0 d0
:3 0 e0 :3 0 92c
92d 0 1d :2 0
2 :4 0 136 :2 0
e2 :2 0 30 :2 0
483 932 934 :3 0
486 92e 936 92b
938 937 :2 0 d3
:3 0 e3 :3 0 93a
93b 0 d5 :4 0
137 :4 0 d8 :2 0
d9 :3 0 48a 93f
941 :3 0 d8 :2 0
f7 :4 0 48d 943
945 :3 0 d8 :2 0
fe :4 0 490 947
949 :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 ff :3 0
94e 94f 0 493
94d 951 de :4 0
495 94c 954 498
94b 956 :3 0 d8
:2 0 100 :4 0 49b
958 95a :3 0 d8
:2 0 db :4 0 49e
95c 95e :3 0 d8
:2 0 27 :3 0 4a1
960 962 :3 0 d8
:2 0 db :4 0 4a4
964 966 :3 0 4a7
93c 968 :2 0 96a
4aa 96b 939 96a
0 96c 4ac 0
996 d0 :3 0 d1
:3 0 96d 96e 0
d0 :3 0 e0 :3 0
970 971 0 30
:2 0 2 :4 0 138
:2 0 e2 :2 0 30
:2 0 4ae 976 978
:3 0 4b1 972 97a
96f 97c 97b :2 0
d3 :3 0 e3 :3 0
97e 97f 0 d5
:4 0 139 :4 0 d8
:2 0 d9 :3 0 4b5
983 985 :3 0 4b8
980 987 :2 0 989
4bb 98a 97d 989
0 98b 4bd 0
996 103 :3 0 104
:3 0 98c 98d 0
1a :3 0 ff :3 0
98f 990 0 27
:3 0 105 :3 0 4bf
98e 994 :2 0 996
4c3 997 928 996
0 998 4c7 0
51ec 13a :3 0 3d
:3 0 13b :3 0 13c
:3 0 29 :4 0 13d
1 :8 0 9a4 15
:3 0 ee :3 0 99f
9a0 0 f1 :3 0
9a1 9a2 0 9a4
4c9 9f7 f2 :3 0
15 :3 0 ee :3 0
9a6 9a7 0 f1
:3 0 9a8 9a9 0
9ab 4cc 9ad 4ce
9ac 9ab :2 0 9f5
f3 :3 0 15 :3 0
ee :3 0 9b0 9b1
0 f1 :3 0 9b2
9b3 0 9ed d0
:3 0 d1 :3 0 9b5
9b6 0 d0 :3 0
e0 :3 0 9b8 9b9
0 f4 :2 0 2
:4 0 13e :2 0 e2
:2 0 30 :2 0 4d0
9be 9c0 :3 0 4d3
9ba 9c2 9b7 9c4
9c3 :2 0 d3 :3 0
e3 :3 0 9c6 9c7
0 d5 :4 0 13f
:4 0 d8 :2 0 d9
:3 0 4d7 9cb 9cd
:3 0 d8 :2 0 f7
:4 0 4da 9cf 9d1
:3 0 d8 :2 0 f8
:4 0 4dd 9d3 9d5
:3 0 d8 :2 0 f1
:3 0 4e0 9d7 9d9
:3 0 d8 :2 0 f9
:4 0 4e3 9db 9dd
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 4e6
9e0 9e4 4ea 9df
9e6 :3 0 4ed 9c8
9e8 :2 0 9ea 4f0
9eb 9c5 9ea 0
9ec 4f2 0 9ed
4f4 9f0 :3 0 9f0
0 9f0 9ef 9ed
9ee :6 0 9f2 f
:3 0 4f7 9f4 4f9
9f3 9f2 :2 0 9f5
4fb :2 0 9f7 0
9f7 9f6 9a4 9f5
:6 0 51ec 1 :3 0
123 :3 0 140 :3 0
9f9 9fa 0 3d
:3 0 141 :4 0 4fe
9fb 9fe e7 :2 0
45 :2 0 503 a00
a02 :3 0 3d :3 0
eb :4 0 a04 a05
0 a07 506 a08
a03 a07 0 a09
508 0 51ec 15
:3 0 ee :3 0 a0a
a0b 0 15 :3 0
e7 :2 0 10d :3 0
a0d a0f 0 50c
a0e a11 :3 0 a12
:2 0 d0 :3 0 d1
:3 0 a14 a15 0
d0 :3 0 e0 :3 0
a17 a18 0 1d
:2 0 2 :4 0 142
:2 0 e2 :2 0 30
:2 0 50f a1d a1f
:3 0 512 a19 a21
a16 a23 a22 :2 0
d3 :3 0 e3 :3 0
a25 a26 0 d5
:4 0 143 :4 0 d8
:2 0 d9 :3 0 516
a2a a2c :3 0 d8
:2 0 f7 :4 0 519
a2e a30 :3 0 d8
:2 0 fe :4 0 51c
a32 a34 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 ff
:3 0 a39 a3a 0
51f a38 a3c de
:4 0 521 a37 a3f
524 a36 a41 :3 0
d8 :2 0 100 :4 0
527 a43 a45 :3 0
d8 :2 0 db :4 0
52a a47 a49 :3 0
d8 :2 0 29 :3 0
52d a4b a4d :3 0
d8 :2 0 db :4 0
530 a4f a51 :3 0
533 a27 a53 :2 0
a55 536 a56 a24
a55 0 a57 538
0 a81 d0 :3 0
d1 :3 0 a58 a59
0 d0 :3 0 e0
:3 0 a5b a5c 0
30 :2 0 2 :4 0
144 :2 0 e2 :2 0
30 :2 0 53a a61
a63 :3 0 53d a5d
a65 a5a a67 a66
:2 0 d3 :3 0 e3
:3 0 a69 a6a 0
d5 :4 0 145 :4 0
d8 :2 0 d9 :3 0
541 a6e a70 :3 0
544 a6b a72 :2 0
a74 547 a75 a68
a74 0 a76 549
0 a81 103 :3 0
104 :3 0 a77 a78
0 1a :3 0 ff
:3 0 a7a a7b 0
29 :3 0 105 :3 0
54b a79 a7f :2 0
a81 54f a82 a13
a81 0 a83 553
0 51ec 69 :3 0
12 :3 0 a84 a85
0 51ec 6b :3 0
e5 :3 0 8f :3 0
69 :3 0 45 :2 0
555 a89 a8c ea
:2 0 558 a88 a8f
a87 a90 0 51ec
6c :3 0 e5 :3 0
8f :3 0 69 :3 0
45 :2 0 55b a94
a97 146 :2 0 55e
a93 a9a a92 a9b
0 51ec 6a :3 0
e5 :3 0 8f :3 0
69 :3 0 45 :2 0
561 a9f aa2 30
:2 0 564 a9e aa5
a9d aa6 0 51ec
147 :3 0 a7 :3 0
81 :3 0 9d :3 0
9e :3 0 28 :3 0
9e :3 0 a8 :3 0
9f :3 0 29 :3 0
a0 :4 0 148 1
:8 0 ab9 15 :3 0
ee :3 0 ab4 ab5
0 f1 :3 0 ab6
ab7 0 ab9 567
b0c f2 :3 0 15
:3 0 ee :3 0 abb
abc 0 f1 :3 0
abd abe 0 ac0
56a ac2 56c ac1
ac0 :2 0 b0a f3
:3 0 15 :3 0 ee
:3 0 ac5 ac6 0
f1 :3 0 ac7 ac8
0 b02 d0 :3 0
d1 :3 0 aca acb
0 d0 :3 0 e0
:3 0 acd ace 0
f4 :2 0 2 :4 0
149 :2 0 e2 :2 0
30 :2 0 56e ad3
ad5 :3 0 571 acf
ad7 acc ad9 ad8
:2 0 d3 :3 0 e3
:3 0 adb adc 0
d5 :4 0 14a :4 0
d8 :2 0 d9 :3 0
575 ae0 ae2 :3 0
d8 :2 0 f7 :4 0
578 ae4 ae6 :3 0
d8 :2 0 f8 :4 0
57b ae8 aea :3 0
d8 :2 0 f1 :3 0
57e aec aee :3 0
d8 :2 0 f9 :4 0
581 af0 af2 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 584 af5
af9 588 af4 afb
:3 0 58b add afd
:2 0 aff 58e b00
ada aff 0 b01
590 0 b02 592
b05 :3 0 b05 0
b05 b04 b02 b03
:6 0 b07 11 :3 0
595 b09 597 b08
b07 :2 0 b0a 599
:2 0 b0c 0 b0c
b0b ab9 b0a :6 0
51ec 1 :3 0 147
:3 0 a7 :3 0 80
:3 0 9d :3 0 9e
:3 0 28 :3 0 a8
:3 0 28 :3 0 9f
:3 0 29 :3 0 a0
:4 0 14b 1 :8 0
b1f 15 :3 0 ee
:3 0 b1a b1b 0
f1 :3 0 b1c b1d
0 b1f 59c b72
f2 :3 0 15 :3 0
ee :3 0 b21 b22
0 f1 :3 0 b23
b24 0 b26 59f
b28 5a1 b27 b26
:2 0 b70 f3 :3 0
15 :3 0 ee :3 0
b2b b2c 0 f1
:3 0 b2d b2e 0
b68 d0 :3 0 d1
:3 0 b30 b31 0
d0 :3 0 e0 :3 0
b33 b34 0 f4
:2 0 2 :4 0 14c
:2 0 e2 :2 0 30
:2 0 5a3 b39 b3b
:3 0 5a6 b35 b3d
b32 b3f b3e :2 0
d3 :3 0 e3 :3 0
b41 b42 0 d5
:4 0 14d :4 0 d8
:2 0 d9 :3 0 5aa
b46 b48 :3 0 d8
:2 0 f7 :4 0 5ad
b4a b4c :3 0 d8
:2 0 f8 :4 0 5b0
b4e b50 :3 0 d8
:2 0 f1 :3 0 5b3
b52 b54 :3 0 d8
:2 0 f9 :4 0 5b6
b56 b58 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 5b9 b5b b5f
5bd b5a b61 :3 0
5c0 b43 b63 :2 0
b65 5c3 b66 b40
b65 0 b67 5c5
0 b68 5c7 b6b
:3 0 b6b 0 b6b
b6a b68 b69 :6 0
b6d 13 :3 0 5ca
b6f 5cc b6e b6d
:2 0 b70 5ce :2 0
b72 0 b72 b71
b1f b70 :6 0 51ec
1 :3 0 8d :3 0
14e :2 0 45 :2 0
5d3 b75 b77 :3 0
8f :3 0 6c :3 0
45 :2 0 5d6 b79
b7c e7 :2 0 45
:2 0 5db b7e b80
:3 0 147 :3 0 70
:3 0 14f :3 0 9d
:3 0 9e :3 0 28
:3 0 a8 :3 0 28
:3 0 9f :3 0 27
:4 0 150 1 :8 0
b92 15 :3 0 ee
:3 0 b8d b8e 0
f1 :3 0 b8f b90
0 b92 5de be5
f2 :3 0 15 :3 0
ee :3 0 b94 b95
0 f1 :3 0 b96
b97 0 b99 5e1
b9b 5e3 b9a b99
:2 0 be3 f3 :3 0
15 :3 0 ee :3 0
b9e b9f 0 f1
:3 0 ba0 ba1 0
bdb d0 :3 0 d1
:3 0 ba3 ba4 0
d0 :3 0 e0 :3 0
ba6 ba7 0 f4
:2 0 2 :4 0 151
:2 0 e2 :2 0 30
:2 0 5e5 bac bae
:3 0 5e8 ba8 bb0
ba5 bb2 bb1 :2 0
d3 :3 0 e3 :3 0
bb4 bb5 0 d5
:4 0 152 :4 0 d8
:2 0 d9 :3 0 5ec
bb9 bbb :3 0 d8
:2 0 f7 :4 0 5ef
bbd bbf :3 0 d8
:2 0 f8 :4 0 5f2
bc1 bc3 :3 0 d8
:2 0 f1 :3 0 5f5
bc5 bc7 :3 0 d8
:2 0 f9 :4 0 5f8
bc9 bcb :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 5fb bce bd2
5ff bcd bd4 :3 0
602 bb6 bd6 :2 0
bd8 605 bd9 bb3
bd8 0 bda 607
0 bdb 609 bde
:3 0 bde 0 bde
bdd bdb bdc :6 0
be0 15 :3 0 60c
be2 60e be1 be0
:2 0 be3 610 :2 0
be5 0 be5 be4
b92 be3 :6 0 cd7
1 :3 0 8f :3 0
70 :3 0 45 :2 0
613 be7 bea 14e
:2 0 45 :2 0 618
bec bee :3 0 153
:2 0 61b bf0 bf1
:3 0 75 :3 0 45
:2 0 bf3 bf4 0
cd4 147 :3 0 75
:3 0 14f :3 0 9d
:3 0 9e :3 0 28
:3 0 a8 :3 0 9e
:3 0 9f :3 0 27
:4 0 154 1 :8 0
c06 15 :3 0 ee
:3 0 c01 c02 0
f1 :3 0 c03 c04
0 c06 61d c59
f2 :3 0 15 :3 0
ee :3 0 c08 c09
0 f1 :3 0 c0a
c0b 0 c0d 620
c0f 622 c0e c0d
:2 0 c57 f3 :3 0
15 :3 0 ee :3 0
c12 c13 0 f1
:3 0 c14 c15 0
c4f d0 :3 0 d1
:3 0 c17 c18 0
d0 :3 0 e0 :3 0
c1a c1b 0 f4
:2 0 2 :4 0 155
:2 0 e2 :2 0 30
:2 0 624 c20 c22
:3 0 627 c1c c24
c19 c26 c25 :2 0
d3 :3 0 e3 :3 0
c28 c29 0 d5
:4 0 156 :4 0 d8
:2 0 d9 :3 0 62b
c2d c2f :3 0 d8
:2 0 f7 :4 0 62e
c31 c33 :3 0 d8
:2 0 f8 :4 0 631
c35 c37 :3 0 d8
:2 0 f1 :3 0 634
c39 c3b :3 0 d8
:2 0 f9 :4 0 637
c3d c3f :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 63a c42 c46
63e c41 c48 :3 0
641 c2a c4a :2 0
c4c 644 c4d c27
c4c 0 c4e 646
0 c4f 648 c52
:3 0 c52 0 c52
c51 c4f c50 :6 0
c54 17 :3 0 64b
c56 64d c55 c54
:2 0 c57 64f :2 0
c59 0 c59 c58
c06 c57 :6 0 cd4
1 :3 0 8f :3 0
75 :3 0 45 :2 0
652 c5b c5e 14e
:2 0 45 :2 0 657
c60 c62 :3 0 d0
:3 0 d1 :3 0 c64
c65 0 d0 :3 0
e0 :3 0 c67 c68
0 1d :2 0 2
:4 0 157 :2 0 e2
:2 0 30 :2 0 65a
c6d c6f :3 0 65d
c69 c71 c66 c73
c72 :2 0 d3 :3 0
e3 :3 0 c75 c76
0 d5 :4 0 158
:4 0 d8 :2 0 d9
:3 0 661 c7a c7c
:3 0 d8 :2 0 f7
:4 0 664 c7e c80
:3 0 d8 :2 0 fe
:4 0 667 c82 c84
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 159 :3 0 c89
c8a 0 66a c88
c8c de :4 0 66c
c87 c8f 66f c86
c91 :3 0 d8 :2 0
100 :4 0 672 c93
c95 :3 0 d8 :2 0
db :4 0 675 c97
c99 :3 0 d8 :2 0
27 :3 0 678 c9b
c9d :3 0 d8 :2 0
db :4 0 67b c9f
ca1 :3 0 67e c77
ca3 :2 0 ca5 681
ca6 c74 ca5 0
ca7 683 0 cd1
d0 :3 0 d1 :3 0
ca8 ca9 0 d0
:3 0 e0 :3 0 cab
cac 0 30 :2 0
2 :4 0 15a :2 0
e2 :2 0 30 :2 0
685 cb1 cb3 :3 0
688 cad cb5 caa
cb7 cb6 :2 0 d3
:3 0 e3 :3 0 cb9
cba 0 d5 :4 0
15b :4 0 d8 :2 0
d9 :3 0 68c cbe
cc0 :3 0 68f cbb
cc2 :2 0 cc4 692
cc5 cb8 cc4 0
cc6 694 0 cd1
103 :3 0 104 :3 0
cc7 cc8 0 1a
:3 0 159 :3 0 cca
ccb 0 27 :3 0
105 :3 0 696 cc9
ccf :2 0 cd1 69a
cd2 c63 cd1 0
cd3 69e 0 cd4
6a0 cd5 bf2 cd4
0 cd6 6a4 0
cd7 6a6 cd8 b81
cd7 0 cd9 6a9
0 cdb 15c :3 0
6ab de2 15d :3 0
8f :3 0 4b :3 0
45 :2 0 6ad cdd
ce0 6b0 cdc ce2
14e :2 0 45 :2 0
6b4 ce4 ce6 :3 0
8f :3 0 6c :3 0
45 :2 0 6b7 ce8
ceb e7 :2 0 45
:2 0 6bc ced cef
:3 0 8f :3 0 81
:3 0 45 :2 0 6bf
cf1 cf4 e7 :2 0
45 :2 0 6c4 cf6
cf8 :3 0 cf0 cfa
cf9 :2 0 cfb :2 0
ce7 cfd cfc :2 0
75 :3 0 45 :2 0
cff d00 0 de0
147 :3 0 75 :3 0
14f :3 0 9d :3 0
9e :3 0 28 :3 0
9f :3 0 27 :3 0
a0 :3 0 a1 :4 0
15e 1 :8 0 d12
15 :3 0 ee :3 0
d0d d0e 0 f1
:3 0 d0f d10 0
d12 6c7 d65 f2
:3 0 15 :3 0 ee
:3 0 d14 d15 0
f1 :3 0 d16 d17
0 d19 6ca d1b
6cc d1a d19 :2 0
d63 f3 :3 0 15
:3 0 ee :3 0 d1e
d1f 0 f1 :3 0
d20 d21 0 d5b
d0 :3 0 d1 :3 0
d23 d24 0 d0
:3 0 e0 :3 0 d26
d27 0 f4 :2 0
2 :4 0 15f :2 0
e2 :2 0 30 :2 0
6ce d2c d2e :3 0
6d1 d28 d30 d25
d32 d31 :2 0 d3
:3 0 e3 :3 0 d34
d35 0 d5 :4 0
160 :4 0 d8 :2 0
d9 :3 0 6d5 d39
d3b :3 0 d8 :2 0
f7 :4 0 6d8 d3d
d3f :3 0 d8 :2 0
f8 :4 0 6db d41
d43 :3 0 d8 :2 0
f1 :3 0 6de d45
d47 :3 0 d8 :2 0
f9 :4 0 6e1 d49
d4b :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
6e4 d4e d52 6e8
d4d d54 :3 0 6eb
d36 d56 :2 0 d58
6ee d59 d33 d58
0 d5a 6f0 0
d5b 6f2 d5e :3 0
d5e 0 d5e d5d
d5b d5c :6 0 d60
19 :3 0 6f5 d62
6f7 d61 d60 :2 0
d63 6f9 :2 0 d65
0 d65 d64 d12
d63 :6 0 de0 1
:3 0 8f :3 0 75
:3 0 45 :2 0 6fc
d67 d6a 117 :2 0
45 :2 0 701 d6c
d6e :3 0 d0 :3 0
d1 :3 0 d70 d71
0 d0 :3 0 e0
:3 0 d73 d74 0
1d :2 0 2 :4 0
161 :2 0 e2 :2 0
30 :2 0 704 d79
d7b :3 0 707 d75
d7d d72 d7f d7e
:2 0 d3 :3 0 e3
:3 0 d81 d82 0
d5 :4 0 162 :4 0
d8 :2 0 d9 :3 0
70b d86 d88 :3 0
d8 :2 0 f7 :4 0
70e d8a d8c :3 0
d8 :2 0 fe :4 0
711 d8e d90 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
159 :3 0 d95 d96
0 714 d94 d98
de :4 0 716 d93
d9b 719 d92 d9d
:3 0 d8 :2 0 100
:4 0 71c d9f da1
:3 0 d8 :2 0 db
:4 0 71f da3 da5
:3 0 d8 :2 0 27
:3 0 722 da7 da9
:3 0 d8 :2 0 db
:4 0 725 dab dad
:3 0 728 d83 daf
:2 0 db1 72b db2
d80 db1 0 db3
72d 0 ddd d0
:3 0 d1 :3 0 db4
db5 0 d0 :3 0
e0 :3 0 db7 db8
0 30 :2 0 2
:4 0 163 :2 0 e2
:2 0 30 :2 0 72f
dbd dbf :3 0 732
db9 dc1 db6 dc3
dc2 :2 0 d3 :3 0
e3 :3 0 dc5 dc6
0 d5 :4 0 164
:4 0 d8 :2 0 d9
:3 0 736 dca dcc
:3 0 739 dc7 dce
:2 0 dd0 73c dd1
dc4 dd0 0 dd2
73e 0 ddd 103
:3 0 104 :3 0 dd3
dd4 0 1a :3 0
159 :3 0 dd6 dd7
0 27 :3 0 105
:3 0 740 dd5 ddb
:2 0 ddd 744 dde
d6f ddd 0 ddf
748 0 de0 74a
de1 cfe de0 0
de3 b78 cdb 0
de3 74e 0 51ec
36 :3 0 45 :4 0
de4 de5 0 51ec
20 :3 0 eb :4 0
de7 de8 0 51ec
21 :3 0 eb :4 0
dea deb 0 51ec
23 :4 0 ded dee
0 51ec 8b :4 0
df0 df1 0 51ec
2a :4 0 df3 df4
0 51ec ec :3 0
9b :4 0 df9 :2 0
51ec df7 dfa :3 0
9b :3 0 5f :4 0
dfe :2 0 51ec dfb
dfc :3 0 9b :3 0
ed :3 0 dff e00
:3 0 15 :3 0 ee
:3 0 e02 e03 0
45 :2 0 e04 e05
0 e07 751 e0e
15 :3 0 ee :3 0
e08 e09 0 ef
:2 0 e0a e0b 0
e0d 753 e0f e01
e07 0 e10 0
e0d 0 e10 755
0 51ec 15 :3 0
ee :3 0 e11 e12
0 15 :3 0 e7
:2 0 165 :3 0 e14
e16 0 75a e15
e18 :3 0 e19 :2 0
55 :3 0 45 :2 0
e1b e1c 0 e1e
75d e23 55 :3 0
146 :2 0 e1f e20
0 e22 75f e24
e1a e1e 0 e25
0 e22 0 e25
761 0 51ec f0
:3 0 9b :4 0 e29
:2 0 e2f e27 0
15 :3 0 ee :3 0
e2a e2b 0 f1
:3 0 e2c e2d 0
e2f 764 e82 f2
:3 0 15 :3 0 ee
:3 0 e31 e32 0
f1 :3 0 e33 e34
0 e36 767 e38
769 e37 e36 :2 0
e80 f3 :3 0 15
:3 0 ee :3 0 e3b
e3c 0 f1 :3 0
e3d e3e 0 e78
d0 :3 0 d1 :3 0
e40 e41 0 d0
:3 0 e0 :3 0 e43
e44 0 f4 :2 0
2 :4 0 166 :2 0
e2 :2 0 30 :2 0
76b e49 e4b :3 0
76e e45 e4d e42
e4f e4e :2 0 d3
:3 0 e3 :3 0 e51
e52 0 d5 :4 0
167 :4 0 d8 :2 0
d9 :3 0 772 e56
e58 :3 0 d8 :2 0
f7 :4 0 775 e5a
e5c :3 0 d8 :2 0
f8 :4 0 778 e5e
e60 :3 0 d8 :2 0
f1 :3 0 77b e62
e64 :3 0 d8 :2 0
f9 :4 0 77e e66
e68 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
781 e6b e6f 785
e6a e71 :3 0 788
e53 e73 :2 0 e75
78b e76 e50 e75
0 e77 78d 0
e78 78f e7b :3 0
e7b 0 e7b e7a
e78 e79 :6 0 e7d
1b :3 0 792 e7f
794 e7e e7d :2 0
e80 796 :2 0 e82
0 e82 e81 e2f
e80 :6 0 51ec 1
:3 0 8f :3 0 55
:3 0 45 :2 0 799
e84 e87 e7 :2 0
146 :2 0 79e e89
e8b :3 0 8f :3 0
6c :3 0 45 :2 0
7a1 e8d e90 e7
:2 0 146 :2 0 7a6
e92 e94 :3 0 55
:3 0 45 :2 0 e96
e97 0 e99 7a9
e9a e95 e99 0
e9b 7ab 0 e9c
7ad e9d e8c e9c
0 e9e 7af 0
51ec 168 :3 0 41
:3 0 13b :3 0 13c
:3 0 29 :4 0 169
1 :8 0 eaa 15
:3 0 ee :3 0 ea5
ea6 0 f1 :3 0
ea7 ea8 0 eaa
7b1 efd f2 :3 0
15 :3 0 ee :3 0
eac ead 0 f1
:3 0 eae eaf 0
eb1 7b4 eb3 7b6
eb2 eb1 :2 0 efb
f3 :3 0 15 :3 0
ee :3 0 eb6 eb7
0 f1 :3 0 eb8
eb9 0 ef3 d0
:3 0 d1 :3 0 ebb
ebc 0 d0 :3 0
e0 :3 0 ebe ebf
0 f4 :2 0 2
:4 0 16a :2 0 e2
:2 0 30 :2 0 7b8
ec4 ec6 :3 0 7bb
ec0 ec8 ebd eca
ec9 :2 0 d3 :3 0
e3 :3 0 ecc ecd
0 d5 :4 0 16b
:4 0 d8 :2 0 d9
:3 0 7bf ed1 ed3
:3 0 d8 :2 0 f7
:4 0 7c2 ed5 ed7
:3 0 d8 :2 0 f8
:4 0 7c5 ed9 edb
:3 0 d8 :2 0 f1
:3 0 7c8 edd edf
:3 0 d8 :2 0 f9
:4 0 7cb ee1 ee3
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 7ce
ee6 eea 7d2 ee5
eec :3 0 7d5 ece
eee :2 0 ef0 7d8
ef1 ecb ef0 0
ef2 7da 0 ef3
7dc ef6 :3 0 ef6
0 ef6 ef5 ef3
ef4 :6 0 ef8 1d
:3 0 7df efa 7e1
ef9 ef8 :2 0 efb
7e3 :2 0 efd 0
efd efc eaa efb
:6 0 51ec 1 :3 0
a5 :3 0 16c :3 0
21 :3 0 5e :3 0
bd :3 0 99 :3 0
28 :3 0 a0 :3 0
36 :3 0 9f :3 0
27 :4 0 16d 1
:8 0 f10 15 :3 0
ee :3 0 f0b f0c
0 f1 :3 0 f0d
f0e 0 f10 7e6
f63 f2 :3 0 15
:3 0 ee :3 0 f12
f13 0 f1 :3 0
f14 f15 0 f17
7e9 f19 7eb f18
f17 :2 0 f61 f3
:3 0 15 :3 0 ee
:3 0 f1c f1d 0
f1 :3 0 f1e f1f
0 f59 d0 :3 0
d1 :3 0 f21 f22
0 d0 :3 0 e0
:3 0 f24 f25 0
f4 :2 0 2 :4 0
16e :2 0 e2 :2 0
30 :2 0 7ed f2a
f2c :3 0 7f0 f26
f2e f23 f30 f2f
:2 0 d3 :3 0 e3
:3 0 f32 f33 0
d5 :4 0 16f :4 0
d8 :2 0 d9 :3 0
7f4 f37 f39 :3 0
d8 :2 0 f7 :4 0
7f7 f3b f3d :3 0
d8 :2 0 f8 :4 0
7fa f3f f41 :3 0
d8 :2 0 f1 :3 0
7fd f43 f45 :3 0
d8 :2 0 f9 :4 0
800 f47 f49 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 803 f4c
f50 807 f4b f52
:3 0 80a f34 f54
:2 0 f56 80d f57
f31 f56 0 f58
80f 0 f59 811
f5c :3 0 f5c 0
f5c f5b f59 f5a
:6 0 f5e 1f :3 0
814 f60 816 f5f
f5e :2 0 f61 818
:2 0 f63 0 f63
f62 f10 f61 :6 0
51ec 1 :3 0 15
:3 0 ee :3 0 f65
f66 0 15 :3 0
e7 :2 0 10d :3 0
f68 f6a 0 81d
f69 f6c :3 0 f6d
:2 0 8f :3 0 6c
:3 0 45 :2 0 820
f6f f72 14e :2 0
45 :2 0 825 f74
f76 :3 0 153 :2 0
828 f78 f79 :3 0
f6e f7b f7a :2 0
21 :3 0 eb :4 0
f7d f7e 0 12b2
21 :3 0 170 :4 0
f81 f82 :3 0 f80
f83 0 12b2 16c
:3 0 171 :3 0 5e
:3 0 78 :3 0 bd
:3 0 99 :3 0 28
:3 0 a0 :3 0 9f
:3 0 29 :4 0 172
1 :8 0 f95 15
:3 0 ee :3 0 f90
f91 0 f1 :3 0
f92 f93 0 f95
82a fe8 f2 :3 0
15 :3 0 ee :3 0
f97 f98 0 f1
:3 0 f99 f9a 0
f9c 82d f9e 82f
f9d f9c :2 0 fe6
f3 :3 0 15 :3 0
ee :3 0 fa1 fa2
0 f1 :3 0 fa3
fa4 0 fde d0
:3 0 d1 :3 0 fa6
fa7 0 d0 :3 0
e0 :3 0 fa9 faa
0 f4 :2 0 2
:4 0 173 :2 0 e2
:2 0 30 :2 0 831
faf fb1 :3 0 834
fab fb3 fa8 fb5
fb4 :2 0 d3 :3 0
e3 :3 0 fb7 fb8
0 d5 :4 0 174
:4 0 d8 :2 0 d9
:3 0 838 fbc fbe
:3 0 d8 :2 0 f7
:4 0 83b fc0 fc2
:3 0 d8 :2 0 f8
:4 0 83e fc4 fc6
:3 0 d8 :2 0 f1
:3 0 841 fc8 fca
:3 0 d8 :2 0 f9
:4 0 844 fcc fce
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 847
fd1 fd5 84b fd0
fd7 :3 0 84e fb9
fd9 :2 0 fdb 851
fdc fb6 fdb 0
fdd 853 0 fde
855 fe1 :3 0 fe1
0 fe1 fe0 fde
fdf :6 0 fe3 21
:3 0 858 fe5 85a
fe4 fe3 :2 0 fe6
85c :2 0 fe8 0
fe8 fe7 f95 fe6
:6 0 12b2 1 :3 0
15 :3 0 ee :3 0
fea feb 0 15
:3 0 e7 :2 0 165
:3 0 fed fef 0
861 fee ff1 :3 0
ff2 :2 0 77 :3 0
175 :3 0 176 :3 0
ff5 ff6 0 8f
:3 0 5e :3 0 45
:2 0 864 ff8 ffb
1a :3 0 177 :3 0
ffd ffe 0 867
ff7 1000 ff4 1001
0 1003 86a 1019
7b :3 0 178 :3 0
45 :2 0 8f :3 0
4a :3 0 45 :2 0
86c 1007 100a 1a
:3 0 179 :3 0 100c
100d 0 78 :3 0
86f 1005 1010 1004
1011 0 1018 77
:3 0 1a :3 0 177
:3 0 1014 1015 0
1013 1016 0 1018
874 101a ff3 1003
0 101b 0 1018
0 101b 877 0
12b2 76 :3 0 45
:4 0 101c 101d 0
12b2 7a :3 0 30
:2 0 101f 1020 0
12b2 7b :3 0 17a
:3 0 28 :3 0 27
:3 0 4a :3 0 77
:3 0 78 :3 0 76
:3 0 7a :3 0 87a
1023 102b 1022 102c
0 12b2 85 :3 0
17b :3 0 8f :3 0
4a :3 0 45 :2 0
882 1030 1033 885
102f 1035 102e 1036
0 12b2 bd :3 0
a5 :3 0 9e :3 0
99 :3 0 a9 :3 0
a0 :3 0 9f :3 0
13c :3 0 16c :3 0
171 :3 0 17c :3 0
17d :3 0 17e :3 0
21 :3 0 28 :3 0
28 :3 0 4a :3 0
36 :3 0 27 :3 0
29 :3 0 77 :3 0
78 :3 0 85 :3 0
13 :3 0 d9 :4 0
17f 1 :8 0 1067
ed :4 0 1052 :3 0
105 :3 0 e7 :2 0
889 1055 1056 :3 0
15 :3 0 ee :3 0
1058 1059 0 45
:2 0 105a 105b 0
105d 88c 1064 15
:3 0 ee :3 0 105e
105f 0 ef :2 0
1060 1061 0 1063
88e 1065 1057 105d
0 1066 0 1063
0 1066 890 0
1067 893 10ba f2
:3 0 15 :3 0 ee
:3 0 1069 106a 0
f1 :3 0 106b 106c
0 106e 896 1070
898 106f 106e :2 0
10b8 f3 :3 0 15
:3 0 ee :3 0 1073
1074 0 f1 :3 0
1075 1076 0 10b0
d0 :3 0 d1 :3 0
1078 1079 0 d0
:3 0 e0 :3 0 107b
107c 0 f4 :2 0
2 :4 0 180 :2 0
e2 :2 0 30 :2 0
89a 1081 1083 :3 0
89d 107d 1085 107a
1087 1086 :2 0 d3
:3 0 e3 :3 0 1089
108a 0 d5 :4 0
181 :4 0 d8 :2 0
d9 :3 0 8a1 108e
1090 :3 0 d8 :2 0
f7 :4 0 8a4 1092
1094 :3 0 d8 :2 0
f8 :4 0 8a7 1096
1098 :3 0 d8 :2 0
f1 :3 0 8aa 109a
109c :3 0 d8 :2 0
f9 :4 0 8ad 109e
10a0 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
8b0 10a3 10a7 8b4
10a2 10a9 :3 0 8b7
108b 10ab :2 0 10ad
8ba 10ae 1088 10ad
0 10af 8bc 0
10b0 8be 10b3 :3 0
10b3 0 10b3 10b2
10b0 10b1 :6 0 10b5
23 :3 0 8c1 10b7
8c3 10b6 10b5 :2 0
10b8 8c5 :2 0 10ba
0 10ba 10b9 1067
10b8 :6 0 12b2 1
:3 0 123 :3 0 140
:3 0 10bc 10bd 0
28 :3 0 26 :3 0
8c8 10be 10c1 e7
:2 0 45 :2 0 8cd
10c3 10c5 :3 0 4c
:3 0 45 :2 0 10c7
10c8 0 10ca 8d0
1133 147 :3 0 a7
:3 0 4c :3 0 9d
:3 0 9e :3 0 28
:3 0 a8 :3 0 26
:3 0 9f :3 0 29
:3 0 a0 :3 0 182
:4 0 183 1 :8 0
10dd 15 :3 0 ee
:3 0 10d8 10d9 0
f1 :3 0 10da 10db
0 10dd 8d2 1130
f2 :3 0 15 :3 0
ee :3 0 10df 10e0
0 f1 :3 0 10e1
10e2 0 10e4 8d5
10e6 8d7 10e5 10e4
:2 0 112e f3 :3 0
15 :3 0 ee :3 0
10e9 10ea 0 f1
:3 0 10eb 10ec 0
1126 d0 :3 0 d1
:3 0 10ee 10ef 0
d0 :3 0 e0 :3 0
10f1 10f2 0 f4
:2 0 2 :4 0 184
:2 0 e2 :2 0 30
:2 0 8d9 10f7 10f9
:3 0 8dc 10f3 10fb
10f0 10fd 10fc :2 0
d3 :3 0 e3 :3 0
10ff 1100 0 d5
:4 0 185 :4 0 d8
:2 0 d9 :3 0 8e0
1104 1106 :3 0 d8
:2 0 f7 :4 0 8e3
1108 110a :3 0 d8
:2 0 f8 :4 0 8e6
110c 110e :3 0 d8
:2 0 f1 :3 0 8e9
1110 1112 :3 0 d8
:2 0 f9 :4 0 8ec
1114 1116 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 8ef 1119 111d
8f3 1118 111f :3 0
8f6 1101 1121 :2 0
1123 8f9 1124 10fe
1123 0 1125 8fb
0 1126 8fd 1129
:3 0 1129 0 1129
1128 1126 1127 :6 0
112b 25 :3 0 900
112d 902 112c 112b
:2 0 112e 904 :2 0
1130 0 1130 112f
10dd 112e :6 0 1132
1 :3 0 907 1134
10c6 10ca 0 1135
0 1132 0 1135
909 0 12b2 8f
:3 0 4c :3 0 45
:2 0 90c 1136 1139
e7 :2 0 45 :2 0
911 113b 113d :3 0
bc :3 0 186 :3 0
187 :3 0 186 :3 0
41 :3 0 3e :3 0
99 :3 0 28 :3 0
9e :3 0 28 :4 0
188 1 :8 0 115f
ed :4 0 114a :3 0
105 :3 0 e7 :2 0
916 114d 114e :3 0
15 :3 0 ee :3 0
1150 1151 0 45
:2 0 1152 1153 0
1155 919 115c 15
:3 0 ee :3 0 1156
1157 0 ef :2 0
1158 1159 0 115b
91b 115d 114f 1155
0 115e 0 115b
0 115e 91d 0
115f 920 11b2 f2
:3 0 15 :3 0 ee
:3 0 1161 1162 0
f1 :3 0 1163 1164
0 1166 923 1168
925 1167 1166 :2 0
11b0 f3 :3 0 15
:3 0 ee :3 0 116b
116c 0 f1 :3 0
116d 116e 0 11a8
d0 :3 0 d1 :3 0
1170 1171 0 d0
:3 0 e0 :3 0 1173
1174 0 f4 :2 0
2 :4 0 189 :2 0
e2 :2 0 30 :2 0
927 1179 117b :3 0
92a 1175 117d 1172
117f 117e :2 0 d3
:3 0 e3 :3 0 1181
1182 0 d5 :4 0
18a :4 0 d8 :2 0
d9 :3 0 92e 1186
1188 :3 0 d8 :2 0
f7 :4 0 931 118a
118c :3 0 d8 :2 0
f8 :4 0 934 118e
1190 :3 0 d8 :2 0
f1 :3 0 937 1192
1194 :3 0 d8 :2 0
f9 :4 0 93a 1196
1198 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
93d 119b 119f 941
119a 11a1 :3 0 944
1183 11a3 :2 0 11a5
947 11a6 1180 11a5
0 11a7 949 0
11a8 94b 11ab :3 0
11ab 0 11ab 11aa
11a8 11a9 :6 0 11ad
27 :3 0 94e 11af
950 11ae 11ad :2 0
11b0 952 :2 0 11b2
0 11b2 11b1 115f
11b0 :6 0 1230 1
:3 0 bc :3 0 186
:3 0 18b :3 0 186
:3 0 3e :3 0 186
:3 0 18c :3 0 3e
:3 0 18c :3 0 186
:3 0 186 :3 0 186
:3 0 3e :3 0 9e
:3 0 28 :3 0 99
:3 0 28 :4 0 18d
1 :8 0 11db ed
:4 0 11c6 :3 0 105
:3 0 e7 :2 0 957
11c9 11ca :3 0 15
:3 0 ee :3 0 11cc
11cd 0 45 :2 0
11ce 11cf 0 11d1
95a 11d8 15 :3 0
ee :3 0 11d2 11d3
0 ef :2 0 11d4
11d5 0 11d7 95c
11d9 11cb 11d1 0
11da 0 11d7 0
11da 95e 0 11db
961 122e f2 :3 0
15 :3 0 ee :3 0
11dd 11de 0 f1
:3 0 11df 11e0 0
11e2 964 11e4 966
11e3 11e2 :2 0 122c
f3 :3 0 15 :3 0
ee :3 0 11e7 11e8
0 f1 :3 0 11e9
11ea 0 1224 d0
:3 0 d1 :3 0 11ec
11ed 0 d0 :3 0
e0 :3 0 11ef 11f0
0 f4 :2 0 2
:4 0 18e :2 0 e2
:2 0 30 :2 0 968
11f5 11f7 :3 0 96b
11f1 11f9 11ee 11fb
11fa :2 0 d3 :3 0
e3 :3 0 11fd 11fe
0 d5 :4 0 18f
:4 0 d8 :2 0 d9
:3 0 96f 1202 1204
:3 0 d8 :2 0 f7
:4 0 972 1206 1208
:3 0 d8 :2 0 f8
:4 0 975 120a 120c
:3 0 d8 :2 0 f1
:3 0 978 120e 1210
:3 0 d8 :2 0 f9
:4 0 97b 1212 1214
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 97e
1217 121b 982 1216
121d :3 0 985 11ff
121f :2 0 1221 988
1222 11fc 1221 0
1223 98a 0 1224
98c 1227 :3 0 1227
0 1227 1226 1224
1225 :6 0 1229 29
:3 0 98f 122b 991
122a 1229 :2 0 122c
993 :2 0 122e 0
122e 122d 11db 122c
:6 0 1230 1 :3 0
996 12ae bc :3 0
186 :3 0 18b :3 0
186 :3 0 3e :3 0
186 :3 0 18c :3 0
3e :3 0 18c :3 0
186 :3 0 186 :3 0
186 :3 0 3e :3 0
9e :3 0 28 :3 0
99 :3 0 28 :4 0
18d 1 :8 0 1258
ed :4 0 1243 :3 0
105 :3 0 e7 :2 0
99b 1246 1247 :3 0
15 :3 0 ee :3 0
1249 124a 0 45
:2 0 124b 124c 0
124e 99e 1255 15
:3 0 ee :3 0 124f
1250 0 ef :2 0
1251 1252 0 1254
9a0 1256 1248 124e
0 1257 0 1254
0 1257 9a2 0
1258 9a5 12ab f2
:3 0 15 :3 0 ee
:3 0 125a 125b 0
f1 :3 0 125c 125d
0 125f 9a8 1261
9aa 1260 125f :2 0
12a9 f3 :3 0 15
:3 0 ee :3 0 1264
1265 0 f1 :3 0
1266 1267 0 12a1
d0 :3 0 d1 :3 0
1269 126a 0 d0
:3 0 e0 :3 0 126c
126d 0 f4 :2 0
2 :4 0 190 :2 0
e2 :2 0 30 :2 0
9ac 1272 1274 :3 0
9af 126e 1276 126b
1278 1277 :2 0 d3
:3 0 e3 :3 0 127a
127b 0 d5 :4 0
191 :4 0 d8 :2 0
d9 :3 0 9b3 127f
1281 :3 0 d8 :2 0
f7 :4 0 9b6 1283
1285 :3 0 d8 :2 0
f8 :4 0 9b9 1287
1289 :3 0 d8 :2 0
f1 :3 0 9bc 128b
128d :3 0 d8 :2 0
f9 :4 0 9bf 128f
1291 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
9c2 1294 1298 9c6
1293 129a :3 0 9c9
127c 129c :2 0 129e
9cc 129f 1279 129e
0 12a0 9ce 0
12a1 9d0 12a4 :3 0
12a4 0 12a4 12a3
12a1 12a2 :6 0 12a6
2b :3 0 9d3 12a8
9d5 12a7 12a6 :2 0
12a9 9d7 :2 0 12ab
0 12ab 12aa 1258
12a9 :6 0 12ad 1
:3 0 9da 12af 113e
1230 0 12b0 0
12ad 0 12b0 9dc
0 12b2 15c :3 0
9df 15e6 15 :3 0
ee :3 0 12b3 12b4
0 15 :3 0 e7
:2 0 165 :3 0 12b6
12b8 0 9ed 12b7
12ba :3 0 12bb :2 0
bc :3 0 186 :3 0
123 :3 0 192 :3 0
3e :3 0 186 :3 0
187 :3 0 186 :3 0
41 :3 0 187 :3 0
186 :3 0 41 :3 0
3e :3 0 99 :3 0
28 :3 0 9e :3 0
28 :4 0 193 1
:8 0 12e4 ed :4 0
12cf :3 0 105 :3 0
e7 :2 0 9f2 12d2
12d3 :3 0 15 :3 0
ee :3 0 12d5 12d6
0 45 :2 0 12d7
12d8 0 12da 9f5
12e1 15 :3 0 ee
:3 0 12db 12dc 0
ef :2 0 12dd 12de
0 12e0 9f7 12e2
12d4 12da 0 12e3
0 12e0 0 12e3
9f9 0 12e4 9fc
1337 f2 :3 0 15
:3 0 ee :3 0 12e6
12e7 0 f1 :3 0
12e8 12e9 0 12eb
9ff 12ed a01 12ec
12eb :2 0 1335 f3
:3 0 15 :3 0 ee
:3 0 12f0 12f1 0
f1 :3 0 12f2 12f3
0 132d d0 :3 0
d1 :3 0 12f5 12f6
0 d0 :3 0 e0
:3 0 12f8 12f9 0
f4 :2 0 2 :4 0
194 :2 0 e2 :2 0
30 :2 0 a03 12fe
1300 :3 0 a06 12fa
1302 12f7 1304 1303
:2 0 d3 :3 0 e3
:3 0 1306 1307 0
d5 :4 0 195 :4 0
d8 :2 0 d9 :3 0
a0a 130b 130d :3 0
d8 :2 0 f7 :4 0
a0d 130f 1311 :3 0
d8 :2 0 f8 :4 0
a10 1313 1315 :3 0
d8 :2 0 f1 :3 0
a13 1317 1319 :3 0
d8 :2 0 f9 :4 0
a16 131b 131d :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 a19 1320
1324 a1d 131f 1326
:3 0 a20 1308 1328
:2 0 132a a23 132b
1305 132a 0 132c
a25 0 132d a27
1330 :3 0 1330 0
1330 132f 132d 132e
:6 0 1332 2d :3 0
a2a 1334 a2c 1333
1332 :2 0 1335 a2e
:2 0 1337 0 1337
1336 12e4 1335 :6 0
15e4 1 :3 0 2f
:3 0 45 :4 0 1339
133a 0 15e4 a7
:3 0 23 :3 0 9d
:3 0 a5 :3 0 21
:3 0 182 :4 0 196
1 :8 0 1348 15
:3 0 ee :3 0 1343
1344 0 f1 :3 0
1345 1346 0 1348
a31 139b f2 :3 0
15 :3 0 ee :3 0
134a 134b 0 f1
:3 0 134c 134d 0
134f a34 1351 a36
1350 134f :2 0 1399
f3 :3 0 15 :3 0
ee :3 0 1354 1355
0 f1 :3 0 1356
1357 0 1391 d0
:3 0 d1 :3 0 1359
135a 0 d0 :3 0
e0 :3 0 135c 135d
0 f4 :2 0 2
:4 0 197 :2 0 e2
:2 0 30 :2 0 a38
1362 1364 :3 0 a3b
135e 1366 135b 1368
1367 :2 0 d3 :3 0
e3 :3 0 136a 136b
0 d5 :4 0 198
:4 0 d8 :2 0 d9
:3 0 a3f 136f 1371
:3 0 d8 :2 0 f7
:4 0 a42 1373 1375
:3 0 d8 :2 0 f8
:4 0 a45 1377 1379
:3 0 d8 :2 0 f1
:3 0 a48 137b 137d
:3 0 d8 :2 0 f9
:4 0 a4b 137f 1381
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 a4e
1384 1388 a52 1383
138a :3 0 a55 136c
138c :2 0 138e a58
138f 1369 138e 0
1390 a5a 0 1391
a5c 1394 :3 0 1394
0 1394 1393 1391
1392 :6 0 1396 2f
:3 0 a5f 1398 a61
1397 1396 :2 0 1399
a63 :2 0 139b 0
139b 139a 1348 1399
:6 0 15e4 1 :3 0
15 :3 0 ee :3 0
139d 139e 0 15
:3 0 e7 :2 0 10d
:3 0 13a0 13a2 0
a68 13a1 13a4 :3 0
13a5 :2 0 a7 :3 0
23 :3 0 9d :3 0
a5 :3 0 21 :3 0
182 :4 0 199 1
:8 0 13b3 15 :3 0
ee :3 0 13ae 13af
0 f1 :3 0 13b0
13b1 0 13b3 a6b
1406 f2 :3 0 15
:3 0 ee :3 0 13b5
13b6 0 f1 :3 0
13b7 13b8 0 13ba
a6e 13bc a70 13bb
13ba :2 0 1404 f3
:3 0 15 :3 0 ee
:3 0 13bf 13c0 0
f1 :3 0 13c1 13c2
0 13fc d0 :3 0
d1 :3 0 13c4 13c5
0 d0 :3 0 e0
:3 0 13c7 13c8 0
f4 :2 0 2 :4 0
19a :2 0 e2 :2 0
30 :2 0 a72 13cd
13cf :3 0 a75 13c9
13d1 13c6 13d3 13d2
:2 0 d3 :3 0 e3
:3 0 13d5 13d6 0
d5 :4 0 19b :4 0
d8 :2 0 d9 :3 0
a79 13da 13dc :3 0
d8 :2 0 f7 :4 0
a7c 13de 13e0 :3 0
d8 :2 0 f8 :4 0
a7f 13e2 13e4 :3 0
d8 :2 0 f1 :3 0
a82 13e6 13e8 :3 0
d8 :2 0 f9 :4 0
a85 13ea 13ec :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 a88 13ef
13f3 a8c 13ee 13f5
:3 0 a8f 13d7 13f7
:2 0 13f9 a92 13fa
13d4 13f9 0 13fb
a94 0 13fc a96
13ff :3 0 13ff 0
13ff 13fe 13fc 13fd
:6 0 1401 31 :3 0
a99 1403 a9b 1402
1401 :2 0 1404 a9d
:2 0 1406 0 1406
1405 13b3 1404 :6 0
1418 1 :3 0 15
:3 0 ee :3 0 1408
1409 0 15 :3 0
e7 :2 0 165 :3 0
140b 140d 0 aa2
140c 140f :3 0 1410
:2 0 2f :3 0 146
:4 0 1412 1413 0
1415 aa5 1416 1411
1415 0 1417 aa7
0 1418 aa9 1419
13a6 1418 0 141a
aac 0 15e4 8f
:3 0 6c :3 0 45
:2 0 aae 141b 141e
14e :2 0 45 :2 0
ab3 1420 1422 :3 0
153 :2 0 ab6 1424
1425 :3 0 8f :3 0
5e :3 0 45 :2 0
ab8 1427 142a 1a
:3 0 e7 :2 0 19c
:3 0 142c 142e 0
abd 142d 1430 :3 0
7b :3 0 178 :3 0
45 :2 0 8f :3 0
4a :3 0 45 :2 0
ac0 1435 1438 1a
:3 0 179 :3 0 143a
143b 0 78 :3 0
ac3 1433 143e 1432
143f 0 14bd bd
:3 0 13c :3 0 29
:3 0 16c :3 0 1a
:3 0 177 :3 0 171
:3 0 78 :3 0 a5
:3 0 21 :4 0 19d
1 :8 0 1461 ed
:4 0 144c :3 0 105
:3 0 e7 :2 0 aca
144f 1450 :3 0 15
:3 0 ee :3 0 1452
1453 0 45 :2 0
1454 1455 0 1457
acd 145e 15 :3 0
ee :3 0 1458 1459
0 ef :2 0 145a
145b 0 145d acf
145f 1451 1457 0
1460 0 145d 0
1460 ad1 0 1461
ad4 14b4 f2 :3 0
15 :3 0 ee :3 0
1463 1464 0 f1
:3 0 1465 1466 0
1468 ad7 146a ad9
1469 1468 :2 0 14b2
f3 :3 0 15 :3 0
ee :3 0 146d 146e
0 f1 :3 0 146f
1470 0 14aa d0
:3 0 d1 :3 0 1472
1473 0 d0 :3 0
e0 :3 0 1475 1476
0 f4 :2 0 2
:4 0 19e :2 0 e2
:2 0 30 :2 0 adb
147b 147d :3 0 ade
1477 147f 1474 1481
1480 :2 0 d3 :3 0
e3 :3 0 1483 1484
0 d5 :4 0 19f
:4 0 d8 :2 0 d9
:3 0 ae2 1488 148a
:3 0 d8 :2 0 f7
:4 0 ae5 148c 148e
:3 0 d8 :2 0 f8
:4 0 ae8 1490 1492
:3 0 d8 :2 0 f1
:3 0 aeb 1494 1496
:3 0 d8 :2 0 f9
:4 0 aee 1498 149a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 af1
149d 14a1 af5 149c
14a3 :3 0 af8 1485
14a5 :2 0 14a7 afb
14a8 1482 14a7 0
14a9 afd 0 14aa
aff 14ad :3 0 14ad
0 14ad 14ac 14aa
14ab :6 0 14af 33
:3 0 b02 14b1 b04
14b0 14af :2 0 14b2
b06 :2 0 14b4 0
14b4 14b3 1461 14b2
:6 0 14bd 1 :3 0
7b :3 0 1a0 :3 0
21 :3 0 b09 14b7
14b9 14b6 14ba 0
14bd 15c :3 0 b0b
15df e5 :3 0 8f
:3 0 5e :3 0 45
:2 0 b0f 14bf 14c2
1a :3 0 177 :3 0
14c4 14c5 0 b12
14be 14c7 14c8 :2 0
1a :3 0 14e :2 0
177 :3 0 14ca 14cc
0 b17 14cb 14ce
:3 0 bd :3 0 13c
:3 0 29 :3 0 16c
:3 0 1a1 :3 0 176
:3 0 16c :3 0 1a
:3 0 177 :3 0 a5
:3 0 21 :4 0 1a2
1 :8 0 14f1 ed
:4 0 14dc :3 0 105
:3 0 e7 :2 0 b1c
14df 14e0 :3 0 15
:3 0 ee :3 0 14e2
14e3 0 45 :2 0
14e4 14e5 0 14e7
b1f 14ee 15 :3 0
ee :3 0 14e8 14e9
0 ef :2 0 14ea
14eb 0 14ed b21
14ef 14e1 14e7 0
14f0 0 14ed 0
14f0 b23 0 14f1
b26 1544 f2 :3 0
15 :3 0 ee :3 0
14f3 14f4 0 f1
:3 0 14f5 14f6 0
14f8 b29 14fa b2b
14f9 14f8 :2 0 1542
f3 :3 0 15 :3 0
ee :3 0 14fd 14fe
0 f1 :3 0 14ff
1500 0 153a d0
:3 0 d1 :3 0 1502
1503 0 d0 :3 0
e0 :3 0 1505 1506
0 f4 :2 0 2
:4 0 1a3 :2 0 e2
:2 0 30 :2 0 b2d
150b 150d :3 0 b30
1507 150f 1504 1511
1510 :2 0 d3 :3 0
e3 :3 0 1513 1514
0 d5 :4 0 1a4
:4 0 d8 :2 0 d9
:3 0 b34 1518 151a
:3 0 d8 :2 0 f7
:4 0 b37 151c 151e
:3 0 d8 :2 0 f8
:4 0 b3a 1520 1522
:3 0 d8 :2 0 f1
:3 0 b3d 1524 1526
:3 0 d8 :2 0 f9
:4 0 b40 1528 152a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 b43
152d 1531 b47 152c
1533 :3 0 b4a 1515
1535 :2 0 1537 b4d
1538 1512 1537 0
1539 b4f 0 153a
b51 153d :3 0 153d
0 153d 153c 153a
153b :6 0 153f 35
:3 0 b54 1541 b56
1540 153f :2 0 1542
b58 :2 0 1544 0
1544 1543 14f1 1542
:6 0 154d 1 :3 0
7b :3 0 1a0 :3 0
21 :3 0 b5b 1547
1549 1546 154a 0
154d 15c :3 0 b5d
154e 14cf 154d 0
15e0 e5 :3 0 8f
:3 0 5e :3 0 45
:2 0 b60 1550 1553
1a :3 0 1a5 :3 0
1555 1556 0 b63
154f 1558 1559 :2 0
1a :3 0 14e :2 0
1a5 :3 0 155b 155d
0 b68 155c 155f
:3 0 bd :3 0 13c
:3 0 29 :3 0 16c
:3 0 1a1 :3 0 176
:3 0 16c :3 0 1a
:3 0 1a5 :3 0 a5
:3 0 21 :4 0 1a6
1 :8 0 1582 ed
:4 0 156d :3 0 105
:3 0 e7 :2 0 b6d
1570 1571 :3 0 15
:3 0 ee :3 0 1573
1574 0 45 :2 0
1575 1576 0 1578
b70 157f 15 :3 0
ee :3 0 1579 157a
0 ef :2 0 157b
157c 0 157e b72
1580 1572 1578 0
1581 0 157e 0
1581 b74 0 1582
b77 15d5 f2 :3 0
15 :3 0 ee :3 0
1584 1585 0 f1
:3 0 1586 1587 0
1589 b7a 158b b7c
158a 1589 :2 0 15d3
f3 :3 0 15 :3 0
ee :3 0 158e 158f
0 f1 :3 0 1590
1591 0 15cb d0
:3 0 d1 :3 0 1593
1594 0 d0 :3 0
e0 :3 0 1596 1597
0 f4 :2 0 2
:4 0 1a7 :2 0 e2
:2 0 30 :2 0 b7e
159c 159e :3 0 b81
1598 15a0 1595 15a2
15a1 :2 0 d3 :3 0
e3 :3 0 15a4 15a5
0 d5 :4 0 1a8
:4 0 d8 :2 0 d9
:3 0 b85 15a9 15ab
:3 0 d8 :2 0 f7
:4 0 b88 15ad 15af
:3 0 d8 :2 0 f8
:4 0 b8b 15b1 15b3
:3 0 d8 :2 0 f1
:3 0 b8e 15b5 15b7
:3 0 d8 :2 0 f9
:4 0 b91 15b9 15bb
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 b94
15be 15c2 b98 15bd
15c4 :3 0 b9b 15a6
15c6 :2 0 15c8 b9e
15c9 15a3 15c8 0
15ca ba0 0 15cb
ba2 15ce :3 0 15ce
0 15ce 15cd 15cb
15cc :6 0 15d0 37
:3 0 ba5 15d2 ba7
15d1 15d0 :2 0 15d3
ba9 :2 0 15d5 0
15d5 15d4 1582 15d3
:6 0 15dd 1 :3 0
7b :3 0 1a0 :3 0
21 :3 0 bac 15d8
15da 15d7 15db 0
15dd bae 15de 1560
15dd 0 15e0 1431
14bd 0 15e0 bb1
0 15e1 bb5 15e2
1426 15e1 0 15e3
bb7 0 15e4 bb9
15e5 12bc 15e4 0
15e7 f7c 12b2 0
15e7 bbf 0 51ec
68 :3 0 1a9 :3 0
122 :3 0 67 :3 0
123 :3 0 124 :3 0
125 :3 0 126 :3 0
67 :3 0 132 :3 0
1a9 :3 0 127 :3 0
128 :3 0 125 :3 0
1a9 :3 0 122 :3 0
125 :3 0 99 :3 0
1a9 :3 0 122 :3 0
9f :3 0 27 :4 0
1aa 1 :8 0 1604
15 :3 0 ee :3 0
15ff 1600 0 f1
:3 0 1601 1602 0
1604 bc2 1657 f2
:3 0 15 :3 0 ee
:3 0 1606 1607 0
f1 :3 0 1608 1609
0 160b bc5 160d
bc7 160c 160b :2 0
1655 f3 :3 0 15
:3 0 ee :3 0 1610
1611 0 f1 :3 0
1612 1613 0 164d
d0 :3 0 d1 :3 0
1615 1616 0 d0
:3 0 e0 :3 0 1618
1619 0 f4 :2 0
2 :4 0 1ab :2 0
e2 :2 0 30 :2 0
bc9 161e 1620 :3 0
bcc 161a 1622 1617
1624 1623 :2 0 d3
:3 0 e3 :3 0 1626
1627 0 d5 :4 0
1ac :4 0 d8 :2 0
d9 :3 0 bd0 162b
162d :3 0 d8 :2 0
f7 :4 0 bd3 162f
1631 :3 0 d8 :2 0
f8 :4 0 bd6 1633
1635 :3 0 d8 :2 0
f1 :3 0 bd9 1637
1639 :3 0 d8 :2 0
f9 :4 0 bdc 163b
163d :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
bdf 1640 1644 be3
163f 1646 :3 0 be6
1628 1648 :2 0 164a
be9 164b 1625 164a
0 164c beb 0
164d bed 1650 :3 0
1650 0 1650 164f
164d 164e :6 0 1652
39 :3 0 bf0 1654
bf2 1653 1652 :2 0
1655 bf4 :2 0 1657
0 1657 1656 1604
1655 :6 0 51ec 1
:3 0 15 :3 0 ee
:3 0 1659 165a 0
15 :3 0 14e :2 0
165 :3 0 165c 165e
0 bf9 165d 1660
:3 0 1661 :2 0 67
:3 0 1ad :2 0 1663
1664 0 1666 bfc
1667 1662 1666 0
1668 bfe 0 51ec
71 :3 0 eb :4 0
1669 166a 0 51ec
73 :3 0 eb :4 0
166c 166d 0 51ec
2c :3 0 eb :4 0
166f 1670 0 51ec
7b :3 0 1ae :4 0
1673 1674 :3 0 1672
1675 0 51ec 8f
:3 0 6a :3 0 45
:2 0 c00 1677 167a
e7 :2 0 45 :2 0
c05 167c 167e :3 0
167f :2 0 8f :3 0
6b :3 0 45 :2 0
c08 1681 1684 e7
:2 0 45 :2 0 c0d
1686 1688 :3 0 1689
:2 0 1680 168b 168a
:2 0 7b :3 0 1af
:3 0 28 :3 0 27
:3 0 36 :3 0 71
:3 0 73 :3 0 90
:3 0 62 :3 0 65
:3 0 64 :3 0 66
:3 0 c10 168e 1699
168d 169a 0 16f0
8f :3 0 6b :3 0
45 :2 0 c1b 169c
169f e7 :2 0 45
:2 0 c20 16a1 16a3
:3 0 62 :3 0 8f
:3 0 62 :3 0 45
:2 0 c23 16a6 16a9
1b0 :2 0 8f :3 0
67 :3 0 45 :2 0
c26 16ac 16af c29
16ab 16b1 :3 0 16a5
16b2 0 16c3 65
:3 0 8f :3 0 65
:3 0 45 :2 0 c2c
16b5 16b8 1b0 :2 0
8f :3 0 67 :3 0
45 :2 0 c2f 16bb
16be c32 16ba 16c0
:3 0 16b4 16c1 0
16c3 c35 16c4 16a4
16c3 0 16c5 c38
0 16f0 8f :3 0
6a :3 0 45 :2 0
c3a 16c6 16c9 e7
:2 0 45 :2 0 c3f
16cb 16cd :3 0 64
:3 0 8f :3 0 64
:3 0 45 :2 0 c42
16d0 16d3 1b0 :2 0
8f :3 0 67 :3 0
45 :2 0 c45 16d6
16d9 c48 16d5 16db
:3 0 16cf 16dc 0
16ed 66 :3 0 8f
:3 0 66 :3 0 45
:2 0 c4b 16df 16e2
1b0 :2 0 8f :3 0
67 :3 0 45 :2 0
c4e 16e5 16e8 c51
16e4 16ea :3 0 16de
16eb 0 16ed c54
16ee 16ce 16ed 0
16ef c57 0 16f0
c59 16f1 168c 16f0
0 16f2 c5d 0
51ec 54 :3 0 45
:2 0 16f3 16f4 0
51ec 4c :3 0 45
:2 0 16f6 16f7 0
51ec 1b1 :3 0 96
:3 0 44 :3 0 97
:3 0 99 :3 0 27
:4 0 1b2 1 :8 0
1705 15 :3 0 ee
:3 0 1700 1701 0
f1 :3 0 1702 1703
0 1705 c5f 1758
f2 :3 0 15 :3 0
ee :3 0 1707 1708
0 f1 :3 0 1709
170a 0 170c c62
170e c64 170d 170c
:2 0 1756 f3 :3 0
15 :3 0 ee :3 0
1711 1712 0 f1
:3 0 1713 1714 0
174e d0 :3 0 d1
:3 0 1716 1717 0
d0 :3 0 e0 :3 0
1719 171a 0 f4
:2 0 2 :4 0 1b3
:2 0 e2 :2 0 30
:2 0 c66 171f 1721
:3 0 c69 171b 1723
1718 1725 1724 :2 0
d3 :3 0 e3 :3 0
1727 1728 0 d5
:4 0 1b4 :4 0 d8
:2 0 d9 :3 0 c6d
172c 172e :3 0 d8
:2 0 f7 :4 0 c70
1730 1732 :3 0 d8
:2 0 f8 :4 0 c73
1734 1736 :3 0 d8
:2 0 f1 :3 0 c76
1738 173a :3 0 d8
:2 0 f9 :4 0 c79
173c 173e :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 c7c 1741 1745
c80 1740 1747 :3 0
c83 1729 1749 :2 0
174b c86 174c 1726
174b 0 174d c88
0 174e c8a 1751
:3 0 1751 0 1751
1750 174e 174f :6 0
1753 3b :3 0 c8d
1755 c8f 1754 1753
:2 0 1756 c91 :2 0
1758 0 1758 1757
1705 1756 :6 0 51ec
1 :3 0 8b :4 0
175a 175b 0 51ec
a7 :3 0 b3 :3 0
8b :3 0 82 :3 0
9d :3 0 9e :3 0
28 :3 0 a8 :3 0
28 :3 0 9f :3 0
29 :3 0 a0 :4 0
1b5 1 :8 0 176f
15 :3 0 ee :3 0
176a 176b 0 f1
:3 0 176c 176d 0
176f c94 17c2 f2
:3 0 15 :3 0 ee
:3 0 1771 1772 0
f1 :3 0 1773 1774
0 1776 c97 1778
c99 1777 1776 :2 0
17c0 f3 :3 0 15
:3 0 ee :3 0 177b
177c 0 f1 :3 0
177d 177e 0 17b8
d0 :3 0 d1 :3 0
1780 1781 0 d0
:3 0 e0 :3 0 1783
1784 0 f4 :2 0
2 :4 0 1b6 :2 0
e2 :2 0 30 :2 0
c9b 1789 178b :3 0
c9e 1785 178d 1782
178f 178e :2 0 d3
:3 0 e3 :3 0 1791
1792 0 d5 :4 0
1b7 :4 0 d8 :2 0
d9 :3 0 ca2 1796
1798 :3 0 d8 :2 0
f7 :4 0 ca5 179a
179c :3 0 d8 :2 0
f8 :4 0 ca8 179e
17a0 :3 0 d8 :2 0
f1 :3 0 cab 17a2
17a4 :3 0 d8 :2 0
f9 :4 0 cae 17a6
17a8 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
cb1 17ab 17af cb5
17aa 17b1 :3 0 cb8
1793 17b3 :2 0 17b5
cbb 17b6 1790 17b5
0 17b7 cbd 0
17b8 cbf 17bb :3 0
17bb 0 17bb 17ba
17b8 17b9 :6 0 17bd
3d :3 0 cc2 17bf
cc4 17be 17bd :2 0
17c0 cc6 :2 0 17c2
0 17c2 17c1 176f
17c0 :6 0 51ec 1
:3 0 1b8 :3 0 1b9
:3 0 82 :3 0 79
:3 0 113 :3 0 9e
:3 0 28 :4 0 1ba
1 :8 0 17d1 15
:3 0 ee :3 0 17cc
17cd 0 f1 :3 0
17ce 17cf 0 17d1
cc9 1824 f2 :3 0
15 :3 0 ee :3 0
17d3 17d4 0 f1
:3 0 17d5 17d6 0
17d8 ccc 17da cce
17d9 17d8 :2 0 1822
f3 :3 0 15 :3 0
ee :3 0 17dd 17de
0 f1 :3 0 17df
17e0 0 181a d0
:3 0 d1 :3 0 17e2
17e3 0 d0 :3 0
e0 :3 0 17e5 17e6
0 f4 :2 0 2
:4 0 1bb :2 0 e2
:2 0 30 :2 0 cd0
17eb 17ed :3 0 cd3
17e7 17ef 17e4 17f1
17f0 :2 0 d3 :3 0
e3 :3 0 17f3 17f4
0 d5 :4 0 1bc
:4 0 d8 :2 0 d9
:3 0 cd7 17f8 17fa
:3 0 d8 :2 0 f7
:4 0 cda 17fc 17fe
:3 0 d8 :2 0 f8
:4 0 cdd 1800 1802
:3 0 d8 :2 0 f1
:3 0 ce0 1804 1806
:3 0 d8 :2 0 f9
:4 0 ce3 1808 180a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 ce6
180d 1811 cea 180c
1813 :3 0 ced 17f5
1815 :2 0 1817 cf0
1818 17f2 1817 0
1819 cf2 0 181a
cf4 181d :3 0 181d
0 181d 181c 181a
181b :6 0 181f 3f
:3 0 cf7 1821 cf9
1820 181f :2 0 1822
cfb :2 0 1824 0
1824 1823 17d1 1822
:6 0 51ec 1 :3 0
123 :3 0 140 :3 0
1826 1827 0 28
:3 0 26 :3 0 cfe
1828 182b 14e :2 0
45 :2 0 d03 182d
182f :3 0 153 :2 0
d06 1831 1832 :3 0
8b :3 0 1bd :2 0
d08 1835 1836 :3 0
1837 :2 0 53 :3 0
45 :2 0 1839 183a
0 26bb a5 :3 0
aa :3 0 ad :3 0
ae :3 0 ac :3 0
ad :3 0 ae :3 0
af :3 0 b3 :3 0
b4 :3 0 b5 :3 0
b6 :3 0 a8 :3 0
ab :3 0 b7 :3 0
b8 :3 0 b9 :3 0
ba :3 0 1c :3 0
86 :3 0 34 :3 0
35 :3 0 82 :3 0
83 :3 0 7e :3 0
7f :3 0 26 :3 0
88 :3 0 4d :3 0
4f :3 0 50 :3 0
51 :3 0 9d :3 0
a7 :3 0 8b :4 0
1be 1 :8 0 1865
15 :3 0 ee :3 0
1860 1861 0 f1
:3 0 1862 1863 0
1865 d0a 18b8 f2
:3 0 15 :3 0 ee
:3 0 1867 1868 0
f1 :3 0 1869 186a
0 186c d0d 186e
d0f 186d 186c :2 0
18b6 f3 :3 0 15
:3 0 ee :3 0 1871
1872 0 f1 :3 0
1873 1874 0 18ae
d0 :3 0 d1 :3 0
1876 1877 0 d0
:3 0 e0 :3 0 1879
187a 0 f4 :2 0
2 :4 0 1bf :2 0
e2 :2 0 30 :2 0
d11 187f 1881 :3 0
d14 187b 1883 1878
1885 1884 :2 0 d3
:3 0 e3 :3 0 1887
1888 0 d5 :4 0
1c0 :4 0 d8 :2 0
d9 :3 0 d18 188c
188e :3 0 d8 :2 0
f7 :4 0 d1b 1890
1892 :3 0 d8 :2 0
f8 :4 0 d1e 1894
1896 :3 0 d8 :2 0
f1 :3 0 d21 1898
189a :3 0 d8 :2 0
f9 :4 0 d24 189c
189e :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
d27 18a1 18a5 d2b
18a0 18a7 :3 0 d2e
1889 18a9 :2 0 18ab
d31 18ac 1886 18ab
0 18ad d33 0
18ae d35 18b1 :3 0
18b1 0 18b1 18b0
18ae 18af :6 0 18b3
41 :3 0 d38 18b5
d3a 18b4 18b3 :2 0
18b6 d3c :2 0 18b8
0 18b8 18b7 1865
18b6 :6 0 26bb 1
:3 0 15 :3 0 ee
:3 0 18ba 18bb 0
15 :3 0 e7 :2 0
165 :3 0 18bd 18bf
0 d41 18be 18c1
:3 0 18c2 :2 0 8b
:3 0 1bd :2 0 d44
18c5 18c6 :3 0 18c7
:2 0 18c8 :2 0 18c3
18ca 18c9 :2 0 84
:3 0 1c1 :2 0 30
:2 0 d46 18cd 18cf
:3 0 18cc 18d0 0
18e3 15 :3 0 ee
:3 0 18d2 18d3 0
1c2 :3 0 28 :3 0
28 :3 0 8b :3 0
34 :3 0 35 :3 0
7e :3 0 7f :3 0
84 :3 0 83 :3 0
82 :3 0 d48 18d5
18e0 18d4 18e1 0
18e3 d53 18e4 18cb
18e3 0 18e5 d56
0 26bb 61 :3 0
45 :2 0 18e6 18e7
0 26bb 8f :3 0
80 :3 0 45 :2 0
d58 18e9 18ec e7
:2 0 30 :2 0 d5d
18ee 18f0 :3 0 8f
:3 0 51 :3 0 45
:2 0 d60 18f2 18f5
8f :3 0 14e :2 0
f :3 0 45 :2 0
d63 18f7 18fb d68
18f8 18fd :3 0 8f
:3 0 4d :3 0 45
:2 0 d6b 18ff 1902
8f :3 0 14e :2 0
b :3 0 45 :2 0
d6e 1904 1908 d73
1905 190a :3 0 18fe
190c 190b :2 0 e5
:3 0 8f :3 0 c
:3 0 45 :2 0 d76
190f 1912 1a :3 0
1c3 :3 0 1914 1915
0 d79 190e 1917
14e :2 0 45 :2 0
d7e 1919 191b :3 0
d0 :3 0 d1 :3 0
191d 191e 0 d0
:3 0 e0 :3 0 1920
1921 0 1d :2 0
2 :4 0 1c4 :2 0
e2 :2 0 30 :2 0
d81 1926 1928 :3 0
d84 1922 192a 191f
192c 192b :2 0 d3
:3 0 e3 :3 0 192e
192f 0 d5 :4 0
1c5 :4 0 d8 :2 0
d9 :3 0 d88 1933
1935 :3 0 d8 :2 0
f7 :4 0 d8b 1937
1939 :3 0 d8 :2 0
fe :4 0 d8e 193b
193d :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 1c6 :3 0
1942 1943 0 d91
1941 1945 de :4 0
d93 1940 1948 d96
193f 194a :3 0 d8
:2 0 100 :4 0 d99
194c 194e :3 0 d8
:2 0 db :4 0 d9c
1950 1952 :3 0 d8
:2 0 27 :3 0 d9f
1954 1956 :3 0 d8
:2 0 db :4 0 da2
1958 195a :3 0 da5
1930 195c :2 0 195e
da8 195f 192d 195e
0 1960 daa 0
198a d0 :3 0 d1
:3 0 1961 1962 0
d0 :3 0 e0 :3 0
1964 1965 0 30
:2 0 2 :4 0 1c7
:2 0 e2 :2 0 30
:2 0 dac 196a 196c
:3 0 daf 1966 196e
1963 1970 196f :2 0
d3 :3 0 e3 :3 0
1972 1973 0 d5
:4 0 1c8 :4 0 d8
:2 0 d9 :3 0 db3
1977 1979 :3 0 db6
1974 197b :2 0 197d
db9 197e 1971 197d
0 197f dbb 0
198a 103 :3 0 104
:3 0 1980 1981 0
1a :3 0 1c6 :3 0
1983 1984 0 27
:3 0 105 :3 0 dbd
1982 1988 :2 0 198a
dc1 199e 61 :3 0
30 :2 0 198b 198c
0 199d 8f :3 0
f :3 0 45 :2 0
dc5 198e 1991 e7
:2 0 45 :2 0 dca
1993 1995 :3 0 88
:3 0 45 :2 0 1997
1998 0 199a dcd
199b 1996 199a 0
199c dcf 0 199d
dd1 199f 191c 198a
0 19a0 0 199d
0 19a0 dd4 0
19a1 dd7 19a2 190d
19a1 0 19a3 dd9
0 19bf 48 :3 0
9 :3 0 19a4 19a5
0 19bf 2a :3 0
7 :3 0 19a7 19a8
0 19bf 2c :3 0
8 :3 0 19aa 19ab
0 19bf 4d :3 0
b :3 0 19ad 19ae
0 19bf 4e :3 0
10 :3 0 19b0 19b1
0 19bf 4f :3 0
d :3 0 19b3 19b4
0 19bf 50 :3 0
e :3 0 19b6 19b7
0 19bf 57 :3 0
c :3 0 19b9 19ba
0 19bf 51 :3 0
f :3 0 19bc 19bd
0 19bf ddb 19c0
18f1 19bf 0 19c1
de6 0 26bb 15
:3 0 ee :3 0 19c2
19c3 0 15 :3 0
e7 :2 0 165 :3 0
19c5 19c7 0 dea
19c6 19c9 :3 0 19ca
:2 0 92 :3 0 30
:2 0 19cc 19cd 0
26b8 93 :3 0 30
:2 0 19cf 19d0 0
26b8 23 :3 0 1bd
:2 0 ded 19d3 19d4
:3 0 19d5 :2 0 ae
:3 0 79 :3 0 30
:2 0 30 :2 0 def
19d7 19db e7 :2 0
1c9 :4 0 df5 19dd
19df :3 0 84 :3 0
1c1 :2 0 30 :2 0
df8 19e2 19e4 :3 0
19e1 19e5 0 19f8
15 :3 0 ee :3 0
19e7 19e8 0 1c2
:3 0 28 :3 0 28
:3 0 23 :3 0 34
:3 0 35 :3 0 7e
:3 0 7f :3 0 84
:3 0 83 :3 0 82
:3 0 dfa 19ea 19f5
19e9 19f6 0 19f8
e05 19f9 19e0 19f8
0 19fa e08 0
1e4d a5 :3 0 ad
:3 0 ae :3 0 1ca
:3 0 b3 :3 0 b4
:3 0 aa :3 0 b7
:3 0 b9 :3 0 ba
:3 0 107 :3 0 108
:3 0 17c :3 0 20
:3 0 34 :3 0 82
:3 0 83 :3 0 86
:3 0 4d :3 0 50
:3 0 51 :3 0 89
:3 0 8a :3 0 85
:3 0 9d :3 0 a7
:3 0 23 :4 0 1cb
1 :8 0 1a1c 15
:3 0 ee :3 0 1a17
1a18 0 f1 :3 0
1a19 1a1a 0 1a1c
e0a 1a6f f2 :3 0
15 :3 0 ee :3 0
1a1e 1a1f 0 f1
:3 0 1a20 1a21 0
1a23 e0d 1a25 e0f
1a24 1a23 :2 0 1a6d
f3 :3 0 15 :3 0
ee :3 0 1a28 1a29
0 f1 :3 0 1a2a
1a2b 0 1a65 d0
:3 0 d1 :3 0 1a2d
1a2e 0 d0 :3 0
e0 :3 0 1a30 1a31
0 f4 :2 0 2
:4 0 1cc :2 0 e2
:2 0 30 :2 0 e11
1a36 1a38 :3 0 e14
1a32 1a3a 1a2f 1a3c
1a3b :2 0 d3 :3 0
e3 :3 0 1a3e 1a3f
0 d5 :4 0 1cd
:4 0 d8 :2 0 d9
:3 0 e18 1a43 1a45
:3 0 d8 :2 0 f7
:4 0 e1b 1a47 1a49
:3 0 d8 :2 0 f8
:4 0 e1e 1a4b 1a4d
:3 0 d8 :2 0 f1
:3 0 e21 1a4f 1a51
:3 0 d8 :2 0 f9
:4 0 e24 1a53 1a55
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 e27
1a58 1a5c e2b 1a57
1a5e :3 0 e2e 1a40
1a60 :2 0 1a62 e31
1a63 1a3d 1a62 0
1a64 e33 0 1a65
e35 1a68 :3 0 1a68
0 1a68 1a67 1a65
1a66 :6 0 1a6a 43
:3 0 e38 1a6c e3a
1a6b 1a6a :2 0 1a6d
e3c :2 0 1a6f 0
1a6f 1a6e 1a1c 1a6d
:6 0 1e4d 1 :3 0
15 :3 0 ee :3 0
1a71 1a72 0 15
:3 0 e7 :2 0 165
:3 0 1a74 1a76 0
e41 1a75 1a78 :3 0
1a79 :2 0 8f :3 0
51 :3 0 45 :2 0
e44 1a7b 1a7e 8f
:3 0 14e :2 0 f
:3 0 45 :2 0 e47
1a80 1a84 e4c 1a81
1a86 :3 0 8f :3 0
4d :3 0 45 :2 0
e4f 1a88 1a8b 8f
:3 0 14e :2 0 b
:3 0 45 :2 0 e52
1a8d 1a91 e57 1a8e
1a93 :3 0 1a87 1a95
1a94 :2 0 d0 :3 0
d1 :3 0 1a97 1a98
0 d0 :3 0 e0
:3 0 1a9a 1a9b 0
1d :2 0 2 :4 0
1ce :2 0 e2 :2 0
30 :2 0 e5a 1aa0
1aa2 :3 0 e5d 1a9c
1aa4 1a99 1aa6 1aa5
:2 0 d3 :3 0 e3
:3 0 1aa8 1aa9 0
d5 :4 0 1cf :4 0
d8 :2 0 d9 :3 0
e61 1aad 1aaf :3 0
d8 :2 0 f7 :4 0
e64 1ab1 1ab3 :3 0
d8 :2 0 fe :4 0
e67 1ab5 1ab7 :3 0
d8 :2 0 8f :3 0
dd :3 0 1a :3 0
1c6 :3 0 1abc 1abd
0 e6a 1abb 1abf
de :4 0 e6c 1aba
1ac2 e6f 1ab9 1ac4
:3 0 d8 :2 0 100
:4 0 e72 1ac6 1ac8
:3 0 d8 :2 0 db
:4 0 e75 1aca 1acc
:3 0 d8 :2 0 27
:3 0 e78 1ace 1ad0
:3 0 d8 :2 0 db
:4 0 e7b 1ad2 1ad4
:3 0 e7e 1aaa 1ad6
:2 0 1ad8 e81 1ad9
1aa7 1ad8 0 1ada
e83 0 1b04 d0
:3 0 d1 :3 0 1adb
1adc 0 d0 :3 0
e0 :3 0 1ade 1adf
0 30 :2 0 2
:4 0 1d0 :2 0 e2
:2 0 30 :2 0 e85
1ae4 1ae6 :3 0 e88
1ae0 1ae8 1add 1aea
1ae9 :2 0 d3 :3 0
e3 :3 0 1aec 1aed
0 d5 :4 0 1d1
:4 0 d8 :2 0 d9
:3 0 e8c 1af1 1af3
:3 0 e8f 1aee 1af5
:2 0 1af7 e92 1af8
1aeb 1af7 0 1af9
e94 0 1b04 103
:3 0 104 :3 0 1afa
1afb 0 1a :3 0
1c6 :3 0 1afd 1afe
0 27 :3 0 105
:3 0 e96 1afc 1b02
:2 0 1b04 e9a 1b05
1a96 1b04 0 1b06
e9e 0 1e49 53
:3 0 ae :3 0 2f
:3 0 30 :2 0 30
:2 0 ea0 1b08 1b0c
e7 :2 0 146 :4 0
ea6 1b0e 1b10 :3 0
146 :2 0 ea9 1b13
1b12 45 :3 0 1b15
0 eab :2 0 1b07
1b17 0 1e49 8f
:3 0 80 :3 0 45
:2 0 eae 1b19 1b1c
14e :2 0 45 :2 0
eb3 1b1e 1b20 :3 0
5f :3 0 30 :2 0
1b22 1b23 0 1e46
92 :3 0 45 :2 0
1b25 1b26 0 1e46
8f :3 0 81 :3 0
45 :2 0 eb6 1b28
1b2b 14e :2 0 45
:2 0 ebb 1b2d 1b2f
:3 0 8f :3 0 6c
:3 0 45 :2 0 ebe
1b31 1b34 14e :2 0
45 :2 0 ec3 1b36
1b38 :3 0 1d2 :3 0
1d3 :3 0 86 :3 0
1d4 :3 0 9e :3 0
28 :3 0 a7 :3 0
8b :3 0 1d5 :3 0
8b :4 0 1d6 1
:8 0 1b4a 15 :3 0
ee :3 0 1b45 1b46
0 f1 :3 0 1b47
1b48 0 1b4a ec6
1b9d f2 :3 0 15
:3 0 ee :3 0 1b4c
1b4d 0 f1 :3 0
1b4e 1b4f 0 1b51
ec9 1b53 ecb 1b52
1b51 :2 0 1b9b f3
:3 0 15 :3 0 ee
:3 0 1b56 1b57 0
f1 :3 0 1b58 1b59
0 1b93 d0 :3 0
d1 :3 0 1b5b 1b5c
0 d0 :3 0 e0
:3 0 1b5e 1b5f 0
f4 :2 0 2 :4 0
1d7 :2 0 e2 :2 0
30 :2 0 ecd 1b64
1b66 :3 0 ed0 1b60
1b68 1b5d 1b6a 1b69
:2 0 d3 :3 0 e3
:3 0 1b6c 1b6d 0
d5 :4 0 1d8 :4 0
d8 :2 0 d9 :3 0
ed4 1b71 1b73 :3 0
d8 :2 0 f7 :4 0
ed7 1b75 1b77 :3 0
d8 :2 0 f8 :4 0
eda 1b79 1b7b :3 0
d8 :2 0 f1 :3 0
edd 1b7d 1b7f :3 0
d8 :2 0 f9 :4 0
ee0 1b81 1b83 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 ee3 1b86
1b8a ee7 1b85 1b8c
:3 0 eea 1b6e 1b8e
:2 0 1b90 eed 1b91
1b6b 1b90 0 1b92
eef 0 1b93 ef1
1b96 :3 0 1b96 0
1b96 1b95 1b93 1b94
:6 0 1b98 45 :3 0
ef4 1b9a ef6 1b99
1b98 :2 0 1b9b ef8
:2 0 1b9d 0 1b9d
1b9c 1b4a 1b9b :6 0
1b9f 1 :3 0 efb
1c04 1d2 :3 0 1d3
:3 0 86 :3 0 1d4
:3 0 9e :3 0 28
:3 0 9f :3 0 29
:4 0 1d9 1 :8 0
1bae 15 :3 0 ee
:3 0 1ba9 1baa 0
f1 :3 0 1bab 1bac
0 1bae efd 1c01
f2 :3 0 15 :3 0
ee :3 0 1bb0 1bb1
0 f1 :3 0 1bb2
1bb3 0 1bb5 f00
1bb7 f02 1bb6 1bb5
:2 0 1bff f3 :3 0
15 :3 0 ee :3 0
1bba 1bbb 0 f1
:3 0 1bbc 1bbd 0
1bf7 d0 :3 0 d1
:3 0 1bbf 1bc0 0
d0 :3 0 e0 :3 0
1bc2 1bc3 0 f4
:2 0 2 :4 0 1da
:2 0 e2 :2 0 30
:2 0 f04 1bc8 1bca
:3 0 f07 1bc4 1bcc
1bc1 1bce 1bcd :2 0
d3 :3 0 e3 :3 0
1bd0 1bd1 0 d5
:4 0 1db :4 0 d8
:2 0 d9 :3 0 f0b
1bd5 1bd7 :3 0 d8
:2 0 f7 :4 0 f0e
1bd9 1bdb :3 0 d8
:2 0 f8 :4 0 f11
1bdd 1bdf :3 0 d8
:2 0 f1 :3 0 f14
1be1 1be3 :3 0 d8
:2 0 f9 :4 0 f17
1be5 1be7 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 f1a 1bea 1bee
f1e 1be9 1bf0 :3 0
f21 1bd2 1bf2 :2 0
1bf4 f24 1bf5 1bcf
1bf4 0 1bf6 f26
0 1bf7 f28 1bfa
:3 0 1bfa 0 1bfa
1bf9 1bf7 1bf8 :6 0
1bfc 47 :3 0 f2b
1bfe f2d 1bfd 1bfc
:2 0 1bff f2f :2 0
1c01 0 1c01 1c00
1bae 1bff :6 0 1c03
1 :3 0 f32 1c05
1b39 1b9f 0 1c06
0 1c03 0 1c06
f34 0 1c07 f37
1c08 1b30 1c07 0
1c09 f39 0 1e46
8f :3 0 6c :3 0
45 :2 0 f3b 1c0a
1c0d 14e :2 0 45
:2 0 f40 1c0f 1c11
:3 0 1d4 :3 0 9e
:3 0 28 :3 0 a7
:3 0 8b :3 0 1d5
:3 0 8b :4 0 1dc
1 :8 0 1c30 ed
:4 0 1c1b :3 0 105
:3 0 e7 :2 0 f45
1c1e 1c1f :3 0 15
:3 0 ee :3 0 1c21
1c22 0 45 :2 0
1c23 1c24 0 1c26
f48 1c2d 15 :3 0
ee :3 0 1c27 1c28
0 ef :2 0 1c29
1c2a 0 1c2c f4a
1c2e 1c20 1c26 0
1c2f 0 1c2c 0
1c2f f4c 0 1c30
f4f 1c83 f2 :3 0
15 :3 0 ee :3 0
1c32 1c33 0 f1
:3 0 1c34 1c35 0
1c37 f52 1c39 f54
1c38 1c37 :2 0 1c81
f3 :3 0 15 :3 0
ee :3 0 1c3c 1c3d
0 f1 :3 0 1c3e
1c3f 0 1c79 d0
:3 0 d1 :3 0 1c41
1c42 0 d0 :3 0
e0 :3 0 1c44 1c45
0 f4 :2 0 2
:4 0 1dd :2 0 e2
:2 0 30 :2 0 f56
1c4a 1c4c :3 0 f59
1c46 1c4e 1c43 1c50
1c4f :2 0 d3 :3 0
e3 :3 0 1c52 1c53
0 d5 :4 0 1de
:4 0 d8 :2 0 d9
:3 0 f5d 1c57 1c59
:3 0 d8 :2 0 f7
:4 0 f60 1c5b 1c5d
:3 0 d8 :2 0 f8
:4 0 f63 1c5f 1c61
:3 0 d8 :2 0 f1
:3 0 f66 1c63 1c65
:3 0 d8 :2 0 f9
:4 0 f69 1c67 1c69
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 f6c
1c6c 1c70 f70 1c6b
1c72 :3 0 f73 1c54
1c74 :2 0 1c76 f76
1c77 1c51 1c76 0
1c78 f78 0 1c79
f7a 1c7c :3 0 1c7c
0 1c7c 1c7b 1c79
1c7a :6 0 1c7e 49
:3 0 f7d 1c80 f7f
1c7f 1c7e :2 0 1c81
f81 :2 0 1c83 0
1c83 1c82 1c30 1c81
:6 0 1c85 1 :3 0
f84 1e43 1df :3 0
9e :3 0 28 :3 0
9f :3 0 29 :4 0
1e0 1 :8 0 1ca1
ed :4 0 1c8c :3 0
105 :3 0 e7 :2 0
f88 1c8f 1c90 :3 0
15 :3 0 ee :3 0
1c92 1c93 0 45
:2 0 1c94 1c95 0
1c97 f8b 1c9e 15
:3 0 ee :3 0 1c98
1c99 0 ef :2 0
1c9a 1c9b 0 1c9d
f8d 1c9f 1c91 1c97
0 1ca0 0 1c9d
0 1ca0 f8f 0
1ca1 f92 1cf4 f2
:3 0 15 :3 0 ee
:3 0 1ca3 1ca4 0
f1 :3 0 1ca5 1ca6
0 1ca8 f95 1caa
f97 1ca9 1ca8 :2 0
1cf2 f3 :3 0 15
:3 0 ee :3 0 1cad
1cae 0 f1 :3 0
1caf 1cb0 0 1cea
d0 :3 0 d1 :3 0
1cb2 1cb3 0 d0
:3 0 e0 :3 0 1cb5
1cb6 0 f4 :2 0
2 :4 0 1e1 :2 0
e2 :2 0 30 :2 0
f99 1cbb 1cbd :3 0
f9c 1cb7 1cbf 1cb4
1cc1 1cc0 :2 0 d3
:3 0 e3 :3 0 1cc3
1cc4 0 d5 :4 0
1e2 :4 0 d8 :2 0
d9 :3 0 fa0 1cc8
1cca :3 0 d8 :2 0
f7 :4 0 fa3 1ccc
1cce :3 0 d8 :2 0
f8 :4 0 fa6 1cd0
1cd2 :3 0 d8 :2 0
f1 :3 0 fa9 1cd4
1cd6 :3 0 d8 :2 0
f9 :4 0 fac 1cd8
1cda :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
faf 1cdd 1ce1 fb3
1cdc 1ce3 :3 0 fb6
1cc5 1ce5 :2 0 1ce7
fb9 1ce8 1cc2 1ce7
0 1ce9 fbb 0
1cea fbd 1ced :3 0
1ced 0 1ced 1cec
1cea 1ceb :6 0 1cef
4b :3 0 fc0 1cf1
fc2 1cf0 1cef :2 0
1cf2 fc4 :2 0 1cf4
0 1cf4 1cf3 1ca1
1cf2 :6 0 1e42 1
:3 0 bd :3 0 a5
:3 0 1c :4 0 1e3
1 :8 0 1d0f ed
:4 0 1cfa :3 0 105
:3 0 e7 :2 0 fc9
1cfd 1cfe :3 0 15
:3 0 ee :3 0 1d00
1d01 0 45 :2 0
1d02 1d03 0 1d05
fcc 1d0c 15 :3 0
ee :3 0 1d06 1d07
0 ef :2 0 1d08
1d09 0 1d0b fce
1d0d 1cff 1d05 0
1d0e 0 1d0b 0
1d0e fd0 0 1d0f
fd3 1d62 f2 :3 0
15 :3 0 ee :3 0
1d11 1d12 0 f1
:3 0 1d13 1d14 0
1d16 fd6 1d18 fd8
1d17 1d16 :2 0 1d60
f3 :3 0 15 :3 0
ee :3 0 1d1b 1d1c
0 f1 :3 0 1d1d
1d1e 0 1d58 d0
:3 0 d1 :3 0 1d20
1d21 0 d0 :3 0
e0 :3 0 1d23 1d24
0 f4 :2 0 2
:4 0 1e4 :2 0 e2
:2 0 30 :2 0 fda
1d29 1d2b :3 0 fdd
1d25 1d2d 1d22 1d2f
1d2e :2 0 d3 :3 0
e3 :3 0 1d31 1d32
0 d5 :4 0 1e5
:4 0 d8 :2 0 d9
:3 0 fe1 1d36 1d38
:3 0 d8 :2 0 f7
:4 0 fe4 1d3a 1d3c
:3 0 d8 :2 0 f8
:4 0 fe7 1d3e 1d40
:3 0 d8 :2 0 f1
:3 0 fea 1d42 1d44
:3 0 d8 :2 0 f9
:4 0 fed 1d46 1d48
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 ff0
1d4b 1d4f ff4 1d4a
1d51 :3 0 ff7 1d33
1d53 :2 0 1d55 ffa
1d56 1d30 1d55 0
1d57 ffc 0 1d58
ffe 1d5b :3 0 1d5b
0 1d5b 1d5a 1d58
1d59 :6 0 1d5d 4d
:3 0 1001 1d5f 1003
1d5e 1d5d :2 0 1d60
1005 :2 0 1d62 0
1d62 1d61 1d0f 1d60
:6 0 1e42 1 :3 0
9d :3 0 a7 :3 0
8b :4 0 1e6 1
:8 0 1d7d ed :4 0
1d68 :3 0 105 :3 0
e7 :2 0 100a 1d6b
1d6c :3 0 15 :3 0
ee :3 0 1d6e 1d6f
0 45 :2 0 1d70
1d71 0 1d73 100d
1d7a 15 :3 0 ee
:3 0 1d74 1d75 0
ef :2 0 1d76 1d77
0 1d79 100f 1d7b
1d6d 1d73 0 1d7c
0 1d79 0 1d7c
1011 0 1d7d 1014
1dd0 f2 :3 0 15
:3 0 ee :3 0 1d7f
1d80 0 f1 :3 0
1d81 1d82 0 1d84
1017 1d86 1019 1d85
1d84 :2 0 1dce f3
:3 0 15 :3 0 ee
:3 0 1d89 1d8a 0
f1 :3 0 1d8b 1d8c
0 1dc6 d0 :3 0
d1 :3 0 1d8e 1d8f
0 d0 :3 0 e0
:3 0 1d91 1d92 0
f4 :2 0 2 :4 0
1e7 :2 0 e2 :2 0
30 :2 0 101b 1d97
1d99 :3 0 101e 1d93
1d9b 1d90 1d9d 1d9c
:2 0 d3 :3 0 e3
:3 0 1d9f 1da0 0
d5 :4 0 1e8 :4 0
d8 :2 0 d9 :3 0
1022 1da4 1da6 :3 0
d8 :2 0 f7 :4 0
1025 1da8 1daa :3 0
d8 :2 0 f8 :4 0
1028 1dac 1dae :3 0
d8 :2 0 f1 :3 0
102b 1db0 1db2 :3 0
d8 :2 0 f9 :4 0
102e 1db4 1db6 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1031 1db9
1dbd 1035 1db8 1dbf
:3 0 1038 1da1 1dc1
:2 0 1dc3 103b 1dc4
1d9e 1dc3 0 1dc5
103d 0 1dc6 103f
1dc9 :3 0 1dc9 0
1dc9 1dc8 1dc6 1dc7
:6 0 1dcb 4f :3 0
1042 1dcd 1044 1dcc
1dcb :2 0 1dce 1046
:2 0 1dd0 0 1dd0
1dcf 1d7d 1dce :6 0
1e42 1 :3 0 1d4
:3 0 9e :3 0 28
:3 0 a7 :3 0 8b
:4 0 1e9 1 :8 0
1ded ed :4 0 1dd8
:3 0 105 :3 0 e7
:2 0 104b 1ddb 1ddc
:3 0 15 :3 0 ee
:3 0 1dde 1ddf 0
45 :2 0 1de0 1de1
0 1de3 104e 1dea
15 :3 0 ee :3 0
1de4 1de5 0 ef
:2 0 1de6 1de7 0
1de9 1050 1deb 1ddd
1de3 0 1dec 0
1de9 0 1dec 1052
0 1ded 1055 1e40
f2 :3 0 15 :3 0
ee :3 0 1def 1df0
0 f1 :3 0 1df1
1df2 0 1df4 1058
1df6 105a 1df5 1df4
:2 0 1e3e f3 :3 0
15 :3 0 ee :3 0
1df9 1dfa 0 f1
:3 0 1dfb 1dfc 0
1e36 d0 :3 0 d1
:3 0 1dfe 1dff 0
d0 :3 0 e0 :3 0
1e01 1e02 0 f4
:2 0 2 :4 0 1ea
:2 0 e2 :2 0 30
:2 0 105c 1e07 1e09
:3 0 105f 1e03 1e0b
1e00 1e0d 1e0c :2 0
d3 :3 0 e3 :3 0
1e0f 1e10 0 d5
:4 0 1eb :4 0 d8
:2 0 d9 :3 0 1063
1e14 1e16 :3 0 d8
:2 0 f7 :4 0 1066
1e18 1e1a :3 0 d8
:2 0 f8 :4 0 1069
1e1c 1e1e :3 0 d8
:2 0 f1 :3 0 106c
1e20 1e22 :3 0 d8
:2 0 f9 :4 0 106f
1e24 1e26 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1072 1e29 1e2d
1076 1e28 1e2f :3 0
1079 1e11 1e31 :2 0
1e33 107c 1e34 1e0e
1e33 0 1e35 107e
0 1e36 1080 1e39
:3 0 1e39 0 1e39
1e38 1e36 1e37 :6 0
1e3b 51 :3 0 1083
1e3d 1085 1e3c 1e3b
:2 0 1e3e 1087 :2 0
1e40 0 1e40 1e3f
1ded 1e3e :6 0 1e42
1 :3 0 108a 1e44
1c12 1c85 0 1e45
0 1e42 0 1e45
108f 0 1e46 1092
1e47 1b21 1e46 0
1e48 1097 0 1e49
1099 1e4a 1a7a 1e49
0 1e4b 109d 0
1e4d 15c :3 0 109f
1ed4 8f :3 0 55
:3 0 45 :2 0 10a3
1e4e 1e51 14e :2 0
45 :2 0 10a8 1e53
1e55 :3 0 153 :2 0
10ab 1e57 1e58 :3 0
8f :3 0 6c :3 0
45 :2 0 10ad 1e5a
1e5d 14e :2 0 45
:2 0 10b2 1e5f 1e61
:3 0 1e59 1e63 1e62
:2 0 d0 :3 0 d1
:3 0 1e65 1e66 0
d0 :3 0 e0 :3 0
1e68 1e69 0 1d
:2 0 2 :4 0 1ec
:2 0 e2 :2 0 30
:2 0 10b5 1e6e 1e70
:3 0 10b8 1e6a 1e72
1e67 1e74 1e73 :2 0
d3 :3 0 e3 :3 0
1e76 1e77 0 d5
:4 0 1ed :4 0 d8
:2 0 d9 :3 0 10bc
1e7b 1e7d :3 0 d8
:2 0 f7 :4 0 10bf
1e7f 1e81 :3 0 d8
:2 0 fe :4 0 10c2
1e83 1e85 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 159
:3 0 1e8a 1e8b 0
10c5 1e89 1e8d de
:4 0 10c7 1e88 1e90
10ca 1e87 1e92 :3 0
d8 :2 0 100 :4 0
10cd 1e94 1e96 :3 0
d8 :2 0 db :4 0
10d0 1e98 1e9a :3 0
d8 :2 0 27 :3 0
10d3 1e9c 1e9e :3 0
d8 :2 0 db :4 0
10d6 1ea0 1ea2 :3 0
10d9 1e78 1ea4 :2 0
1ea6 10dc 1ea7 1e75
1ea6 0 1ea8 10de
0 1ed2 d0 :3 0
d1 :3 0 1ea9 1eaa
0 d0 :3 0 e0
:3 0 1eac 1ead 0
30 :2 0 2 :4 0
1ee :2 0 e2 :2 0
30 :2 0 10e0 1eb2
1eb4 :3 0 10e3 1eae
1eb6 1eab 1eb8 1eb7
:2 0 d3 :3 0 e3
:3 0 1eba 1ebb 0
d5 :4 0 1ef :4 0
d8 :2 0 d9 :3 0
10e7 1ebf 1ec1 :3 0
10ea 1ebc 1ec3 :2 0
1ec5 10ed 1ec6 1eb9
1ec5 0 1ec7 10ef
0 1ed2 103 :3 0
104 :3 0 1ec8 1ec9
0 1a :3 0 159
:3 0 1ecb 1ecc 0
27 :3 0 105 :3 0
10f1 1eca 1ed0 :2 0
1ed2 10f5 1ed3 1e64
1ed2 0 1ed5 19d6
1e4d 0 1ed5 10f9
0 26b8 92 :3 0
14e :2 0 45 :2 0
10fe 1ed7 1ed9 :3 0
23 :3 0 8b :3 0
1edb 1edc 0 2393
8f :3 0 6b :3 0
45 :2 0 1101 1ede
1ee1 e7 :2 0 45
:2 0 1106 1ee3 1ee5
:3 0 1ee6 :2 0 8f
:3 0 6a :3 0 45
:2 0 1109 1ee8 1eeb
e7 :2 0 45 :2 0
110e 1eed 1eef :3 0
1ef0 :2 0 1ee7 1ef2
1ef1 :2 0 8f :3 0
82 :3 0 45 :2 0
1111 1ef4 1ef7 e7
:2 0 45 :2 0 1116
1ef9 1efb :3 0 9d
:3 0 a5 :3 0 21
:3 0 9f :3 0 27
:3 0 a0 :3 0 b5
:3 0 62 :3 0 1f0
:3 0 65 :3 0 b6
:3 0 64 :3 0 1f1
:3 0 66 :3 0 ab
:3 0 61 :3 0 ab
:3 0 88 :3 0 1f2
:3 0 aa :3 0 1f3
:3 0 62 :3 0 1f4
:3 0 1a1 :3 0 176
:3 0 1f4 :3 0 1a
:3 0 1f5 :3 0 a7
:3 0 23 :4 0 1f6
1 :8 0 1f31 ed
:4 0 1f1c :3 0 105
:3 0 e7 :2 0 111b
1f1f 1f20 :3 0 15
:3 0 ee :3 0 1f22
1f23 0 45 :2 0
1f24 1f25 0 1f27
111e 1f2e 15 :3 0
ee :3 0 1f28 1f29
0 ef :2 0 1f2a
1f2b 0 1f2d 1120
1f2f 1f21 1f27 0
1f30 0 1f2d 0
1f30 1122 0 1f31
1125 1f84 f2 :3 0
15 :3 0 ee :3 0
1f33 1f34 0 f1
:3 0 1f35 1f36 0
1f38 1128 1f3a 112a
1f39 1f38 :2 0 1f82
f3 :3 0 15 :3 0
ee :3 0 1f3d 1f3e
0 f1 :3 0 1f3f
1f40 0 1f7a d0
:3 0 d1 :3 0 1f42
1f43 0 d0 :3 0
e0 :3 0 1f45 1f46
0 f4 :2 0 2
:4 0 1f7 :2 0 e2
:2 0 30 :2 0 112c
1f4b 1f4d :3 0 112f
1f47 1f4f 1f44 1f51
1f50 :2 0 d3 :3 0
e3 :3 0 1f53 1f54
0 d5 :4 0 1f8
:4 0 d8 :2 0 d9
:3 0 1133 1f58 1f5a
:3 0 d8 :2 0 f7
:4 0 1136 1f5c 1f5e
:3 0 d8 :2 0 f8
:4 0 1139 1f60 1f62
:3 0 d8 :2 0 f1
:3 0 113c 1f64 1f66
:3 0 d8 :2 0 f9
:4 0 113f 1f68 1f6a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1142
1f6d 1f71 1146 1f6c
1f73 :3 0 1149 1f55
1f75 :2 0 1f77 114c
1f78 1f52 1f77 0
1f79 114e 0 1f7a
1150 1f7d :3 0 1f7d
0 1f7d 1f7c 1f7a
1f7b :6 0 1f7f 53
:3 0 1153 1f81 1155
1f80 1f7f :2 0 1f82
1157 :2 0 1f84 0
1f84 1f83 1f31 1f82
:6 0 1f86 1 :3 0
115a 2015 9d :3 0
a5 :3 0 21 :3 0
9f :3 0 27 :3 0
a0 :3 0 b5 :3 0
62 :3 0 1f0 :3 0
65 :3 0 b6 :3 0
64 :3 0 1f1 :3 0
66 :3 0 ab :3 0
61 :3 0 ab :3 0
88 :3 0 1f2 :3 0
aa :3 0 1f3 :3 0
62 :3 0 1f9 :3 0
aa :3 0 aa :3 0
64 :3 0 1f4 :3 0
1a1 :3 0 176 :3 0
1f4 :3 0 1a :3 0
1f5 :3 0 a7 :3 0
23 :4 0 1fa 1
:8 0 1fbf ed :4 0
1faa :3 0 105 :3 0
e7 :2 0 115e 1fad
1fae :3 0 15 :3 0
ee :3 0 1fb0 1fb1
0 45 :2 0 1fb2
1fb3 0 1fb5 1161
1fbc 15 :3 0 ee
:3 0 1fb6 1fb7 0
ef :2 0 1fb8 1fb9
0 1fbb 1163 1fbd
1faf 1fb5 0 1fbe
0 1fbb 0 1fbe
1165 0 1fbf 1168
2012 f2 :3 0 15
:3 0 ee :3 0 1fc1
1fc2 0 f1 :3 0
1fc3 1fc4 0 1fc6
116b 1fc8 116d 1fc7
1fc6 :2 0 2010 f3
:3 0 15 :3 0 ee
:3 0 1fcb 1fcc 0
f1 :3 0 1fcd 1fce
0 2008 d0 :3 0
d1 :3 0 1fd0 1fd1
0 d0 :3 0 e0
:3 0 1fd3 1fd4 0
f4 :2 0 2 :4 0
1fb :2 0 e2 :2 0
30 :2 0 116f 1fd9
1fdb :3 0 1172 1fd5
1fdd 1fd2 1fdf 1fde
:2 0 d3 :3 0 e3
:3 0 1fe1 1fe2 0
d5 :4 0 1fc :4 0
d8 :2 0 d9 :3 0
1176 1fe6 1fe8 :3 0
d8 :2 0 f7 :4 0
1179 1fea 1fec :3 0
d8 :2 0 f8 :4 0
117c 1fee 1ff0 :3 0
d8 :2 0 f1 :3 0
117f 1ff2 1ff4 :3 0
d8 :2 0 f9 :4 0
1182 1ff6 1ff8 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1185 1ffb
1fff 1189 1ffa 2001
:3 0 118c 1fe3 2003
:2 0 2005 118f 2006
1fe0 2005 0 2007
1191 0 2008 1193
200b :3 0 200b 0
200b 200a 2008 2009
:6 0 200d 55 :3 0
1196 200f 1198 200e
200d :2 0 2010 119a
:2 0 2012 0 2012
2011 1fbf 2010 :6 0
2014 1 :3 0 119d
2016 1efc 1f86 0
2017 0 2014 0
2017 119f 0 2019
15c :3 0 11a2 2242
8f :3 0 6b :3 0
45 :2 0 11a4 201a
201d e7 :2 0 45
:2 0 11a9 201f 2021
:3 0 9d :3 0 a5
:3 0 21 :3 0 9f
:3 0 27 :3 0 a0
:3 0 b5 :3 0 62
:3 0 1f0 :3 0 65
:3 0 ab :3 0 61
:3 0 ab :3 0 88
:3 0 1f2 :3 0 aa
:3 0 1f3 :3 0 62
:3 0 1f4 :3 0 1a1
:3 0 176 :3 0 1f4
:3 0 1a :3 0 1f5
:3 0 a7 :3 0 23
:4 0 1fd 1 :8 0
2053 ed :4 0 203e
:3 0 105 :3 0 e7
:2 0 11ae 2041 2042
:3 0 15 :3 0 ee
:3 0 2044 2045 0
45 :2 0 2046 2047
0 2049 11b1 2050
15 :3 0 ee :3 0
204a 204b 0 ef
:2 0 204c 204d 0
204f 11b3 2051 2043
2049 0 2052 0
204f 0 2052 11b5
0 2053 11b8 20a6
f2 :3 0 15 :3 0
ee :3 0 2055 2056
0 f1 :3 0 2057
2058 0 205a 11bb
205c 11bd 205b 205a
:2 0 20a4 f3 :3 0
15 :3 0 ee :3 0
205f 2060 0 f1
:3 0 2061 2062 0
209c d0 :3 0 d1
:3 0 2064 2065 0
d0 :3 0 e0 :3 0
2067 2068 0 f4
:2 0 2 :4 0 1fe
:2 0 e2 :2 0 30
:2 0 11bf 206d 206f
:3 0 11c2 2069 2071
2066 2073 2072 :2 0
d3 :3 0 e3 :3 0
2075 2076 0 d5
:4 0 1ff :4 0 d8
:2 0 d9 :3 0 11c6
207a 207c :3 0 d8
:2 0 f7 :4 0 11c9
207e 2080 :3 0 d8
:2 0 f8 :4 0 11cc
2082 2084 :3 0 d8
:2 0 f1 :3 0 11cf
2086 2088 :3 0 d8
:2 0 f9 :4 0 11d2
208a 208c :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 11d5 208f 2093
11d9 208e 2095 :3 0
11dc 2077 2097 :2 0
2099 11df 209a 2074
2099 0 209b 11e1
0 209c 11e3 209f
:3 0 209f 0 209f
209e 209c 209d :6 0
20a1 57 :3 0 11e6
20a3 11e8 20a2 20a1
:2 0 20a4 11ea :2 0
20a6 0 20a6 20a5
2053 20a4 :6 0 20a9
1 :3 0 15c :3 0
11ed 20aa 2022 20a9
0 2244 8f :3 0
6a :3 0 45 :2 0
11ef 20ab 20ae e7
:2 0 45 :2 0 11f4
20b0 20b2 :3 0 8f
:3 0 82 :3 0 45
:2 0 11f7 20b4 20b7
e7 :2 0 45 :2 0
11fc 20b9 20bb :3 0
9d :3 0 a5 :3 0
21 :3 0 9f :3 0
27 :3 0 a0 :3 0
b6 :3 0 64 :3 0
1f1 :3 0 66 :3 0
ab :3 0 61 :3 0
ab :3 0 88 :3 0
1f4 :3 0 1a1 :3 0
176 :3 0 1f4 :3 0
1a :3 0 1f5 :3 0
a7 :3 0 23 :4 0
200 1 :8 0 20e9
ed :4 0 20d4 :3 0
105 :3 0 e7 :2 0
1201 20d7 20d8 :3 0
15 :3 0 ee :3 0
20da 20db 0 45
:2 0 20dc 20dd 0
20df 1204 20e6 15
:3 0 ee :3 0 20e0
20e1 0 ef :2 0
20e2 20e3 0 20e5
1206 20e7 20d9 20df
0 20e8 0 20e5
0 20e8 1208 0
20e9 120b 213c f2
:3 0 15 :3 0 ee
:3 0 20eb 20ec 0
f1 :3 0 20ed 20ee
0 20f0 120e 20f2
1210 20f1 20f0 :2 0
213a f3 :3 0 15
:3 0 ee :3 0 20f5
20f6 0 f1 :3 0
20f7 20f8 0 2132
d0 :3 0 d1 :3 0
20fa 20fb 0 d0
:3 0 e0 :3 0 20fd
20fe 0 f4 :2 0
2 :4 0 201 :2 0
e2 :2 0 30 :2 0
1212 2103 2105 :3 0
1215 20ff 2107 20fc
2109 2108 :2 0 d3
:3 0 e3 :3 0 210b
210c 0 d5 :4 0
202 :4 0 d8 :2 0
d9 :3 0 1219 2110
2112 :3 0 d8 :2 0
f7 :4 0 121c 2114
2116 :3 0 d8 :2 0
f8 :4 0 121f 2118
211a :3 0 d8 :2 0
f1 :3 0 1222 211c
211e :3 0 d8 :2 0
f9 :4 0 1225 2120
2122 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1228 2125 2129 122c
2124 212b :3 0 122f
210d 212d :2 0 212f
1232 2130 210a 212f
0 2131 1234 0
2132 1236 2135 :3 0
2135 0 2135 2134
2132 2133 :6 0 2137
59 :3 0 1239 2139
123b 2138 2137 :2 0
213a 123d :2 0 213c
0 213c 213b 20e9
213a :6 0 213e 1
:3 0 1240 21c5 9d
:3 0 a5 :3 0 21
:3 0 9f :3 0 27
:3 0 a0 :3 0 b6
:3 0 64 :3 0 1f1
:3 0 66 :3 0 ab
:3 0 61 :3 0 ab
:3 0 88 :3 0 1f9
:3 0 aa :3 0 aa
:3 0 64 :3 0 1f4
:3 0 1a1 :3 0 176
:3 0 1f4 :3 0 1a
:3 0 1f5 :3 0 a7
:3 0 23 :4 0 203
1 :8 0 216f ed
:4 0 215a :3 0 105
:3 0 e7 :2 0 1244
215d 215e :3 0 15
:3 0 ee :3 0 2160
2161 0 45 :2 0
2162 2163 0 2165
1247 216c 15 :3 0
ee :3 0 2166 2167
0 ef :2 0 2168
2169 0 216b 1249
216d 215f 2165 0
216e 0 216b 0
216e 124b 0 216f
124e 21c2 f2 :3 0
15 :3 0 ee :3 0
2171 2172 0 f1
:3 0 2173 2174 0
2176 1251 2178 1253
2177 2176 :2 0 21c0
f3 :3 0 15 :3 0
ee :3 0 217b 217c
0 f1 :3 0 217d
217e 0 21b8 d0
:3 0 d1 :3 0 2180
2181 0 d0 :3 0
e0 :3 0 2183 2184
0 f4 :2 0 2
:4 0 204 :2 0 e2
:2 0 30 :2 0 1255
2189 218b :3 0 1258
2185 218d 2182 218f
218e :2 0 d3 :3 0
e3 :3 0 2191 2192
0 d5 :4 0 205
:4 0 d8 :2 0 d9
:3 0 125c 2196 2198
:3 0 d8 :2 0 f7
:4 0 125f 219a 219c
:3 0 d8 :2 0 f8
:4 0 1262 219e 21a0
:3 0 d8 :2 0 f1
:3 0 1265 21a2 21a4
:3 0 d8 :2 0 f9
:4 0 1268 21a6 21a8
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 126b
21ab 21af 126f 21aa
21b1 :3 0 1272 2193
21b3 :2 0 21b5 1275
21b6 2190 21b5 0
21b7 1277 0 21b8
1279 21bb :3 0 21bb
0 21bb 21ba 21b8
21b9 :6 0 21bd 5b
:3 0 127c 21bf 127e
21be 21bd :2 0 21c0
1280 :2 0 21c2 0
21c2 21c1 216f 21c0
:6 0 21c4 1 :3 0
1283 21c6 20bc 213e
0 21c7 0 21c4
0 21c7 1285 0
21c8 1288 21c9 20b3
21c8 0 2244 9d
:3 0 a5 :3 0 21
:3 0 ab :3 0 61
:3 0 ab :3 0 88
:3 0 9f :3 0 27
:3 0 a0 :3 0 a7
:3 0 23 :4 0 206
1 :8 0 21ec ed
:4 0 21d7 :3 0 105
:3 0 e7 :2 0 128c
21da 21db :3 0 15
:3 0 ee :3 0 21dd
21de 0 45 :2 0
21df 21e0 0 21e2
128f 21e9 15 :3 0
ee :3 0 21e3 21e4
0 ef :2 0 21e5
21e6 0 21e8 1291
21ea 21dc 21e2 0
21eb 0 21e8 0
21eb 1293 0 21ec
1296 223f f2 :3 0
15 :3 0 ee :3 0
21ee 21ef 0 f1
:3 0 21f0 21f1 0
21f3 1299 21f5 129b
21f4 21f3 :2 0 223d
f3 :3 0 15 :3 0
ee :3 0 21f8 21f9
0 f1 :3 0 21fa
21fb 0 2235 d0
:3 0 d1 :3 0 21fd
21fe 0 d0 :3 0
e0 :3 0 2200 2201
0 f4 :2 0 2
:4 0 207 :2 0 e2
:2 0 30 :2 0 129d
2206 2208 :3 0 12a0
2202 220a 21ff 220c
220b :2 0 d3 :3 0
e3 :3 0 220e 220f
0 d5 :4 0 208
:4 0 d8 :2 0 d9
:3 0 12a4 2213 2215
:3 0 d8 :2 0 f7
:4 0 12a7 2217 2219
:3 0 d8 :2 0 f8
:4 0 12aa 221b 221d
:3 0 d8 :2 0 f1
:3 0 12ad 221f 2221
:3 0 d8 :2 0 f9
:4 0 12b0 2223 2225
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 12b3
2228 222c 12b7 2227
222e :3 0 12ba 2210
2230 :2 0 2232 12bd
2233 220d 2232 0
2234 12bf 0 2235
12c1 2238 :3 0 2238
0 2238 2237 2235
2236 :6 0 223a 5d
:3 0 12c4 223c 12c6
223b 223a :2 0 223d
12c8 :2 0 223f 0
223f 223e 21ec 223d
:6 0 2241 1 :3 0
12cb 2243 1ef3 2019
0 2244 0 2241
0 2244 12cd 0
2393 1d4 :3 0 9e
:3 0 28 :3 0 a7
:3 0 23 :4 0 209
1 :8 0 2260 ed
:4 0 224b :3 0 105
:3 0 e7 :2 0 12d4
224e 224f :3 0 15
:3 0 ee :3 0 2251
2252 0 45 :2 0
2253 2254 0 2256
12d7 225d 15 :3 0
ee :3 0 2257 2258
0 ef :2 0 2259
225a 0 225c 12d9
225e 2250 2256 0
225f 0 225c 0
225f 12db 0 2260
12de 22b3 f2 :3 0
15 :3 0 ee :3 0
2262 2263 0 f1
:3 0 2264 2265 0
2267 12e1 2269 12e3
2268 2267 :2 0 22b1
f3 :3 0 15 :3 0
ee :3 0 226c 226d
0 f1 :3 0 226e
226f 0 22a9 d0
:3 0 d1 :3 0 2271
2272 0 d0 :3 0
e0 :3 0 2274 2275
0 f4 :2 0 2
:4 0 20a :2 0 e2
:2 0 30 :2 0 12e5
227a 227c :3 0 12e8
2276 227e 2273 2280
227f :2 0 d3 :3 0
e3 :3 0 2282 2283
0 d5 :4 0 20b
:4 0 d8 :2 0 d9
:3 0 12ec 2287 2289
:3 0 d8 :2 0 f7
:4 0 12ef 228b 228d
:3 0 d8 :2 0 f8
:4 0 12f2 228f 2291
:3 0 d8 :2 0 f1
:3 0 12f5 2293 2295
:3 0 d8 :2 0 f9
:4 0 12f8 2297 2299
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 12fb
229c 22a0 12ff 229b
22a2 :3 0 1302 2284
22a4 :2 0 22a6 1305
22a7 2281 22a6 0
22a8 1307 0 22a9
1309 22ac :3 0 22ac
0 22ac 22ab 22a9
22aa :6 0 22ae 5f
:3 0 130c 22b0 130e
22af 22ae :2 0 22b1
1310 :2 0 22b3 0
22b3 22b2 2260 22b1
:6 0 2393 1 :3 0
bd :3 0 a5 :3 0
1c :4 0 1e3 1
:8 0 22ce ed :4 0
22b9 :3 0 105 :3 0
e7 :2 0 1315 22bc
22bd :3 0 15 :3 0
ee :3 0 22bf 22c0
0 45 :2 0 22c1
22c2 0 22c4 1318
22cb 15 :3 0 ee
:3 0 22c5 22c6 0
ef :2 0 22c7 22c8
0 22ca 131a 22cc
22be 22c4 0 22cd
0 22ca 0 22cd
131c 0 22ce 131f
2321 f2 :3 0 15
:3 0 ee :3 0 22d0
22d1 0 f1 :3 0
22d2 22d3 0 22d5
1322 22d7 1324 22d6
22d5 :2 0 231f f3
:3 0 15 :3 0 ee
:3 0 22da 22db 0
f1 :3 0 22dc 22dd
0 2317 d0 :3 0
d1 :3 0 22df 22e0
0 d0 :3 0 e0
:3 0 22e2 22e3 0
f4 :2 0 2 :4 0
20c :2 0 e2 :2 0
30 :2 0 1326 22e8
22ea :3 0 1329 22e4
22ec 22e1 22ee 22ed
:2 0 d3 :3 0 e3
:3 0 22f0 22f1 0
d5 :4 0 20d :4 0
d8 :2 0 d9 :3 0
132d 22f5 22f7 :3 0
d8 :2 0 f7 :4 0
1330 22f9 22fb :3 0
d8 :2 0 f8 :4 0
1333 22fd 22ff :3 0
d8 :2 0 f1 :3 0
1336 2301 2303 :3 0
d8 :2 0 f9 :4 0
1339 2305 2307 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 133c 230a
230e 1340 2309 2310
:3 0 1343 22f2 2312
:2 0 2314 1346 2315
22ef 2314 0 2316
1348 0 2317 134a
231a :3 0 231a 0
231a 2319 2317 2318
:6 0 231c 61 :3 0
134d 231e 134f 231d
231c :2 0 231f 1351
:2 0 2321 0 2321
2320 22ce 231f :6 0
2393 1 :3 0 1df
:3 0 9e :3 0 28
:3 0 9f :3 0 29
:4 0 1e0 1 :8 0
233e ed :4 0 2329
:3 0 105 :3 0 e7
:2 0 1356 232c 232d
:3 0 15 :3 0 ee
:3 0 232f 2330 0
45 :2 0 2331 2332
0 2334 1359 233b
15 :3 0 ee :3 0
2335 2336 0 ef
:2 0 2337 2338 0
233a 135b 233c 232e
2334 0 233d 0
233a 0 233d 135d
0 233e 1360 2391
f2 :3 0 15 :3 0
ee :3 0 2340 2341
0 f1 :3 0 2342
2343 0 2345 1363
2347 1365 2346 2345
:2 0 238f f3 :3 0
15 :3 0 ee :3 0
234a 234b 0 f1
:3 0 234c 234d 0
2387 d0 :3 0 d1
:3 0 234f 2350 0
d0 :3 0 e0 :3 0
2352 2353 0 f4
:2 0 2 :4 0 20e
:2 0 e2 :2 0 30
:2 0 1367 2358 235a
:3 0 136a 2354 235c
2351 235e 235d :2 0
d3 :3 0 e3 :3 0
2360 2361 0 d5
:4 0 20f :4 0 d8
:2 0 d9 :3 0 136e
2365 2367 :3 0 d8
:2 0 f7 :4 0 1371
2369 236b :3 0 d8
:2 0 f8 :4 0 1374
236d 236f :3 0 d8
:2 0 f1 :3 0 1377
2371 2373 :3 0 d8
:2 0 f9 :4 0 137a
2375 2377 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 137d 237a 237e
1381 2379 2380 :3 0
1384 2362 2382 :2 0
2384 1387 2385 235f
2384 0 2386 1389
0 2387 138b 238a
:3 0 238a 0 238a
2389 2387 2388 :6 0
238c 63 :3 0 138e
238e 1390 238d 238c
:2 0 238f 1392 :2 0
2391 0 2391 2390
233e 238f :6 0 2393
1 :3 0 1395 2394
1eda 2393 0 2395
139b 0 26b8 93
:3 0 14e :2 0 45
:2 0 139f 2397 2399
:3 0 8f :3 0 4d
:3 0 45 :2 0 13a2
239b 239e e7 :2 0
45 :2 0 13a7 23a0
23a2 :3 0 57 :3 0
1a :3 0 210 :3 0
23a5 23a6 0 23a4
23a7 0 23a9 13aa
23ba 57 :3 0 175
:3 0 176 :3 0 23ab
23ac 0 8f :3 0
57 :3 0 45 :2 0
13ac 23ae 23b1 1a
:3 0 210 :3 0 23b3
23b4 0 13af 23ad
23b6 23aa 23b7 0
23b9 13b2 23bb 23a3
23a9 0 23bc 0
23b9 0 23bc 13b4
0 264d 5f :3 0
30 :2 0 23bd 23be
0 264d 8f :3 0
80 :3 0 45 :2 0
13b7 23c0 23c3 e7
:2 0 30 :2 0 13bc
23c5 23c7 :3 0 8f
:3 0 48 :3 0 45
:2 0 13bf 23c9 23cc
8f :3 0 211 :2 0
86 :3 0 45 :2 0
13c2 23ce 23d2 13c7
23cf 23d4 :3 0 48
:3 0 8f :3 0 86
:3 0 45 :2 0 13ca
23d7 23da 23d6 23db
0 23dd 13cd 23de
23d5 23dd 0 23df
13cf 0 264a 53
:3 0 45 :2 0 23e0
23e1 0 264a 49
:3 0 45 :2 0 23e3
23e4 0 264a 175
:3 0 212 :3 0 23e6
23e7 0 61 :3 0
30 :2 0 13d1 23e8
23eb 14e :2 0 45
:2 0 13d6 23ed 23ef
:3 0 5a :3 0 146
:2 0 23f1 23f2 0
23f4 13d9 23f9 5a
:3 0 30 :2 0 23f5
23f6 0 23f8 13db
23fa 23f0 23f4 0
23fb 0 23f8 0
23fb 13dd 0 264a
8f :3 0 f :3 0
45 :2 0 13e0 23fc
23ff e7 :2 0 45
:2 0 13e5 2401 2403
:3 0 4d :3 0 45
:2 0 2405 2406 0
2408 13e8 2409 2404
2408 0 240a 13ea
0 264a 75 :3 0
213 :3 0 39 :3 0
3a :3 0 8f :3 0
4f :3 0 45 :2 0
13ec 240f 2412 8f
:3 0 50 :3 0 45
:2 0 13ef 2414 2417
8f :3 0 5b :3 0
45 :2 0 13f2 2419
241c 8f :3 0 57
:3 0 45 :2 0 13f5
241e 2421 8f :3 0
51 :3 0 45 :2 0
13f8 2423 2426 8f
:3 0 4e :3 0 45
:2 0 13fb 2428 242b
8f :3 0 58 :3 0
45 :2 0 13fe 242d
2430 8f :3 0 59
:3 0 45 :2 0 1401
2432 2435 4d :3 0
48 :3 0 52 :3 0
1404 240c 243a 240b
243b 0 264a 8f
:3 0 75 :3 0 45
:2 0 1412 243d 2440
1a :3 0 e7 :2 0
214 :3 0 2442 2444
0 1417 2443 2446
:3 0 d0 :3 0 d1
:3 0 2448 2449 0
d0 :3 0 e0 :3 0
244b 244c 0 215
:2 0 2 :4 0 216
:2 0 e2 :2 0 30
:2 0 141a 2451 2453
:3 0 141d 244d 2455
244a 2457 2456 :2 0
d3 :3 0 e3 :3 0
2459 245a 0 d5
:4 0 217 :4 0 d8
:2 0 d9 :3 0 1421
245e 2460 :3 0 d8
:2 0 f7 :4 0 1424
2462 2464 :3 0 d8
:2 0 fe :4 0 1427
2466 2468 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 214
:3 0 246d 246e 0
142a 246c 2470 de
:4 0 142c 246b 2473
142f 246a 2475 :3 0
1432 245b 2477 :2 0
2479 1435 247a 2458
2479 0 247b 1437
0 24a5 d0 :3 0
d1 :3 0 247c 247d
0 d0 :3 0 e0
:3 0 247f 2480 0
30 :2 0 2 :4 0
218 :2 0 e2 :2 0
30 :2 0 1439 2485
2487 :3 0 143c 2481
2489 247e 248b 248a
:2 0 d3 :3 0 e3
:3 0 248d 248e 0
d5 :4 0 219 :4 0
d8 :2 0 d9 :3 0
1440 2492 2494 :3 0
1443 248f 2496 :2 0
2498 1446 2499 248c
2498 0 249a 1448
0 24a5 103 :3 0
21a :3 0 249b 249c
0 1a :3 0 214
:3 0 249e 249f 0
105 :3 0 144a 249d
24a2 :2 0 24a5 15c
:3 0 144d 251e 8f
:3 0 75 :3 0 45
:2 0 1451 24a6 24a9
14e :2 0 45 :2 0
1456 24ab 24ad :3 0
d0 :3 0 d1 :3 0
24af 24b0 0 d0
:3 0 e0 :3 0 24b2
24b3 0 1d :2 0
2 :4 0 21b :2 0
e2 :2 0 30 :2 0
1459 24b8 24ba :3 0
145c 24b4 24bc 24b1
24be 24bd :2 0 d3
:3 0 e3 :3 0 24c0
24c1 0 d5 :4 0
21c :4 0 d8 :2 0
d9 :3 0 1460 24c5
24c7 :3 0 d8 :2 0
f7 :4 0 1463 24c9
24cb :3 0 d8 :2 0
fe :4 0 1466 24cd
24cf :3 0 d8 :2 0
8f :3 0 dd :3 0
75 :3 0 1469 24d3
24d5 de :4 0 146b
24d2 24d8 146e 24d1
24da :3 0 d8 :2 0
100 :4 0 1471 24dc
24de :3 0 d8 :2 0
db :4 0 1474 24e0
24e2 :3 0 d8 :2 0
28 :3 0 1477 24e4
24e6 :3 0 d8 :2 0
db :4 0 147a 24e8
24ea :3 0 147d 24c2
24ec :2 0 24ee 1480
24ef 24bf 24ee 0
24f0 1482 0 251c
d0 :3 0 d1 :3 0
24f1 24f2 0 d0
:3 0 e0 :3 0 24f4
24f5 0 30 :2 0
2 :4 0 21d :2 0
e2 :2 0 30 :2 0
1484 24fa 24fc :3 0
1487 24f6 24fe 24f3
2500 24ff :2 0 d3
:3 0 e3 :3 0 2502
2503 0 d5 :4 0
21e :4 0 d8 :2 0
d9 :3 0 148b 2507
2509 :3 0 148e 2504
250b :2 0 250d 1491
250e 2501 250d 0
250f 1493 0 251c
103 :3 0 104 :3 0
2510 2511 0 8f
:3 0 75 :3 0 45
:2 0 1495 2513 2516
28 :3 0 105 :3 0
1498 2512 251a :2 0
251c 149c 251d 24ae
251c 0 251f 2447
24a5 0 251f 14a0
0 264a 74 :3 0
21f :2 0 2520 2521
0 264a 8c :3 0
220 :3 0 23 :3 0
28 :3 0 28 :3 0
27 :3 0 74 :3 0
4a :3 0 31 :3 0
31 :3 0 31 :3 0
31 :3 0 2a :3 0
2c :3 0 52 :3 0
48 :3 0 4d :3 0
4f :3 0 50 :3 0
49 :3 0 5b :3 0
36 :3 0 53 :3 0
57 :3 0 51 :3 0
4e :3 0 5a :3 0
58 :3 0 5c :3 0
1f :3 0 45 :2 0
45 :2 0 21f :2 0
21f :2 0 45 :2 0
14a3 2524 2546 2523
2547 0 264a 8c
:3 0 e7 :2 0 221
:2 0 14c7 254a 254c
:3 0 d0 :3 0 d1
:3 0 254e 254f 0
d0 :3 0 e0 :3 0
2551 2552 0 1d
:2 0 2 :4 0 222
:2 0 e2 :2 0 30
:2 0 14ca 2557 2559
:3 0 14cd 2553 255b
2550 255d 255c :2 0
d3 :3 0 e3 :3 0
255f 2560 0 d5
:4 0 223 :4 0 d8
:2 0 d9 :3 0 14d1
2564 2566 :3 0 d8
:2 0 f7 :4 0 14d4
2568 256a :3 0 d8
:2 0 fe :4 0 14d7
256c 256e :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 224
:3 0 2573 2574 0
14da 2572 2576 de
:4 0 14dc 2571 2579
14df 2570 257b :3 0
d8 :2 0 100 :4 0
14e2 257d 257f :3 0
d8 :2 0 db :4 0
14e5 2581 2583 :3 0
d8 :2 0 27 :3 0
14e8 2585 2587 :3 0
d8 :2 0 db :4 0
14eb 2589 258b :3 0
14ee 2561 258d :2 0
258f 14f1 2590 255e
258f 0 2591 14f3
0 25bc d0 :3 0
d1 :3 0 2592 2593
0 d0 :3 0 e0
:3 0 2595 2596 0
30 :2 0 2 :4 0
225 :2 0 e2 :2 0
30 :2 0 14f5 259b
259d :3 0 14f8 2597
259f 2594 25a1 25a0
:2 0 d3 :3 0 e3
:3 0 25a3 25a4 0
d5 :4 0 226 :4 0
d8 :2 0 d9 :3 0
14fc 25a8 25aa :3 0
14ff 25a5 25ac :2 0
25ae 1502 25af 25a2
25ae 0 25b0 1504
0 25bc 103 :3 0
104 :3 0 25b1 25b2
0 1a :3 0 224
:3 0 25b4 25b5 0
27 :3 0 105 :3 0
1506 25b3 25b9 :2 0
25bc 15c :3 0 150a
2647 8c :3 0 14e
:2 0 45 :2 0 1510
25be 25c0 :3 0 d0
:3 0 d1 :3 0 25c2
25c3 0 d0 :3 0
e0 :3 0 25c5 25c6
0 1d :2 0 2
:4 0 227 :2 0 e2
:2 0 30 :2 0 1513
25cb 25cd :3 0 1516
25c7 25cf 25c4 25d1
25d0 :2 0 d3 :3 0
e3 :3 0 25d3 25d4
0 d5 :4 0 228
:4 0 d8 :2 0 d9
:3 0 151a 25d8 25da
:3 0 d8 :2 0 f7
:4 0 151d 25dc 25de
:3 0 d8 :2 0 fe
:4 0 1520 25e0 25e2
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 1c6 :3 0 25e7
25e8 0 1523 25e6
25ea de :4 0 1525
25e5 25ed 1528 25e4
25ef :3 0 d8 :2 0
100 :4 0 152b 25f1
25f3 :3 0 d8 :2 0
db :4 0 152e 25f5
25f7 :3 0 d8 :2 0
21 :3 0 1531 25f9
25fb :3 0 d8 :2 0
db :4 0 1534 25fd
25ff :3 0 1537 25d5
2601 :2 0 2603 153a
2604 25d2 2603 0
2605 153c 0 262f
d0 :3 0 d1 :3 0
2606 2607 0 d0
:3 0 e0 :3 0 2609
260a 0 30 :2 0
2 :4 0 229 :2 0
e2 :2 0 30 :2 0
153e 260f 2611 :3 0
1541 260b 2613 2608
2615 2614 :2 0 d3
:3 0 e3 :3 0 2617
2618 0 d5 :4 0
22a :4 0 d8 :2 0
d9 :3 0 1545 261c
261e :3 0 1548 2619
2620 :2 0 2622 154b
2623 2616 2622 0
2624 154d 0 262f
103 :3 0 104 :3 0
2625 2626 0 1a
:3 0 1c6 :3 0 2628
2629 0 21 :3 0
105 :3 0 154f 2627
262d :2 0 262f 1553
2630 25c1 262f 0
2649 75 :3 0 ea
:2 0 2631 2632 0
2646 75 :3 0 22b
:3 0 28 :3 0 23
:3 0 75 :3 0 8f
:3 0 58 :3 0 45
:2 0 1557 2639 263c
8f :3 0 48 :3 0
45 :2 0 155a 263e
2641 155d 2635 2643
2634 2644 0 2646
1563 2648 254d 25bc
0 2649 0 2646
0 2649 1566 0
264a 156a 264b 23c8
264a 0 264c 1575
0 264d 1577 264e
239a 264d 0 264f
157b 0 26b8 5b
:3 0 1a :3 0 e9
:3 0 2651 2652 0
2650 2653 0 26b8
1b1 :3 0 22c :3 0
2a :3 0 1d4 :3 0
9e :3 0 28 :3 0
a7 :3 0 23 :4 0
22d 1 :8 0 2663
15 :3 0 ee :3 0
265e 265f 0 f1
:3 0 2660 2661 0
2663 157d 26b6 f2
:3 0 15 :3 0 ee
:3 0 2665 2666 0
f1 :3 0 2667 2668
0 266a 1580 266c
1582 266b 266a :2 0
26b4 f3 :3 0 15
:3 0 ee :3 0 266f
2670 0 f1 :3 0
2671 2672 0 26ac
d0 :3 0 d1 :3 0
2674 2675 0 d0
:3 0 e0 :3 0 2677
2678 0 f4 :2 0
2 :4 0 22e :2 0
e2 :2 0 30 :2 0
1584 267d 267f :3 0
1587 2679 2681 2676
2683 2682 :2 0 d3
:3 0 e3 :3 0 2685
2686 0 d5 :4 0
22f :4 0 d8 :2 0
d9 :3 0 158b 268a
268c :3 0 d8 :2 0
f7 :4 0 158e 268e
2690 :3 0 d8 :2 0
f8 :4 0 1591 2692
2694 :3 0 d8 :2 0
f1 :3 0 1594 2696
2698 :3 0 d8 :2 0
f9 :4 0 1597 269a
269c :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
159a 269f 26a3 159e
269e 26a5 :3 0 15a1
2687 26a7 :2 0 26a9
15a4 26aa 2684 26a9
0 26ab 15a6 0
26ac 15a8 26af :3 0
26af 0 26af 26ae
26ac 26ad :6 0 26b1
65 :3 0 15ab 26b3
15ad 26b2 26b1 :2 0
26b4 15af :2 0 26b6
0 26b6 26b5 2663
26b4 :6 0 26b8 1
:3 0 15b2 26b9 19cb
26b8 0 26ba 15ba
0 26bb 15bc 26bc
1838 26bb 0 26bd
15c3 0 26c1 4c
:3 0 45 :2 0 26be
26bf 0 26c1 15c5
26c2 1833 26c1 0
26c3 15c8 0 51ec
37 :3 0 ae :3 0
37 :3 0 d8 :2 0
230 :4 0 15ca 26c7
26c9 :3 0 30 :2 0
38 :2 0 15cd 26c5
26cd 26c4 26ce 0
51ec 22 :3 0 eb
:4 0 26d0 26d1 0
51ec 48 :3 0 9
:3 0 26d3 26d4 0
51ec 168 :3 0 41
:3 0 13b :3 0 13c
:3 0 29 :4 0 169
1 :8 0 26e1 15
:3 0 ee :3 0 26dc
26dd 0 f1 :3 0
26de 26df 0 26e1
15d1 2734 f2 :3 0
15 :3 0 ee :3 0
26e3 26e4 0 f1
:3 0 26e5 26e6 0
26e8 15d4 26ea 15d6
26e9 26e8 :2 0 2732
f3 :3 0 15 :3 0
ee :3 0 26ed 26ee
0 f1 :3 0 26ef
26f0 0 272a d0
:3 0 d1 :3 0 26f2
26f3 0 d0 :3 0
e0 :3 0 26f5 26f6
0 f4 :2 0 2
:4 0 231 :2 0 e2
:2 0 30 :2 0 15d8
26fb 26fd :3 0 15db
26f7 26ff 26f4 2701
2700 :2 0 d3 :3 0
e3 :3 0 2703 2704
0 d5 :4 0 232
:4 0 d8 :2 0 d9
:3 0 15df 2708 270a
:3 0 d8 :2 0 f7
:4 0 15e2 270c 270e
:3 0 d8 :2 0 f8
:4 0 15e5 2710 2712
:3 0 d8 :2 0 f1
:3 0 15e8 2714 2716
:3 0 d8 :2 0 f9
:4 0 15eb 2718 271a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 15ee
271d 2721 15f2 271c
2723 :3 0 15f5 2705
2725 :2 0 2727 15f8
2728 2702 2727 0
2729 15fa 0 272a
15fc 272d :3 0 272d
0 272d 272c 272a
272b :6 0 272f 67
:3 0 15ff 2731 1601
2730 272f :2 0 2732
1603 :2 0 2734 0
2734 2733 26e1 2732
:6 0 51ec 1 :3 0
7e :3 0 21f :2 0
2736 2737 0 51ec
7f :3 0 21f :2 0
2739 273a 0 51ec
4c :3 0 45 :2 0
273c 273d 0 51ec
2a :3 0 39 :3 0
273f 2740 0 51ec
ec :3 0 a3 :4 0
2745 :2 0 51ec 2743
2746 :3 0 233 :3 0
a3 :3 0 20 :3 0
22 :3 0 26 :3 0
4a :3 0 48 :3 0
88 :3 0 2a :3 0
7c :3 0 7d :3 0
87 :3 0 52 :3 0
25 :3 0 82 :3 0
83 :3 0 7e :3 0
7f :3 0 4d :3 0
4f :3 0 50 :3 0
51 :3 0 57 :4 0
275f :2 0 464d 2748
2760 :3 0 1606 :3 0
a3 :3 0 ed :3 0
2761 2762 :3 0 15
:3 0 ee :3 0 2764
2765 0 45 :2 0
2766 2767 0 2769
161c 2770 15 :3 0
ee :3 0 276a 276b
0 ef :2 0 276c
276d 0 276f 161e
2771 2763 2769 0
2772 0 276f 0
2772 1620 0 464d
15 :3 0 ee :3 0
2773 2774 0 15
:3 0 14e :2 0 165
:3 0 2776 2778 0
1625 2777 277a :3 0
277b :2 0 234 :8 0
277f 1628 2780 277c
277f 0 2781 162a
0 464d 53 :3 0
45 :2 0 2782 2783
0 464d 8f :3 0
48 :3 0 45 :2 0
162c 2785 2788 e7
:2 0 45 :2 0 1631
278a 278c :3 0 7b
:3 0 235 :3 0 20
:3 0 45 :2 0 1634
278f 2792 278e 2793
0 2a2b bd :3 0
a5 :3 0 20 :4 0
236 1 :8 0 27ae
ed :4 0 2799 :3 0
105 :3 0 e7 :2 0
1639 279c 279d :3 0
15 :3 0 ee :3 0
279f 27a0 0 45
:2 0 27a1 27a2 0
27a4 163c 27ab 15
:3 0 ee :3 0 27a5
27a6 0 ef :2 0
27a7 27a8 0 27aa
163e 27ac 279e 27a4
0 27ad 0 27aa
0 27ad 1640 0
27ae 1643 2801 f2
:3 0 15 :3 0 ee
:3 0 27b0 27b1 0
f1 :3 0 27b2 27b3
0 27b5 1646 27b7
1648 27b6 27b5 :2 0
27ff f3 :3 0 15
:3 0 ee :3 0 27ba
27bb 0 f1 :3 0
27bc 27bd 0 27f7
d0 :3 0 d1 :3 0
27bf 27c0 0 d0
:3 0 e0 :3 0 27c2
27c3 0 f4 :2 0
2 :4 0 237 :2 0
e2 :2 0 30 :2 0
164a 27c8 27ca :3 0
164d 27c4 27cc 27c1
27ce 27cd :2 0 d3
:3 0 e3 :3 0 27d0
27d1 0 d5 :4 0
238 :4 0 d8 :2 0
d9 :3 0 1651 27d5
27d7 :3 0 d8 :2 0
f7 :4 0 1654 27d9
27db :3 0 d8 :2 0
f8 :4 0 1657 27dd
27df :3 0 d8 :2 0
f1 :3 0 165a 27e1
27e3 :3 0 d8 :2 0
f9 :4 0 165d 27e5
27e7 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1660 27ea 27ee 1664
27e9 27f0 :3 0 1667
27d2 27f2 :2 0 27f4
166a 27f5 27cf 27f4
0 27f6 166c 0
27f7 166e 27fa :3 0
27fa 0 27fa 27f9
27f7 27f8 :6 0 27fc
6a :3 0 1671 27fe
1673 27fd 27fc :2 0
27ff 1675 :2 0 2801
0 2801 2800 27ae
27ff :6 0 2a2b 69
:3 0 9d :3 0 a7
:3 0 22 :4 0 239
1 :8 0 281c ed
:4 0 2807 :3 0 105
:3 0 e7 :2 0 167a
280a 280b :3 0 15
:3 0 ee :3 0 280d
280e 0 45 :2 0
280f 2810 0 2812
167d 2819 15 :3 0
ee :3 0 2813 2814
0 ef :2 0 2815
2816 0 2818 167f
281a 280c 2812 0
281b 0 2818 0
281b 1681 0 281c
1684 286f f2 :3 0
15 :3 0 ee :3 0
281e 281f 0 f1
:3 0 2820 2821 0
2823 1687 2825 1689
2824 2823 :2 0 286d
f3 :3 0 15 :3 0
ee :3 0 2828 2829
0 f1 :3 0 282a
282b 0 2865 d0
:3 0 d1 :3 0 282d
282e 0 d0 :3 0
e0 :3 0 2830 2831
0 f4 :2 0 2
:4 0 23a :2 0 e2
:2 0 30 :2 0 168b
2836 2838 :3 0 168e
2832 283a 282f 283c
283b :2 0 d3 :3 0
e3 :3 0 283e 283f
0 d5 :4 0 23b
:4 0 d8 :2 0 d9
:3 0 1692 2843 2845
:3 0 d8 :2 0 f7
:4 0 1695 2847 2849
:3 0 d8 :2 0 f8
:4 0 1698 284b 284d
:3 0 d8 :2 0 f1
:3 0 169b 284f 2851
:3 0 d8 :2 0 f9
:4 0 169e 2853 2855
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 16a1
2858 285c 16a5 2857
285e :3 0 16a8 2840
2860 :2 0 2862 16ab
2863 283d 2862 0
2864 16ad 0 2865
16af 2868 :3 0 2868
0 2868 2867 2865
2866 :6 0 286a 6c
:3 0 16b2 286c 16b4
286b 286a :2 0 286d
16b6 :2 0 286f 0
286f 286e 281c 286d
:6 0 2a2b 69 :3 0
23c :3 0 a7 :3 0
22 :4 0 23d 1
:8 0 288a ed :4 0
2875 :3 0 105 :3 0
e7 :2 0 16bb 2878
2879 :3 0 15 :3 0
ee :3 0 287b 287c
0 45 :2 0 287d
287e 0 2880 16be
2887 15 :3 0 ee
:3 0 2881 2882 0
ef :2 0 2883 2884
0 2886 16c0 2888
287a 2880 0 2889
0 2886 0 2889
16c2 0 288a 16c5
28dd f2 :3 0 15
:3 0 ee :3 0 288c
288d 0 f1 :3 0
288e 288f 0 2891
16c8 2893 16ca 2892
2891 :2 0 28db f3
:3 0 15 :3 0 ee
:3 0 2896 2897 0
f1 :3 0 2898 2899
0 28d3 d0 :3 0
d1 :3 0 289b 289c
0 d0 :3 0 e0
:3 0 289e 289f 0
f4 :2 0 2 :4 0
23e :2 0 e2 :2 0
30 :2 0 16cc 28a4
28a6 :3 0 16cf 28a0
28a8 289d 28aa 28a9
:2 0 d3 :3 0 e3
:3 0 28ac 28ad 0
d5 :4 0 23f :4 0
d8 :2 0 d9 :3 0
16d3 28b1 28b3 :3 0
d8 :2 0 f7 :4 0
16d6 28b5 28b7 :3 0
d8 :2 0 f8 :4 0
16d9 28b9 28bb :3 0
d8 :2 0 f1 :3 0
16dc 28bd 28bf :3 0
d8 :2 0 f9 :4 0
16df 28c1 28c3 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 16e2 28c6
28ca 16e6 28c5 28cc
:3 0 16e9 28ae 28ce
:2 0 28d0 16ec 28d1
28ab 28d0 0 28d2
16ee 0 28d3 16f0
28d6 :3 0 28d6 0
28d6 28d5 28d3 28d4
:6 0 28d8 6e :3 0
16f3 28da 16f5 28d9
28d8 :2 0 28db 16f7
:2 0 28dd 0 28dd
28dc 288a 28db :6 0
2a2b 69 :3 0 1d4
:3 0 9e :3 0 28
:3 0 a7 :3 0 22
:4 0 240 1 :8 0
28fa ed :4 0 28e5
:3 0 105 :3 0 e7
:2 0 16fc 28e8 28e9
:3 0 15 :3 0 ee
:3 0 28eb 28ec 0
45 :2 0 28ed 28ee
0 28f0 16ff 28f7
15 :3 0 ee :3 0
28f1 28f2 0 ef
:2 0 28f3 28f4 0
28f6 1701 28f8 28ea
28f0 0 28f9 0
28f6 0 28f9 1703
0 28fa 1706 294d
f2 :3 0 15 :3 0
ee :3 0 28fc 28fd
0 f1 :3 0 28fe
28ff 0 2901 1709
2903 170b 2902 2901
:2 0 294b f3 :3 0
15 :3 0 ee :3 0
2906 2907 0 f1
:3 0 2908 2909 0
2943 d0 :3 0 d1
:3 0 290b 290c 0
d0 :3 0 e0 :3 0
290e 290f 0 f4
:2 0 2 :4 0 241
:2 0 e2 :2 0 30
:2 0 170d 2914 2916
:3 0 1710 2910 2918
290d 291a 2919 :2 0
d3 :3 0 e3 :3 0
291c 291d 0 d5
:4 0 242 :4 0 d8
:2 0 d9 :3 0 1714
2921 2923 :3 0 d8
:2 0 f7 :4 0 1717
2925 2927 :3 0 d8
:2 0 f8 :4 0 171a
2929 292b :3 0 d8
:2 0 f1 :3 0 171d
292d 292f :3 0 d8
:2 0 f9 :4 0 1720
2931 2933 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1723 2936 293a
1727 2935 293c :3 0
172a 291e 293e :2 0
2940 172d 2941 291b
2940 0 2942 172f
0 2943 1731 2946
:3 0 2946 0 2946
2945 2943 2944 :6 0
2948 70 :3 0 1734
294a 1736 2949 2948
:2 0 294b 1738 :2 0
294d 0 294d 294c
28fa 294b :6 0 2a2b
69 :3 0 243 :3 0
a5 :3 0 22 :4 0
244 1 :8 0 2968
ed :4 0 2953 :3 0
105 :3 0 e7 :2 0
173d 2956 2957 :3 0
15 :3 0 ee :3 0
2959 295a 0 45
:2 0 295b 295c 0
295e 1740 2965 15
:3 0 ee :3 0 295f
2960 0 ef :2 0
2961 2962 0 2964
1742 2966 2958 295e
0 2967 0 2964
0 2967 1744 0
2968 1747 29bb f2
:3 0 15 :3 0 ee
:3 0 296a 296b 0
f1 :3 0 296c 296d
0 296f 174a 2971
174c 2970 296f :2 0
29b9 f3 :3 0 15
:3 0 ee :3 0 2974
2975 0 f1 :3 0
2976 2977 0 29b1
d0 :3 0 d1 :3 0
2979 297a 0 d0
:3 0 e0 :3 0 297c
297d 0 f4 :2 0
2 :4 0 245 :2 0
e2 :2 0 30 :2 0
174e 2982 2984 :3 0
1751 297e 2986 297b
2988 2987 :2 0 d3
:3 0 e3 :3 0 298a
298b 0 d5 :4 0
246 :4 0 d8 :2 0
d9 :3 0 1755 298f
2991 :3 0 d8 :2 0
f7 :4 0 1758 2993
2995 :3 0 d8 :2 0
f8 :4 0 175b 2997
2999 :3 0 d8 :2 0
f1 :3 0 175e 299b
299d :3 0 d8 :2 0
f9 :4 0 1761 299f
29a1 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1764 29a4 29a8 1768
29a3 29aa :3 0 176b
298c 29ac :2 0 29ae
176e 29af 2989 29ae
0 29b0 1770 0
29b1 1772 29b4 :3 0
29b4 0 29b4 29b3
29b1 29b2 :6 0 29b6
72 :3 0 1775 29b8
1777 29b7 29b6 :2 0
29b9 1779 :2 0 29bb
0 29bb 29ba 2968
29b9 :6 0 2a2b 69
:3 0 247 :3 0 a5
:3 0 22 :4 0 248
1 :8 0 29d6 ed
:4 0 29c1 :3 0 105
:3 0 e7 :2 0 177e
29c4 29c5 :3 0 15
:3 0 ee :3 0 29c7
29c8 0 45 :2 0
29c9 29ca 0 29cc
1781 29d3 15 :3 0
ee :3 0 29cd 29ce
0 ef :2 0 29cf
29d0 0 29d2 1783
29d4 29c6 29cc 0
29d5 0 29d2 0
29d5 1785 0 29d6
1788 2a29 f2 :3 0
15 :3 0 ee :3 0
29d8 29d9 0 f1
:3 0 29da 29db 0
29dd 178b 29df 178d
29de 29dd :2 0 2a27
f3 :3 0 15 :3 0
ee :3 0 29e2 29e3
0 f1 :3 0 29e4
29e5 0 2a1f d0
:3 0 d1 :3 0 29e7
29e8 0 d0 :3 0
e0 :3 0 29ea 29eb
0 f4 :2 0 2
:4 0 249 :2 0 e2
:2 0 30 :2 0 178f
29f0 29f2 :3 0 1792
29ec 29f4 29e9 29f6
29f5 :2 0 d3 :3 0
e3 :3 0 29f8 29f9
0 d5 :4 0 24a
:4 0 d8 :2 0 d9
:3 0 1796 29fd 29ff
:3 0 d8 :2 0 f7
:4 0 1799 2a01 2a03
:3 0 d8 :2 0 f8
:4 0 179c 2a05 2a07
:3 0 d8 :2 0 f1
:3 0 179f 2a09 2a0b
:3 0 d8 :2 0 f9
:4 0 17a2 2a0d 2a0f
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 17a5
2a12 2a16 17a9 2a11
2a18 :3 0 17ac 29fa
2a1a :2 0 2a1c 17af
2a1d 29f7 2a1c 0
2a1e 17b1 0 2a1f
17b3 2a22 :3 0 2a22
0 2a22 2a21 2a1f
2a20 :6 0 2a24 74
:3 0 17b6 2a26 17b8
2a25 2a24 :2 0 2a27
17ba :2 0 2a29 0
2a29 2a28 29d6 2a27
:6 0 2a2b 69 :3 0
17bd 463c 8f :3 0
55 :3 0 45 :2 0
17c5 2a2c 2a2f e7
:2 0 45 :2 0 17ca
2a31 2a33 :3 0 23
:3 0 22 :3 0 2a35
2a36 0 2a38 17cd
2a39 2a34 2a38 0
2a3a 17cf 0 463b
24b :3 0 9f :3 0
27 :3 0 a7 :3 0
22 :3 0 9e :3 0
28 :3 0 9f :3 0
29 :4 0 24c 1
:8 0 2a5a ed :4 0
2a45 :3 0 105 :3 0
e7 :2 0 17d3 2a48
2a49 :3 0 15 :3 0
ee :3 0 2a4b 2a4c
0 45 :2 0 2a4d
2a4e 0 2a50 17d6
2a57 15 :3 0 ee
:3 0 2a51 2a52 0
ef :2 0 2a53 2a54
0 2a56 17d8 2a58
2a4a 2a50 0 2a59
0 2a56 0 2a59
17da 0 2a5a 17dd
2aad f2 :3 0 15
:3 0 ee :3 0 2a5c
2a5d 0 f1 :3 0
2a5e 2a5f 0 2a61
17e0 2a63 17e2 2a62
2a61 :2 0 2aab f3
:3 0 15 :3 0 ee
:3 0 2a66 2a67 0
f1 :3 0 2a68 2a69
0 2aa3 d0 :3 0
d1 :3 0 2a6b 2a6c
0 d0 :3 0 e0
:3 0 2a6e 2a6f 0
f4 :2 0 2 :4 0
24d :2 0 e2 :2 0
30 :2 0 17e4 2a74
2a76 :3 0 17e7 2a70
2a78 2a6d 2a7a 2a79
:2 0 d3 :3 0 e3
:3 0 2a7c 2a7d 0
d5 :4 0 24e :4 0
d8 :2 0 d9 :3 0
17eb 2a81 2a83 :3 0
d8 :2 0 f7 :4 0
17ee 2a85 2a87 :3 0
d8 :2 0 f8 :4 0
17f1 2a89 2a8b :3 0
d8 :2 0 f1 :3 0
17f4 2a8d 2a8f :3 0
d8 :2 0 f9 :4 0
17f7 2a91 2a93 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 17fa 2a96
2a9a 17fe 2a95 2a9c
:3 0 1801 2a7e 2a9e
:2 0 2aa0 1804 2aa1
2a7b 2aa0 0 2aa2
1806 0 2aa3 1808
2aa6 :3 0 2aa6 0
2aa6 2aa5 2aa3 2aa4
:6 0 2aa8 76 :3 0
180b 2aaa 180d 2aa9
2aa8 :2 0 2aab 180f
:2 0 2aad 0 2aad
2aac 2a5a 2aab :6 0
463b 69 :3 0 84
:3 0 1c1 :2 0 30
:2 0 1812 2ab0 2ab2
:3 0 2aaf 2ab3 0
463b 15 :3 0 ee
:3 0 2ab5 2ab6 0
1c2 :3 0 28 :3 0
26 :3 0 22 :3 0
7c :3 0 7d :3 0
7e :3 0 7f :3 0
84 :3 0 83 :3 0
82 :3 0 1814 2ab8
2ac3 2ab7 2ac4 0
463b a7 :3 0 182
:3 0 24 :3 0 2f
:3 0 9d :3 0 9e
:3 0 28 :3 0 a8
:3 0 26 :3 0 9f
:3 0 27 :3 0 a0
:4 0 24f 1 :8 0
2ad8 15 :3 0 ee
:3 0 2ad3 2ad4 0
f1 :3 0 2ad5 2ad6
0 2ad8 181f 2b2b
f2 :3 0 15 :3 0
ee :3 0 2ada 2adb
0 f1 :3 0 2adc
2add 0 2adf 1822
2ae1 1824 2ae0 2adf
:2 0 2b29 f3 :3 0
15 :3 0 ee :3 0
2ae4 2ae5 0 f1
:3 0 2ae6 2ae7 0
2b21 d0 :3 0 d1
:3 0 2ae9 2aea 0
d0 :3 0 e0 :3 0
2aec 2aed 0 f4
:2 0 2 :4 0 250
:2 0 e2 :2 0 30
:2 0 1826 2af2 2af4
:3 0 1829 2aee 2af6
2aeb 2af8 2af7 :2 0
d3 :3 0 e3 :3 0
2afa 2afb 0 d5
:4 0 251 :4 0 d8
:2 0 d9 :3 0 182d
2aff 2b01 :3 0 d8
:2 0 f7 :4 0 1830
2b03 2b05 :3 0 d8
:2 0 f8 :4 0 1833
2b07 2b09 :3 0 d8
:2 0 f1 :3 0 1836
2b0b 2b0d :3 0 d8
:2 0 f9 :4 0 1839
2b0f 2b11 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 183c 2b14 2b18
1840 2b13 2b1a :3 0
1843 2afc 2b1c :2 0
2b1e 1846 2b1f 2af9
2b1e 0 2b20 1848
0 2b21 184a 2b24
:3 0 2b24 0 2b24
2b23 2b21 2b22 :6 0
2b26 78 :3 0 184d
2b28 184f 2b27 2b26
:2 0 2b29 1851 :2 0
2b2b 0 2b2b 2b2a
2ad8 2b29 :6 0 463b
69 :3 0 15 :3 0
ee :3 0 2b2d 2b2e
0 15 :3 0 e7
:2 0 10d :3 0 2b30
2b32 0 1856 2b31
2b34 :3 0 2b35 :2 0
70 :3 0 45 :2 0
2b37 2b38 0 3122
a5 :3 0 16c :3 0
171 :3 0 1c :3 0
46 :3 0 1e :3 0
bd :3 0 99 :3 0
26 :3 0 9f :3 0
27 :3 0 a0 :4 0
252 1 :8 0 2b4c
15 :3 0 ee :3 0
2b47 2b48 0 f1
:3 0 2b49 2b4a 0
2b4c 1859 2b9f f2
:3 0 15 :3 0 ee
:3 0 2b4e 2b4f 0
f1 :3 0 2b50 2b51
0 2b53 185c 2b55
185e 2b54 2b53 :2 0
2b9d f3 :3 0 15
:3 0 ee :3 0 2b58
2b59 0 f1 :3 0
2b5a 2b5b 0 2b95
d0 :3 0 d1 :3 0
2b5d 2b5e 0 d0
:3 0 e0 :3 0 2b60
2b61 0 f4 :2 0
2 :4 0 253 :2 0
e2 :2 0 30 :2 0
1860 2b66 2b68 :3 0
1863 2b62 2b6a 2b5f
2b6c 2b6b :2 0 d3
:3 0 e3 :3 0 2b6e
2b6f 0 d5 :4 0
254 :4 0 d8 :2 0
d9 :3 0 1867 2b73
2b75 :3 0 d8 :2 0
f7 :4 0 186a 2b77
2b79 :3 0 d8 :2 0
f8 :4 0 186d 2b7b
2b7d :3 0 d8 :2 0
f1 :3 0 1870 2b7f
2b81 :3 0 d8 :2 0
f9 :4 0 1873 2b83
2b85 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1876 2b88 2b8c 187a
2b87 2b8e :3 0 187d
2b70 2b90 :2 0 2b92
1880 2b93 2b6d 2b92
0 2b94 1882 0
2b95 1884 2b98 :3 0
2b98 0 2b98 2b97
2b95 2b96 :6 0 2b9a
7a :3 0 1887 2b9c
1889 2b9b 2b9a :2 0
2b9d 188b :2 0 2b9f
0 2b9f 2b9e 2b4c
2b9d :6 0 3122 69
:3 0 15 :3 0 ee
:3 0 2ba1 2ba2 0
15 :3 0 e7 :2 0
165 :3 0 2ba4 2ba6
0 1890 2ba5 2ba8
:3 0 2ba9 :2 0 e5
:3 0 8f :3 0 46
:3 0 45 :2 0 1893
2bac 2baf 1a :3 0
1a5 :3 0 2bb1 2bb2
0 1896 2bab 2bb4
2bb5 :2 0 1a :3 0
e7 :2 0 1a5 :3 0
2bb7 2bb9 0 189b
2bb8 2bbb :3 0 48
:3 0 45 :2 0 2bbd
2bbe 0 2c34 bd
:3 0 13c :3 0 29
:3 0 9f :3 0 27
:3 0 a0 :3 0 a5
:3 0 20 :4 0 255
1 :8 0 2bde ed
:4 0 2bc9 :3 0 105
:3 0 e7 :2 0 18a0
2bcc 2bcd :3 0 15
:3 0 ee :3 0 2bcf
2bd0 0 45 :2 0
2bd1 2bd2 0 2bd4
18a3 2bdb 15 :3 0
ee :3 0 2bd5 2bd6
0 ef :2 0 2bd7
2bd8 0 2bda 18a5
2bdc 2bce 2bd4 0
2bdd 0 2bda 0
2bdd 18a7 0 2bde
18aa 2c31 f2 :3 0
15 :3 0 ee :3 0
2be0 2be1 0 f1
:3 0 2be2 2be3 0
2be5 18ad 2be7 18af
2be6 2be5 :2 0 2c2f
f3 :3 0 15 :3 0
ee :3 0 2bea 2beb
0 f1 :3 0 2bec
2bed 0 2c27 d0
:3 0 d1 :3 0 2bef
2bf0 0 d0 :3 0
e0 :3 0 2bf2 2bf3
0 f4 :2 0 2
:4 0 256 :2 0 e2
:2 0 30 :2 0 18b1
2bf8 2bfa :3 0 18b4
2bf4 2bfc 2bf1 2bfe
2bfd :2 0 d3 :3 0
e3 :3 0 2c00 2c01
0 d5 :4 0 257
:4 0 d8 :2 0 d9
:3 0 18b8 2c05 2c07
:3 0 d8 :2 0 f7
:4 0 18bb 2c09 2c0b
:3 0 d8 :2 0 f8
:4 0 18be 2c0d 2c0f
:3 0 d8 :2 0 f1
:3 0 18c1 2c11 2c13
:3 0 d8 :2 0 f9
:4 0 18c4 2c15 2c17
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 18c7
2c1a 2c1e 18cb 2c19
2c20 :3 0 18ce 2c02
2c22 :2 0 2c24 18d1
2c25 2bff 2c24 0
2c26 18d3 0 2c27
18d5 2c2a :3 0 2c2a
0 2c2a 2c29 2c27
2c28 :6 0 2c2c 7c
:3 0 18d8 2c2e 18da
2c2d 2c2c :2 0 2c2f
18dc :2 0 2c31 0
2c31 2c30 2bde 2c2f
:6 0 2c34 69 :3 0
15c :3 0 18df 2d45
8f :3 0 46 :3 0
45 :2 0 18e2 2c35
2c38 1a :3 0 e7
:2 0 19c :3 0 2c3a
2c3c 0 18e7 2c3b
2c3e :3 0 7b :3 0
178 :3 0 45 :2 0
8f :3 0 4a :3 0
45 :2 0 18ea 2c43
2c46 1a :3 0 179
:3 0 2c48 2c49 0
78 :3 0 18ed 2c41
2c4c 2c40 2c4d 0
2cc7 bd :3 0 16c
:3 0 1a :3 0 1a5
:3 0 171 :3 0 78
:3 0 13c :3 0 29
:3 0 9f :3 0 27
:3 0 a0 :3 0 a5
:3 0 20 :4 0 258
1 :8 0 2c72 ed
:4 0 2c5d :3 0 105
:3 0 e7 :2 0 18f4
2c60 2c61 :3 0 15
:3 0 ee :3 0 2c63
2c64 0 45 :2 0
2c65 2c66 0 2c68
18f7 2c6f 15 :3 0
ee :3 0 2c69 2c6a
0 ef :2 0 2c6b
2c6c 0 2c6e 18f9
2c70 2c62 2c68 0
2c71 0 2c6e 0
2c71 18fb 0 2c72
18fe 2cc5 f2 :3 0
15 :3 0 ee :3 0
2c74 2c75 0 f1
:3 0 2c76 2c77 0
2c79 1901 2c7b 1903
2c7a 2c79 :2 0 2cc3
f3 :3 0 15 :3 0
ee :3 0 2c7e 2c7f
0 f1 :3 0 2c80
2c81 0 2cbb d0
:3 0 d1 :3 0 2c83
2c84 0 d0 :3 0
e0 :3 0 2c86 2c87
0 f4 :2 0 2
:4 0 259 :2 0 e2
:2 0 30 :2 0 1905
2c8c 2c8e :3 0 1908
2c88 2c90 2c85 2c92
2c91 :2 0 d3 :3 0
e3 :3 0 2c94 2c95
0 d5 :4 0 25a
:4 0 d8 :2 0 d9
:3 0 190c 2c99 2c9b
:3 0 d8 :2 0 f7
:4 0 190f 2c9d 2c9f
:3 0 d8 :2 0 f8
:4 0 1912 2ca1 2ca3
:3 0 d8 :2 0 f1
:3 0 1915 2ca5 2ca7
:3 0 d8 :2 0 f9
:4 0 1918 2ca9 2cab
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 191b
2cae 2cb2 191f 2cad
2cb4 :3 0 1922 2c96
2cb6 :2 0 2cb8 1925
2cb9 2c93 2cb8 0
2cba 1927 0 2cbb
1929 2cbe :3 0 2cbe
0 2cbe 2cbd 2cbb
2cbc :6 0 2cc0 7e
:3 0 192c 2cc2 192e
2cc1 2cc0 :2 0 2cc3
1930 :2 0 2cc5 0
2cc5 2cc4 2c72 2cc3
:6 0 2cc7 69 :3 0
1933 2cc8 2c3f 2cc7
0 2d47 bd :3 0
16c :3 0 1a1 :3 0
176 :3 0 46 :3 0
1a :3 0 1a5 :3 0
171 :3 0 1e :3 0
13c :3 0 29 :3 0
9f :3 0 27 :3 0
a0 :3 0 a5 :3 0
20 :4 0 25b 1
:8 0 2cef ed :4 0
2cda :3 0 105 :3 0
e7 :2 0 1938 2cdd
2cde :3 0 15 :3 0
ee :3 0 2ce0 2ce1
0 45 :2 0 2ce2
2ce3 0 2ce5 193b
2cec 15 :3 0 ee
:3 0 2ce6 2ce7 0
ef :2 0 2ce8 2ce9
0 2ceb 193d 2ced
2cdf 2ce5 0 2cee
0 2ceb 0 2cee
193f 0 2cef 1942
2d42 f2 :3 0 15
:3 0 ee :3 0 2cf1
2cf2 0 f1 :3 0
2cf3 2cf4 0 2cf6
1945 2cf8 1947 2cf7
2cf6 :2 0 2d40 f3
:3 0 15 :3 0 ee
:3 0 2cfb 2cfc 0
f1 :3 0 2cfd 2cfe
0 2d38 d0 :3 0
d1 :3 0 2d00 2d01
0 d0 :3 0 e0
:3 0 2d03 2d04 0
f4 :2 0 2 :4 0
25c :2 0 e2 :2 0
30 :2 0 1949 2d09
2d0b :3 0 194c 2d05
2d0d 2d02 2d0f 2d0e
:2 0 d3 :3 0 e3
:3 0 2d11 2d12 0
d5 :4 0 25d :4 0
d8 :2 0 d9 :3 0
1950 2d16 2d18 :3 0
d8 :2 0 f7 :4 0
1953 2d1a 2d1c :3 0
d8 :2 0 f8 :4 0
1956 2d1e 2d20 :3 0
d8 :2 0 f1 :3 0
1959 2d22 2d24 :3 0
d8 :2 0 f9 :4 0
195c 2d26 2d28 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 195f 2d2b
2d2f 1963 2d2a 2d31
:3 0 1966 2d13 2d33
:2 0 2d35 1969 2d36
2d10 2d35 0 2d37
196b 0 2d38 196d
2d3b :3 0 2d3b 0
2d3b 2d3a 2d38 2d39
:6 0 2d3d 80 :3 0
1970 2d3f 1972 2d3e
2d3d :2 0 2d40 1974
:2 0 2d42 0 2d42
2d41 2cef 2d40 :6 0
2d44 69 :3 0 1977
2d46 2bbc 2c34 0
2d47 0 2d44 0
2d47 1979 0 2dcf
15 :3 0 ee :3 0
2d48 2d49 0 15
:3 0 e7 :2 0 165
:3 0 2d4b 2d4d 0
197f 2d4c 2d4f :3 0
2d50 :2 0 8f :3 0
48 :3 0 45 :2 0
1982 2d52 2d55 117
:2 0 45 :2 0 1987
2d57 2d59 :3 0 2d5a
:2 0 2d51 2d5c 2d5b
:2 0 bd :3 0 a5
:3 0 1c :4 0 1e3
1 :8 0 2d77 ed
:4 0 2d62 :3 0 105
:3 0 e7 :2 0 198c
2d65 2d66 :3 0 15
:3 0 ee :3 0 2d68
2d69 0 45 :2 0
2d6a 2d6b 0 2d6d
198f 2d74 15 :3 0
ee :3 0 2d6e 2d6f
0 ef :2 0 2d70
2d71 0 2d73 1991
2d75 2d67 2d6d 0
2d76 0 2d73 0
2d76 1993 0 2d77
1996 2dca f2 :3 0
15 :3 0 ee :3 0
2d79 2d7a 0 f1
:3 0 2d7b 2d7c 0
2d7e 1999 2d80 199b
2d7f 2d7e :2 0 2dc8
f3 :3 0 15 :3 0
ee :3 0 2d83 2d84
0 f1 :3 0 2d85
2d86 0 2dc0 d0
:3 0 d1 :3 0 2d88
2d89 0 d0 :3 0
e0 :3 0 2d8b 2d8c
0 f4 :2 0 2
:4 0 25e :2 0 e2
:2 0 30 :2 0 199d
2d91 2d93 :3 0 19a0
2d8d 2d95 2d8a 2d97
2d96 :2 0 d3 :3 0
e3 :3 0 2d99 2d9a
0 d5 :4 0 25f
:4 0 d8 :2 0 d9
:3 0 19a4 2d9e 2da0
:3 0 d8 :2 0 f7
:4 0 19a7 2da2 2da4
:3 0 d8 :2 0 f8
:4 0 19aa 2da6 2da8
:3 0 d8 :2 0 f1
:3 0 19ad 2daa 2dac
:3 0 d8 :2 0 f9
:4 0 19b0 2dae 2db0
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 19b3
2db3 2db7 19b7 2db2
2db9 :3 0 19ba 2d9b
2dbb :2 0 2dbd 19bd
2dbe 2d98 2dbd 0
2dbf 19bf 0 2dc0
19c1 2dc3 :3 0 2dc3
0 2dc3 2dc2 2dc0
2dc1 :6 0 2dc5 82
:3 0 19c4 2dc7 19c6
2dc6 2dc5 :2 0 2dc8
19c8 :2 0 2dca 0
2dca 2dc9 2d77 2dc8
:6 0 2dcc 69 :3 0
19cb 2dcd 2d5d 2dcc
0 2dce 19cd 0
2dcf 19cf 30af 260
:3 0 a5 :3 0 ae
:3 0 11d :3 0 186
:3 0 18b :3 0 11d
:3 0 186 :3 0 1c
:3 0 40 :3 0 bc
:3 0 11d :3 0 bd
:3 0 260 :3 0 11d
:3 0 99 :3 0 26
:3 0 11d :3 0 99
:3 0 260 :3 0 99
:3 0 260 :3 0 16c
:3 0 260 :3 0 9f
:3 0 11d :3 0 261
:3 0 a7 :3 0 9d
:3 0 262 :3 0 262
:3 0 a5 :3 0 260
:3 0 a5 :4 0 263
1 :8 0 2df8 15
:3 0 ee :3 0 2df3
2df4 0 f1 :3 0
2df5 2df6 0 2df8
19d2 2e4b f2 :3 0
15 :3 0 ee :3 0
2dfa 2dfb 0 f1
:3 0 2dfc 2dfd 0
2dff 19d5 2e01 19d7
2e00 2dff :2 0 2e49
f3 :3 0 15 :3 0
ee :3 0 2e04 2e05
0 f1 :3 0 2e06
2e07 0 2e41 d0
:3 0 d1 :3 0 2e09
2e0a 0 d0 :3 0
e0 :3 0 2e0c 2e0d
0 f4 :2 0 2
:4 0 264 :2 0 e2
:2 0 30 :2 0 19d9
2e12 2e14 :3 0 19dc
2e0e 2e16 2e0b 2e18
2e17 :2 0 d3 :3 0
e3 :3 0 2e1a 2e1b
0 d5 :4 0 265
:4 0 d8 :2 0 d9
:3 0 19e0 2e1f 2e21
:3 0 d8 :2 0 f7
:4 0 19e3 2e23 2e25
:3 0 d8 :2 0 f8
:4 0 19e6 2e27 2e29
:3 0 d8 :2 0 f1
:3 0 19e9 2e2b 2e2d
:3 0 d8 :2 0 f9
:4 0 19ec 2e2f 2e31
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 19ef
2e34 2e38 19f3 2e33
2e3a :3 0 19f6 2e1c
2e3c :2 0 2e3e 19f9
2e3f 2e19 2e3e 0
2e40 19fb 0 2e41
19fd 2e44 :3 0 2e44
0 2e44 2e43 2e41
2e42 :6 0 2e46 84
:3 0 1a00 2e48 1a02
2e47 2e46 :2 0 2e49
1a04 :2 0 2e4b 0
2e4b 2e4a 2df8 2e49
:6 0 30ae 69 :3 0
15 :3 0 ee :3 0
2e4d 2e4e 0 15
:3 0 e7 :2 0 165
:3 0 2e50 2e52 0
1a09 2e51 2e54 :3 0
2e55 :2 0 1c :3 0
1bd :2 0 1a0c 2e58
2e59 :3 0 2e5a :2 0
2e5b :2 0 2e56 2e5d
2e5c :2 0 7b :3 0
178 :3 0 45 :2 0
8f :3 0 4a :3 0
45 :2 0 1a0e 2e62
2e65 1a :3 0 266
:3 0 2e67 2e68 0
78 :3 0 1a11 2e60
2e6b 2e5f 2e6c 0
2fc5 bd :3 0 a5
:3 0 1c :4 0 1e3
1 :8 0 2e87 ed
:4 0 2e72 :3 0 105
:3 0 e7 :2 0 1a18
2e75 2e76 :3 0 15
:3 0 ee :3 0 2e78
2e79 0 45 :2 0
2e7a 2e7b 0 2e7d
1a1b 2e84 15 :3 0
ee :3 0 2e7e 2e7f
0 ef :2 0 2e80
2e81 0 2e83 1a1d
2e85 2e77 2e7d 0
2e86 0 2e83 0
2e86 1a1f 0 2e87
1a22 2eda f2 :3 0
15 :3 0 ee :3 0
2e89 2e8a 0 f1
:3 0 2e8b 2e8c 0
2e8e 1a25 2e90 1a27
2e8f 2e8e :2 0 2ed8
f3 :3 0 15 :3 0
ee :3 0 2e93 2e94
0 f1 :3 0 2e95
2e96 0 2ed0 d0
:3 0 d1 :3 0 2e98
2e99 0 d0 :3 0
e0 :3 0 2e9b 2e9c
0 f4 :2 0 2
:4 0 267 :2 0 e2
:2 0 30 :2 0 1a29
2ea1 2ea3 :3 0 1a2c
2e9d 2ea5 2e9a 2ea7
2ea6 :2 0 d3 :3 0
e3 :3 0 2ea9 2eaa
0 d5 :4 0 268
:4 0 d8 :2 0 d9
:3 0 1a30 2eae 2eb0
:3 0 d8 :2 0 f7
:4 0 1a33 2eb2 2eb4
:3 0 d8 :2 0 f8
:4 0 1a36 2eb6 2eb8
:3 0 d8 :2 0 f1
:3 0 1a39 2eba 2ebc
:3 0 d8 :2 0 f9
:4 0 1a3c 2ebe 2ec0
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1a3f
2ec3 2ec7 1a43 2ec2
2ec9 :3 0 1a46 2eab
2ecb :2 0 2ecd 1a49
2ece 2ea8 2ecd 0
2ecf 1a4b 0 2ed0
1a4d 2ed3 :3 0 2ed3
0 2ed3 2ed2 2ed0
2ed1 :6 0 2ed5 86
:3 0 1a50 2ed7 1a52
2ed6 2ed5 :2 0 2ed8
1a54 :2 0 2eda 0
2eda 2ed9 2e87 2ed8
:6 0 2fc5 69 :3 0
bd :3 0 9f :3 0
27 :3 0 a0 :3 0
13c :3 0 29 :3 0
16c :3 0 171 :3 0
78 :3 0 a5 :3 0
20 :4 0 269 1
:8 0 2efd ed :4 0
2ee8 :3 0 105 :3 0
e7 :2 0 1a59 2eeb
2eec :3 0 15 :3 0
ee :3 0 2eee 2eef
0 45 :2 0 2ef0
2ef1 0 2ef3 1a5c
2efa 15 :3 0 ee
:3 0 2ef4 2ef5 0
ef :2 0 2ef6 2ef7
0 2ef9 1a5e 2efb
2eed 2ef3 0 2efc
0 2ef9 0 2efc
1a60 0 2efd 1a63
2f50 f2 :3 0 15
:3 0 ee :3 0 2eff
2f00 0 f1 :3 0
2f01 2f02 0 2f04
1a66 2f06 1a68 2f05
2f04 :2 0 2f4e f3
:3 0 15 :3 0 ee
:3 0 2f09 2f0a 0
f1 :3 0 2f0b 2f0c
0 2f46 d0 :3 0
d1 :3 0 2f0e 2f0f
0 d0 :3 0 e0
:3 0 2f11 2f12 0
f4 :2 0 2 :4 0
26a :2 0 e2 :2 0
30 :2 0 1a6a 2f17
2f19 :3 0 1a6d 2f13
2f1b 2f10 2f1d 2f1c
:2 0 d3 :3 0 e3
:3 0 2f1f 2f20 0
d5 :4 0 26b :4 0
d8 :2 0 d9 :3 0
1a71 2f24 2f26 :3 0
d8 :2 0 f7 :4 0
1a74 2f28 2f2a :3 0
d8 :2 0 f8 :4 0
1a77 2f2c 2f2e :3 0
d8 :2 0 f1 :3 0
1a7a 2f30 2f32 :3 0
d8 :2 0 f9 :4 0
1a7d 2f34 2f36 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1a80 2f39
2f3d 1a84 2f38 2f3f
:3 0 1a87 2f21 2f41
:2 0 2f43 1a8a 2f44
2f1e 2f43 0 2f45
1a8c 0 2f46 1a8e
2f49 :3 0 2f49 0
2f49 2f48 2f46 2f47
:6 0 2f4b 88 :3 0
1a91 2f4d 1a93 2f4c
2f4b :2 0 2f4e 1a95
:2 0 2f50 0 2f50
2f4f 2efd 2f4e :6 0
2fc5 69 :3 0 bc
:3 0 186 :3 0 187
:3 0 186 :3 0 40
:3 0 3e :3 0 99
:3 0 26 :4 0 26c
1 :8 0 2f70 ed
:4 0 2f5b :3 0 105
:3 0 e7 :2 0 1a9a
2f5e 2f5f :3 0 15
:3 0 ee :3 0 2f61
2f62 0 45 :2 0
2f63 2f64 0 2f66
1a9d 2f6d 15 :3 0
ee :3 0 2f67 2f68
0 ef :2 0 2f69
2f6a 0 2f6c 1a9f
2f6e 2f60 2f66 0
2f6f 0 2f6c 0
2f6f 1aa1 0 2f70
1aa4 2fc3 f2 :3 0
15 :3 0 ee :3 0
2f72 2f73 0 f1
:3 0 2f74 2f75 0
2f77 1aa7 2f79 1aa9
2f78 2f77 :2 0 2fc1
f3 :3 0 15 :3 0
ee :3 0 2f7c 2f7d
0 f1 :3 0 2f7e
2f7f 0 2fb9 d0
:3 0 d1 :3 0 2f81
2f82 0 d0 :3 0
e0 :3 0 2f84 2f85
0 f4 :2 0 2
:4 0 26d :2 0 e2
:2 0 30 :2 0 1aab
2f8a 2f8c :3 0 1aae
2f86 2f8e 2f83 2f90
2f8f :2 0 d3 :3 0
e3 :3 0 2f92 2f93
0 d5 :4 0 26e
:4 0 d8 :2 0 d9
:3 0 1ab2 2f97 2f99
:3 0 d8 :2 0 f7
:4 0 1ab5 2f9b 2f9d
:3 0 d8 :2 0 f8
:4 0 1ab8 2f9f 2fa1
:3 0 d8 :2 0 f1
:3 0 1abb 2fa3 2fa5
:3 0 d8 :2 0 f9
:4 0 1abe 2fa7 2fa9
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1ac1
2fac 2fb0 1ac5 2fab
2fb2 :3 0 1ac8 2f94
2fb4 :2 0 2fb6 1acb
2fb7 2f91 2fb6 0
2fb8 1acd 0 2fb9
1acf 2fbc :3 0 2fbc
0 2fbc 2fbb 2fb9
2fba :6 0 2fbe 8a
:3 0 1ad2 2fc0 1ad4
2fbf 2fbe :2 0 2fc1
1ad6 :2 0 2fc3 0
2fc3 2fc2 2f70 2fc1
:6 0 2fc5 69 :3 0
1ad9 30ab bc :3 0
186 :3 0 187 :3 0
186 :3 0 41 :3 0
3e :3 0 99 :3 0
26 :4 0 26f 1
:8 0 2fe4 ed :4 0
2fcf :3 0 105 :3 0
e7 :2 0 1ae0 2fd2
2fd3 :3 0 15 :3 0
ee :3 0 2fd5 2fd6
0 45 :2 0 2fd7
2fd8 0 2fda 1ae3
2fe1 15 :3 0 ee
:3 0 2fdb 2fdc 0
ef :2 0 2fdd 2fde
0 2fe0 1ae5 2fe2
2fd4 2fda 0 2fe3
0 2fe0 0 2fe3
1ae7 0 2fe4 1aea
3037 f2 :3 0 15
:3 0 ee :3 0 2fe6
2fe7 0 f1 :3 0
2fe8 2fe9 0 2feb
1aed 2fed 1aef 2fec
2feb :2 0 3035 f3
:3 0 15 :3 0 ee
:3 0 2ff0 2ff1 0
f1 :3 0 2ff2 2ff3
0 302d d0 :3 0
d1 :3 0 2ff5 2ff6
0 d0 :3 0 e0
:3 0 2ff8 2ff9 0
f4 :2 0 2 :4 0
270 :2 0 e2 :2 0
30 :2 0 1af1 2ffe
3000 :3 0 1af4 2ffa
3002 2ff7 3004 3003
:2 0 d3 :3 0 e3
:3 0 3006 3007 0
d5 :4 0 271 :4 0
d8 :2 0 d9 :3 0
1af8 300b 300d :3 0
d8 :2 0 f7 :4 0
1afb 300f 3011 :3 0
d8 :2 0 f8 :4 0
1afe 3013 3015 :3 0
d8 :2 0 f1 :3 0
1b01 3017 3019 :3 0
d8 :2 0 f9 :4 0
1b04 301b 301d :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1b07 3020
3024 1b0b 301f 3026
:3 0 1b0e 3008 3028
:2 0 302a 1b11 302b
3005 302a 0 302c
1b13 0 302d 1b15
3030 :3 0 3030 0
3030 302f 302d 302e
:6 0 3032 8c :3 0
1b18 3034 1b1a 3033
3032 :2 0 3035 1b1c
:2 0 3037 0 3037
3036 2fe4 3035 :6 0
30aa 69 :3 0 bd
:3 0 9f :3 0 27
:3 0 a0 :3 0 a5
:3 0 20 :4 0 272
1 :8 0 3055 ed
:4 0 3040 :3 0 105
:3 0 e7 :2 0 1b21
3043 3044 :3 0 15
:3 0 ee :3 0 3046
3047 0 45 :2 0
3048 3049 0 304b
1b24 3052 15 :3 0
ee :3 0 304c 304d
0 ef :2 0 304e
304f 0 3051 1b26
3053 3045 304b 0
3054 0 3051 0
3054 1b28 0 3055
1b2b 30a8 f2 :3 0
15 :3 0 ee :3 0
3057 3058 0 f1
:3 0 3059 305a 0
305c 1b2e 305e 1b30
305d 305c :2 0 30a6
f3 :3 0 15 :3 0
ee :3 0 3061 3062
0 f1 :3 0 3063
3064 0 309e d0
:3 0 d1 :3 0 3066
3067 0 d0 :3 0
e0 :3 0 3069 306a
0 f4 :2 0 2
:4 0 273 :2 0 e2
:2 0 30 :2 0 1b32
306f 3071 :3 0 1b35
306b 3073 3068 3075
3074 :2 0 d3 :3 0
e3 :3 0 3077 3078
0 d5 :4 0 274
:4 0 d8 :2 0 d9
:3 0 1b39 307c 307e
:3 0 d8 :2 0 f7
:4 0 1b3c 3080 3082
:3 0 d8 :2 0 f8
:4 0 1b3f 3084 3086
:3 0 d8 :2 0 f1
:3 0 1b42 3088 308a
:3 0 d8 :2 0 f9
:4 0 1b45 308c 308e
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1b48
3091 3095 1b4c 3090
3097 :3 0 1b4f 3079
3099 :2 0 309b 1b52
309c 3076 309b 0
309d 1b54 0 309e
1b56 30a1 :3 0 30a1
0 30a1 30a0 309e
309f :6 0 30a3 8e
:3 0 1b59 30a5 1b5b
30a4 30a3 :2 0 30a6
1b5d :2 0 30a8 0
30a8 30a7 3055 30a6
:6 0 30aa 69 :3 0
1b60 30ac 2e5e 2fc5
0 30ad 0 30aa
0 30ad 1b63 0
30ae 1b66 30b0 2baa
2dcf 0 30b1 0
30ae 0 30b1 1b69
0 3122 1d4 :3 0
9e :3 0 28 :3 0
a7 :3 0 22 :4 0
240 1 :8 0 30cd
ed :4 0 30b8 :3 0
105 :3 0 e7 :2 0
1b6e 30bb 30bc :3 0
15 :3 0 ee :3 0
30be 30bf 0 45
:2 0 30c0 30c1 0
30c3 1b71 30ca 15
:3 0 ee :3 0 30c4
30c5 0 ef :2 0
30c6 30c7 0 30c9
1b73 30cb 30bd 30c3
0 30cc 0 30c9
0 30cc 1b75 0
30cd 1b78 3120 f2
:3 0 15 :3 0 ee
:3 0 30cf 30d0 0
f1 :3 0 30d1 30d2
0 30d4 1b7b 30d6
1b7d 30d5 30d4 :2 0
311e f3 :3 0 15
:3 0 ee :3 0 30d9
30da 0 f1 :3 0
30db 30dc 0 3116
d0 :3 0 d1 :3 0
30de 30df 0 d0
:3 0 e0 :3 0 30e1
30e2 0 f4 :2 0
2 :4 0 275 :2 0
e2 :2 0 30 :2 0
1b7f 30e7 30e9 :3 0
1b82 30e3 30eb 30e0
30ed 30ec :2 0 d3
:3 0 e3 :3 0 30ef
30f0 0 d5 :4 0
276 :4 0 d8 :2 0
d9 :3 0 1b86 30f4
30f6 :3 0 d8 :2 0
f7 :4 0 1b89 30f8
30fa :3 0 d8 :2 0
f8 :4 0 1b8c 30fc
30fe :3 0 d8 :2 0
f1 :3 0 1b8f 3100
3102 :3 0 d8 :2 0
f9 :4 0 1b92 3104
3106 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1b95 3109 310d 1b99
3108 310f :3 0 1b9c
30f1 3111 :2 0 3113
1b9f 3114 30ee 3113
0 3115 1ba1 0
3116 1ba3 3119 :3 0
3119 0 3119 3118
3116 3117 :6 0 311b
90 :3 0 1ba6 311d
1ba8 311c 311b :2 0
311e 1baa :2 0 3120
0 3120 311f 30cd
311e :6 0 3122 69
:3 0 1bad 3286 70
:3 0 30 :2 0 3123
3124 0 3285 bd
:3 0 a5 :3 0 20
:4 0 236 1 :8 0
313f ed :4 0 312a
:3 0 105 :3 0 e7
:2 0 1bb4 312d 312e
:3 0 15 :3 0 ee
:3 0 3130 3131 0
45 :2 0 3132 3133
0 3135 1bb7 313c
15 :3 0 ee :3 0
3136 3137 0 ef
:2 0 3138 3139 0
313b 1bb9 313d 312f
3135 0 313e 0
313b 0 313e 1bbb
0 313f 1bbe 3192
f2 :3 0 15 :3 0
ee :3 0 3141 3142
0 f1 :3 0 3143
3144 0 3146 1bc1
3148 1bc3 3147 3146
:2 0 3190 f3 :3 0
15 :3 0 ee :3 0
314b 314c 0 f1
:3 0 314d 314e 0
3188 d0 :3 0 d1
:3 0 3150 3151 0
d0 :3 0 e0 :3 0
3153 3154 0 f4
:2 0 2 :4 0 277
:2 0 e2 :2 0 30
:2 0 1bc5 3159 315b
:3 0 1bc8 3155 315d
3152 315f 315e :2 0
d3 :3 0 e3 :3 0
3161 3162 0 d5
:4 0 278 :4 0 d8
:2 0 d9 :3 0 1bcc
3166 3168 :3 0 d8
:2 0 f7 :4 0 1bcf
316a 316c :3 0 d8
:2 0 f8 :4 0 1bd2
316e 3170 :3 0 d8
:2 0 f1 :3 0 1bd5
3172 3174 :3 0 d8
:2 0 f9 :4 0 1bd8
3176 3178 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1bdb 317b 317f
1bdf 317a 3181 :3 0
1be2 3163 3183 :2 0
3185 1be5 3186 3160
3185 0 3187 1be7
0 3188 1be9 318b
:3 0 318b 0 318b
318a 3188 3189 :6 0
318d 92 :3 0 1bec
318f 1bee 318e 318d
:2 0 3190 1bf0 :2 0
3192 0 3192 3191
313f 3190 :6 0 3285
69 :3 0 9d :3 0
a7 :3 0 22 :4 0
239 1 :8 0 31ad
ed :4 0 3198 :3 0
105 :3 0 e7 :2 0
1bf5 319b 319c :3 0
15 :3 0 ee :3 0
319e 319f 0 45
:2 0 31a0 31a1 0
31a3 1bf8 31aa 15
:3 0 ee :3 0 31a4
31a5 0 ef :2 0
31a6 31a7 0 31a9
1bfa 31ab 319d 31a3
0 31ac 0 31a9
0 31ac 1bfc 0
31ad 1bff 3200 f2
:3 0 15 :3 0 ee
:3 0 31af 31b0 0
f1 :3 0 31b1 31b2
0 31b4 1c02 31b6
1c04 31b5 31b4 :2 0
31fe f3 :3 0 15
:3 0 ee :3 0 31b9
31ba 0 f1 :3 0
31bb 31bc 0 31f6
d0 :3 0 d1 :3 0
31be 31bf 0 d0
:3 0 e0 :3 0 31c1
31c2 0 f4 :2 0
2 :4 0 279 :2 0
e2 :2 0 30 :2 0
1c06 31c7 31c9 :3 0
1c09 31c3 31cb 31c0
31cd 31cc :2 0 d3
:3 0 e3 :3 0 31cf
31d0 0 d5 :4 0
27a :4 0 d8 :2 0
d9 :3 0 1c0d 31d4
31d6 :3 0 d8 :2 0
f7 :4 0 1c10 31d8
31da :3 0 d8 :2 0
f8 :4 0 1c13 31dc
31de :3 0 d8 :2 0
f1 :3 0 1c16 31e0
31e2 :3 0 d8 :2 0
f9 :4 0 1c19 31e4
31e6 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1c1c 31e9 31ed 1c20
31e8 31ef :3 0 1c23
31d1 31f1 :2 0 31f3
1c26 31f4 31ce 31f3
0 31f5 1c28 0
31f6 1c2a 31f9 :3 0
31f9 0 31f9 31f8
31f6 31f7 :6 0 31fb
94 :3 0 1c2d 31fd
1c2f 31fc 31fb :2 0
31fe 1c31 :2 0 3200
0 3200 31ff 31ad
31fe :6 0 3285 69
:3 0 1d4 :3 0 9e
:3 0 28 :3 0 a7
:3 0 22 :4 0 240
1 :8 0 321d ed
:4 0 3208 :3 0 105
:3 0 e7 :2 0 1c36
320b 320c :3 0 15
:3 0 ee :3 0 320e
320f 0 45 :2 0
3210 3211 0 3213
1c39 321a 15 :3 0
ee :3 0 3214 3215
0 ef :2 0 3216
3217 0 3219 1c3b
321b 320d 3213 0
321c 0 3219 0
321c 1c3d 0 321d
1c40 3270 f2 :3 0
15 :3 0 ee :3 0
321f 3220 0 f1
:3 0 3221 3222 0
3224 1c43 3226 1c45
3225 3224 :2 0 326e
f3 :3 0 15 :3 0
ee :3 0 3229 322a
0 f1 :3 0 322b
322c 0 3266 d0
:3 0 d1 :3 0 322e
322f 0 d0 :3 0
e0 :3 0 3231 3232
0 f4 :2 0 2
:4 0 27b :2 0 e2
:2 0 30 :2 0 1c47
3237 3239 :3 0 1c4a
3233 323b 3230 323d
323c :2 0 d3 :3 0
e3 :3 0 323f 3240
0 d5 :4 0 27c
:4 0 d8 :2 0 d9
:3 0 1c4e 3244 3246
:3 0 d8 :2 0 f7
:4 0 1c51 3248 324a
:3 0 d8 :2 0 f8
:4 0 1c54 324c 324e
:3 0 d8 :2 0 f1
:3 0 1c57 3250 3252
:3 0 d8 :2 0 f9
:4 0 1c5a 3254 3256
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1c5d
3259 325d 1c61 3258
325f :3 0 1c64 3241
3261 :2 0 3263 1c67
3264 323e 3263 0
3265 1c69 0 3266
1c6b 3269 :3 0 3269
0 3269 3268 3266
3267 :6 0 326b 96
:3 0 1c6e 326d 1c70
326c 326b :2 0 326e
1c72 :2 0 3270 0
3270 326f 321d 326e
:6 0 3285 69 :3 0
ae :3 0 2f :3 0
30 :2 0 30 :2 0
1c75 3272 3276 e7
:2 0 146 :4 0 1c7b
3278 327a :3 0 53
:3 0 146 :2 0 327c
327d 0 327f 1c7e
3280 327b 327f 0
3281 1c80 0 3285
22 :3 0 24 :3 0
3282 3283 0 3285
1c82 3287 2b36 3122
0 3288 0 3285
0 3288 1c89 0
463b 8f :3 0 48
:3 0 45 :2 0 1c8c
3289 328c 117 :2 0
45 :2 0 1c91 328e
3290 :3 0 8f :3 0
6e :3 0 45 :2 0
1c94 3292 3295 e7
:2 0 30 :2 0 1c99
3297 3299 :3 0 329a
:2 0 42 :3 0 1bd
:2 0 1c9c 329d 329e
:3 0 329f :2 0 32a0
:2 0 329b 32a2 32a1
:2 0 131 :3 0 131
:3 0 42 :3 0 6d
:3 0 bc :3 0 99
:3 0 26 :4 0 27d
1 :8 0 32b1 15
:3 0 ee :3 0 32ac
32ad 0 f1 :3 0
32ae 32af 0 32b1
1c9e 3304 f2 :3 0
15 :3 0 ee :3 0
32b3 32b4 0 f1
:3 0 32b5 32b6 0
32b8 1ca1 32ba 1ca3
32b9 32b8 :2 0 3302
f3 :3 0 15 :3 0
ee :3 0 32bd 32be
0 f1 :3 0 32bf
32c0 0 32fa d0
:3 0 d1 :3 0 32c2
32c3 0 d0 :3 0
e0 :3 0 32c5 32c6
0 f4 :2 0 2
:4 0 27e :2 0 e2
:2 0 30 :2 0 1ca5
32cb 32cd :3 0 1ca8
32c7 32cf 32c4 32d1
32d0 :2 0 d3 :3 0
e3 :3 0 32d3 32d4
0 d5 :4 0 27f
:4 0 d8 :2 0 d9
:3 0 1cac 32d8 32da
:3 0 d8 :2 0 f7
:4 0 1caf 32dc 32de
:3 0 d8 :2 0 f8
:4 0 1cb2 32e0 32e2
:3 0 d8 :2 0 f1
:3 0 1cb5 32e4 32e6
:3 0 d8 :2 0 f9
:4 0 1cb8 32e8 32ea
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1cbb
32ed 32f1 1cbf 32ec
32f3 :3 0 1cc2 32d5
32f5 :2 0 32f7 1cc5
32f8 32d2 32f7 0
32f9 1cc7 0 32fa
1cc9 32fd :3 0 32fd
0 32fd 32fc 32fa
32fb :6 0 32ff 98
:3 0 1ccc 3301 1cce
3300 32ff :2 0 3302
1cd0 :2 0 3304 0
3304 3303 32b1 3302
:6 0 3473 69 :3 0
15 :3 0 ee :3 0
3306 3307 0 15
:3 0 e7 :2 0 165
:3 0 3309 330b 0
1cd5 330a 330d :3 0
330e :2 0 8f :3 0
6d :3 0 45 :2 0
1cd8 3310 3313 e7
:2 0 45 :2 0 1cdd
3315 3317 :3 0 3318
:2 0 330f 331a 3319
:2 0 bc :3 0 131
:3 0 42 :3 0 99
:3 0 26 :4 0 280
1 :8 0 3337 ed
:4 0 3322 :3 0 105
:3 0 e7 :2 0 1ce2
3325 3326 :3 0 15
:3 0 ee :3 0 3328
3329 0 45 :2 0
332a 332b 0 332d
1ce5 3334 15 :3 0
ee :3 0 332e 332f
0 ef :2 0 3330
3331 0 3333 1ce7
3335 3327 332d 0
3336 0 3333 0
3336 1ce9 0 3337
1cec 338a f2 :3 0
15 :3 0 ee :3 0
3339 333a 0 f1
:3 0 333b 333c 0
333e 1cef 3340 1cf1
333f 333e :2 0 3388
f3 :3 0 15 :3 0
ee :3 0 3343 3344
0 f1 :3 0 3345
3346 0 3380 d0
:3 0 d1 :3 0 3348
3349 0 d0 :3 0
e0 :3 0 334b 334c
0 f4 :2 0 2
:4 0 281 :2 0 e2
:2 0 30 :2 0 1cf3
3351 3353 :3 0 1cf6
334d 3355 334a 3357
3356 :2 0 d3 :3 0
e3 :3 0 3359 335a
0 d5 :4 0 282
:4 0 d8 :2 0 d9
:3 0 1cfa 335e 3360
:3 0 d8 :2 0 f7
:4 0 1cfd 3362 3364
:3 0 d8 :2 0 f8
:4 0 1d00 3366 3368
:3 0 d8 :2 0 f1
:3 0 1d03 336a 336c
:3 0 d8 :2 0 f9
:4 0 1d06 336e 3370
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1d09
3373 3377 1d0d 3372
3379 :3 0 1d10 335b
337b :2 0 337d 1d13
337e 3358 337d 0
337f 1d15 0 3380
1d17 3383 :3 0 3383
0 3383 3382 3380
3381 :6 0 3385 9a
:3 0 1d1a 3387 1d1c
3386 3385 :2 0 3388
1d1e :2 0 338a 0
338a 3389 3337 3388
:6 0 338d 69 :3 0
15c :3 0 1d21 3471
15 :3 0 ee :3 0
338e 338f 0 15
:3 0 e7 :2 0 165
:3 0 3391 3393 0
1d25 3392 3395 :3 0
3396 :2 0 8f :3 0
6d :3 0 45 :2 0
1d28 3398 339b e7
:2 0 146 :2 0 1d2d
339d 339f :3 0 33a0
:2 0 3397 33a2 33a1
:2 0 f0 :3 0 a3
:4 0 33a7 :2 0 33ad
33a5 0 15 :3 0
ee :3 0 33a8 33a9
0 f1 :3 0 33aa
33ab 0 33ad 1d30
3400 f2 :3 0 15
:3 0 ee :3 0 33af
33b0 0 f1 :3 0
33b1 33b2 0 33b4
1d33 33b6 1d35 33b5
33b4 :2 0 33fe f3
:3 0 15 :3 0 ee
:3 0 33b9 33ba 0
f1 :3 0 33bb 33bc
0 33f6 d0 :3 0
d1 :3 0 33be 33bf
0 d0 :3 0 e0
:3 0 33c1 33c2 0
f4 :2 0 2 :4 0
283 :2 0 e2 :2 0
30 :2 0 1d37 33c7
33c9 :3 0 1d3a 33c3
33cb 33c0 33cd 33cc
:2 0 d3 :3 0 e3
:3 0 33cf 33d0 0
d5 :4 0 284 :4 0
d8 :2 0 d9 :3 0
1d3e 33d4 33d6 :3 0
d8 :2 0 f7 :4 0
1d41 33d8 33da :3 0
d8 :2 0 f8 :4 0
1d44 33dc 33de :3 0
d8 :2 0 f1 :3 0
1d47 33e0 33e2 :3 0
d8 :2 0 f9 :4 0
1d4a 33e4 33e6 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1d4d 33e9
33ed 1d51 33e8 33ef
:3 0 1d54 33d1 33f1
:2 0 33f3 1d57 33f4
33ce 33f3 0 33f5
1d59 0 33f6 1d5b
33f9 :3 0 33f9 0
33f9 33f8 33f6 33f7
:6 0 33fb 9c :3 0
1d5e 33fd 1d60 33fc
33fb :2 0 33fe 1d62
:2 0 3400 0 3400
33ff 33ad 33fe :6 0
346f 69 :3 0 d0
:3 0 d1 :3 0 3402
3403 0 d0 :3 0
e0 :3 0 3405 3406
0 1d :2 0 2
:4 0 285 :2 0 e2
:2 0 30 :2 0 1d65
340b 340d :3 0 1d68
3407 340f 3404 3411
3410 :2 0 d3 :3 0
e3 :3 0 3413 3414
0 d5 :4 0 286
:4 0 d8 :2 0 d9
:3 0 1d6c 3418 341a
:3 0 d8 :2 0 f7
:4 0 1d6f 341c 341e
:3 0 d8 :2 0 fe
:4 0 1d72 3420 3422
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 287 :3 0 3427
3428 0 1d75 3426
342a de :4 0 1d77
3425 342d 1d7a 3424
342f :3 0 d8 :2 0
100 :4 0 1d7d 3431
3433 :3 0 d8 :2 0
db :4 0 1d80 3435
3437 :3 0 d8 :2 0
26 :3 0 1d83 3439
343b :3 0 d8 :2 0
db :4 0 1d86 343d
343f :3 0 1d89 3415
3441 :2 0 3443 1d8c
3444 3412 3443 0
3445 1d8e 0 346f
d0 :3 0 d1 :3 0
3446 3447 0 d0
:3 0 e0 :3 0 3449
344a 0 30 :2 0
2 :4 0 288 :2 0
e2 :2 0 30 :2 0
1d90 344f 3451 :3 0
1d93 344b 3453 3448
3455 3454 :2 0 d3
:3 0 e3 :3 0 3457
3458 0 d5 :4 0
289 :4 0 d8 :2 0
d9 :3 0 1d97 345c
345e :3 0 1d9a 3459
3460 :2 0 3462 1d9d
3463 3456 3462 0
3464 1d9f 0 346f
103 :3 0 104 :3 0
3465 3466 0 1a
:3 0 287 :3 0 3468
3469 0 26 :3 0
105 :3 0 1da1 3467
346d :2 0 346f 1da5
3470 33a3 346f 0
3472 331b 338d 0
3472 1daa 0 3473
1dad 3474 32a3 3473
0 3475 1db0 0
4638 8f :3 0 87
:3 0 45 :2 0 1db2
3476 3479 1a :3 0
e7 :2 0 28a :3 0
347b 347d 0 1db7
347c 347f :3 0 8f
:3 0 87 :3 0 45
:2 0 1dba 3481 3484
1a :3 0 e7 :2 0
28b :3 0 3486 3488
0 1dbf 3487 348a
:3 0 3480 348c 348b
:2 0 28c :3 0 28d
:3 0 28e :4 0 3490
:4 0 3491 :2 0 388e
15 :3 0 ee :3 0
3493 3494 0 45
:2 0 3495 3496 0
388e 8f :3 0 51
:3 0 45 :2 0 1dc2
3498 349b e7 :2 0
45 :2 0 1dc7 349d
349f :3 0 8f :3 0
4d :3 0 45 :2 0
1dca 34a1 34a4 e7
:2 0 45 :2 0 1dcf
34a6 34a8 :3 0 34a0
34aa 34a9 :2 0 28f
:3 0 a4 :3 0 22c
:3 0 97 :3 0 a4
:3 0 a4 :3 0 99
:3 0 27 :3 0 a4
:3 0 22c :3 0 ad
:3 0 ae :3 0 7c
:3 0 ad :3 0 ae
:3 0 7d :4 0 290
1 :8 0 34d2 ed
:4 0 34bd :3 0 105
:3 0 e7 :2 0 1dd4
34c0 34c1 :3 0 15
:3 0 ee :3 0 34c3
34c4 0 45 :2 0
34c5 34c6 0 34c8
1dd7 34cf 15 :3 0
ee :3 0 34c9 34ca
0 ef :2 0 34cb
34cc 0 34ce 1dd9
34d0 34c2 34c8 0
34d1 0 34ce 0
34d1 1ddb 0 34d2
1dde 3525 f2 :3 0
15 :3 0 ee :3 0
34d4 34d5 0 f1
:3 0 34d6 34d7 0
34d9 1de1 34db 1de3
34da 34d9 :2 0 3523
f3 :3 0 15 :3 0
ee :3 0 34de 34df
0 f1 :3 0 34e0
34e1 0 351b d0
:3 0 d1 :3 0 34e3
34e4 0 d0 :3 0
e0 :3 0 34e6 34e7
0 f4 :2 0 2
:4 0 291 :2 0 e2
:2 0 30 :2 0 1de5
34ec 34ee :3 0 1de8
34e8 34f0 34e5 34f2
34f1 :2 0 d3 :3 0
e3 :3 0 34f4 34f5
0 d5 :4 0 292
:4 0 d8 :2 0 d9
:3 0 1dec 34f9 34fb
:3 0 d8 :2 0 f7
:4 0 1def 34fd 34ff
:3 0 d8 :2 0 f8
:4 0 1df2 3501 3503
:3 0 d8 :2 0 f1
:3 0 1df5 3505 3507
:3 0 d8 :2 0 f9
:4 0 1df8 3509 350b
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1dfb
350e 3512 1dff 350d
3514 :3 0 1e02 34f6
3516 :2 0 3518 1e05
3519 34f3 3518 0
351a 1e07 0 351b
1e09 351e :3 0 351e
0 351e 351d 351b
351c :6 0 3520 9e
:3 0 1e0c 3522 1e0e
3521 3520 :2 0 3523
1e10 :2 0 3525 0
3525 3524 34d2 3523
:6 0 3527 69 :3 0
1e13 35b0 28f :3 0
a4 :3 0 22c :3 0
97 :3 0 a4 :3 0
1d4 :3 0 293 :3 0
a4 :3 0 99 :3 0
27 :3 0 a4 :3 0
22c :3 0 ad :3 0
ae :3 0 7c :3 0
ad :3 0 ae :3 0
7d :3 0 293 :3 0
9e :3 0 28 :3 0
293 :3 0 a7 :3 0
22 :3 0 a4 :3 0
22c :3 0 293 :3 0
22c :4 0 294 1
:8 0 355a ed :4 0
3545 :3 0 105 :3 0
e7 :2 0 1e17 3548
3549 :3 0 15 :3 0
ee :3 0 354b 354c
0 45 :2 0 354d
354e 0 3550 1e1a
3557 15 :3 0 ee
:3 0 3551 3552 0
ef :2 0 3553 3554
0 3556 1e1c 3558
354a 3550 0 3559
0 3556 0 3559
1e1e 0 355a 1e21
35ad f2 :3 0 15
:3 0 ee :3 0 355c
355d 0 f1 :3 0
355e 355f 0 3561
1e24 3563 1e26 3562
3561 :2 0 35ab f3
:3 0 15 :3 0 ee
:3 0 3566 3567 0
f1 :3 0 3568 3569
0 35a3 d0 :3 0
d1 :3 0 356b 356c
0 d0 :3 0 e0
:3 0 356e 356f 0
f4 :2 0 2 :4 0
295 :2 0 e2 :2 0
30 :2 0 1e28 3574
3576 :3 0 1e2b 3570
3578 356d 357a 3579
:2 0 d3 :3 0 e3
:3 0 357c 357d 0
d5 :4 0 296 :4 0
d8 :2 0 d9 :3 0
1e2f 3581 3583 :3 0
d8 :2 0 f7 :4 0
1e32 3585 3587 :3 0
d8 :2 0 f8 :4 0
1e35 3589 358b :3 0
d8 :2 0 f1 :3 0
1e38 358d 358f :3 0
d8 :2 0 f9 :4 0
1e3b 3591 3593 :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1e3e 3596
359a 1e42 3595 359c
:3 0 1e45 357e 359e
:2 0 35a0 1e48 35a1
357b 35a0 0 35a2
1e4a 0 35a3 1e4c
35a6 :3 0 35a6 0
35a6 35a5 35a3 35a4
:6 0 35a8 a0 :3 0
1e4f 35aa 1e51 35a9
35a8 :2 0 35ab 1e53
:2 0 35ad 0 35ad
35ac 355a 35ab :6 0
35af 69 :3 0 1e56
35b1 34ab 3527 0
35b2 0 35af 0
35b2 1e58 0 388e
15 :3 0 ee :3 0
35b3 35b4 0 15
:3 0 e7 :2 0 165
:3 0 35b6 35b8 0
1e5d 35b7 35ba :3 0
35bb :2 0 75 :3 0
45 :2 0 35bd 35be
0 3887 147 :3 0
22c :3 0 297 :3 0
22c :3 0 75 :3 0
32 :3 0 28f :4 0
298 1 :8 0 35cd
15 :3 0 ee :3 0
35c8 35c9 0 f1
:3 0 35ca 35cb 0
35cd 1e60 3620 f2
:3 0 15 :3 0 ee
:3 0 35cf 35d0 0
f1 :3 0 35d1 35d2
0 35d4 1e63 35d6
1e65 35d5 35d4 :2 0
361e f3 :3 0 15
:3 0 ee :3 0 35d9
35da 0 f1 :3 0
35db 35dc 0 3616
d0 :3 0 d1 :3 0
35de 35df 0 d0
:3 0 e0 :3 0 35e1
35e2 0 f4 :2 0
2 :4 0 299 :2 0
e2 :2 0 30 :2 0
1e67 35e7 35e9 :3 0
1e6a 35e3 35eb 35e0
35ed 35ec :2 0 d3
:3 0 e3 :3 0 35ef
35f0 0 d5 :4 0
29a :4 0 d8 :2 0
d9 :3 0 1e6e 35f4
35f6 :3 0 d8 :2 0
f7 :4 0 1e71 35f8
35fa :3 0 d8 :2 0
f8 :4 0 1e74 35fc
35fe :3 0 d8 :2 0
f1 :3 0 1e77 3600
3602 :3 0 d8 :2 0
f9 :4 0 1e7a 3604
3606 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
1e7d 3609 360d 1e81
3608 360f :3 0 1e84
35f1 3611 :2 0 3613
1e87 3614 35ee 3613
0 3615 1e89 0
3616 1e8b 3619 :3 0
3619 0 3619 3618
3616 3617 :6 0 361b
a2 :3 0 1e8e 361d
1e90 361c 361b :2 0
361e 1e92 :2 0 3620
0 3620 361f 35cd
361e :6 0 3887 69
:3 0 8f :3 0 75
:3 0 45 :2 0 1e95
3622 3625 e7 :2 0
45 :2 0 1e9a 3627
3629 :3 0 29b :3 0
362b :4 0 362d 1e9d
37bc 1d4 :3 0 9e
:3 0 28 :3 0 a7
:3 0 22 :4 0 29c
1 :8 0 3649 ed
:4 0 3634 :3 0 105
:3 0 e7 :2 0 1ea1
3637 3638 :3 0 15
:3 0 ee :3 0 363a
363b 0 45 :2 0
363c 363d 0 363f
1ea4 3646 15 :3 0
ee :3 0 3640 3641
0 ef :2 0 3642
3643 0 3645 1ea6
3647 3639 363f 0
3648 0 3645 0
3648 1ea8 0 3649
1eab 369c f2 :3 0
15 :3 0 ee :3 0
364b 364c 0 f1
:3 0 364d 364e 0
3650 1eae 3652 1eb0
3651 3650 :2 0 369a
f3 :3 0 15 :3 0
ee :3 0 3655 3656
0 f1 :3 0 3657
3658 0 3692 d0
:3 0 d1 :3 0 365a
365b 0 d0 :3 0
e0 :3 0 365d 365e
0 f4 :2 0 2
:4 0 29d :2 0 e2
:2 0 30 :2 0 1eb2
3663 3665 :3 0 1eb5
365f 3667 365c 3669
3668 :2 0 d3 :3 0
e3 :3 0 366b 366c
0 d5 :4 0 29e
:4 0 d8 :2 0 d9
:3 0 1eb9 3670 3672
:3 0 d8 :2 0 f7
:4 0 1ebc 3674 3676
:3 0 d8 :2 0 f8
:4 0 1ebf 3678 367a
:3 0 d8 :2 0 f1
:3 0 1ec2 367c 367e
:3 0 d8 :2 0 f9
:4 0 1ec5 3680 3682
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 1ec8
3685 3689 1ecc 3684
368b :3 0 1ecf 366d
368d :2 0 368f 1ed2
3690 366a 368f 0
3691 1ed4 0 3692
1ed6 3695 :3 0 3695
0 3695 3694 3692
3693 :6 0 3697 a4
:3 0 1ed9 3699 1edb
3698 3697 :2 0 369a
1edd :2 0 369c 0
369c 369b 3649 369a
:6 0 37bb 69 :3 0
6f :3 0 29f :3 0
8f :3 0 2a0 :3 0
48 :3 0 1ee0 36a1
36a3 45 :2 0 1ee2
36a0 36a6 2a1 :2 0
8f :3 0 2a0 :3 0
75 :3 0 1ee5 36aa
36ac 45 :2 0 1ee7
36a9 36af 1eea 36a8
36b1 :3 0 36b2 :2 0
e2 :2 0 2a2 :2 0
1eed 36b4 36b6 :3 0
1ef0 369f 36b8 369e
36b9 0 37bb 96
:3 0 2a3 :3 0 60
:3 0 17 :3 0 97
:3 0 99 :3 0 28
:3 0 22c :3 0 32
:4 0 2a4 1 :8 0
36ca 15 :3 0 ee
:3 0 36c5 36c6 0
f1 :3 0 36c7 36c8
0 36ca 1ef2 371d
f2 :3 0 15 :3 0
ee :3 0 36cc 36cd
0 f1 :3 0 36ce
36cf 0 36d1 1ef5
36d3 1ef7 36d2 36d1
:2 0 371b f3 :3 0
15 :3 0 ee :3 0
36d6 36d7 0 f1
:3 0 36d8 36d9 0
3713 d0 :3 0 d1
:3 0 36db 36dc 0
d0 :3 0 e0 :3 0
36de 36df 0 f4
:2 0 2 :4 0 2a5
:2 0 e2 :2 0 30
:2 0 1ef9 36e4 36e6
:3 0 1efc 36e0 36e8
36dd 36ea 36e9 :2 0
d3 :3 0 e3 :3 0
36ec 36ed 0 d5
:4 0 2a6 :4 0 d8
:2 0 d9 :3 0 1f00
36f1 36f3 :3 0 d8
:2 0 f7 :4 0 1f03
36f5 36f7 :3 0 d8
:2 0 f8 :4 0 1f06
36f9 36fb :3 0 d8
:2 0 f1 :3 0 1f09
36fd 36ff :3 0 d8
:2 0 f9 :4 0 1f0c
3701 3703 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 1f0f 3706 370a
1f13 3705 370c :3 0
1f16 36ee 370e :2 0
3710 1f19 3711 36eb
3710 0 3712 1f1b
0 3713 1f1d 3716
:3 0 3716 0 3716
3715 3713 3714 :6 0
3718 a6 :3 0 1f20
371a 1f22 3719 3718
:2 0 371b 1f24 :2 0
371d 0 371d 371c
36ca 371b :6 0 37bb
69 :3 0 8f :3 0
60 :3 0 45 :2 0
1f27 371f 3722 8f
:3 0 117 :2 0 6f
:3 0 45 :2 0 1f2a
3724 3728 1f2f 3725
372a :3 0 1a1 :3 0
2a7 :3 0 372c 372d
0 8f :3 0 6f
:3 0 45 :2 0 1f32
372f 3732 17 :3 0
1f35 372e 3735 :2 0
3737 1f38 3738 372b
3737 0 3739 1f3a
0 37bb 1d4 :3 0
9e :3 0 9f :3 0
a7 :3 0 22c :3 0
182 :3 0 1d3 :3 0
2a3 :3 0 1d5 :3 0
2a8 :3 0 a8 :3 0
28 :3 0 27 :3 0
22 :3 0 22c :3 0
6f :3 0 17 :3 0
55 :3 0 22 :3 0
23 :3 0 26 :3 0
28f :4 0 2a9 1
:8 0 3766 ed :4 0
3751 :3 0 105 :3 0
e7 :2 0 1f3e 3754
3755 :3 0 15 :3 0
ee :3 0 3757 3758
0 45 :2 0 3759
375a 0 375c 1f41
3763 15 :3 0 ee
:3 0 375d 375e 0
ef :2 0 375f 3760
0 3762 1f43 3764
3756 375c 0 3765
0 3762 0 3765
1f45 0 3766 1f48
37b9 f2 :3 0 15
:3 0 ee :3 0 3768
3769 0 f1 :3 0
376a 376b 0 376d
1f4b 376f 1f4d 376e
376d :2 0 37b7 f3
:3 0 15 :3 0 ee
:3 0 3772 3773 0
f1 :3 0 3774 3775
0 37af d0 :3 0
d1 :3 0 3777 3778
0 d0 :3 0 e0
:3 0 377a 377b 0
f4 :2 0 2 :4 0
2aa :2 0 e2 :2 0
30 :2 0 1f4f 3780
3782 :3 0 1f52 377c
3784 3779 3786 3785
:2 0 d3 :3 0 e3
:3 0 3788 3789 0
d5 :4 0 2ab :4 0
d8 :2 0 d9 :3 0
1f56 378d 378f :3 0
d8 :2 0 f7 :4 0
1f59 3791 3793 :3 0
d8 :2 0 f8 :4 0
1f5c 3795 3797 :3 0
d8 :2 0 f1 :3 0
1f5f 3799 379b :3 0
d8 :2 0 f9 :4 0
1f62 379d 379f :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1f65 37a2
37a6 1f69 37a1 37a8
:3 0 1f6c 378a 37aa
:2 0 37ac 1f6f 37ad
3787 37ac 0 37ae
1f71 0 37af 1f73
37b2 :3 0 37b2 0
37b2 37b1 37af 37b0
:6 0 37b4 a8 :3 0
1f76 37b6 1f78 37b5
37b4 :2 0 37b7 1f7a
:2 0 37b9 0 37b9
37b8 3766 37b7 :6 0
37bb 69 :3 0 1f7d
37bd 362a 362d 0
37be 0 37bb 0
37be 1f83 0 3887
9d :3 0 9f :3 0
27 :3 0 a0 :3 0
a1 :3 0 55 :3 0
23 :3 0 b5 :3 0
6b :3 0 62 :3 0
b5 :3 0 1f0 :3 0
6b :3 0 65 :3 0
1f0 :3 0 b6 :3 0
6a :3 0 64 :3 0
b6 :3 0 1f1 :3 0
6a :3 0 66 :3 0
1f1 :3 0 1f4 :3 0
1a1 :3 0 176 :3 0
1f4 :3 0 1a :3 0
1f5 :3 0 a7 :3 0
22 :4 0 2ac 1
:8 0 37f4 ed :4 0
37df :3 0 105 :3 0
e7 :2 0 1f88 37e2
37e3 :3 0 15 :3 0
ee :3 0 37e5 37e6
0 45 :2 0 37e7
37e8 0 37ea 1f8b
37f1 15 :3 0 ee
:3 0 37eb 37ec 0
ef :2 0 37ed 37ee
0 37f0 1f8d 37f2
37e4 37ea 0 37f3
0 37f0 0 37f3
1f8f 0 37f4 1f92
3847 f2 :3 0 15
:3 0 ee :3 0 37f6
37f7 0 f1 :3 0
37f8 37f9 0 37fb
1f95 37fd 1f97 37fc
37fb :2 0 3845 f3
:3 0 15 :3 0 ee
:3 0 3800 3801 0
f1 :3 0 3802 3803
0 383d d0 :3 0
d1 :3 0 3805 3806
0 d0 :3 0 e0
:3 0 3808 3809 0
f4 :2 0 2 :4 0
2ad :2 0 e2 :2 0
30 :2 0 1f99 380e
3810 :3 0 1f9c 380a
3812 3807 3814 3813
:2 0 d3 :3 0 e3
:3 0 3816 3817 0
d5 :4 0 2ae :4 0
d8 :2 0 d9 :3 0
1fa0 381b 381d :3 0
d8 :2 0 f7 :4 0
1fa3 381f 3821 :3 0
d8 :2 0 f8 :4 0
1fa6 3823 3825 :3 0
d8 :2 0 f1 :3 0
1fa9 3827 3829 :3 0
d8 :2 0 f9 :4 0
1fac 382b 382d :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 1faf 3830
3834 1fb3 382f 3836
:3 0 1fb6 3818 3838
:2 0 383a 1fb9 383b
3815 383a 0 383c
1fbb 0 383d 1fbd
3840 :3 0 3840 0
3840 383f 383d 383e
:6 0 3842 aa :3 0
1fc0 3844 1fc2 3843
3842 :2 0 3845 1fc4
:2 0 3847 0 3847
3846 37f4 3845 :6 0
3887 69 :3 0 88
:3 0 29f :3 0 8f
:3 0 2a0 :3 0 6f
:3 0 1fc7 384c 384e
45 :2 0 1fc9 384b
3851 2a1 :2 0 8f
:3 0 2a0 :3 0 58
:3 0 1fcc 3855 3857
45 :2 0 1fce 3854
385a 1fd1 3853 385c
:3 0 385d :2 0 1b0
:2 0 2af :2 0 1fd4
385f 3861 :3 0 1fd7
384a 3863 3849 3864
0 3887 75 :3 0
175 :3 0 176 :3 0
3867 3868 0 8f
:3 0 88 :3 0 45
:2 0 1fd9 386a 386d
1a :3 0 2b0 :3 0
386f 3870 0 1fdc
3869 3872 3866 3873
0 3887 7b :3 0
22b :3 0 28 :3 0
22 :3 0 75 :3 0
8f :3 0 58 :3 0
45 :2 0 1fdf 387a
387d 8f :3 0 48
:3 0 45 :2 0 1fe2
387f 3882 1fe5 3876
3884 3875 3885 0
3887 1feb 388b 29b
:3 0 3888 :4 0 388a
1ff3 388c 35bc 3887
0 388d 0 388a
0 388d 1ff5 0
388e 1ff8 4183 2c
:3 0 eb :4 0 388f
3890 0 4182 8d
:3 0 14e :2 0 45
:2 0 1fff 3893 3895
:3 0 8f :3 0 70
:3 0 45 :2 0 2002
3897 389a 14e :2 0
45 :2 0 2007 389c
389e :3 0 48 :3 0
9 :3 0 38a0 38a1
0 3946 8f :3 0
4d :3 0 45 :2 0
200a 38a3 38a6 e7
:2 0 45 :2 0 200f
38a8 38aa :3 0 8f
:3 0 88 :3 0 45
:2 0 2012 38ac 38af
14e :2 0 2b1 :2 0
2017 38b1 38b3 :3 0
38ab 38b5 38b4 :2 0
8f :3 0 88 :3 0
45 :2 0 201a 38b7
38ba 14e :2 0 45
:2 0 201f 38bc 38be
:3 0 38b6 38c0 38bf
:2 0 50 :3 0 ef
:2 0 38c2 38c3 0
38cc 4d :3 0 8f
:3 0 88 :3 0 45
:2 0 2022 38c6 38c9
38c5 38ca 0 38cc
2025 38cd 38c1 38cc
0 38ce 2028 0
3946 9d :3 0 1f4
:3 0 1a1 :3 0 176
:3 0 1f4 :3 0 1a
:3 0 1f5 :3 0 2b2
:3 0 2b2 :3 0 48
:3 0 a7 :3 0 22
:4 0 2b3 1 :8 0
38f1 ed :4 0 38dc
:3 0 105 :3 0 e7
:2 0 202c 38df 38e0
:3 0 15 :3 0 ee
:3 0 38e2 38e3 0
45 :2 0 38e4 38e5
0 38e7 202f 38ee
15 :3 0 ee :3 0
38e8 38e9 0 ef
:2 0 38ea 38eb 0
38ed 2031 38ef 38e1
38e7 0 38f0 0
38ed 0 38f0 2033
0 38f1 2036 3944
f2 :3 0 15 :3 0
ee :3 0 38f3 38f4
0 f1 :3 0 38f5
38f6 0 38f8 2039
38fa 203b 38f9 38f8
:2 0 3942 f3 :3 0
15 :3 0 ee :3 0
38fd 38fe 0 f1
:3 0 38ff 3900 0
393a d0 :3 0 d1
:3 0 3902 3903 0
d0 :3 0 e0 :3 0
3905 3906 0 f4
:2 0 2 :4 0 2b4
:2 0 e2 :2 0 30
:2 0 203d 390b 390d
:3 0 2040 3907 390f
3904 3911 3910 :2 0
d3 :3 0 e3 :3 0
3913 3914 0 d5
:4 0 2b5 :4 0 d8
:2 0 d9 :3 0 2044
3918 391a :3 0 d8
:2 0 f7 :4 0 2047
391c 391e :3 0 d8
:2 0 f8 :4 0 204a
3920 3922 :3 0 d8
:2 0 f1 :3 0 204d
3924 3926 :3 0 d8
:2 0 f9 :4 0 2050
3928 392a :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2053 392d 3931
2057 392c 3933 :3 0
205a 3915 3935 :2 0
3937 205d 3938 3912
3937 0 3939 205f
0 393a 2061 393d
:3 0 393d 0 393d
393c 393a 393b :6 0
393f ac :3 0 2064
3941 2066 3940 393f
:2 0 3942 2068 :2 0
3944 0 3944 3943
38f1 3942 :6 0 3946
69 :3 0 206b 3b83
48 :3 0 9 :3 0
3947 3948 0 3b82
2a :3 0 7 :3 0
394a 394b 0 3b82
2c :3 0 8 :3 0
394d 394e 0 3b82
4d :3 0 b :3 0
3950 3951 0 3b82
4e :3 0 10 :3 0
3953 3954 0 3b82
4f :3 0 d :3 0
3956 3957 0 3b82
50 :3 0 e :3 0
3959 395a 0 3b82
57 :3 0 c :3 0
395c 395d 0 3b82
51 :3 0 f :3 0
395f 3960 0 3b82
e5 :3 0 8f :3 0
c :3 0 45 :2 0
206f 3963 3966 1a
:3 0 1c3 :3 0 3968
3969 0 2072 3962
396b 396c :2 0 14e
:2 0 45 :2 0 2077
396e 3970 :3 0 3971
:2 0 8f :3 0 51
:3 0 45 :2 0 207a
3973 3976 8f :3 0
14e :2 0 f :3 0
45 :2 0 207d 3978
397c 2082 3979 397e
:3 0 8f :3 0 4d
:3 0 45 :2 0 2085
3980 3983 8f :3 0
14e :2 0 b :3 0
45 :2 0 2088 3985
3989 208d 3986 398b
:3 0 397f 398d 398c
:2 0 398e :2 0 3972
3990 398f :2 0 8f
:3 0 e :3 0 45
:2 0 2090 3992 3995
e7 :2 0 ef :2 0
2095 3997 3999 :3 0
9d :3 0 9f :3 0
27 :3 0 a0 :3 0
a1 :3 0 55 :3 0
23 :3 0 b5 :3 0
6b :3 0 62 :3 0
b5 :3 0 1f0 :3 0
6b :3 0 65 :3 0
1f0 :3 0 b6 :3 0
6a :3 0 64 :3 0
b6 :3 0 1f1 :3 0
6a :3 0 66 :3 0
1f1 :3 0 ab :3 0
b :3 0 2b2 :3 0
48 :3 0 ba :3 0
f :3 0 1f4 :3 0
1a1 :3 0 176 :3 0
1f4 :3 0 1a :3 0
1f5 :3 0 a7 :3 0
22 :4 0 2b6 1
:8 0 39d6 ed :4 0
39c1 :3 0 105 :3 0
e7 :2 0 209a 39c4
39c5 :3 0 15 :3 0
ee :3 0 39c7 39c8
0 45 :2 0 39c9
39ca 0 39cc 209d
39d3 15 :3 0 ee
:3 0 39cd 39ce 0
ef :2 0 39cf 39d0
0 39d2 209f 39d4
39c6 39cc 0 39d5
0 39d2 0 39d5
20a1 0 39d6 20a4
3a29 f2 :3 0 15
:3 0 ee :3 0 39d8
39d9 0 f1 :3 0
39da 39db 0 39dd
20a7 39df 20a9 39de
39dd :2 0 3a27 f3
:3 0 15 :3 0 ee
:3 0 39e2 39e3 0
f1 :3 0 39e4 39e5
0 3a1f d0 :3 0
d1 :3 0 39e7 39e8
0 d0 :3 0 e0
:3 0 39ea 39eb 0
f4 :2 0 2 :4 0
2b7 :2 0 e2 :2 0
30 :2 0 20ab 39f0
39f2 :3 0 20ae 39ec
39f4 39e9 39f6 39f5
:2 0 d3 :3 0 e3
:3 0 39f8 39f9 0
d5 :4 0 2b8 :4 0
d8 :2 0 d9 :3 0
20b2 39fd 39ff :3 0
d8 :2 0 f7 :4 0
20b5 3a01 3a03 :3 0
d8 :2 0 f8 :4 0
20b8 3a05 3a07 :3 0
d8 :2 0 f1 :3 0
20bb 3a09 3a0b :3 0
d8 :2 0 f9 :4 0
20be 3a0d 3a0f :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 20c1 3a12
3a16 20c5 3a11 3a18
:3 0 20c8 39fa 3a1a
:2 0 3a1c 20cb 3a1d
39f7 3a1c 0 3a1e
20cd 0 3a1f 20cf
3a22 :3 0 3a22 0
3a22 3a21 3a1f 3a20
:6 0 3a24 ae :3 0
20d2 3a26 20d4 3a25
3a24 :2 0 3a27 20d6
:2 0 3a29 0 3a29
3a28 39d6 3a27 :6 0
3a2b 69 :3 0 20d9
3abf 9d :3 0 9f
:3 0 27 :3 0 a0
:3 0 a1 :3 0 55
:3 0 23 :3 0 b5
:3 0 6b :3 0 62
:3 0 b5 :3 0 1f0
:3 0 6b :3 0 65
:3 0 1f0 :3 0 b6
:3 0 6a :3 0 64
:3 0 b6 :3 0 1f1
:3 0 6a :3 0 66
:3 0 1f1 :3 0 b7
:3 0 b :3 0 2b2
:3 0 48 :3 0 b9
:3 0 e :3 0 ba
:3 0 f :3 0 1f4
:3 0 1a1 :3 0 176
:3 0 1f4 :3 0 1a
:3 0 1f5 :3 0 a7
:3 0 22 :4 0 2b9
1 :8 0 3a69 ed
:4 0 3a54 :3 0 105
:3 0 e7 :2 0 20dd
3a57 3a58 :3 0 15
:3 0 ee :3 0 3a5a
3a5b 0 45 :2 0
3a5c 3a5d 0 3a5f
20e0 3a66 15 :3 0
ee :3 0 3a60 3a61
0 ef :2 0 3a62
3a63 0 3a65 20e2
3a67 3a59 3a5f 0
3a68 0 3a65 0
3a68 20e4 0 3a69
20e7 3abc f2 :3 0
15 :3 0 ee :3 0
3a6b 3a6c 0 f1
:3 0 3a6d 3a6e 0
3a70 20ea 3a72 20ec
3a71 3a70 :2 0 3aba
f3 :3 0 15 :3 0
ee :3 0 3a75 3a76
0 f1 :3 0 3a77
3a78 0 3ab2 d0
:3 0 d1 :3 0 3a7a
3a7b 0 d0 :3 0
e0 :3 0 3a7d 3a7e
0 f4 :2 0 2
:4 0 2ba :2 0 e2
:2 0 30 :2 0 20ee
3a83 3a85 :3 0 20f1
3a7f 3a87 3a7c 3a89
3a88 :2 0 d3 :3 0
e3 :3 0 3a8b 3a8c
0 d5 :4 0 2bb
:4 0 d8 :2 0 d9
:3 0 20f5 3a90 3a92
:3 0 d8 :2 0 f7
:4 0 20f8 3a94 3a96
:3 0 d8 :2 0 f8
:4 0 20fb 3a98 3a9a
:3 0 d8 :2 0 f1
:3 0 20fe 3a9c 3a9e
:3 0 d8 :2 0 f9
:4 0 2101 3aa0 3aa2
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2104
3aa5 3aa9 2108 3aa4
3aab :3 0 210b 3a8d
3aad :2 0 3aaf 210e
3ab0 3a8a 3aaf 0
3ab1 2110 0 3ab2
2112 3ab5 :3 0 3ab5
0 3ab5 3ab4 3ab2
3ab3 :6 0 3ab7 b0
:3 0 2115 3ab9 2117
3ab8 3ab7 :2 0 3aba
2119 :2 0 3abc 0
3abc 3abb 3a69 3aba
:6 0 3abe 69 :3 0
211c 3ac0 399a 3a2b
0 3ac1 0 3abe
0 3ac1 211e 0
3ac2 2121 3b50 9d
:3 0 9f :3 0 27
:3 0 a0 :3 0 a1
:3 0 55 :3 0 23
:3 0 b5 :3 0 6b
:3 0 62 :3 0 b5
:3 0 1f0 :3 0 6b
:3 0 65 :3 0 1f0
:3 0 b6 :3 0 6a
:3 0 64 :3 0 b6
:3 0 1f1 :3 0 6a
:3 0 66 :3 0 1f1
:3 0 1f4 :3 0 1a1
:3 0 176 :3 0 1f4
:3 0 1a :3 0 1f5
:3 0 2b2 :3 0 48
:3 0 a7 :3 0 22
:4 0 2bc 1 :8 0
3afa ed :4 0 3ae5
:3 0 105 :3 0 e7
:2 0 2125 3ae8 3ae9
:3 0 15 :3 0 ee
:3 0 3aeb 3aec 0
45 :2 0 3aed 3aee
0 3af0 2128 3af7
15 :3 0 ee :3 0
3af1 3af2 0 ef
:2 0 3af3 3af4 0
3af6 212a 3af8 3aea
3af0 0 3af9 0
3af6 0 3af9 212c
0 3afa 212f 3b4d
f2 :3 0 15 :3 0
ee :3 0 3afc 3afd
0 f1 :3 0 3afe
3aff 0 3b01 2132
3b03 2134 3b02 3b01
:2 0 3b4b f3 :3 0
15 :3 0 ee :3 0
3b06 3b07 0 f1
:3 0 3b08 3b09 0
3b43 d0 :3 0 d1
:3 0 3b0b 3b0c 0
d0 :3 0 e0 :3 0
3b0e 3b0f 0 f4
:2 0 2 :4 0 2bd
:2 0 e2 :2 0 30
:2 0 2136 3b14 3b16
:3 0 2139 3b10 3b18
3b0d 3b1a 3b19 :2 0
d3 :3 0 e3 :3 0
3b1c 3b1d 0 d5
:4 0 2be :4 0 d8
:2 0 d9 :3 0 213d
3b21 3b23 :3 0 d8
:2 0 f7 :4 0 2140
3b25 3b27 :3 0 d8
:2 0 f8 :4 0 2143
3b29 3b2b :3 0 d8
:2 0 f1 :3 0 2146
3b2d 3b2f :3 0 d8
:2 0 f9 :4 0 2149
3b31 3b33 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 214c 3b36 3b3a
2150 3b35 3b3c :3 0
2153 3b1e 3b3e :2 0
3b40 2156 3b41 3b1b
3b40 0 3b42 2158
0 3b43 215a 3b46
:3 0 3b46 0 3b46
3b45 3b43 3b44 :6 0
3b48 b2 :3 0 215d
3b4a 215f 3b49 3b48
:2 0 3b4b 2161 :2 0
3b4d 0 3b4d 3b4c
3afa 3b4b :6 0 3b4f
69 :3 0 2164 3b51
3991 3ac2 0 3b52
0 3b4f 0 3b52
2166 0 3b82 8f
:3 0 51 :3 0 45
:2 0 2169 3b53 3b56
e7 :2 0 45 :2 0
216e 3b58 3b5a :3 0
3b5b :2 0 8f :3 0
50 :3 0 45 :2 0
2171 3b5d 3b60 14e
:2 0 ef :2 0 2176
3b62 3b64 :3 0 3b65
:2 0 3b5c 3b67 3b66
:2 0 4d :3 0 45
:2 0 3b69 3b6a 0
3b6d 15c :3 0 2179
3b80 8f :3 0 50
:3 0 45 :2 0 217b
3b6e 3b71 e7 :2 0
ef :2 0 2180 3b73
3b75 :3 0 88 :3 0
8f :3 0 4d :3 0
45 :2 0 2183 3b78
3b7b 3b77 3b7c 0
3b7e 2186 3b7f 3b76
3b7e 0 3b81 3b68
3b6d 0 3b81 2188
0 3b82 218b 3b84
389f 3946 0 3b85
0 3b82 0 3b85
2197 0 3d57 75
:3 0 213 :3 0 39
:3 0 3a :3 0 8f
:3 0 4f :3 0 45
:2 0 219a 3b8a 3b8d
8f :3 0 50 :3 0
45 :2 0 219d 3b8f
3b92 8f :3 0 5b
:3 0 45 :2 0 21a0
3b94 3b97 8f :3 0
57 :3 0 45 :2 0
21a3 3b99 3b9c 8f
:3 0 51 :3 0 45
:2 0 21a6 3b9e 3ba1
8f :3 0 4e :3 0
45 :2 0 21a9 3ba3
3ba6 8f :3 0 58
:3 0 45 :2 0 21ac
3ba8 3bab 8f :3 0
59 :3 0 45 :2 0
21af 3bad 3bb0 4d
:3 0 48 :3 0 52
:3 0 21b2 3b87 3bb5
3b86 3bb6 0 3d57
8f :3 0 75 :3 0
45 :2 0 21c0 3bb8
3bbb 1a :3 0 e7
:2 0 214 :3 0 3bbd
3bbf 0 21c5 3bbe
3bc1 :3 0 f0 :3 0
a3 :4 0 3bc6 :2 0
3bcc 3bc4 0 15
:3 0 ee :3 0 3bc7
3bc8 0 f1 :3 0
3bc9 3bca 0 3bcc
21c8 3c1f f2 :3 0
15 :3 0 ee :3 0
3bce 3bcf 0 f1
:3 0 3bd0 3bd1 0
3bd3 21cb 3bd5 21cd
3bd4 3bd3 :2 0 3c1d
f3 :3 0 15 :3 0
ee :3 0 3bd8 3bd9
0 f1 :3 0 3bda
3bdb 0 3c15 d0
:3 0 d1 :3 0 3bdd
3bde 0 d0 :3 0
e0 :3 0 3be0 3be1
0 f4 :2 0 2
:4 0 2bf :2 0 e2
:2 0 30 :2 0 21cf
3be6 3be8 :3 0 21d2
3be2 3bea 3bdf 3bec
3beb :2 0 d3 :3 0
e3 :3 0 3bee 3bef
0 d5 :4 0 2c0
:4 0 d8 :2 0 d9
:3 0 21d6 3bf3 3bf5
:3 0 d8 :2 0 f7
:4 0 21d9 3bf7 3bf9
:3 0 d8 :2 0 f8
:4 0 21dc 3bfb 3bfd
:3 0 d8 :2 0 f1
:3 0 21df 3bff 3c01
:3 0 d8 :2 0 f9
:4 0 21e2 3c03 3c05
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 21e5
3c08 3c0c 21e9 3c07
3c0e :3 0 21ec 3bf0
3c10 :2 0 3c12 21ef
3c13 3bed 3c12 0
3c14 21f1 0 3c15
21f3 3c18 :3 0 3c18
0 3c18 3c17 3c15
3c16 :6 0 3c1a b4
:3 0 21f6 3c1c 21f8
3c1b 3c1a :2 0 3c1d
21fa :2 0 3c1f 0
3c1f 3c1e 3bcc 3c1d
:6 0 3c7e 69 :3 0
d0 :3 0 d1 :3 0
3c21 3c22 0 d0
:3 0 e0 :3 0 3c24
3c25 0 215 :2 0
2 :4 0 2c1 :2 0
e2 :2 0 30 :2 0
21fd 3c2a 3c2c :3 0
2200 3c26 3c2e 3c23
3c30 3c2f :2 0 d3
:3 0 e3 :3 0 3c32
3c33 0 d5 :4 0
2c2 :4 0 d8 :2 0
d9 :3 0 2204 3c37
3c39 :3 0 d8 :2 0
f7 :4 0 2207 3c3b
3c3d :3 0 d8 :2 0
fe :4 0 220a 3c3f
3c41 :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 214 :3 0
3c46 3c47 0 220d
3c45 3c49 de :4 0
220f 3c44 3c4c 2212
3c43 3c4e :3 0 2215
3c34 3c50 :2 0 3c52
2218 3c53 3c31 3c52
0 3c54 221a 0
3c7e d0 :3 0 d1
:3 0 3c55 3c56 0
d0 :3 0 e0 :3 0
3c58 3c59 0 30
:2 0 2 :4 0 2c3
:2 0 e2 :2 0 30
:2 0 221c 3c5e 3c60
:3 0 221f 3c5a 3c62
3c57 3c64 3c63 :2 0
d3 :3 0 e3 :3 0
3c66 3c67 0 d5
:4 0 2c4 :4 0 d8
:2 0 d9 :3 0 2223
3c6b 3c6d :3 0 2226
3c68 3c6f :2 0 3c71
2229 3c72 3c65 3c71
0 3c73 222b 0
3c7e 103 :3 0 21a
:3 0 3c74 3c75 0
1a :3 0 214 :3 0
3c77 3c78 0 105
:3 0 222d 3c76 3c7b
:2 0 3c7e 15c :3 0
2230 3d55 8f :3 0
75 :3 0 45 :2 0
2235 3c7f 3c82 14e
:2 0 45 :2 0 223a
3c84 3c86 :3 0 f0
:3 0 a3 :4 0 3c8b
:2 0 3c91 3c89 0
15 :3 0 ee :3 0
3c8c 3c8d 0 f1
:3 0 3c8e 3c8f 0
3c91 223d 3ce4 f2
:3 0 15 :3 0 ee
:3 0 3c93 3c94 0
f1 :3 0 3c95 3c96
0 3c98 2240 3c9a
2242 3c99 3c98 :2 0
3ce2 f3 :3 0 15
:3 0 ee :3 0 3c9d
3c9e 0 f1 :3 0
3c9f 3ca0 0 3cda
d0 :3 0 d1 :3 0
3ca2 3ca3 0 d0
:3 0 e0 :3 0 3ca5
3ca6 0 f4 :2 0
2 :4 0 2c5 :2 0
e2 :2 0 30 :2 0
2244 3cab 3cad :3 0
2247 3ca7 3caf 3ca4
3cb1 3cb0 :2 0 d3
:3 0 e3 :3 0 3cb3
3cb4 0 d5 :4 0
2c6 :4 0 d8 :2 0
d9 :3 0 224b 3cb8
3cba :3 0 d8 :2 0
f7 :4 0 224e 3cbc
3cbe :3 0 d8 :2 0
f8 :4 0 2251 3cc0
3cc2 :3 0 d8 :2 0
f1 :3 0 2254 3cc4
3cc6 :3 0 d8 :2 0
f9 :4 0 2257 3cc8
3cca :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
225a 3ccd 3cd1 225e
3ccc 3cd3 :3 0 2261
3cb5 3cd5 :2 0 3cd7
2264 3cd8 3cb2 3cd7
0 3cd9 2266 0
3cda 2268 3cdd :3 0
3cdd 0 3cdd 3cdc
3cda 3cdb :6 0 3cdf
b6 :3 0 226b 3ce1
226d 3ce0 3cdf :2 0
3ce2 226f :2 0 3ce4
0 3ce4 3ce3 3c91
3ce2 :6 0 3d53 69
:3 0 d0 :3 0 d1
:3 0 3ce6 3ce7 0
d0 :3 0 e0 :3 0
3ce9 3cea 0 1d
:2 0 2 :4 0 2c7
:2 0 e2 :2 0 30
:2 0 2272 3cef 3cf1
:3 0 2275 3ceb 3cf3
3ce8 3cf5 3cf4 :2 0
d3 :3 0 e3 :3 0
3cf7 3cf8 0 d5
:4 0 2c8 :4 0 d8
:2 0 d9 :3 0 2279
3cfc 3cfe :3 0 d8
:2 0 f7 :4 0 227c
3d00 3d02 :3 0 d8
:2 0 fe :4 0 227f
3d04 3d06 :3 0 d8
:2 0 8f :3 0 dd
:3 0 75 :3 0 2282
3d0a 3d0c de :4 0
2284 3d09 3d0f 2287
3d08 3d11 :3 0 d8
:2 0 100 :4 0 228a
3d13 3d15 :3 0 d8
:2 0 db :4 0 228d
3d17 3d19 :3 0 d8
:2 0 28 :3 0 2290
3d1b 3d1d :3 0 d8
:2 0 db :4 0 2293
3d1f 3d21 :3 0 2296
3cf9 3d23 :2 0 3d25
2299 3d26 3cf6 3d25
0 3d27 229b 0
3d53 d0 :3 0 d1
:3 0 3d28 3d29 0
d0 :3 0 e0 :3 0
3d2b 3d2c 0 30
:2 0 2 :4 0 2c9
:2 0 e2 :2 0 30
:2 0 229d 3d31 3d33
:3 0 22a0 3d2d 3d35
3d2a 3d37 3d36 :2 0
d3 :3 0 e3 :3 0
3d39 3d3a 0 d5
:4 0 2ca :4 0 d8
:2 0 d9 :3 0 22a4
3d3e 3d40 :3 0 22a7
3d3b 3d42 :2 0 3d44
22aa 3d45 3d38 3d44
0 3d46 22ac 0
3d53 103 :3 0 104
:3 0 3d47 3d48 0
8f :3 0 75 :3 0
45 :2 0 22ae 3d4a
3d4d 28 :3 0 105
:3 0 22b1 3d49 3d51
:2 0 3d53 22b5 3d54
3c87 3d53 0 3d56
3bc2 3c7e 0 3d56
22ba 0 3d57 22bd
3ef8 8f :3 0 4d
:3 0 45 :2 0 22c1
3d58 3d5b e7 :2 0
45 :2 0 22c6 3d5d
3d5f :3 0 8f :3 0
88 :3 0 45 :2 0
22c9 3d61 3d64 14e
:2 0 2b1 :2 0 22ce
3d66 3d68 :3 0 3d60
3d6a 3d69 :2 0 8f
:3 0 88 :3 0 45
:2 0 22d1 3d6c 3d6f
14e :2 0 45 :2 0
22d6 3d71 3d73 :3 0
3d6b 3d75 3d74 :2 0
50 :3 0 ef :2 0
3d77 3d78 0 3d81
4d :3 0 8f :3 0
88 :3 0 45 :2 0
22d9 3d7b 3d7e 3d7a
3d7f 0 3d81 22dc
3d82 3d76 3d81 0
3d83 22df 0 3ef7
8f :3 0 52 :3 0
45 :2 0 22e1 3d84
3d87 e7 :2 0 45
:2 0 22e6 3d89 3d8b
:3 0 3d8c :2 0 8f
:3 0 52 :3 0 45
:2 0 22e9 3d8e 3d91
8f :3 0 211 :2 0
58 :3 0 45 :2 0
22ec 3d93 3d97 22f1
3d94 3d99 :3 0 3d9a
:2 0 3d8d 3d9c 3d9b
:2 0 52 :3 0 8f
:3 0 58 :3 0 45
:2 0 22f4 3d9f 3da2
3d9e 3da3 0 3da5
22f7 3db9 52 :3 0
29f :3 0 8f :3 0
52 :3 0 45 :2 0
22f9 3da8 3dab 2a1
:2 0 8f :3 0 58
:3 0 45 :2 0 22fc
3dae 3db1 22ff 3dad
3db3 :3 0 2302 3da7
3db5 3da6 3db6 0
3db8 2304 3dba 3d9d
3da5 0 3dbb 0
3db8 0 3dbb 2306
0 3ef7 8f :3 0
52 :3 0 45 :2 0
2309 3dbc 3dbf 211
:2 0 2cb :2 0 230e
3dc1 3dc3 :3 0 52
:3 0 8f :3 0 52
:3 0 45 :2 0 2311
3dc6 3dc9 1b0 :2 0
43 :2 0 2314 3dcb
3dcd :3 0 3dc5 3dce
0 3dd0 2317 3de3
52 :3 0 29f :3 0
2a0 :3 0 8f :3 0
52 :3 0 45 :2 0
2319 3dd4 3dd7 231c
3dd3 3dd9 1b0 :2 0
2cc :2 0 231e 3ddb
3ddd :3 0 2321 3dd2
3ddf 3dd1 3de0 0
3de2 2323 3de4 3dc4
3dd0 0 3de5 0
3de2 0 3de5 2325
0 3ef7 8f :3 0
70 :3 0 45 :2 0
2328 3de6 3de9 14e
:2 0 45 :2 0 232d
3deb 3ded :3 0 9d
:3 0 1f4 :3 0 1a1
:3 0 176 :3 0 1f4
:3 0 1a :3 0 1f5
:3 0 2b2 :3 0 2b2
:3 0 48 :3 0 a7
:3 0 22 :4 0 2b3
1 :8 0 3e11 ed
:4 0 3dfc :3 0 105
:3 0 e7 :2 0 2332
3dff 3e00 :3 0 15
:3 0 ee :3 0 3e02
3e03 0 45 :2 0
3e04 3e05 0 3e07
2335 3e0e 15 :3 0
ee :3 0 3e08 3e09
0 ef :2 0 3e0a
3e0b 0 3e0d 2337
3e0f 3e01 3e07 0
3e10 0 3e0d 0
3e10 2339 0 3e11
233c 3e64 f2 :3 0
15 :3 0 ee :3 0
3e13 3e14 0 f1
:3 0 3e15 3e16 0
3e18 233f 3e1a 2341
3e19 3e18 :2 0 3e62
f3 :3 0 15 :3 0
ee :3 0 3e1d 3e1e
0 f1 :3 0 3e1f
3e20 0 3e5a d0
:3 0 d1 :3 0 3e22
3e23 0 d0 :3 0
e0 :3 0 3e25 3e26
0 f4 :2 0 2
:4 0 2cd :2 0 e2
:2 0 30 :2 0 2343
3e2b 3e2d :3 0 2346
3e27 3e2f 3e24 3e31
3e30 :2 0 d3 :3 0
e3 :3 0 3e33 3e34
0 d5 :4 0 2ce
:4 0 d8 :2 0 d9
:3 0 234a 3e38 3e3a
:3 0 d8 :2 0 f7
:4 0 234d 3e3c 3e3e
:3 0 d8 :2 0 f8
:4 0 2350 3e40 3e42
:3 0 d8 :2 0 f1
:3 0 2353 3e44 3e46
:3 0 d8 :2 0 f9
:4 0 2356 3e48 3e4a
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2359
3e4d 3e51 235d 3e4c
3e53 :3 0 2360 3e35
3e55 :2 0 3e57 2363
3e58 3e32 3e57 0
3e59 2365 0 3e5a
2367 3e5d :3 0 3e5d
0 3e5d 3e5c 3e5a
3e5b :6 0 3e5f b8
:3 0 236a 3e61 236c
3e60 3e5f :2 0 3e62
236e :2 0 3e64 0
3e64 3e63 3e11 3e62
:6 0 3e66 69 :3 0
2371 3ef4 9d :3 0
9f :3 0 27 :3 0
a0 :3 0 a1 :3 0
55 :3 0 23 :3 0
b5 :3 0 6b :3 0
62 :3 0 b5 :3 0
1f0 :3 0 6b :3 0
65 :3 0 1f0 :3 0
b6 :3 0 6a :3 0
64 :3 0 b6 :3 0
1f1 :3 0 6a :3 0
66 :3 0 1f1 :3 0
1f4 :3 0 1a1 :3 0
176 :3 0 1f4 :3 0
1a :3 0 1f5 :3 0
2b2 :3 0 48 :3 0
a7 :3 0 22 :4 0
2cf 1 :8 0 3e9e
ed :4 0 3e89 :3 0
105 :3 0 e7 :2 0
2375 3e8c 3e8d :3 0
15 :3 0 ee :3 0
3e8f 3e90 0 45
:2 0 3e91 3e92 0
3e94 2378 3e9b 15
:3 0 ee :3 0 3e95
3e96 0 ef :2 0
3e97 3e98 0 3e9a
237a 3e9c 3e8e 3e94
0 3e9d 0 3e9a
0 3e9d 237c 0
3e9e 237f 3ef1 f2
:3 0 15 :3 0 ee
:3 0 3ea0 3ea1 0
f1 :3 0 3ea2 3ea3
0 3ea5 2382 3ea7
2384 3ea6 3ea5 :2 0
3eef f3 :3 0 15
:3 0 ee :3 0 3eaa
3eab 0 f1 :3 0
3eac 3ead 0 3ee7
d0 :3 0 d1 :3 0
3eaf 3eb0 0 d0
:3 0 e0 :3 0 3eb2
3eb3 0 f4 :2 0
2 :4 0 2d0 :2 0
e2 :2 0 30 :2 0
2386 3eb8 3eba :3 0
2389 3eb4 3ebc 3eb1
3ebe 3ebd :2 0 d3
:3 0 e3 :3 0 3ec0
3ec1 0 d5 :4 0
2d1 :4 0 d8 :2 0
d9 :3 0 238d 3ec5
3ec7 :3 0 d8 :2 0
f7 :4 0 2390 3ec9
3ecb :3 0 d8 :2 0
f8 :4 0 2393 3ecd
3ecf :3 0 d8 :2 0
f1 :3 0 2396 3ed1
3ed3 :3 0 d8 :2 0
f9 :4 0 2399 3ed5
3ed7 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
239c 3eda 3ede 23a0
3ed9 3ee0 :3 0 23a3
3ec2 3ee2 :2 0 3ee4
23a6 3ee5 3ebf 3ee4
0 3ee6 23a8 0
3ee7 23aa 3eea :3 0
3eea 0 3eea 3ee9
3ee7 3ee8 :6 0 3eec
ba :3 0 23ad 3eee
23af 3eed 3eec :2 0
3eef 23b1 :2 0 3ef1
0 3ef1 3ef0 3e9e
3eef :6 0 3ef3 69
:3 0 23b4 3ef5 3dee
3e66 0 3ef6 0
3ef3 0 3ef6 23b6
0 3ef7 23b9 3ef9
3896 3d57 0 3efa
0 3ef7 0 3efa
23be 0 4182 49
:3 0 45 :2 0 3efb
3efc 0 4182 8f
:3 0 5b :3 0 45
:2 0 23c1 3efe 3f01
1a :3 0 e7 :2 0
e9 :3 0 3f03 3f05
0 23c6 3f04 3f07
:3 0 5a :3 0 2d2
:2 0 3f09 3f0a 0
3f0c 23c9 3f11 5a
:3 0 30 :2 0 3f0d
3f0e 0 3f10 23cb
3f12 3f08 3f0c 0
3f13 0 3f10 0
3f13 23cd 0 4182
8f :3 0 4d :3 0
45 :2 0 23d0 3f14
3f17 e7 :2 0 45
:2 0 23d5 3f19 3f1b
:3 0 57 :3 0 1a
:3 0 210 :3 0 3f1e
3f1f 0 3f1d 3f20
0 3f22 23d8 3f33
57 :3 0 175 :3 0
176 :3 0 3f24 3f25
0 8f :3 0 57
:3 0 45 :2 0 23da
3f27 3f2a 1a :3 0
210 :3 0 3f2c 3f2d
0 23dd 3f26 3f2f
3f23 3f30 0 3f32
23e0 3f34 3f1c 3f22
0 3f35 0 3f32
0 3f35 23e2 0
4182 4e :3 0 45
:2 0 3f36 3f37 0
4182 8f :3 0 4d
:3 0 45 :2 0 23e5
3f39 3f3c 117 :2 0
45 :2 0 23ea 3f3e
3f40 :3 0 8f :3 0
50 :3 0 45 :2 0
23ed 3f42 3f45 e7
:2 0 ef :2 0 23f2
3f47 3f49 :3 0 75
:3 0 29f :3 0 8f
:3 0 58 :3 0 45
:2 0 23f5 3f4d 3f50
1b0 :2 0 8f :3 0
4d :3 0 45 :2 0
23f8 3f53 3f56 23fb
3f52 3f58 :3 0 3f59
:2 0 2a1 :2 0 2af
:2 0 23fe 3f5b 3f5d
:3 0 3f5e :2 0 e2
:2 0 2a2 :2 0 2401
3f60 3f62 :3 0 2404
3f4c 3f64 3f4b 3f65
0 3f9a 8f :3 0
44 :3 0 45 :2 0
2406 3f67 3f6a 8f
:3 0 211 :2 0 75
:3 0 45 :2 0 2409
3f6c 3f70 240e 3f6d
3f72 :3 0 75 :3 0
8f :3 0 44 :3 0
45 :2 0 2411 3f75
3f78 3f74 3f79 0
3f96 4d :3 0 29f
:3 0 8f :3 0 75
:3 0 45 :2 0 2414
3f7d 3f80 1b0 :2 0
2af :2 0 2417 3f82
3f84 :3 0 3f85 :2 0
2a1 :2 0 8f :3 0
58 :3 0 45 :2 0
241a 3f88 3f8b 241d
3f87 3f8d :3 0 e2
:2 0 2a2 :2 0 2420
3f8f 3f91 :3 0 2423
3f7c 3f93 3f7b 3f94
0 3f96 2425 3f97
3f73 3f96 0 3f98
2428 0 3f9a 15c
:3 0 242a 3fb1 8f
:3 0 44 :3 0 45
:2 0 242d 3f9b 3f9e
8f :3 0 211 :2 0
4d :3 0 45 :2 0
2430 3fa0 3fa4 2435
3fa1 3fa6 :3 0 4d
:3 0 8f :3 0 44
:3 0 45 :2 0 2438
3fa9 3fac 3fa8 3fad
0 3faf 243b 3fb0
3fa7 3faf 0 3fb2
3f4a 3f9a 0 3fb2
243d 0 3fb3 2440
3fb4 3f41 3fb3 0
3fb5 2442 0 4182
8c :3 0 220 :3 0
22 :3 0 28 :3 0
26 :3 0 27 :3 0
74 :3 0 4a :3 0
31 :3 0 31 :3 0
31 :3 0 31 :3 0
2a :3 0 2c :3 0
52 :3 0 48 :3 0
4d :3 0 4f :3 0
50 :3 0 49 :3 0
5b :3 0 36 :3 0
53 :3 0 57 :3 0
51 :3 0 4e :3 0
5a :3 0 58 :3 0
5c :3 0 1f :3 0
45 :2 0 45 :2 0
21f :2 0 21f :2 0
45 :2 0 2444 3fb7
3fd9 3fb6 3fda 0
4182 8c :3 0 e7
:2 0 221 :2 0 2468
3fdd 3fdf :3 0 f0
:3 0 a3 :4 0 3fe4
:2 0 3fea 3fe2 0
15 :3 0 ee :3 0
3fe5 3fe6 0 f1
:3 0 3fe7 3fe8 0
3fea 246b 403d f2
:3 0 15 :3 0 ee
:3 0 3fec 3fed 0
f1 :3 0 3fee 3fef
0 3ff1 246e 3ff3
2470 3ff2 3ff1 :2 0
403b f3 :3 0 15
:3 0 ee :3 0 3ff6
3ff7 0 f1 :3 0
3ff8 3ff9 0 4033
d0 :3 0 d1 :3 0
3ffb 3ffc 0 d0
:3 0 e0 :3 0 3ffe
3fff 0 f4 :2 0
2 :4 0 2d3 :2 0
e2 :2 0 30 :2 0
2472 4004 4006 :3 0
2475 4000 4008 3ffd
400a 4009 :2 0 d3
:3 0 e3 :3 0 400c
400d 0 d5 :4 0
2d4 :4 0 d8 :2 0
d9 :3 0 2479 4011
4013 :3 0 d8 :2 0
f7 :4 0 247c 4015
4017 :3 0 d8 :2 0
f8 :4 0 247f 4019
401b :3 0 d8 :2 0
f1 :3 0 2482 401d
401f :3 0 d8 :2 0
f9 :4 0 2485 4021
4023 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2488 4026 402a 248c
4025 402c :3 0 248f
400e 402e :2 0 4030
2492 4031 400b 4030
0 4032 2494 0
4033 2496 4036 :3 0
4036 0 4036 4035
4033 4034 :6 0 4038
bc :3 0 2499 403a
249b 4039 4038 :2 0
403b 249d :2 0 403d
0 403d 403c 3fea
403b :6 0 40ad 69
:3 0 d0 :3 0 d1
:3 0 403f 4040 0
d0 :3 0 e0 :3 0
4042 4043 0 1d
:2 0 2 :4 0 2d5
:2 0 e2 :2 0 30
:2 0 24a0 4048 404a
:3 0 24a3 4044 404c
4041 404e 404d :2 0
d3 :3 0 e3 :3 0
4050 4051 0 d5
:4 0 2d6 :4 0 d8
:2 0 d9 :3 0 24a7
4055 4057 :3 0 d8
:2 0 f7 :4 0 24aa
4059 405b :3 0 d8
:2 0 fe :4 0 24ad
405d 405f :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 224
:3 0 4064 4065 0
24b0 4063 4067 de
:4 0 24b2 4062 406a
24b5 4061 406c :3 0
d8 :2 0 100 :4 0
24b8 406e 4070 :3 0
d8 :2 0 db :4 0
24bb 4072 4074 :3 0
d8 :2 0 27 :3 0
24be 4076 4078 :3 0
d8 :2 0 db :4 0
24c1 407a 407c :3 0
24c4 4052 407e :2 0
4080 24c7 4081 404f
4080 0 4082 24c9
0 40ad d0 :3 0
d1 :3 0 4083 4084
0 d0 :3 0 e0
:3 0 4086 4087 0
30 :2 0 2 :4 0
2d7 :2 0 e2 :2 0
30 :2 0 24cb 408c
408e :3 0 24ce 4088
4090 4085 4092 4091
:2 0 d3 :3 0 e3
:3 0 4094 4095 0
d5 :4 0 2d8 :4 0
d8 :2 0 d9 :3 0
24d2 4099 409b :3 0
24d5 4096 409d :2 0
409f 24d8 40a0 4093
409f 0 40a1 24da
0 40ad 103 :3 0
104 :3 0 40a2 40a3
0 1a :3 0 224
:3 0 40a5 40a6 0
27 :3 0 105 :3 0
24dc 40a4 40aa :2 0
40ad 15c :3 0 24e0
4180 8c :3 0 14e
:2 0 45 :2 0 24e7
40af 40b1 :3 0 f0
:3 0 a3 :4 0 40b6
:2 0 40bc 40b4 0
15 :3 0 ee :3 0
40b7 40b8 0 f1
:3 0 40b9 40ba 0
40bc 24ea 410f f2
:3 0 15 :3 0 ee
:3 0 40be 40bf 0
f1 :3 0 40c0 40c1
0 40c3 24ed 40c5
24ef 40c4 40c3 :2 0
410d f3 :3 0 15
:3 0 ee :3 0 40c8
40c9 0 f1 :3 0
40ca 40cb 0 4105
d0 :3 0 d1 :3 0
40cd 40ce 0 d0
:3 0 e0 :3 0 40d0
40d1 0 f4 :2 0
2 :4 0 2d9 :2 0
e2 :2 0 30 :2 0
24f1 40d6 40d8 :3 0
24f4 40d2 40da 40cf
40dc 40db :2 0 d3
:3 0 e3 :3 0 40de
40df 0 d5 :4 0
2da :4 0 d8 :2 0
d9 :3 0 24f8 40e3
40e5 :3 0 d8 :2 0
f7 :4 0 24fb 40e7
40e9 :3 0 d8 :2 0
f8 :4 0 24fe 40eb
40ed :3 0 d8 :2 0
f1 :3 0 2501 40ef
40f1 :3 0 d8 :2 0
f9 :4 0 2504 40f3
40f5 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2507 40f8 40fc 250b
40f7 40fe :3 0 250e
40e0 4100 :2 0 4102
2511 4103 40dd 4102
0 4104 2513 0
4105 2515 4108 :3 0
4108 0 4108 4107
4105 4106 :6 0 410a
be :3 0 2518 410c
251a 410b 410a :2 0
410d 251c :2 0 410f
0 410f 410e 40bc
410d :6 0 417e 69
:3 0 d0 :3 0 d1
:3 0 4111 4112 0
d0 :3 0 e0 :3 0
4114 4115 0 1d
:2 0 2 :4 0 2db
:2 0 e2 :2 0 30
:2 0 251f 411a 411c
:3 0 2522 4116 411e
4113 4120 411f :2 0
d3 :3 0 e3 :3 0
4122 4123 0 d5
:4 0 2dc :4 0 d8
:2 0 d9 :3 0 2526
4127 4129 :3 0 d8
:2 0 f7 :4 0 2529
412b 412d :3 0 d8
:2 0 fe :4 0 252c
412f 4131 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 1c6
:3 0 4136 4137 0
252f 4135 4139 de
:4 0 2531 4134 413c
2534 4133 413e :3 0
d8 :2 0 100 :4 0
2537 4140 4142 :3 0
d8 :2 0 db :4 0
253a 4144 4146 :3 0
d8 :2 0 21 :3 0
253d 4148 414a :3 0
d8 :2 0 db :4 0
2540 414c 414e :3 0
2543 4124 4150 :2 0
4152 2546 4153 4121
4152 0 4154 2548
0 417e d0 :3 0
d1 :3 0 4155 4156
0 d0 :3 0 e0
:3 0 4158 4159 0
30 :2 0 2 :4 0
2dd :2 0 e2 :2 0
30 :2 0 254a 415e
4160 :3 0 254d 415a
4162 4157 4164 4163
:2 0 d3 :3 0 e3
:3 0 4166 4167 0
d5 :4 0 2de :4 0
d8 :2 0 d9 :3 0
2551 416b 416d :3 0
2554 4168 416f :2 0
4171 2557 4172 4165
4171 0 4173 2559
0 417e 103 :3 0
104 :3 0 4174 4175
0 1a :3 0 1c6
:3 0 4177 4178 0
21 :3 0 105 :3 0
255b 4176 417c :2 0
417e 255f 417f 40b2
417e 0 4181 3fe0
40ad 0 4181 2564
0 4182 2567 4184
348d 388e 0 4185
0 4182 0 4185
2571 0 4638 bc
:3 0 186 :3 0 187
:3 0 186 :3 0 41
:3 0 99 :3 0 26
:4 0 2df 1 :8 0
41a3 ed :4 0 418e
:3 0 105 :3 0 e7
:2 0 2576 4191 4192
:3 0 15 :3 0 ee
:3 0 4194 4195 0
45 :2 0 4196 4197
0 4199 2579 41a0
15 :3 0 ee :3 0
419a 419b 0 ef
:2 0 419c 419d 0
419f 257b 41a1 4193
4199 0 41a2 0
419f 0 41a2 257d
0 41a3 2580 41f6
f2 :3 0 15 :3 0
ee :3 0 41a5 41a6
0 f1 :3 0 41a7
41a8 0 41aa 2583
41ac 2585 41ab 41aa
:2 0 41f4 f3 :3 0
15 :3 0 ee :3 0
41af 41b0 0 f1
:3 0 41b1 41b2 0
41ec d0 :3 0 d1
:3 0 41b4 41b5 0
d0 :3 0 e0 :3 0
41b7 41b8 0 f4
:2 0 2 :4 0 2e0
:2 0 e2 :2 0 30
:2 0 2587 41bd 41bf
:3 0 258a 41b9 41c1
41b6 41c3 41c2 :2 0
d3 :3 0 e3 :3 0
41c5 41c6 0 d5
:4 0 2e1 :4 0 d8
:2 0 d9 :3 0 258e
41ca 41cc :3 0 d8
:2 0 f7 :4 0 2591
41ce 41d0 :3 0 d8
:2 0 f8 :4 0 2594
41d2 41d4 :3 0 d8
:2 0 f1 :3 0 2597
41d6 41d8 :3 0 d8
:2 0 f9 :4 0 259a
41da 41dc :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 259d 41df 41e3
25a1 41de 41e5 :3 0
25a4 41c7 41e7 :2 0
41e9 25a7 41ea 41c4
41e9 0 41eb 25a9
0 41ec 25ab 41ef
:3 0 41ef 0 41ef
41ee 41ec 41ed :6 0
41f1 c0 :3 0 25ae
41f3 25b0 41f2 41f1
:2 0 41f4 25b2 :2 0
41f6 0 41f6 41f5
41a3 41f4 :6 0 4638
69 :3 0 243 :3 0
22 :3 0 2e2 :3 0
99 :3 0 2e2 :3 0
2e3 :3 0 2e2 :3 0
2e4 :3 0 2e2 :3 0
2e5 :3 0 2e2 :3 0
2e6 :3 0 2e7 :3 0
2e2 :3 0 127 :3 0
13b :3 0 2e8 :3 0
2e2 :3 0 99 :3 0
2e8 :3 0 13a :3 0
2e8 :3 0 13c :3 0
29 :4 0 2e9 1
:8 0 4226 ed :4 0
4211 :3 0 105 :3 0
e7 :2 0 25b7 4214
4215 :3 0 15 :3 0
ee :3 0 4217 4218
0 45 :2 0 4219
421a 0 421c 25ba
4223 15 :3 0 ee
:3 0 421d 421e 0
ef :2 0 421f 4220
0 4222 25bc 4224
4216 421c 0 4225
0 4222 0 4225
25be 0 4226 25c1
4279 f2 :3 0 15
:3 0 ee :3 0 4228
4229 0 f1 :3 0
422a 422b 0 422d
25c4 422f 25c6 422e
422d :2 0 4277 f3
:3 0 15 :3 0 ee
:3 0 4232 4233 0
f1 :3 0 4234 4235
0 426f d0 :3 0
d1 :3 0 4237 4238
0 d0 :3 0 e0
:3 0 423a 423b 0
f4 :2 0 2 :4 0
2ea :2 0 e2 :2 0
30 :2 0 25c8 4240
4242 :3 0 25cb 423c
4244 4239 4246 4245
:2 0 d3 :3 0 e3
:3 0 4248 4249 0
d5 :4 0 2eb :4 0
d8 :2 0 d9 :3 0
25cf 424d 424f :3 0
d8 :2 0 f7 :4 0
25d2 4251 4253 :3 0
d8 :2 0 f8 :4 0
25d5 4255 4257 :3 0
d8 :2 0 f1 :3 0
25d8 4259 425b :3 0
d8 :2 0 f9 :4 0
25db 425d 425f :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 25de 4262
4266 25e2 4261 4268
:3 0 25e5 424a 426a
:2 0 426c 25e8 426d
4247 426c 0 426e
25ea 0 426f 25ec
4272 :3 0 4272 0
4272 4271 426f 4270
:6 0 4274 c2 :3 0
25ef 4276 25f1 4275
4274 :2 0 4277 25f3
:2 0 4279 0 4279
4278 4226 4277 :6 0
4638 69 :3 0 243
:3 0 22 :3 0 13a
:3 0 2e3 :3 0 2e4
:3 0 2e5 :3 0 2e6
:3 0 2ec :3 0 243
:3 0 a5 :3 0 29
:4 0 2ed 1 :8 0
429c ed :4 0 4287
:3 0 105 :3 0 e7
:2 0 25f8 428a 428b
:3 0 15 :3 0 ee
:3 0 428d 428e 0
45 :2 0 428f 4290
0 4292 25fb 4299
15 :3 0 ee :3 0
4293 4294 0 ef
:2 0 4295 4296 0
4298 25fd 429a 428c
4292 0 429b 0
4298 0 429b 25ff
0 429c 2602 42ef
f2 :3 0 15 :3 0
ee :3 0 429e 429f
0 f1 :3 0 42a0
42a1 0 42a3 2605
42a5 2607 42a4 42a3
:2 0 42ed f3 :3 0
15 :3 0 ee :3 0
42a8 42a9 0 f1
:3 0 42aa 42ab 0
42e5 d0 :3 0 d1
:3 0 42ad 42ae 0
d0 :3 0 e0 :3 0
42b0 42b1 0 f4
:2 0 2 :4 0 2ee
:2 0 e2 :2 0 30
:2 0 2609 42b6 42b8
:3 0 260c 42b2 42ba
42af 42bc 42bb :2 0
d3 :3 0 e3 :3 0
42be 42bf 0 d5
:4 0 2ef :4 0 d8
:2 0 d9 :3 0 2610
42c3 42c5 :3 0 d8
:2 0 f7 :4 0 2613
42c7 42c9 :3 0 d8
:2 0 f8 :4 0 2616
42cb 42cd :3 0 d8
:2 0 f1 :3 0 2619
42cf 42d1 :3 0 d8
:2 0 f9 :4 0 261c
42d3 42d5 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 261f 42d8 42dc
2623 42d7 42de :3 0
2626 42c0 42e0 :2 0
42e2 2629 42e3 42bd
42e2 0 42e4 262b
0 42e5 262d 42e8
:3 0 42e8 0 42e8
42e7 42e5 42e6 :6 0
42ea c4 :3 0 2630
42ec 2632 42eb 42ea
:2 0 42ed 2634 :2 0
42ef 0 42ef 42ee
429c 42ed :6 0 4638
69 :3 0 247 :3 0
22 :3 0 2f0 :3 0
2e3 :3 0 2e4 :3 0
2e5 :3 0 2e6 :3 0
2f1 :3 0 247 :3 0
a5 :3 0 29 :4 0
2f2 1 :8 0 4312
ed :4 0 42fd :3 0
105 :3 0 e7 :2 0
2639 4300 4301 :3 0
15 :3 0 ee :3 0
4303 4304 0 45
:2 0 4305 4306 0
4308 263c 430f 15
:3 0 ee :3 0 4309
430a 0 ef :2 0
430b 430c 0 430e
263e 4310 4302 4308
0 4311 0 430e
0 4311 2640 0
4312 2643 4365 f2
:3 0 15 :3 0 ee
:3 0 4314 4315 0
f1 :3 0 4316 4317
0 4319 2646 431b
2648 431a 4319 :2 0
4363 f3 :3 0 15
:3 0 ee :3 0 431e
431f 0 f1 :3 0
4320 4321 0 435b
d0 :3 0 d1 :3 0
4323 4324 0 d0
:3 0 e0 :3 0 4326
4327 0 f4 :2 0
2 :4 0 2f3 :2 0
e2 :2 0 30 :2 0
264a 432c 432e :3 0
264d 4328 4330 4325
4332 4331 :2 0 d3
:3 0 e3 :3 0 4334
4335 0 d5 :4 0
2f4 :4 0 d8 :2 0
d9 :3 0 2651 4339
433b :3 0 d8 :2 0
f7 :4 0 2654 433d
433f :3 0 d8 :2 0
f8 :4 0 2657 4341
4343 :3 0 d8 :2 0
f1 :3 0 265a 4345
4347 :3 0 d8 :2 0
f9 :4 0 265d 4349
434b :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2660 434e 4352 2664
434d 4354 :3 0 2667
4336 4356 :2 0 4358
266a 4359 4333 4358
0 435a 266c 0
435b 266e 435e :3 0
435e 0 435e 435d
435b 435c :6 0 4360
c6 :3 0 2671 4362
2673 4361 4360 :2 0
4363 2675 :2 0 4365
0 4365 4364 4312
4363 :6 0 4638 69
:3 0 54 :3 0 8f
:3 0 54 :3 0 45
:2 0 2678 4368 436b
e2 :2 0 30 :2 0
267b 436d 436f :3 0
4367 4370 0 4638
4c :3 0 8f :3 0
4c :3 0 45 :2 0
267e 4373 4376 e2
:2 0 8f :3 0 48
:3 0 45 :2 0 2681
4379 437c 2684 4378
437e :3 0 4372 437f
0 4638 76 :3 0
30 :4 0 4381 4382
0 4638 7b :3 0
2f5 :3 0 28 :3 0
29 :3 0 76 :3 0
2687 4385 4389 4384
438a 0 4638 76
:3 0 45 :4 0 438c
438d 0 4638 7b
:3 0 2f5 :3 0 28
:3 0 27 :3 0 76
:3 0 268b 4390 4394
438f 4395 0 4638
23c :3 0 9f :3 0
27 :3 0 9e :3 0
28 :3 0 a7 :3 0
22 :4 0 2f6 1
:8 0 43b4 ed :4 0
439f :3 0 105 :3 0
e7 :2 0 2691 43a2
43a3 :3 0 15 :3 0
ee :3 0 43a5 43a6
0 45 :2 0 43a7
43a8 0 43aa 2694
43b1 15 :3 0 ee
:3 0 43ab 43ac 0
ef :2 0 43ad 43ae
0 43b0 2696 43b2
43a4 43aa 0 43b3
0 43b0 0 43b3
2698 0 43b4 269b
4407 f2 :3 0 15
:3 0 ee :3 0 43b6
43b7 0 f1 :3 0
43b8 43b9 0 43bb
269e 43bd 26a0 43bc
43bb :2 0 4405 f3
:3 0 15 :3 0 ee
:3 0 43c0 43c1 0
f1 :3 0 43c2 43c3
0 43fd d0 :3 0
d1 :3 0 43c5 43c6
0 d0 :3 0 e0
:3 0 43c8 43c9 0
f4 :2 0 2 :4 0
2f7 :2 0 e2 :2 0
30 :2 0 26a2 43ce
43d0 :3 0 26a5 43ca
43d2 43c7 43d4 43d3
:2 0 d3 :3 0 e3
:3 0 43d6 43d7 0
d5 :4 0 2f8 :4 0
d8 :2 0 d9 :3 0
26a9 43db 43dd :3 0
d8 :2 0 f7 :4 0
26ac 43df 43e1 :3 0
d8 :2 0 f8 :4 0
26af 43e3 43e5 :3 0
d8 :2 0 f1 :3 0
26b2 43e7 43e9 :3 0
d8 :2 0 f9 :4 0
26b5 43eb 43ed :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 26b8 43f0
43f4 26bc 43ef 43f6
:3 0 26bf 43d8 43f8
:2 0 43fa 26c2 43fb
43d5 43fa 0 43fc
26c4 0 43fd 26c6
4400 :3 0 4400 0
4400 43ff 43fd 43fe
:6 0 4402 c8 :3 0
26c9 4404 26cb 4403
4402 :2 0 4405 26cd
:2 0 4407 0 4407
4406 43b4 4405 :6 0
4638 69 :3 0 8f
:3 0 6b :3 0 45
:2 0 26d0 4409 440c
e7 :2 0 45 :2 0
26d5 440e 4410 :3 0
4411 :2 0 8f :3 0
6a :3 0 45 :2 0
26d8 4413 4416 e7
:2 0 45 :2 0 26dd
4418 441a :3 0 441b
:2 0 4412 441d 441c
:2 0 24b :3 0 9f
:3 0 27 :3 0 2f9
:3 0 62 :3 0 2fa
:3 0 65 :3 0 2fb
:3 0 64 :3 0 2fc
:3 0 66 :3 0 17d
:3 0 1f :3 0 17e
:3 0 d9 :3 0 a7
:3 0 1c :4 0 2fd
1 :8 0 4446 ed
:4 0 4431 :3 0 105
:3 0 e7 :2 0 26e2
4434 4435 :3 0 15
:3 0 ee :3 0 4437
4438 0 45 :2 0
4439 443a 0 443c
26e5 4443 15 :3 0
ee :3 0 443d 443e
0 ef :2 0 443f
4440 0 4442 26e7
4444 4436 443c 0
4445 0 4442 0
4445 26e9 0 4446
26ec 4499 f2 :3 0
15 :3 0 ee :3 0
4448 4449 0 f1
:3 0 444a 444b 0
444d 26ef 444f 26f1
444e 444d :2 0 4497
f3 :3 0 15 :3 0
ee :3 0 4452 4453
0 f1 :3 0 4454
4455 0 448f d0
:3 0 d1 :3 0 4457
4458 0 d0 :3 0
e0 :3 0 445a 445b
0 f4 :2 0 2
:4 0 2fe :2 0 e2
:2 0 30 :2 0 26f3
4460 4462 :3 0 26f6
445c 4464 4459 4466
4465 :2 0 d3 :3 0
e3 :3 0 4468 4469
0 d5 :4 0 2ff
:4 0 d8 :2 0 d9
:3 0 26fa 446d 446f
:3 0 d8 :2 0 f7
:4 0 26fd 4471 4473
:3 0 d8 :2 0 f8
:4 0 2700 4475 4477
:3 0 d8 :2 0 f1
:3 0 2703 4479 447b
:3 0 d8 :2 0 f9
:4 0 2706 447d 447f
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2709
4482 4486 270d 4481
4488 :3 0 2710 446a
448a :2 0 448c 2713
448d 4467 448c 0
448e 2715 0 448f
2717 4492 :3 0 4492
0 4492 4491 448f
4490 :6 0 4494 ca
:3 0 271a 4496 271c
4495 4494 :2 0 4497
271e :2 0 4499 0
4499 4498 4446 4497
:6 0 449c 69 :3 0
15c :3 0 2721 4635
8f :3 0 6b :3 0
45 :2 0 2723 449d
44a0 e7 :2 0 45
:2 0 2728 44a2 44a4
:3 0 24b :3 0 9f
:3 0 27 :3 0 2f9
:3 0 62 :3 0 2fa
:3 0 65 :3 0 17d
:3 0 1f :3 0 17e
:3 0 d9 :3 0 a7
:3 0 1c :4 0 300
1 :8 0 44c9 ed
:4 0 44b4 :3 0 105
:3 0 e7 :2 0 272d
44b7 44b8 :3 0 15
:3 0 ee :3 0 44ba
44bb 0 45 :2 0
44bc 44bd 0 44bf
2730 44c6 15 :3 0
ee :3 0 44c0 44c1
0 ef :2 0 44c2
44c3 0 44c5 2732
44c7 44b9 44bf 0
44c8 0 44c5 0
44c8 2734 0 44c9
2737 451c f2 :3 0
15 :3 0 ee :3 0
44cb 44cc 0 f1
:3 0 44cd 44ce 0
44d0 273a 44d2 273c
44d1 44d0 :2 0 451a
f3 :3 0 15 :3 0
ee :3 0 44d5 44d6
0 f1 :3 0 44d7
44d8 0 4512 d0
:3 0 d1 :3 0 44da
44db 0 d0 :3 0
e0 :3 0 44dd 44de
0 f4 :2 0 2
:4 0 301 :2 0 e2
:2 0 30 :2 0 273e
44e3 44e5 :3 0 2741
44df 44e7 44dc 44e9
44e8 :2 0 d3 :3 0
e3 :3 0 44eb 44ec
0 d5 :4 0 302
:4 0 d8 :2 0 d9
:3 0 2745 44f0 44f2
:3 0 d8 :2 0 f7
:4 0 2748 44f4 44f6
:3 0 d8 :2 0 f8
:4 0 274b 44f8 44fa
:3 0 d8 :2 0 f1
:3 0 274e 44fc 44fe
:3 0 d8 :2 0 f9
:4 0 2751 4500 4502
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2754
4505 4509 2758 4504
450b :3 0 275b 44ed
450d :2 0 450f 275e
4510 44ea 450f 0
4511 2760 0 4512
2762 4515 :3 0 4515
0 4515 4514 4512
4513 :6 0 4517 cc
:3 0 2765 4519 2767
4518 4517 :2 0 451a
2769 :2 0 451c 0
451c 451b 44c9 451a
:6 0 4526 69 :3 0
64 :3 0 8f :3 0
7f :3 0 45 :2 0
276c 451f 4522 451e
4523 0 4526 15c
:3 0 276f 4527 44a5
4526 0 4637 8f
:3 0 6a :3 0 45
:2 0 2772 4528 452b
e7 :2 0 45 :2 0
2777 452d 452f :3 0
24b :3 0 9f :3 0
27 :3 0 2fb :3 0
64 :3 0 2fc :3 0
66 :3 0 17d :3 0
1f :3 0 17e :3 0
d9 :3 0 a7 :3 0
1c :4 0 303 1
:8 0 4554 ed :4 0
453f :3 0 105 :3 0
e7 :2 0 277c 4542
4543 :3 0 15 :3 0
ee :3 0 4545 4546
0 45 :2 0 4547
4548 0 454a 277f
4551 15 :3 0 ee
:3 0 454b 454c 0
ef :2 0 454d 454e
0 4550 2781 4552
4544 454a 0 4553
0 4550 0 4553
2783 0 4554 2786
45a7 f2 :3 0 15
:3 0 ee :3 0 4556
4557 0 f1 :3 0
4558 4559 0 455b
2789 455d 278b 455c
455b :2 0 45a5 f3
:3 0 15 :3 0 ee
:3 0 4560 4561 0
f1 :3 0 4562 4563
0 459d d0 :3 0
d1 :3 0 4565 4566
0 d0 :3 0 e0
:3 0 4568 4569 0
f4 :2 0 2 :4 0
304 :2 0 e2 :2 0
30 :2 0 278d 456e
4570 :3 0 2790 456a
4572 4567 4574 4573
:2 0 d3 :3 0 e3
:3 0 4576 4577 0
d5 :4 0 305 :4 0
d8 :2 0 d9 :3 0
2794 457b 457d :3 0
d8 :2 0 f7 :4 0
2797 457f 4581 :3 0
d8 :2 0 f8 :4 0
279a 4583 4585 :3 0
d8 :2 0 f1 :3 0
279d 4587 4589 :3 0
d8 :2 0 f9 :4 0
27a0 458b 458d :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 27a3 4590
4594 27a7 458f 4596
:3 0 27aa 4578 4598
:2 0 459a 27ad 459b
4575 459a 0 459c
27af 0 459d 27b1
45a0 :3 0 45a0 0
45a0 459f 459d 459e
:6 0 45a2 ce :3 0
27b4 45a4 27b6 45a3
45a2 :2 0 45a5 27b8
:2 0 45a7 0 45a7
45a6 4554 45a5 :6 0
45b0 69 :3 0 62
:3 0 8f :3 0 7e
:3 0 45 :2 0 27bb
45aa 45ad 45a9 45ae
0 45b0 27be 45b1
4530 45b0 0 4637
24b :3 0 9f :3 0
27 :3 0 17d :3 0
1f :3 0 17e :3 0
d9 :3 0 a7 :3 0
1c :4 0 306 1
:8 0 45d1 ed :4 0
45bc :3 0 105 :3 0
e7 :2 0 27c3 45bf
45c0 :3 0 15 :3 0
ee :3 0 45c2 45c3
0 45 :2 0 45c4
45c5 0 45c7 27c6
45ce 15 :3 0 ee
:3 0 45c8 45c9 0
ef :2 0 45ca 45cb
0 45cd 27c8 45cf
45c1 45c7 0 45d0
0 45cd 0 45d0
27ca 0 45d1 27cd
4624 f2 :3 0 15
:3 0 ee :3 0 45d3
45d4 0 f1 :3 0
45d5 45d6 0 45d8
27d0 45da 27d2 45d9
45d8 :2 0 4622 f3
:3 0 15 :3 0 ee
:3 0 45dd 45de 0
f1 :3 0 45df 45e0
0 461a d0 :3 0
d1 :3 0 45e2 45e3
0 d0 :3 0 e0
:3 0 45e5 45e6 0
f4 :2 0 2 :4 0
307 :2 0 e2 :2 0
30 :2 0 27d4 45eb
45ed :3 0 27d7 45e7
45ef 45e4 45f1 45f0
:2 0 d3 :3 0 e3
:3 0 45f3 45f4 0
d5 :4 0 308 :4 0
d8 :2 0 d9 :3 0
27db 45f8 45fa :3 0
d8 :2 0 f7 :4 0
27de 45fc 45fe :3 0
d8 :2 0 f8 :4 0
27e1 4600 4602 :3 0
d8 :2 0 f1 :3 0
27e4 4604 4606 :3 0
d8 :2 0 f9 :4 0
27e7 4608 460a :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 27ea 460d
4611 27ee 460c 4613
:3 0 27f1 45f5 4615
:2 0 4617 27f4 4618
45f2 4617 0 4619
27f6 0 461a 27f8
461d :3 0 461d 0
461d 461c 461a 461b
:6 0 461f d0 :3 0
27fb 4621 27fd 4620
461f :2 0 4622 27ff
:2 0 4624 0 4624
4623 45d1 4622 :6 0
4634 69 :3 0 62
:3 0 8f :3 0 7e
:3 0 45 :2 0 2802
4627 462a 4626 462b
0 4634 64 :3 0
8f :3 0 7f :3 0
45 :2 0 2805 462e
4631 462d 4632 0
4634 2808 4636 441e
449c 0 4637 0
4634 0 4637 280c
0 4638 2811 4639
3291 4638 0 463a
2820 0 463b 2822
463d 278d 2a2b 0
463e 0 463b 0
463e 282a 0 464d
15 :3 0 ee :3 0
463f 4640 0 309
:3 0 28 :3 0 29
:3 0 1f :3 0 282d
4642 4646 4641 4647
0 464d 29b :5 0
464b d2 0 464c
2831 464b 464a 464d
2833 464f 233 :4 0
464d :4 0 51ec f0
:3 0 a3 :4 0 4653
:2 0 4659 4651 0
15 :3 0 ee :3 0
4654 4655 0 f1
:3 0 4656 4657 0
4659 283b 46ac f2
:3 0 15 :3 0 ee
:3 0 465b 465c 0
f1 :3 0 465d 465e
0 4660 283e 4662
2840 4661 4660 :2 0
46aa f3 :3 0 15
:3 0 ee :3 0 4665
4666 0 f1 :3 0
4667 4668 0 46a2
d0 :3 0 d1 :3 0
466a 466b 0 d0
:3 0 e0 :3 0 466d
466e 0 f4 :2 0
2 :4 0 30a :2 0
e2 :2 0 30 :2 0
2842 4673 4675 :3 0
2845 466f 4677 466c
4679 4678 :2 0 d3
:3 0 e3 :3 0 467b
467c 0 d5 :4 0
30b :4 0 d8 :2 0
d9 :3 0 2849 4680
4682 :3 0 d8 :2 0
f7 :4 0 284c 4684
4686 :3 0 d8 :2 0
f8 :4 0 284f 4688
468a :3 0 d8 :2 0
f1 :3 0 2852 468c
468e :3 0 d8 :2 0
f9 :4 0 2855 4690
4692 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2858 4695 4699 285c
4694 469b :3 0 285f
467d 469d :2 0 469f
2862 46a0 467a 469f
0 46a1 2864 0
46a2 2866 46a5 :3 0
46a5 0 46a5 46a4
46a2 46a3 :6 0 46a7
d2 :3 0 2869 46a9
286b 46a8 46a7 :2 0
46aa 286d :2 0 46ac
0 46ac 46ab 4659
46aa :6 0 51ec 1
:3 0 5f :3 0 45
:2 0 46ae 46af 0
51ec 8f :3 0 54
:3 0 45 :2 0 2870
46b1 46b4 117 :2 0
45 :2 0 2875 46b6
46b8 :3 0 48 :3 0
9 :3 0 46ba 46bb
0 4c15 8f :3 0
48 :3 0 45 :2 0
2878 46bd 46c0 8f
:3 0 30c :2 0 4c
:3 0 45 :2 0 287b
46c2 46c6 2880 46c3
46c8 :3 0 48 :3 0
8f :3 0 48 :3 0
45 :2 0 2883 46cb
46ce 1c1 :2 0 8f
:3 0 4c :3 0 45
:2 0 2886 46d1 46d4
2889 46d0 46d6 :3 0
46ca 46d7 0 4aa4
8f :3 0 48 :3 0
45 :2 0 288c 46d9
46dc 117 :2 0 45
:2 0 2891 46de 46e0
:3 0 46e1 :2 0 8f
:3 0 55 :3 0 45
:2 0 2894 46e3 46e6
117 :2 0 45 :2 0
2899 46e8 46ea :3 0
46eb :2 0 46e2 46ed
46ec :2 0 23 :3 0
1bd :2 0 289c 46f0
46f1 :3 0 46f2 :2 0
46f3 :2 0 46ee 46f5
46f4 :2 0 2a :3 0
7 :3 0 46f7 46f8
0 4aa0 2c :3 0
8 :3 0 46fa 46fb
0 4aa0 4d :3 0
b :3 0 46fd 46fe
0 4aa0 4e :3 0
10 :3 0 4700 4701
0 4aa0 4f :3 0
d :3 0 4703 4704
0 4aa0 50 :3 0
e :3 0 4706 4707
0 4aa0 57 :3 0
c :3 0 4709 470a
0 4aa0 51 :3 0
f :3 0 470c 470d
0 4aa0 8f :3 0
51 :3 0 45 :2 0
289e 470f 4712 e7
:2 0 45 :2 0 28a3
4714 4716 :3 0 4717
:2 0 8f :3 0 50
:3 0 45 :2 0 28a6
4719 471c 14e :2 0
ef :2 0 28ab 471e
4720 :3 0 4721 :2 0
4718 4723 4722 :2 0
4d :3 0 45 :2 0
4725 4726 0 4729
15c :3 0 28ae 473c
8f :3 0 50 :3 0
45 :2 0 28b0 472a
472d e7 :2 0 ef
:2 0 28b5 472f 4731
:3 0 88 :3 0 8f
:3 0 4d :3 0 45
:2 0 28b8 4734 4737
4733 4738 0 473a
28bb 473b 4732 473a
0 473d 4724 4729
0 473d 28bd 0
4aa0 75 :3 0 213
:3 0 39 :3 0 3a
:3 0 8f :3 0 4f
:3 0 45 :2 0 28c0
4742 4745 8f :3 0
50 :3 0 45 :2 0
28c3 4747 474a 8f
:3 0 5b :3 0 45
:2 0 28c6 474c 474f
8f :3 0 57 :3 0
45 :2 0 28c9 4751
4754 8f :3 0 51
:3 0 45 :2 0 28cc
4756 4759 8f :3 0
4e :3 0 45 :2 0
28cf 475b 475e 8f
:3 0 58 :3 0 45
:2 0 28d2 4760 4763
8f :3 0 59 :3 0
45 :2 0 28d5 4765
4768 4d :3 0 48
:3 0 52 :3 0 28d8
473f 476d 473e 476e
0 4aa0 8f :3 0
75 :3 0 45 :2 0
28e6 4770 4773 1a
:3 0 e7 :2 0 214
:3 0 4775 4777 0
28eb 4776 4779 :3 0
d0 :3 0 d1 :3 0
477b 477c 0 d0
:3 0 e0 :3 0 477e
477f 0 215 :2 0
2 :4 0 30d :2 0
e2 :2 0 30 :2 0
28ee 4784 4786 :3 0
28f1 4780 4788 477d
478a 4789 :2 0 d3
:3 0 e3 :3 0 478c
478d 0 d5 :4 0
30e :4 0 d8 :2 0
d9 :3 0 28f5 4791
4793 :3 0 d8 :2 0
f7 :4 0 28f8 4795
4797 :3 0 d8 :2 0
fe :4 0 28fb 4799
479b :3 0 d8 :2 0
8f :3 0 dd :3 0
1a :3 0 214 :3 0
47a0 47a1 0 28fe
479f 47a3 de :4 0
2900 479e 47a6 2903
479d 47a8 :3 0 2906
478e 47aa :2 0 47ac
2909 47ad 478b 47ac
0 47ae 290b 0
47d8 d0 :3 0 d1
:3 0 47af 47b0 0
d0 :3 0 e0 :3 0
47b2 47b3 0 30
:2 0 2 :4 0 30f
:2 0 e2 :2 0 30
:2 0 290d 47b8 47ba
:3 0 2910 47b4 47bc
47b1 47be 47bd :2 0
d3 :3 0 e3 :3 0
47c0 47c1 0 d5
:4 0 310 :4 0 d8
:2 0 d9 :3 0 2914
47c5 47c7 :3 0 2917
47c2 47c9 :2 0 47cb
291a 47cc 47bf 47cb
0 47cd 291c 0
47d8 103 :3 0 21a
:3 0 47ce 47cf 0
1a :3 0 214 :3 0
47d1 47d2 0 105
:3 0 291e 47d0 47d5
:2 0 47d8 15c :3 0
2921 4851 8f :3 0
75 :3 0 45 :2 0
2925 47d9 47dc 14e
:2 0 45 :2 0 292a
47de 47e0 :3 0 d0
:3 0 d1 :3 0 47e2
47e3 0 d0 :3 0
e0 :3 0 47e5 47e6
0 1d :2 0 2
:4 0 311 :2 0 e2
:2 0 30 :2 0 292d
47eb 47ed :3 0 2930
47e7 47ef 47e4 47f1
47f0 :2 0 d3 :3 0
e3 :3 0 47f3 47f4
0 d5 :4 0 312
:4 0 d8 :2 0 d9
:3 0 2934 47f8 47fa
:3 0 d8 :2 0 f7
:4 0 2937 47fc 47fe
:3 0 d8 :2 0 fe
:4 0 293a 4800 4802
:3 0 d8 :2 0 8f
:3 0 dd :3 0 75
:3 0 293d 4806 4808
de :4 0 293f 4805
480b 2942 4804 480d
:3 0 d8 :2 0 100
:4 0 2945 480f 4811
:3 0 d8 :2 0 db
:4 0 2948 4813 4815
:3 0 d8 :2 0 28
:3 0 294b 4817 4819
:3 0 d8 :2 0 db
:4 0 294e 481b 481d
:3 0 2951 47f5 481f
:2 0 4821 2954 4822
47f2 4821 0 4823
2956 0 484f d0
:3 0 d1 :3 0 4824
4825 0 d0 :3 0
e0 :3 0 4827 4828
0 30 :2 0 2
:4 0 313 :2 0 e2
:2 0 30 :2 0 2958
482d 482f :3 0 295b
4829 4831 4826 4833
4832 :2 0 d3 :3 0
e3 :3 0 4835 4836
0 d5 :4 0 314
:4 0 d8 :2 0 d9
:3 0 295f 483a 483c
:3 0 2962 4837 483e
:2 0 4840 2965 4841
4834 4840 0 4842
2967 0 484f 103
:3 0 104 :3 0 4843
4844 0 8f :3 0
75 :3 0 45 :2 0
2969 4846 4849 28
:3 0 105 :3 0 296c
4845 484d :2 0 484f
2970 4850 47e1 484f
0 4852 477a 47d8
0 4852 2974 0
4aa0 28c :3 0 28d
:3 0 315 :4 0 4855
:4 0 4856 :2 0 4aa0
15 :3 0 ee :3 0
4858 4859 0 45
:2 0 485a 485b 0
4aa0 316 :3 0 22c
:3 0 1d2 :3 0 1d3
:3 0 1d4 :3 0 9e
:3 0 28 :3 0 1d5
:3 0 23 :3 0 22c
:4 0 317 1 :8 0
487d ed :4 0 4868
:3 0 105 :3 0 e7
:2 0 2979 486b 486c
:3 0 15 :3 0 ee
:3 0 486e 486f 0
45 :2 0 4870 4871
0 4873 297c 487a
15 :3 0 ee :3 0
4874 4875 0 ef
:2 0 4876 4877 0
4879 297e 487b 486d
4873 0 487c 0
4879 0 487c 2980
0 487d 2983 48d0
f2 :3 0 15 :3 0
ee :3 0 487f 4880
0 f1 :3 0 4881
4882 0 4884 2986
4886 2988 4885 4884
:2 0 48ce f3 :3 0
15 :3 0 ee :3 0
4889 488a 0 f1
:3 0 488b 488c 0
48c6 d0 :3 0 d1
:3 0 488e 488f 0
d0 :3 0 e0 :3 0
4891 4892 0 f4
:2 0 2 :4 0 318
:2 0 e2 :2 0 30
:2 0 298a 4897 4899
:3 0 298d 4893 489b
4890 489d 489c :2 0
d3 :3 0 e3 :3 0
489f 48a0 0 d5
:4 0 319 :4 0 d8
:2 0 d9 :3 0 2991
48a4 48a6 :3 0 d8
:2 0 f7 :4 0 2994
48a8 48aa :3 0 d8
:2 0 f8 :4 0 2997
48ac 48ae :3 0 d8
:2 0 f1 :3 0 299a
48b0 48b2 :3 0 d8
:2 0 f9 :4 0 299d
48b4 48b6 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 29a0 48b9 48bd
29a4 48b8 48bf :3 0
29a7 48a1 48c1 :2 0
48c3 29aa 48c4 489e
48c3 0 48c5 29ac
0 48c6 29ae 48c9
:3 0 48c9 0 48c9
48c8 48c6 48c7 :6 0
48cb d4 :3 0 29b1
48cd 29b3 48cc 48cb
:2 0 48ce 29b5 :2 0
48d0 0 48d0 48cf
487d 48ce :6 0 4aa0
1 :3 0 2c :3 0
eb :4 0 48d2 48d3
0 4aa0 53 :3 0
45 :2 0 48d5 48d6
0 4aa0 5a :3 0
45 :2 0 48d8 48d9
0 4aa0 49 :3 0
45 :2 0 48db 48dc
0 4aa0 4a :3 0
30 :2 0 48de 48df
0 4aa0 8f :3 0
4d :3 0 45 :2 0
29b8 48e1 48e4 117
:2 0 45 :2 0 29bd
48e6 48e8 :3 0 4d
:3 0 175 :3 0 176
:3 0 48eb 48ec 0
8f :3 0 4d :3 0
45 :2 0 29c0 48ee
48f1 1a :3 0 2b0
:3 0 48f3 48f4 0
29c3 48ed 48f6 48ea
48f7 0 48fc 57
:3 0 30 :2 0 48f9
48fa 0 48fc 29c6
4901 57 :3 0 45
:2 0 48fd 48fe 0
4900 29c9 4902 48e9
48fc 0 4903 0
4900 0 4903 29cb
0 4aa0 74 :3 0
21f :2 0 4904 4905
0 4aa0 8c :3 0
220 :3 0 21 :3 0
28 :3 0 28 :3 0
27 :3 0 74 :3 0
4a :3 0 31 :3 0
31 :3 0 31 :3 0
31 :3 0 2a :3 0
2c :3 0 52 :3 0
48 :3 0 4d :3 0
4f :3 0 50 :3 0
49 :3 0 5b :3 0
36 :3 0 53 :3 0
57 :3 0 51 :3 0
4e :3 0 5a :3 0
58 :3 0 5c :3 0
1f :3 0 45 :2 0
45 :2 0 21f :2 0
21f :2 0 45 :2 0
29ce 4908 492a 4907
492b 0 4aa0 8c
:3 0 e7 :2 0 221
:2 0 29f2 492e 4930
:3 0 d0 :3 0 d1
:3 0 4932 4933 0
d0 :3 0 e0 :3 0
4935 4936 0 1d
:2 0 2 :4 0 31a
:2 0 e2 :2 0 30
:2 0 29f5 493b 493d
:3 0 29f8 4937 493f
4934 4941 4940 :2 0
d3 :3 0 e3 :3 0
4943 4944 0 d5
:4 0 31b :4 0 d8
:2 0 d9 :3 0 29fc
4948 494a :3 0 d8
:2 0 f7 :4 0 29ff
494c 494e :3 0 d8
:2 0 fe :4 0 2a02
4950 4952 :3 0 d8
:2 0 8f :3 0 dd
:3 0 1a :3 0 224
:3 0 4957 4958 0
2a05 4956 495a de
:4 0 2a07 4955 495d
2a0a 4954 495f :3 0
d8 :2 0 100 :4 0
2a0d 4961 4963 :3 0
d8 :2 0 db :4 0
2a10 4965 4967 :3 0
d8 :2 0 27 :3 0
2a13 4969 496b :3 0
d8 :2 0 db :4 0
2a16 496d 496f :3 0
2a19 4945 4971 :2 0
4973 2a1c 4974 4942
4973 0 4975 2a1e
0 49a0 d0 :3 0
d1 :3 0 4976 4977
0 d0 :3 0 e0
:3 0 4979 497a 0
30 :2 0 2 :4 0
31c :2 0 e2 :2 0
30 :2 0 2a20 497f
4981 :3 0 2a23 497b
4983 4978 4985 4984
:2 0 d3 :3 0 e3
:3 0 4987 4988 0
d5 :4 0 31d :4 0
d8 :2 0 d9 :3 0
2a27 498c 498e :3 0
2a2a 4989 4990 :2 0
4992 2a2d 4993 4986
4992 0 4994 2a2f
0 49a0 103 :3 0
104 :3 0 4995 4996
0 1a :3 0 224
:3 0 4998 4999 0
27 :3 0 105 :3 0
2a31 4997 499d :2 0
49a0 15c :3 0 2a35
4a9d 8c :3 0 14e
:2 0 45 :2 0 2a3b
49a2 49a4 :3 0 d0
:3 0 d1 :3 0 49a6
49a7 0 d0 :3 0
e0 :3 0 49a9 49aa
0 1d :2 0 2
:4 0 31e :2 0 e2
:2 0 30 :2 0 2a3e
49af 49b1 :3 0 2a41
49ab 49b3 49a8 49b5
49b4 :2 0 d3 :3 0
e3 :3 0 49b7 49b8
0 d5 :4 0 31f
:4 0 d8 :2 0 d9
:3 0 2a45 49bc 49be
:3 0 d8 :2 0 f7
:4 0 2a48 49c0 49c2
:3 0 d8 :2 0 fe
:4 0 2a4b 49c4 49c6
:3 0 d8 :2 0 8f
:3 0 dd :3 0 1a
:3 0 1c6 :3 0 49cb
49cc 0 2a4e 49ca
49ce de :4 0 2a50
49c9 49d1 2a53 49c8
49d3 :3 0 d8 :2 0
100 :4 0 2a56 49d5
49d7 :3 0 d8 :2 0
db :4 0 2a59 49d9
49db :3 0 d8 :2 0
21 :3 0 2a5c 49dd
49df :3 0 d8 :2 0
db :4 0 2a5f 49e1
49e3 :3 0 2a62 49b9
49e5 :2 0 49e7 2a65
49e8 49b6 49e7 0
49e9 2a67 0 4a13
d0 :3 0 d1 :3 0
49ea 49eb 0 d0
:3 0 e0 :3 0 49ed
49ee 0 30 :2 0
2 :4 0 320 :2 0
e2 :2 0 30 :2 0
2a69 49f3 49f5 :3 0
2a6c 49ef 49f7 49ec
49f9 49f8 :2 0 d3
:3 0 e3 :3 0 49fb
49fc 0 d5 :4 0
321 :4 0 d8 :2 0
d9 :3 0 2a70 4a00
4a02 :3 0 2a73 49fd
4a04 :2 0 4a06 2a76
4a07 49fa 4a06 0
4a08 2a78 0 4a13
103 :3 0 104 :3 0
4a09 4a0a 0 1a
:3 0 1c6 :3 0 4a0c
4a0d 0 21 :3 0
105 :3 0 2a7a 4a0b
4a11 :2 0 4a13 2a7e
4a14 49a5 4a13 0
4a9f 9d :3 0 a5
:3 0 21 :3 0 9f
:3 0 27 :3 0 a0
:3 0 b5 :3 0 6a
:3 0 62 :3 0 67
:3 0 b5 :3 0 1f0
:3 0 6a :3 0 65
:3 0 67 :3 0 1f0
:3 0 b6 :3 0 6b
:3 0 64 :3 0 67
:3 0 b6 :3 0 1f1
:3 0 6b :3 0 66
:3 0 67 :3 0 1f1
:3 0 a7 :3 0 23
:4 0 322 1 :8 0
4a47 ed :4 0 4a32
:3 0 105 :3 0 e7
:2 0 2a84 4a35 4a36
:3 0 15 :3 0 ee
:3 0 4a38 4a39 0
45 :2 0 4a3a 4a3b
0 4a3d 2a87 4a44
15 :3 0 ee :3 0
4a3e 4a3f 0 ef
:2 0 4a40 4a41 0
4a43 2a89 4a45 4a37
4a3d 0 4a46 0
4a43 0 4a46 2a8b
0 4a47 2a8e 4a9a
f2 :3 0 15 :3 0
ee :3 0 4a49 4a4a
0 f1 :3 0 4a4b
4a4c 0 4a4e 2a91
4a50 2a93 4a4f 4a4e
:2 0 4a98 f3 :3 0
15 :3 0 ee :3 0
4a53 4a54 0 f1
:3 0 4a55 4a56 0
4a90 d0 :3 0 d1
:3 0 4a58 4a59 0
d0 :3 0 e0 :3 0
4a5b 4a5c 0 f4
:2 0 2 :4 0 323
:2 0 e2 :2 0 30
:2 0 2a95 4a61 4a63
:3 0 2a98 4a5d 4a65
4a5a 4a67 4a66 :2 0
d3 :3 0 e3 :3 0
4a69 4a6a 0 d5
:4 0 324 :4 0 d8
:2 0 d9 :3 0 2a9c
4a6e 4a70 :3 0 d8
:2 0 f7 :4 0 2a9f
4a72 4a74 :3 0 d8
:2 0 f8 :4 0 2aa2
4a76 4a78 :3 0 d8
:2 0 f1 :3 0 2aa5
4a7a 4a7c :3 0 d8
:2 0 f9 :4 0 2aa8
4a7e 4a80 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2aab 4a83 4a87
2aaf 4a82 4a89 :3 0
2ab2 4a6b 4a8b :2 0
4a8d 2ab5 4a8e 4a68
4a8d 0 4a8f 2ab7
0 4a90 2ab9 4a93
:3 0 4a93 0 4a93
4a92 4a90 4a91 :6 0
4a95 d6 :3 0 2abc
4a97 2abe 4a96 4a95
:2 0 4a98 2ac0 :2 0
4a9a 0 4a9a 4a99
4a47 4a98 :6 0 4a9c
1 :3 0 2ac3 4a9e
4931 49a0 0 4a9f
0 4a9c 0 4a9f
2ac5 0 4aa0 2ac9
4aa1 46f6 4aa0 0
4aa2 2ae1 0 4aa4
15c :3 0 2ae3 4b30
8d :3 0 14e :2 0
45 :2 0 2ae8 4aa6
4aa8 :3 0 8f :3 0
55 :3 0 45 :2 0
2aeb 4aaa 4aad 117
:2 0 45 :2 0 2af0
4aaf 4ab1 :3 0 4aa9
4ab3 4ab2 :2 0 23
:3 0 1bd :2 0 2af3
4ab6 4ab7 :3 0 4ab8
:2 0 4ab4 4aba 4ab9
:2 0 1d4 :3 0 1d5
:3 0 23 :3 0 9e
:3 0 28 :3 0 a7
:3 0 22 :4 0 325
1 :8 0 4ad9 ed
:4 0 4ac4 :3 0 105
:3 0 e7 :2 0 2af7
4ac7 4ac8 :3 0 15
:3 0 ee :3 0 4aca
4acb 0 45 :2 0
4acc 4acd 0 4acf
2afa 4ad6 15 :3 0
ee :3 0 4ad0 4ad1
0 ef :2 0 4ad2
4ad3 0 4ad5 2afc
4ad7 4ac9 4acf 0
4ad8 0 4ad5 0
4ad8 2afe 0 4ad9
2b01 4b2c f2 :3 0
15 :3 0 ee :3 0
4adb 4adc 0 f1
:3 0 4add 4ade 0
4ae0 2b04 4ae2 2b06
4ae1 4ae0 :2 0 4b2a
f3 :3 0 15 :3 0
ee :3 0 4ae5 4ae6
0 f1 :3 0 4ae7
4ae8 0 4b22 d0
:3 0 d1 :3 0 4aea
4aeb 0 d0 :3 0
e0 :3 0 4aed 4aee
0 f4 :2 0 2
:4 0 326 :2 0 e2
:2 0 30 :2 0 2b08
4af3 4af5 :3 0 2b0b
4aef 4af7 4aec 4af9
4af8 :2 0 d3 :3 0
e3 :3 0 4afb 4afc
0 d5 :4 0 327
:4 0 d8 :2 0 d9
:3 0 2b0f 4b00 4b02
:3 0 d8 :2 0 f7
:4 0 2b12 4b04 4b06
:3 0 d8 :2 0 f8
:4 0 2b15 4b08 4b0a
:3 0 d8 :2 0 f1
:3 0 2b18 4b0c 4b0e
:3 0 d8 :2 0 f9
:4 0 2b1b 4b10 4b12
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2b1e
4b15 4b19 2b22 4b14
4b1b :3 0 2b25 4afd
4b1d :2 0 4b1f 2b28
4b20 4afa 4b1f 0
4b21 2b2a 0 4b22
2b2c 4b25 :3 0 4b25
0 4b25 4b24 4b22
4b23 :6 0 4b27 d8
:3 0 2b2f 4b29 2b31
4b28 4b27 :2 0 4b2a
2b33 :2 0 4b2c 0
4b2c 4b2b 4ad9 4b2a
:6 0 4b2e 1 :3 0
2b36 4b2f 4abb 4b2e
0 4b31 46c9 4aa4
0 4b31 2b38 0
4c15 147 :3 0 5f
:3 0 bd :3 0 99
:3 0 28 :3 0 9f
:3 0 29 :3 0 a0
:4 0 328 1 :8 0
4b40 15 :3 0 ee
:3 0 4b3b 4b3c 0
f1 :3 0 4b3d 4b3e
0 4b40 2b3b 4b93
f2 :3 0 15 :3 0
ee :3 0 4b42 4b43
0 f1 :3 0 4b44
4b45 0 4b47 2b3e
4b49 2b40 4b48 4b47
:2 0 4b91 f3 :3 0
15 :3 0 ee :3 0
4b4c 4b4d 0 f1
:3 0 4b4e 4b4f 0
4b89 d0 :3 0 d1
:3 0 4b51 4b52 0
d0 :3 0 e0 :3 0
4b54 4b55 0 f4
:2 0 2 :4 0 329
:2 0 e2 :2 0 30
:2 0 2b42 4b5a 4b5c
:3 0 2b45 4b56 4b5e
4b53 4b60 4b5f :2 0
d3 :3 0 e3 :3 0
4b62 4b63 0 d5
:4 0 32a :4 0 d8
:2 0 d9 :3 0 2b49
4b67 4b69 :3 0 d8
:2 0 f7 :4 0 2b4c
4b6b 4b6d :3 0 d8
:2 0 f8 :4 0 2b4f
4b6f 4b71 :3 0 d8
:2 0 f1 :3 0 2b52
4b73 4b75 :3 0 d8
:2 0 f9 :4 0 2b55
4b77 4b79 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2b58 4b7c 4b80
2b5c 4b7b 4b82 :3 0
2b5f 4b64 4b84 :2 0
4b86 2b62 4b87 4b61
4b86 0 4b88 2b64
0 4b89 2b66 4b8c
:3 0 4b8c 0 4b8c
4b8b 4b89 4b8a :6 0
4b8e da :3 0 2b69
4b90 2b6b 4b8f 4b8e
:2 0 4b91 2b6d :2 0
4b93 0 4b93 4b92
4b40 4b91 :6 0 4c15
1 :3 0 8f :3 0
5f :3 0 45 :2 0
2b70 4b95 4b98 e7
:2 0 45 :2 0 2b75
4b9a 4b9c :3 0 bc
:3 0 186 :3 0 187
:3 0 186 :3 0 41
:3 0 9e :3 0 28
:3 0 99 :3 0 28
:4 0 32b 1 :8 0
4bbd ed :4 0 4ba8
:3 0 105 :3 0 e7
:2 0 2b7a 4bab 4bac
:3 0 15 :3 0 ee
:3 0 4bae 4baf 0
45 :2 0 4bb0 4bb1
0 4bb3 2b7d 4bba
15 :3 0 ee :3 0
4bb4 4bb5 0 ef
:2 0 4bb6 4bb7 0
4bb9 2b7f 4bbb 4bad
4bb3 0 4bbc 0
4bb9 0 4bbc 2b81
0 4bbd 2b84 4c10
f2 :3 0 15 :3 0
ee :3 0 4bbf 4bc0
0 f1 :3 0 4bc1
4bc2 0 4bc4 2b87
4bc6 2b89 4bc5 4bc4
:2 0 4c0e f3 :3 0
15 :3 0 ee :3 0
4bc9 4bca 0 f1
:3 0 4bcb 4bcc 0
4c06 d0 :3 0 d1
:3 0 4bce 4bcf 0
d0 :3 0 e0 :3 0
4bd1 4bd2 0 f4
:2 0 2 :4 0 32c
:2 0 e2 :2 0 30
:2 0 2b8b 4bd7 4bd9
:3 0 2b8e 4bd3 4bdb
4bd0 4bdd 4bdc :2 0
d3 :3 0 e3 :3 0
4bdf 4be0 0 d5
:4 0 32d :4 0 d8
:2 0 d9 :3 0 2b92
4be4 4be6 :3 0 d8
:2 0 f7 :4 0 2b95
4be8 4bea :3 0 d8
:2 0 f8 :4 0 2b98
4bec 4bee :3 0 d8
:2 0 f1 :3 0 2b9b
4bf0 4bf2 :3 0 d8
:2 0 f9 :4 0 2b9e
4bf4 4bf6 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2ba1 4bf9 4bfd
2ba5 4bf8 4bff :3 0
2ba8 4be1 4c01 :2 0
4c03 2bab 4c04 4bde
4c03 0 4c05 2bad
0 4c06 2baf 4c09
:3 0 4c09 0 4c09
4c08 4c06 4c07 :6 0
4c0b dc :3 0 2bb2
4c0d 2bb4 4c0c 4c0b
:2 0 4c0e 2bb6 :2 0
4c10 0 4c10 4c0f
4bbd 4c0e :6 0 4c12
1 :3 0 2bb9 4c13
4b9d 4c12 0 4c14
2bbb 0 4c15 2bbd
4c16 46b9 4c15 0
4c17 2bc2 0 51ec
6c :3 0 45 :2 0
4c18 4c19 0 51ec
8b :3 0 1bd :2 0
2bc4 4c1c 4c1d :3 0
4c1e :2 0 bc :3 0
1f4 :3 0 1a1 :3 0
176 :3 0 1f4 :3 0
1a :3 0 32e :3 0
99 :3 0 28 :4 0
32f 1 :8 0 4c3f
ed :4 0 4c2a :3 0
105 :3 0 e7 :2 0
2bc8 4c2d 4c2e :3 0
15 :3 0 ee :3 0
4c30 4c31 0 45
:2 0 4c32 4c33 0
4c35 2bcb 4c3c 15
:3 0 ee :3 0 4c36
4c37 0 ef :2 0
4c38 4c39 0 4c3b
2bcd 4c3d 4c2f 4c35
0 4c3e 0 4c3b
0 4c3e 2bcf 0
4c3f 2bd2 4c92 f2
:3 0 15 :3 0 ee
:3 0 4c41 4c42 0
f1 :3 0 4c43 4c44
0 4c46 2bd5 4c48
2bd7 4c47 4c46 :2 0
4c90 f3 :3 0 15
:3 0 ee :3 0 4c4b
4c4c 0 f1 :3 0
4c4d 4c4e 0 4c88
d0 :3 0 d1 :3 0
4c50 4c51 0 d0
:3 0 e0 :3 0 4c53
4c54 0 f4 :2 0
2 :4 0 330 :2 0
e2 :2 0 30 :2 0
2bd9 4c59 4c5b :3 0
2bdc 4c55 4c5d 4c52
4c5f 4c5e :2 0 d3
:3 0 e3 :3 0 4c61
4c62 0 d5 :4 0
331 :4 0 d8 :2 0
d9 :3 0 2be0 4c66
4c68 :3 0 d8 :2 0
f7 :4 0 2be3 4c6a
4c6c :3 0 d8 :2 0
f8 :4 0 2be6 4c6e
4c70 :3 0 d8 :2 0
f1 :3 0 2be9 4c72
4c74 :3 0 d8 :2 0
f9 :4 0 2bec 4c76
4c78 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2bef 4c7b 4c7f 2bf3
4c7a 4c81 :3 0 2bf6
4c63 4c83 :2 0 4c85
2bf9 4c86 4c60 4c85
0 4c87 2bfb 0
4c88 2bfd 4c8b :3 0
4c8b 0 4c8b 4c8a
4c88 4c89 :6 0 4c8d
de :3 0 2c00 4c8f
2c02 4c8e 4c8d :2 0
4c90 2c04 :2 0 4c92
0 4c92 4c91 4c3f
4c90 :6 0 4fcb 1
:3 0 8f :3 0 55
:3 0 45 :2 0 2c07
4c94 4c97 e7 :2 0
45 :2 0 2c0c 4c99
4c9b :3 0 147 :3 0
5f :3 0 9d :3 0
9e :3 0 28 :3 0
a1 :3 0 8b :4 0
332 1 :8 0 4caa
15 :3 0 ee :3 0
4ca5 4ca6 0 f1
:3 0 4ca7 4ca8 0
4caa 2c0f 4cfd f2
:3 0 15 :3 0 ee
:3 0 4cac 4cad 0
f1 :3 0 4cae 4caf
0 4cb1 2c12 4cb3
2c14 4cb2 4cb1 :2 0
4cfb f3 :3 0 15
:3 0 ee :3 0 4cb6
4cb7 0 f1 :3 0
4cb8 4cb9 0 4cf3
d0 :3 0 d1 :3 0
4cbb 4cbc 0 d0
:3 0 e0 :3 0 4cbe
4cbf 0 f4 :2 0
2 :4 0 333 :2 0
e2 :2 0 30 :2 0
2c16 4cc4 4cc6 :3 0
2c19 4cc0 4cc8 4cbd
4cca 4cc9 :2 0 d3
:3 0 e3 :3 0 4ccc
4ccd 0 d5 :4 0
334 :4 0 d8 :2 0
d9 :3 0 2c1d 4cd1
4cd3 :3 0 d8 :2 0
f7 :4 0 2c20 4cd5
4cd7 :3 0 d8 :2 0
f8 :4 0 2c23 4cd9
4cdb :3 0 d8 :2 0
f1 :3 0 2c26 4cdd
4cdf :3 0 d8 :2 0
f9 :4 0 2c29 4ce1
4ce3 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2c2c 4ce6 4cea 2c30
4ce5 4cec :3 0 2c33
4cce 4cee :2 0 4cf0
2c36 4cf1 4ccb 4cf0
0 4cf2 2c38 0
4cf3 2c3a 4cf6 :3 0
4cf6 0 4cf6 4cf5
4cf3 4cf4 :6 0 4cf8
e0 :3 0 2c3d 4cfa
2c3f 4cf9 4cf8 :2 0
4cfb 2c41 :2 0 4cfd
0 4cfd 4cfc 4caa
4cfb :6 0 4dee 1
:3 0 8f :3 0 5f
:3 0 45 :2 0 2c44
4cff 4d02 e7 :2 0
45 :2 0 2c49 4d04
4d06 :3 0 bd :3 0
9e :3 0 28 :3 0
99 :3 0 28 :3 0
9f :3 0 29 :3 0
a0 :4 0 335 1
:8 0 4d26 ed :4 0
4d11 :3 0 105 :3 0
e7 :2 0 2c4e 4d14
4d15 :3 0 15 :3 0
ee :3 0 4d17 4d18
0 45 :2 0 4d19
4d1a 0 4d1c 2c51
4d23 15 :3 0 ee
:3 0 4d1d 4d1e 0
ef :2 0 4d1f 4d20
0 4d22 2c53 4d24
4d16 4d1c 0 4d25
0 4d22 0 4d25
2c55 0 4d26 2c58
4d79 f2 :3 0 15
:3 0 ee :3 0 4d28
4d29 0 f1 :3 0
4d2a 4d2b 0 4d2d
2c5b 4d2f 2c5d 4d2e
4d2d :2 0 4d77 f3
:3 0 15 :3 0 ee
:3 0 4d32 4d33 0
f1 :3 0 4d34 4d35
0 4d6f d0 :3 0
d1 :3 0 4d37 4d38
0 d0 :3 0 e0
:3 0 4d3a 4d3b 0
f4 :2 0 2 :4 0
336 :2 0 e2 :2 0
30 :2 0 2c5f 4d40
4d42 :3 0 2c62 4d3c
4d44 4d39 4d46 4d45
:2 0 d3 :3 0 e3
:3 0 4d48 4d49 0
d5 :4 0 337 :4 0
d8 :2 0 d9 :3 0
2c66 4d4d 4d4f :3 0
d8 :2 0 f7 :4 0
2c69 4d51 4d53 :3 0
d8 :2 0 f8 :4 0
2c6c 4d55 4d57 :3 0
d8 :2 0 f1 :3 0
2c6f 4d59 4d5b :3 0
d8 :2 0 f9 :4 0
2c72 4d5d 4d5f :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2c75 4d62
4d66 2c79 4d61 4d68
:3 0 2c7c 4d4a 4d6a
:2 0 4d6c 2c7f 4d6d
4d47 4d6c 0 4d6e
2c81 0 4d6f 2c83
4d72 :3 0 4d72 0
4d72 4d71 4d6f 4d70
:6 0 4d74 e2 :3 0
2c86 4d76 2c88 4d75
4d74 :2 0 4d77 2c8a
:2 0 4d79 0 4d79
4d78 4d26 4d77 :6 0
4deb 1 :3 0 1df
:3 0 9e :3 0 28
:3 0 9f :3 0 29
:4 0 1e0 1 :8 0
4d96 ed :4 0 4d81
:3 0 105 :3 0 e7
:2 0 2c8f 4d84 4d85
:3 0 15 :3 0 ee
:3 0 4d87 4d88 0
45 :2 0 4d89 4d8a
0 4d8c 2c92 4d93
15 :3 0 ee :3 0
4d8d 4d8e 0 ef
:2 0 4d8f 4d90 0
4d92 2c94 4d94 4d86
4d8c 0 4d95 0
4d92 0 4d95 2c96
0 4d96 2c99 4de9
f2 :3 0 15 :3 0
ee :3 0 4d98 4d99
0 f1 :3 0 4d9a
4d9b 0 4d9d 2c9c
4d9f 2c9e 4d9e 4d9d
:2 0 4de7 f3 :3 0
15 :3 0 ee :3 0
4da2 4da3 0 f1
:3 0 4da4 4da5 0
4ddf d0 :3 0 d1
:3 0 4da7 4da8 0
d0 :3 0 e0 :3 0
4daa 4dab 0 f4
:2 0 2 :4 0 338
:2 0 e2 :2 0 30
:2 0 2ca0 4db0 4db2
:3 0 2ca3 4dac 4db4
4da9 4db6 4db5 :2 0
d3 :3 0 e3 :3 0
4db8 4db9 0 d5
:4 0 339 :4 0 d8
:2 0 d9 :3 0 2ca7
4dbd 4dbf :3 0 d8
:2 0 f7 :4 0 2caa
4dc1 4dc3 :3 0 d8
:2 0 f8 :4 0 2cad
4dc5 4dc7 :3 0 d8
:2 0 f1 :3 0 2cb0
4dc9 4dcb :3 0 d8
:2 0 f9 :4 0 2cb3
4dcd 4dcf :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2cb6 4dd2 4dd6
2cba 4dd1 4dd8 :3 0
2cbd 4dba 4dda :2 0
4ddc 2cc0 4ddd 4db7
4ddc 0 4dde 2cc2
0 4ddf 2cc4 4de2
:3 0 4de2 0 4de2
4de1 4ddf 4de0 :6 0
4de4 e4 :3 0 2cc7
4de6 2cc9 4de5 4de4
:2 0 4de7 2ccb :2 0
4de9 0 4de9 4de8
4d96 4de7 :6 0 4deb
1 :3 0 2cce 4dec
4d07 4deb 0 4ded
2cd1 0 4dee 2cd3
4def 4c9c 4dee 0
4df0 2cd6 0 4fcb
8f :3 0 5f :3 0
45 :2 0 2cd8 4df1
4df4 117 :2 0 45
:2 0 2cdd 4df6 4df8
:3 0 75 :3 0 2d2
:2 0 4dfa 4dfb 0
4fc8 7b :3 0 22b
:3 0 28 :3 0 8b
:3 0 75 :3 0 45
:2 0 45 :2 0 2ce0
4dfe 4e04 4dfd 4e05
0 4fc8 ac :3 0
af :3 0 33a :3 0
ad :3 0 ae :3 0
33b :3 0 ad :3 0
ae :3 0 33c :3 0
b3 :3 0 b4 :3 0
b5 :3 0 b6 :3 0
39 :3 0 3a :3 0
48 :3 0 34 :3 0
35 :3 0 82 :3 0
83 :3 0 7e :3 0
7f :3 0 9d :3 0
a7 :3 0 8b :4 0
33d 1 :8 0 4e26
15 :3 0 ee :3 0
4e21 4e22 0 f1
:3 0 4e23 4e24 0
4e26 2ce6 4e79 f2
:3 0 15 :3 0 ee
:3 0 4e28 4e29 0
f1 :3 0 4e2a 4e2b
0 4e2d 2ce9 4e2f
2ceb 4e2e 4e2d :2 0
4e77 f3 :3 0 15
:3 0 ee :3 0 4e32
4e33 0 f1 :3 0
4e34 4e35 0 4e6f
d0 :3 0 d1 :3 0
4e37 4e38 0 d0
:3 0 e0 :3 0 4e3a
4e3b 0 f4 :2 0
2 :4 0 33e :2 0
e2 :2 0 30 :2 0
2ced 4e40 4e42 :3 0
2cf0 4e3c 4e44 4e39
4e46 4e45 :2 0 d3
:3 0 e3 :3 0 4e48
4e49 0 d5 :4 0
33f :4 0 d8 :2 0
d9 :3 0 2cf4 4e4d
4e4f :3 0 d8 :2 0
f7 :4 0 2cf7 4e51
4e53 :3 0 d8 :2 0
f8 :4 0 2cfa 4e55
4e57 :3 0 d8 :2 0
f1 :3 0 2cfd 4e59
4e5b :3 0 d8 :2 0
f9 :4 0 2d00 4e5d
4e5f :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2d03 4e62 4e66 2d07
4e61 4e68 :3 0 2d0a
4e4a 4e6a :2 0 4e6c
2d0d 4e6d 4e47 4e6c
0 4e6e 2d0f 0
4e6f 2d11 4e72 :3 0
4e72 0 4e72 4e71
4e6f 4e70 :6 0 4e74
e6 :3 0 2d14 4e76
2d16 4e75 4e74 :2 0
4e77 2d18 :2 0 4e79
0 4e79 4e78 4e26
4e77 :6 0 4fc8 1
:3 0 15 :3 0 ee
:3 0 4e7b 4e7c 0
15 :3 0 e7 :2 0
165 :3 0 4e7e 4e80
0 2d1d 4e7f 4e82
:3 0 4e83 :2 0 8f
:3 0 82 :3 0 45
:2 0 2d20 4e85 4e88
e7 :2 0 45 :2 0
2d25 4e8a 4e8c :3 0
1df :3 0 340 :3 0
39 :3 0 341 :3 0
3a :3 0 342 :3 0
48 :3 0 343 :3 0
48 :3 0 7e :3 0
344 :3 0 9e :3 0
28 :3 0 9f :3 0
29 :4 0 345 1
:8 0 4eb3 ed :4 0
4e9e :3 0 105 :3 0
e7 :2 0 2d2a 4ea1
4ea2 :3 0 15 :3 0
ee :3 0 4ea4 4ea5
0 45 :2 0 4ea6
4ea7 0 4ea9 2d2d
4eb0 15 :3 0 ee
:3 0 4eaa 4eab 0
ef :2 0 4eac 4ead
0 4eaf 2d2f 4eb1
4ea3 4ea9 0 4eb2
0 4eaf 0 4eb2
2d31 0 4eb3 2d34
4f06 f2 :3 0 15
:3 0 ee :3 0 4eb5
4eb6 0 f1 :3 0
4eb7 4eb8 0 4eba
2d37 4ebc 2d39 4ebb
4eba :2 0 4f04 f3
:3 0 15 :3 0 ee
:3 0 4ebf 4ec0 0
f1 :3 0 4ec1 4ec2
0 4efc d0 :3 0
d1 :3 0 4ec4 4ec5
0 d0 :3 0 e0
:3 0 4ec7 4ec8 0
f4 :2 0 2 :4 0
346 :2 0 e2 :2 0
30 :2 0 2d3b 4ecd
4ecf :3 0 2d3e 4ec9
4ed1 4ec6 4ed3 4ed2
:2 0 d3 :3 0 e3
:3 0 4ed5 4ed6 0
d5 :4 0 347 :4 0
d8 :2 0 d9 :3 0
2d42 4eda 4edc :3 0
d8 :2 0 f7 :4 0
2d45 4ede 4ee0 :3 0
d8 :2 0 f8 :4 0
2d48 4ee2 4ee4 :3 0
d8 :2 0 f1 :3 0
2d4b 4ee6 4ee8 :3 0
d8 :2 0 f9 :4 0
2d4e 4eea 4eec :3 0
d8 :2 0 ae :3 0
fa :3 0 30 :2 0
fb :2 0 2d51 4eef
4ef3 2d55 4eee 4ef5
:3 0 2d58 4ed7 4ef7
:2 0 4ef9 2d5b 4efa
4ed4 4ef9 0 4efb
2d5d 0 4efc 2d5f
4eff :3 0 4eff 0
4eff 4efe 4efc 4efd
:6 0 4f01 e8 :3 0
2d62 4f03 2d64 4f02
4f01 :2 0 4f04 2d66
:2 0 4f06 0 4f06
4f05 4eb3 4f04 :6 0
4f08 1 :3 0 2d69
4f86 1df :3 0 340
:3 0 39 :3 0 341
:3 0 3a :3 0 342
:3 0 48 :3 0 343
:3 0 48 :3 0 7e
:3 0 344 :3 0 48
:3 0 7f :3 0 9e
:3 0 28 :3 0 9f
:3 0 29 :4 0 348
1 :8 0 4f30 ed
:4 0 4f1b :3 0 105
:3 0 e7 :2 0 2d6d
4f1e 4f1f :3 0 15
:3 0 ee :3 0 4f21
4f22 0 45 :2 0
4f23 4f24 0 4f26
2d70 4f2d 15 :3 0
ee :3 0 4f27 4f28
0 ef :2 0 4f29
4f2a 0 4f2c 2d72
4f2e 4f20 4f26 0
4f2f 0 4f2c 0
4f2f 2d74 0 4f30
2d77 4f83 f2 :3 0
15 :3 0 ee :3 0
4f32 4f33 0 f1
:3 0 4f34 4f35 0
4f37 2d7a 4f39 2d7c
4f38 4f37 :2 0 4f81
f3 :3 0 15 :3 0
ee :3 0 4f3c 4f3d
0 f1 :3 0 4f3e
4f3f 0 4f79 d0
:3 0 d1 :3 0 4f41
4f42 0 d0 :3 0
e0 :3 0 4f44 4f45
0 f4 :2 0 2
:4 0 349 :2 0 e2
:2 0 30 :2 0 2d7e
4f4a 4f4c :3 0 2d81
4f46 4f4e 4f43 4f50
4f4f :2 0 d3 :3 0
e3 :3 0 4f52 4f53
0 d5 :4 0 34a
:4 0 d8 :2 0 d9
:3 0 2d85 4f57 4f59
:3 0 d8 :2 0 f7
:4 0 2d88 4f5b 4f5d
:3 0 d8 :2 0 f8
:4 0 2d8b 4f5f 4f61
:3 0 d8 :2 0 f1
:3 0 2d8e 4f63 4f65
:3 0 d8 :2 0 f9
:4 0 2d91 4f67 4f69
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2d94
4f6c 4f70 2d98 4f6b
4f72 :3 0 2d9b 4f54
4f74 :2 0 4f76 2d9e
4f77 4f51 4f76 0
4f78 2da0 0 4f79
2da2 4f7c :3 0 4f7c
0 4f7c 4f7b 4f79
4f7a :6 0 4f7e ea
:3 0 2da5 4f80 2da7
4f7f 4f7e :2 0 4f81
2da9 :2 0 4f83 0
4f83 4f82 4f30 4f81
:6 0 4f85 1 :3 0
2dac 4f87 4e8d 4f08
0 4f88 0 4f85
0 4f88 2dae 0
4fab ae :3 0 79
:3 0 30 :2 0 30
:2 0 2db1 4f89 4f8d
e7 :2 0 1c9 :4 0
2db7 4f8f 4f91 :3 0
4f92 :2 0 84 :3 0
45 :2 0 4f94 4f95
0 4fa8 15 :3 0
ee :3 0 4f97 4f98
0 1c2 :3 0 28
:3 0 28 :3 0 8b
:3 0 34 :3 0 35
:3 0 7e :3 0 7f
:3 0 84 :3 0 83
:3 0 82 :3 0 2dba
4f9a 4fa5 4f99 4fa6
0 4fa8 2dc5 4fa9
4f93 4fa8 0 4faa
2dc8 0 4fab 2dca
4fac 4e84 4fab 0
4fad 2dcd 0 4fc8
23 :3 0 1bd :2 0
2dcf 4faf 4fb0 :3 0
4fb1 :2 0 4fb2 :2 0
123 :3 0 140 :3 0
4fb4 4fb5 0 8b
:3 0 23 :3 0 2dd1
4fb6 4fb9 e7 :2 0
45 :2 0 2dd6 4fbb
4fbd :3 0 4fbe :2 0
4fb3 4fc0 4fbf :2 0
6c :3 0 30 :2 0
4fc2 4fc3 0 4fc5
2dd9 4fc6 4fc1 4fc5
0 4fc7 2ddb 0
4fc8 2ddd 4fc9 4df9
4fc8 0 4fca 2de3
0 4fcb 2de5 4fcc
4c1f 4fcb 0 4fcd
2de9 0 51ec 23
:3 0 1bd :2 0 2deb
4fcf 4fd0 :3 0 4fd1
:2 0 75 :3 0 2d2
:2 0 4fd3 4fd4 0
5186 7b :3 0 22b
:3 0 28 :3 0 23
:3 0 75 :3 0 45
:2 0 45 :2 0 2ded
4fd7 4fdd 4fd6 4fde
0 5186 ac :3 0
af :3 0 33a :3 0
ad :3 0 ae :3 0
33b :3 0 ad :3 0
ae :3 0 33c :3 0
b3 :3 0 b4 :3 0
b5 :3 0 b6 :3 0
39 :3 0 3a :3 0
48 :3 0 34 :3 0
35 :3 0 82 :3 0
83 :3 0 62 :3 0
64 :3 0 9d :3 0
a7 :3 0 23 :4 0
34b 1 :8 0 4fff
15 :3 0 ee :3 0
4ffa 4ffb 0 f1
:3 0 4ffc 4ffd 0
4fff 2df3 5052 f2
:3 0 15 :3 0 ee
:3 0 5001 5002 0
f1 :3 0 5003 5004
0 5006 2df6 5008
2df8 5007 5006 :2 0
5050 f3 :3 0 15
:3 0 ee :3 0 500b
500c 0 f1 :3 0
500d 500e 0 5048
d0 :3 0 d1 :3 0
5010 5011 0 d0
:3 0 e0 :3 0 5013
5014 0 f4 :2 0
2 :4 0 34c :2 0
e2 :2 0 30 :2 0
2dfa 5019 501b :3 0
2dfd 5015 501d 5012
501f 501e :2 0 d3
:3 0 e3 :3 0 5021
5022 0 d5 :4 0
34d :4 0 d8 :2 0
d9 :3 0 2e01 5026
5028 :3 0 d8 :2 0
f7 :4 0 2e04 502a
502c :3 0 d8 :2 0
f8 :4 0 2e07 502e
5030 :3 0 d8 :2 0
f1 :3 0 2e0a 5032
5034 :3 0 d8 :2 0
f9 :4 0 2e0d 5036
5038 :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2e10 503b 503f 2e14
503a 5041 :3 0 2e17
5023 5043 :2 0 5045
2e1a 5046 5020 5045
0 5047 2e1c 0
5048 2e1e 504b :3 0
504b 0 504b 504a
5048 5049 :6 0 504d
ec :3 0 2e21 504f
2e23 504e 504d :2 0
5050 2e25 :2 0 5052
0 5052 5051 4fff
5050 :6 0 5186 1
:3 0 8f :3 0 82
:3 0 45 :2 0 2e28
5054 5057 e7 :2 0
45 :2 0 2e2d 5059
505b :3 0 1df :3 0
340 :3 0 39 :3 0
341 :3 0 3a :3 0
342 :3 0 48 :3 0
343 :3 0 48 :3 0
62 :3 0 344 :3 0
9e :3 0 28 :3 0
9f :3 0 27 :4 0
34e 1 :8 0 5082
ed :4 0 506d :3 0
105 :3 0 e7 :2 0
2e32 5070 5071 :3 0
15 :3 0 ee :3 0
5073 5074 0 45
:2 0 5075 5076 0
5078 2e35 507f 15
:3 0 ee :3 0 5079
507a 0 ef :2 0
507b 507c 0 507e
2e37 5080 5072 5078
0 5081 0 507e
0 5081 2e39 0
5082 2e3c 50d5 f2
:3 0 15 :3 0 ee
:3 0 5084 5085 0
f1 :3 0 5086 5087
0 5089 2e3f 508b
2e41 508a 5089 :2 0
50d3 f3 :3 0 15
:3 0 ee :3 0 508e
508f 0 f1 :3 0
5090 5091 0 50cb
d0 :3 0 d1 :3 0
5093 5094 0 d0
:3 0 e0 :3 0 5096
5097 0 f4 :2 0
2 :4 0 34f :2 0
e2 :2 0 30 :2 0
2e43 509c 509e :3 0
2e46 5098 50a0 5095
50a2 50a1 :2 0 d3
:3 0 e3 :3 0 50a4
50a5 0 d5 :4 0
350 :4 0 d8 :2 0
d9 :3 0 2e4a 50a9
50ab :3 0 d8 :2 0
f7 :4 0 2e4d 50ad
50af :3 0 d8 :2 0
f8 :4 0 2e50 50b1
50b3 :3 0 d8 :2 0
f1 :3 0 2e53 50b5
50b7 :3 0 d8 :2 0
f9 :4 0 2e56 50b9
50bb :3 0 d8 :2 0
ae :3 0 fa :3 0
30 :2 0 fb :2 0
2e59 50be 50c2 2e5d
50bd 50c4 :3 0 2e60
50a6 50c6 :2 0 50c8
2e63 50c9 50a3 50c8
0 50ca 2e65 0
50cb 2e67 50ce :3 0
50ce 0 50ce 50cd
50cb 50cc :6 0 50d0
ee :3 0 2e6a 50d2
2e6c 50d1 50d0 :2 0
50d3 2e6e :2 0 50d5
0 50d5 50d4 5082
50d3 :6 0 50d7 1
:3 0 2e71 5155 1df
:3 0 340 :3 0 39
:3 0 341 :3 0 3a
:3 0 342 :3 0 48
:3 0 343 :3 0 48
:3 0 62 :3 0 344
:3 0 48 :3 0 64
:3 0 9e :3 0 28
:3 0 9f :3 0 27
:4 0 351 1 :8 0
50ff ed :4 0 50ea
:3 0 105 :3 0 e7
:2 0 2e75 50ed 50ee
:3 0 15 :3 0 ee
:3 0 50f0 50f1 0
45 :2 0 50f2 50f3
0 50f5 2e78 50fc
15 :3 0 ee :3 0
50f6 50f7 0 ef
:2 0 50f8 50f9 0
50fb 2e7a 50fd 50ef
50f5 0 50fe 0
50fb 0 50fe 2e7c
0 50ff 2e7f 5152
f2 :3 0 15 :3 0
ee :3 0 5101 5102
0 f1 :3 0 5103
5104 0 5106 2e82
5108 2e84 5107 5106
:2 0 5150 f3 :3 0
15 :3 0 ee :3 0
510b 510c 0 f1
:3 0 510d 510e 0
5148 d0 :3 0 d1
:3 0 5110 5111 0
d0 :3 0 e0 :3 0
5113 5114 0 f4
:2 0 2 :4 0 352
:2 0 e2 :2 0 30
:2 0 2e86 5119 511b
:3 0 2e89 5115 511d
5112 511f 511e :2 0
d3 :3 0 e3 :3 0
5121 5122 0 d5
:4 0 353 :4 0 d8
:2 0 d9 :3 0 2e8d
5126 5128 :3 0 d8
:2 0 f7 :4 0 2e90
512a 512c :3 0 d8
:2 0 f8 :4 0 2e93
512e 5130 :3 0 d8
:2 0 f1 :3 0 2e96
5132 5134 :3 0 d8
:2 0 f9 :4 0 2e99
5136 5138 :3 0 d8
:2 0 ae :3 0 fa
:3 0 30 :2 0 fb
:2 0 2e9c 513b 513f
2ea0 513a 5141 :3 0
2ea3 5123 5143 :2 0
5145 2ea6 5146 5120
5145 0 5147 2ea8
0 5148 2eaa 514b
:3 0 514b 0 514b
514a 5148 5149 :6 0
514d f0 :3 0 2ead
514f 2eaf 514e 514d
:2 0 5150 2eb1 :2 0
5152 0 5152 5151
50ff 5150 :6 0 5154
1 :3 0 2eb4 5156
505c 50d7 0 5157
0 5154 0 5157
2eb6 0 5186 ae
:3 0 79 :3 0 30
:2 0 30 :2 0 2eb9
5158 515c e7 :2 0
1c9 :4 0 2ebf 515e
5160 :3 0 5161 :2 0
8f :3 0 6c :3 0
45 :2 0 2ec2 5163
5166 e7 :2 0 45
:2 0 2ec7 5168 516a
:3 0 516b :2 0 5162
516d 516c :2 0 84
:3 0 45 :2 0 516f
5170 0 5183 15
:3 0 ee :3 0 5172
5173 0 1c2 :3 0
28 :3 0 28 :3 0
23 :3 0 34 :3 0
35 :3 0 62 :3 0
64 :3 0 84 :3 0
83 :3 0 82 :3 0
2eca 5175 5180 5174
5181 0 5183 2ed5
5184 516e 5183 0
5185 2ed8 0 5186
2eda 5187 4fd2 5186
0 5188 2ee0 0
51ec 7b :3 0 354
:3 0 28 :3 0 2ee2
518a 518c 5189 518d
0 51ec 15 :3 0
ee :3 0 518f 5190
0 e7 :2 0 ef
:2 0 2ee6 5192 5194
:3 0 15 :3 0 ee
:3 0 5196 5197 0
45 :2 0 5198 5199
0 519b 2ee9 519c
5195 519b 0 519d
2eeb 0 51ec d0
:3 0 d1 :3 0 519e
519f 0 d0 :3 0
e0 :3 0 51a1 51a2
0 ea :2 0 2
:4 0 355 :2 0 e2
:2 0 30 :2 0 2eed
51a7 51a9 :3 0 2ef0
51a3 51ab 51a0 51ad
51ac :2 0 d3 :3 0
e3 :3 0 51af 51b0
0 d5 :4 0 356
:4 0 d8 :2 0 d9
:3 0 2ef4 51b4 51b6
:3 0 d8 :2 0 f7
:4 0 2ef7 51b8 51ba
:3 0 d8 :2 0 fe
:4 0 2efa 51bc 51be
:3 0 d8 :2 0 8f
:3 0 dd :3 0 15
:3 0 ee :3 0 51c3
51c4 0 2efd 51c2
51c6 de :4 0 2eff
51c1 51c9 2f02 51c0
51cb :3 0 d8 :2 0
100 :4 0 2f05 51cd
51cf :3 0 d8 :2 0
db :4 0 2f08 51d1
51d3 :3 0 d8 :2 0
23 :3 0 2f0b 51d5
51d7 :3 0 d8 :2 0
db :4 0 2f0e 51d9
51db :3 0 2f11 51b1
51dd :2 0 51df 2f14
51e0 51ae 51df 0
51e1 2f16 0 51ec
103 :3 0 357 :3 0
51e2 51e3 0 15
:3 0 ee :3 0 51e5
51e6 0 23 :3 0
105 :3 0 2f18 51e4
51ea :2 0 51ec 2f1c
528d 15 :3 0 358
:2 0 4 51ed 51ee
0 d0 :3 0 d1
:3 0 51f0 51f1 0
d0 :3 0 e0 :3 0
51f3 51f4 0 f4
:2 0 2 :4 0 359
:2 0 e2 :2 0 30
:2 0 2f78 51f9 51fb
:3 0 2f7b 51f5 51fd
51f2 51ff 51fe :2 0
d3 :3 0 e3 :3 0
5201 5202 0 d5
:4 0 35a :4 0 d8
:2 0 d9 :3 0 2f7f
5206 5208 :3 0 2f82
5203 520a :2 0 5223
d3 :3 0 e3 :3 0
520c 520d 0 d5
:4 0 35b :4 0 d8
:2 0 15 :3 0 35c
:3 0 5212 5213 0
2f85 5211 5215 :3 0
d8 :2 0 100 :4 0
2f88 5217 5219 :3 0
d8 :2 0 15 :3 0
35d :3 0 521c 521d
0 2f8b 521b 521f
:3 0 2f8e 520e 5221
:2 0 5223 2f91 5224
5200 5223 0 5225
2f94 0 5235 ec
:3 0 cf :3 0 15
:3 0 35c :3 0 35e
:3 0 15 :3 0 35d
:3 0 35f :3 0 14f
:4 0 360 1 :a 0
5231 :2 0 5235 5227
522f :2 0 14 :3 0
cf :3 0 5233 :2 0
5235 2f96 5237 2f9a
5236 5235 :2 0 528b
f3 :3 0 15 :3 0
ee :3 0 523a 523b
0 f1 :3 0 523c
523d 0 5283 d0
:3 0 d1 :3 0 523f
5240 0 d0 :3 0
e0 :3 0 5242 5243
0 f4 :2 0 2
:4 0 361 :2 0 e2
:2 0 30 :2 0 2f9c
5248 524a :3 0 2f9f
5244 524c 5241 524e
524d :2 0 d3 :3 0
e3 :3 0 5250 5251
0 d5 :4 0 362
:4 0 d8 :2 0 d9
:3 0 2fa3 5255 5257
:3 0 2fa6 5252 5259
:2 0 5273 d3 :3 0
e3 :3 0 525b 525c
0 d5 :4 0 f8
:4 0 d8 :2 0 f1
:3 0 2fa9 5260 5262
:3 0 d8 :2 0 f9
:4 0 2fac 5264 5266
:3 0 d8 :2 0 ae
:3 0 fa :3 0 30
:2 0 fb :2 0 2faf
5269 526d 2fb3 5268
526f :3 0 2fb6 525d
5271 :2 0 5273 2fb9
5274 524f 5273 0
5275 2fbc 0 5283
ec :3 0 cf :3 0
35e :3 0 15 :3 0
35d :3 0 35f :3 0
14f :4 0 363 1
:a 0 527f :2 0 5283
5277 527d :2 0 14
:3 0 cf :3 0 5281
:2 0 5283 2fbe 5286
:3 0 5286 0 5286
5285 5283 5284 :6 0
5288 1 :3 0 2fc3
528a 2fc5 5289 5288
:2 0 528b 2fc7 :2 0
528d 2fca 528d 528c
51ec 528b :6 0 528e
:2 0 2 44 528d
5291 :3 0 5290 528e
5292 :8 0 
303c
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
52 1 50 1
59 1 57 1
60 1 5e 1
67 1 65 1
6e 1 6c 1
75 1 73 1
7c 1 7a 1
83 1 81 1
8a 1 88 1
91 1 8f 1
98 1 96 1
9f 1 9d 1
a6 1 a4 1
ab 1 b0 1
b5 1 ba 1
c1 1 bf 1
c8 1 c6 1
cd 1 d2 1
d7 1 de 1
dc 1 e5 1
e3 1 ea 1
ef 1 f4 1
f9 1 100 1
fe 1 107 1
105 1 10e 1
10c 1 115 1
113 1 11c 1
11a 1 121 1
127 1 12d 1
133 1 139 1
13f 1 145 1
14b 1 151 1
157 1 15d 1
163 1 169 1
16f 1 175 1
17b 1 181 1
187 1 18d 1
193 1 199 1
19f 1 1a5 1
1ab 1 1b1 1
1b7 1 1bd 1
1c3 1 1c9 1
1cf 1 1d5 1
1db 1 1e1 1
1e7 1 1ed 1
1f3 1 1f9 1
1ff 1 205 1
20b 1 211 1
217 1 21d 1
225 1 223 1
22c 1 22a 1
231 1 237 1
23f 1 23d 1
244 1 24c 1
24a 1 253 1
251 1 258 1
25e 1 264 1
269 1 26e 1
274 1 27a 1
280 1 286 1
28c 1 292 1
298 1 29e 1
2a4 1 2aa 1
2b2 1 2b0 1
2b9 1 2b7 1
2c0 1 2be 1
2c5 2 2d0 2d1
1 2d3 1 2cb
1 2d9 1 2df
1 2e5 1 2ea
1 2f9 1 30d
1 385 1 38b
1 398 1 3a4
2 3a7 3a9 2
3ac 3ae 2 3b0
3b2 2 3b4 3b6
2 3b8 3ba 2
3bc 3be 2 3c0
3c2 2 3c4 3c6
2 3c8 3ca 2
3cc 3ce 2 3d0
3d2 2 3d4 3d6
2 3d8 3da 2
3dc 3de 2 3e0
3e2 2 3e4 3e6
2 3e8 3ea 2
3ec 3ee 2 3f0
3f2 2 3f4 3f6
2 3f8 3fa 1
400 2 402 403
2 3fc 405 2
407 409 1 40f
2 411 412 2
40b 414 2 416
418 1 41e 2
420 421 2 41a
423 2 425 427
1 42d 2 42f
430 2 429 432
2 434 436 1
43c 2 43e 43f
2 438 441 2
443 445 1 44b
2 44d 44e 2
447 450 2 452
454 1 45a 2
45c 45d 2 456
45f 2 461 463
1 469 2 46b
46c 2 465 46e
2 470 472 1
478 2 47a 47b
2 474 47d 2
47f 481 2 483
485 2 487 489
2 48b 48d 2
48f 491 4 3a0
3a6 3ab 493 1
495 1 497 2
4a1 4a3 3 49f
4a0 4a5 2 4ae
4b0 2 4ad 4b2
1 4b4 1 4b6
2 4cd 4ce 2
4d0 4d3 2 4d8
4d9 1 4df 2
4db 4df 2 4e4
4e5 1 4eb 2
4e7 4eb 1 4f3
1 4f5 1 51c
1 522 2 524
525 2 52e 534
1 53b 1 536
2 54e 550 3
54c 54d 552 2
55b 55d 2 55f
561 2 563 565
2 567 569 2
56b 56d 3 572
573 574 2 56f
576 2 55a 578
1 57a 1 57c
2 545 57d 1
581 1 540 2
53e 585 2 58b
58c 1 590 2
58e 590 2 59b
59d 3 599 59a
59f 2 5a8 5aa
2 5ac 5ae 2
5b0 5b2 1 5ba
2 5bc 5bd 2
5b4 5bf 2 5c1
5c3 2 5c5 5c7
2 5c9 5cb 2
5cd 5cf 2 5a7
5d1 1 5d3 1
5d5 2 5df 5e1
3 5dd 5de 5e3
2 5ec 5ee 2
5eb 5f0 1 5f2
1 5f4 3 5fb
5fc 5fd 3 5d6
5f5 5ff 1 601
2 612 617 1
61e 1 619 2
631 633 3 62f
630 635 2 63e
640 2 642 644
2 646 648 2
64a 64c 2 64e
650 3 655 656
657 2 652 659
2 63d 65b 1
65d 1 65f 2
628 660 1 664
1 623 2 621
668 1 673 2
66f 673 2 67f
681 3 67d 67e
683 2 68c 68e
2 690 692 2
694 696 1 69e
2 6a0 6a1 2
698 6a3 2 6a5
6a7 2 6a9 6ab
2 6ad 6af 2
6b1 6b3 2 68b
6b5 1 6b7 1
6b9 2 6c3 6c5
3 6c1 6c2 6c7
2 6d0 6d2 2
6cf 6d4 1 6d6
1 6d8 3 6df
6e0 6e1 3 6ba
6d9 6e3 1 6e5
2 6ef 6f4 1
6fb 1 6f6 2
70e 710 3 70c
70d 712 2 71b
71d 2 71f 721
2 723 725 2
727 729 2 72b
72d 3 732 733
734 2 72f 736
2 71a 738 1
73a 1 73c 2
705 73d 1 741
1 700 2 6fe
745 2 74b 74c
1 750 2 74e
750 2 75b 75d
3 759 75a 75f
2 768 76a 2
76c 76e 2 770
772 1 77a 2
77c 77d 2 774
77f 2 781 783
2 785 787 2
789 78b 2 78d
78f 2 767 791
1 793 1 795
2 79f 7a1 3
79d 79e 7a3 2
7ac 7ae 2 7ab
7b0 1 7b2 1
7b4 3 7bb 7bc
7bd 3 796 7b5
7bf 1 7c1 2
7e8 7ed 1 7f4
1 7ef 2 807
809 3 805 806
80b 2 814 816
2 818 81a 2
81c 81e 2 820
822 2 824 826
3 82b 82c 82d
2 828 82f 2
813 831 1 833
1 835 2 7fe
836 1 83a 1
7f9 2 7f7 83e
1 849 2 845
849 2 855 857
3 853 854 859
2 862 864 2
866 868 2 86a
86c 1 874 2
876 877 2 86e
879 2 87b 87d
2 87f 881 2
883 885 2 887
889 2 861 88b
1 88d 1 88f
2 899 89b 3
897 898 89d 2
8a6 8a8 2 8a5
8aa 1 8ac 1
8ae 3 8b5 8b6
8b7 3 890 8af
8b9 1 8bb 2
8c4 8c9 1 8d0
1 8cb 2 8e3
8e5 3 8e1 8e2
8e7 2 8f0 8f2
2 8f4 8f6 2
8f8 8fa 2 8fc
8fe 2 900 902
3 907 908 909
2 904 90b 2
8ef 90d 1 90f
1 911 2 8da
912 1 916 1
8d5 2 8d3 91a
1 925 2 921
925 2 931 933
3 92f 930 935
2 93e 940 2
942 944 2 946
948 1 950 2
952 953 2 94a
955 2 957 959
2 95b 95d 2
95f 961 2 963
965 2 93d 967
1 969 1 96b
2 975 977 3
973 974 979 2
982 984 2 981
986 1 988 1
98a 3 991 992
993 3 96c 98b
995 1 997 2
99e 9a3 1 9aa
1 9a5 2 9bd
9bf 3 9bb 9bc
9c1 2 9ca 9cc
2 9ce 9d0 2
9d2 9d4 2 9d6
9d8 2 9da 9dc
3 9e1 9e2 9e3
2 9de 9e5 2
9c9 9e7 1 9e9
1 9eb 2 9b4
9ec 1 9f0 1
9af 2 9ad 9f4
2 9fc 9fd 1
a01 2 9ff a01
1 a06 1 a08
1 a10 2 a0c
a10 2 a1c a1e
3 a1a a1b a20
2 a29 a2b 2
a2d a2f 2 a31
a33 1 a3b 2
a3d a3e 2 a35
a40 2 a42 a44
2 a46 a48 2
a4a a4c 2 a4e
a50 2 a28 a52
1 a54 1 a56
2 a60 a62 3
a5e a5f a64 2
a6d a6f 2 a6c
a71 1 a73 1
a75 3 a7c a7d
a7e 3 a57 a76
a80 1 a82 2
a8a a8b 2 a8d
a8e 2 a95 a96
2 a98 a99 2
aa0 aa1 2 aa3
aa4 2 ab3 ab8
1 abf 1 aba
2 ad2 ad4 3
ad0 ad1 ad6 2
adf ae1 2 ae3
ae5 2 ae7 ae9
2 aeb aed 2
aef af1 3 af6
af7 af8 2 af3
afa 2 ade afc
1 afe 1 b00
2 ac9 b01 1
b05 1 ac4 2
ac2 b09 2 b19
b1e 1 b25 1
b20 2 b38 b3a
3 b36 b37 b3c
2 b45 b47 2
b49 b4b 2 b4d
b4f 2 b51 b53
2 b55 b57 3
b5c b5d b5e 2
b59 b60 2 b44
b62 1 b64 1
b66 2 b2f b67
1 b6b 1 b2a
2 b28 b6f 1
b76 2 b74 b76
2 b7a b7b 1
b7f 2 b7d b7f
2 b8c b91 1
b98 1 b93 2
bab bad 3 ba9
baa baf 2 bb8
bba 2 bbc bbe
2 bc0 bc2 2
bc4 bc6 2 bc8
bca 3 bcf bd0
bd1 2 bcc bd3
2 bb7 bd5 1
bd7 1 bd9 2
ba2 bda 1 bde
1 b9d 2 b9b
be2 2 be8 be9
1 bed 2 beb
bed 1 bef 2
c00 c05 1 c0c
1 c07 2 c1f
c21 3 c1d c1e
c23 2 c2c c2e
2 c30 c32 2
c34 c36 2 c38
c3a 2 c3c c3e
3 c43 c44 c45
2 c40 c47 2
c2b c49 1 c4b
1 c4d 2 c16
c4e 1 c52 1
c11 2 c0f c56
2 c5c c5d 1
c61 2 c5f c61
2 c6c c6e 3
c6a c6b c70 2
c79 c7b 2 c7d
c7f 2 c81 c83
1 c8b 2 c8d
c8e 2 c85 c90
2 c92 c94 2
c96 c98 2 c9a
c9c 2 c9e ca0
2 c78 ca2 1
ca4 1 ca6 2
cb0 cb2 3 cae
caf cb4 2 cbd
cbf 2 cbc cc1
1 cc3 1 cc5
3 ccc ccd cce
3 ca7 cc6 cd0
1 cd2 3 bf5
c59 cd3 1 cd5
2 be5 cd6 1
cd8 1 cd9 2
cde cdf 1 ce1
1 ce5 2 ce3
ce5 2 ce9 cea
1 cee 2 cec
cee 2 cf2 cf3
1 cf7 2 cf5
cf7 2 d0c d11
1 d18 1 d13
2 d2b d2d 3
d29 d2a d2f 2
d38 d3a 2 d3c
d3e 2 d40 d42
2 d44 d46 2
d48 d4a 3 d4f
d50 d51 2 d4c
d53 2 d37 d55
1 d57 1 d59
2 d22 d5a 1
d5e 1 d1d 2
d1b d62 2 d68
d69 1 d6d 2
d6b d6d 2 d78
d7a 3 d76 d77
d7c 2 d85 d87
2 d89 d8b 2
d8d d8f 1 d97
2 d99 d9a 2
d91 d9c 2 d9e
da0 2 da2 da4
2 da6 da8 2
daa dac 2 d84
dae 1 db0 1
db2 2 dbc dbe
3 dba dbb dc0
2 dc9 dcb 2
dc8 dcd 1 dcf
1 dd1 3 dd8
dd9 dda 3 db3
dd2 ddc 1 dde
3 d01 d65 ddf
2 de2 de1 1
e06 1 e0c 2
e0e e0f 1 e17
2 e13 e17 1
e1d 1 e21 2
e23 e24 2 e28
e2e 1 e35 1
e30 2 e48 e4a
3 e46 e47 e4c
2 e55 e57 2
e59 e5b 2 e5d
e5f 2 e61 e63
2 e65 e67 3
e6c e6d e6e 2
e69 e70 2 e54
e72 1 e74 1
e76 2 e3f e77
1 e7b 1 e3a
2 e38 e7f 2
e85 e86 1 e8a
2 e88 e8a 2
e8e e8f 1 e93
2 e91 e93 1
e98 1 e9a 1
e9b 1 e9d 2
ea4 ea9 1 eb0
1 eab 2 ec3
ec5 3 ec1 ec2
ec7 2 ed0 ed2
2 ed4 ed6 2
ed8 eda 2 edc
ede 2 ee0 ee2
3 ee7 ee8 ee9
2 ee4 eeb 2
ecf eed 1 eef
1 ef1 2 eba
ef2 1 ef6 1
eb5 2 eb3 efa
2 f0a f0f 1
f16 1 f11 2
f29 f2b 3 f27
f28 f2d 2 f36
f38 2 f3a f3c
2 f3e f40 2
f42 f44 2 f46
f48 3 f4d f4e
f4f 2 f4a f51
2 f35 f53 1
f55 1 f57 2
f20 f58 1 f5c
1 f1b 2 f19
f60 1 f6b 2
f67 f6b 2 f70
f71 1 f75 2
f73 f75 1 f77
2 f8f f94 1
f9b 1 f96 2
fae fb0 3 fac
fad fb2 2 fbb
fbd 2 fbf fc1
2 fc3 fc5 2
fc7 fc9 2 fcb
fcd 3 fd2 fd3
fd4 2 fcf fd6
2 fba fd8 1
fda 1 fdc 2
fa5 fdd 1 fe1
1 fa0 2 f9e
fe5 1 ff0 2
fec ff0 2 ff9
ffa 2 ffc fff
1 1002 2 1008
1009 4 1006 100b
100e 100f 2 1012
1017 2 1019 101a
7 1024 1025 1026
1027 1028 1029 102a
2 1031 1032 1
1034 1 1054 2
1053 1054 1 105c
1 1062 2 1064
1065 2 1051 1066
1 106d 1 1068
2 1080 1082 3
107e 107f 1084 2
108d 108f 2 1091
1093 2 1095 1097
2 1099 109b 2
109d 109f 3 10a4
10a5 10a6 2 10a1
10a8 2 108c 10aa
1 10ac 1 10ae
2 1077 10af 1
10b3 1 1072 2
1070 10b7 2 10bf
10c0 1 10c4 2
10c2 10c4 1 10c9
2 10d7 10dc 1
10e3 1 10de 2
10f6 10f8 3 10f4
10f5 10fa 2 1103
1105 2 1107 1109
2 110b 110d 2
110f 1111 2 1113
1115 3 111a 111b
111c 2 1117 111e
2 1102 1120 1
1122 1 1124 2
10ed 1125 1 1129
1 10e8 2 10e6
112d 1 1130 2
1133 1134 2 1137
1138 1 113c 2
113a 113c 1 114c
2 114b 114c 1
1154 1 115a 2
115c 115d 2 1149
115e 1 1165 1
1160 2 1178 117a
3 1176 1177 117c
2 1185 1187 2
1189 118b 2 118d
118f 2 1191 1193
2 1195 1197 3
119c 119d 119e 2
1199 11a0 2 1184
11a2 1 11a4 1
11a6 2 116f 11a7
1 11ab 1 116a
2 1168 11af 1
11c8 2 11c7 11c8
1 11d0 1 11d6
2 11d8 11d9 2
11c5 11da 1 11e1
1 11dc 2 11f4
11f6 3 11f2 11f3
11f8 2 1201 1203
2 1205 1207 2
1209 120b 2 120d
120f 2 1211 1213
3 1218 1219 121a
2 1215 121c 2
1200 121e 1 1220
1 1222 2 11eb
1223 1 1227 1
11e6 2 11e4 122b
2 11b2 122e 1
1245 2 1244 1245
1 124d 1 1253
2 1255 1256 2
1242 1257 1 125e
1 1259 2 1271
1273 3 126f 1270
1275 2 127e 1280
2 1282 1284 2
1286 1288 2 128a
128c 2 128e 1290
3 1295 1296 1297
2 1292 1299 2
127d 129b 1 129d
1 129f 2 1268
12a0 1 12a4 1
1263 2 1261 12a8
1 12ab 2 12ae
12af b f7f f84
fe8 101b 101e 1021
102d 1037 10ba 1135
12b0 1 12b9 2
12b5 12b9 1 12d1
2 12d0 12d1 1
12d9 1 12df 2
12e1 12e2 2 12ce
12e3 1 12ea 1
12e5 2 12fd 12ff
3 12fb 12fc 1301
2 130a 130c 2
130e 1310 2 1312
1314 2 1316 1318
2 131a 131c 3
1321 1322 1323 2
131e 1325 2 1309
1327 1 1329 1
132b 2 12f4 132c
1 1330 1 12ef
2 12ed 1334 2
1342 1347 1 134e
1 1349 2 1361
1363 3 135f 1360
1365 2 136e 1370
2 1372 1374 2
1376 1378 2 137a
137c 2 137e 1380
3 1385 1386 1387
2 1382 1389 2
136d 138b 1 138d
1 138f 2 1358
1390 1 1394 1
1353 2 1351 1398
1 13a3 2 139f
13a3 2 13ad 13b2
1 13b9 1 13b4
2 13cc 13ce 3
13ca 13cb 13d0 2
13d9 13db 2 13dd
13df 2 13e1 13e3
2 13e5 13e7 2
13e9 13eb 3 13f0
13f1 13f2 2 13ed
13f4 2 13d8 13f6
1 13f8 1 13fa
2 13c3 13fb 1
13ff 1 13be 2
13bc 1403 1 140e
2 140a 140e 1
1414 1 1416 2
1406 1417 1 1419
2 141c 141d 1
1421 2 141f 1421
1 1423 2 1428
1429 1 142f 2
142b 142f 2 1436
1437 4 1434 1439
143c 143d 1 144e
2 144d 144e 1
1456 1 145c 2
145e 145f 2 144b
1460 1 1467 1
1462 2 147a 147c
3 1478 1479 147e
2 1487 1489 2
148b 148d 2 148f
1491 2 1493 1495
2 1497 1499 3
149e 149f 14a0 2
149b 14a2 2 1486
14a4 1 14a6 1
14a8 2 1471 14a9
1 14ad 1 146c
2 146a 14b1 1
14b8 3 1440 14b4
14bb 2 14c0 14c1
2 14c3 14c6 1
14cd 2 14c9 14cd
1 14de 2 14dd
14de 1 14e6 1
14ec 2 14ee 14ef
2 14db 14f0 1
14f7 1 14f2 2
150a 150c 3 1508
1509 150e 2 1517
1519 2 151b 151d
2 151f 1521 2
1523 1525 2 1527
1529 3 152e 152f
1530 2 152b 1532
2 1516 1534 1
1536 1 1538 2
1501 1539 1 153d
1 14fc 2 14fa
1541 1 1548 2
1544 154b 2 1551
1552 2 1554 1557
1 155e 2 155a
155e 1 156f 2
156e 156f 1 1577
1 157d 2 157f
1580 2 156c 1581
1 1588 1 1583
2 159b 159d 3
1599 159a 159f 2
15a8 15aa 2 15ac
15ae 2 15b0 15b2
2 15b4 15b6 2
15b8 15ba 3 15bf
15c0 15c1 2 15bc
15c3 2 15a7 15c5
1 15c7 1 15c9
2 1592 15ca 1
15ce 1 158d 2
158b 15d2 1 15d9
2 15d5 15dc 3
15df 154e 15de 1
15e0 1 15e2 5
1337 133b 139b 141a
15e3 2 15e6 15e5
2 15fe 1603 1
160a 1 1605 2
161d 161f 3 161b
161c 1621 2 162a
162c 2 162e 1630
2 1632 1634 2
1636 1638 2 163a
163c 3 1641 1642
1643 2 163e 1645
2 1629 1647 1
1649 1 164b 2
1614 164c 1 1650
1 160f 2 160d
1654 1 165f 2
165b 165f 1 1665
1 1667 2 1678
1679 1 167d 2
167b 167d 2 1682
1683 1 1687 2
1685 1687 a 168f
1690 1691 1692 1693
1694 1695 1696 1697
1698 2 169d 169e
1 16a2 2 16a0
16a2 2 16a7 16a8
2 16ad 16ae 2
16aa 16b0 2 16b6
16b7 2 16bc 16bd
2 16b9 16bf 2
16b3 16c2 1 16c4
2 16c7 16c8 1
16cc 2 16ca 16cc
2 16d1 16d2 2
16d7 16d8 2 16d4
16da 2 16e0 16e1
2 16e6 16e7 2
16e3 16e9 2 16dd
16ec 1 16ee 3
169b 16c5 16ef 1
16f1 2 16ff 1704
1 170b 1 1706
2 171e 1720 3
171c 171d 1722 2
172b 172d 2 172f
1731 2 1733 1735
2 1737 1739 2
173b 173d 3 1742
1743 1744 2 173f
1746 2 172a 1748
1 174a 1 174c
2 1715 174d 1
1751 1 1710 2
170e 1755 2 1769
176e 1 1775 1
1770 2 1788 178a
3 1786 1787 178c
2 1795 1797 2
1799 179b 2 179d
179f 2 17a1 17a3
2 17a5 17a7 3
17ac 17ad 17ae 2
17a9 17b0 2 1794
17b2 1 17b4 1
17b6 2 177f 17b7
1 17bb 1 177a
2 1778 17bf 2
17cb 17d0 1 17d7
1 17d2 2 17ea
17ec 3 17e8 17e9
17ee 2 17f7 17f9
2 17fb 17fd 2
17ff 1801 2 1803
1805 2 1807 1809
3 180e 180f 1810
2 180b 1812 2
17f6 1814 1 1816
1 1818 2 17e1
1819 1 181d 1
17dc 2 17da 1821
2 1829 182a 1
182e 2 182c 182e
1 1830 1 1834
2 185f 1864 1
186b 1 1866 2
187e 1880 3 187c
187d 1882 2 188b
188d 2 188f 1891
2 1893 1895 2
1897 1899 2 189b
189d 3 18a2 18a3
18a4 2 189f 18a6
2 188a 18a8 1
18aa 1 18ac 2
1875 18ad 1 18b1
1 1870 2 186e
18b5 1 18c0 2
18bc 18c0 1 18c4
1 18ce a 18d6
18d7 18d8 18d9 18da
18db 18dc 18dd 18de
18df 2 18d1 18e2
1 18e4 2 18ea
18eb 1 18ef 2
18ed 18ef 2 18f3
18f4 2 18f9 18fa
1 18fc 2 18f6
18fc 2 1900 1901
2 1906 1907 1
1909 2 1903 1909
2 1910 1911 2
1913 1916 1 191a
2 1918 191a 2
1925 1927 3 1923
1924 1929 2 1932
1934 2 1936 1938
2 193a 193c 1
1944 2 1946 1947
2 193e 1949 2
194b 194d 2 194f
1951 2 1953 1955
2 1957 1959 2
1931 195b 1 195d
1 195f 2 1969
196b 3 1967 1968
196d 2 1976 1978
2 1975 197a 1
197c 1 197e 3
1985 1986 1987 3
1960 197f 1989 2
198f 1990 1 1994
2 1992 1994 1
1999 1 199b 2
198d 199c 2 199e
199f 1 19a0 1
19a2 a 19a3 19a6
19a9 19ac 19af 19b2
19b5 19b8 19bb 19be
1 19c0 1 19c8
2 19c4 19c8 1
19d2 3 19d8 19d9
19da 1 19de 2
19dc 19de 1 19e3
a 19eb 19ec 19ed
19ee 19ef 19f0 19f1
19f2 19f3 19f4 2
19e6 19f7 1 19f9
2 1a16 1a1b 1
1a22 1 1a1d 2
1a35 1a37 3 1a33
1a34 1a39 2 1a42
1a44 2 1a46 1a48
2 1a4a 1a4c 2
1a4e 1a50 2 1a52
1a54 3 1a59 1a5a
1a5b 2 1a56 1a5d
2 1a41 1a5f 1
1a61 1 1a63 2
1a2c 1a64 1 1a68
1 1a27 2 1a25
1a6c 1 1a77 2
1a73 1a77 2 1a7c
1a7d 2 1a82 1a83
1 1a85 2 1a7f
1a85 2 1a89 1a8a
2 1a8f 1a90 1
1a92 2 1a8c 1a92
2 1a9f 1aa1 3
1a9d 1a9e 1aa3 2
1aac 1aae 2 1ab0
1ab2 2 1ab4 1ab6
1 1abe 2 1ac0
1ac1 2 1ab8 1ac3
2 1ac5 1ac7 2
1ac9 1acb 2 1acd
1acf 2 1ad1 1ad3
2 1aab 1ad5 1
1ad7 1 1ad9 2
1ae3 1ae5 3 1ae1
1ae2 1ae7 2 1af0
1af2 2 1aef 1af4
1 1af6 1 1af8
3 1aff 1b00 1b01
3 1ada 1af9 1b03
1 1b05 3 1b09
1b0a 1b0b 1 1b0f
2 1b0d 1b0f 1
1b11 2 1b14 1b16
2 1b1a 1b1b 1
1b1f 2 1b1d 1b1f
2 1b29 1b2a 1
1b2e 2 1b2c 1b2e
2 1b32 1b33 1
1b37 2 1b35 1b37
2 1b44 1b49 1
1b50 1 1b4b 2
1b63 1b65 3 1b61
1b62 1b67 2 1b70
1b72 2 1b74 1b76
2 1b78 1b7a 2
1b7c 1b7e 2 1b80
1b82 3 1b87 1b88
1b89 2 1b84 1b8b
2 1b6f 1b8d 1
1b8f 1 1b91 2
1b5a 1b92 1 1b96
1 1b55 2 1b53
1b9a 1 1b9d 2
1ba8 1bad 1 1bb4
1 1baf 2 1bc7
1bc9 3 1bc5 1bc6
1bcb 2 1bd4 1bd6
2 1bd8 1bda 2
1bdc 1bde 2 1be0
1be2 2 1be4 1be6
3 1beb 1bec 1bed
2 1be8 1bef 2
1bd3 1bf1 1 1bf3
1 1bf5 2 1bbe
1bf6 1 1bfa 1
1bb9 2 1bb7 1bfe
1 1c01 2 1c04
1c05 1 1c06 1
1c08 2 1c0b 1c0c
1 1c10 2 1c0e
1c10 1 1c1d 2
1c1c 1c1d 1 1c25
1 1c2b 2 1c2d
1c2e 2 1c1a 1c2f
1 1c36 1 1c31
2 1c49 1c4b 3
1c47 1c48 1c4d 2
1c56 1c58 2 1c5a
1c5c 2 1c5e 1c60
2 1c62 1c64 2
1c66 1c68 3 1c6d
1c6e 1c6f 2 1c6a
1c71 2 1c55 1c73
1 1c75 1 1c77
2 1c40 1c78 1
1c7c 1 1c3b 2
1c39 1c80 1 1c83
1 1c8e 2 1c8d
1c8e 1 1c96 1
1c9c 2 1c9e 1c9f
2 1c8b 1ca0 1
1ca7 1 1ca2 2
1cba 1cbc 3 1cb8
1cb9 1cbe 2 1cc7
1cc9 2 1ccb 1ccd
2 1ccf 1cd1 2
1cd3 1cd5 2 1cd7
1cd9 3 1cde 1cdf
1ce0 2 1cdb 1ce2
2 1cc6 1ce4 1
1ce6 1 1ce8 2
1cb1 1ce9 1 1ced
1 1cac 2 1caa
1cf1 1 1cfc 2
1cfb 1cfc 1 1d04
1 1d0a 2 1d0c
1d0d 2 1cf9 1d0e
1 1d15 1 1d10
2 1d28 1d2a 3
1d26 1d27 1d2c 2
1d35 1d37 2 1d39
1d3b 2 1d3d 1d3f
2 1d41 1d43 2
1d45 1d47 3 1d4c
1d4d 1d4e 2 1d49
1d50 2 1d34 1d52
1 1d54 1 1d56
2 1d1f 1d57 1
1d5b 1 1d1a 2
1d18 1d5f 1 1d6a
2 1d69 1d6a 1
1d72 1 1d78 2
1d7a 1d7b 2 1d67
1d7c 1 1d83 1
1d7e 2 1d96 1d98
3 1d94 1d95 1d9a
2 1da3 1da5 2
1da7 1da9 2 1dab
1dad 2 1daf 1db1
2 1db3 1db5 3
1dba 1dbb 1dbc 2
1db7 1dbe 2 1da2
1dc0 1 1dc2 1
1dc4 2 1d8d 1dc5
1 1dc9 1 1d88
2 1d86 1dcd 1
1dda 2 1dd9 1dda
1 1de2 1 1de8
2 1dea 1deb 2
1dd7 1dec 1 1df3
1 1dee 2 1e06
1e08 3 1e04 1e05
1e0a 2 1e13 1e15
2 1e17 1e19 2
1e1b 1e1d 2 1e1f
1e21 2 1e23 1e25
3 1e2a 1e2b 1e2c
2 1e27 1e2e 2
1e12 1e30 1 1e32
1 1e34 2 1dfd
1e35 1 1e39 1
1df8 2 1df6 1e3d
4 1cf4 1d62 1dd0
1e40 2 1e43 1e44
4 1b24 1b27 1c09
1e45 1 1e47 3
1b06 1b18 1e48 1
1e4a 3 19fa 1a6f
1e4b 2 1e4f 1e50
1 1e54 2 1e52
1e54 1 1e56 2
1e5b 1e5c 1 1e60
2 1e5e 1e60 2
1e6d 1e6f 3 1e6b
1e6c 1e71 2 1e7a
1e7c 2 1e7e 1e80
2 1e82 1e84 1
1e8c 2 1e8e 1e8f
2 1e86 1e91 2
1e93 1e95 2 1e97
1e99 2 1e9b 1e9d
2 1e9f 1ea1 2
1e79 1ea3 1 1ea5
1 1ea7 2 1eb1
1eb3 3 1eaf 1eb0
1eb5 2 1ebe 1ec0
2 1ebd 1ec2 1
1ec4 1 1ec6 3
1ecd 1ece 1ecf 3
1ea8 1ec7 1ed1 2
1ed4 1ed3 1 1ed8
2 1ed6 1ed8 2
1edf 1ee0 1 1ee4
2 1ee2 1ee4 2
1ee9 1eea 1 1eee
2 1eec 1eee 2
1ef5 1ef6 1 1efa
2 1ef8 1efa 1
1f1e 2 1f1d 1f1e
1 1f26 1 1f2c
2 1f2e 1f2f 2
1f1b 1f30 1 1f37
1 1f32 2 1f4a
1f4c 3 1f48 1f49
1f4e 2 1f57 1f59
2 1f5b 1f5d 2
1f5f 1f61 2 1f63
1f65 2 1f67 1f69
3 1f6e 1f6f 1f70
2 1f6b 1f72 2
1f56 1f74 1 1f76
1 1f78 2 1f41
1f79 1 1f7d 1
1f3c 2 1f3a 1f81
1 1f84 1 1fac
2 1fab 1fac 1
1fb4 1 1fba 2
1fbc 1fbd 2 1fa9
1fbe 1 1fc5 1
1fc0 2 1fd8 1fda
3 1fd6 1fd7 1fdc
2 1fe5 1fe7 2
1fe9 1feb 2 1fed
1fef 2 1ff1 1ff3
2 1ff5 1ff7 3
1ffc 1ffd 1ffe 2
1ff9 2000 2 1fe4
2002 1 2004 1
2006 2 1fcf 2007
1 200b 1 1fca
2 1fc8 200f 1
2012 2 2015 2016
1 2017 2 201b
201c 1 2020 2
201e 2020 1 2040
2 203f 2040 1
2048 1 204e 2
2050 2051 2 203d
2052 1 2059 1
2054 2 206c 206e
3 206a 206b 2070
2 2079 207b 2
207d 207f 2 2081
2083 2 2085 2087
2 2089 208b 3
2090 2091 2092 2
208d 2094 2 2078
2096 1 2098 1
209a 2 2063 209b
1 209f 1 205e
2 205c 20a3 1
20a6 2 20ac 20ad
1 20b1 2 20af
20b1 2 20b5 20b6
1 20ba 2 20b8
20ba 1 20d6 2
20d5 20d6 1 20de
1 20e4 2 20e6
20e7 2 20d3 20e8
1 20ef 1 20ea
2 2102 2104 3
2100 2101 2106 2
210f 2111 2 2113
2115 2 2117 2119
2 211b 211d 2
211f 2121 3 2126
2127 2128 2 2123
212a 2 210e 212c
1 212e 1 2130
2 20f9 2131 1
2135 1 20f4 2
20f2 2139 1 213c
1 215c 2 215b
215c 1 2164 1
216a 2 216c 216d
2 2159 216e 1
2175 1 2170 2
2188 218a 3 2186
2187 218c 2 2195
2197 2 2199 219b
2 219d 219f 2
21a1 21a3 2 21a5
21a7 3 21ac 21ad
21ae 2 21a9 21b0
2 2194 21b2 1
21b4 1 21b6 2
217f 21b7 1 21bb
1 217a 2 2178
21bf 1 21c2 2
21c5 21c6 1 21c7
1 21d9 2 21d8
21d9 1 21e1 1
21e7 2 21e9 21ea
2 21d6 21eb 1
21f2 1 21ed 2
2205 2207 3 2203
2204 2209 2 2212
2214 2 2216 2218
2 221a 221c 2
221e 2220 2 2222
2224 3 2229 222a
222b 2 2226 222d
2 2211 222f 1
2231 1 2233 2
21fc 2234 1 2238
1 21f7 2 21f5
223c 1 223f 4
2242 20aa 21c9 2243
1 224d 2 224c
224d 1 2255 1
225b 2 225d 225e
2 224a 225f 1
2266 1 2261 2
2279 227b 3 2277
2278 227d 2 2286
2288 2 228a 228c
2 228e 2290 2
2292 2294 2 2296
2298 3 229d 229e
229f 2 229a 22a1
2 2285 22a3 1
22a5 1 22a7 2
2270 22a8 1 22ac
1 226b 2 2269
22b0 1 22bb 2
22ba 22bb 1 22c3
1 22c9 2 22cb
22cc 2 22b8 22cd
1 22d4 1 22cf
2 22e7 22e9 3
22e5 22e6 22eb 2
22f4 22f6 2 22f8
22fa 2 22fc 22fe
2 2300 2302 2
2304 2306 3 230b
230c 230d 2 2308
230f 2 22f3 2311
1 2313 1 2315
2 22de 2316 1
231a 1 22d9 2
22d7 231e 1 232b
2 232a 232b 1
2333 1 2339 2
233b 233c 2 2328
233d 1 2344 1
233f 2 2357 2359
3 2355 2356 235b
2 2364 2366 2
2368 236a 2 236c
236e 2 2370 2372
2 2374 2376 3
237b 237c 237d 2
2378 237f 2 2363
2381 1 2383 1
2385 2 234e 2386
1 238a 1 2349
2 2347 238e 5
1edd 2244 22b3 2321
2391 1 2394 1
2398 2 2396 2398
2 239c 239d 1
23a1 2 239f 23a1
1 23a8 2 23af
23b0 2 23b2 23b5
1 23b8 2 23ba
23bb 2 23c1 23c2
1 23c6 2 23c4
23c6 2 23ca 23cb
2 23d0 23d1 1
23d3 2 23cd 23d3
2 23d8 23d9 1
23dc 1 23de 2
23e9 23ea 1 23ee
2 23ec 23ee 1
23f3 1 23f7 2
23f9 23fa 2 23fd
23fe 1 2402 2
2400 2402 1 2407
1 2409 2 2410
2411 2 2415 2416
2 241a 241b 2
241f 2420 2 2424
2425 2 2429 242a
2 242e 242f 2
2433 2434 d 240d
240e 2413 2418 241d
2422 2427 242c 2431
2436 2437 2438 2439
2 243e 243f 1
2445 2 2441 2445
2 2450 2452 3
244e 244f 2454 2
245d 245f 2 2461
2463 2 2465 2467
1 246f 2 2471
2472 2 2469 2474
2 245c 2476 1
2478 1 247a 2
2484 2486 3 2482
2483 2488 2 2491
2493 2 2490 2495
1 2497 1 2499
2 24a0 24a1 3
247b 249a 24a3 2
24a7 24a8 1 24ac
2 24aa 24ac 2
24b7 24b9 3 24b5
24b6 24bb 2 24c4
24c6 2 24c8 24ca
2 24cc 24ce 1
24d4 2 24d6 24d7
2 24d0 24d9 2
24db 24dd 2 24df
24e1 2 24e3 24e5
2 24e7 24e9 2
24c3 24eb 1 24ed
1 24ef 2 24f9
24fb 3 24f7 24f8
24fd 2 2506 2508
2 2505 250a 1
250c 1 250e 2
2514 2515 3 2517
2518 2519 3 24f0
250f 251b 2 251e
251d 21 2525 2526
2527 2528 2529 252a
252b 252c 252d 252e
252f 2530 2531 2532
2533 2534 2535 2536
2537 2538 2539 253a
253b 253c 253d 253e
253f 2540 2541 2542
2543 2544 2545 1
254b 2 2549 254b
2 2556 2558 3
2554 2555 255a 2
2563 2565 2 2567
2569 2 256b 256d
1 2575 2 2577
2578 2 256f 257a
2 257c 257e 2
2580 2582 2 2584
2586 2 2588 258a
2 2562 258c 1
258e 1 2590 2
259a 259c 3 2598
2599 259e 2 25a7
25a9 2 25a6 25ab
1 25ad 1 25af
3 25b6 25b7 25b8
3 2591 25b0 25ba
1 25bf 2 25bd
25bf 2 25ca 25cc
3 25c8 25c9 25ce
2 25d7 25d9 2
25db 25dd 2 25df
25e1 1 25e9 2
25eb 25ec 2 25e3
25ee 2 25f0 25f2
2 25f4 25f6 2
25f8 25fa 2 25fc
25fe 2 25d6 2600
1 2602 1 2604
2 260e 2610 3
260c 260d 2612 2
261b 261d 2 261a
261f 1 2621 1
2623 3 262a 262b
262c 3 2605 2624
262e 2 263a 263b
2 263f 2640 5
2636 2637 2638 263d
2642 2 2633 2645
3 2647 2630 2648
a 23df 23e2 23e5
23fb 240a 243c 251f
2522 2548 2649 1
264b 3 23bc 23bf
264c 1 264e 2
265d 2662 1 2669
1 2664 2 267c
267e 3 267a 267b
2680 2 2689 268b
2 268d 268f 2
2691 2693 2 2695
2697 2 2699 269b
3 26a0 26a1 26a2
2 269d 26a4 2
2688 26a6 1 26a8
1 26aa 2 2673
26ab 1 26af 1
266e 2 266c 26b3
7 19ce 19d1 1ed5
2395 264f 2654 26b6
1 26b9 6 183b
18b8 18e5 18e8 19c1
26ba 1 26bc 2
26bd 26c0 1 26c2
2 26c6 26c8 3
26ca 26cb 26cc 2
26db 26e0 1 26e7
1 26e2 2 26fa
26fc 3 26f8 26f9
26fe 2 2707 2709
2 270b 270d 2
270f 2711 2 2713
2715 2 2717 2719
3 271e 271f 2720
2 271b 2722 2
2706 2724 1 2726
1 2728 2 26f1
2729 1 272d 1
26ec 2 26ea 2731
15 2749 274a 274b
274c 274d 274e 274f
2750 2751 2752 2753
2754 2755 2756 2757
2758 2759 275a 275b
275c 275d 1 2768
1 276e 2 2770
2771 1 2779 2
2775 2779 1 277e
1 2780 2 2786
2787 1 278b 2
2789 278b 2 2790
2791 1 279b 2
279a 279b 1 27a3
1 27a9 2 27ab
27ac 2 2798 27ad
1 27b4 1 27af
2 27c7 27c9 3
27c5 27c6 27cb 2
27d4 27d6 2 27d8
27da 2 27dc 27de
2 27e0 27e2 2
27e4 27e6 3 27eb
27ec 27ed 2 27e8
27ef 2 27d3 27f1
1 27f3 1 27f5
2 27be 27f6 1
27fa 1 27b9 2
27b7 27fe 1 2809
2 2808 2809 1
2811 1 2817 2
2819 281a 2 2806
281b 1 2822 1
281d 2 2835 2837
3 2833 2834 2839
2 2842 2844 2
2846 2848 2 284a
284c 2 284e 2850
2 2852 2854 3
2859 285a 285b 2
2856 285d 2 2841
285f 1 2861 1
2863 2 282c 2864
1 2868 1 2827
2 2825 286c 1
2877 2 2876 2877
1 287f 1 2885
2 2887 2888 2
2874 2889 1 2890
1 288b 2 28a3
28a5 3 28a1 28a2
28a7 2 28b0 28b2
2 28b4 28b6 2
28b8 28ba 2 28bc
28be 2 28c0 28c2
3 28c7 28c8 28c9
2 28c4 28cb 2
28af 28cd 1 28cf
1 28d1 2 289a
28d2 1 28d6 1
2895 2 2893 28da
1 28e7 2 28e6
28e7 1 28ef 1
28f5 2 28f7 28f8
2 28e4 28f9 1
2900 1 28fb 2
2913 2915 3 2911
2912 2917 2 2920
2922 2 2924 2926
2 2928 292a 2
292c 292e 2 2930
2932 3 2937 2938
2939 2 2934 293b
2 291f 293d 1
293f 1 2941 2
290a 2942 1 2946
1 2905 2 2903
294a 1 2955 2
2954 2955 1 295d
1 2963 2 2965
2966 2 2952 2967
1 296e 1 2969
2 2981 2983 3
297f 2980 2985 2
298e 2990 2 2992
2994 2 2996 2998
2 299a 299c 2
299e 29a0 3 29a5
29a6 29a7 2 29a2
29a9 2 298d 29ab
1 29ad 1 29af
2 2978 29b0 1
29b4 1 2973 2
2971 29b8 1 29c3
2 29c2 29c3 1
29cb 1 29d1 2
29d3 29d4 2 29c0
29d5 1 29dc 1
29d7 2 29ef 29f1
3 29ed 29ee 29f3
2 29fc 29fe 2
2a00 2a02 2 2a04
2a06 2 2a08 2a0a
2 2a0c 2a0e 3
2a13 2a14 2a15 2
2a10 2a17 2 29fb
2a19 1 2a1b 1
2a1d 2 29e6 2a1e
1 2a22 1 29e1
2 29df 2a26 7
2794 2801 286f 28dd
294d 29bb 2a29 2
2a2d 2a2e 1 2a32
2 2a30 2a32 1
2a37 1 2a39 1
2a47 2 2a46 2a47
1 2a4f 1 2a55
2 2a57 2a58 2
2a44 2a59 1 2a60
1 2a5b 2 2a73
2a75 3 2a71 2a72
2a77 2 2a80 2a82
2 2a84 2a86 2
2a88 2a8a 2 2a8c
2a8e 2 2a90 2a92
3 2a97 2a98 2a99
2 2a94 2a9b 2
2a7f 2a9d 1 2a9f
1 2aa1 2 2a6a
2aa2 1 2aa6 1
2a65 2 2a63 2aaa
1 2ab1 a 2ab9
2aba 2abb 2abc 2abd
2abe 2abf 2ac0 2ac1
2ac2 2 2ad2 2ad7
1 2ade 1 2ad9
2 2af1 2af3 3
2aef 2af0 2af5 2
2afe 2b00 2 2b02
2b04 2 2b06 2b08
2 2b0a 2b0c 2
2b0e 2b10 3 2b15
2b16 2b17 2 2b12
2b19 2 2afd 2b1b
1 2b1d 1 2b1f
2 2ae8 2b20 1
2b24 1 2ae3 2
2ae1 2b28 1 2b33
2 2b2f 2b33 2
2b46 2b4b 1 2b52
1 2b4d 2 2b65
2b67 3 2b63 2b64
2b69 2 2b72 2b74
2 2b76 2b78 2
2b7a 2b7c 2 2b7e
2b80 2 2b82 2b84
3 2b89 2b8a 2b8b
2 2b86 2b8d 2
2b71 2b8f 1 2b91
1 2b93 2 2b5c
2b94 1 2b98 1
2b57 2 2b55 2b9c
1 2ba7 2 2ba3
2ba7 2 2bad 2bae
2 2bb0 2bb3 1
2bba 2 2bb6 2bba
1 2bcb 2 2bca
2bcb 1 2bd3 1
2bd9 2 2bdb 2bdc
2 2bc8 2bdd 1
2be4 1 2bdf 2
2bf7 2bf9 3 2bf5
2bf6 2bfb 2 2c04
2c06 2 2c08 2c0a
2 2c0c 2c0e 2
2c10 2c12 2 2c14
2c16 3 2c1b 2c1c
2c1d 2 2c18 2c1f
2 2c03 2c21 1
2c23 1 2c25 2
2bee 2c26 1 2c2a
1 2be9 2 2be7
2c2e 2 2bbf 2c31
2 2c36 2c37 1
2c3d 2 2c39 2c3d
2 2c44 2c45 4
2c42 2c47 2c4a 2c4b
1 2c5f 2 2c5e
2c5f 1 2c67 1
2c6d 2 2c6f 2c70
2 2c5c 2c71 1
2c78 1 2c73 2
2c8b 2c8d 3 2c89
2c8a 2c8f 2 2c98
2c9a 2 2c9c 2c9e
2 2ca0 2ca2 2
2ca4 2ca6 2 2ca8
2caa 3 2caf 2cb0
2cb1 2 2cac 2cb3
2 2c97 2cb5 1
2cb7 1 2cb9 2
2c82 2cba 1 2cbe
1 2c7d 2 2c7b
2cc2 2 2c4e 2cc5
1 2cdc 2 2cdb
2cdc 1 2ce4 1
2cea 2 2cec 2ced
2 2cd9 2cee 1
2cf5 1 2cf0 2
2d08 2d0a 3 2d06
2d07 2d0c 2 2d15
2d17 2 2d19 2d1b
2 2d1d 2d1f 2
2d21 2d23 2 2d25
2d27 3 2d2c 2d2d
2d2e 2 2d29 2d30
2 2d14 2d32 1
2d34 1 2d36 2
2cff 2d37 1 2d3b
1 2cfa 2 2cf8
2d3f 1 2d42 3
2d45 2cc8 2d46 1
2d4e 2 2d4a 2d4e
2 2d53 2d54 1
2d58 2 2d56 2d58
1 2d64 2 2d63
2d64 1 2d6c 1
2d72 2 2d74 2d75
2 2d61 2d76 1
2d7d 1 2d78 2
2d90 2d92 3 2d8e
2d8f 2d94 2 2d9d
2d9f 2 2da1 2da3
2 2da5 2da7 2
2da9 2dab 2 2dad
2daf 3 2db4 2db5
2db6 2 2db1 2db8
2 2d9c 2dba 1
2dbc 1 2dbe 2
2d87 2dbf 1 2dc3
1 2d82 2 2d80
2dc7 1 2dca 1
2dcd 2 2d47 2dce
2 2df2 2df7 1
2dfe 1 2df9 2
2e11 2e13 3 2e0f
2e10 2e15 2 2e1e
2e20 2 2e22 2e24
2 2e26 2e28 2
2e2a 2e2c 2 2e2e
2e30 3 2e35 2e36
2e37 2 2e32 2e39
2 2e1d 2e3b 1
2e3d 1 2e3f 2
2e08 2e40 1 2e44
1 2e03 2 2e01
2e48 1 2e53 2
2e4f 2e53 1 2e57
2 2e63 2e64 4
2e61 2e66 2e69 2e6a
1 2e74 2 2e73
2e74 1 2e7c 1
2e82 2 2e84 2e85
2 2e71 2e86 1
2e8d 1 2e88 2
2ea0 2ea2 3 2e9e
2e9f 2ea4 2 2ead
2eaf 2 2eb1 2eb3
2 2eb5 2eb7 2
2eb9 2ebb 2 2ebd
2ebf 3 2ec4 2ec5
2ec6 2 2ec1 2ec8
2 2eac 2eca 1
2ecc 1 2ece 2
2e97 2ecf 1 2ed3
1 2e92 2 2e90
2ed7 1 2eea 2
2ee9 2eea 1 2ef2
1 2ef8 2 2efa
2efb 2 2ee7 2efc
1 2f03 1 2efe
2 2f16 2f18 3
2f14 2f15 2f1a 2
2f23 2f25 2 2f27
2f29 2 2f2b 2f2d
2 2f2f 2f31 2
2f33 2f35 3 2f3a
2f3b 2f3c 2 2f37
2f3e 2 2f22 2f40
1 2f42 1 2f44
2 2f0d 2f45 1
2f49 1 2f08 2
2f06 2f4d 1 2f5d
2 2f5c 2f5d 1
2f65 1 2f6b 2
2f6d 2f6e 2 2f5a
2f6f 1 2f76 1
2f71 2 2f89 2f8b
3 2f87 2f88 2f8d
2 2f96 2f98 2
2f9a 2f9c 2 2f9e
2fa0 2 2fa2 2fa4
2 2fa6 2fa8 3
2fad 2fae 2faf 2
2faa 2fb1 2 2f95
2fb3 1 2fb5 1
2fb7 2 2f80 2fb8
1 2fbc 1 2f7b
2 2f79 2fc0 4
2e6d 2eda 2f50 2fc3
1 2fd1 2 2fd0
2fd1 1 2fd9 1
2fdf 2 2fe1 2fe2
2 2fce 2fe3 1
2fea 1 2fe5 2
2ffd 2fff 3 2ffb
2ffc 3001 2 300a
300c 2 300e 3010
2 3012 3014 2
3016 3018 2 301a
301c 3 3021 3022
3023 2 301e 3025
2 3009 3027 1
3029 1 302b 2
2ff4 302c 1 3030
1 2fef 2 2fed
3034 1 3042 2
3041 3042 1 304a
1 3050 2 3052
3053 2 303f 3054
1 305b 1 3056
2 306e 3070 3
306c 306d 3072 2
307b 307d 2 307f
3081 2 3083 3085
2 3087 3089 2
308b 308d 3 3092
3093 3094 2 308f
3096 2 307a 3098
1 309a 1 309c
2 3065 309d 1
30a1 1 3060 2
305e 30a5 2 3037
30a8 2 30ab 30ac
2 2e4b 30ad 2
30af 30b0 1 30ba
2 30b9 30ba 1
30c2 1 30c8 2
30ca 30cb 2 30b7
30cc 1 30d3 1
30ce 2 30e6 30e8
3 30e4 30e5 30ea
2 30f3 30f5 2
30f7 30f9 2 30fb
30fd 2 30ff 3101
2 3103 3105 3
310a 310b 310c 2
3107 310e 2 30f2
3110 1 3112 1
3114 2 30dd 3115
1 3119 1 30d8
2 30d6 311d 4
2b39 2b9f 30b1 3120
1 312c 2 312b
312c 1 3134 1
313a 2 313c 313d
2 3129 313e 1
3145 1 3140 2
3158 315a 3 3156
3157 315c 2 3165
3167 2 3169 316b
2 316d 316f 2
3171 3173 2 3175
3177 3 317c 317d
317e 2 3179 3180
2 3164 3182 1
3184 1 3186 2
314f 3187 1 318b
1 314a 2 3148
318f 1 319a 2
3199 319a 1 31a2
1 31a8 2 31aa
31ab 2 3197 31ac
1 31b3 1 31ae
2 31c6 31c8 3
31c4 31c5 31ca 2
31d3 31d5 2 31d7
31d9 2 31db 31dd
2 31df 31e1 2
31e3 31e5 3 31ea
31eb 31ec 2 31e7
31ee 2 31d2 31f0
1 31f2 1 31f4
2 31bd 31f5 1
31f9 1 31b8 2
31b6 31fd 1 320a
2 3209 320a 1
3212 1 3218 2
321a 321b 2 3207
321c 1 3223 1
321e 2 3236 3238
3 3234 3235 323a
2 3243 3245 2
3247 3249 2 324b
324d 2 324f 3251
2 3253 3255 3
325a 325b 325c 2
3257 325e 2 3242
3260 1 3262 1
3264 2 322d 3265
1 3269 1 3228
2 3226 326d 3
3273 3274 3275 1
3279 2 3277 3279
1 327e 1 3280
6 3125 3192 3200
3270 3281 3284 2
3286 3287 2 328a
328b 1 328f 2
328d 328f 2 3293
3294 1 3298 2
3296 3298 1 329c
2 32ab 32b0 1
32b7 1 32b2 2
32ca 32cc 3 32c8
32c9 32ce 2 32d7
32d9 2 32db 32dd
2 32df 32e1 2
32e3 32e5 2 32e7
32e9 3 32ee 32ef
32f0 2 32eb 32f2
2 32d6 32f4 1
32f6 1 32f8 2
32c1 32f9 1 32fd
1 32bc 2 32ba
3301 1 330c 2
3308 330c 2 3311
3312 1 3316 2
3314 3316 1 3324
2 3323 3324 1
332c 1 3332 2
3334 3335 2 3321
3336 1 333d 1
3338 2 3350 3352
3 334e 334f 3354
2 335d 335f 2
3361 3363 2 3365
3367 2 3369 336b
2 336d 336f 3
3374 3375 3376 2
3371 3378 2 335c
337a 1 337c 1
337e 2 3347 337f
1 3383 1 3342
2 3340 3387 1
338a 1 3394 2
3390 3394 2 3399
339a 1 339e 2
339c 339e 2 33a6
33ac 1 33b3 1
33ae 2 33c6 33c8
3 33c4 33c5 33ca
2 33d3 33d5 2
33d7 33d9 2 33db
33dd 2 33df 33e1
2 33e3 33e5 3
33ea 33eb 33ec 2
33e7 33ee 2 33d2
33f0 1 33f2 1
33f4 2 33bd 33f5
1 33f9 1 33b8
2 33b6 33fd 2
340a 340c 3 3408
3409 340e 2 3417
3419 2 341b 341d
2 341f 3421 1
3429 2 342b 342c
2 3423 342e 2
3430 3432 2 3434
3436 2 3438 343a
2 343c 343e 2
3416 3440 1 3442
1 3444 2 344e
3450 3 344c 344d
3452 2 345b 345d
2 345a 345f 1
3461 1 3463 3
346a 346b 346c 4
3400 3445 3464 346e
2 3471 3470 2
3304 3472 1 3474
2 3477 3478 1
347e 2 347a 347e
2 3482 3483 1
3489 2 3485 3489
2 3499 349a 1
349e 2 349c 349e
2 34a2 34a3 1
34a7 2 34a5 34a7
1 34bf 2 34be
34bf 1 34c7 1
34cd 2 34cf 34d0
2 34bc 34d1 1
34d8 1 34d3 2
34eb 34ed 3 34e9
34ea 34ef 2 34f8
34fa 2 34fc 34fe
2 3500 3502 2
3504 3506 2 3508
350a 3 350f 3510
3511 2 350c 3513
2 34f7 3515 1
3517 1 3519 2
34e2 351a 1 351e
1 34dd 2 34db
3522 1 3525 1
3547 2 3546 3547
1 354f 1 3555
2 3557 3558 2
3544 3559 1 3560
1 355b 2 3573
3575 3 3571 3572
3577 2 3580 3582
2 3584 3586 2
3588 358a 2 358c
358e 2 3590 3592
3 3597 3598 3599
2 3594 359b 2
357f 359d 1 359f
1 35a1 2 356a
35a2 1 35a6 1
3565 2 3563 35aa
1 35ad 2 35b0
35b1 1 35b9 2
35b5 35b9 2 35c7
35cc 1 35d3 1
35ce 2 35e6 35e8
3 35e4 35e5 35ea
2 35f3 35f5 2
35f7 35f9 2 35fb
35fd 2 35ff 3601
2 3603 3605 3
360a 360b 360c 2
3607 360e 2 35f2
3610 1 3612 1
3614 2 35dd 3615
1 3619 1 35d8
2 35d6 361d 2
3623 3624 1 3628
2 3626 3628 1
362c 1 3636 2
3635 3636 1 363e
1 3644 2 3646
3647 2 3633 3648
1 364f 1 364a
2 3662 3664 3
3660 3661 3666 2
366f 3671 2 3673
3675 2 3677 3679
2 367b 367d 2
367f 3681 3 3686
3687 3688 2 3683
368a 2 366e 368c
1 368e 1 3690
2 3659 3691 1
3695 1 3654 2
3652 3699 1 36a2
2 36a4 36a5 1
36ab 2 36ad 36ae
2 36a7 36b0 2
36b3 36b5 1 36b7
2 36c4 36c9 1
36d0 1 36cb 2
36e3 36e5 3 36e1
36e2 36e7 2 36f0
36f2 2 36f4 36f6
2 36f8 36fa 2
36fc 36fe 2 3700
3702 3 3707 3708
3709 2 3704 370b
2 36ef 370d 1
370f 1 3711 2
36da 3712 1 3716
1 36d5 2 36d3
371a 2 3720 3721
2 3726 3727 1
3729 2 3723 3729
2 3730 3731 2
3733 3734 1 3736
1 3738 1 3753
2 3752 3753 1
375b 1 3761 2
3763 3764 2 3750
3765 1 376c 1
3767 2 377f 3781
3 377d 377e 3783
2 378c 378e 2
3790 3792 2 3794
3796 2 3798 379a
2 379c 379e 3
37a3 37a4 37a5 2
37a0 37a7 2 378b
37a9 1 37ab 1
37ad 2 3776 37ae
1 37b2 1 3771
2 376f 37b6 5
369c 36ba 371d 3739
37b9 2 37bc 37bd
1 37e1 2 37e0
37e1 1 37e9 1
37ef 2 37f1 37f2
2 37de 37f3 1
37fa 1 37f5 2
380d 380f 3 380b
380c 3811 2 381a
381c 2 381e 3820
2 3822 3824 2
3826 3828 2 382a
382c 3 3831 3832
3833 2 382e 3835
2 3819 3837 1
3839 1 383b 2
3804 383c 1 3840
1 37ff 2 37fd
3844 1 384d 2
384f 3850 1 3856
2 3858 3859 2
3852 385b 2 385e
3860 1 3862 2
386b 386c 2 386e
3871 2 387b 387c
2 3880 3881 5
3877 3878 3879 387e
3883 7 35bf 3620
37be 3847 3865 3874
3886 1 3889 2
388b 388c 4 3492
3497 35b2 388d 1
3894 2 3892 3894
2 3898 3899 1
389d 2 389b 389d
2 38a4 38a5 1
38a9 2 38a7 38a9
2 38ad 38ae 1
38b2 2 38b0 38b2
2 38b8 38b9 1
38bd 2 38bb 38bd
2 38c7 38c8 2
38c4 38cb 1 38cd
1 38de 2 38dd
38de 1 38e6 1
38ec 2 38ee 38ef
2 38db 38f0 1
38f7 1 38f2 2
390a 390c 3 3908
3909 390e 2 3917
3919 2 391b 391d
2 391f 3921 2
3923 3925 2 3927
3929 3 392e 392f
3930 2 392b 3932
2 3916 3934 1
3936 1 3938 2
3901 3939 1 393d
1 38fc 2 38fa
3941 3 38a2 38ce
3944 2 3964 3965
2 3967 396a 1
396f 2 396d 396f
2 3974 3975 2
397a 397b 1 397d
2 3977 397d 2
3981 3982 2 3987
3988 1 398a 2
3984 398a 2 3993
3994 1 3998 2
3996 3998 1 39c3
2 39c2 39c3 1
39cb 1 39d1 2
39d3 39d4 2 39c0
39d5 1 39dc 1
39d7 2 39ef 39f1
3 39ed 39ee 39f3
2 39fc 39fe 2
3a00 3a02 2 3a04
3a06 2 3a08 3a0a
2 3a0c 3a0e 3
3a13 3a14 3a15 2
3a10 3a17 2 39fb
3a19 1 3a1b 1
3a1d 2 39e6 3a1e
1 3a22 1 39e1
2 39df 3a26 1
3a29 1 3a56 2
3a55 3a56 1 3a5e
1 3a64 2 3a66
3a67 2 3a53 3a68
1 3a6f 1 3a6a
2 3a82 3a84 3
3a80 3a81 3a86 2
3a8f 3a91 2 3a93
3a95 2 3a97 3a99
2 3a9b 3a9d 2
3a9f 3aa1 3 3aa6
3aa7 3aa8 2 3aa3
3aaa 2 3a8e 3aac
1 3aae 1 3ab0
2 3a79 3ab1 1
3ab5 1 3a74 2
3a72 3ab9 1 3abc
2 3abf 3ac0 1
3ac1 1 3ae7 2
3ae6 3ae7 1 3aef
1 3af5 2 3af7
3af8 2 3ae4 3af9
1 3b00 1 3afb
2 3b13 3b15 3
3b11 3b12 3b17 2
3b20 3b22 2 3b24
3b26 2 3b28 3b2a
2 3b2c 3b2e 2
3b30 3b32 3 3b37
3b38 3b39 2 3b34
3b3b 2 3b1f 3b3d
1 3b3f 1 3b41
2 3b0a 3b42 1
3b46 1 3b05 2
3b03 3b4a 1 3b4d
2 3b50 3b51 2
3b54 3b55 1 3b59
2 3b57 3b59 2
3b5e 3b5f 1 3b63
2 3b61 3b63 1
3b6b 2 3b6f 3b70
1 3b74 2 3b72
3b74 2 3b79 3b7a
1 3b7d 2 3b80
3b7f b 3949 394c
394f 3952 3955 3958
395b 395e 3961 3b52
3b81 2 3b83 3b84
2 3b8b 3b8c 2
3b90 3b91 2 3b95
3b96 2 3b9a 3b9b
2 3b9f 3ba0 2
3ba4 3ba5 2 3ba9
3baa 2 3bae 3baf
d 3b88 3b89 3b8e
3b93 3b98 3b9d 3ba2
3ba7 3bac 3bb1 3bb2
3bb3 3bb4 2 3bb9
3bba 1 3bc0 2
3bbc 3bc0 2 3bc5
3bcb 1 3bd2 1
3bcd 2 3be5 3be7
3 3be3 3be4 3be9
2 3bf2 3bf4 2
3bf6 3bf8 2 3bfa
3bfc 2 3bfe 3c00
2 3c02 3c04 3
3c09 3c0a 3c0b 2
3c06 3c0d 2 3bf1
3c0f 1 3c11 1
3c13 2 3bdc 3c14
1 3c18 1 3bd7
2 3bd5 3c1c 2
3c29 3c2b 3 3c27
3c28 3c2d 2 3c36
3c38 2 3c3a 3c3c
2 3c3e 3c40 1
3c48 2 3c4a 3c4b
2 3c42 3c4d 2
3c35 3c4f 1 3c51
1 3c53 2 3c5d
3c5f 3 3c5b 3c5c
3c61 2 3c6a 3c6c
2 3c69 3c6e 1
3c70 1 3c72 2
3c79 3c7a 4 3c1f
3c54 3c73 3c7c 2
3c80 3c81 1 3c85
2 3c83 3c85 2
3c8a 3c90 1 3c97
1 3c92 2 3caa
3cac 3 3ca8 3ca9
3cae 2 3cb7 3cb9
2 3cbb 3cbd 2
3cbf 3cc1 2 3cc3
3cc5 2 3cc7 3cc9
3 3cce 3ccf 3cd0
2 3ccb 3cd2 2
3cb6 3cd4 1 3cd6
1 3cd8 2 3ca1
3cd9 1 3cdd 1
3c9c 2 3c9a 3ce1
2 3cee 3cf0 3
3cec 3ced 3cf2 2
3cfb 3cfd 2 3cff
3d01 2 3d03 3d05
1 3d0b 2 3d0d
3d0e 2 3d07 3d10
2 3d12 3d14 2
3d16 3d18 2 3d1a
3d1c 2 3d1e 3d20
2 3cfa 3d22 1
3d24 1 3d26 2
3d30 3d32 3 3d2e
3d2f 3d34 2 3d3d
3d3f 2 3d3c 3d41
1 3d43 1 3d45
2 3d4b 3d4c 3
3d4e 3d4f 3d50 4
3ce4 3d27 3d46 3d52
2 3d55 3d54 3
3b85 3bb7 3d56 2
3d59 3d5a 1 3d5e
2 3d5c 3d5e 2
3d62 3d63 1 3d67
2 3d65 3d67 2
3d6d 3d6e 1 3d72
2 3d70 3d72 2
3d7c 3d7d 2 3d79
3d80 1 3d82 2
3d85 3d86 1 3d8a
2 3d88 3d8a 2
3d8f 3d90 2 3d95
3d96 1 3d98 2
3d92 3d98 2 3da0
3da1 1 3da4 2
3da9 3daa 2 3daf
3db0 2 3dac 3db2
1 3db4 1 3db7
2 3db9 3dba 2
3dbd 3dbe 1 3dc2
2 3dc0 3dc2 2
3dc7 3dc8 2 3dca
3dcc 1 3dcf 2
3dd5 3dd6 1 3dd8
2 3dda 3ddc 1
3dde 1 3de1 2
3de3 3de4 2 3de7
3de8 1 3dec 2
3dea 3dec 1 3dfe
2 3dfd 3dfe 1
3e06 1 3e0c 2
3e0e 3e0f 2 3dfb
3e10 1 3e17 1
3e12 2 3e2a 3e2c
3 3e28 3e29 3e2e
2 3e37 3e39 2
3e3b 3e3d 2 3e3f
3e41 2 3e43 3e45
2 3e47 3e49 3
3e4e 3e4f 3e50 2
3e4b 3e52 2 3e36
3e54 1 3e56 1
3e58 2 3e21 3e59
1 3e5d 1 3e1c
2 3e1a 3e61 1
3e64 1 3e8b 2
3e8a 3e8b 1 3e93
1 3e99 2 3e9b
3e9c 2 3e88 3e9d
1 3ea4 1 3e9f
2 3eb7 3eb9 3
3eb5 3eb6 3ebb 2
3ec4 3ec6 2 3ec8
3eca 2 3ecc 3ece
2 3ed0 3ed2 2
3ed4 3ed6 3 3edb
3edc 3edd 2 3ed8
3edf 2 3ec3 3ee1
1 3ee3 1 3ee5
2 3eae 3ee6 1
3eea 1 3ea9 2
3ea7 3eee 1 3ef1
2 3ef4 3ef5 4
3d83 3dbb 3de5 3ef6
2 3ef8 3ef9 2
3eff 3f00 1 3f06
2 3f02 3f06 1
3f0b 1 3f0f 2
3f11 3f12 2 3f15
3f16 1 3f1a 2
3f18 3f1a 1 3f21
2 3f28 3f29 2
3f2b 3f2e 1 3f31
2 3f33 3f34 2
3f3a 3f3b 1 3f3f
2 3f3d 3f3f 2
3f43 3f44 1 3f48
2 3f46 3f48 2
3f4e 3f4f 2 3f54
3f55 2 3f51 3f57
2 3f5a 3f5c 2
3f5f 3f61 1 3f63
2 3f68 3f69 2
3f6e 3f6f 1 3f71
2 3f6b 3f71 2
3f76 3f77 2 3f7e
3f7f 2 3f81 3f83
2 3f89 3f8a 2
3f86 3f8c 2 3f8e
3f90 1 3f92 2
3f7a 3f95 1 3f97
2 3f66 3f98 2
3f9c 3f9d 2 3fa2
3fa3 1 3fa5 2
3f9f 3fa5 2 3faa
3fab 1 3fae 2
3fb1 3fb0 1 3fb2
1 3fb4 21 3fb8
3fb9 3fba 3fbb 3fbc
3fbd 3fbe 3fbf 3fc0
3fc1 3fc2 3fc3 3fc4
3fc5 3fc6 3fc7 3fc8
3fc9 3fca 3fcb 3fcc
3fcd 3fce 3fcf 3fd0
3fd1 3fd2 3fd3 3fd4
3fd5 3fd6 3fd7 3fd8
1 3fde 2 3fdc
3fde 2 3fe3 3fe9
1 3ff0 1 3feb
2 4003 4005 3
4001 4002 4007 2
4010 4012 2 4014
4016 2 4018 401a
2 401c 401e 2
4020 4022 3 4027
4028 4029 2 4024
402b 2 400f 402d
1 402f 1 4031
2 3ffa 4032 1
4036 1 3ff5 2
3ff3 403a 2 4047
4049 3 4045 4046
404b 2 4054 4056
2 4058 405a 2
405c 405e 1 4066
2 4068 4069 2
4060 406b 2 406d
406f 2 4071 4073
2 4075 4077 2
4079 407b 2 4053
407d 1 407f 1
4081 2 408b 408d
3 4089 408a 408f
2 4098 409a 2
4097 409c 1 409e
1 40a0 3 40a7
40a8 40a9 4 403d
4082 40a1 40ab 1
40b0 2 40ae 40b0
2 40b5 40bb 1
40c2 1 40bd 2
40d5 40d7 3 40d3
40d4 40d9 2 40e2
40e4 2 40e6 40e8
2 40ea 40ec 2
40ee 40f0 2 40f2
40f4 3 40f9 40fa
40fb 2 40f6 40fd
2 40e1 40ff 1
4101 1 4103 2
40cc 4104 1 4108
1 40c7 2 40c5
410c 2 4119 411b
3 4117 4118 411d
2 4126 4128 2
412a 412c 2 412e
4130 1 4138 2
413a 413b 2 4132
413d 2 413f 4141
2 4143 4145 2
4147 4149 2 414b
414d 2 4125 414f
1 4151 1 4153
2 415d 415f 3
415b 415c 4161 2
416a 416c 2 4169
416e 1 4170 1
4172 3 4179 417a
417b 4 410f 4154
4173 417d 2 4180
417f 9 3891 3efa
3efd 3f13 3f35 3f38
3fb5 3fdb 4181 2
4183 4184 1 4190
2 418f 4190 1
4198 1 419e 2
41a0 41a1 2 418d
41a2 1 41a9 1
41a4 2 41bc 41be
3 41ba 41bb 41c0
2 41c9 41cb 2
41cd 41cf 2 41d1
41d3 2 41d5 41d7
2 41d9 41db 3
41e0 41e1 41e2 2
41dd 41e4 2 41c8
41e6 1 41e8 1
41ea 2 41b3 41eb
1 41ef 1 41ae
2 41ac 41f3 1
4213 2 4212 4213
1 421b 1 4221
2 4223 4224 2
4210 4225 1 422c
1 4227 2 423f
4241 3 423d 423e
4243 2 424c 424e
2 4250 4252 2
4254 4256 2 4258
425a 2 425c 425e
3 4263 4264 4265
2 4260 4267 2
424b 4269 1 426b
1 426d 2 4236
426e 1 4272 1
4231 2 422f 4276
1 4289 2 4288
4289 1 4291 1
4297 2 4299 429a
2 4286 429b 1
42a2 1 429d 2
42b5 42b7 3 42b3
42b4 42b9 2 42c2
42c4 2 42c6 42c8
2 42ca 42cc 2
42ce 42d0 2 42d2
42d4 3 42d9 42da
42db 2 42d6 42dd
2 42c1 42df 1
42e1 1 42e3 2
42ac 42e4 1 42e8
1 42a7 2 42a5
42ec 1 42ff 2
42fe 42ff 1 4307
1 430d 2 430f
4310 2 42fc 4311
1 4318 1 4313
2 432b 432d 3
4329 432a 432f 2
4338 433a 2 433c
433e 2 4340 4342
2 4344 4346 2
4348 434a 3 434f
4350 4351 2 434c
4353 2 4337 4355
1 4357 1 4359
2 4322 435a 1
435e 1 431d 2
431b 4362 2 4369
436a 2 436c 436e
2 4374 4375 2
437a 437b 2 4377
437d 3 4386 4387
4388 3 4391 4392
4393 1 43a1 2
43a0 43a1 1 43a9
1 43af 2 43b1
43b2 2 439e 43b3
1 43ba 1 43b5
2 43cd 43cf 3
43cb 43cc 43d1 2
43da 43dc 2 43de
43e0 2 43e2 43e4
2 43e6 43e8 2
43ea 43ec 3 43f1
43f2 43f3 2 43ee
43f5 2 43d9 43f7
1 43f9 1 43fb
2 43c4 43fc 1
4400 1 43bf 2
43bd 4404 2 440a
440b 1 440f 2
440d 440f 2 4414
4415 1 4419 2
4417 4419 1 4433
2 4432 4433 1
443b 1 4441 2
4443 4444 2 4430
4445 1 444c 1
4447 2 445f 4461
3 445d 445e 4463
2 446c 446e 2
4470 4472 2 4474
4476 2 4478 447a
2 447c 447e 3
4483 4484 4485 2
4480 4487 2 446b
4489 1 448b 1
448d 2 4456 448e
1 4492 1 4451
2 444f 4496 1
4499 2 449e 449f
1 44a3 2 44a1
44a3 1 44b6 2
44b5 44b6 1 44be
1 44c4 2 44c6
44c7 2 44b3 44c8
1 44cf 1 44ca
2 44e2 44e4 3
44e0 44e1 44e6 2
44ef 44f1 2 44f3
44f5 2 44f7 44f9
2 44fb 44fd 2
44ff 4501 3 4506
4507 4508 2 4503
450a 2 44ee 450c
1 450e 1 4510
2 44d9 4511 1
4515 1 44d4 2
44d2 4519 2 4520
4521 2 451c 4524
2 4529 452a 1
452e 2 452c 452e
1 4541 2 4540
4541 1 4549 1
454f 2 4551 4552
2 453e 4553 1
455a 1 4555 2
456d 456f 3 456b
456c 4571 2 457a
457c 2 457e 4580
2 4582 4584 2
4586 4588 2 458a
458c 3 4591 4592
4593 2 458e 4595
2 4579 4597 1
4599 1 459b 2
4564 459c 1 45a0
1 455f 2 455d
45a4 2 45ab 45ac
2 45a7 45af 1
45be 2 45bd 45be
1 45c6 1 45cc
2 45ce 45cf 2
45bb 45d0 1 45d7
1 45d2 2 45ea
45ec 3 45e8 45e9
45ee 2 45f7 45f9
2 45fb 45fd 2
45ff 4601 2 4603
4605 2 4607 4609
3 460e 460f 4610
2 460b 4612 2
45f6 4614 1 4616
1 4618 2 45e1
4619 1 461d 1
45dc 2 45da 4621
2 4628 4629 2
462f 4630 3 4624
462c 4633 4 4635
4527 45b1 4636 e
3475 4185 41f6 4279
42ef 4365 4371 4380
4383 438b 438e 4396
4407 4637 1 4639
7 2a3a 2aad 2ab4
2ac5 2b2b 3288 463a
2 463c 463d 3
4643 4644 4645 1
4649 7 275e 2772
2781 2784 463e 4648
464c 2 4652 4658
1 465f 1 465a
2 4672 4674 3
4670 4671 4676 2
467f 4681 2 4683
4685 2 4687 4689
2 468b 468d 2
468f 4691 3 4696
4697 4698 2 4693
469a 2 467e 469c
1 469e 1 46a0
2 4669 46a1 1
46a5 1 4664 2
4662 46a9 2 46b2
46b3 1 46b7 2
46b5 46b7 2 46be
46bf 2 46c4 46c5
1 46c7 2 46c1
46c7 2 46cc 46cd
2 46d2 46d3 2
46cf 46d5 2 46da
46db 1 46df 2
46dd 46df 2 46e4
46e5 1 46e9 2
46e7 46e9 1 46ef
2 4710 4711 1
4715 2 4713 4715
2 471a 471b 1
471f 2 471d 471f
1 4727 2 472b
472c 1 4730 2
472e 4730 2 4735
4736 1 4739 2
473c 473b 2 4743
4744 2 4748 4749
2 474d 474e 2
4752 4753 2 4757
4758 2 475c 475d
2 4761 4762 2
4766 4767 d 4740
4741 4746 474b 4750
4755 475a 475f 4764
4769 476a 476b 476c
2 4771 4772 1
4778 2 4774 4778
2 4783 4785 3
4781 4782 4787 2
4790 4792 2 4794
4796 2 4798 479a
1 47a2 2 47a4
47a5 2 479c 47a7
2 478f 47a9 1
47ab 1 47ad 2
47b7 47b9 3 47b5
47b6 47bb 2 47c4
47c6 2 47c3 47c8
1 47ca 1 47cc
2 47d3 47d4 3
47ae 47cd 47d6 2
47da 47db 1 47df
2 47dd 47df 2
47ea 47ec 3 47e8
47e9 47ee 2 47f7
47f9 2 47fb 47fd
2 47ff 4801 1
4807 2 4809 480a
2 4803 480c 2
480e 4810 2 4812
4814 2 4816 4818
2 481a 481c 2
47f6 481e 1 4820
1 4822 2 482c
482e 3 482a 482b
4830 2 4839 483b
2 4838 483d 1
483f 1 4841 2
4847 4848 3 484a
484b 484c 3 4823
4842 484e 2 4851
4850 1 486a 2
4869 486a 1 4872
1 4878 2 487a
487b 2 4867 487c
1 4883 1 487e
2 4896 4898 3
4894 4895 489a 2
48a3 48a5 2 48a7
48a9 2 48ab 48ad
2 48af 48b1 2
48b3 48b5 3 48ba
48bb 48bc 2 48b7
48be 2 48a2 48c0
1 48c2 1 48c4
2 488d 48c5 1
48c9 1 4888 2
4886 48cd 2 48e2
48e3 1 48e7 2
48e5 48e7 2 48ef
48f0 2 48f2 48f5
2 48f8 48fb 1
48ff 2 4901 4902
21 4909 490a 490b
490c 490d 490e 490f
4910 4911 4912 4913
4914 4915 4916 4917
4918 4919 491a 491b
491c 491d 491e 491f
4920 4921 4922 4923
4924 4925 4926 4927
4928 4929 1 492f
2 492d 492f 2
493a 493c 3 4938
4939 493e 2 4947
4949 2 494b 494d
2 494f 4951 1
4959 2 495b 495c
2 4953 495e 2
4960 4962 2 4964
4966 2 4968 496a
2 496c 496e 2
4946 4970 1 4972
1 4974 2 497e
4980 3 497c 497d
4982 2 498b 498d
2 498a 498f 1
4991 1 4993 3
499a 499b 499c 3
4975 4994 499e 1
49a3 2 49a1 49a3
2 49ae 49b0 3
49ac 49ad 49b2 2
49bb 49bd 2 49bf
49c1 2 49c3 49c5
1 49cd 2 49cf
49d0 2 49c7 49d2
2 49d4 49d6 2
49d8 49da 2 49dc
49de 2 49e0 49e2
2 49ba 49e4 1
49e6 1 49e8 2
49f2 49f4 3 49f0
49f1 49f6 2 49ff
4a01 2 49fe 4a03
1 4a05 1 4a07
3 4a0e 4a0f 4a10
3 49e9 4a08 4a12
1 4a34 2 4a33
4a34 1 4a3c 1
4a42 2 4a44 4a45
2 4a31 4a46 1
4a4d 1 4a48 2
4a60 4a62 3 4a5e
4a5f 4a64 2 4a6d
4a6f 2 4a71 4a73
2 4a75 4a77 2
4a79 4a7b 2 4a7d
4a7f 3 4a84 4a85
4a86 2 4a81 4a88
2 4a6c 4a8a 1
4a8c 1 4a8e 2
4a57 4a8f 1 4a93
1 4a52 2 4a50
4a97 1 4a9a 3
4a9d 4a14 4a9e 17
46f9 46fc 46ff 4702
4705 4708 470b 470e
473d 476f 4852 4857
485c 48d0 48d4 48d7
48da 48dd 48e0 4903
4906 492c 4a9f 1
4aa1 2 46d8 4aa2
1 4aa7 2 4aa5
4aa7 2 4aab 4aac
1 4ab0 2 4aae
4ab0 1 4ab5 1
4ac6 2 4ac5 4ac6
1 4ace 1 4ad4
2 4ad6 4ad7 2
4ac3 4ad8 1 4adf
1 4ada 2 4af2
4af4 3 4af0 4af1
4af6 2 4aff 4b01
2 4b03 4b05 2
4b07 4b09 2 4b0b
4b0d 2 4b0f 4b11
3 4b16 4b17 4b18
2 4b13 4b1a 2
4afe 4b1c 1 4b1e
1 4b20 2 4ae9
4b21 1 4b25 1
4ae4 2 4ae2 4b29
1 4b2c 2 4b30
4b2f 2 4b3a 4b3f
1 4b46 1 4b41
2 4b59 4b5b 3
4b57 4b58 4b5d 2
4b66 4b68 2 4b6a
4b6c 2 4b6e 4b70
2 4b72 4b74 2
4b76 4b78 3 4b7d
4b7e 4b7f 2 4b7a
4b81 2 4b65 4b83
1 4b85 1 4b87
2 4b50 4b88 1
4b8c 1 4b4b 2
4b49 4b90 2 4b96
4b97 1 4b9b 2
4b99 4b9b 1 4baa
2 4ba9 4baa 1
4bb2 1 4bb8 2
4bba 4bbb 2 4ba7
4bbc 1 4bc3 1
4bbe 2 4bd6 4bd8
3 4bd4 4bd5 4bda
2 4be3 4be5 2
4be7 4be9 2 4beb
4bed 2 4bef 4bf1
2 4bf3 4bf5 3
4bfa 4bfb 4bfc 2
4bf7 4bfe 2 4be2
4c00 1 4c02 1
4c04 2 4bcd 4c05
1 4c09 1 4bc8
2 4bc6 4c0d 1
4c10 1 4c13 4
46bc 4b31 4b93 4c14
1 4c16 1 4c1b
1 4c2c 2 4c2b
4c2c 1 4c34 1
4c3a 2 4c3c 4c3d
2 4c29 4c3e 1
4c45 1 4c40 2
4c58 4c5a 3 4c56
4c57 4c5c 2 4c65
4c67 2 4c69 4c6b
2 4c6d 4c6f 2
4c71 4c73 2 4c75
4c77 3 4c7c 4c7d
4c7e 2 4c79 4c80
2 4c64 4c82 1
4c84 1 4c86 2
4c4f 4c87 1 4c8b
1 4c4a 2 4c48
4c8f 2 4c95 4c96
1 4c9a 2 4c98
4c9a 2 4ca4 4ca9
1 4cb0 1 4cab
2 4cc3 4cc5 3
4cc1 4cc2 4cc7 2
4cd0 4cd2 2 4cd4
4cd6 2 4cd8 4cda
2 4cdc 4cde 2
4ce0 4ce2 3 4ce7
4ce8 4ce9 2 4ce4
4ceb 2 4ccf 4ced
1 4cef 1 4cf1
2 4cba 4cf2 1
4cf6 1 4cb5 2
4cb3 4cfa 2 4d00
4d01 1 4d05 2
4d03 4d05 1 4d13
2 4d12 4d13 1
4d1b 1 4d21 2
4d23 4d24 2 4d10
4d25 1 4d2c 1
4d27 2 4d3f 4d41
3 4d3d 4d3e 4d43
2 4d4c 4d4e 2
4d50 4d52 2 4d54
4d56 2 4d58 4d5a
2 4d5c 4d5e 3
4d63 4d64 4d65 2
4d60 4d67 2 4d4b
4d69 1 4d6b 1
4d6d 2 4d36 4d6e
1 4d72 1 4d31
2 4d2f 4d76 1
4d83 2 4d82 4d83
1 4d8b 1 4d91
2 4d93 4d94 2
4d80 4d95 1 4d9c
1 4d97 2 4daf
4db1 3 4dad 4dae
4db3 2 4dbc 4dbe
2 4dc0 4dc2 2
4dc4 4dc6 2 4dc8
4dca 2 4dcc 4dce
3 4dd3 4dd4 4dd5
2 4dd0 4dd7 2
4dbb 4dd9 1 4ddb
1 4ddd 2 4da6
4dde 1 4de2 1
4da1 2 4d9f 4de6
2 4d79 4de9 1
4dec 2 4cfd 4ded
1 4def 2 4df2
4df3 1 4df7 2
4df5 4df7 5 4dff
4e00 4e01 4e02 4e03
2 4e20 4e25 1
4e2c 1 4e27 2
4e3f 4e41 3 4e3d
4e3e 4e43 2 4e4c
4e4e 2 4e50 4e52
2 4e54 4e56 2
4e58 4e5a 2 4e5c
4e5e 3 4e63 4e64
4e65 2 4e60 4e67
2 4e4b 4e69 1
4e6b 1 4e6d 2
4e36 4e6e 1 4e72
1 4e31 2 4e2f
4e76 1 4e81 2
4e7d 4e81 2 4e86
4e87 1 4e8b 2
4e89 4e8b 1 4ea0
2 4e9f 4ea0 1
4ea8 1 4eae 2
4eb0 4eb1 2 4e9d
4eb2 1 4eb9 1
4eb4 2 4ecc 4ece
3 4eca 4ecb 4ed0
2 4ed9 4edb 2
4edd 4edf 2 4ee1
4ee3 2 4ee5 4ee7
2 4ee9 4eeb 3
4ef0 4ef1 4ef2 2
4eed 4ef4 2 4ed8
4ef6 1 4ef8 1
4efa 2 4ec3 4efb
1 4eff 1 4ebe
2 4ebc 4f03 1
4f06 1 4f1d 2
4f1c 4f1d 1 4f25
1 4f2b 2 4f2d
4f2e 2 4f1a 4f2f
1 4f36 1 4f31
2 4f49 4f4b 3
4f47 4f48 4f4d 2
4f56 4f58 2 4f5a
4f5c 2 4f5e 4f60
2 4f62 4f64 2
4f66 4f68 3 4f6d
4f6e 4f6f 2 4f6a
4f71 2 4f55 4f73
1 4f75 1 4f77
2 4f40 4f78 1
4f7c 1 4f3b 2
4f39 4f80 1 4f83
2 4f86 4f87 3
4f8a 4f8b 4f8c 1
4f90 2 4f8e 4f90
a 4f9b 4f9c 4f9d
4f9e 4f9f 4fa0 4fa1
4fa2 4fa3 4fa4 2
4f96 4fa7 1 4fa9
2 4f88 4faa 1
4fac 1 4fae 2
4fb7 4fb8 1 4fbc
2 4fba 4fbc 1
4fc4 1 4fc6 5
4dfc 4e06 4e79 4fad
4fc7 1 4fc9 3
4c92 4df0 4fca 1
4fcc 1 4fce 5
4fd8 4fd9 4fda 4fdb
4fdc 2 4ff9 4ffe
1 5005 1 5000
2 5018 501a 3
5016 5017 501c 2
5025 5027 2 5029
502b 2 502d 502f
2 5031 5033 2
5035 5037 3 503c
503d 503e 2 5039
5040 2 5024 5042
1 5044 1 5046
2 500f 5047 1
504b 1 500a 2
5008 504f 2 5055
5056 1 505a 2
5058 505a 1 506f
2 506e 506f 1
5077 1 507d 2
507f 5080 2 506c
5081 1 5088 1
5083 2 509b 509d
3 5099 509a 509f
2 50a8 50aa 2
50ac 50ae 2 50b0
50b2 2 50b4 50b6
2 50b8 50ba 3
50bf 50c0 50c1 2
50bc 50c3 2 50a7
50c5 1 50c7 1
50c9 2 5092 50ca
1 50ce 1 508d
2 508b 50d2 1
50d5 1 50ec 2
50eb 50ec 1 50f4
1 50fa 2 50fc
50fd 2 50e9 50fe
1 5105 1 5100
2 5118 511a 3
5116 5117 511c 2
5125 5127 2 5129
512b 2 512d 512f
2 5131 5133 2
5135 5137 3 513c
513d 513e 2 5139
5140 2 5124 5142
1 5144 1 5146
2 510f 5147 1
514b 1 510a 2
5108 514f 1 5152
2 5155 5156 3
5159 515a 515b 1
515f 2 515d 515f
2 5164 5165 1
5169 2 5167 5169
a 5176 5177 5178
5179 517a 517b 517c
517d 517e 517f 2
5171 5182 1 5184
5 4fd5 4fdf 5052
5157 5185 1 5187
1 518b 1 5193
2 5191 5193 1
519a 1 519c 2
51a6 51a8 3 51a4
51a5 51aa 2 51b3
51b5 2 51b7 51b9
2 51bb 51bd 1
51c5 2 51c7 51c8
2 51bf 51ca 2
51cc 51ce 2 51d0
51d2 2 51d4 51d6
2 51d8 51da 2
51b2 51dc 1 51de
1 51e0 3 51e7
51e8 51e9 5b 498
4b7 4ba 4bd 4c0
4c3 4c6 4c9 4d6
4f6 4f9 4fc 4ff
502 505 508 50b
50e 513 526 52b
588 602 66b 6e6
6e9 748 7c2 841
8bc 91d 998 9f7
a09 a83 a86 a91
a9c aa7 b0c b72
de3 de6 de9 dec
def df2 df5 df8
dfd e10 e25 e82
e9e efd f63 15e7
1657 1668 166b 166e
1671 1676 16f2 16f5
16f8 1758 175c 17c2
1824 26c3 26cf 26d2
26d5 2734 2738 273b
273e 2741 2744 464f
46ac 46b0 4c17 4c1a
4fcd 5188 518e 519d
51e1 51eb 2 51f8
51fa 3 51f6 51f7
51fc 2 5205 5207
2 5204 5209 2
5210 5214 2 5216
5218 2 521a 521e
2 520f 5220 2
520b 5222 1 5224
3 5225 5230 5234
1 51ef 2 5247
5249 3 5245 5246
524b 2 5254 5256
2 5253 5258 2
525f 5261 2 5263
5265 3 526a 526b
526c 2 5267 526e
2 525e 5270 2
525a 5272 1 5274
4 523e 5275 527e
5282 1 5286 1
5239 2 5237 528a
71 4e 55 5c
63 6a 71 78
7f 86 8d 94
9b a2 a9 ae
b3 b8 bd c4
cb d0 d5 da
e1 e8 ed f2
f7 fc 103 10a
111 118 11f 125
12b 131 137 13d
143 149 14f 155
15b 161 167 16d
173 179 17f 185
18b 191 197 19d
1a3 1a9 1af 1b5
1bb 1c1 1c7 1cd
1d3 1d9 1df 1e5
1eb 1f1 1f7 1fd
203 209 20f 215
21b 221 228 22f
235 23b 242 248
24f 256 25c 262
267 26c 272 278
27e 284 28a 290
296 29c 2a2 2a8
2ae 2b5 2bc 2c3
2c9 2d7 2dd 2e3
2e8 2ed 2fa 30e
386 390 
1
4
0 
5291
0
1
140
f2
82
0 1 1 1 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1 1b 1 1d 1 1f
1 21 1 23 1 25 1 27
1 29 1 2b 1 2d 1 2f
1 31 1 33 1 35 1 37
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 4f
1 51 1 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 67
1 69 6a 69 6c 69 6e 69
70 69 72 69 74 69 76 69
78 69 7a 69 7c 69 7e 69
80 69 82 69 84 69 86 69
88 69 8a 69 8c 69 8e 69
90 69 92 69 94 69 96 69
98 69 9a 69 9c 69 9e 69
a0 69 a2 69 a4 69 a6 69
a8 69 aa 69 ac 69 ae 69
b0 69 b2 69 b4 69 b6 69
b8 69 ba 69 bc 69 be 69
c0 69 c2 69 c4 69 c6 69
c8 69 ca 69 cc 69 ce 69
d0 1 d2 1 d4 1 d6 1
d8 1 da 1 dc 1 de 1
e0 1 e2 1 e4 1 e6 1
e8 1 ea 1 ec 1 ee 1
f0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

274 1 0
3b 1 0
33 1 0
244 1 0
2c5 1 0
27a 1 0
37 1 0
f9 1 0
187 1 0
237 1 0
1a5 1 0
139 1 0
b0 1 0
73 1 0
251 1 0
2f 1 0
280 1 0
292 1 0
24a 1 0
7a 1 0
27 1 0
20b 1 0
b 1 0
181 1 0
88 1 0
23 1 0
2e5 1 0
1e7 1 0
dc 1 0
fe 1 0
81 1 0
4649 69 d2
1bd 1 0
f4 1 0
2d9 1 0
1d5 1 0
1c3 1 0
65 1 0
23d 1 0
19f 1 0
1db 1 0
46 1 0
1b7 1 0
127 1 0
cd 1 0
314 1 4
25e 1 0
217 1 0
1f9 1 0
145 1 0
2aa 1 0
1b 1 0
163 1 0
300 1 3
22a 1 0
133 1 0
ea 1 0
b5 1 0
2f0 1 2
223 1 0
ab 1 0
17 1 0
21d 1 0
157 1 0
286 1 0
26e 1 0
57 1 0
3 1 0
1f3 1 0
29e 1 0
2 0 1
2cb 1 0
18d 1 0
2b0 1 0
113 1 0
2ea 1 0
269 1 0
ef 1 0
ba 1 0
258 1 0
14b 1 0
28c 1 0
199 1 0
12d 1 0
121 1 0
2b 1 0
2be 1 0
2b7 1 0
205 1 0
8f 1 0
50 1 0
e3 1 0
f 1 0
7 1 0
15d 1 0
151 1 0
2df 1 0
1ab 1 0
175 1 0
bf 1 0
211 1 0
1ed 1 0
a4 1 0
10c 1 0
2a4 1 0
298 1 0
1e1 1 0
13f 1 0
231 1 0
1c9 1 0
d2 1 0
9d 1 0
96 1 0
193 1 0
6c 1 0
1b1 1 0
1f 1 0
264 1 0
1ff 1 0
1cf 1 0
d7 1 0
105 1 0
16f 1 0
5e 1 0
11a 1 0
169 1 0
13 1 0
38b 1 0
17b 1 0
c6 1 0
0

/
SHOW ERRORS FUNCTION SP_A_RESTOPROF;
ALTER FUNCTION SP_A_RESTOPROF COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES ==
CREATE OR REPLACE FUNCTION SP_U_RATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5b
2 :e:
1FUNCTION:
1SP_U_RATES:
1ID:
1VARCHAR2:
1REG_COST:
1NUMBER:
1SPEC_COST:
1REG_RATE:
1SPEC_RATE:
1RATE_ADJUSTMENT001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RES_ID:
1H_REG_COST:
10:
1H_REG_RATE:
1H_SPEC_COST:
1H_SPEC_RATE:
1H_RATE_ADJUSTMENT:
1H_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
134:
1+:
1FPUT:
1               ENTER:: SP_U_RATES(35) :: cplan.sql(12977) :: :
1IS NULL:
139:
1        RETURN_ERROR:: SP_U_RATES(40) :: cplan.sql(12982) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
142:
1                EXIT:: SP_U_RATES(43) :: cplan.sql(12985) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1SC_STATE:
1FC_U_RATES:
1=:
1100:
14:
166:
1       RETURN_STATUS:: SP_U_RATES(67) :: cplan.sql(13009) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
173:
1           EXCEPTION:: SP_U_RATES(74) :: cplan.sql(13016) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
185:
1           EXCEPTION:: SP_U_RATES(86) :: cplan.sql(13028) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2a9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 51 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :9 a0 a5
b d :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
2a9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10b fa fe d9
106 f9 127 116 11a f6 122 115
143 132 136 112 13e 131 15f 14e
152 12e 15a 14d 17b 16a 16e 14a
176 169 197 186 18a 166 192 185
1b7 1a2 1a6 182 1aa 1b2 1a1 1be
1c2 19e 1c6 1ca 1ce 1d1 1d6 1d7
1 1d9 1de 1e2 1e6 1e9 1ee 1f2
1f6 1f9 1fe 1ff 201 206 209 20d
20e 213 218 21b 220 221 226 229
22d 22e 233 236 23b 23c 241 244
249 24a 24f 252 256 25a 25e 25f
261 266 267 269 26a 26f 272 277
278 27d 280 284 288 28c 28d 28f
294 295 297 298 29d 2a0 2a5 2a6
2ab 2ae 2b2 2b6 2ba 2bb 2bd 2c2
2c3 2c5 2c6 2cb 2ce 2d3 2d4 2d9
2dc 2e0 2e4 2e8 2e9 2eb 2f0 2f1
2f3 2f4 2f9 2fc 301 302 307 30a
30e 312 316 317 319 31e 31f 321
322 327 32a 32f 330 335 338 33d
33e 343 346 34a 34b 350 353 358
359 35e 361 366 367 36c 36d 372
374 378 37b 37f 383 386 38a 38e
391 394 399 39c 39f 3a2 3a3 3a8
3a9 1 3ab 3b0 3b4 3b8 3bb 3c0
3c5 3c8 3cc 3cd 3d2 3d3 3d8 3da
3de 3e1 3e5 3e8 3e9 3ee 3f1 3f5
3f9 3fc 400 404 407 40a 40f 412
415 418 419 41e 41f 1 421 426
42a 42e 431 436 43b 43e 442 443
448 44b 450 451 456 459 45e 45f
464 467 46b 46f 473 477 47a 47b
47d 482 483 485 486 48b 48e 493
494 499 49c 4a1 4a2 4a7 4aa 4ae
4af 4b4 4b7 4bc 4bd 4c2 4c3 4c8
4ca 4ce 4d1 4d5 4d9 4dc 4e0 4e4
4e7 4ea 4ef 4f2 4f5 4f8 4f9 4fe
4ff 1 501 506 50a 50e 511 516
51b 51e 522 523 528 529 52e 530
534 537 53b 53f 542 546 54a 54d
551 555 556 55b 55d 561 564 568
56b 56f 573 577 57b 57f 583 587
58b 58f 593 597 59b 59f 5a3 5a7
5ab 5af 5b3 5b7 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5da 5de 5e2 5e6
5ea 5ee 5f2 5f3 5f5 5f9 5fd 601
604 607 60a 60b 610 614 618 61b
61e 622 624 628 62b 62f 633 636
63a 63e 641 644 649 64c 64f 652
653 658 659 1 65b 660 664 668
66b 670 675 678 67c 67d 682 685
68a 68b 690 693 698 699 69e 6a1
6a5 6a9 6ad 6b1 6b4 6b5 6b7 6bc
6bd 6bf 6c0 6c5 6c8 6cd 6ce 6d3
6d6 6db 6dc 6e1 6e4 6e8 6e9 6ee
6f1 6f6 6f7 6fc 6fd 702 704 708
70b 70f 713 716 71a 71e 721 725
729 72a 72f 731 735 739 73c 740
744 747 74b 74f 752 755 75a 75d
760 763 764 769 76a 1 76c 771
775 779 77c 781 786 789 78d 78e
793 794 799 79d 7a1 7a4 7a9 7ae
7b1 7b5 7b9 7bc 7bd 7c2 7c5 7ca
7cb 7d0 7d3 7d7 7db 7de 7df 7e4
7e5 7ea 7ec 7f0 7f3 7f7 7fb 7ff
803 807 80b 80f 813 817 823 828
82c 830 834 838 83a 83b 840 1
844 848 84c 84f 853 857 85b 85f
862 866 86a 86d 870 875 878 87b
87e 87f 884 885 1 887 88c 890
894 897 89c 8a1 8a4 8a8 8a9 8ae
8af 8b4 8b8 8bc 8bf 8c4 8c9 8cc
8d0 8d1 8d6 8d9 8de 8df 8e4 8e7
8eb 8ef 8f2 8f5 8f6 8f8 8f9 8fe
8ff 904 906 90a 90d 911 915 919
91d 921 925 929 935 93a 93e 942
946 94a 94c 950 952 95e 960 962
963 968 96c 96e 97a 97e 980 981
98a 
2a9
2
0 1 a 6 9 :3 6 f :3 6
10 :3 6 f :3 6 10 :3 6 19 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 d 16
15 :2 d :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 10 1a 10 :2 4 :2 10
1a 10 :2 4 :2 16 25 16 :2 4 :2 b
1a b :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 52 58 5b :2 52
69 7d 8 :2 69 d 10 :2 69 13
16 :2 69 b e :2 69 13 16 1f
27 :2 1f 32 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 33 :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
32 :2 16 :2 69 b e :2 69 13 16
1f 27 :2 1f 33 :2 16 :2 69 b e
:2 69 13 16 1f 27 :2 1f 3c :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 30 33 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
:4 8 7 a :2 14 26 :2 30 3c 40
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 6e 71 :2 21 75
78 :2 21 82 85 8e 96 :2 9f :2 8e
b0 :2 85 :2 21 b8 bb :2 21 c3 c6
:2 21 cb ce :2 21 d1 d4 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4d 4f 50 :2 4d :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 53 :3 7 :2 12
26 :2 2f 3f 43 :2 7 14 :3 4 e
:2 4 c :2 4 10 :2 4 12 :2 4 13
:2 4 12 :2 4 13 :2 4 19 :2 4 :2 d
19 24 2a 36 43 4f 23 36
40 :2 19 4 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 4a 4c 4d :2 4a
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
6b 6e :2 1e 72 75 :2 1e 7f 82
8b 93 :2 9c :2 8b a7 :2 82 :2 1e af
b2 :2 1e ba bd :2 1e c2 c5 :2 1e
c8 cb :2 1e :2 7 50 :3 4 :2 f 21
:2 2a 34 38 :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 54 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 51 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
2a9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :9 1b
:2 18 :2 1c :2 18 :9 1c
:2 18 :2 1d :2 18 :9 1d
:2 18 :2 1e :2 18 :9 1e
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :4 18 :3 17
:11 22 :b 23 :3 22 :5 26
:11 27 :30 28 :3 27 :11 2a
:b 2b :3 2a :a 2d :3 26
:3 30 :3 33 :3 34 :3 35
:3 36 :3 37 :3 38 :3 39
:9 3b :3 3c :3 3b :7 3e
:5 3f :3 3e :11 42 :30 43
:3 42 :a 45 16 :3 48
:11 49 :b 4a :17 4b :3 49
:2 4d :3 4e :3 4f 50
4e 4d 4e :3 51
:3 48 :2 52 :5 54 :11 55
:b 56 :18 57 :3 55 :2 59
5a :3 5b 5c 5a
59 5a :3 5d :2 53
:6 52 47 :7 1 
98c
4
:3 0 1 :3 0 2
:a 0 2a4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 6 :3 0 8
:7 0 11 10 :3 0
6 :3 0 9 :7 0
15 14 :3 0 11
:2 0 f b :3 0
a :7 0 19 18
:3 0 4 :3 0 c
:7 0 1d 1c :3 0
d :3 0 e :3 0
f :2 0 4 21
22 0 1f 23
0 2a4 2 24
:2 0 11 :2 0 1b
4 :3 0 11 :2 0
19 27 29 :6 0
2c 2a 0 2a2
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 2a2
0 12 :6 0 14
:2 0 21 6 :3 0
35 :7 0 39 36
37 2a2 0 13
:6 0 14 :2 0 23
6 :3 0 3b :7 0
3f 3c 3d 2a2
0 15 :6 0 14
:2 0 25 6 :3 0
41 :7 0 45 42
43 2a2 0 16
:6 0 14 :2 0 27
6 :3 0 47 :7 0
4b 48 49 2a2
0 17 :6 0 14
:2 0 29 b :3 0
4d :7 0 51 4e
4f 2a2 0 18
:6 0 59 5a 0
2b b :3 0 53
:7 0 57 54 55
2a2 0 19 :6 0
5f 60 0 2d
e :3 0 f :2 0
4 5b :7 0 5e
5c 0 2a2 0
1a :6 0 1b :3 0
1c :3 0 1b :3 0
1d :3 0 62 63
0 2 :4 0 2f
64 66 61 68
67 :2 0 1e :3 0
1f :3 0 6a 6b
0 20 :4 0 1b
:3 0 21 :3 0 6e
6f 0 2 :4 0
31 70 72 22
:4 0 23 :2 0 24
:3 0 33 75 77
:3 0 25 :4 0 23
:2 0 26 :4 0 36
7a 7c :3 0 23
:2 0 3 :3 0 39
7e 80 :3 0 23
:2 0 26 :4 0 3c
82 84 :3 0 23
:2 0 27 :4 0 3f
86 88 :3 0 23
:2 0 28 :3 0 29
:3 0 5 :3 0 42
8c 8e 2a :4 0
44 8b 91 47
8a 93 :3 0 23
:2 0 27 :4 0 4a
95 97 :3 0 23
:2 0 28 :3 0 29
:3 0 7 :3 0 4d
9b 9d 2a :4 0
4f 9a a0 52
99 a2 :3 0 23
:2 0 27 :4 0 55
a4 a6 :3 0 23
:2 0 28 :3 0 29
:3 0 8 :3 0 58
aa ac 2a :4 0
5a a9 af 5d
a8 b1 :3 0 23
:2 0 27 :4 0 60
b3 b5 :3 0 23
:2 0 28 :3 0 29
:3 0 9 :3 0 63
b9 bb 2a :4 0
65 b8 be 68
b7 c0 :3 0 23
:2 0 27 :4 0 6b
c2 c4 :3 0 23
:2 0 28 :3 0 29
:3 0 a :3 0 6e
c8 ca 2a :4 0
70 c7 cd 73
c6 cf :3 0 23
:2 0 27 :4 0 76
d1 d3 :3 0 23
:2 0 26 :4 0 79
d5 d7 :3 0 23
:2 0 c :3 0 7c
d9 db :3 0 23
:2 0 26 :4 0 7f
dd df :3 0 23
:2 0 2b :4 0 82
e1 e3 :3 0 85
6c e5 :2 0 e7
8a e8 69 e7
0 e9 8c 0
202 1b :3 0 1c
:3 0 ea eb 0
1b :3 0 2c :3 0
ed ee 0 2d
:2 0 2 :4 0 2e
:2 0 2f :2 0 2d
:2 0 8e f3 f5
:3 0 91 ef f7
ec f9 f8 :2 0
1e :3 0 30 :3 0
fb fc 0 20
:4 0 31 :4 0 23
:2 0 24 :3 0 95
100 102 :3 0 98
fd 104 :2 0 106
9b 107 fa 106
0 108 9d 0
202 3 :3 0 32
:2 0 9f 10a 10b
:3 0 10c :2 0 1b
:3 0 1c :3 0 10e
10f 0 1b :3 0
2c :3 0 111 112
0 11 :2 0 2
:4 0 33 :2 0 2f
:2 0 2d :2 0 a1
117 119 :3 0 a4
113 11b 110 11d
11c :2 0 1e :3 0
30 :3 0 11f 120
0 20 :4 0 34
:4 0 23 :2 0 24
:3 0 a8 124 126
:3 0 23 :2 0 35
:4 0 ab 128 12a
:3 0 23 :2 0 36
:4 0 ae 12c 12e
:3 0 23 :2 0 28
:3 0 29 :3 0 37
:3 0 38 :3 0 133
134 0 b1 132
136 2a :4 0 b3
131 139 b6 130
13b :3 0 23 :2 0
39 :4 0 b9 13d
13f :3 0 23 :2 0
26 :4 0 bc 141
143 :3 0 23 :2 0
3 :3 0 bf 145
147 :3 0 23 :2 0
26 :4 0 c2 149
14b :3 0 c5 121
14d :2 0 14f c8
150 11e 14f 0
151 ca 0 17b
1b :3 0 1c :3 0
152 153 0 1b
:3 0 2c :3 0 155
156 0 2d :2 0
2 :4 0 3a :2 0
2f :2 0 2d :2 0
cc 15b 15d :3 0
cf 157 15f 154
161 160 :2 0 1e
:3 0 30 :3 0 163
164 0 20 :4 0
3b :4 0 23 :2 0
24 :3 0 d3 168
16a :3 0 d6 165
16c :2 0 16e d9
16f 162 16e 0
170 db 0 17b
3c :3 0 3d :3 0
171 172 0 37
:3 0 38 :3 0 174
175 0 3 :3 0
3e :3 0 dd 173
179 :2 0 17b e1
17c 10d 17b 0
17d e5 0 202
19 :3 0 2d :2 0
17e 17f 0 202
10 :3 0 3 :3 0
181 182 0 202
12 :3 0 c :3 0
184 185 0 202
13 :3 0 5 :3 0
187 188 0 202
16 :3 0 7 :3 0
18a 18b 0 202
15 :3 0 8 :3 0
18d 18e 0 202
17 :3 0 9 :3 0
190 191 0 202
18 :3 0 a :3 0
193 194 0 202
e :3 0 3f :3 0
196 197 0 40
:3 0 10 :3 0 13
:3 0 16 :3 0 15
:3 0 17 :3 0 18
:3 0 12 :3 0 19
:3 0 e7 199 1a2
198 1a3 0 202
e :3 0 3f :3 0
1a5 1a6 0 41
:2 0 42 :2 0 f2
1a8 1aa :3 0 e
:3 0 3f :3 0 1ac
1ad 0 14 :2 0
1ae 1af 0 1b1
f5 1b2 1ab 1b1
0 1b3 f7 0
202 1b :3 0 1c
:3 0 1b4 1b5 0
1b :3 0 2c :3 0
1b7 1b8 0 43
:2 0 2 :4 0 44
:2 0 2f :2 0 2d
:2 0 f9 1bd 1bf
:3 0 fc 1b9 1c1
1b6 1c3 1c2 :2 0
1e :3 0 30 :3 0
1c5 1c6 0 20
:4 0 45 :4 0 23
:2 0 24 :3 0 100
1ca 1cc :3 0 23
:2 0 35 :4 0 103
1ce 1d0 :3 0 23
:2 0 36 :4 0 106
1d2 1d4 :3 0 23
:2 0 28 :3 0 29
:3 0 e :3 0 3f
:3 0 1d9 1da 0
109 1d8 1dc 2a
:4 0 10b 1d7 1df
10e 1d6 1e1 :3 0
23 :2 0 39 :4 0
111 1e3 1e5 :3 0
23 :2 0 26 :4 0
114 1e7 1e9 :3 0
23 :2 0 3 :3 0
117 1eb 1ed :3 0
23 :2 0 26 :4 0
11a 1ef 1f1 :3 0
11d 1c7 1f3 :2 0
1f5 120 1f6 1c4
1f5 0 1f7 122
0 202 3c :3 0
46 :3 0 1f8 1f9
0 e :3 0 3f
:3 0 1fb 1fc 0
3 :3 0 3e :3 0
124 1fa 200 :2 0
202 128 2a3 e
:3 0 47 :2 0 4
203 204 0 1b
:3 0 1c :3 0 206
207 0 1b :3 0
2c :3 0 209 20a
0 48 :2 0 2
:4 0 49 :2 0 2f
:2 0 2d :2 0 138
20f 211 :3 0 13b
20b 213 208 215
214 :2 0 1e :3 0
30 :3 0 217 218
0 20 :4 0 4a
:4 0 23 :2 0 24
:3 0 13f 21c 21e
:3 0 142 219 220
:2 0 239 1e :3 0
30 :3 0 222 223
0 20 :4 0 4b
:4 0 23 :2 0 e
:3 0 4c :3 0 228
229 0 145 227
22b :3 0 23 :2 0
39 :4 0 148 22d
22f :3 0 23 :2 0
e :3 0 4d :3 0
232 233 0 14b
231 235 :3 0 14e
224 237 :2 0 239
151 23a 216 239
0 23b 154 0
24b 4e :3 0 1a
:3 0 e :3 0 4c
:3 0 4f :3 0 e
:3 0 4d :3 0 3
:3 0 50 :4 0 51
1 :a 0 247 :2 0
24b 23d 245 :2 0
d :3 0 1a :3 0
249 :2 0 24b 156
24d 15a 24c 24b
:2 0 2a1 52 :3 0
e :3 0 3f :3 0
250 251 0 53
:3 0 252 253 0
299 1b :3 0 1c
:3 0 255 256 0
1b :3 0 2c :3 0
258 259 0 48
:2 0 2 :4 0 54
:2 0 2f :2 0 2d
:2 0 15c 25e 260
:3 0 15f 25a 262
257 264 263 :2 0
1e :3 0 30 :3 0
266 267 0 20
:4 0 55 :4 0 23
:2 0 24 :3 0 163
26b 26d :3 0 166
268 26f :2 0 289
1e :3 0 30 :3 0
271 272 0 20
:4 0 56 :4 0 23
:2 0 53 :3 0 169
276 278 :3 0 23
:2 0 57 :4 0 16c
27a 27c :3 0 23
:2 0 58 :3 0 59
:3 0 2d :2 0 5a
:2 0 16f 27f 283
173 27e 285 :3 0
176 273 287 :2 0
289 179 28a 265
289 0 28b 17c
0 299 4e :3 0
1a :3 0 4f :3 0
e :3 0 4d :3 0
3 :3 0 50 :4 0
5b 1 :a 0 295
:2 0 299 28d 293
:2 0 d :3 0 1a
:3 0 297 :2 0 299
17e 29c :3 0 29c
0 29c 29b 299
29a :6 0 29e 1
:3 0 183 2a0 185
29f 29e :2 0 2a1
187 :2 0 2a3 18a
2a3 2a2 202 2a1
:6 0 2a4 :2 0 2
24 2a3 2a7 :3 0
2a6 2a4 2a8 :8 0

194
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
34 1 3a 1
40 1 46 1
4c 1 52 1
58 1 65 1
71 2 74 76
2 79 7b 2
7d 7f 2 81
83 2 85 87
1 8d 2 8f
90 2 89 92
2 94 96 1
9c 2 9e 9f
2 98 a1 2
a3 a5 1 ab
2 ad ae 2
a7 b0 2 b2
b4 1 ba 2
bc bd 2 b6
bf 2 c1 c3
1 c9 2 cb
cc 2 c5 ce
2 d0 d2 2
d4 d6 2 d8
da 2 dc de
2 e0 e2 4
6d 73 78 e4
1 e6 1 e8
2 f2 f4 3
f0 f1 f6 2
ff 101 2 fe
103 1 105 1
107 1 109 2
116 118 3 114
115 11a 2 123
125 2 127 129
2 12b 12d 1
135 2 137 138
2 12f 13a 2
13c 13e 2 140
142 2 144 146
2 148 14a 2
122 14c 1 14e
1 150 2 15a
15c 3 158 159
15e 2 167 169
2 166 16b 1
16d 1 16f 3
176 177 178 3
151 170 17a 1
17c 8 19a 19b
19c 19d 19e 19f
1a0 1a1 1 1a9
2 1a7 1a9 1
1b0 1 1b2 2
1bc 1be 3 1ba
1bb 1c0 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 1
1db 2 1dd 1de
2 1d5 1e0 2
1e2 1e4 2 1e6
1e8 2 1ea 1ec
2 1ee 1f0 2
1c8 1f2 1 1f4
1 1f6 3 1fd
1fe 1ff f e9
108 17d 180 183
186 189 18c 18f
192 195 1a4 1b3
1f7 201 2 20e
210 3 20c 20d
212 2 21b 21d
2 21a 21f 2
226 22a 2 22c
22e 2 230 234
2 225 236 2
221 238 1 23a
3 23b 246 24a
1 205 2 25d
25f 3 25b 25c
261 2 26a 26c
2 269 26e 2
275 277 2 279
27b 3 280 281
282 2 27d 284
2 274 286 2
270 288 1 28a
4 254 28b 294
298 1 29c 1
24f 2 24d 2a0
9 2b 32 38
3e 44 4a 50
56 5d 
1
4
0 
2a7
0
1
14
2
11
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
4c 1 0
3 1 0
13 1 0
1b 1 0
40 1 0
3a 1 0
f 1 0
26 1 0
b 1 0
2d 1 0
17 1 0
52 1 0
46 1 0
34 1 0
58 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES;
ALTER FUNCTION SP_U_RATES COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES_EDITED
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES_EDITED ==
CREATE OR REPLACE FUNCTION SP_U_RATES_EDITED wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
73
2 :e:
1FUNCTION:
1SP_U_RATES_EDITED:
1ID:
1VARCHAR2:
1RATES_EDITED001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RESOURCE_ID:
1H_REG_COST:
1NUMBER:
10:
1H_SPEC_COST:
1H_REG_RATE:
1H_SPEC_RATE:
1H_FLAG:
1H_OLD_REG_COST:
1H_OLD_REG_SALE:
1H_OLD_SPEC_COST:
1H_OLD_SPEC_RATE:
1H_RATE_ID:
1H_RATE_ADJUSTMENT:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES_EDITED(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
131:
1+:
1FPUT:
1               ENTER:: SP_U_RATES_EDITED(32) :: cplan.sql(13084) :: :
1REGULAR_COST:
1REGULAR_RATE:
1SPECIAL_COST:
1SPECIAL_RATE:
1RATE_ADJUSTMENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT REGULAR_COST, REGULAR_RATE,:n      SPECIAL_COST, SPECIAL_RATE, RATE_AD+
1JUSTMENT:n      INTO   h_old_reg_cost, h_old_reg_sale ,:n      h_old_spec_cos+
1t,h_old_spec_rate, h_rate_adjustment:n      FROM TASK_ASSIGNMENTS:n      WHER+
1E TSK_ASSIGNMENT_ID = id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
153:
1           EXCEPTION:: SP_U_RATES_EDITED(54) :: cplan.sql(13106) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1RATE_ID:
1RESOURCES:
1RESOURCE_ID:
1SELECT RATE_ID INTO h_rate_id:n      FROM RESOURCES:n      WHERE RESOURCE_ID +
1= res_id001:
170:
1           EXCEPTION:: SP_U_RATES_EDITED(71) :: cplan.sql(13123) :: :
1REGULAR_SALE:
1SPECIAL_SALE:
1RATES:
1SELECT REGULAR_COST, REGULAR_SALE,:n      SPECIAL_COST, SPECIAL_SALE:n      I+
1NTO   h_reg_cost, h_reg_rate ,:n      h_spec_cost,h_spec_rate:n      FROM RAT+
1ES:n      WHERE RATE_ID = h_rate_id:
190:
1           EXCEPTION:: SP_U_RATES_EDITED(91) :: cplan.sql(13143) :: :
1RATES_EDITED:
1BITAND:
1UPDATE TASK_ASSIGNMENTS:n      SET RATES_EDITED = BITAND(RATES_EDITED,rates_e+
1dited001):n      WHERE TSK_ASSIGNMENT_ID = id:
1FOUND:
1TRUE:
1=:
1100:
1111:
1           EXCEPTION:: SP_U_RATES_EDITED(112) :: cplan.sql(13164) :: :
1>:
12:
1FC_U_RATES:
14:
1129:
1       RETURN_STATUS:: SP_U_RATES_EDITED(130) :: cplan.sql(13182) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1136:
1           EXCEPTION:: SP_U_RATES_EDITED(137) :: cplan.sql(13189) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1148:
1           EXCEPTION:: SP_U_RATES_EDITED(149) :: cplan.sql(13201) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3b4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d a0 51 d :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:b a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b 51 a5
b 5a 7e 51 b4 2e :2 a0 d
:2 a0 d b7 19 3c :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e :2 a0 d :2 a0 d b7 19 3c
:2 a0 6b :9 a0 a5 b d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
3b4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 bf ae b2 8d
ba ad db ca ce aa d6 c9
f7 e6 ea c6 f2 e5 113 102
106 e2 10e 101 12f 11e 122 fe
12a 11d 14b 13a 13e 11a 146 139
167 156 15a 136 162 155 183 172
176 152 17e 171 19f 18e 192 16e
19a 18d 1bc 1aa 18a 1ae 1af 1b7
1a9 1d8 1c7 1cb 1a6 1d3 1c6 1f8
1e3 1e7 1c3 1eb 1f3 1e2 1ff 203
1df 207 20b 20f 212 217 218 1
21a 21f 223 227 22a 22f 233 237
23a 23f 240 242 247 24a 24e 24f
254 259 25c 261 262 267 26a 26e
26f 274 277 27c 27d 282 285 28a
28b 290 293 297 29b 29f 2a0 2a2
2a7 2a8 2aa 2ab 2b0 2b3 2b8 2b9
2be 2c1 2c6 2c7 2cc 2cf 2d3 2d4
2d9 2dc 2e1 2e2 2e7 2ea 2ef 2f0
2f5 2f6 2fb 2fd 301 304 308 30c
30f 313 317 31a 31d 322 325 328
32b 32c 331 332 1 334 339 33d
341 344 349 34e 351 355 356 35b
35c 361 363 367 36a 36e 372 376
37a 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3a9 3ad 3b1 3b5
3c1 3c5 3c9 3cc 3d0 3d4 3d6 3da
3de 3e2 3e5 3e9 3ed 3ef 3f0 3f5
1 3f9 3fd 401 404 408 40c 410
414 417 41b 41f 422 425 42a 42d
430 433 434 439 43a 1 43c 441
445 449 44c 451 456 459 45d 45e
463 466 46b 46c 471 474 479 47a
47f 482 486 487 48c 48f 494 495
49a 49d 4a1 4a5 4a8 4ab 4ac 4ae
4af 4b4 4b5 4ba 4bc 4c0 4c3 4c5
4c9 4cb 4d7 4d9 4db 4dc 4e1 4e5
4e7 4f3 4f5 4f9 4fd 501 505 509
515 519 51d 520 524 528 52a 52e
532 536 539 53d 541 543 544 549
1 54d 551 555 558 55c 560 564
568 56b 56f 573 576 579 57e 581
584 587 588 58d 58e 1 590 595
599 59d 5a0 5a5 5aa 5ad 5b1 5b2
5b7 5ba 5bf 5c0 5c5 5c8 5cd 5ce
5d3 5d6 5da 5db 5e0 5e3 5e8 5e9
5ee 5f1 5f5 5f9 5fc 5ff 600 602
603 608 609 60e 610 614 617 619
61d 61f 62b 62d 62f 630 635 639
63b 647 649 64d 651 655 659 65d
661 665 669 66d 671 675 681 685
689 68c 690 694 696 69a 69e 6a2
6a5 6a9 6ad 6af 6b0 6b5 1 6b9
6bd 6c1 6c4 6c8 6cc 6d0 6d4 6d7
6db 6df 6e2 6e5 6ea 6ed 6f0 6f3
6f4 6f9 6fa 1 6fc 701 705 709
70c 711 716 719 71d 71e 723 726
72b 72c 731 734 739 73a 73f 742
746 747 74c 74f 754 755 75a 75d
761 765 768 76b 76c 76e 76f 774
775 77a 77c 780 783 785 789 78b
797 799 79b 79c 7a1 7a5 7a7 7b3
7b5 7b9 7bd 7c1 7c5 7c9 7cd 7d1
7dd 7e1 7e6 7ea 7ed 7ee 7f3 7f7
7fb 7fe 801 805 807 80b 80f 812
815 819 81b 81f 823 826 828 82c
830 834 837 83b 83f 841 842 847
1 84b 84f 853 856 85a 85e 862
866 869 86d 871 874 877 87c 87f
882 885 886 88b 88c 1 88e 893
897 89b 89e 8a3 8a8 8ab 8af 8b0
8b5 8b8 8bd 8be 8c3 8c6 8cb 8cc
8d1 8d4 8d8 8d9 8de 8e1 8e6 8e7
8ec 8ef 8f3 8f7 8fa 8fd 8fe 900
901 906 907 90c 90e 912 915 917
91b 91d 929 92b 92d 92e 933 937
939 945 947 94b 94f 953 956 957
959 95c 95d 95f 962 965 968 969
96e 972 976 97a 97e 982 986 988
98c 98f 993 997 99b 99e 99f 9a1
9a4 9a5 9a7 9aa 9ad 9b0 9b1 9b6
9ba 9be 9c2 9c6 9ca 9ce 9d0 9d4
9d7 9db 9df 9e2 9e6 9ea 9ee 9f2
9f6 9fa 9fe a02 a06 a07 a09 a0d
a11 a15 a18 a1c a20 a23 a26 a2b
a2e a31 a34 a35 a3a a3b 1 a3d
a42 a46 a4a a4d a52 a57 a5a a5e
a5f a64 a67 a6c a6d a72 a75 a7a
a7b a80 a83 a87 a8b a8f a93 a96
a97 a99 a9e a9f aa1 aa2 aa7 aaa
aaf ab0 ab5 ab8 abd abe ac3 ac6
aca acb ad0 ad3 ad8 ad9 ade adf
ae4 ae6 aea aed af1 af5 af8 afc
b00 b03 b07 b0b b0c b11 b13 b17
b1b b1e b22 b26 b29 b2d b31 b34
b37 b3c b3f b42 b45 b46 b4b b4c
1 b4e b53 b57 b5b b5e b63 b68
b6b b6f b70 b75 b76 b7b b7f b83
b86 b8b b90 b93 b97 b9b b9e b9f
ba4 ba7 bac bad bb2 bb5 bb9 bbd
bc0 bc1 bc6 bc7 bcc bce bd2 bd5
bd9 bdd be1 be5 be9 bed bf1 bf5
bf9 c05 c0a c0e c12 c16 c1a c1c
c1d c22 1 c26 c2a c2e c31 c35
c39 c3d c41 c44 c48 c4c c4f c52
c57 c5a c5d c60 c61 c66 c67 1
c69 c6e c72 c76 c79 c7e c83 c86
c8a c8b c90 c91 c96 c9a c9e ca1
ca6 cab cae cb2 cb3 cb8 cbb cc0
cc1 cc6 cc9 ccd cd1 cd4 cd7 cd8
cda cdb ce0 ce1 ce6 ce8 cec cef
cf3 cf7 cfb cff d03 d07 d0b d17
d1c d20 d24 d28 d2c d2e d32 d34
d40 d42 d44 d45 d4a d4e d50 d5c
d60 d62 d63 d6c 
3b4
2
0 1 a 6 9 :3 6 16 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 b 1a b :2 4 :2 13
1d 13 :2 4 :2 13 1d 13 :2 4 :2 14
1e 14 :2 4 :2 14 1e 14 :2 4 e
17 16 :2 e :2 4 :2 16 25 16 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 59 5f 62 :2 59 70 8b 8
:2 70 d 10 :2 70 13 16 :2 70 b
e :2 70 13 16 1f 27 :2 1f 39
:2 16 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 30 33
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:3 4 15 :2 4 e 4 e 1c 7
15 23 e 1e 7 17 28 c
d 21 :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 58 5a 5b :2 58 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8e 91 :2 24 99 9c
:2 24 a8 ab b2 bb be :2 ab :2 24
:2 d 5e :2 a :2 7 :4 13 :2 7 4 :3 1
e 1b c d 1b :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 58 5a 5b :2 58
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 e 1c 7 15 e
1a 7 13 c d 17 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5a 5b
:2 58 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 e b 1a 21
2e d 21 7 e a 16 :3 14
a :2 13 1f a 1b a :2 13 1f
a :4 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5b 5c
:2 58 :2 29 :3 d :2 13 18 24 69 6c
:2 24 79 7c :2 24 80 83 :2 24 8f
92 :2 24 9a 9d :2 24 a9 ac b3
bc bf :2 ac :2 24 :2 d 5f :2 a :2 7
:4 13 :2 7 4 :3 1 8 f 18 29
:2 f 2d :2 8 7 31 33 :2 31 7
19 :2 7 1a 7 35 :2 4 8 f
18 29 :2 f 2d :2 8 7 31 33
:2 31 7 19 :2 7 1a 7 35 :3 4
:2 d 19 24 2a 3a 4b 23 34
47 56 :2 19 4 7 :2 11 23 :2 2d
39 3c 51 54 55 :2 51 :2 23 :3 7
:2 d 12 1e 63 66 :2 1e 73 76
:2 1e 7a 7d :2 1e 87 8a 93 9b
:2 a4 :2 93 af :2 8a :2 1e b7 ba :2 1e
c2 c5 :2 1e ca cd :2 1e d0 d3
:2 1e :2 7 58 :3 4 :2 f 21 :2 2a 34
38 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 55 58 59 :2 55
:2 26 :3 a :2 10 15 21 66 69 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5c :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 52 55 56 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 59 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
3b4
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :6 a :6 b
:6 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :7 13
:6 14 :7 16 :b 18 :11 19
1a :2 19 :2 1a :2 19
:2 1a :2 19 :2 1b :2 19
:9 1b :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :4 19
:3 18 :11 1f :b 20 :3 1f
:3 23 :3 25 :2 28 :3 29
:2 2a :3 2b 2c :2 2d
28 :5 2e 27 30
:5 31 :3 30 :2 32 :5 34
:11 35 :24 36 :3 35 :2 33
:6 32 2f :3 17 :2 3c
3d :2 3e 3c :5 3f
3b 41 :5 42 :3 41
:2 43 :5 45 :11 46 :24 47
:3 46 :2 44 :6 43 40
:3 17 :2 4d :2 4e :2 4f
:2 50 51 :2 52 4d
:5 53 4c 55 :5 56
:3 55 :2 57 :5 59 :11 5a
:24 5b :3 5a :2 58 :6 57
54 :3 17 61 :4 62
:2 63 61 :6 64 :5 65
64 :5 67 66 :3 64
60 6a :5 6b :3 6a
:2 6c :5 6e :11 6f :24 70
:3 6f :2 6d :6 6c 69
:3 17 :e 75 :3 76 :3 77
:3 75 :e 79 :3 7a :3 7b
:3 79 :8 7e :4 7f :3 7e
:11 81 :30 82 :3 81 :a 84
17 :3 87 :11 88 :b 89
:17 8a :3 88 :2 8c :3 8d
:3 8e 8f 8d 8c
8d :3 90 :3 87 :2 91
:5 93 :11 94 :b 95 :18 96
:3 94 :2 98 99 :3 9a
9b 99 98 99
:3 9c :2 92 :6 91 86
:7 1 
d6e
4
:3 0 1 :3 0 2
:a 0 3af 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 3af 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 3ad
0 b :6 0 10
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 3ad
0 d :6 0 10
:2 0 15 f :3 0
25 :7 0 29 26
27 3ad 0 e
:6 0 10 :2 0 17
f :3 0 2b :7 0
2f 2c 2d 3ad
0 11 :6 0 10
:2 0 19 f :3 0
31 :7 0 35 32
33 3ad 0 12
:6 0 10 :2 0 1b
f :3 0 37 :7 0
3b 38 39 3ad
0 13 :6 0 10
:2 0 1d 6 :3 0
3d :7 0 41 3e
3f 3ad 0 14
:6 0 10 :2 0 1f
f :3 0 43 :7 0
47 44 45 3ad
0 15 :6 0 10
:2 0 21 f :3 0
49 :7 0 4d 4a
4b 3ad 0 16
:6 0 10 :2 0 23
f :3 0 4f :7 0
53 50 51 3ad
0 17 :6 0 c
:2 0 25 f :3 0
55 :7 0 59 56
57 3ad 0 18
:6 0 10 :2 0 29
4 :3 0 27 5b
5d :6 0 60 5e
0 3ad 0 19
:6 0 68 69 0
2b 6 :3 0 62
:7 0 66 63 64
3ad 0 1a :6 0
6e 6f 0 2d
9 :3 0 a :2 0
4 6a :7 0 6d
6b 0 3ad 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 71 72
0 2 :4 0 2f
73 75 70 77
76 :2 0 1f :3 0
20 :3 0 79 7a
0 21 :4 0 1c
:3 0 22 :3 0 7d
7e 0 2 :4 0
31 7f 81 23
:4 0 24 :2 0 25
:3 0 33 84 86
:3 0 26 :4 0 24
:2 0 27 :4 0 36
89 8b :3 0 24
:2 0 3 :3 0 39
8d 8f :3 0 24
:2 0 27 :4 0 3c
91 93 :3 0 24
:2 0 28 :4 0 3f
95 97 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
9b 9d 2b :4 0
44 9a a0 47
99 a2 :3 0 24
:2 0 28 :4 0 4a
a4 a6 :3 0 24
:2 0 27 :4 0 4d
a8 aa :3 0 24
:2 0 7 :3 0 50
ac ae :3 0 24
:2 0 27 :4 0 53
b0 b2 :3 0 24
:2 0 2c :4 0 56
b4 b6 :3 0 59
7b b8 :2 0 ba
5e bb 78 ba
0 bc 60 0
30d 1c :3 0 1d
:3 0 bd be 0
1c :3 0 2d :3 0
c0 c1 0 2e
:2 0 2 :4 0 2f
:2 0 30 :2 0 2e
:2 0 62 c6 c8
:3 0 65 c2 ca
bf cc cb :2 0
1f :3 0 31 :3 0
ce cf 0 21
:4 0 32 :4 0 24
:2 0 25 :3 0 69
d3 d5 :3 0 6c
d0 d7 :2 0 d9
6f da cd d9
0 db 71 0
30d d :3 0 7
:3 0 dc dd 0
30d 14 :3 0 10
:2 0 df e0 0
30d 33 :3 0 34
:3 0 35 :3 0 36
:3 0 37 :3 0 15
:3 0 16 :3 0 17
:3 0 18 :3 0 1a
:3 0 38 :3 0 39
:3 0 3 :4 0 3a
1 :8 0 f5 9
:3 0 3b :3 0 f0
f1 0 3c :3 0
f2 f3 0 f5
73 148 3d :3 0
9 :3 0 3b :3 0
f7 f8 0 3c
:3 0 f9 fa 0
fc 76 fe 78
fd fc :2 0 146
3e :3 0 9 :3 0
3b :3 0 101 102
0 3c :3 0 103
104 0 13e 1c
:3 0 1d :3 0 106
107 0 1c :3 0
2d :3 0 109 10a
0 3f :2 0 2
:4 0 40 :2 0 30
:2 0 2e :2 0 7a
10f 111 :3 0 7d
10b 113 108 115
114 :2 0 1f :3 0
31 :3 0 117 118
0 21 :4 0 41
:4 0 24 :2 0 25
:3 0 81 11c 11e
:3 0 24 :2 0 42
:4 0 84 120 122
:3 0 24 :2 0 43
:4 0 87 124 126
:3 0 24 :2 0 3c
:3 0 8a 128 12a
:3 0 24 :2 0 44
:4 0 8d 12c 12e
:3 0 24 :2 0 45
:3 0 46 :3 0 2e
:2 0 47 :2 0 90
131 135 94 130
137 :3 0 97 119
139 :2 0 13b 9a
13c 116 13b 0
13d 9c 0 13e
9e 141 :3 0 141
0 141 140 13e
13f :6 0 143 2
:3 0 a1 145 a3
144 143 :2 0 146
a5 :2 0 148 0
148 147 f5 146
:6 0 30d 1 :3 0
48 :3 0 19 :3 0
49 :3 0 4a :3 0
7 :4 0 4b 1
:8 0 155 9 :3 0
3b :3 0 150 151
0 3c :3 0 152
153 0 155 a8
1a8 3d :3 0 9
:3 0 3b :3 0 157
158 0 3c :3 0
159 15a 0 15c
ab 15e ad 15d
15c :2 0 1a6 3e
:3 0 9 :3 0 3b
:3 0 161 162 0
3c :3 0 163 164
0 19e 1c :3 0
1d :3 0 166 167
0 1c :3 0 2d
:3 0 169 16a 0
3f :2 0 2 :4 0
4c :2 0 30 :2 0
2e :2 0 af 16f
171 :3 0 b2 16b
173 168 175 174
:2 0 1f :3 0 31
:3 0 177 178 0
21 :4 0 4d :4 0
24 :2 0 25 :3 0
b6 17c 17e :3 0
24 :2 0 42 :4 0
b9 180 182 :3 0
24 :2 0 43 :4 0
bc 184 186 :3 0
24 :2 0 3c :3 0
bf 188 18a :3 0
24 :2 0 44 :4 0
c2 18c 18e :3 0
24 :2 0 45 :3 0
46 :3 0 2e :2 0
47 :2 0 c5 191
195 c9 190 197
:3 0 cc 179 199
:2 0 19b cf 19c
176 19b 0 19d
d1 0 19e d3
1a1 :3 0 1a1 0
1a1 1a0 19e 19f
:6 0 1a3 4 :3 0
d6 1a5 d8 1a4
1a3 :2 0 1a6 da
:2 0 1a8 0 1a8
1a7 155 1a6 :6 0
30d 1 :3 0 33
:3 0 4e :3 0 35
:3 0 4f :3 0 e
:3 0 12 :3 0 11
:3 0 13 :3 0 50
:3 0 48 :3 0 19
:4 0 51 1 :8 0
1bb 9 :3 0 3b
:3 0 1b6 1b7 0
3c :3 0 1b8 1b9
0 1bb dd 20e
3d :3 0 9 :3 0
3b :3 0 1bd 1be
0 3c :3 0 1bf
1c0 0 1c2 e0
1c4 e2 1c3 1c2
:2 0 20c 3e :3 0
9 :3 0 3b :3 0
1c7 1c8 0 3c
:3 0 1c9 1ca 0
204 1c :3 0 1d
:3 0 1cc 1cd 0
1c :3 0 2d :3 0
1cf 1d0 0 3f
:2 0 2 :4 0 52
:2 0 30 :2 0 2e
:2 0 e4 1d5 1d7
:3 0 e7 1d1 1d9
1ce 1db 1da :2 0
1f :3 0 31 :3 0
1dd 1de 0 21
:4 0 53 :4 0 24
:2 0 25 :3 0 eb
1e2 1e4 :3 0 24
:2 0 42 :4 0 ee
1e6 1e8 :3 0 24
:2 0 43 :4 0 f1
1ea 1ec :3 0 24
:2 0 3c :3 0 f4
1ee 1f0 :3 0 24
:2 0 44 :4 0 f7
1f2 1f4 :3 0 24
:2 0 45 :3 0 46
:3 0 2e :2 0 47
:2 0 fa 1f7 1fb
fe 1f6 1fd :3 0
101 1df 1ff :2 0
201 104 202 1dc
201 0 203 106
0 204 108 207
:3 0 207 0 207
206 204 205 :6 0
209 6 :3 0 10b
20b 10d 20a 209
:2 0 20c 10f :2 0
20e 0 20e 20d
1bb 20c :6 0 30d
1 :3 0 38 :3 0
54 :3 0 55 :3 0
54 :3 0 5 :3 0
39 :3 0 3 :4 0
56 1 :8 0 22d
57 :4 0 218 :3 0
58 :3 0 59 :2 0
114 21b 21c :3 0
9 :3 0 3b :3 0
21e 21f 0 10
:2 0 220 221 0
223 117 22a 9
:3 0 3b :3 0 224
225 0 5a :2 0
226 227 0 229
119 22b 21d 223
0 22c 0 229
0 22c 11b 0
22d 11e 280 3d
:3 0 9 :3 0 3b
:3 0 22f 230 0
3c :3 0 231 232
0 234 121 236
123 235 234 :2 0
27e 3e :3 0 9
:3 0 3b :3 0 239
23a 0 3c :3 0
23b 23c 0 276
1c :3 0 1d :3 0
23e 23f 0 1c
:3 0 2d :3 0 241
242 0 3f :2 0
2 :4 0 5b :2 0
30 :2 0 2e :2 0
125 247 249 :3 0
128 243 24b 240
24d 24c :2 0 1f
:3 0 31 :3 0 24f
250 0 21 :4 0
5c :4 0 24 :2 0
25 :3 0 12c 254
256 :3 0 24 :2 0
42 :4 0 12f 258
25a :3 0 24 :2 0
43 :4 0 132 25c
25e :3 0 24 :2 0
3c :3 0 135 260
262 :3 0 24 :2 0
44 :4 0 138 264
266 :3 0 24 :2 0
45 :3 0 46 :3 0
2e :2 0 47 :2 0
13b 269 26d 13f
268 26f :3 0 142
251 271 :2 0 273
145 274 24e 273
0 275 147 0
276 149 279 :3 0
279 0 279 278
276 277 :6 0 27b
8 :3 0 14c 27d
14e 27c 27b :2 0
27e 150 :2 0 280
0 280 27f 22d
27e :6 0 30d 1
:3 0 55 :3 0 29
:3 0 5 :3 0 10
:2 0 153 283 286
2e :2 0 156 282
289 28a :2 0 5d
:2 0 10 :2 0 15b
28c 28e :3 0 15
:3 0 e :3 0 290
291 0 296 17
:3 0 11 :3 0 293
294 0 296 15e
297 28f 296 0
298 161 0 30d
55 :3 0 29 :3 0
5 :3 0 10 :2 0
163 29a 29d 5e
:2 0 166 299 2a0
2a1 :2 0 5d :2 0
10 :2 0 16b 2a3
2a5 :3 0 16 :3 0
12 :3 0 2a7 2a8
0 2ad 18 :3 0
13 :3 0 2aa 2ab
0 2ad 16e 2ae
2a6 2ad 0 2af
171 0 30d 9
:3 0 3b :3 0 2b0
2b1 0 5f :3 0
b :3 0 15 :3 0
17 :3 0 16 :3 0
18 :3 0 1a :3 0
d :3 0 14 :3 0
173 2b3 2bc 2b2
2bd 0 30d 1c
:3 0 1d :3 0 2bf
2c0 0 1c :3 0
2d :3 0 2c2 2c3
0 60 :2 0 2
:4 0 61 :2 0 30
:2 0 2e :2 0 17c
2c8 2ca :3 0 17f
2c4 2cc 2c1 2ce
2cd :2 0 1f :3 0
31 :3 0 2d0 2d1
0 21 :4 0 62
:4 0 24 :2 0 25
:3 0 183 2d5 2d7
:3 0 24 :2 0 42
:4 0 186 2d9 2db
:3 0 24 :2 0 63
:4 0 189 2dd 2df
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3b :3 0 2e4
2e5 0 18c 2e3
2e7 2b :4 0 18e
2e2 2ea 191 2e1
2ec :3 0 24 :2 0
64 :4 0 194 2ee
2f0 :3 0 24 :2 0
27 :4 0 197 2f2
2f4 :3 0 24 :2 0
3 :3 0 19a 2f6
2f8 :3 0 24 :2 0
27 :4 0 19d 2fa
2fc :3 0 1a0 2d2
2fe :2 0 300 1a3
301 2cf 300 0
302 1a5 0 30d
65 :3 0 66 :3 0
303 304 0 9
:3 0 3b :3 0 306
307 0 3 :3 0
58 :3 0 1a7 305
30b :2 0 30d 1ab
3ae 9 :3 0 67
:2 0 4 30e 30f
0 1c :3 0 1d
:3 0 311 312 0
1c :3 0 2d :3 0
314 315 0 3f
:2 0 2 :4 0 68
:2 0 30 :2 0 2e
:2 0 1b9 31a 31c
:3 0 1bc 316 31e
313 320 31f :2 0
1f :3 0 31 :3 0
322 323 0 21
:4 0 69 :4 0 24
:2 0 25 :3 0 1c0
327 329 :3 0 1c3
324 32b :2 0 344
1f :3 0 31 :3 0
32d 32e 0 21
:4 0 6a :4 0 24
:2 0 9 :3 0 6b
:3 0 333 334 0
1c6 332 336 :3 0
24 :2 0 64 :4 0
1c9 338 33a :3 0
24 :2 0 9 :3 0
6c :3 0 33d 33e
0 1cc 33c 340
:3 0 1cf 32f 342
:2 0 344 1d2 345
321 344 0 346
1d5 0 356 6d
:3 0 1b :3 0 9
:3 0 6b :3 0 6e
:3 0 9 :3 0 6c
:3 0 3 :3 0 6f
:4 0 70 1 :a 0
352 :2 0 356 348
350 :2 0 8 :3 0
1b :3 0 354 :2 0
356 1d7 358 1db
357 356 :2 0 3ac
3e :3 0 9 :3 0
3b :3 0 35b 35c
0 3c :3 0 35d
35e 0 3a4 1c
:3 0 1d :3 0 360
361 0 1c :3 0
2d :3 0 363 364
0 3f :2 0 2
:4 0 71 :2 0 30
:2 0 2e :2 0 1dd
369 36b :3 0 1e0
365 36d 362 36f
36e :2 0 1f :3 0
31 :3 0 371 372
0 21 :4 0 72
:4 0 24 :2 0 25
:3 0 1e4 376 378
:3 0 1e7 373 37a
:2 0 394 1f :3 0
31 :3 0 37c 37d
0 21 :4 0 43
:4 0 24 :2 0 3c
:3 0 1ea 381 383
:3 0 24 :2 0 44
:4 0 1ed 385 387
:3 0 24 :2 0 45
:3 0 46 :3 0 2e
:2 0 47 :2 0 1f0
38a 38e 1f4 389
390 :3 0 1f7 37e
392 :2 0 394 1fa
395 370 394 0
396 1fd 0 3a4
6d :3 0 1b :3 0
6e :3 0 9 :3 0
6c :3 0 3 :3 0
6f :4 0 73 1
:a 0 3a0 :2 0 3a4
398 39e :2 0 8
:3 0 1b :3 0 3a2
:2 0 3a4 1ff 3a7
:3 0 3a7 0 3a7
3a6 3a4 3a5 :6 0
3a9 1 :3 0 204
3ab 206 3aa 3a9
:2 0 3ac 208 :2 0
3ae 20b 3ae 3ad
30d 3ac :6 0 3af
:2 0 2 14 3ae
3b2 :3 0 3b1 3af
3b3 :8 0 
21a
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
24 1 2a 1
30 1 36 1
3c 1 42 1
48 1 4e 1
54 1 5c 1
5a 1 61 1
67 1 74 1
80 2 83 85
2 88 8a 2
8c 8e 2 90
92 2 94 96
1 9c 2 9e
9f 2 98 a1
2 a3 a5 2
a7 a9 2 ab
ad 2 af b1
2 b3 b5 4
7c 82 87 b7
1 b9 1 bb
2 c5 c7 3
c3 c4 c9 2
d2 d4 2 d1
d6 1 d8 1
da 2 ef f4
1 fb 1 f6
2 10e 110 3
10c 10d 112 2
11b 11d 2 11f
121 2 123 125
2 127 129 2
12b 12d 3 132
133 134 2 12f
136 2 11a 138
1 13a 1 13c
2 105 13d 1
141 1 100 2
fe 145 2 14f
154 1 15b 1
156 2 16e 170
3 16c 16d 172
2 17b 17d 2
17f 181 2 183
185 2 187 189
2 18b 18d 3
192 193 194 2
18f 196 2 17a
198 1 19a 1
19c 2 165 19d
1 1a1 1 160
2 15e 1a5 2
1b5 1ba 1 1c1
1 1bc 2 1d4
1d6 3 1d2 1d3
1d8 2 1e1 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
3 1f8 1f9 1fa
2 1f5 1fc 2
1e0 1fe 1 200
1 202 2 1cb
203 1 207 1
1c6 2 1c4 20b
1 21a 2 219
21a 1 222 1
228 2 22a 22b
2 217 22c 1
233 1 22e 2
246 248 3 244
245 24a 2 253
255 2 257 259
2 25b 25d 2
25f 261 2 263
265 3 26a 26b
26c 2 267 26e
2 252 270 1
272 1 274 2
23d 275 1 279
1 238 2 236
27d 2 284 285
2 287 288 1
28d 2 28b 28d
2 292 295 1
297 2 29b 29c
2 29e 29f 1
2a4 2 2a2 2a4
2 2a9 2ac 1
2ae 8 2b4 2b5
2b6 2b7 2b8 2b9
2ba 2bb 2 2c7
2c9 3 2c5 2c6
2cb 2 2d4 2d6
2 2d8 2da 2
2dc 2de 1 2e6
2 2e8 2e9 2
2e0 2eb 2 2ed
2ef 2 2f1 2f3
2 2f5 2f7 2
2f9 2fb 2 2d3
2fd 1 2ff 1
301 3 308 309
30a d bc db
de e1 148 1a8
20e 280 298 2af
2be 302 30c 2
319 31b 3 317
318 31d 2 326
328 2 325 32a
2 331 335 2
337 339 2 33b
33f 2 330 341
2 32c 343 1
345 3 346 351
355 1 310 2
368 36a 3 366
367 36c 2 375
377 2 374 379
2 380 382 2
384 386 3 38b
38c 38d 2 388
38f 2 37f 391
2 37b 393 1
395 4 35f 396
39f 3a3 1 3a7
1 35a 2 358
3ab e 1b 22
28 2e 34 3a
40 46 4c 52
58 5f 65 6c

1
4
0 
3b2
0
1
14
a
12
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
42 1 0
61 1 0
5a 1 0
1d 1 0
54 1 0
3 1 0
b 1 0
2a 1 0
30 1 0
2 0 1
48 1 0
4e 1 0
16 1 0
3c 1 0
36 1 0
7 1 0
24 1 0
67 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES_EDITED;
ALTER FUNCTION SP_U_RATES_EDITED COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TIMECODE2
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TIMECODE2 ==
CREATE OR REPLACE FUNCTION SP_U_TIMECODE2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
55
2 :e:
1FUNCTION:
1SP_U_TIMECODE2:
1ASSIGN_ID:
1VARCHAR2:
1ID:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TEMP_SC_STATE:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TIMECODE2(:
1':
1, :
1);:
1CHECK_TRACE:
11:
117:
1+:
1FPUT:
1               ENTER:: SP_U_TIMECODE2(18) :: cplan.sql(13243) :: :
1IS NULL:
18:
122:
1      RETURN_INVALID:: SP_U_TIMECODE2(23) :: cplan.sql(13248) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
125:
1                EXIT:: SP_U_TIMECODE2(26) :: cplan.sql(13251) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TASK_ASSIGNMENTS:
1TIMECODE2_ID:
1TSK_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET TIMECODE2_ID = id WHERE TSK_ASSIGNMENT_ID = assig+
1n_id:
1FOUND:
1=:
1SC_STATE:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
145:
1           EXCEPTION:: SP_U_TIMECODE2(46) :: cplan.sql(13271) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
151:
1       RETURN_STATUS:: SP_U_TIMECODE2(52) :: cplan.sql(13277) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
158:
1           EXCEPTION:: SP_U_TIMECODE2(59) :: cplan.sql(13284) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
170:
1           EXCEPTION:: SP_U_TIMECODE2(71) :: cplan.sql(13296) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
250
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
250
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 71 5d 61 69 6c 5c
91 7c 80 59 84 8c 7b 98
9c 78 a0 a4 a8 ab b0 b1
1 b3 b8 bc c0 c3 c8 cc
d0 d3 d8 d9 db e0 e3 e7
e8 ed f2 f5 fa fb 100 103
107 108 10d 110 115 116 11b 11e
123 124 129 12c 131 132 137 13a
13e 13f 144 147 14c 14d 152 155
15a 15b 160 161 166 168 16c 16f
173 177 17a 17e 182 185 188 18d
190 193 196 197 19c 19d 1 19f
1a4 1a8 1ac 1af 1b4 1b9 1bc 1c0
1c1 1c6 1c7 1cc 1ce 1d2 1d5 1d9
1dc 1dd 1e2 1e5 1e8 1ec 1ef 1f0
1f5 1f8 1 1fb 200 204 208 20b
20f 213 216 219 21e 221 224 227
228 22d 22e 1 230 235 239 23d
240 245 24a 24d 251 252 257 25a
25f 260 265 268 26d 26e 273 276
27a 27e 282 286 289 28a 28c 291
292 294 295 29a 29b 2a0 2a2 2a6
2a9 2ad 2b1 2b4 2b8 2bc 2bf 2c2
2c7 2ca 2cd 2d0 2d1 2d6 2d7 1
2d9 2de 2e2 2e6 2e9 2ee 2f3 2f6
2fa 2fb 300 301 306 308 30c 30f
313 317 31a 31e 322 325 329 32a
32f 331 335 338 33c 340 344 348
34c 358 35c 361 365 368 369 36e
372 376 379 37c 380 382 386 38a
38d 390 394 396 39a 39e 3a1 3a3
3a7 3ab 3af 3b2 3b6 3ba 3bc 3bd
3c2 1 3c6 3ca 3ce 3d1 3d5 3d9
3dd 3e1 3e4 3e8 3ec 3ef 3f2 3f7
3fa 3fd 400 401 406 407 1 409
40e 412 416 419 41e 423 426 42a
42b 430 433 438 439 43e 441 446
447 44c 44f 453 454 459 45c 461
462 467 46a 46e 472 475 478 479
47b 47c 481 482 487 489 48d 490
492 496 498 4a4 4a6 4a8 4a9 4ae
4b2 4b4 4c0 4c2 4c6 4ca 4cd 4d1
4d5 4d8 4db 4e0 4e3 4e6 4e9 4ea
4ef 4f0 1 4f2 4f7 4fb 4ff 502
507 50c 50f 513 514 519 51c 521
522 527 52a 52f 530 535 538 53c
540 544 548 54b 54c 54e 553 554
556 557 55c 55f 564 565 56a 56d
572 573 578 57b 57f 580 585 588
58d 58e 593 594 599 59b 59f 5a2
5a6 5aa 5ad 5b1 5b5 5b8 5bc 5c0
5c1 5c6 5c8 5cc 5d0 5d3 5d7 5db
5de 5e2 5e6 5e9 5ec 5f1 5f4 5f7
5fa 5fb 600 601 1 603 608 60c
610 613 618 61d 620 624 625 62a
62b 630 634 638 63b 640 645 648
64c 650 653 654 659 65c 661 662
667 66a 66e 672 675 676 67b 67c
681 683 687 68a 68e 692 696 69a
69e 6a2 6a6 6aa 6ae 6ba 6bf 6c3
6c7 6cb 6cf 6d1 6d2 6d7 1 6db
6df 6e3 6e6 6ea 6ee 6f2 6f6 6f9
6fd 701 704 707 70c 70f 712 715
716 71b 71c 1 71e 723 727 72b
72e 733 738 73b 73f 740 745 746
74b 74f 753 756 75b 760 763 767
768 76d 770 775 776 77b 77e 782
786 789 78c 78d 78f 790 795 796
79b 79d 7a1 7a4 7a8 7ac 7b0 7b4
7b8 7bc 7c0 7cc 7d1 7d5 7d9 7dd
7e1 7e3 7e7 7e9 7f5 7f7 7f9 7fa
7ff 803 805 811 815 817 818 821 
250
2
0 1 a 6 10 :3 6 9 :2 6
1 3 a 13 a :2 1 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 56 5c 5f :2 56
6d 85 8 :2 6d d 10 :2 6d 1a
1d :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 21 24 :2 6d 29 2c
:2 6d :2 7 4c :2 4 7 :2 11 23 :2 2d
39 3c 4e 50 51 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e :2 7 54
:2 4 :4 9 8 7 :4 22 21 20 :2 7
a :2 14 26 :2 30 3c 3f 51 53
54 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 51 53 54 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 2f :2 4
e 23 32 3b 4f 7 e a
16 :3 14 a :2 13 1f a 1b a
:2 13 1f a :4 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
57 58 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5b
:2 a :2 7 :4 13 :2 7 4 :3 1 7 :2 11
23 :2 2d 39 3c 4e 50 51 :2 4e
:2 23 :3 7 :2 d 12 1e 5f 62 :2 1e
6f 72 :2 1e 76 79 :2 1e 83 86
8f 97 :2 a0 :2 8f ab :2 86 :2 1e b3
b6 :2 1e be c1 :2 1e c6 c9 :2 1e
d3 d6 :2 1e :2 7 54 :3 4 :2 f 21
:2 2a 34 3f :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 52 54
55 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 58 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4f 51
52 :2 4f :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 55 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
250
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :6 7
:7 9 :b b :11 c d
:2 c :2 d :2 c :2 d
:2 c :2 e :2 c :2 e
:2 c :2 e :2 c :2 e
:2 c :2 e :4 c :3 b
:11 11 :b 12 :3 11 :e 15
:11 16 :20 17 :3 16 :11 19
:b 1a :3 19 :9 1c :3 15
:6 21 :6 22 :5 23 22
:5 25 24 :3 22 20
28 :5 29 :3 28 :2 2a
:5 2c :11 2d :24 2e :3 2d
:2 2b :6 2a 27 :3 a
:11 33 :30 34 :3 33 :a 36
a :3 39 :11 3a :b 3b
:17 3c :3 3a :2 3e :3 3f
:3 40 41 3f 3e
3f :3 42 :3 39 :2 43
:5 45 :11 46 :b 47 :18 48
:3 46 :2 4a 4b :3 4c
4d 4b 4a 4b
:3 4e :2 44 :6 43 38
:7 1 
823
4
:3 0 1 :3 0 2
:a 0 24b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 4
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :3 0 8 :2 0
4 b f 0
24b 2 10 :2 0
19 1a 0 :2 a
:3 0 13 :7 0 b
:2 0 17 14 15
249 0 9 :6 0
1f 20 0 c
7 :3 0 8 :2 0
4 1b :7 0 1e
1c 0 249 0
c :6 0 d :3 0
e :3 0 d :3 0
f :3 0 22 23
0 2 :4 0 e
24 26 21 28
27 :2 0 10 :3 0
11 :3 0 2a 2b
0 12 :4 0 d
:3 0 13 :3 0 2e
2f 0 2 :4 0
10 30 32 14
:4 0 15 :2 0 16
:3 0 12 35 37
:3 0 17 :4 0 15
:2 0 18 :4 0 15
3a 3c :3 0 15
:2 0 3 :3 0 18
3e 40 :3 0 15
:2 0 18 :4 0 1b
42 44 :3 0 15
:2 0 19 :4 0 1e
46 48 :3 0 15
:2 0 18 :4 0 21
4a 4c :3 0 15
:2 0 5 :3 0 24
4e 50 :3 0 15
:2 0 18 :4 0 27
52 54 :3 0 15
:2 0 1a :4 0 2a
56 58 :3 0 2d
2c 5a :2 0 5c
32 5d 29 5c
0 5e 34 0
1a9 d :3 0 e
:3 0 5f 60 0
d :3 0 1b :3 0
62 63 0 1c
:2 0 2 :4 0 1d
:2 0 1e :2 0 1c
:2 0 36 68 6a
:3 0 39 64 6c
61 6e 6d :2 0
10 :3 0 1f :3 0
70 71 0 12
:4 0 20 :4 0 15
:2 0 16 :3 0 3d
75 77 :3 0 40
72 79 :2 0 7b
43 7c 6f 7b
0 7d 45 0
1a9 3 :3 0 21
:2 0 47 7f 80
:3 0 81 :2 0 82
:2 0 5 :3 0 21
:2 0 49 85 86
:3 0 87 :2 0 88
:2 0 83 8a 89
:2 0 d :3 0 e
:3 0 8c 8d 0
d :3 0 1b :3 0
8f 90 0 22
:2 0 2 :4 0 23
:2 0 1e :2 0 1c
:2 0 4b 95 97
:3 0 4e 91 99
8e 9b 9a :2 0
10 :3 0 1f :3 0
9d 9e 0 12
:4 0 24 :4 0 15
:2 0 16 :3 0 52
a2 a4 :3 0 15
:2 0 25 :4 0 55
a6 a8 :3 0 15
:2 0 26 :4 0 58
aa ac :3 0 15
:2 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 b1 b2 0
5b b0 b4 2b
:4 0 5d af b7
60 ae b9 :3 0
63 9f bb :2 0
bd 66 be 9c
bd 0 bf 68
0 e8 d :3 0
e :3 0 c0 c1
0 d :3 0 1b
:3 0 c3 c4 0
1c :2 0 2 :4 0
2c :2 0 1e :2 0
1c :2 0 6a c9
cb :3 0 6d c5
cd c2 cf ce
:2 0 10 :3 0 1f
:3 0 d1 d2 0
12 :4 0 2d :4 0
15 :2 0 16 :3 0
71 d6 d8 :3 0
74 d3 da :2 0
dc 77 dd d0
dc 0 de 79
0 e8 2e :3 0
2f :3 0 df e0
0 29 :3 0 2a
:3 0 e2 e3 0
30 :3 0 7b e1
e6 :2 0 e8 7e
e9 8b e8 0
ea 82 0 1a9
31 :3 0 32 :3 0
5 :3 0 33 :3 0
3 :4 0 34 1
:8 0 106 35 :4 0
f1 :3 0 30 :3 0
36 :2 0 86 f4
f5 :3 0 7 :3 0
37 :3 0 f7 f8
0 b :2 0 f9
fa 0 fc 89
103 7 :3 0 37
:3 0 fd fe 0
38 :2 0 ff 100
0 102 8b 104
f6 fc 0 105
0 102 0 105
8d 0 106 90
159 39 :3 0 7
:3 0 37 :3 0 108
109 0 3a :3 0
10a 10b 0 10d
93 10f 95 10e
10d :2 0 157 3b
:3 0 7 :3 0 37
:3 0 112 113 0
3a :3 0 114 115
0 14f d :3 0
e :3 0 117 118
0 d :3 0 1b
:3 0 11a 11b 0
3c :2 0 2 :4 0
3d :2 0 1e :2 0
1c :2 0 97 120
122 :3 0 9a 11c
124 119 126 125
:2 0 10 :3 0 1f
:3 0 128 129 0
12 :4 0 3e :4 0
15 :2 0 16 :3 0
9e 12d 12f :3 0
15 :2 0 25 :4 0
a1 131 133 :3 0
15 :2 0 3f :4 0
a4 135 137 :3 0
15 :2 0 3a :3 0
a7 139 13b :3 0
15 :2 0 40 :4 0
aa 13d 13f :3 0
15 :2 0 41 :3 0
42 :3 0 1c :2 0
43 :2 0 ad 142
146 b1 141 148
:3 0 b4 12a 14a
:2 0 14c b7 14d
127 14c 0 14e
b9 0 14f bb
152 :3 0 152 0
152 151 14f 150
:6 0 154 2 :3 0
be 156 c0 155
154 :2 0 157 c2
:2 0 159 0 159
158 106 157 :6 0
1a9 1 :3 0 d
:3 0 e :3 0 15b
15c 0 d :3 0
1b :3 0 15e 15f
0 44 :2 0 2
:4 0 45 :2 0 1e
:2 0 1c :2 0 c5
164 166 :3 0 c8
160 168 15d 16a
169 :2 0 10 :3 0
1f :3 0 16c 16d
0 12 :4 0 46
:4 0 15 :2 0 16
:3 0 cc 171 173
:3 0 15 :2 0 25
:4 0 cf 175 177
:3 0 15 :2 0 26
:4 0 d2 179 17b
:3 0 15 :2 0 27
:3 0 28 :3 0 7
:3 0 37 :3 0 180
181 0 d5 17f
183 2b :4 0 d7
17e 186 da 17d
188 :3 0 15 :2 0
47 :4 0 dd 18a
18c :3 0 15 :2 0
18 :4 0 e0 18e
190 :3 0 15 :2 0
3 :3 0 e3 192
194 :3 0 15 :2 0
18 :4 0 e6 196
198 :3 0 e9 16e
19a :2 0 19c ec
19d 16b 19c 0
19e ee 0 1a9
2e :3 0 48 :3 0
19f 1a0 0 7
:3 0 37 :3 0 1a2
1a3 0 3 :3 0
30 :3 0 f0 1a1
1a7 :2 0 1a9 f4
24a 7 :3 0 49
:2 0 4 1aa 1ab
0 d :3 0 e
:3 0 1ad 1ae 0
d :3 0 1b :3 0
1b0 1b1 0 3c
:2 0 2 :4 0 4a
:2 0 1e :2 0 1c
:2 0 fb 1b6 1b8
:3 0 fe 1b2 1ba
1af 1bc 1bb :2 0
10 :3 0 1f :3 0
1be 1bf 0 12
:4 0 4b :4 0 15
:2 0 16 :3 0 102
1c3 1c5 :3 0 105
1c0 1c7 :2 0 1e0
10 :3 0 1f :3 0
1c9 1ca 0 12
:4 0 4c :4 0 15
:2 0 7 :3 0 4d
:3 0 1cf 1d0 0
108 1ce 1d2 :3 0
15 :2 0 47 :4 0
10b 1d4 1d6 :3 0
15 :2 0 7 :3 0
4e :3 0 1d9 1da
0 10e 1d8 1dc
:3 0 111 1cb 1de
:2 0 1e0 114 1e1
1bd 1e0 0 1e2
117 0 1f2 4f
:3 0 c :3 0 7
:3 0 4d :3 0 50
:3 0 7 :3 0 4e
:3 0 5 :3 0 51
:4 0 52 1 :a 0
1ee :2 0 1f2 1e4
1ec :2 0 6 :3 0
c :3 0 1f0 :2 0
1f2 119 1f4 11d
1f3 1f2 :2 0 248
3b :3 0 7 :3 0
37 :3 0 1f7 1f8
0 3a :3 0 1f9
1fa 0 240 d
:3 0 e :3 0 1fc
1fd 0 d :3 0
1b :3 0 1ff 200
0 3c :2 0 2
:4 0 53 :2 0 1e
:2 0 1c :2 0 11f
205 207 :3 0 122
201 209 1fe 20b
20a :2 0 10 :3 0
1f :3 0 20d 20e
0 12 :4 0 54
:4 0 15 :2 0 16
:3 0 126 212 214
:3 0 129 20f 216
:2 0 230 10 :3 0
1f :3 0 218 219
0 12 :4 0 3f
:4 0 15 :2 0 3a
:3 0 12c 21d 21f
:3 0 15 :2 0 40
:4 0 12f 221 223
:3 0 15 :2 0 41
:3 0 42 :3 0 1c
:2 0 43 :2 0 132
226 22a 136 225
22c :3 0 139 21a
22e :2 0 230 13c
231 20c 230 0
232 13f 0 240
4f :3 0 c :3 0
50 :3 0 7 :3 0
4e :3 0 5 :3 0
51 :4 0 55 1
:a 0 23c :2 0 240
234 23a :2 0 6
:3 0 c :3 0 23e
:2 0 240 141 243
:3 0 243 0 243
242 240 241 :6 0
245 1 :3 0 146
247 148 246 245
:2 0 248 14a :2 0
24a 14d 24a 249
1a9 248 :6 0 24b
:2 0 2 10 24a
24e :3 0 24d 24b
24f :8 0 
150
4
:3 0 1 3 1
7 2 6 a
1 12 1 18
1 25 1 31
2 34 36 2
39 3b 2 3d
3f 2 41 43
2 45 47 2
49 4b 2 4d
4f 2 51 53
2 55 57 4
2d 33 38 59
1 5b 1 5d
2 67 69 3
65 66 6b 2
74 76 2 73
78 1 7a 1
7c 1 7e 1
84 2 94 96
3 92 93 98
2 a1 a3 2
a5 a7 2 a9
ab 1 b3 2
b5 b6 2 ad
b8 2 a0 ba
1 bc 1 be
2 c8 ca 3
c6 c7 cc 2
d5 d7 2 d4
d9 1 db 1
dd 2 e4 e5
3 bf de e7
1 e9 1 f3
2 f2 f3 1
fb 1 101 2
103 104 2 f0
105 1 10c 1
107 2 11f 121
3 11d 11e 123
2 12c 12e 2
130 132 2 134
136 2 138 13a
2 13c 13e 3
143 144 145 2
140 147 2 12b
149 1 14b 1
14d 2 116 14e
1 152 1 111
2 10f 156 2
163 165 3 161
162 167 2 170
172 2 174 176
2 178 17a 1
182 2 184 185
2 17c 187 2
189 18b 2 18d
18f 2 191 193
2 195 197 2
16f 199 1 19b
1 19d 3 1a4
1a5 1a6 6 5e
7d ea 159 19e
1a8 2 1b5 1b7
3 1b3 1b4 1b9
2 1c2 1c4 2
1c1 1c6 2 1cd
1d1 2 1d3 1d5
2 1d7 1db 2
1cc 1dd 2 1c8
1df 1 1e1 3
1e2 1ed 1f1 1
1ac 2 204 206
3 202 203 208
2 211 213 2
210 215 2 21c
21e 2 220 222
3 227 228 229
2 224 22b 2
21b 22d 2 217
22f 1 231 4
1fb 232 23b 23f
1 243 1 1f6
2 1f4 247 2
16 1d 
1
4
0 
24e
0
1
14
4
5
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
12 1 0
3 1 0
18 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TIMECODE2;
ALTER FUNCTION SP_U_TIMECODE2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_S_PROFILE
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
 $$bitflag       Description
   0	-  WBS Project global view: Resources  Profile with Competencies  Skills
   1	-  WBS Project global view: Resources  Profiles
   6	-  CRI Project global view: Resources  Profiles
   2,3	-  WBS  CRI - Assignments View
   4	-  WBS  CRI - All assignments with effort (no participants, no project assignments) in the current project
   5	-  WBS  CRI - All participants (no effort) in the current project
   8	-  WBS  CRI - All assignments (effort, participants, project assignments) in the current project
   9	-  WBS  CRI - All assignments for a Resource / Profile under a element (project, deliverable, task)
   7	-  WBS Project Assignments
   11	-  DOC Assignments View (SC_TABLE_DOC, SC_TABLE_POL_DOC, SC_TABLE_RES_DOC, SC_TABLE_AST_DOC,SC_TABLE_CLN_DOC,SC_TABLE_VDR_DOC)
   12	-  WBS  CRI - display nickname for All assignments (effort, participants, project assignments) in the current project
   13	-  Returns nickname for All assignments (effort, participants, project assignments) in the current pool
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_S_PROFILE ==
CREATE OR REPLACE FUNCTION SP_S_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
200
2 :e:
1FUNCTION:
1SP_S_PROFILE:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_ID:
132:
1H_REC_USER:
1H_PROJECT_ID:
1H_IN:
1255:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_PER_DAY:
1H_TYPE_ID:
1H_COUNT:
1H_TEMP_SC_STATE:
1H_LEVEL_STATE:
1C7751A:
1C7751B:
1C7751C:
1C7751T:
1C7751D:
1C7751E:
1C7751F:
1C7751G:
1C7751H:
1C7751J:
1C7751L:
1C7751M:
1C7751N:
1C77513N:
1CLN_AST_RES:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_S_PROFILE(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
175:
1+:
1FPUT:
1               ENTER:: SP_S_PROFILE(76) :: cplan.sql(13411) :: :
1IS NULL:
182:
1        RETURN_ERROR:: SP_S_PROFILE(83) :: cplan.sql(13418) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
185:
1                EXIT:: SP_S_PROFILE(86) :: cplan.sql(13421) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1=:
12:
13:
1B:
1PROJECT_ID:
1TYPE_ID:
1A:
1MINUTE_PER_DAY:
1LEVEL_STATE:
1TMT_WBS:
1ELEMENT_ID:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480), B.LEVEL_STAT+
1E:n         INTO h_project_id, h_type_id, h_per_day, h_level_state:n         +
1FROM TMT_WBS A, TMT_WBS B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJ+
1ECT_ID:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1110:
1           EXCEPTION:: SP_S_PROFILE(111) :: cplan.sql(13446) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480):n            +
1INTO h_project_id, h_type_id, h_per_day:n            FROM TMT_WBS A, TMT_CRI +
1B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJECT_ID:
1129:
1           EXCEPTION:: SP_S_PROFILE(130) :: cplan.sql(13465) :: :
1TMT_POOLS:
1SELECT 480 INTO h_per_day FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1146:
1           EXCEPTION:: SP_S_PROFILE(147) :: cplan.sql(13482) :: :
1153:
1        RETURN_ERROR:: SP_S_PROFILE(154) :: cplan.sql(13489) :: :
1156:
1                EXIT:: SP_S_PROFILE(157) :: cplan.sql(13492) :: :
1ELSIF:
110:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID INTO h_project_id:n         FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1174:
1           EXCEPTION:: SP_S_PROFILE(175) :: cplan.sql(13510) :: :
1181:
1        RETURN_ERROR:: SP_S_PROFILE(182) :: cplan.sql(13517) :: :
1184:
1                EXIT:: SP_S_PROFILE(185) :: cplan.sql(13520) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = h_id:
1           EXCEPTION:: SP_S_PROFILE(201) :: cplan.sql(13536) :: :
113:
1RANK:
1SELECT RANK INTO h_rank FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1215:
1           EXCEPTION:: SP_S_PROFILE(216) :: cplan.sql(13551) :: :
1222:
1        RETURN_ERROR:: SP_S_PROFILE(223) :: cplan.sql(13558) :: :
1225:
1                EXIT:: SP_S_PROFILE(226) :: cplan.sql(13561) :: :
1480:
1!=:
1SC_SRCH_PARTICIPANT:
111:
1SC_ASSET_ASSIGNED_RESOURCES:
1SC_CLIENT_ASSIGNED_RESOURCES:
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = id:
1245:
1           EXCEPTION:: SP_S_PROFILE(246) :: cplan.sql(13581) :: :
1252:
1        RETURN_ERROR:: SP_S_PROFILE(253) :: cplan.sql(13588) :: :
1                EXIT:: SP_S_PROFILE(256) :: cplan.sql(13591) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_ASGNDRES_INFO:
1PMO_TMP_ASGNDRES_INFO:
1RESOURCE_ID:
1PARENT_ID:
1RATE_ID:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1R:
1RESOURCE_ASSIGNMENTS:
1JOIN:
1TMT_COMPETENCIES:
1RESOURCE_TYPE:
1INSERT INTO PMO_TMP_ASGNDRES_INFO:n         (:n         RESOURCE_ID,:n       +
1  PARENT_ID,:n         RATE_ID,:n         PROFICIENCY_LEVEL_ID,:n         PRE+
1FERENCE_LEVEL_ID,:n         EXPERIENCE_ID,:n         LAST_USED_DATETIME:n    +
1     ):n         SELECT DISTINCT:n         a.RESOURCE_ID,:n         r.PARENT_+
1ID,:n         r.RATE_ID,:n         r.PROFICIENCY_LEVEL_ID,:n         r.PREFER+
1ENCE_LEVEL_ID,:n         r.EXPERIENCE_ID,:n         r.LAST_USED_DATETIME:n   +
1      FROM RESOURCE_ASSIGNMENTS a JOIN TMT_COMPETENCIES r ON a.RESOURCE_ID=r.+
1RESOURCE_ID:n         WHERE PROJECT_ID = h_id AND RESOURCE_TYPE = '0':
1FOUND:
1100:
1301:
1           EXCEPTION:: SP_S_PROFILE(302) :: cplan.sql(13637) :: :
1DELETE FROM PMO_TMP_PROF_INFO:
1PMO_TMP_PROF_INFO:
1PROFILE_ID:
1INSERT INTO PMO_TMP_PROF_INFO (PROFILE_ID):n         SELECT DISTINCT RESOURCE+
1_ID:n         FROM RESOURCE_ASSIGNMENTS:n         WHERE PROJECT_ID = h_id AND+
1 RESOURCE_TYPE = '1':
1327:
1           EXCEPTION:: SP_S_PROFILE(328) :: cplan.sql(13663) :: :
1OPEN:
1TA:
1RES:
1RES_TYPE:
1P:
1FULL_NAME:
1ELEMENT_NAME:
1STATUS1_ID:
1E_MAIL_ADDRESS:
1D:
1ROLE_NAME:
1LAST_USED:
1RC:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1OBJECTIVES:
1RESOURCES:
1C:
1LEFT:
1OUTER:
1RATES:
1PRF:
1PROFILE_NAME:
1PROFILES:
1ROLE_ID:
1RESOURCE_ASSIGN_SKILLS:
1S:
1RES_ASSIGNMENT_ID:
1SKILL_ID:
1RESOURCE_ASSIGN_ROLES:
1SELECT CASE WHEN EXISTS(SELECT * FROM TASK_ASSIGNMENTS ta WHERE ta.PROJECT_ID+
1=h_id AND ta.RESOURCE_ID = RES.RESOURCE_ID) THEN 13 ELSE 185 END AS RES_TYPE,+
1:n      RES.RESOURCE_ID, p.FULL_NAME AS ELEMENT_NAME, p.STATUS1_ID, p.E_MAIL_+
1ADDRESS, d.TYPE_ID, d.ELEMENT_NAME AS ROLE_NAME,:n      RES.PROFICIENCY_LEVEL+
1_ID, RES.PREFERENCE_LEVEL_ID, RES.EXPERIENCE_ID, RES.LAST_USED_DATETIME AS LA+
1ST_USED,rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' A+
1S OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_ASGNDRES_INFO RES JOIN RESOURCES +
1p ON RES.RESOURCE_ID=p.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMEN+
1T_ID=RES.PARENT_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=RES.RATE_ID:n      :n      UNI+
1ON ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID, p.+
1PROFILE_NAME AS ELEMENT_NAME, 0 AS STATUS1_ID, '' AS E_MAIL_ADDRESS,:n      c+
1.TYPE_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFE+
1RENCE_LEVEL_ID,r.EXPERIENCE_ID,r.LAST_USED_DATETIME AS LAST_USED,:n      rc.R+
1EGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE,'' AS OBJECTIVES,+
1'' AS RANK:n      FROM PMO_TMP_PROF_INFO PRF  JOIN PROFILES p ON PRF.PROFILE_+
1ID=p.PROFILE_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON p.ROLE_ID=r.ELEM+
1ENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID+
1:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION+
1 ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PRO+
1FILE_NAME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE+
1_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE+
1_LEVEL_ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGU+
1LAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,''+
1 AS RANK:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=+
1p.PROFILE_ID:n      JOIN RESOURCE_ASSIGN_SKILLS s ON p.PROFILE_ID=s.RES_ASSIG+
1NMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.SKILL_ID=r.ELEMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n     +
1 LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      :n      UNION ALL:n +
1     :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS RESOURCE_ID,p.PROFILE_NA+
1ME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_ADDRESS,:n      c.TYPE_ID, c.+
1ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEVEL_ID, r.PREFERENCE_LEVEL_+
1ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST_USED,:n      rc.REGULAR_COS+
1T,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' AS OBJECTIVES,'' AS RAN+
1K:n      FROM PMO_TMP_PROF_INFO PRF JOIN PROFILES p ON PRF.PROFILE_ID=p.PROFI+
1LE_ID:n      JOIN RESOURCE_ASSIGN_ROLES s ON p.PROFILE_ID=s.RES_ASSIGNMENT_ID+
1:n      LEFT OUTER JOIN TMT_COMPETENCIES r ON s.ROLE_ID=r.ELEMENT_ID:n      L+
1EFT OUTER JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.PARENT_ID:n      LEFT OUT+
1ER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n      ORDER BY RES_TYPE, RESOURCE_I+
1D, TYPE_ID:
1376:
1                EXIT:: SP_S_PROFILE(377) :: cplan.sql(13712) :: :
16:
1DELETE FROM PMO_TMP_RES_DATA:
1PMO_TMP_RES_DATA:
1RA:
1PROJECT_ASSIGNMENT_ID:
1T:
1TASK_ID:
1INSERT INTO PMO_TMP_RES_DATA (RESOURCE_ID, TYPE_ID):n         SELECT DISTINCT+
1:n         ra.RESOURCE_ID,:n         CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL T+
1HEN 185 ELSE 13 END AS TYPE_ID:n         FROM RESOURCE_ASSIGNMENTS ra LEFT OU+
1TER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=h_id AND ra.RESOURCE_ID = ta.RE+
1SOURCE_ID:n         WHERE ra.PROJECT_ID=h_id AND ra.RESOURCE_TYPE='0' AND ta.+
1PROJECT_ASSIGNMENT_ID IS NuLL AND:n         NOT EXISTS(SELECT * FROM TASK_ASS+
1IGNMENTS t WHERE ra.RESOURCE_ID = t.RESOURCE_ID AND t.TASK_ID=h_id):
1404:
1           EXCEPTION:: SP_S_PROFILE(405) :: cplan.sql(13740) :: :
1FC_U_CREATETMPTABLE:
1PMO_TMP_CPLN01_TEMP:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME):n         SELECT DIS+
1TINCT r.PROFILE_ID ,r.PROFILE_NAME:n         FROM RESOURCE_ASSIGNMENTS a JOIN+
1 PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID :n         +
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETEN+
1CIES d ON d.ELEMENT_ID=c.PARENT_ID :n         JOIN TASK_ASSIGNMENTS t ON t.RE+
1S_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID AND t.PROJECT_ASSIGNMENT_ID IS NuLL:n    +
1     WHERE a.PROJECT_ID=h_id AND a.ELEMENT_TYPE>1:
1431:
1           EXCEPTION:: SP_S_PROFILE(432) :: cplan.sql(13767) :: :
1TO_TIMESTAMP:
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_EFFORT:
1START_DATE:
1FINISH_DATE:
1WORK:
1REMAINING:
1T_UNIT:
1BEST_START:
1BEST_FINISH:
1CALENDAR:
1PLANNED_WORK:
1PERIOD_AVAILABILITY:
1ASSIGN_STRING:
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,a.TYPE_ID,p.E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00+
1::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FIN+
1ISH,0 AS PLANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS STAR+
1T_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS+
1 REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BES+
1T_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, +
1'' AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_DATA+
1 a JOIN RESOURCES p ON a.RESOURCE_ID=p.RESOURCE_ID:n      :n      UNION ALL:n+
1      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_NAME,41 AS T+
1YPE_ID,'' AS E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FINISH,0 AS P+
1LANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DATE, TO+
1_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING+
1,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST+
1_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASS+
1IGN_STRING, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP:n    +
1  ORDER BY TYPE_ID:
1451:
1                EXIT:: SP_S_PROFILE(452) :: cplan.sql(13787) :: :
1PARTICIPANT:
1START_DT:
1FINISH_DT:
1WORK_LOCATION:
1SECURITY_ID:
1G:
1SECURITY_NAME:
1CRI_SECURITY_ID:
1G2:
1CRI_SECURITY_NAME:
1REGULAR_RATE:
1SPECIAL_RATE:
1FS_LABOR_CODE:
1REC_STATUS:
1TIMECODE2_ID:
1TC:
1TIMECODE2:
1C_EFFORT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1C_OCCURRENCE:
1BILLABLE:
1ASSIGNMENT_DELAY:
1TMT_GLOBAL_SECURITY:
1TMT_TIMECODES:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,:n      a.PROFILE_ID, p.PROFILE_NAME +
1AS ELEMENT_NAME,41 AS TYPE_ID,a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.PLANNED_S+
1TART,t.PLANNED_FINISH,:n      t.PLANNED_WORK,t.START_DT,t.FINISH_DT,h_per_day+
1 AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURIT+
1Y_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, +
1g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL+
1_COST,t.SPECIAL_RATE,'' AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,:n     +
1 t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID,TC.ELEMENT_NAME AS TIMECODE2, t.T_UNI+
1T, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, BILLABL+
1E,:n      t.ASSIGNMENT_DELAY:n      FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JO+
1IN TASK_ASSIGNMENTS t ON t.TASK_ID = h_id AND a.RES_ASSIGNMENT_ID = t.RES_ASS+
1IGNMENT_ID:n      LEFT OUTER JOIN PROFILES p ON a.RESOURCE_ID = p.PROFILE_ID +
1LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LE+
1FT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY+
1_ID)=g2.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= +
1t.TIMECODE2_ID:n      WHERE a.ELEMENT_ID = h_id AND a.RESOURCE_TYPE='1' ORDER+
1 BY ELEMENT_NAME:
1467:
1                EXIT:: SP_S_PROFILE(468) :: cplan.sql(13803) :: :
1ISTASK:
1COUNT:
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID = h_id:
1483:
1           EXCEPTION:: SP_S_PROFILE(484) :: cplan.sql(13819) :: :
1DUAL:
1BIT_FLAG:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n               SELEC+
1T 'X' FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND TASK_ID = h_i+
1d AND BIT_FLAG = '0'):
1503:
1           EXCEPTION:: SP_S_PROFILE(504) :: cplan.sql(13839) :: :
1TIMESHEET_APPROVAL_STATUS:
1APV:
1TO_DATE:
1ACTUAL_START:
1WEEK_OF:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n                  SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1           ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURC+
1E_ID:n                  WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = h+
1_id AND:n                  (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     )+
1 <= apv.WEEK_OF):
1523:
1           EXCEPTION:: SP_S_PROFILE(524) :: cplan.sql(13859) :: :
1SD:
1FD:
1SCHED_EFFORT:
1WORK_TODATE:
1UNITS_PERCENT:
1MILESTONE_PERCENT:
1TRUNC:
1TO_NUMBER:
1WORK_PERCENT:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1ACTUAL_FINISH:
1ACTUAL:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_EFFORT:
1PROPOSED_WORK:
1CLOB_DATA:
1EMPTYLOB:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_EFFORT:
1BASELINE1_WORK:
1TIMECODE2_NAME:
1CAPITAL_EXPENSE:
1RATE_ADJUSTMENT:
1ASSIGN_COUNT:
1DURATION:
1LEVEL_START:
1LEVEL_FINISH:
1LEVEL_DURATION:
1LEVEL_EFFORT:
1PERCENT_DISCRETE:
1TOP_ID:
1LEVEL_AFFECTED_FLAG:
1LABOR_COST_CC_ID:
1LABOR_COST_CC_NAME:
1LABOR_REVENUE_CC_ID:
1LABOR_REVENUE_CC_NAME:
1DEFAULT_LABOR_FLAG:
1CONTRACT_ID:
1CONTRACT_NAME:
1EXTERNAL_ID:
1SCHED_FINISH:
1SC_UFS:
1SC_FS:
1SC_SS:
1SC_FF:
1SC_SF:
1SCHED_START:
1SCHED_WORK:
1ASSIGN_UNITS:
1UNITS_MSP:
1SCHED_DURATION:
1PLANNED_DURATION:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1EC:
1CC:
1CTR:
1TMT_CHARGECODES:
1TMT_CONTRACTS:
1SELECT t.ELEMENT_ID, a.RESOURCE_ID, t.ELEMENT_NAME, t.TYPE_ID, '' AS RES_ASSI+
1GNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n         t.SD, t.FD, t.STA+
1RT_DT AS PLANNED_START, t.FINISH_DT AS PLANNED_FINISH,:n         t.SCHED_EFFO+
1RT + t.PLANNED_EFFORT AS PLANNED_WORK, t.SCHED_EFFORT + t.PLANNED_EFFORT - t.+
1WORK_TODATE AS REMAINING,:n         0 UNITS_PERCENT, t.MILESTONE_PERCENT,:n  +
1       CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE+
1)/TO_NUMBER(t.SCHED_EFFORT + t.PLANNED_EFFORT))*10000) END AS WORK_PERCENT,:n+
1         TO_TIMESTAMP('1899-12-31 00::00::00') AS BAK_START_DT,TO_TIMESTAMP('+
11899-12-31 00::00::00') AS BAK_FINISH_DT,0 AS BAK_WORK,:n         t.FORECAST_+
1START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WO+
1RK_TODATE AS ACTUAL,t.PROPOSED_START, t.PROPOSED_FINISH, t.PROPOSED_EFFORT AS+
1 PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_DAY, 0 AS WORK_LOCATION, ''+
1 AS SECURITY_ID, '' AS SECURITY_NAME,:n         '' AS CRI_SECURITY_ID, '' AS +
1CRI_SECURITY_NAME, 0.00 AS REGULAR_COST,0.00 AS REGULAR_RATE,0.00 AS SPECIAL_+
1COST,0.00 AS SPECIAL_RATE,:n         '' AS FS_LABOR_CODE,t.REC_STATUS,(SELECT+
1 CLOB_DATA FROM EMPTYLOB) AS ASSIGN_STRING,t.BASELINE1_START,t.BASELINE1_FINI+
1SH,t.BASELINE1_EFFORT AS BASELINE1_WORK,:n         '' AS PROJECT_ASSIGNMENT_I+
1D,'' AS TIMECODE2_ID, '' AS TIMECODE2_NAME, 0 AS T_UNIT, 0 AS C_EFFORT, 0 AS +
1C_UNIT, 0 AS C_CONTOUR, 0 AS CONTOUR_TYPE, 0 AS C_OCCURRENCE, 0 AS BILLABLE, +
10 AS CAPITAL_EXPENSE,:n         0 AS ASSIGNMENT_DELAY, h_bit_flag AS BIT_FLAG+
1, 0 AS RATE_ADJUSTMENT, t.ASSIGN_COUNT, t.DURATION,:n         CASE WHEN h_lev+
1el_state = 1 THEN t.LEVEL_START ELSE TO_TIMESTAMP('1899-12-31 00::00::00') EN+
1D AS LEVEL_START,:n         CASE WHEN h_level_state = 1 THEN t.LEVEL_FINISH E+
1LSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n         CASE+
1 WHEN h_level_state = 1 THEN t.LEVEL_DURATION ELSE 0 END AS LEVEL_EFFORT, t.W+
1ORK_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n  +
1       '' AS LABOR_COST_CC_ID, '' AS LABOR_COST_CC_NAME, '' AS LABOR_REVENUE_+
1CC_ID, '' AS LABOR_REVENUE_CC_NAME, 'N' AS DEFAULT_LABOR_FLAG,:n         '' A+
1S CONTRACT_ID, '' AS CONTRACT_NAME, '' AS EXTERNAL_ID:n         FROM TMT_WBS +
1t LEFT JOIN RESOURCE_ASSIGNMENTS a ON a.ELEMENT_ID = t.ELEMENT_ID AND a.RESOU+
1RCE_ID = h_rec_user:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECU+
1RITY_ID=g.ELEMENT_ID:n         WHERE t.PROJECT_ID = h_project_id AND t.ELEMEN+
1T_ID = h_id:n         UNION ALL:n         SELECT CASE WHEN t.TSK_ASSIGNMENT_I+
1D IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELSE a.RES_ASSIGNMENT_ID END AS ELEMEN+
1T_ID, a.RESOURCE_ID,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.P+
1ROFILE_NAME FROM PROFILES p WHERE a.RESOURCE_ID = p.PROFILE_ID):n         ELS+
1E (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) E+
1ND AS ELEMENT_NAME,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN 41 WHEN t.TS+
1K_ASSIGNMENT_ID IS NuLL THEN 185 ELSE 13 END AS TYPE_ID,:n         a.RES_ASSI+
1GNMENT_ID, a.PARTICIPANT, t.START_DT, COALESCE(PLANNED_FINISH,SCHED_FINISH) A+
1S FINISH_DT,:n         CASE WHEN t.SD = pmo_cnst.SC_UFS OR t.SD = pmo_cnst.SC+
1_FS THEN pmo_cnst.SC_SS ELSE t.SD END AS SD, CASE WHEN t.FD = pmo_cnst.SC_FF +
1THEN pmo_cnst.SC_SF ELSE t.FD END AS FD, :n         COALESCE(PLANNED_START,SC+
1HED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SCHED_FINISH) AS PLANNED+
1_FINISH,:n         CASE WHEN t.BIT_FLAG = '2' THEN t.SCHED_WORK ELSE t.PLANNE+
1D_WORK END AS PLANNED_WORK,:n         CASE WHEN t.BIT_FLAG = '2' THEN t.SCHED+
1_WORK - t.WORK_TODATE ELSE t.PLANNED_WORK END AS REMAINING,:n         CASE WH+
1EN t.ASSIGN_UNITS > t.UNITS_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS U+
1NITS_PERCENT,:n         0 AS MILESTONE_PERCENT,:n         CASE WHEN t.WORK_TO+
1DATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+S+
1CHED_WORK))*10000) END AS WORK_PERCENT,:n         t.BAK_START_DT,t.BAK_FINISH+
1_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_+
1START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTUAL,PROPOSED_START, PROP+
1OSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_DAY, a.WORK_LOC+
1ATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME,:n         COALESCE(a.C+
1RI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.ELEMENT_NAME AS CRI_SECU+
1RITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL_COST,t.SPECIAL_RATE,:n    +
1     CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_LABOR_CODE FROM RESOURCE+
1S r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n         ELSE '' END AS FS_LABOR_CO+
1DE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_START,t.BASELINE1_FINISH,t.BASELI+
1NE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID, TC.ELEMENT_NAME A+
1S TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE+
1, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n         t.ASSIGNMENT_DELAY+
1, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLAG = '0' THEN '1' ELSE '2+
1' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COUNT, :n         CASE WHEN+
1 t.BIT_FLAG = '2' THEN t.SCHED_DURATION ELSE t.PLANNED_DURATION END AS DURATI+
1ON,:n         CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_START,t.UNRES+
1OLVED_START) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_START,:n+
1         CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_FINISH,t.UNRESOLVE+
1D_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n  +
1       CASE WHEN h_level_state = 1 THEN CASE WHEN t.LEVEL_EFFORT = 0 THEN t.E+
1TC ELSE t.LEVEL_EFFORT END ELSE 0 END AS LEVEL_EFFORT, t.MILESTONE_PERCENT AS+
1 PERCENT_DISCRETE, 1 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,:n         T.LABOR+
1_COST_CC_ID,:n         EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LAB+
1OR_REVENUE_CC_ID,:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAU+
1LT_LABOR_FLAG,:n         T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME,:n +
1        CASE WHEN a.RESOURCE_TYPE= '0' THEN (SELECT r.EXTERNAL_ID FROM RESOUR+
1CES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) ELSE '' END AS EXTERNAL_ID:n      +
1   FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_AS+
1SIGNMENT_ID = t.RES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURI+
1TY g ON a.SECURITY_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECUR+
1ITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         L+
1EFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LE+
1FT OUTER JOIN TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n     +
1    LEFT OUTER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_+
1ID:n         LEFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT+
1_ID:n         WHERE a.PROJECT_ID = h_project_id AND a.ELEMENT_ID = h_id AND a+
1.REC_STATUS NOT IN ('L','D'):n         ORDER BY TOP_ID, ELEMENT_NAME:
1605:
1                EXIT:: SP_S_PROFILE(606) :: cplan.sql(13941) :: :
1TMT_ORGANIZATIONS:
1SC_PROFILE:
1SC_POOLS:
1SC_ORGANIZATION:
1SC_RESOURCE:
1BEST:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,a.RESOURCE_ID,:n         CASE WHEN a.+
1RESOURCE_TYPE='0' THEN (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_+
1ID = r.RESOURCE_ID):n         WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.PROFILE+
1_NAME FROM PROFILES p WHERE a.RESOURCE_ID = p.PROFILE_ID):n         WHEN a.RE+
1SOURCE_TYPE='2' THEN (SELECT p.ELEMENT_NAME FROM TMT_POOLS p WHERE a.RESOURCE+
1_ID = p.ELEMENT_ID):n         ELSE (SELECT p.ELEMENT_NAME FROM TMT_ORGANIZATI+
1ONS p WHERE a.RESOURCE_ID = p.ELEMENT_ID) END AS ELEMENT_NAME,:n         CASE+
1 WHEN a.RESOURCE_TYPE='1' THEN pmo_cnst.SC_PROFILE:n         WHEN a.RESOURCE_+
1TYPE='2' THEN pmo_cnst.SC_POOLS :n         WHEN a.RESOURCE_TYPE='3' THEN pmo_+
1cnst.SC_ORGANIZATION :n         WHEN t.TSK_ASSIGNMENT_ID IS NuLL THEN 185 ELS+
1E pmo_cnst.SC_RESOURCE END AS TYPE_ID,:n         a.RES_ASSIGNMENT_ID, a.PARTI+
1CIPANT, t.START_DT,t.FINISH_DT,:n         t.SD, t.FD, COALESCE(PLANNED_START,+
1SCHED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SCHED_FINISH) AS PLANN+
1ED_FINISH,:n         t.BEST AS PLANNED_WORK, CASE WHEN t.BIT_FLAG = '2' THEN +
1t.SCHED_WORK ELSE t.PLANNED_WORK END AS REMAINING,:n         t.UNITS_MSP AS U+
1NITS_PERCENT, t.MILESTONE_PERCENT, 0 AS WORK_PERCENT,:n         t.BAK_START_D+
1T,t.BAK_FINISH_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_FINISH,t.+
1ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTUAL,PROPOS+
1ED_START, PROPOSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_D+
1AY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME,:n       +
1  COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.ELEMENT_NA+
1ME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL_COST,t.SPECI+
1AL_RATE,:n         CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_LABOR_CODE+
1 FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n         ELSE '' END +
1AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_START,t.BASELINE1_F+
1INISH,t.BASELINE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID, TC.+
1ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, +
1t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n         t.AS+
1SIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLAG = '0' TH+
1EN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COUNT, 0 AS D+
1URATION,:n         t.LEVEL_START, t.LEVEL_FINISH, t.LEVEL_EFFORT, t.MILESTONE+
1_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n         CASE WHEN t.TSK_ASSIGNME+
1NT_ID IS NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMENT_ID AND (t.LE+
1VEL_START <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLVED_FINISH) THE+
1N '1' ELSE '0' END AS LEVEL_AFFECTED_FLAG,:n         T.LABOR_COST_CC_ID,:n   +
1      EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LABOR_REVENUE_CC_ID,+
1:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n +
1        T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME,:n         CASE WHEN+
1 a.RESOURCE_TYPE= '0' THEN (SELECT r.EXTERNAL_ID FROM RESOURCES r WHERE a.RES+
1OURCE_ID = r.RESOURCE_ID) ELSE '' END AS EXTERNAL_ID:n         FROM RESOURCE_+
1ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSIGNMENT_ID = t.R+
1ES_ASSIGNMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURIT+
1Y_ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESC+
1E(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT OUTER JOIN TM+
1T_TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LEFT OUTER JOIN TMT+
1_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n         LEFT OUTER JO+
1IN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n         LEFT+
1 OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n         WHE+
1RE a.REC_STATUS NOT IN ('L','D') AND a.ELEMENT_ID = h_id:n         ORDER BY T+
1YPE_ID, ELEMENT_NAME:
1651:
1                EXIT:: SP_S_PROFILE(652) :: cplan.sql(13987) :: :
14:
1DELETE FROM PMO_TMP_RES_SET:
1PMO_TMP_RES_SET:
1MIN:
1MAX:
1SUM:
1INSERT INTO PMO_TMP_RES_SET:n         (:n         RESOURCE_ID,:n         RESO+
1URCE_TYPE ,:n         PLANNED_START ,:n         PLANNED_FINISH ,:n         PL+
1ANNED_EFFORT ,:n         START_DATE ,:n         FINISH_DATE ,:n         WORK +
1,:n         REMAINING:n         ):n         SELECT:n         RESOURCE_ID,:n  +
1       RESOURCE_TYPE,:n         MIN(PLANNED_START) AS PLANNED_START,:n       +
1  MAX(PLANNED_FINISH) AS PLANNED_FINISH,:n         SUM(PLANNED_WORK) AS PLANN+
1ED_EFFORT,:n         MIN(SCHED_START) AS START_DATE,:n         MAX(SCHED_FINI+
1SH) AS FINISH_DATE,:n         SUM(SCHED_WORK) AS WORK,:n         SUM(ETC) AS +
1REMAINING:n         FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=h_id AND PROJECT_A+
1SSIGNMENT_ID IS NuLL GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1696:
1           EXCEPTION:: SP_S_PROFILE(697) :: cplan.sql(14032) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, PLANNED_START, PLANN+
1ED_FINISH, PLANNED_EFFORT,START_DATE, FINISH_DATE,:n         WORK, REMAINING)+
1:n         SELECT DISTINCT r.PROFILE_ID,r.PROFILE_NAME,:n         a.PLANNED_S+
1TART, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK,+
1 a.REMAINING:n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOURCE_T+
1YPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_I+
1D=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
1722:
1           EXCEPTION:: SP_S_PROFILE(723) :: cplan.sql(14058) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      :n      UNION ALL:n      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNM+
1ENT_ID, ELEMENT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      PLANNED_START+
1, PLANNED_FINISH,PLANNED_EFFORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0+
1 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_F+
1INISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIG+
1N_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP+
1_CPLN01_TEMP ORDER BY TYPE_ID:
1739:
1                EXIT:: SP_S_PROFILE(740) :: cplan.sql(14075) :: :
15:
1783:
1           EXCEPTION:: SP_S_PROFILE(784) :: cplan.sql(14119) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, RESOURCE_TYPE, TYPE_+
1ID, E_MAIL_ADDRESS, PLANNED_START, PLANNED_FINISH, PLANNED_EFFORT,START_DATE,+
1 FINISH_DATE,:n         WORK, REMAINING, FS_LABOR_CODE):n         SELECT DIST+
1INCT r.PROFILE_ID ,r.PROFILE_NAME ,'1',41 ,'',:n         a.PLANNED_START, a.P+
1LANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAIN+
1ING,:n         '':n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOU+
1RCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEM+
1ENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_I+
1D:n         UNION ALL:n         SELECT DISTINCT ra.RESOURCE_ID ,p.FULL_NAME ,+
1'0',185 ,p.E_MAIL_ADDRESS,:n         TO_TIMESTAMP('1899-12-31 00::00::00') , +
1TO_TIMESTAMP('1899-12-31 00::00::00') ,0 ,:n         TO_TIMESTAMP('1899-12-31+
1 00::00::00') , TO_TIMESTAMP('1899-12-31 00::00::00') , 0 , 0 ,p.FS_LABOR_COD+
1E:n         FROM RESOURCE_ASSIGNMENTS ra, RESOURCES p:n         WHERE ra.PROJ+
1ECT_ID=h_id AND ra.RESOURCE_ID = p.RESOURCE_ID:n         AND NOT EXISTS(SELEC+
1T ta.TSK_ASSIGNMENT_ID FROM TASK_ASSIGNMENTS ta:n         WHERE ta.RES_ASSIGN+
1MENT_ID IN (SELECT a.RES_ASSIGNMENT_ID:n         FROM RESOURCE_ASSIGNMENTS a +
1WHERE a.PROJECT_ID = ra.PROJECT_ID AND a.RESOURCE_ID = ra.RESOURCE_ID)):
1819:
1           EXCEPTION:: SP_S_PROFILE(820) :: cplan.sql(14155) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_+
1FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 A+
1S T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINI+
1SH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_+
1STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_RES_S+
1ET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_I+
1D:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_+
1NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED_FINISH,PLANNED_EFF+
1ORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0 AS T_UNIT,h_per_day AS MINU+
1TE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FINISH,0 AS CALENDAR, 0 AS PL+
1ANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STRING, FS_LABOR_CODE, '' +
1AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEMP WHERE RESOURCE_TYPE=+
1'1' AND TYPE_ID = 41:n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_ASSI+
1GNMENT_ID, ELEMENT_NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED+
1_FINISH,PLANNED_EFFORT,:n      START_DATE, FINISH_DATE, WORK, REMAINING,0 AS +
1T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BEST_FINISH,:n     +
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK:n      FROM PMO_TMP_CPLN01_TEM+
1P:n      WHERE RESOURCE_TYPE = '0' AND TYPE_ID = 185:n      ORDER BY TYPE_ID +
1DESC, ELEMENT_NAME:
1842:
1                EXIT:: SP_S_PROFILE(843) :: cplan.sql(14178) :: :
17:
1PLANNED_REMAINING:
1PA:
1DESCRIPTION:
1LEVEL_PLANNED_START:
1LEVEL_PLANNED_FINISH:
1LEVEL_SCHED_START:
1LEVEL_SCHED_FINISH:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1PROJECT_ASSIGNMENTS:
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      b.PLANNED_START, b.PLANNED_FI+
1NISH, b.BEST AS PLANNED_EFFORT, b.PLANNED_WORK AS PLANNED_REMAINING, a.BAK_ST+
1ART_DT AS START_DATE, a.BAK_FINISH_DT AS FINISH_DATE,:n      a.BEST AS WORK, +
1a.SCHED_WORK AS REMAINING, h_per_day AS MINUTE_PER_DAY,'' AS BEST_START, '' A+
1S BEST_FINISH,:n      0 AS CALENDAR,0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILI+
1TY, (SELECT CLOB_DATA FROM EMPTYLOB) AS ASSIGN_STRING,p.FS_LABOR_CODE, '' AS +
1OBJECTIVES,'' AS RANK,:n      pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_CO+
1ST, pa.SPECIAL_RATE, pa.DESCRIPTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_+
1PLANNED_FINISH, pa.LEVEL_SCHED_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMA+
1TED_BASELINE1_START, pa.ESTIMATED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EF+
1FORT,:n      pa.ESTIMATED_BASELINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.+
1ESTIMATED_BASELINE3_EFFORT, P.EXTERNAL_ID:n      FROM RESOURCE_ASSIGNMENTS t +
1JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID = h_id AND pa.RESOURCE_ID = t.RE+
1SOURCE_ID:n      LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNMENT_ID=t.RES_AS+
1SIGNMENT_ID AND a.BIT_FLAG='2':n      LEFT JOIN TASK_ASSIGNMENTS b ON b.RES_A+
1SSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b.BIT_FLAG='0':n      JOIN RESOURCES p O+
1N t.RESOURCE_ID=p.RESOURCE_ID:n      WHERE t.ELEMENT_ID=h_id AND t.RESOURCE_T+
1YPE='0' AND (a.TSK_ASSIGNMENT_ID IS NOT NuLL OR b.TSK_ASSIGNMENT_ID IS NOT Nu+
1LL):n      UNION ALL:n      SELECT t.RESOURCE_ID AS ELEMENT_ID, a.RES_ASSIGNM+
1ENT_ID, p.PROFILE_NAME AS ELEMENT_NAME, 41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n+
1      t.PLANNED_START, t.PLANNED_FINISH,t.BEST AS PLANNED_EFFORT,t.PLANNED_WO+
1RK AS PLANNED_REMAINING,TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DATE, +
1TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE,:n      0 AS WORK,0 AS R+
1EMAINING,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START, '' AS BEST_FINISH,:n  +
1    0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, t.ASSIGN_STRI+
1NG,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      pa.REGULAR_COST, +
1pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, pa.DESCRIPTION,:n      pa.+
1LEVEL_PLANNED_START, pa.LEVEL_PLANNED_FINISH, pa.LEVEL_SCHED_START, pa.LEVEL_+
1SCHED_FINISH,:n      pa.ESTIMATED_BASELINE1_START, pa.ESTIMATED_BASELINE1_FIN+
1ISH, pa.ESTIMATED_BASELINE1_EFFORT,:n      pa.ESTIMATED_BASELINE3_START, pa.E+
1STIMATED_BASELINE3_FINISH, pa.ESTIMATED_BASELINE3_EFFORT, '' AS EXTERNAL_ID:n+
1      FROM RESOURCE_ASSIGNMENTS a JOIN PROFILES p ON a.RESOURCE_ID=p.PROFILE_+
1ID:n      JOIN TASK_ASSIGNMENTS t ON t.RES_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID+
1:n      JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID = h_id AND pa.RESOURCE_I+
1D = a.RESOURCE_ID:n      WHERE a.ELEMENT_ID=h_id AND a.RESOURCE_TYPE='1':n   +
1   ORDER BY TYPE_ID DESC, ELEMENT_NAME:
1940:
1                EXIT:: SP_S_PROFILE(941) :: cplan.sql(14276) :: :
18:
1DELETE FROM PMO_TMP_PRJ_INFO:
1PMO_TMP_PRJ_INFO:
1PRJ_PLANNED_START:
1PRJ_PLANNED_FINISH:
1PRJ_SCHED_START:
1PRJ_SCHED_FINISH:
1SCHED_REMAINING:
1INSERT INTO PMO_TMP_PRJ_INFO:n         (RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n         PLANNED+
1_REMAINING,:n         PLANNED_EFFORT,:n         PRJ_SCHED_START ,:n         P+
1RJ_SCHED_FINISH,:n         SCHED_REMAINING,:n         WORK,:n         TYPE_ID+
1:n         ):n         SELECT:n         RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         MIN(PLANNED_START)  AS PRJ_PLANNED_START,:n         MAX(PLANNED_FI+
1NISH) AS PRJ_PLANNED_FINISH,:n         SUM(PLANNED_WORK)   AS PLANNED_REMAINI+
1NG,:n         SUM(CASE WHEN BIT_FLAG='0' THEN BEST ELSE 0 END) AS PLANNED_EFF+
1ORT,:n         MIN(SCHED_START)    AS PRJ_SCHED_START,:n         MAX(SCHED_FI+
1NISH)   AS PRJ_SCHED_FINISH,:n         SUM(SCHED_WORK)     AS SCHED_REMAINING+
1,:n         SUM(CASE WHEN BIT_FLAG='2' THEN BEST ELSE 0 END) AS WORK, 13:n   +
1      FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID=h_id AND TASK_ID=h_id+
1:n         GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1988:
1           EXCEPTION:: SP_S_PROFILE(989) :: cplan.sql(14324) :: :
1DELETE FROM PMO_TMP_RES_INFO:
1PMO_TMP_RES_INFO:
1INSERT INTO PMO_TMP_RES_INFO:n         (:n         RESOURCE_ID,:n         RES+
1OURCE_TYPE,:n         PLANNED_START,:n         PLANNED_FINISH,:n         PLAN+
1NED_EFFORT,:n         START_DATE,:n         FINISH_DATE,:n         WORK,:n   +
1      REMAINING,:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n+
1         PLANNED_REMAINING,:n         PRJ_SCHED_START,:n         PRJ_SCHED_FI+
1NISH,:n         SCHED_REMAINING,:n         LEVEL_PLANNED_START,:n         LEV+
1EL_PLANNED_FINISH,:n         LEVEL_SCHED_START,:n         LEVEL_SCHED_FINISH,+
1:n         ESTIMATED_BASELINE1_START,:n         ESTIMATED_BASELINE1_FINISH,:n+
1         ESTIMATED_BASELINE1_EFFORT,:n         ESTIMATED_BASELINE3_START,:n  +
1       ESTIMATED_BASELINE3_FINISH,:n         ESTIMATED_BASELINE3_EFFORT,:n   +
1      REGULAR_COST,:n         REGULAR_RATE,:n         SPECIAL_COST,:n        +
1 SPECIAL_RATE,:n         TYPE_ID,:n         DESCRIPTION:n         ):n        +
1 SELECT:n         a.RESOURCE_ID,      a.RESOURCE_TYPE,        a.PLANNED_START+
1,        a.PLANNED_FINISH,:n         a.PLANNED_WORK,     a.SCHED_START,      +
1    a.SCHED_FINISH,         a.SCHED_WORK,:n         a.ETC,              b.PRJ+
1_PLANNED_START,    b.PRJ_PLANNED_FINISH,   b.PLANNED_REMAINING,:n         b.P+
1RJ_SCHED_START,  b.PRJ_SCHED_FINISH,     b.SCHED_REMAINING,:n         a.LEVEL+
1_PLANNED_START, a.LEVEL_PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FI+
1NISH,:n         a.ESTIMATED_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.+
1ESTIMATED_BASELINE1_EFFORT,:n         a.ESTIMATED_BASELINE3_START, a.ESTIMATE+
1D_BASELINE3_FINISH, a.ESTIMATED_BASELINE3_EFFORT,:n         a.REGULAR_COST,  +
1   a.REGULAR_RATE,         a.SPECIAL_COST,         a.SPECIAL_RATE,:n         +
1COALESCE(b.TYPE_ID,CASE WHEN (a.PLANNED_WORK+a.SCHED_WORK) = 0 THEN 185 ELSE +
113 END), a.DESCRIPTION:n         FROM PROJECT_ASSIGNMENTS a LEFT OUTER JOIN P+
1MO_TMP_PRJ_INFO b ON a.RESOURCE_ID = b.RESOURCE_ID:n         WHERE a.PROJECT_+
1ID=h_id:
11057:
1           EXCEPTION:: SP_S_PROFILE(1058) :: cplan.sql(14393) :: :
1RI:
1UPDATE PMO_TMP_RES_INFO RI SET TYPE_ID = 13 WHERE TYPE_ID = 185 AND EXISTS(:n+
1         SELECT TASK_ID FROM TASK_ASSIGNMENTS T WHERE T.PROJECT_ID=h_id AND T+
1.RESOURCE_ID = RI.RESOURCE_ID AND T.RESOURCE_TYPE = '0'):
11078:
1           EXCEPTION:: SP_S_PROFILE(1079) :: cplan.sql(14414) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME, a.TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_FIN+
1ISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 AS T+
1_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BEST_FINISH,+
1 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STR+
1ING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a.PRJ_PLAN+
1NED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOURCE_ID ELS+
1E '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNED_FINISH,+
1 a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED_REMAININ+
1G,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_PLANNED_F+
1INISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED_BASELINE+
11_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,:n      a+
1.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATED_BASELIN+
1E3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.SPECIAL_R+
1ATE, a.DESCRIPTION, p.EXTERNAL_ID:n      FROM PMO_TMP_RES_INFO a JOIN RESOURC+
1ES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      UNION AL+
1L:n      SELECT  r.PROFILE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, r.PROFIL+
1E_NAME AS ELEMENT_NAME,41 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      a.PLANNED_S+
1TART, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK,+
1 a.REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START+
1,''  AS BEST_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILIT+
1Y, '' AS ASSIGN_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n   +
1   CASE WHEN a.PRJ_PLANNED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL+
1 THEN a.RESOURCE_ID ELSE '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START+
1, a.PRJ_PLANNED_FINISH, a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_F+
1INISH, a.SCHED_REMAINING,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_S+
1TART, a.LEVEL_PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n   +
1   a.ESTIMATED_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BAS+
1ELINE1_EFFORT,:n      a.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINI+
1SH, a.ESTIMATED_BASELINE3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SP+
1ECIAL_COST, a.SPECIAL_RATE, a.DESCRIPTION, '' AS EXTERNAL_ID:n      FROM PMO_+
1TMP_RES_INFO a JOIN PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESO+
1URCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n      JOIN +
1TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
11107:
1                EXIT:: SP_S_PROFILE(1108) :: cplan.sql(14443) :: :
1SELECT PROFILE_NAME INTO h_in FROM PROFILES WHERE PROFILE_ID = h_id:
11121:
1           EXCEPTION:: SP_S_PROFILE(1122) :: cplan.sql(14457) :: :
1SC_SQL_SUCCESS:
1ROLE_TYPE:
1ORG_ID:
1ORG:
1ORG_NAME:
1GEO_ID:
1GEO:
1GEO_NAME:
1POOL_ID:
1POOL:
1POOL_NAME:
1TMT_GEOGRAPHIES:
1DS:
1CS:
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,30 AS ROLE_TYPE+
1, p.ROLE_ID, h_in AS ROLE_NAME,:n         ORG_ID, org.ELEMENT_NAME AS ORG_NAM+
1E, GEO_ID, geo.ELEMENT_NAME AS GEO_NAME, POOL_ID, pool.ELEMENT_NAME AS POOL_N+
1AME:n         FROM PROFILES p:n         LEFT JOIN TMT_ORGANIZATIONS org ON or+
1g.ELEMENT_ID  = ORG_ID:n         LEFT JOIN TMT_GEOGRAPHIES geo   ON geo.ELEME+
1NT_ID  = GEO_ID:n         LEFT JOIN TMT_POOLS pool        ON pool.ELEMENT_ID +
1= POOL_ID:n         WHERE p.PROFILE_ID = h_id:n         UNION ALL:n         S+
1ELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,ds.TYPE_ID AS RO+
1LE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, PMO_ORASTD.StringConcat(PMO_ORAS+
1TD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', '), RTRIM(cs.ELEMENT_NAME)) AS ROL+
1E_NAME,:n         '' ORG_ID, '' AS ORG_NAME, '' GEO_ID, '' AS GEO_NAME, '' PO+
1OL_ID, '' AS POOL_NAME:n         FROM RESOURCE_ASSIGN_ROLES r LEFT OUTER JOIN+
1 TMT_COMPETENCIES cs ON r.ROLE_ID=cs.ELEMENT_ID:n         LEFT OUTER JOIN TMT+
1_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT_ID WHERE r.RES_ASSIGNMENT_ID=h_id+
1:n         UNION ALL:n         SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAM+
1E,41 AS TYPE_ID,ds.TYPE_ID AS ROLE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, +
1PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', ')+
1, RTRIM(cs.ELEMENT_NAME)) AS ROLE_NAME,:n         '' ORG_ID, '' AS ORG_NAME, +
1'' GEO_ID, '' AS GEO_NAME, '' POOL_ID, '' AS POOL_NAME:n         FROM RESOURC+
1E_ASSIGN_SKILLS s LEFT OUTER JOIN TMT_COMPETENCIES cs ON s.SKILL_ID=cs.ELEMEN+
1T_ID:n         LEFT OUTER JOIN TMT_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT+
1_ID WHERE s.RES_ASSIGNMENT_ID=h_id:n         ORDER BY ELEMENT_ID,TYPE_ID:
11148:
1                EXIT:: SP_S_PROFILE(1149) :: cplan.sql(14484) :: :
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.RE+
1SOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURCE_+
1ID = p.PROFILE_ID):n      ELSE (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.R+
1ESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n      CASE WHEN t.TSK_ASSIG+
1NMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' THEN 41 ELSE 13 END AS TYP+
1E_ID,:n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT, COALESCE(PLANNED+
1_FINISH,SCHED_FINISH) AS FINISH_DT,:n      t.SD, t.FD, COALESCE(PLANNED_START+
1,SCHED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SCHED_FINISH) AS PLAN+
1NED_FINISH,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK ELSE PLANNED_WORK+
1 END AS PLANNED_WORK,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK - WORK_+
1TODATE ELSE PLANNED_WORK END AS REMAINING,:n      CASE WHEN t.ASSIGN_UNITS > +
1t.UNITS_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS_PERCENT,:n     +
1 0 AS MILESTONE_PERCENT,:n      CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc+
1((TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(PLANNED_WORK+SCHED_WORK))*10000) END AS +
1WORK_PERCENT,:n      t.BAK_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n      t.FORE+
1CAST_START,t.FORECAST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n      t.+
1WORK_TODATE AS ACTUAL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n      +
1h_per_day AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME A+
1S SECURITY_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECU+
1RITY_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,+
1t.SPECIAL_COST,t.SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (SEL+
1ECT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n  +
1    ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_STA+
1RT,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n      t.PROJECT_ASSIGNMENT_ID,t.TIME+
1CODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, +
1t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n+
1      t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLA+
1G = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COU+
1NT, :n      CASE WHEN BIT_FLAG = '2' THEN SCHED_DURATION ELSE PLANNED_DURATIO+
1N END AS DURATION,:n      CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_S+
1TART,t.UNRESOLVED_START) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LE+
1VEL_START,:n      CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_FINISH,t.+
1UNRESOLVED_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FI+
1NISH,:n      CASE WHEN h_level_state = 1 THEN CASE WHEN t.LEVEL_EFFORT = 0 TH+
1EN t.ETC ELSE t.LEVEL_EFFORT END ELSE 0 END AS LEVEL_EFFORT, t.MILESTONE_PERC+
1ENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n      CASE WHEN t.TSK_ASSIGNMENT_ID IS+
1 NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMENT_ID AND (t.LEVEL_STAR+
1T <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLVED_FINISH) THEN '1' EL+
1SE '0' END AS LEVEL_AFFECTED_FLAG,:n      T.LABOR_COST_CC_ID,:n      EC.ELEME+
1NT_NAME AS LABOR_COST_CC_NAME,:n      T.LABOR_REVENUE_CC_ID,:n      CC.ELEMEN+
1T_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n      T.CONTRACT_ID, +
1CTR.ELEMENT_NAME AS CONTRACT_NAME:n      FROM RESOURCE_ASSIGNMENTS a JOIN TAS+
1K_ASSIGNMENTS t ON t.TSK_ASSIGNMENT_ID = h_id AND a.RES_ASSIGNMENT_ID = t.RES+
1_ASSIGNMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=+
1g.ELEMENT_ID:n      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_+
1SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES+
1 TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n      LEFT OUTER JOIN TMT_CHARGECODES E+
1C ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n      LEFT OUTER JOIN TMT_CHARGECODE+
1S CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n      LEFT OUTER JOIN TMT_CONT+
1RACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n      ORDER BY TYPE_ID DESC, ELE+
1MENT_NAME:
11192:
1                EXIT:: SP_S_PROFILE(1193) :: cplan.sql(14528) :: :
1ACCEPTED_DATE:
1DELAY:
1SELECT a.RES_ASSIGNMENT_ID AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.R+
1ESOURCE_TYPE='0' THEN (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_I+
1D = r.RESOURCE_ID):n      WHEN a.RESOURCE_TYPE='2' THEN (SELECT p.ELEMENT_NAM+
1E FROM TMT_POOLS p WHERE a.RESOURCE_ID = p.ELEMENT_ID):n      ELSE (SELECT p.+
1ELEMENT_NAME FROM TMT_ORGANIZATIONS p WHERE a.RESOURCE_ID = p.ELEMENT_ID) END+
1 AS ELEMENT_NAME,:n      CASE WHEN a.RESOURCE_TYPE='2' THEN pmo_cnst.SC_POOLS+
1:n      WHEN a.RESOURCE_TYPE='3' THEN pmo_cnst.SC_ORGANIZATION :n      ELSE 1+
185 END AS TYPE_ID,  :n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, TO_TIMESTAMP(+
1'1899-12-31 00::00::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::0+
10') AS PLANNED_FINISH,:n      0 AS PLANNED_WORK,TO_TIMESTAMP('1899-12-31 00::+
100::00') AS START_DT,TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DT,:n   +
1   TO_TIMESTAMP('1899-12-31 00::00::00') AS SCHED_START,TO_TIMESTAMP('1899-12+
1-31 00::00::00') AS SCHED_FINISH, 0 AS SCHED_WORK,:n      TO_TIMESTAMP('1899-+
112-31 00::00::00') AS BAK_START_DT,TO_TIMESTAMP('1899-12-31 00::00::00') AS B+
1AK_FINISH_DT, 0 AS BAK_WORK,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1FORECAST_START,TO_TIMESTAMP('1899-12-31 00::00::00') AS FORECAST_FINISH,0 AS +
1ETC,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS ACTUAL_START,TO_TIMESTAM+
1P('1899-12-31 00::00::00') AS ACTUAL_FINISH,:n      0 AS ACTUAL,h_per_day AS +
1MINUTE_PER_DAY, a.WORK_LOCATION, TO_TIMESTAMP('1899-12-31 00::00::00') AS ACC+
1EPTED_DATE,:n      a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME, COALESCE(a+
1.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.ELEMENT_NAME AS CRI_SE+
1CURITY_NAME,:n      0 AS REGULAR_COST,0 AS REGULAR_RATE,0 AS SPECIAL_COST, 0 +
1AS SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_LABOR+
1_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n      ELSE '' EN+
1D AS FS_LABOR_CODE,:n      a.REC_STATUS,'' AS ASSIGN_STRING,:n      TO_TIMEST+
1AMP('1899-12-31 00::00::00') AS BASELINE1_START,TO_TIMESTAMP('1899-12-31 00::+
100::00') AS BASELINE1_FINISH,0 AS BASELINE1_WORK,:n      '' AS PROJECT_ASSIGN+
1MENT_ID, '' AS TIMECODE2_ID, '' AS TIMECODE2_NAME, 0 AS T_UNIT,:n      0 AS C+
1_EFFORT, 0 AS C_UNIT, 0 AS C_CONTOUR, 0 AS CONTOUR_TYPE, 0 AS C_OCCURRENCE, 0+
1 AS BILLABLE,:n      0 AS DELAY:n      FROM RESOURCE_ASSIGNMENTS a:n      LEF+
1T OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LEFT +
1OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID+
1)=g2.ELEMENT_ID:n      WHERE a.REC_STATUS NOT IN ('L','D') AND a.ELEMENT_ID =+
1 h_id:n      ORDER BY TYPE_ID DESC, ELEMENT_NAME:
11225:
1                EXIT:: SP_S_PROFILE(1226) :: cplan.sql(14561) :: :
112:
1DELETE FROM PMO_TMP_RTA:
1PMO_TMP_RTA:
1PA_FLAG:
1TABLE_TYPE:
1SC_TABLE_WBS:
1INSERT INTO PMO_TMP_RTA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SELEC+
1T RESOURCE_ID, RESOURCE_TYPE, 'N' AS PA_FLAG:n         FROM TASK_ASSIGNMENTS+
1:n         WHERE PROJECT_ID = h_id AND:n         PROJECT_ASSIGNMENT_ID IS NuL+
1L AND:n         TABLE_TYPE = pmo_cnst.SC_TABLE_WBS:n         GROUP BY RESOURC+
1E_ID, RESOURCE_TYPE:
11255:
1           EXCEPTION:: SP_S_PROFILE(1256) :: cplan.sql(14591) :: :
1DELETE FROM PMO_TMP_CP_PRJ:
1PMO_TMP_CP_PRJ:
1INSERT INTO PMO_TMP_CP_PRJ (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SE+
1LECT  RESOURCE_ID, RESOURCE_TYPE, 'Y' AS PA_FLAG:n         FROM TASK_ASSIGNME+
1NTS:n         WHERE PROJECT_ID = h_id AND:n         TASK_ID = h_id:n         +
1GROUP BY RESOURCE_ID, RESOURCE_TYPE:
11283:
1           EXCEPTION:: SP_S_PROFILE(1284) :: cplan.sql(14619) :: :
1DELETE FROM PMO_TMP_RESOURCE_DATA:
1PMO_TMP_RESOURCE_DATA:
1INSERT INTO PMO_TMP_RESOURCE_DATA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n    +
1     SELECT a.RESOURCE_ID, a.RESOURCE_TYPE, a.PA_FLAG:n         FROM PMO_TMP_+
1RTA a LEFT OUTER JOIN PMO_TMP_CP_PRJ b ON a.RESOURCE_ID=b.RESOURCE_ID:n      +
1   UNION:n         SELECT b.RESOURCE_ID, b.RESOURCE_TYPE, b.PA_FLAG:n        +
1 FROM PMO_TMP_CP_PRJ b LEFT OUTER JOIN PMO_TMP_RTA a ON a.RESOURCE_ID=b.RESOU+
1RCE_ID:
11311:
1           EXCEPTION:: SP_S_PROFILE(1312) :: cplan.sql(14647) :: :
1NICK_NAME:
1PRJ:
1RD:
1SELECT a.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID+
1, p.NICK_NAME, a.PA_FLAG:n      FROM PMO_TMP_RESOURCE_DATA a JOIN RESOURCES p+
1 ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      LEFT OUTER J+
1OIN PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION +
1ALL:n      :n      SELECT DISTINCT r.PROFILE_ID AS ELEMENT_ID, r.PROFILE_NAME+
1 AS ELEMENT_NAME,41 AS TYPE_ID, ' ' AS NICK_NAME, a.PA_FLAG:n      FROM PMO_T+
1MP_RESOURCE_DATA a JOIN PROFILES r ON a.RESOURCE_TYPE = '1' AND r.PROFILE_ID +
1= a.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n   +
1   JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:n      LEFT OUTER JOIN+
1 PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n      UNION ALL+
1:n      :n      SELECT DISTINCT ra.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS +
1ELEMENT_NAME, 185 AS TYPE_ID, p.NICK_NAME, 'N' AS PA_FLAG:n      FROM RESOURC+
1E_ASSIGNMENTS ra, RESOURCES p:n      WHERE ra.PROJECT_ID=h_id AND:n      ra.R+
1ESOURCE_ID = p.RESOURCE_ID AND:n      NOT EXISTS(SELECT rd.RESOURCE_ID FROM P+
1MO_TMP_RESOURCE_DATA rd WHERE ra.RESOURCE_ID = rd.RESOURCE_ID):n      ORDER B+
1Y TYPE_ID DESC, ELEMENT_NAME:
11337:
1                EXIT:: SP_S_PROFILE(1338) :: cplan.sql(14673) :: :
1%%:
1SELECT t.ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID, p.NICK_NAME, +
1'N' AS PA_FLAG:n      FROM TMT_POOLS t JOIN RESOURCES p:n      ON t.ELEMENT_I+
1D = p.RESOURCE_ID:n      WHERE t.TYPE_ID = 13:n      AND t.RANK LIKE h_rank:n+
1      ORDER BY ELEMENT_NAME:
11352:
1                EXIT:: SP_S_PROFILE(1353) :: cplan.sql(14688) :: :
1SELECT R.RESOURCE_ID AS ELEMENT_ID, R.FULL_NAME AS ELEMENT_NAME,pmo_cnst.SC_R+
1ESOURCE AS TYPE_ID, R.NICK_NAME, 'N' AS PA_FLAG:n      FROM PROJECT_ASSIGNMEN+
1TS RA, RESOURCES R:n      WHERE RA.PROJECT_ID = h_id:n      AND RA.RESOURCE_I+
1D = R.RESOURCE_ID:n      ORDER BY ELEMENT_NAME:
11366:
1                EXIT:: SP_S_PROFILE(1367) :: cplan.sql(14702) :: :
11371:
1       RETURN_STATUS:: SP_S_PROFILE(1372) :: cplan.sql(14707) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11380:
1           EXCEPTION:: SP_S_PROFILE(1381) :: cplan.sql(14716) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11392:
1           EXCEPTION:: SP_S_PROFILE(1393) :: cplan.sql(14728) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2082
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :18 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :15 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :4 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 19 3c b7 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 51 d a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
a 10 :2 a0 51 a5 b a0 7e
a0 6b b4 2e 5a a 10 :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6e 11e 11d :2 a0 6b 51 d :22 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6e 11e 11d :2 a0 6b 51 d :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :12d a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 :2 a0 6e
11e 11d :2 a0 6b 51 d :26 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 b4 2e d :2e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :49 a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
:8d a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
a5 b 7e 51 b4 2e a0 51
d :7 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e a0 6e d b7 a0
51 d :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :1c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e a0 6e
d b7 a0 6e d b7 :2 19 3c
b7 a0 6e d b7 :2 19 3c b7
:2 19 3c :212 a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 b7 :14e a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 :2 19 3c
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :27 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 b4 2e
d :35 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :4c a0 12a e9 dd :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 65 a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6e 11e
11d :2 a0 6b 51 d :27 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d :62 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :6a a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :e7 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :2f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :71 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :d8 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :9a a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 19 3c
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :143 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :a2 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :e a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :26 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :6c a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
7e 6e b4 2e :2 51 a5 b d
:1a a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 a0 b7 19 :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a 52 10 :1a a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
2082
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 101 12e 121 14f 13e
142 11e 14a 13d 16b 15a 15e 13a
166 159 187 176 17a 156 182 175
1a3 192 196 172 19e 191 1bf 1ae
1b2 18e 1ba 1ad 1df 1ca 1ce 1aa
1d2 1da 1c9 1ff 1ea 1ee 1c6 1f2
1fa 1e9 21f 20a 20e 1e6 212 21a
209 23f 22a 22e 206 232 23a 229
25f 24a 24e 226 252 25a 249 27f
26a 26e 246 272 27a 269 29f 28a
28e 266 292 29a 289 2bf 2aa 2ae
286 2b2 2ba 2a9 2df 2ca 2ce 2a6
2d2 2da 2c9 2ff 2ea 2ee 2c6 2f2
2fa 2e9 31f 30a 30e 2e6 312 31a
309 33f 32a 32e 306 332 33a 329
35f 34a 34e 326 352 35a 349 37f
36a 36e 346 372 37a 369 39f 38a
38e 366 392 39a 389 3bf 3aa 3ae
386 3b2 3ba 3a9 3c6 3ca 3a6 3ce
3d2 3d6 3d9 3de 3df 1 3e1 3e6
3ea 3ee 3f1 3f6 3fa 3fe 401 406
407 409 40e 411 415 416 41b 420
423 428 429 42e 431 435 436 43b
43e 443 444 449 44c 451 452 457
45a 45e 462 466 467 469 46e 46f
471 472 477 47a 47f 480 485 488
48d 48e 493 496 49a 49b 4a0 4a3
4a8 4a9 4ae 4b1 4b6 4b7 4bc 4bd
4c2 4c4 4c8 4cb 4cf 4d3 4d6 4da
4de 4e1 4e4 4e9 4ec 4ef 4f2 4f3
4f8 4f9 1 4fb 500 504 508 50b
510 515 518 51c 51d 522 523 528
52a 52e 531 535 538 539 53e 541
545 549 54c 550 554 557 55a 55f
562 565 568 569 56e 56f 1 571
576 57a 57e 581 586 58b 58e 592
593 598 59b 5a0 5a1 5a6 5a9 5ae
5af 5b4 5b7 5bb 5bf 5c3 5c7 5ca
5cb 5cd 5d2 5d3 5d5 5d6 5db 5de
5e3 5e4 5e9 5ec 5f1 5f2 5f7 5fa
5fe 5ff 604 607 60c 60d 612 613
618 61a 61e 621 625 629 62c 630
634 637 63a 63f 642 645 648 649
64e 64f 1 651 656 65a 65e 661
666 66b 66e 672 673 678 679 67e
680 684 687 68b 68f 692 696 69a
69d 6a1 6a5 6a6 6ab 6ad 6b1 6b4
6b8 6bc 6c0 6c4 6c8 6cc 6d0 6d4
6d8 6dc 6e0 6e3 6e4 6e6 6e9 6ec
6ed 6f2 6f5 6f9 6fd 700 701 703
706 709 70a 70f 1 712 717 71b
71f 723 727 72b 72f 733 737 73b
73f 743 747 74b 74f 753 757 75b
75f 763 767 76b 76f 773 777 783
787 78b 78e 792 796 798 79c 7a0
7a4 7a7 7ab 7af 7b1 7b2 7b7 1
7bb 7bf 7c3 7c6 7ca 7ce 7d2 7d6
7d9 7dd 7e1 7e4 7e7 7ec 7ef 7f2
7f5 7f6 7fb 7fc 1 7fe 803 807
80b 80e 813 818 81b 81f 820 825
828 82d 82e 833 836 83b 83c 841
844 848 849 84e 851 856 857 85c
85f 863 867 86a 86d 86e 870 871
876 877 87c 87e 882 885 887 88b
88d 899 89b 89d 89e 8a3 8a7 8a9
8b5 8b7 8bb 8bf 8c2 8c6 8c9 8cd
8d0 8d1 8d6 8d9 8dd 8e1 8e5 8e9
8ed 8f1 8f5 8f9 8fd 901 905 909
90d 911 915 919 91d 921 925 929
92d 939 93d 941 944 948 94c 94e
952 956 95a 95d 961 965 967 968
96d 1 971 975 979 97c 980 984
988 98c 98f 993 997 99a 99d 9a2
9a5 9a8 9ab 9ac 9b1 9b2 1 9b4
9b9 9bd 9c1 9c4 9c9 9ce 9d1 9d5
9d6 9db 9de 9e3 9e4 9e9 9ec 9f1
9f2 9f7 9fa 9fe 9ff a04 a07 a0c
a0d a12 a15 a19 a1d a20 a23 a24
a26 a27 a2c a2d a32 a34 a38 a3b
a3d a41 a43 a4f a51 a53 a54 a59
a5d a5f a6b a6d a71 a75 a78 a7c
a7f a83 a86 a87 a8c a8f a93 a97
a9b a9f aab aaf ab3 ab6 aba abe
ac0 ac4 ac8 acc acf ad3 ad7 ad9
ada adf 1 ae3 ae7 aeb aee af2
af6 afa afe b01 b05 b09 b0c b0f
b14 b17 b1a b1d b1e b23 b24 1
b26 b2b b2f b33 b36 b3b b40 b43
b47 b48 b4d b50 b55 b56 b5b b5e
b63 b64 b69 b6c b70 b71 b76 b79
b7e b7f b84 b87 b8b b8f b92 b95
b96 b98 b99 b9e b9f ba4 ba6 baa
bad baf bb3 bb5 bc1 bc3 bc5 bc6
bcb bcf bd1 bdd bdf be3 be7 bea
bee bf1 bf5 bf8 bf9 bfe c01 c05
c09 c0c c10 c14 c17 c1a c1f c22
c25 c28 c29 c2e c2f 1 c31 c36
c3a c3e c41 c46 c4b c4e c52 c53
c58 c5b c60 c61 c66 c69 c6e c6f
c74 c77 c7b c7f c83 c87 c8a c8b
c8d c92 c93 c95 c96 c9b c9e ca3
ca4 ca9 cac cb1 cb2 cb7 cba cbe
cbf cc4 cc7 ccc ccd cd2 cd3 cd8
cda cde ce1 ce5 ce9 cec cf0 cf4
cf7 cfa cff d02 d05 d08 d09 d0e
d0f 1 d11 d16 d1a d1e d21 d26
d2b d2e d32 d33 d38 d39 d3e d40
d44 d47 d4b d4f d52 d56 d5a d5d
d61 d65 d66 d6b d6d d71 d74 d76
d7a d7d d7f d83 d86 d8a d8c d90
d94 d97 d98 d9a d9d da0 da1 da6
daa dae db2 db6 dba dc6 dca dce
dd1 dd5 dd9 ddb ddf de3 de7 dea
dee df2 df4 df5 dfa 1 dfe e02
e06 e09 e0d e11 e15 e19 e1c e20
e24 e27 e2a e2f e32 e35 e38 e39
e3e e3f 1 e41 e46 e4a e4e e51
e56 e5b e5e e62 e63 e68 e6b e70
e71 e76 e79 e7e e7f e84 e87 e8b
e8c e91 e94 e99 e9a e9f ea2 ea6
eaa ead eb0 eb1 eb3 eb4 eb9 eba
ebf ec1 ec5 ec8 eca ece ed0 edc
ede ee0 ee1 ee6 eea eec ef8 efa
efe f02 f05 f09 f0c f10 f13 f14
f19 f1c f20 f24 f27 f2b f2f f32
f35 f3a f3d f40 f43 f44 f49 f4a
1 f4c f51 f55 f59 f5c f61 f66
f69 f6d f6e f73 f76 f7b f7c f81
f84 f89 f8a f8f f92 f96 f9a f9e
fa2 fa5 fa6 fa8 fad fae fb0 fb1
fb6 fb9 fbe fbf fc4 fc7 fcc fcd
fd2 fd5 fd9 fda fdf fe2 fe7 fe8
fed fee ff3 ff5 ff9 ffc 1000 1004
1007 100b 100f 1012 1015 101a 101d 1020
1023 1024 1029 102a 1 102c 1031 1035
1039 103c 1041 1046 1049 104d 104e 1053
1054 1059 105b 105f 1062 1066 106a 106d
1071 1075 1078 107c 1080 1081 1086 1088
108c 108f 1093 1097 109b 109f 10a3 10a7
10ab 10af 10bb 10bf 10c3 10c6 10ca 10ce
10d0 10d4 10d8 10dc 10df 10e3 10e7 10e9
10ea 10ef 1 10f3 10f7 10fb 10fe 1102
1106 110a 110e 1111 1115 1119 111c 111f
1124 1127 112a 112d 112e 1133 1134 1
1136 113b 113f 1143 1146 114b 1150 1153
1157 1158 115d 1160 1165 1166 116b 116e
1173 1174 1179 117c 1180 1181 1186 1189
118e 118f 1194 1197 119b 119f 11a2 11a5
11a6 11a8 11a9 11ae 11af 11b4 11b6 11ba
11bd 11bf 11c3 11c5 11d1 11d3 11d5 11d6
11db 11df 11e1 11ed 11ef 11f3 11f5 11f9
11fd 1201 1204 1205 1207 120a 120d 120e
1213 1217 121b 121f 1223 1227 1233 1237
123b 123e 1242 1246 1248 124c 1250 1254
1257 125b 125f 1261 1262 1267 1 126b
126f 1273 1276 127a 127e 1282 1286 1289
128d 1291 1294 1297 129c 129f 12a2 12a5
12a6 12ab 12ac 1 12ae 12b3 12b7 12bb
12be 12c3 12c8 12cb 12cf 12d0 12d5 12d8
12dd 12de 12e3 12e6 12eb 12ec 12f1 12f4
12f8 12f9 12fe 1301 1306 1307 130c 130f
1313 1317 131a 131d 131e 1320 1321 1326
1327 132c 132e 1332 1335 1337 133b 133d
1349 134b 134d 134e 1353 1357 1359 1365
1367 136b 136f 1372 1376 1379 137d 1380
1381 1386 1389 138d 1391 1394 1398 139c
139f 13a2 13a7 13aa 13ad 13b0 13b1 13b6
13b7 1 13b9 13be 13c2 13c6 13c9 13ce
13d3 13d6 13da 13db 13e0 13e3 13e8 13e9
13ee 13f1 13f6 13f7 13fc 13ff 1403 1407
140b 140f 1412 1413 1415 141a 141b 141d
141e 1423 1426 142b 142c 1431 1434 1439
143a 143f 1442 1446 1447 144c 144f 1454
1455 145a 145b 1460 1462 1466 1469 146d
1471 1474 1478 147c 147f 1482 1487 148a
148d 1490 1491 1496 1497 1 1499 149e
14a2 14a6 14a9 14ae 14b3 14b6 14ba 14bb
14c0 14c1 14c6 14c8 14cc 14cf 14d3 14d7
14da 14de 14e2 14e5 14e9 14ed 14ee 14f3
14f5 14f9 14fc 1500 1503 1507 150b 150d
1511 1515 1519 151c 151d 151f 1523 1526
152a 152d 152e 1533 1536 153a 153e 1541
1542 1544 1547 154a 154b 1550 1 1553
1558 155c 1560 1563 1564 1566 156a 156d
1571 1574 1575 157a 1 157d 1582 1586
158a 158d 158e 1590 1594 1597 159b 159e
159f 15a4 1 15a7 15ac 15b0 15b4 15b8
15bc 15c0 15c4 15c8 15cc 15d8 15dc 15e0
15e3 15e7 15eb 15ed 15f1 15f5 15f9 15fc
1600 1604 1606 1607 160c 1 1610 1614
1618 161b 161f 1623 1627 162b 162e 1632
1636 1639 163c 1641 1644 1647 164a 164b
1650 1651 1 1653 1658 165c 1660 1663
1668 166d 1670 1674 1675 167a 167d 1682
1683 1688 168b 1690 1691 1696 1699 169d
169e 16a3 16a6 16ab 16ac 16b1 16b4 16b8
16bc 16bf 16c2 16c3 16c5 16c6 16cb 16cc
16d1 16d3 16d7 16da 16dc 16e0 16e2 16ee
16f0 16f2 16f3 16f8 16fc 16fe 170a 170c
1710 1714 1717 171b 171e 1722 1725 1726
172b 172e 1732 1736 1739 173d 1741 1744
1747 174c 174f 1752 1755 1756 175b 175c
1 175e 1763 1767 176b 176e 1773 1778
177b 177f 1780 1785 1788 178d 178e 1793
1796 179b 179c 17a1 17a4 17a8 17ac 17b0
17b4 17b7 17b8 17ba 17bf 17c0 17c2 17c3
17c8 17cb 17d0 17d1 17d6 17d9 17de 17df
17e4 17e7 17eb 17ec 17f1 17f4 17f9 17fa
17ff 1800 1805 1807 180b 180e 1812 1816
1819 181d 1821 1824 1827 182c 182f 1832
1835 1836 183b 183c 1 183e 1843 1847
184b 184e 1853 1858 185b 185f 1860 1865
1866 186b 186d 1871 1874 1878 187c 187f
1883 1887 188a 188e 1892 1893 1898 189a
189e 18a1 18a3 18a7 18ab 18ae 18b2 18b6
18b9 18ba 18bc 18bf 18c2 18c3 18c8 18cc
18d0 18d5 18da 18de 18e2 18e6 18e9 18ec
18f0 18f4 18f8 18fc 1900 1904 1908 190c
1910 1914 1918 191c 1920 1924 1928 192c
1930 1934 1938 193c 1940 1944 1948 194c
1950 1954 1958 195c 1960 1964 1968 196c
1970 1974 1978 1984 1988 198d 1991 1994
1995 199a 199e 19a2 19a5 19a8 19ac 19ae
19b2 19b6 19b9 19bc 19c0 19c2 19c6 19ca
19cd 19cf 19d3 19d7 19db 19de 19e2 19e6
19e8 19e9 19ee 1 19f2 19f6 19fa 19fd
1a01 1a05 1a09 1a0d 1a10 1a14 1a18 1a1b
1a1e 1a23 1a26 1a29 1a2c 1a2d 1a32 1a33
1 1a35 1a3a 1a3e 1a42 1a45 1a4a 1a4f
1a52 1a56 1a57 1a5c 1a5f 1a64 1a65 1a6a
1a6d 1a72 1a73 1a78 1a7b 1a7f 1a80 1a85
1a88 1a8d 1a8e 1a93 1a96 1a9a 1a9e 1aa1
1aa4 1aa5 1aa7 1aa8 1aad 1aae 1ab3 1ab5
1ab9 1abc 1abe 1ac2 1ac4 1ad0 1ad2 1ad4
1ad5 1ada 1ade 1ae0 1aec 1aee 1af2 1af6
1afb 1b00 1b04 1b08 1b0c 1b0f 1b12 1b16
1b1a 1b1e 1b22 1b26 1b2a 1b2e 1b32 1b3e
1b42 1b47 1b4b 1b4e 1b4f 1b54 1b58 1b5c
1b5f 1b62 1b66 1b68 1b6c 1b70 1b73 1b76
1b7a 1b7c 1b80 1b84 1b87 1b89 1b8d 1b91
1b95 1b98 1b9c 1ba0 1ba2 1ba3 1ba8 1
1bac 1bb0 1bb4 1bb7 1bbb 1bbf 1bc3 1bc7
1bca 1bce 1bd2 1bd5 1bd8 1bdd 1be0 1be3
1be6 1be7 1bec 1bed 1 1bef 1bf4 1bf8
1bfc 1bff 1c04 1c09 1c0c 1c10 1c11 1c16
1c19 1c1e 1c1f 1c24 1c27 1c2c 1c2d 1c32
1c35 1c39 1c3a 1c3f 1c42 1c47 1c48 1c4d
1c50 1c54 1c58 1c5b 1c5e 1c5f 1c61 1c62
1c67 1c68 1c6d 1c6f 1c73 1c76 1c78 1c7c
1c7e 1c8a 1c8c 1c8e 1c8f 1c94 1c98 1c9a
1ca6 1ca8 1cac 1cb0 1cb4 1cb8 1cbc 1cc0
1cc4 1cc8 1ccc 1cd0 1cd4 1cd8 1cdc 1ce0
1ce4 1ce8 1cec 1cf0 1cf4 1cf8 1cfc 1d00
1d04 1d08 1d0c 1d10 1d14 1d18 1d1c 1d20
1d24 1d28 1d2c 1d30 1d34 1d38 1d3c 1d40
1d44 1d48 1d4c 1d50 1d54 1d58 1d5c 1d60
1d64 1d68 1d6c 1d70 1d74 1d78 1d7c 1d80
1d84 1d88 1d8c 1d90 1d94 1d98 1d9c 1da0
1da4 1da8 1dac 1db0 1db4 1db8 1dbc 1dc0
1dc4 1dc8 1dcc 1dd0 1dd4 1dd8 1ddc 1de0
1de4 1de8 1dec 1df0 1df4 1df8 1dfc 1e00
1e04 1e08 1e0c 1e10 1e14 1e18 1e1c 1e20
1e24 1e28 1e2c 1e30 1e34 1e38 1e3c 1e40
1e44 1e48 1e4c 1e50 1e54 1e58 1e5c 1e60
1e64 1e68 1e6c 1e70 1e74 1e78 1e7c 1e80
1e84 1e88 1e8c 1e90 1e94 1e98 1e9c 1ea0
1ea4 1ea8 1eac 1eb0 1eb4 1eb8 1ebc 1ec0
1ec4 1ec8 1ecc 1ed0 1ed4 1ed8 1edc 1ee0
1ee4 1ee8 1eec 1ef0 1ef4 1ef8 1efc 1f00
1f04 1f08 1f0c 1f10 1f14 1f18 1f1c 1f20
1f24 1f28 1f2c 1f30 1f34 1f38 1f3c 1f40
1f44 1f48 1f4c 1f50 1f54 1f58 1f5c 1f60
1f64 1f68 1f6c 1f70 1f74 1f78 1f7c 1f80
1f84 1f88 1f8c 1f90 1f94 1f98 1f9c 1fa0
1fa4 1fa8 1fac 1fb0 1fb4 1fb8 1fbc 1fc0
1fc4 1fc8 1fcc 1fd0 1fd4 1fd8 1fdc 1fe0
1fe4 1fe8 1fec 1ff0 1ff4 1ff8 1ffc 2000
2004 2008 200c 2010 2014 2018 201c 2020
2024 2028 202c 2030 2034 2038 203c 2040
2044 2048 204c 2050 2054 2058 205c 2060
2064 2068 206c 2070 2074 2078 207c 2080
2084 2088 208c 2090 2094 2098 209c 20a0
20a4 20a8 20ac 20b0 20b4 20b8 20bc 20c0
20c4 20c8 20cc 20d0 20d4 20d8 20dc 20e0
20e4 20e8 20ec 20f0 20f4 20f8 20fc 2100
2104 2108 210c 2110 2114 2118 211c 2120
2124 2128 212c 2130 2134 2138 213c 2140
2144 2148 214c 2150 2154 2158 215c 2168
216d 2171 2175 2179 217c 2180 2184 2187
218a 218f 2192 2195 2198 2199 219e 219f
1 21a1 21a6 21aa 21ae 21b1 21b6 21bb
21be 21c2 21c3 21c8 21c9 21ce 21d0 21d4
21d7 21db 21df 21e3 21e7 21e9 21ed 21f1
21f4 21f5 21f7 21fa 21fd 21fe 2203 2206
220a 220e 2211 2212 2214 2217 221a 221b
2220 1 2223 2228 222c 2230 2235 223a
223e 2242 2246 2249 224c 2250 2254 2258
225c 2260 2264 2268 226c 2270 2274 2278
227c 2280 2284 2288 228c 2290 2294 2298
229c 22a0 22a4 22a8 22ac 22b0 22b4 22b8
22bc 22c0 22c4 22c8 22cc 22d0 22d4 22d8
22dc 22e0 22e4 22e8 22f4 22f8 22fd 2301
2304 2305 230a 230e 2312 2315 2318 231c
231e 2322 2326 2329 232c 2330 2332 2336
233a 233d 233f 2343 2347 234b 234e 2352
2356 2358 2359 235e 1 2362 2366 236a
236d 2371 2375 2379 237d 2380 2384 2388
238b 238e 2393 2396 2399 239c 239d 23a2
23a3 1 23a5 23aa 23ae 23b2 23b5 23ba
23bf 23c2 23c6 23c7 23cc 23cf 23d4 23d5
23da 23dd 23e2 23e3 23e8 23eb 23ef 23f0
23f5 23f8 23fd 23fe 2403 2406 240a 240e
2411 2414 2415 2417 2418 241d 241e 2423
2425 2429 242c 242e 2432 2434 2440 2442
2444 2445 244a 244e 2450 245c 245e 2462
2466 2469 246d 246e 2473 2477 247b 247f
2483 2487 248b 248f 2493 2497 249b 249f
24a3 24a7 24ab 24af 24b3 24b7 24bb 24bf
24c3 24c7 24cb 24cf 24d3 24d7 24db 24df
24e3 24e7 24eb 24ef 24f3 24f7 24fb 24ff
2503 2507 250b 250f 2513 2517 251b 251f
2523 2527 252b 252f 253b 253f 2544 2548
254b 254c 2551 2555 2559 255c 255f 2563
2565 2569 256d 2570 2573 2577 2579 257d
2581 2584 2586 258a 258e 2592 2595 2599
259d 259f 25a0 25a5 1 25a9 25ad 25b1
25b4 25b8 25bc 25c0 25c4 25c7 25cb 25cf
25d2 25d5 25da 25dd 25e0 25e3 25e4 25e9
25ea 1 25ec 25f1 25f5 25f9 25fc 2601
2606 2609 260d 260e 2613 2616 261b 261c
2621 2624 2629 262a 262f 2632 2636 2637
263c 263f 2644 2645 264a 264d 2651 2655
2658 265b 265c 265e 265f 2664 2665 266a
266c 2670 2673 2675 2679 267b 2687 2689
268b 268c 2691 2695 2697 26a3 26a5 26a9
26ad 26b1 26b5 26b9 26bd 26c1 26c5 26c9
26cd 26d1 26d5 26d9 26dd 26e1 26e5 26e9
26ed 26f1 26f5 26f9 26fd 2701 2705 2709
270d 2711 2715 2719 271d 2721 2725 2729
272d 2731 2735 2739 273d 2741 2745 2749
274d 2751 2755 2759 275d 2761 2765 2769
276d 2771 2775 2779 277d 2781 2785 2789
278d 2791 2795 2799 279d 27a1 27a5 27a9
27ad 27b1 27b5 27b9 27bd 27c1 27c5 27c9
27d5 27da 27de 27e2 27e6 27e9 27ed 27f1
27f4 27f7 27fc 27ff 2802 2805 2806 280b
280c 1 280e 2813 2817 281b 281e 2823
2828 282b 282f 2830 2835 2836 283b 283d
2841 2844 2848 284c 2850 2854 2856 285a
285e 2862 2865 2866 2868 286b 286e 286f
2874 2878 287c 2880 2884 2888 288c 2890
2894 2898 289c 28a0 28a4 28a8 28ac 28b0
28b4 28b8 28bc 28c0 28c4 28c8 28cc 28d0
28d4 28d8 28dc 28e0 28e4 28e8 28ec 28f0
28f4 28f8 28fc 2900 2904 2908 290c 2910
2914 2918 291c 2920 2924 2928 292c 2930
2934 2938 293c 2940 2944 2948 294c 2950
2954 2958 295c 2960 2964 2968 296c 2970
2974 2978 297c 2980 2984 2988 298c 2990
2994 2998 299c 29a0 29a4 29a8 29ac 29b0
29b4 29b8 29bc 29c0 29c4 29c8 29cc 29d0
29d4 29d8 29dc 29e0 29e4 29e8 29ec 29f0
29f4 29f8 29fc 2a00 2a04 2a08 2a0c 2a10
2a14 2a18 2a1c 2a20 2a24 2a28 2a2c 2a30
2a34 2a38 2a3c 2a40 2a44 2a48 2a4c 2a50
2a54 2a58 2a5c 2a60 2a64 2a68 2a6c 2a70
2a74 2a78 2a7c 2a80 2a84 2a88 2a8c 2a90
2a94 2a98 2a9c 2aa0 2aa4 2aa8 2ab4 2ab9
2abd 2ac1 2ac5 2ac8 2acc 2ad0 2ad3 2ad6
2adb 2ade 2ae1 2ae4 2ae5 2aea 2aeb 1
2aed 2af2 2af6 2afa 2afd 2b02 2b07 2b0a
2b0e 2b0f 2b14 2b15 2b1a 2b1c 2b20 2b23
2b27 2b2b 2b2f 2b33 2b35 2b39 2b3d 2b41
2b44 2b45 2b47 2b4a 2b4d 2b4e 2b53 2b57
2b5b 2b5f 2b62 2b63 2b65 2b66 2b68 2b6b
2b6e 2b6f 2b74 2b78 2b7b 2b7f 2b83 2b87
2b8b 2b8f 2b93 2b97 2b9b 2ba7 2bab 2baf
2bb2 2bb6 2bba 2bbc 2bc0 2bc4 2bc8 2bcb
2bcf 2bd3 2bd5 2bd6 2bdb 1 2bdf 2be3
2be7 2bea 2bee 2bf2 2bf6 2bfa 2bfd 2c01
2c05 2c08 2c0b 2c10 2c13 2c16 2c19 2c1a
2c1f 2c20 1 2c22 2c27 2c2b 2c2f 2c32
2c37 2c3c 2c3f 2c43 2c44 2c49 2c4c 2c51
2c52 2c57 2c5a 2c5f 2c60 2c65 2c68 2c6c
2c6d 2c72 2c75 2c7a 2c7b 2c80 2c83 2c87
2c8b 2c8e 2c91 2c92 2c94 2c95 2c9a 2c9b
2ca0 2ca2 2ca6 2ca9 2cab 2caf 2cb1 2cbd
2cbf 2cc1 2cc2 2cc7 2ccb 2ccd 2cd9 2cdb
2cdf 2ce3 2ce6 2ce7 2ce9 2cec 2cef 2cf0
2cf5 2cf9 2cfe 2d02 2d04 2d08 2d0b 2d0f
2d13 2d17 2d1b 2d1f 2d23 2d27 2d2b 2d2f
2d33 2d3f 2d43 2d47 2d4a 2d4e 2d52 2d54
2d58 2d5c 2d60 2d63 2d67 2d6b 2d6d 2d6e
2d73 1 2d77 2d7b 2d7f 2d82 2d86 2d8a
2d8e 2d92 2d95 2d99 2d9d 2da0 2da3 2da8
2dab 2dae 2db1 2db2 2db7 2db8 1 2dba
2dbf 2dc3 2dc7 2dca 2dcf 2dd4 2dd7 2ddb
2ddc 2de1 2de4 2de9 2dea 2def 2df2 2df7
2df8 2dfd 2e00 2e04 2e05 2e0a 2e0d 2e12
2e13 2e18 2e1b 2e1f 2e23 2e26 2e29 2e2a
2e2c 2e2d 2e32 2e33 2e38 2e3a 2e3e 2e41
2e43 2e47 2e49 2e55 2e57 2e59 2e5a 2e5f
2e63 2e65 2e71 2e73 2e77 2e7b 2e7e 2e7f
2e81 2e84 2e87 2e88 2e8d 2e91 2e95 2e99
2e9d 2ea1 2ea5 2ea9 2ead 2eb1 2eb5 2eb9
2ebd 2ec1 2ec5 2ec9 2ecd 2ed1 2ed5 2ed9
2edd 2ee1 2ee5 2ee9 2eed 2ef1 2ef5 2ef9
2efd 2f09 2f0d 2f11 2f14 2f18 2f1c 2f1e
2f22 2f26 2f2a 2f2d 2f31 2f35 2f37 2f38
2f3d 1 2f41 2f45 2f49 2f4c 2f50 2f54
2f58 2f5c 2f5f 2f63 2f67 2f6a 2f6d 2f72
2f75 2f78 2f7b 2f7c 2f81 2f82 1 2f84
2f89 2f8d 2f91 2f94 2f99 2f9e 2fa1 2fa5
2fa6 2fab 2fae 2fb3 2fb4 2fb9 2fbc 2fc1
2fc2 2fc7 2fca 2fce 2fcf 2fd4 2fd7 2fdc
2fdd 2fe2 2fe5 2fe9 2fed 2ff0 2ff3 2ff4
2ff6 2ff7 2ffc 2ffd 3002 3004 3008 300b
300d 3011 3013 301f 3021 3023 3024 3029
302d 302f 303b 303d 3041 3045 3048 3049
304b 304e 3051 3052 3057 305b 3060 3064
3066 306a 306f 3073 3075 3079 307d 3080
3082 3086 308b 308f 3091 3095 3099 309c
309e 30a2 30a6 30a9 30ad 30b1 30b5 30b9
30bd 30c1 30c5 30c9 30cd 30d1 30d5 30d9
30dd 30e1 30e5 30e9 30ed 30f1 30f5 30f9
30fd 3101 3105 3109 310d 3111 3115 3119
311d 3121 3125 3129 312d 3131 3135 3139
313d 3141 3145 3149 314d 3151 3155 3159
315d 3161 3165 3169 316d 3171 3175 3179
317d 3181 3185 3189 318d 3191 3195 3199
319d 31a1 31a5 31a9 31ad 31b1 31b5 31b9
31bd 31c1 31c5 31c9 31cd 31d1 31d5 31d9
31dd 31e1 31e5 31e9 31ed 31f1 31f5 31f9
31fd 3201 3205 3209 320d 3211 3215 3219
321d 3221 3225 3229 322d 3231 3235 3239
323d 3241 3245 3249 324d 3251 3255 3259
325d 3261 3265 3269 326d 3271 3275 3279
327d 3281 3285 3289 328d 3291 3295 3299
329d 32a1 32a5 32a9 32ad 32b1 32b5 32b9
32bd 32c1 32c5 32c9 32cd 32d1 32d5 32d9
32dd 32e1 32e5 32e9 32ed 32f1 32f5 32f9
32fd 3301 3305 3309 330d 3311 3315 3319
331d 3321 3325 3329 332d 3331 3335 3339
333d 3341 3345 3349 334d 3351 3355 3359
335d 3361 3365 3369 336d 3371 3375 3379
337d 3381 3385 3389 338d 3391 3395 3399
339d 33a1 33a5 33a9 33ad 33b1 33b5 33b9
33bd 33c1 33c5 33c9 33cd 33d1 33d5 33d9
33dd 33e1 33e5 33e9 33ed 33f1 33f5 33f9
33fd 3401 3405 3409 340d 3411 3415 3419
341d 3421 3425 3429 342d 3431 3435 3439
343d 3441 3445 3449 344d 3451 3455 3459
345d 3461 3465 3469 346d 3471 3475 3479
347d 3481 3485 3489 348d 3491 3495 3499
349d 34a1 34a5 34a9 34ad 34b1 34b5 34b9
34bd 34c1 34c5 34c9 34cd 34d1 34d5 34d9
34dd 34e1 34e5 34e9 34ed 34f1 34f5 34f9
34fd 3501 3505 3509 350d 3511 3515 3519
351d 3521 3525 3529 352d 3531 3535 3539
353d 3541 3545 3549 354d 3551 3555 3559
355d 3561 3565 3569 356d 3571 3575 3579
357d 3581 3585 3589 358d 3591 3595 3599
359d 35a1 35a5 35a9 35ad 35b1 35b5 35b9
35bd 35c1 35c5 35c9 35cd 35d1 35d5 35d9
35dd 35e1 35e5 35e9 35ed 35f1 35f5 35f9
35fd 3601 3605 3609 360d 3611 3615 3619
361d 3621 3625 3629 362d 3631 3635 3639
363d 3641 3645 3649 364d 3651 3655 3659
365d 3661 3665 3669 366d 3671 3675 3679
367d 3681 3685 3689 368d 3691 3695 3699
369d 36a1 36a5 36a9 36ad 36b1 36b5 36b9
36bd 36c1 36c5 36c9 36cd 36d1 36d5 36d9
36dd 36e1 36e5 36e9 36ed 36f1 36f5 36f9
36fd 3701 3705 3709 370d 3711 3715 3719
371d 3721 3725 3729 372d 3731 3735 3739
373d 3741 3745 3749 374d 3751 3755 3759
375d 3761 3765 3769 376d 3771 3775 3779
377d 3781 3785 3789 378d 3791 3795 3799
379d 37a1 37a5 37a9 37ad 37b1 37b5 37b9
37bd 37c1 37c5 37c9 37cd 37d1 37d5 37d9
37dd 37e1 37e5 37e9 37ed 37f1 37f5 37f9
37fd 3801 3805 3809 380d 3811 3815 3819
381d 3821 3825 3829 382d 3831 3835 3839
383d 3841 3845 3849 384d 3851 3855 3859
385d 3861 3865 3869 386d 3871 3875 3879
387d 3881 3885 3889 388d 3891 3895 3899
389d 38a1 38a5 38a9 38ad 38b1 38b5 38b9
38bd 38c1 38c5 38c9 38cd 38d1 38d5 38d9
38dd 38e1 38e5 38e9 38ed 38f1 38fd 3902
3906 390a 390e 3911 3915 3919 391c 391f
3924 3927 392a 392d 392e 3933 3934 1
3936 393b 393f 3943 3946 394b 3950 3953
3957 3958 395d 395e 3963 3965 3969 396c
3970 3974 3978 397a 397e 3982 3986 398a
398e 3992 3996 399a 399e 39a2 39a6 39aa
39ae 39b2 39b6 39ba 39be 39c2 39c6 39ca
39ce 39d2 39d6 39da 39de 39e2 39e6 39ea
39ee 39f2 39f6 39fa 39fe 3a02 3a06 3a0a
3a0e 3a12 3a16 3a1a 3a1e 3a22 3a26 3a2a
3a2e 3a32 3a36 3a3a 3a3e 3a42 3a46 3a4a
3a4e 3a52 3a56 3a5a 3a5e 3a62 3a66 3a6a
3a6e 3a72 3a76 3a7a 3a7e 3a82 3a86 3a8a
3a8e 3a92 3a96 3a9a 3a9e 3aa2 3aa6 3aaa
3aae 3ab2 3ab6 3aba 3abe 3ac2 3ac6 3aca
3ace 3ad2 3ad6 3ada 3ade 3ae2 3ae6 3aea
3aee 3af2 3af6 3afa 3afe 3b02 3b06 3b0a
3b0e 3b12 3b16 3b1a 3b1e 3b22 3b26 3b2a
3b2e 3b32 3b36 3b3a 3b3e 3b42 3b46 3b4a
3b4e 3b52 3b56 3b5a 3b5e 3b62 3b66 3b6a
3b6e 3b72 3b76 3b7a 3b7e 3b82 3b86 3b8a
3b8e 3b92 3b96 3b9a 3b9e 3ba2 3ba6 3baa
3bae 3bb2 3bb6 3bba 3bbe 3bc2 3bc6 3bca
3bce 3bd2 3bd6 3bda 3bde 3be2 3be6 3bea
3bee 3bf2 3bf6 3bfa 3bfe 3c02 3c06 3c0a
3c0e 3c12 3c16 3c1a 3c1e 3c22 3c26 3c2a
3c2e 3c32 3c36 3c3a 3c3e 3c42 3c46 3c4a
3c4e 3c52 3c56 3c5a 3c5e 3c62 3c66 3c6a
3c6e 3c72 3c76 3c7a 3c7e 3c82 3c86 3c8a
3c8e 3c92 3c96 3c9a 3c9e 3ca2 3ca6 3caa
3cae 3cb2 3cb6 3cba 3cbe 3cc2 3cc6 3cca
3cce 3cd2 3cd6 3cda 3cde 3ce2 3ce6 3cea
3cee 3cf2 3cf6 3cfa 3cfe 3d02 3d06 3d0a
3d0e 3d12 3d16 3d1a 3d1e 3d22 3d26 3d2a
3d2e 3d32 3d36 3d3a 3d3e 3d42 3d46 3d4a
3d4e 3d52 3d56 3d5a 3d5e 3d62 3d66 3d6a
3d6e 3d72 3d76 3d7a 3d7e 3d82 3d86 3d8a
3d8e 3d92 3d96 3d9a 3d9e 3da2 3da6 3daa
3dae 3db2 3db6 3dba 3dbe 3dc2 3dc6 3dca
3dce 3dd2 3dd6 3dda 3dde 3de2 3de6 3dea
3dee 3df2 3df6 3dfa 3dfe 3e02 3e06 3e0a
3e0e 3e12 3e16 3e1a 3e1e 3e22 3e26 3e2a
3e2e 3e32 3e36 3e3a 3e3e 3e42 3e46 3e4a
3e4e 3e52 3e56 3e5a 3e5e 3e62 3e66 3e6a
3e6e 3e72 3e76 3e7a 3e7e 3e82 3e86 3e8a
3e8e 3e92 3e96 3e9a 3e9e 3ea2 3ea6 3eaa
3eae 3eb2 3ebe 3ec3 3ec7 3ecb 3ecf 3ed2
3ed6 3eda 3edd 3ee0 3ee5 3ee8 3eeb 3eee
3eef 3ef4 3ef5 1 3ef7 3efc 3f00 3f04
3f07 3f0c 3f11 3f14 3f18 3f19 3f1e 3f1f
3f24 3f26 3f2a 3f2d 3f31 3f35 3f39 3f3b
3f3f 3f43 3f46 3f4a 3f4c 3f50 3f54 3f58
3f5b 3f5c 3f5e 3f61 3f64 3f65 3f6a 3f6e
3f72 3f77 3f7c 3f80 3f84 3f88 3f8b 3f8e
3f92 3f96 3f9a 3f9e 3fa2 3fa6 3faa 3fae
3fb2 3fb6 3fba 3fbe 3fc2 3fc6 3fca 3fce
3fd2 3fd6 3fda 3fde 3fe2 3fe6 3fea 3fee
3ff2 3ff6 3ffa 3ffe 4002 4006 400a 400e
4012 4016 401a 401e 4022 4026 402a 402e
403a 403e 4043 4047 404a 404b 4050 4054
4058 405b 405e 4062 4064 4068 406c 406f
4072 4076 4078 407c 4080 4083 4085 4089
408d 4091 4094 4098 409c 409e 409f 40a4
1 40a8 40ac 40b0 40b3 40b7 40bb 40bf
40c3 40c6 40ca 40ce 40d1 40d4 40d9 40dc
40df 40e2 40e3 40e8 40e9 1 40eb 40f0
40f4 40f8 40fb 4100 4105 4108 410c 410d
4112 4115 411a 411b 4120 4123 4128 4129
412e 4131 4135 4136 413b 413e 4143 4144
4149 414c 4150 4154 4157 415a 415b 415d
415e 4163 4164 4169 416b 416f 4172 4174
4178 417a 4186 4188 418a 418b 4190 4194
4196 41a2 41a4 41a8 41ac 41af 41b3 41b4
41b9 41bd 41c1 41c5 41c9 41cd 41d1 41d5
41d9 41dd 41e1 41e5 41e9 41ed 41f1 41f5
41f9 41fd 4201 4205 4209 420d 4211 4215
4219 421d 4221 4225 4229 422d 4231 4235
4239 423d 4241 4245 4249 424d 4251 4255
4259 425d 4261 4265 4269 426d 4271 4275
4279 427d 4281 4285 4289 428d 4291 429d
42a1 42a6 42aa 42ad 42ae 42b3 42b7 42bb
42be 42c1 42c5 42c7 42cb 42cf 42d2 42d5
42d9 42db 42df 42e3 42e6 42e8 42ec 42f0
42f4 42f7 42fb 42ff 4301 4302 4307 1
430b 430f 4313 4316 431a 431e 4322 4326
4329 432d 4331 4334 4337 433c 433f 4342
4345 4346 434b 434c 1 434e 4353 4357
435b 435e 4363 4368 436b 436f 4370 4375
4378 437d 437e 4383 4386 438b 438c 4391
4394 4398 4399 439e 43a1 43a6 43a7 43ac
43af 43b3 43b7 43ba 43bd 43be 43c0 43c1
43c6 43c7 43cc 43ce 43d2 43d5 43d7 43db
43dd 43e9 43eb 43ed 43ee 43f3 43f7 43f9
4405 4407 440b 440f 4413 4417 441b 441f
4423 4427 442b 442f 4433 4437 443b 443f
4443 4447 444b 444f 4453 4457 445b 445f
4463 4467 446b 446f 4473 4477 447b 447f
4483 4487 448b 448f 4493 4497 449b 449f
44a3 44a7 44ab 44af 44b3 44b7 44bb 44bf
44c3 44c7 44cb 44cf 44d3 44d7 44db 44df
44e3 44e7 44eb 44ef 44f3 44f7 44fb 44ff
4503 4507 450b 450f 4513 4517 451b 451f
4523 4527 452b 452f 4533 4537 4543 4548
454c 4550 4554 4557 455b 455f 4562 4565
456a 456d 4570 4573 4574 4579 457a 1
457c 4581 4585 4589 458c 4591 4596 4599
459d 459e 45a3 45a4 45a9 45ab 45af 45b2
45b6 45ba 45be 45c2 45c4 45c8 45cc 45d0
45d3 45d4 45d6 45d9 45dc 45dd 45e2 45e6
45ea 45ef 45f4 45f8 45fc 4600 4603 4606
460a 460e 4612 4616 461a 461e 4622 4626
462a 462e 4632 4636 463a 463e 4642 4646
464a 464e 4652 4656 465a 465e 4662 4666
466a 466e 4672 4676 467a 467e 4682 4686
468a 468e 4692 4696 469a 469e 46a2 46a6
46b2 46b6 46bb 46bf 46c2 46c3 46c8 46cc
46d0 46d3 46d6 46da 46dc 46e0 46e4 46e7
46ea 46ee 46f0 46f4 46f8 46fb 46fd 4701
4705 4709 470c 4710 4714 4716 4717 471c
1 4720 4724 4728 472b 472f 4733 4737
473b 473e 4742 4746 4749 474c 4751 4754
4757 475a 475b 4760 4761 1 4763 4768
476c 4770 4773 4778 477d 4780 4784 4785
478a 478d 4792 4793 4798 479b 47a0 47a1
47a6 47a9 47ad 47ae 47b3 47b6 47bb 47bc
47c1 47c4 47c8 47cc 47cf 47d2 47d3 47d5
47d6 47db 47dc 47e1 47e3 47e7 47ea 47ec
47f0 47f2 47fe 4800 4802 4803 4808 480c
480e 481a 481c 4820 4824 4827 482b 482c
4831 4835 4839 483d 4841 4845 4849 484d
4851 4855 4859 485d 4861 4865 4869 486d
4871 4875 4879 487d 4881 4885 4889 488d
4891 4895 4899 489d 48a1 48a5 48a9 48ad
48b1 48b5 48b9 48bd 48c1 48c5 48c9 48cd
48d1 48d5 48d9 48dd 48e1 48e5 48e9 48ed
48f1 48f5 48f9 48fd 4901 4905 4909 490d
4911 4915 4919 491d 4921 4925 4929 492d
4931 4935 4939 493d 4941 4945 4949 494d
4951 4955 4959 495d 4961 4965 4969 496d
4971 4975 4979 497d 4981 4985 4989 498d
4991 4995 4999 499d 49a1 49a5 49a9 49ad
49b1 49b5 49b9 49bd 49c9 49cd 49d2 49d6
49d9 49da 49df 49e3 49e7 49ea 49ed 49f1
49f3 49f7 49fb 49fe 4a01 4a05 4a07 4a0b
4a0f 4a12 4a14 4a18 4a1c 4a20 4a23 4a27
4a2b 4a2d 4a2e 4a33 1 4a37 4a3b 4a3f
4a42 4a46 4a4a 4a4e 4a52 4a55 4a59 4a5d
4a60 4a63 4a68 4a6b 4a6e 4a71 4a72 4a77
4a78 1 4a7a 4a7f 4a83 4a87 4a8a 4a8f
4a94 4a97 4a9b 4a9c 4aa1 4aa4 4aa9 4aaa
4aaf 4ab2 4ab7 4ab8 4abd 4ac0 4ac4 4ac5
4aca 4acd 4ad2 4ad3 4ad8 4adb 4adf 4ae3
4ae6 4ae9 4aea 4aec 4aed 4af2 4af3 4af8
4afa 4afe 4b01 4b03 4b07 4b09 4b15 4b17
4b19 4b1a 4b1f 4b23 4b25 4b31 4b33 4b37
4b3b 4b3f 4b43 4b47 4b4b 4b4f 4b53 4b57
4b5b 4b5f 4b63 4b67 4b6b 4b6f 4b73 4b77
4b7b 4b7f 4b83 4b87 4b8b 4b8f 4b93 4b97
4b9b 4b9f 4ba3 4ba7 4bab 4baf 4bb3 4bb7
4bbb 4bbf 4bc3 4bc7 4bcb 4bcf 4bd3 4bd7
4bdb 4bdf 4be3 4be7 4beb 4bef 4bf3 4bf7
4bfb 4bff 4c03 4c07 4c0b 4c0f 4c13 4c17
4c1b 4c1f 4c23 4c27 4c2b 4c2f 4c33 4c37
4c3b 4c3f 4c43 4c47 4c4b 4c4f 4c53 4c57
4c5b 4c5f 4c63 4c67 4c6b 4c6f 4c73 4c77
4c7b 4c7f 4c83 4c87 4c8b 4c8f 4c93 4c97
4c9b 4c9f 4ca3 4ca7 4cab 4caf 4cb3 4cb7
4cbb 4cbf 4cc3 4cc7 4ccb 4ccf 4cd3 4cd7
4cdb 4ce7 4cec 4cf0 4cf4 4cf8 4cfb 4cff
4d03 4d06 4d09 4d0e 4d11 4d14 4d17 4d18
4d1d 4d1e 1 4d20 4d25 4d29 4d2d 4d30
4d35 4d3a 4d3d 4d41 4d42 4d47 4d48 4d4d
4d4f 4d53 4d56 4d5a 4d5e 4d62 4d66 4d68
4d6c 4d70 4d74 4d77 4d78 4d7a 4d7d 4d80
4d81 4d86 4d8a 4d8e 4d92 4d96 4d9a 4d9e
4da2 4da6 4daa 4dae 4db2 4db6 4dba 4dbe
4dc2 4dc6 4dca 4dce 4dd2 4dd6 4dda 4dde
4de2 4de6 4dea 4dee 4df2 4df6 4dfa 4dfe
4e02 4e06 4e0a 4e0e 4e12 4e16 4e1a 4e1e
4e22 4e26 4e2a 4e2e 4e32 4e36 4e3a 4e3e
4e42 4e46 4e4a 4e4e 4e52 4e56 4e5a 4e5e
4e62 4e66 4e6a 4e6e 4e72 4e76 4e7a 4e7e
4e82 4e86 4e8a 4e8e 4e92 4e96 4e9a 4e9e
4ea2 4ea6 4eaa 4eae 4eb2 4eb6 4eba 4ebe
4ec2 4ec6 4eca 4ece 4ed2 4ed6 4eda 4ede
4ee2 4ee6 4eea 4eee 4ef2 4ef6 4efa 4efe
4f02 4f06 4f0a 4f0e 4f12 4f16 4f1a 4f1e
4f22 4f26 4f2a 4f2e 4f32 4f36 4f3a 4f3e
4f42 4f46 4f4a 4f4e 4f52 4f56 4f5a 4f5e
4f62 4f66 4f6a 4f6e 4f72 4f76 4f7a 4f7e
4f82 4f86 4f8a 4f8e 4f92 4f96 4f9a 4f9e
4fa2 4fa6 4faa 4fae 4fb2 4fb6 4fba 4fbe
4fc2 4fc6 4fca 4fce 4fd2 4fd6 4fda 4fde
4fe2 4fe6 4fea 4fee 4ff2 4ff6 4ffa 4ffe
5002 5006 500a 500e 5012 5016 501a 501e
5022 5026 502a 502e 5032 5036 503a 503e
5042 5046 504a 504e 5052 5056 505a 505e
5062 5066 506a 506e 5072 5076 507a 507e
5082 5086 508a 508e 5092 5096 509a 509e
50a2 50a6 50aa 50ae 50b2 50b6 50ba 50be
50c2 50c6 50ca 50ce 50d2 50d6 50da 50de
50e2 50e6 50ea 50ee 50f2 50f6 50fa 50fe
5102 5106 510a 510e 5112 5116 511a 511e
5122 512e 5133 5137 513b 513f 5142 5146
514a 514d 5150 5155 5158 515b 515e 515f
5164 5165 1 5167 516c 5170 5174 5177
517c 5181 5184 5188 5189 518e 518f 5194
5196 519a 519d 51a1 51a5 51a9 51ad 51af
51b3 51b7 51bb 51be 51bf 51c1 51c4 51c7
51c8 51cd 51d1 51d5 51da 51df 51e3 51e7
51eb 51ee 51f1 51f5 51f9 51fd 5201 5205
5209 520d 5211 5215 5219 521d 5221 5225
5229 522d 5231 5235 5239 523d 5241 5245
5249 524d 5251 5255 5259 525d 5261 5265
5269 526d 5271 5275 5279 527d 5281 5285
5289 528d 5291 5295 5299 529d 52a1 52a5
52a9 52ad 52b1 52bd 52c1 52c6 52ca 52cd
52ce 52d3 52d7 52db 52de 52e1 52e5 52e7
52eb 52ef 52f2 52f5 52f9 52fb 52ff 5303
5306 5308 530c 5310 5314 5317 531b 531f
5321 5322 5327 1 532b 532f 5333 5336
533a 533e 5342 5346 5349 534d 5351 5354
5357 535c 535f 5362 5365 5366 536b 536c
1 536e 5373 5377 537b 537e 5383 5388
538b 538f 5390 5395 5398 539d 539e 53a3
53a6 53ab 53ac 53b1 53b4 53b8 53b9 53be
53c1 53c6 53c7 53cc 53cf 53d3 53d7 53da
53dd 53de 53e0 53e1 53e6 53e7 53ec 53ee
53f2 53f5 53f7 53fb 53fd 5409 540b 540d
540e 5413 5417 5419 5425 5427 542b 542f
5434 5439 543d 5441 5445 5448 544b 544f
5453 5457 545b 545f 5463 5467 546b 546f
5473 5477 547b 547f 5483 5487 548b 548f
5493 5497 549b 549f 54a3 54a7 54ab 54af
54b3 54b7 54bb 54bf 54c3 54c7 54cb 54cf
54d3 54d7 54db 54df 54e3 54e7 54eb 54ef
54f3 54f7 54fb 54ff 5503 5507 550b 550f
5513 5517 551b 551f 5523 5527 552b 552f
5533 5537 553b 553f 5543 5547 554b 554f
5553 5557 555b 555f 5563 5567 556b 556f
5573 5577 557b 557f 5583 5587 558b 558f
5593 5597 559b 559f 55a3 55a7 55ab 55af
55b3 55b7 55bb 55bf 55c3 55c7 55cb 55cf
55d3 55d7 55db 55df 55e3 55e7 55eb 55ef
55f3 55f7 55fb 55ff 5603 5607 560b 560f
5613 561f 5623 5628 562c 562f 5630 5635
5639 563d 5640 5643 5647 5649 564d 5651
5654 5657 565b 565d 5661 5665 5668 566a
566e 5672 5676 5679 567d 5681 5683 5684
5689 1 568d 5691 5695 5698 569c 56a0
56a4 56a8 56ab 56af 56b3 56b6 56b9 56be
56c1 56c4 56c7 56c8 56cd 56ce 1 56d0
56d5 56d9 56dd 56e0 56e5 56ea 56ed 56f1
56f2 56f7 56fa 56ff 5700 5705 5708 570d
570e 5713 5716 571a 571b 5720 5723 5728
5729 572e 5731 5735 5739 573c 573f 5740
5742 5743 5748 5749 574e 5750 5754 5757
5759 575d 575f 576b 576d 576f 5770 5775
5779 577b 5787 5789 578d 5791 5795 5799
579d 57a1 57a5 57a9 57ad 57b1 57b5 57b9
57bd 57c1 57c5 57c9 57d5 57d9 57de 57e2
57e5 57e6 57eb 57ef 57f3 57f6 57f9 57fd
57ff 5803 5807 580a 580d 5811 5813 5817
581b 581e 5820 5824 5828 582c 582f 5833
5837 5839 583a 583f 1 5843 5847 584b
584e 5852 5856 585a 585e 5861 5865 5869
586c 586f 5874 5877 587a 587d 587e 5883
5884 1 5886 588b 588f 5893 5896 589b
58a0 58a3 58a7 58a8 58ad 58b0 58b5 58b6
58bb 58be 58c3 58c4 58c9 58cc 58d0 58d1
58d6 58d9 58de 58df 58e4 58e7 58eb 58ef
58f2 58f5 58f6 58f8 58f9 58fe 58ff 5904
5906 590a 590d 590f 5913 5915 5921 5923
5925 5926 592b 592f 5931 593d 593f 5943
5947 594b 594f 5953 5957 595b 595f 5963
5967 596b 596f 5973 5977 597b 597f 5983
5987 598b 598f 5993 5997 599b 599f 59a3
59a7 59ab 59af 59b3 59b7 59bb 59bf 59c3
59c7 59cb 59cf 59d3 59d7 59db 59df 59e3
59e7 59eb 59ef 59f3 59f7 59fb 59ff 5a03
5a07 5a0b 5a0f 5a13 5a17 5a1b 5a1f 5a23
5a27 5a2b 5a2f 5a33 5a37 5a3b 5a3f 5a43
5a47 5a4b 5a4f 5a53 5a57 5a5b 5a5f 5a63
5a67 5a6b 5a6f 5a73 5a77 5a7b 5a7f 5a83
5a87 5a8b 5a8f 5a93 5a97 5a9b 5a9f 5aa3
5aa7 5aab 5aaf 5ab3 5ab7 5abb 5abf 5ac3
5ac7 5acb 5acf 5ad3 5ad7 5adb 5adf 5ae3
5ae7 5aeb 5aef 5af3 5af7 5afb 5aff 5b03
5b07 5b0b 5b0f 5b13 5b17 5b1b 5b1f 5b23
5b27 5b2b 5b2f 5b33 5b37 5b3b 5b3f 5b43
5b47 5b4b 5b4f 5b53 5b57 5b5b 5b5f 5b63
5b67 5b6b 5b6f 5b73 5b77 5b7b 5b7f 5b83
5b87 5b8b 5b8f 5b93 5b97 5b9b 5b9f 5ba3
5ba7 5bab 5baf 5bb3 5bb7 5bbb 5bbf 5bc3
5bc7 5bcb 5bcf 5bd3 5bd7 5bdb 5bdf 5be3
5be7 5beb 5bef 5bf3 5bf7 5bfb 5bff 5c03
5c07 5c0b 5c0f 5c13 5c17 5c1b 5c1f 5c23
5c27 5c2b 5c2f 5c33 5c37 5c3b 5c3f 5c43
5c47 5c4b 5c4f 5c53 5c57 5c5b 5c5f 5c63
5c67 5c6b 5c6f 5c73 5c77 5c7b 5c7f 5c83
5c87 5c8b 5c8f 5c93 5c97 5c9b 5c9f 5cab
5cb0 5cb4 5cb8 5cbc 5cbf 5cc3 5cc7 5cca
5ccd 5cd2 5cd5 5cd8 5cdb 5cdc 5ce1 5ce2
1 5ce4 5ce9 5ced 5cf1 5cf4 5cf9 5cfe
5d01 5d05 5d06 5d0b 5d0c 5d11 5d13 5d17
5d1a 5d1e 5d22 5d26 5d2a 5d2c 5d30 5d34
5d38 5d3b 5d3c 5d3e 5d42 5d45 5d49 5d4c
5d4d 5d52 5d56 5d5a 5d5e 5d62 5d66 5d72
5d76 5d7a 5d7d 5d81 5d85 5d87 5d8b 5d8f
5d93 5d96 5d9a 5d9e 5da0 5da1 5da6 1
5daa 5dae 5db2 5db5 5db9 5dbd 5dc1 5dc5
5dc8 5dcc 5dd0 5dd3 5dd6 5ddb 5dde 5de1
5de4 5de5 5dea 5deb 1 5ded 5df2 5df6
5dfa 5dfd 5e02 5e07 5e0a 5e0e 5e0f 5e14
5e17 5e1c 5e1d 5e22 5e25 5e2a 5e2b 5e30
5e33 5e37 5e38 5e3d 5e40 5e45 5e46 5e4b
5e4e 5e52 5e56 5e59 5e5c 5e5d 5e5f 5e60
5e65 5e66 5e6b 5e6d 5e71 5e74 5e76 5e7a
5e7c 5e88 5e8a 5e8c 5e8d 5e92 5e96 5e98
5ea4 5ea6 5eaa 5eae 5eb1 5eb5 5eb8 5ebc
5ebf 5ec0 5ec5 5ec8 5ecc 5ed0 5ed4 5ed8
5edc 5ee0 5ee4 5ee8 5eec 5ef0 5ef4 5ef8
5efc 5f00 5f04 5f08 5f0c 5f10 5f14 5f18
5f1c 5f20 5f24 5f28 5f2c 5f30 5f34 5f38
5f3c 5f40 5f44 5f48 5f4c 5f50 5f54 5f58
5f5c 5f60 5f64 5f68 5f6c 5f70 5f74 5f78
5f7c 5f80 5f84 5f88 5f8c 5f90 5f94 5f98
5f9c 5fa0 5fa4 5fa8 5fac 5fb0 5fb4 5fb8
5fbc 5fc0 5fc4 5fc8 5fcc 5fd0 5fd4 5fd8
5fdc 5fe0 5fe4 5fe8 5fec 5ff0 5ff4 5ff8
5ffc 6000 6004 6008 600c 6010 6014 6018
601c 6020 6024 6028 602c 6030 6034 6038
603c 6040 6044 6048 604c 6050 6054 6058
605c 6060 6064 6068 606c 6070 6074 6078
607c 6080 6084 6088 608c 6090 6094 6098
609c 60a0 60a4 60a8 60ac 60b0 60b4 60b8
60bc 60c0 60c4 60c8 60cc 60d0 60d4 60d8
60dc 60e0 60e4 60e8 60ec 60f0 60f4 60f8
60fc 6100 6104 6108 610c 6110 6114 6118
611c 6120 6124 6128 612c 6130 613c 6141
6145 6149 614d 6150 6154 6158 615b 615e
6163 6166 6169 616c 616d 6172 6173 1
6175 617a 617e 6182 6185 618a 618f 6192
6196 6197 619c 619d 61a2 61a4 61a8 61ab
61af 61b3 61b7 61b9 61bd 61c0 61c4 61c6
61ca 61ce 61d2 61d5 61d6 61d8 61db 61de
61df 61e4 61e8 61ec 61f0 61f4 61f8 61fc
6200 6204 6208 620c 6210 6214 6218 621c
6220 6224 6228 622c 6230 6234 6238 623c
6240 6244 6248 624c 6250 6254 6258 625c
6260 6264 6268 626c 6270 6274 6278 627c
6280 6284 6288 628c 6290 6294 6298 629c
62a0 62a4 62a8 62ac 62b0 62b4 62b8 62bc
62c0 62c4 62c8 62cc 62d0 62d4 62d8 62dc
62e0 62e4 62e8 62ec 62f0 62f4 62f8 62fc
6300 6304 6308 630c 6310 6314 6318 631c
6320 6324 6328 632c 6330 6334 6338 633c
6340 6344 6348 634c 6350 6354 6358 635c
6360 6364 6368 636c 6370 6374 6378 637c
6380 6384 6388 638c 6390 6394 6398 639c
63a0 63a4 63a8 63ac 63b0 63b4 63b8 63bc
63c0 63c4 63c8 63cc 63d0 63d4 63d8 63dc
63e0 63e4 63e8 63ec 63f0 63f4 63f8 63fc
6400 6404 6408 640c 6410 6414 6418 641c
6420 6424 6428 642c 6430 6434 6438 643c
6440 6444 6448 644c 6450 6454 6458 645c
6460 6464 6468 646c 6470 6474 6478 647c
6480 6484 6488 648c 6490 6494 6498 649c
64a0 64a4 64a8 64ac 64b0 64b4 64b8 64bc
64c0 64c4 64c8 64cc 64d0 64d4 64d8 64dc
64e0 64e4 64e8 64ec 64f0 64f4 64f8 64fc
6500 6504 6508 650c 6510 6514 6518 651c
6520 6524 6528 652c 6530 6534 6538 653c
6540 6544 6548 654c 6550 6554 6558 655c
6560 6564 6568 656c 6570 6574 6578 657c
6580 6584 6588 658c 6590 6594 6598 659c
65a0 65a4 65a8 65ac 65b0 65b4 65b8 65bc
65c0 65c4 65c8 65cc 65d0 65d4 65d8 65dc
65e0 65e4 65e8 65ec 65f0 65f4 65f8 65fc
6600 6604 6608 660c 6610 6614 6618 661c
6620 6624 6628 662c 6630 6634 6638 663c
6640 6644 6648 664c 6650 6654 6658 665c
6660 6664 6668 666c 6670 6674 6678 667c
6680 6684 6688 668c 6690 6694 6698 669c
66a0 66a4 66a8 66ac 66b0 66b4 66b8 66bc
66c0 66c4 66c8 66cc 66d0 66d4 66d8 66dc
66e0 66e4 66e8 66ec 66f0 66fc 6701 6705
6709 670d 6710 6714 6718 671b 671e 6723
6726 6729 672c 672d 6732 6733 1 6735
673a 673e 6742 6745 674a 674f 6752 6756
6757 675c 675d 6762 6764 6768 676b 676f
6773 6777 677b 677d 6781 6785 6789 678c
678d 678f 6792 6795 6796 679b 679f 67a3
67a7 67ab 67af 67b3 67b7 67bb 67bf 67c3
67c7 67cb 67cf 67d3 67d7 67db 67df 67e3
67e7 67eb 67ef 67f3 67f7 67fb 67ff 6803
6807 680b 680f 6813 6817 681b 681f 6823
6827 682b 682f 6833 6837 683b 683f 6843
6847 684b 684f 6853 6857 685b 685f 6863
6867 686b 686f 6873 6877 687b 687f 6883
6887 688b 688f 6893 6897 689b 689f 68a3
68a7 68ab 68af 68b3 68b7 68bb 68bf 68c3
68c7 68cb 68cf 68d3 68d7 68db 68df 68e3
68e7 68eb 68ef 68f3 68f7 68fb 68ff 6903
6907 690b 690f 6913 6917 691b 691f 6923
6927 692b 692f 6933 6937 693b 693f 6943
6947 694b 694f 6953 6957 695b 695f 6963
6967 696b 696f 6973 6977 697b 697f 6983
6987 698b 698f 6993 6997 699b 699f 69a3
69a7 69ab 69af 69b3 69b7 69bb 69bf 69c3
69c7 69cb 69cf 69d3 69d7 69db 69df 69e3
69e7 69eb 69ef 69f3 69f7 69fb 69ff 6a03
6a07 6a0b 6a0f 6a13 6a17 6a1b 6a1f 6a23
6a2f 6a34 6a38 6a3c 6a40 6a43 6a47 6a4b
6a4e 6a51 6a56 6a59 6a5c 6a5f 6a60 6a65
6a66 1 6a68 6a6d 6a71 6a75 6a78 6a7d
6a82 6a85 6a89 6a8a 6a8f 6a90 6a95 6a97
6a9b 6a9e 6aa2 6aa6 6aaa 6aae 6ab0 6ab4
6ab8 6abc 6abf 6ac0 6ac2 6ac5 6ac8 6ac9
6ace 6ad2 6ad6 6adb 6ae0 6ae4 6ae8 6aec
6aef 6af2 6af6 6afa 6afe 6b02 6b06 6b0a
6b0e 6b12 6b16 6b1a 6b1e 6b22 6b26 6b2a
6b2e 6b32 6b36 6b42 6b46 6b4b 6b4f 6b52
6b53 6b58 6b5c 6b60 6b63 6b66 6b6a 6b6c
6b70 6b74 6b77 6b7a 6b7e 6b80 6b84 6b88
6b8b 6b8d 6b91 6b95 6b99 6b9c 6ba0 6ba4
6ba6 6ba7 6bac 1 6bb0 6bb4 6bb8 6bbb
6bbf 6bc3 6bc7 6bcb 6bce 6bd2 6bd6 6bd9
6bdc 6be1 6be4 6be7 6bea 6beb 6bf0 6bf1
1 6bf3 6bf8 6bfc 6c00 6c03 6c08 6c0d
6c10 6c14 6c15 6c1a 6c1d 6c22 6c23 6c28
6c2b 6c30 6c31 6c36 6c39 6c3d 6c3e 6c43
6c46 6c4b 6c4c 6c51 6c54 6c58 6c5c 6c5f
6c62 6c63 6c65 6c66 6c6b 6c6c 6c71 6c73
6c77 6c7a 6c7c 6c80 6c82 6c8e 6c90 6c92
6c93 6c98 6c9c 6c9e 6caa 6cac 6cb0 6cb4
6cb9 6cbe 6cc2 6cc6 6cca 6ccd 6cd0 6cd4
6cd8 6cdc 6ce0 6ce4 6ce8 6cec 6cf0 6cf4
6cf8 6cfc 6d00 6d04 6d08 6d0c 6d18 6d1c
6d21 6d25 6d28 6d29 6d2e 6d32 6d36 6d39
6d3c 6d40 6d42 6d46 6d4a 6d4d 6d50 6d54
6d56 6d5a 6d5e 6d61 6d63 6d67 6d6b 6d6f
6d72 6d76 6d7a 6d7c 6d7d 6d82 1 6d86
6d8a 6d8e 6d91 6d95 6d99 6d9d 6da1 6da4
6da8 6dac 6daf 6db2 6db7 6dba 6dbd 6dc0
6dc1 6dc6 6dc7 1 6dc9 6dce 6dd2 6dd6
6dd9 6dde 6de3 6de6 6dea 6deb 6df0 6df3
6df8 6df9 6dfe 6e01 6e06 6e07 6e0c 6e0f
6e13 6e14 6e19 6e1c 6e21 6e22 6e27 6e2a
6e2e 6e32 6e35 6e38 6e39 6e3b 6e3c 6e41
6e42 6e47 6e49 6e4d 6e50 6e52 6e56 6e58
6e64 6e66 6e68 6e69 6e6e 6e72 6e74 6e80
6e82 6e86 6e8a 6e8f 6e94 6e98 6e9c 6ea0
6ea3 6ea6 6eaa 6eae 6eb2 6eb6 6eba 6ebe
6ec2 6ec6 6eca 6ece 6ed2 6ed6 6eda 6ede
6ee2 6ee6 6eea 6eee 6ef2 6ef6 6efa 6efe
6f02 6f06 6f0a 6f0e 6f12 6f16 6f1a 6f1e
6f22 6f26 6f2a 6f2e 6f32 6f36 6f3a 6f3e
6f42 6f4e 6f52 6f57 6f5b 6f5e 6f5f 6f64
6f68 6f6c 6f6f 6f72 6f76 6f78 6f7c 6f80
6f83 6f86 6f8a 6f8c 6f90 6f94 6f97 6f99
6f9d 6fa1 6fa5 6fa8 6fac 6fb0 6fb2 6fb3
6fb8 1 6fbc 6fc0 6fc4 6fc7 6fcb 6fcf
6fd3 6fd7 6fda 6fde 6fe2 6fe5 6fe8 6fed
6ff0 6ff3 6ff6 6ff7 6ffc 6ffd 1 6fff
7004 7008 700c 700f 7014 7019 701c 7020
7021 7026 7029 702e 702f 7034 7037 703c
703d 7042 7045 7049 704a 704f 7052 7057
7058 705d 7060 7064 7068 706b 706e 706f
7071 7072 7077 7078 707d 707f 7083 7086
7088 708c 708e 709a 709c 709e 709f 70a4
70a8 70aa 70b6 70b8 70bc 70c0 70c4 70c8
70cc 70d0 70d4 70d8 70dc 70e0 70e4 70e8
70ec 70f0 70f4 70f8 70fc 7100 7104 7108
710c 7110 7114 7118 711c 7120 7124 7128
712c 7130 7134 7138 713c 7140 7144 7148
714c 7150 7154 7158 715c 7160 7164 7168
716c 7170 7174 7178 717c 7180 7184 7188
718c 7190 7194 7198 719c 71a0 71a4 71a8
71ac 71b0 71b4 71b8 71bc 71c0 71c4 71c8
71cc 71d0 71d4 71d8 71dc 71e0 71e4 71e8
71ec 71f0 71f4 71f8 71fc 7200 7204 7208
720c 7210 7214 7218 721c 7220 7224 7228
722c 7230 7234 7238 723c 7240 7244 7248
724c 7250 7254 7258 725c 7260 7264 7268
7274 7279 727d 7281 7285 7288 728c 7290
7293 7296 729b 729e 72a1 72a4 72a5 72aa
72ab 1 72ad 72b2 72b6 72ba 72bd 72c2
72c7 72ca 72ce 72cf 72d4 72d5 72da 72dc
72e0 72e3 72e7 72eb 72ef 72f3 72f5 72f9
72fd 7301 7304 7305 7307 730a 730d 730e
7313 7317 731b 731f 7322 7327 7328 732d
7330 7333 7334 7336 733a 733e 7342 7346
734a 734e 7352 7356 735a 735e 7362 7366
736a 736e 7372 7376 737a 737e 7382 7386
738a 738e 7392 7396 739a 739e 73a2 73ae
73b3 73b7 73bb 73bf 73c2 73c6 73ca 73cd
73d0 73d5 73d8 73db 73de 73df 73e4 73e5
1 73e7 73ec 73f0 73f4 73f7 73fc 7401
7404 7408 7409 740e 740f 7414 7416 741a
741d 7421 7425 7429 742d 742f 7433 7437
743b 743e 743f 7441 7445 7448 744c 744f
7450 7455 7458 745c 7460 7463 7464 7466
746a 746d 7471 7474 7475 747a 1 747d
7482 7486 748a 748e 7492 7496 749a 749e
74a2 74a6 74aa 74ae 74b2 74b6 74ba 74be
74c2 74c6 74ca 74ce 74d2 74d6 74da 74de
74e2 74e6 74ea 74f6 74fb 74ff 7503 7507
750a 750e 7512 7515 7518 751d 7520 7523
7526 7527 752c 752d 1 752f 7534 7538
753c 753f 7544 7549 754c 7550 7551 7556
7557 755c 755e 7562 7565 7569 756d 7571
7573 7577 757b 757f 7582 7586 758a 758d
7590 7595 7598 759b 759e 759f 75a4 75a5
1 75a7 75ac 75b0 75b4 75b7 75bc 75c1
75c4 75c8 75c9 75ce 75d1 75d6 75d7 75dc
75df 75e4 75e5 75ea 75ed 75f1 75f5 75f9
75fd 7600 7601 7603 7608 7609 760b 760c
7611 7614 7619 761a 761f 7622 7627 7628
762d 7630 7634 7635 763a 763d 7642 7643
7648 7649 764e 7650 7654 7657 765b 765f
7662 7666 766a 766d 7671 7675 7676 767b
767d 7681 7685 7688 768a 768e 7692 7695
7699 769d 76a0 76a4 76a8 76ab 76ae 76b3
76b6 76b9 76bc 76bd 76c2 76c3 1 76c5
76ca 76ce 76d2 76d5 76da 76df 76e2 76e6
76e7 76ec 76ed 76f2 76f6 76fa 76fd 7702
7707 770a 770e 7712 7715 7716 771b 771e
7723 7724 7729 772c 7730 7734 7737 7738
773d 773e 7743 7745 7749 774c 7750 7754
7758 775c 7760 7764 7768 776c 7770 777c
7781 7785 7789 778d 7791 7793 7794 7799
1 779d 77a1 77a5 77a8 77ac 77b0 77b4
77b8 77bb 77bf 77c3 77c6 77c9 77ce 77d1
77d4 77d7 77d8 77dd 77de 1 77e0 77e5
77e9 77ed 77f0 77f5 77fa 77fd 7801 7802
7807 7808 780d 7811 7815 7818 781d 7822
7825 7829 782a 782f 7832 7837 7838 783d
7840 7844 7848 784b 784e 784f 7851 7852
7857 7858 785d 785f 7863 7866 786a 786e
7872 7876 787a 787e 7882 788e 7893 7897
789b 789f 78a3 78a5 78a9 78ab 78b7 78b9
78bb 78bc 78c1 78c5 78c7 78d3 78d7 78d9
78da 78e3 
2082
2
0 1 a 6 9 :3 6 11 :3 6
10 :2 6 1 3 a 13 a :2 1
4 b 14 13 :2 b :2 4 9 12
11 :2 9 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 9 12 11
:2 9 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 14
23 14 :2 4 :2 12 21 12 4 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e :2 7
e 17 :3 e :2 7 f 18 :3 f :2 7
13 1c :3 13 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 54 5a
5d :2 54 6b 81 8 :2 6b d 10
:2 6b 13 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 34 :2 16 :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b 30 33 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :2 7 52 :2 4 :4 8 7
a :2 14 26 :2 30 3c 40 50 52
53 :2 50 :2 26 :3 a :2 10 15 21 60
63 :2 21 70 73 :2 21 77 7a :2 21
84 87 90 98 :2 a1 :2 90 b2 :2 87
:2 21 ba bd :2 21 c5 c8 :2 21 cd
d0 :2 21 d3 d6 :2 21 :2 a 56 :2 7
a :2 14 26 :2 30 3c 3f 4f 51
52 :2 4f :2 26 :3 a :2 10 15 21 60
63 :2 21 :2 a 55 :3 7 :2 12 26 :2 2f
3f 43 :2 7 14 :3 4 c :2 4 11
:2 4 12 4 8 11 1c :2 8 1f
21 :2 1f 7 28 31 3c :2 28 3f
41 :2 3f 27 :2 7 11 13 1f 21
2a 33 35 4b 4d f 1d 28
33 f 17 1a 22 2a 2c 39
42 44 51 53 :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 44 b :2 14 1f 1d :2 28 :2 1d
a 14 16 22 24 2d 36 38
12 20 2b 12 1a 1d 25 2d
2f 3c 45 47 54 56 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 38 e :2 17 22 20
:2 2b :2 20 d 20 2f 3f 4c :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5c 5f
60 :2 5c :2 32 :3 16 :2 1c 21 2d 6d
70 :2 2d 7d 80 :2 2d 84 87 :2 2d
93 96 :2 2d 9e a1 :2 2d ad b0
b7 c0 c3 :2 b0 :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 3b 11 :2 1a 25
23 :2 2e :2 23 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 8e 91 9a a2
:2 ab :2 9a bc :2 91 :2 2a c4 c7 :2 2a
cf d2 :2 2a d7 da :2 2a df e2
:2 2a :2 13 60 :2 10 13 :2 1d 2f :2 39
45 48 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a :2 13 5f
:3 10 :2 1b 2f :2 38 48 4e :2 10 3e
:2 d 3b :2 a 38 :2 7 4 44 a
13 1e :2 a 21 23 :2 21 11 21
f 26 3a :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 77 7a
:2 27 7e 81 :2 27 8d 90 :2 27 98
9b :2 27 a7 aa b1 ba bd :2 aa
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 26 b :2 14 1f 1d :2 28 :2 1d a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 64
67 :2 24 74 77 :2 24 7b 7e :2 24
88 8b 94 9c :2 a5 :2 94 b6 :2 8b
:2 24 be c1 :2 24 c9 cc :2 24 d1
d4 :2 24 d7 da :2 24 :2 d 5a :2 a
d :2 17 29 :2 33 3f 42 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 64
67 :2 24 :2 d 59 :3 a :2 15 29 :2 32
42 46 :2 a 38 :2 7 11 1a 30
41 4c f 1d 2a :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 26 4 26 44 a 13
1e :2 a 21 23 :2 21 11 1b 27
37 44 :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 26
b :2 14 1f 1d :2 28 :2 1d a d
:2 17 29 :2 33 3f 43 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 64 67
:2 24 74 77 :2 24 7b 7e :2 24 88
8b 94 9c :2 a5 :2 94 b6 :2 8b :2 24
be c1 :2 24 c9 cc :2 24 d1 d4
:2 24 d7 da :2 24 :2 d 5a :2 a d
:2 17 29 :2 33 3f 42 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 64 67
:2 24 :2 d 59 :3 a :2 15 29 :2 32 42
46 :2 a 38 :3 7 14 7 4 26
44 b 14 1f :2 b 25 22 :2 2e
:2 22 a 48 51 5c :2 48 5f 62
:2 5f 47 :2 a 16 1f 2a :2 16 30
2d :2 39 :2 2d 15 :2 a 5b 11 1c
:2 5b 22 1f :2 2b :2 1f 5a :2 a 11
1a 30 41 4c f 1d 2a :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 49 b :2 14 1f
1d :2 28 :2 1d a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 64 67 :2 24 74 77
:2 24 7b 7e :2 24 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 24 be c1 :2 24
c9 cc :2 24 d1 d4 :2 24 d7 da
:2 24 :2 d 5a :2 a d :2 17 29 :2 33
3f 42 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 64 67 :2 24 :2 d 59
:3 a :2 15 29 :2 32 42 46 :2 a 38
:2 7 49 44 :2 4 7 10 1b :2 7
1e 20 :2 1e 7 f 19 :3 7 :2 10
1c 7 16 :8 a c a c a
c a c a c a c a
c f 24 26 2b 3c 41 43
4f 51 10 1d 26 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 22 7 f
19 :3 7 :2 10 1c 7 16 29 1a
f 10 1d 26 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 22 7 c 3d
4e 57 5a 65 6e 71 7f 83
a8 7 b 18 1a 27 35 37
43 45 55 57 60 62 72 7
b 21 25 3a 3e 4d 51 67
71 74 81 84 91 94 a1 a4
b8 c9 c 22 26 2b 35 3a
3e 4a 4c 7 c 1d 22 24
2f 33 7 c 1d 22 24 2f
31 7 c 12 17 1d 23 26
2e 32 14 1d 21 2f 3c 3e
4e 61 73 7 9 12 14 24
7 9 1f 21 35 37 45 47
5d 7 a 17 1a 27 2a 37
3a 4d 5e c 1e 23 28 31
36 3a 45 47 7 c 12 17
28 2d 2f 37 39 7 c 12
17 28 2d 2f 3a 3c 7 c
12 17 1d 23 26 2e 30 14
1d 21 2f 3b 3d 4d 5f 70
7 9 12 14 24 7 9 1f
21 36 38 47 49 5f 7 a
17 1a 27 2a 37 3a 4e 5f
c 1e 22 27 30 35 39 44
46 7 c 23 28 2a 35 37
7 c 12 17 28 2d 2f 38
3a 7 c 12 17 28 2d 2f
3a 3c 7 c 12 17 1d 23
26 2e 30 14 1d 21 2f 3b
3d 4d 5f 70 7 9 12 14
24 7 9 1f 21 36 38 47
49 5f 7 a 17 1a 27 2a
37 3a 4e 5f c 1e 22 27
30 35 39 44 46 7 c 22
27 29 34 36 7 c 12 17
28 2d 2f 37 39 7 c 12
17 28 2d 2f 3a 3c 7 c
12 17 1d 23 26 2e 30 10
1a 27 17 7 17 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 61 64 :2 21 :2 a
56 :3 7 e 7 4 22 b 14
1f :2 b 22 24 :2 22 a 2b 34
3f :2 2b 42 44 :2 42 2a :2 a 7
f 19 :3 7 :2 10 1c 7 16 28
35 a d 14 17 49 f 24
27 2c 32 37 48 4e 51 5c
65 68 76 79 10 13 1e 27
2a 40 43 23 34 3c 3f 4d
4f 5f 61 69 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 47 7 :2 10 :3 1c
7 16 2a 35 1a 1c 28 2a
f 24 26 2b 34 39 3b 51
53 5e 60 a f 20 25 27
32 34 a f 20 25 27 32
34 a f 20 25 27 39 3b
51 53 10 12 1d 26 28 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 47
7 c 1e 20 2f 40 53 55
62 6f 71 79 7b 7 2e 3d
64 78 7 2e 3a 61 73 7e
8d 94 a1 b6 c7 c 1b 2e
49 5e 6f c 1d 1f 24 2e
33 35 41 43 e 1f 32 45
53 7 2e 3d 64 78 7 2e
3a 61 73 7e 8d 94 a1 d
1f 30 3f 52 6d 82 93 c
10 17 7 17 a :2 14 26 :2 30
3c 3f 4f 52 53 :2 4f :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 56
:3 7 e 7 4 47 22 a 13
1e :2 a 21 23 :2 21 7 c 28
2a 4d 4f 66 68 81 7 9
15 17 27 3a 42 44 57 59
66 68 76 78 7 9 16 18
21 23 2d 3a 4a 4c 5b 5d
6a 6c 7c 7 10 12 22 24
34 45 48 58 6b 6d 7a 7c
89 8b 98 9a ad bb bd c8
ca 7 9 1f 21 2e 31 41
4c 4e 56 58 62 64 6c 6e
79 7b 89 8b 99 7 9 c
21 23 28 2e 33 44 49 4b
55 5e 60 74 76 7 c 12
17 20 25 27 35 37 42 47
4d 52 66 6b 6d 79 7b 7
c 12 17 2b 31 3a 3c 4c
4e 5b 5e 7 c 12 17 25
2b 2e 3a 3c d f 1c 25
27 42 17 7 17 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 61 64 :2 21 :2 a
56 :3 7 e 7 4 25 22 a
13 1e :2 a 21 23 :2 21 a 11
1a 25 :2 11 :2 a 29 2c :2 29 a
15 a 14 22 2f 46 53 64
6e :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 2e d
16 1f :2 d 22 24 :2 22 d 1b
d 26 d 18 d 17 27 34
20 37 44 55 5f 68 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5c 5f 60
:2 5c :2 32 :3 16 :2 1c 21 2d 6d 70
:2 2d 7d 80 :2 2d 84 87 :2 2d 93
96 :2 2d 9e a1 :2 2d ad b0 b7
c0 c3 :2 b0 :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 a 10 19 22 :2 10
25 27 :2 25 1a 2a 37 23 34
37 3c 56 16 1a 27 2a 39
3d 4b 4e 19 1c 29 3a 3d
47 14 1c 23 26 49 4d :2 13
:2 1c 28 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5f 62
63 :2 5f :2 35 :3 19 :2 1f 24 30 70
73 :2 30 80 83 :2 30 87 8a :2 30
96 99 :2 30 a1 a4 :2 30 b0 b3
ba c3 c6 :2 b3 :2 30 :2 19 66 :2 16
:2 13 :4 1f :2 13 10 :3 29 13 1c 25
:2 13 28 2a :2 28 13 21 13 2c
13 21 13 :4 10 29 10 1e 10
:4 d :5 a f 21 23 2f 31 3e
40 4e 50 5f 72 74 81 83
8c 8e a c 10 12 16 18
24 33 35 42 a c 1b 1d
2f 3d 3f 4e 50 61 63 72
c 1b 1d 14 16 32 39 43
45 52 5c 5e 6d 6f 8e a
31 3e 65 78 a c 1b 1d
2d 2f 34 36 43 45 a c
1b 22 24 34 36 47 49 5c
a 17 2c 41 54 10 27 42
57 6c 81 10 1e 20 33 42
4f 5d 5f 6f 71 82 84 98
10 2c 40 55 62 71 7e 8e
a1 b4 c3 f 21 2f 3e 4f
51 5f 61 14 2b 2d 3e 69
14 2b 2d 3f 6a 14 2b 2d
4a 58 5a 6a 81 90 10 28
42 5d 7b 10 23 38 f 17
19 1e 23 38 3d 3f 4c 4e
5d 5f 6d a f 15 1a 2e
33 35 41 43 10 12 1f 30
32 3f 1b 1d 40 42 59 5b
74 80 82 14 16 35 37 49
52 5a 5c 6a 6c 17 19 28
32 3a 3c 4a 4c 60 14 16
35 37 69 a c 1f 21 2e
30 3a 43 52 63 14 16 1b
24 2e 30 35 3e 49 52 5d
5f 69 77 79 7e 87 92 9b
a6 a8 b2 a 13 21 31 40
49 58 69 14 16 2a 2c 3c
3e 52 14 16 2a 2c 39 3b
4c 4e 62 14 16 25 27 36
38 4a 4c 5d f 14 16 32
39 43 45 52 5c 69 84 a
c 19 1b 29 2b a c 1b
1d 2d 2f 34 36 43 45 a
c 1b 22 32 43 a 17 27
29 38 3a 47 49 59 a 13
15 25 27 37 48 4b 5b 6e
70 7d 7f 8c 8e 9b 9d 14
16 35 37 4a 54 5c 5e 6c
6e 19 27 29 34 36 44 46
56 58 69 6b a c 22 24
32 35 45 55 57 5f 61 6b
6d 75 77 82 84 92 94 a2
a4 ae b0 a c 28 2a 48
4a 72 7c 7e 94 14 16 2a
2c 40 42 5a 14 2b 34 36
42 44 5b 86 14 2b 34 36
43 45 5d 88 14 35 37 4d
4f 58 5a 79 87 89 9e b5
c4 a c a d 1d a c
a d 1d 34 36 a c 19
1d 2d 14 16 36 38 49 53
5b 5d 6b 6d 89 f 24 26
2b 31 36 47 4c 4e 62 64
a f 15 1a 2e 33 35 41
43 a f 15 1a 2e 34 3d
3f 4f 51 5e 61 a f 15
1a 28 2e 31 3d 3f a f
15 1a 2a 30 33 40 42 a
f 15 1a 2a 30 33 40 42
a f 15 1a 28 2f 33 40
42 10 12 1f 30 32 3f 48
4a 13 1b 1a a 1a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a 11 a 2e a f
2b 2d 50 52 69 6b 84 8f
91 14 16 35 37 46 50 58
5a 68 6a f 11 30 32 44
4d 55 57 65 67 f 11 30
32 44 4e 56 58 66 68 17
19 2b 3d 45 47 55 57 6a
14 16 2d 36 f 11 28 31
f 11 28 31 f 11 39 42
55 a c 1f 21 2e 30 39
3b a c 10 12 16 1f 2d
3d 4c 55 64 75 a c 14
2c 2e 42 44 54 56 6a a
c 19 28 2a 42 a c 19
1b 29 2b a c 1b 1d 2d
2f 34 36 43 45 a c 1b
22 32 43 a 17 27 29 38
3a 47 49 59 a 13 15 25
27 37 48 4b 5b 6e 70 7d
7f 8c 8e 9b 9d 14 16 35
37 4a 54 5c 5e 6c 6e 19
27 29 34 36 44 46 56 58
69 6b a c 22 24 32 35
45 55 57 5f 61 6b 6d 75
77 82 84 92 94 a2 a4 ae
b0 a c 28 2a 48 4a 72
7c 7e 94 a7 a c 19 1b
29 2b 39 3b 50 67 14 16
38 3a 52 54 6b 6d 7c 7e
92 94 a4 a6 d2 a c a
d 1d a c a d 1d 34
36 a c 19 1d 2d 14 16
36 38 49 53 5b 5d 6b 6d
89 f 24 26 2b 31 36 47
4c 4e 62 64 a f 15 1a
2e 33 35 41 43 a f 15
1a 2e 34 3d 3f 4f 51 5e
61 a f 15 1a 28 2e 31
3d 3f a f 15 1a 2a 30
33 40 42 a f 15 1a 2a
30 33 40 42 a f 15 1a
28 2f 33 40 42 10 12 32
34 41 13 1c 1a a 1a d
:2 17 29 :2 33 3f 42 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 64 67
:2 24 :2 d 59 :3 a 11 a :4 7 4
25 22 a 13 1e :2 a 21 23
:2 21 7 f 19 :3 7 :2 10 1c 7
16 :c a e 20 a e 21 a
e 1f a e 1e a e 1f
a e 1d a e 16 f 26
31 3a 61 6e a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 25 7 :2 10 :3 1c
7 16 2a 35 43 52 62 71
7d a 10 1a 1c 27 29 a
c 1b 1d 2c 2e 3e 40 4c
4e 5b 5d 63 65 f 1f 21
26 2f 34 36 4c 4e 59 5b
67 6c 7d 82 84 8f 91 a
f 20 25 27 32 34 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 25 7
c 1e 20 2f 40 53 55 62
75 7d 7f 7 9 18 1a 29
2b 3b 3d 49 4b 58 5a 60
62 71 78 85 d 1e 30 3f
52 6d 7b 7d 92 a3 c 1c
1e 23 2d 32 34 4c 4e 5a
5c e 1f 32 45 53 7 16
25 37 43 50 56 65 6c 79
d 1f 30 3f 52 6d 81 96
a7 c 29 17 7 17 a :2 14
26 :2 30 3c 3f 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 61 64 :2 21
:2 a 56 :3 7 e 7 4 25 22
a 13 1e :2 a 21 23 :2 21 7
f 19 :3 7 :2 10 1c 7 16 :c a
e 20 a e 21 a e 1f
a e 1e a e 1f a e
1d a e 16 f 26 31 3a
61 6e a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 25 7 :2 10 :3 1c 7 16
2a 35 43 52 5b 6b 7a 8a
99 a5 a 10 1b 1a 1c 28
2a a c 1b 1d 2c 2e 3e
40 4c 4e 5b 5d 63 65 f
1f 21 26 2f 34 36 4c 4e
59 5b 67 6c 7d 82 84 8f
91 a f 20 25 27 32 34
1a 1d 2a 2c 40 42 a 30
a 30 5d 5f f 24 28 32
10 13 1e 27 2a 38 3a 20
23 3a 4b 10 13 30 32 f
24 2c 2e 3b 3e 4d 4f 5d
60 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 25 7 c 1e 20 2f 40
53 55 62 75 7d 7f 7 9
18 1a 29 2b 3b 3d 49 4b
58 5a 60 62 71 78 85 d
1e 30 3f 52 6d 7b 7d 92
a3 c 1c 1e 23 2d 32 34
4c 4e 5a 5c e 1f 32 3f
47 7 16 25 37 43 50 56
65 6c 79 d 1f 30 3f 52
6d 7c 91 a2 c 26 3c e
1f 32 3f 47 7 16 25 7
13 20 26 35 3c 49 5e 6f
c 1b 2e 49 57 6c 7d c
d 25 10 1e 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 56 :3 7 e 7 4 25
22 a 13 1e :2 a 21 23 :2 21
7 c 1e 20 2f 3b 3d 50
52 5f 73 7b 7d 7 9 18
1a 2a 2c 34 44 46 56 69
6b 7b 87 89 9a 7 9 11
17 19 27 32 3f 54 66 c
1a 2d 4a 59 66 74 76 8b
9c 7 a 18 1b 29 2c 3a
3d 4b 4e 7 a 1f 22 38
3b 4e 51 7 a 25 28 44
47 7 a 25 28 44 47 63
65 c 21 23 28 3c 42 45
52 5b 5e 6c 6e 7 c 11
22 27 29 3b 3d 53 55 7
c 11 22 27 29 3b 3d 53
55 7 c 16 1b 1d 29 2b
d f 1a 23 25 3c 3e 5f
61 e 10 1f 2b 2d 40 42
52 66 74 7 9 18 1a 29
2b 33 42 44 54 66 8d 99
c0 c 16 20 2d 42 54 c
1b 2e 43 45 59 6e 7f 7
a 18 1b 29 2c 3a 3d 4b
4e 7 a 1f 22 38 3b 4e
51 7 a 25 28 44 47 7
a 25 28 44 47 69 c 21
23 28 31 36 38 44 46 7
c 1d 22 24 36 38 7 c
20 26 29 36 3f 42 50 52
d f 1a 23 25 10 1e 17
7 17 a :2 14 26 :2 30 3c 3f
4f 52 53 :2 4f :2 26 :3 a :2 10 15
21 61 64 :2 21 :2 a 56 :3 7 e
7 4 25 22 a 13 1e :2 a
21 23 :2 21 7 f 19 :3 7 :2 10
1c 7 16 b :d a e 21 a
e 21 a e 21 a 18 2a
3e a e 21 a e 21 a
e 21 a 18 2a 3e f 10
1b 24 2c 13 20 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 77 7a :2 27 7e 81
:2 27 8d 90 :2 27 98 9b :2 27 a7
aa b1 ba bd :2 aa :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 25 7 f
19 :3 7 :2 10 1c 7 16 :20 a c
1e 20 36 38 4e 50 a c
1e 20 36 38 4e 50 a c
1e 20 36 38 4e 50 a c
1e 20 36 38 a c 21 23
39 3b 4e 50 a c 27 29
45 47 a c 27 29 45 47
a c 1e 20 36 38 4e 50
a 13 15 28 2a 37 39 60
62 f 23 25 2a 30 35 46
4b 4d 5b 5d 10 12 1d a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 25
11 22 29 3c 11 1e 2f 37
39 44 4d 4f 5d 60 70 72
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 5a 5b :2 56 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 25 7 c 1e 20 2f 40 53
55 62 70 72 7a 7c 7 9
18 1a 29 2b 3b 3d 49 4b
58 5a 60 62 71 78 85 d
1e 30 3f 52 6d 7b 7d 92
a3 11 13 34 36 57 59 74
8b 8d a0 a2 b6 b8 cb cd
de e0 f2 f4 7 f 7 9
1e 20 36 38 4b 4d 7 9
24 26 42 44 7 9 24 26
42 44 7 9 17 19 27 29
37 39 47 49 56 58 c 1d
1f 24 2e 33 35 4d 4f 5b
5d f 11 1f 30 43 45 55
68 76 7 9 18 1a 29 2b
3b 3d 49 4b 58 5a 60 62
71 78 85 d 1f 30 3f 52
6d 81 96 a7 11 13 34 36
57 59 74 8b 8d a0 a2 b6
b8 cb cd de e0 f2 f4 7
f 7 9 1e 20 36 38 4b
4d 7 9 24 26 42 44 7
9 24 26 42 44 7 9 17
19 27 29 37 39 47 49 5c
c 1d 1f 24 2d 32 34 4a
4c 57 59 7 c 1d 22 24
2f 31 7 c 1d 22 24 2f
31 17 7 17 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 25 22 a 13
1e :2 a 23 21 :2 2c :2 21 11 23
2d 3c 49 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 5a 5b :2 56 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 40 b :2 14 1f 1d :2 28 :2 1d :2 a
f 21 29 35 3d 50 5e 69
6b 74 7c a 12 16 26 30
38 3c 4c 56 5f 64 74 f
18 a f 14 26 2d 31 3f
a f 14 24 2d 31 3f a
f 14 1e 2d 32 3f 10 12
1f 11 19 25 2d 40 48 4b
56 a d 1b 24 2f 3c 47
54 5a 5d 73 79 7c 8e d
1b 28 36 43 52 f 25 27
2c 32 37 48 4e 50 58 5b
a f 15 1a 2b 31 34 3f
42 52 54 66 11 19 25 2d
40 48 4b 56 a d 1b 24
2f 3c 47 54 5a 5d 73 79
7c 8e d 1b 28 36 43 52
f 26 28 2d 33 38 49 4f
51 5a 5d a f 15 1a 2b
31 34 3f 42 52 54 66 13
1e 1a a 1a d :2 17 29 :2 33
3f 42 52 56 57 :2 52 :2 29 :3 d
:2 13 18 24 65 68 :2 24 :2 d 5a
:3 a 11 a 38 :2 7 4 40 22
a 13 1e :2 a 21 23 :2 21 7
c 28 2a 4d 4f 66 68 81
8d 8f 11 13 32 34 46 4f
57 59 67 69 14 16 25 2f
37 39 47 49 5d 11 13 3b
3d 66 7 9 1c 1e 2b 2d
37 40 4f 60 7 9 d f
13 1c 2a 3a 49 52 61 72
11 25 35 49 11 25 32 43
57 11 13 22 24 33 35 47
49 5a c 11 13 2f 36 40
42 4f 59 66 81 7 9 16
18 26 28 7 9 18 1a 2a
2c 31 33 40 42 7 9 18
1f 2f 40 7 14 24 26 35
37 44 46 56 7 10 12 22
24 34 45 48 58 6b 6d 7a
7c 89 8b 98 9a 11 13 32
34 47 51 59 5b 69 6b 16
24 26 31 33 41 43 53 55
66 68 7 9 1f 21 2f 32
42 52 54 5c 5e 68 6a 72
74 7f 81 8f 91 9f a1 ab
ad 7 9 25 27 45 47 6f
79 7b 91 11 25 39 51 11
28 31 33 3f 41 58 83 11
28 31 33 40 42 5a 85 11
32 34 4a 4c 55 57 76 84
86 9b b2 11 13 35 37 4f
51 68 6a 79 7b 8f 91 a1
a3 cf 7 9 7 a 1a 7
9 7 a 1a 31 33 7 9
16 1a 2a c 21 23 28 39
3e 40 54 5d 5f 73 75 7
c 12 17 2b 30 32 3e 40
7 c 12 17 2b 31 3a 3c
4c 4e 5b 5e 7 c 12 17
25 2b 2e 3a 3c 7 c 12
17 27 2d 30 3d 3f 7 c
12 17 27 2d 30 3d 3f 7
c 12 17 25 2c 30 3d 3f
10 1e 17 7 17 a :2 14 26
:2 30 3c 3f 4f 53 54 :2 4f :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
57 :3 7 e 7 4 26 22 a
13 1e :2 a 21 23 :2 21 7 c
1e 20 35 41 43 11 13 32
34 43 4d 55 57 65 67 c
e 2d 2f 41 4b 53 55 63
65 14 16 28 3a 42 44 52
54 67 11 13 2a 33 c e
25 2e 17 7 9 1c 1e 2b
52 61 88 c 19 40 49 70
7 2e 3a 61 74 7 2e 3b
62 76 7 2e 3d 64 79 7
2e 3b 62 c 13 20 30 32
41 68 7 9 16 18 28 37
40 42 52 54 64 75 78 88
c 1e 30 43 11 13 32 34
47 51 59 5b 69 6b 16 7
9 1a 7 2e 3e 65 7b d
2a 3e 53 c 1b 28 38 4b
5e :2 c 21 7 c 12 17 2b
30 32 3e 40 7 c 12 17
2b 31 3a 3c 4c 4e 5b 5e
d f 2f 31 3e 10 1e 17
7 17 a :2 14 26 :2 30 3c 3f
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 57 :3 7 e
7 4 26 22 a 13 1e :2 a
21 23 :2 21 7 f 19 :3 7 :2 10
1c 7 16 23 30 3f 11 1e
34 f 10 1d :2 a 17 20 13
20 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 5a 5b :2 56 :2 2c
:3 10 :2 16 1b 27 68 6b :2 27 78
7b :2 27 7f 82 :2 27 8e 91 :2 27
99 9c :2 27 a8 ab b2 bb be
:2 ab :2 27 :2 10 5e :2 d :2 a :4 16 :2 a
7 :3 26 7 f 19 :3 7 :2 10 1c
7 16 26 33 42 12 1f 35
f 10 1d a 14 13 20 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 5a 5b :2 56 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 26
7 f 19 :3 7 :2 10 1c 7 16
2d 3a 49 11 13 20 22 31
33 f 1b 1d 22 28 2d 3c
41 43 4f 51 11 13 20 22
31 33 f 1e 20 25 2b 30
3c 41 43 4f 51 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 56
5a 5b :2 56 :2 2c :3 10 :2 16 1b 27
68 6b :2 27 78 7b :2 27 7f 82
:2 27 8e 91 :2 27 99 9c :2 27 a8
ab b2 bb be :2 ab :2 27 :2 10 5e
:2 d :2 a :4 16 :2 a 7 :3 26 7 c
1e 20 2f 3b 3d 4a 5d 66
68 73 75 c 22 24 29 33
38 3a 52 54 60 62 7 c
12 17 26 2d 2f 3b 3f 17
19 27 33 35 45 58 68 73
75 c 22 24 29 32 37 39
51 53 60 62 7 c 1d 22
24 2f 31 7 c 1d 22 24
2f 31 7 c 12 17 26 2d
2f 3b 3f 17 1a 29 35 37
44 59 62 64 76 c 21 25
2f d 10 1b 7 a 18 1a
19 1c 2d 43 4c 4f 5d 60
10 1e 17 7 17 a :2 14 26
:2 30 3c 3f 4f 53 54 :2 4f :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
57 :3 7 e 7 4 26 22 a
13 1e :2 a 21 23 :2 21 7 11
18 1f 22 :2 18 28 2b :2 11 :2 7
c 1f 21 2d 2f 3c 4f 58
5a 6c c 16 18 1d 27 a
c 19 1b d f b d 17
10 18 7 18 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 26 22 b 14
1f :2 b 24 22 :2 2d :2 22 a 4e
11 1c :2 4e 21 1f :2 2a :2 1f 4d
:2 a 7 c 23 25 34 40 42
4f 5c 65 74 7d 7f 91 c
20 24 2e d 10 1d b e
1c 1e 10 1c 7 1c a :2 14
26 :2 30 3c 3f 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 57 :3 7 e 7 48 22 a
:2 14 26 :2 30 3c 3f 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 62 65
:2 21 72 75 :2 21 79 7c :2 21 86
89 92 9a :2 a3 :2 92 b4 :2 89 :2 21
bc bf :2 21 c7 ca :2 21 cf d2
:2 21 d5 d8 :2 21 :2 a 57 :3 7 :2 12
24 :2 2d 3d 41 :2 7 :4 4 1 9
12 9 a :2 14 26 :2 30 3c 40
50 54 55 :2 50 :2 26 :3 a :2 10 15
21 62 65 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 58 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4d 51 52 :2 4d :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 55 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
2082
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 16 :7 19 :7 1c :7 1f
:7 22 :7 25 :7 28 :7 2b
:7 2e :7 31 :7 34 :7 37
:7 3a :7 3d :7 40 :7 42
:b 44 :11 45 46 :2 45
:2 46 :2 45 :2 46 :2 45
:2 47 :2 45 :9 47 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :2 45 :2 48 :2 45
:2 48 :4 45 :3 44 :11 4b
:b 4c :3 4b :5 51 :11 52
:30 53 :3 52 :11 55 :b 56
:3 55 :a 58 :3 51 :3 5d
:3 5e :3 5f :16 62 :9 64
:4 65 :b 66 64 :5 67
63 69 :5 6a :3 69
:2 6b :5 6d :11 6e :24 6f
:3 6e :2 6c :6 6b 68
:3 62 :a 75 :7 77 :3 78
:b 79 77 :5 7a 76
7c :5 7d :3 7c :2 7e
:5 80 :11 81 :24 82 :3 81
:2 7f :6 7e 7b :3 75
:a 88 :5 8a :5 8b 89
8d :5 8e :3 8d :2 8f
:5 91 :11 92 :24 93 :3 92
:2 90 :6 8f 8c :3 88
:a 98 :11 99 :30 9a :3 99
:11 9c :b 9d :3 9c :a 9f
:3 98 :3 88 :3 75 a3
62 :9 a3 :2 a5 :3 a6
a5 :5 a7 a4 a9
:5 aa :3 a9 :2 ab :5 ad
:11 ae :24 af :3 ae :2 ac
:6 ab a8 :3 a3 :a b4
:11 b5 :30 b6 :3 b5 :11 b8
:b b9 :3 b8 :a bb :3 b4
:5 bf :3 c0 bf :5 c1
be c3 :5 c4 :3 c3
:2 c5 :5 c7 :11 c8 :24 c9
:3 c8 :2 c6 :6 c5 c2
:3 a3 cd a3 62
:9 cd :6 cf :5 d0 ce
d2 :5 d3 :3 d2 :2 d4
:5 d6 :11 d7 :24 d8 :3 d7
:2 d5 :6 d4 d1 :3 cd
:a dd :11 de :30 df :3 de
:11 e1 :b e2 :3 e1 :a e4
:3 dd :3 e7 e8 cd
62 :18 e8 :c e9 :2 e8
e9 :2 ea :2 e9 :6 ea
e9 :2 e8 :5 ec :3 ed
ec :5 ee eb f0
:5 f1 :3 f0 :2 f2 :5 f4
:11 f5 :24 f6 :3 f5 :2 f3
:6 f2 ef :3 ea :a fb
:11 fc :30 fd :3 fc :11 ff
:b 100 :3 ff :a 102 :3 fb
ea :3 62 :9 108 :5 10a
:5 10b 10e 110 111
112 113 114 115
116 :2 119 :2 11a :2 11b
:2 11c :2 11d :2 11e :2 11f
:9 120 :3 121 10e :6 122
:5 123 122 :5 125 124
:3 122 10d 128 :5 129
:3 128 :2 12a :5 12c :11 12d
:24 12e :3 12d :2 12b :6 12a
127 :3 108 :5 134 :5 135
:2 138 139 13a :3 13b
138 :6 13c :5 13d 13c
:5 13f 13e :3 13c 137
142 :5 143 :3 142 :2 144
:5 146 :11 147 :24 148 :3 147
:2 145 :6 144 141 :3 108
:c 14d :e 14e :13 14f :9 150
:7 151 :7 152 :9 153 :9 157
:5 158 :9 159 :a 15a :9 15b
:9 15c :9 15d :9 15e :9 162
:5 163 :9 164 :a 165 :9 166
:7 167 :9 168 :9 169 :9 16a
:9 16e :5 16f :9 170 :a 171
:9 172 :7 173 :9 174 :9 175
:9 176 :3 177 :3 14d :11 178
:b 179 :3 178 :3 17b 17c
108 :16 17c :5 17e :5 17f
:3 182 :2 184 :3 185 :e 186
:7 187 :9 188 182 :6 189
:5 18a 189 :5 18c 18b
:3 189 181 18f :5 190
:3 18f :2 191 :5 193 :11 194
:24 195 :3 194 :2 192 :6 191
18e :3 17c :7 19a :3 19d
:4 19e :b 19f :7 1a0 :7 1a1
:9 1a2 :5 1a3 19d :6 1a4
:5 1a5 1a4 :5 1a7 1a6
:3 1a4 19c 1aa :5 1ab
:3 1aa :2 1ac :5 1ae :11 1af
:24 1b0 :3 1af :2 1ad :6 1ac
1a9 :3 17c :d 1b5 :5 1b6
:b 1b7 :6 1b8 :9 1b9 :5 1bd
:5 1be :9 1bf :8 1c0 1c1
1c2 :3 1b5 :11 1c3 :b 1c4
:3 1c3 :3 1c6 1c7 17c
108 :9 1c7 :9 1c8 :e 1c9
:f 1ca :16 1cb :14 1cc :2 1cd
:e 1ce :12 1cf :c 1d0 :9 1d1
:6 1d2 :3 1c8 :11 1d3 :b 1d4
:3 1d3 :3 1d6 1d7 1c7
108 :9 1d7 :c 1d8 :3 1d9
:8 1db :5 1dc 1da 1de
:5 1df :3 1de :2 1e0 :5 1e2
:11 1e3 :24 1e4 :3 1e3 :2 1e1
:6 1e0 1dd :3 1d8 :9 1e9
:3 1ea 1e9 :3 1ec :3 1ee
:6 1ef 1ee :5 1f0 1ed
1f2 :5 1f3 :3 1f2 :2 1f4
:5 1f6 :11 1f7 :24 1f8 :3 1f7
:2 1f5 :6 1f4 1f1 :3 1eb
:9 1fd :3 1ff :5 200 :8 201
:6 202 :6 203 1ff :5 204
1fe 206 :5 207 :3 206
:2 208 :5 20a :11 20b :24 20c
:3 20b :2 209 :6 208 205
:3 1fd :9 211 :3 212 211
:3 214 213 :3 211 1fd
:3 217 216 :3 1fd 1eb
:3 1e9 :11 21f :a 220 :c 221
:3 222 :c 223 :5 224 :a 225
:a 226 :5 227 :6 228 :d 229
:b 22a :8 22b :5 22c :5 22d
:9 22e :5 22f :3 230 :d 231
:9 232 :6 233 :9 235 :a 236
:9 237 :5 238 :a 239 :16 23a
:8 23b :7 23c :9 23d :9 23e
23f :a 240 :6 241 :a 242
:6 243 :9 244 :11 245 :a 246
:b 247 :17 248 :a 249 :7 24a
:8 24b :8 24c :d 24d :2 24e
:3 24f :2 250 :5 251 :5 252
:b 253 :b 254 :9 255 :c 256
:9 257 :9 258 :9 259 :9 25a
:8 25b :2 25c :3 21f :11 25d
:b 25e :3 25d :3 260 1d8
:b 264 :a 265 :a 266 :a 267
:9 268 :4 269 :4 26a :4 26b
:5 26c :8 26d :c 26e :a 26f
:6 270 :6 271 :a 272 :6 273
:9 274 :11 275 :a 276 :b 277
:17 278 :b 279 :a 27a :f 27b
:2 27c :3 27d :2 27e :5 27f
:5 280 :b 281 :b 282 :9 283
:c 284 :9 285 :9 286 :9 287
:9 288 :5 289 :2 28a :3 264
:11 28b :b 28c :3 28b :3 28e
261 :3 1d8 290 1d7
108 :9 290 :5 292 :5 293
296 298 299 29a
29b 29c 29d 29e
29f 2a0 2a3 2a4
:3 2a5 :3 2a6 :3 2a7 :3 2a8
:3 2a9 :3 2aa :3 2ab :6 2ac
296 :6 2ad :5 2ae 2ad
:5 2b0 2af :3 2ad 295
2b3 :5 2b4 :3 2b3 :2 2b5
:5 2b7 :11 2b8 :24 2b9 :3 2b8
:2 2b6 :6 2b5 2b2 :3 290
:7 2be :8 2c1 :2 2c2 :4 2c3
:e 2c4 :12 2c5 :7 2c6 2c1
:6 2c7 :5 2c8 2c7 :5 2ca
2c9 :3 2c7 2c0 2cd
:5 2ce :3 2cd :2 2cf :5 2d1
:11 2d2 :24 2d3 :3 2d2 :2 2d0
:6 2cf 2cc :3 290 :c 2d8
:11 2d9 :a 2da :b 2db :5 2df
:a 2e0 :9 2e1 :2 2e2 :3 2d8
:11 2e3 :b 2e4 :3 2e3 :3 2e6
2e7 290 108 :9 2e7
:5 2e9 :5 2ea 2ed 2ef
2f0 2f1 2f2 2f3
2f4 2f5 2f6 2f7
2fa 2fb :3 2fc :3 2fd
:3 2fe :3 2ff :3 300 :3 301
:3 302 :6 303 2ed :6 304
:5 305 304 :5 307 306
:3 304 2ec 30a :5 30b
:3 30a :2 30c :5 30e :11 30f
:24 310 :3 30f :2 30d :6 30c
309 :3 2e7 :7 315 :b 318
:3 319 :4 31a :e 31b :12 31d
:7 31e :6 320 :2 321 :4 322
:4 323 :7 324 :4 325 :4 326
:a 327 318 :6 328 :5 329
328 :5 32b 32a :3 328
317 32e :5 32f :3 32e
:2 330 :5 332 :11 333 :24 334
:3 333 :2 331 :6 330 32d
:3 2e7 :c 339 :11 33a :a 33b
:b 33c :5 33e :a 33f :9 340
:3 341 :5 343 :3 344 :9 345
:7 346 347 :2 348 :2 349
:3 339 :11 34a :b 34b :3 34a
:3 34d 390 2e7 108
:9 390 :d 391 :10 392 :a 393
:a 394 :a 395 :8 396 :6 397
:8 398 :c 399 :a 39a :a 39b
:7 39c :9 39d :a 39f :e 3a0
:6 3a1 :8 3a2 :a 3a3 :8 3a4
:6 3a5 :7 3a6 :9 3a7 :7 3a8
:a 3a9 :5 3aa :2 3ab :3 391
:11 3ac :b 3ad :3 3ac :3 3af
3b0 390 108 :9 3b0
:5 3b2 :5 3b3 3b6 3b7
3b8 3b9 3ba 3bb
3bc 3bd 3be 3bf
3c0 3c1 3c4 3c5
:3 3c6 :3 3c7 :3 3c8 :4 3c9
:3 3ca :3 3cb :3 3cc :4 3cd
3ce :4 3cf :2 3d0 3b6
:6 3d1 :5 3d2 3d1 :5 3d4
3d3 :3 3d1 3b5 3d7
:5 3d8 :3 3d7 :2 3d9 :5 3db
:11 3dc :24 3dd :3 3dc :2 3da
:6 3d9 3d6 :3 3b0 :5 3e4
:5 3e5 3e8 3ea 3eb
3ec 3ed 3ee 3ef
3f0 3f1 3f2 3f3
3f4 3f5 3f6 3f7
3f8 3f9 3fa 3fb
3fc 3fd 3fe 3ff
400 401 402 403
404 405 406 407
408 :8 40b :8 40c :8 40d
:6 40e :8 40f :6 410 :6 411
:8 412 :9 413 :b 414 :3 415
3e8 :6 416 :5 417 416
:5 419 418 :3 416 3e7
41c :5 41d :3 41c :2 41e
:5 420 :11 421 :24 422 :3 421
:2 41f :6 41e 41b :3 3b0
:4 429 :c 42a 429 :6 42b
:5 42c 42b :5 42e 42d
:3 42b 428 431 :5 432
:3 431 :2 433 :5 435 :11 436
:24 437 :3 436 :2 434 :6 433
430 :3 3b0 :d 43c :11 43d
:a 43e :13 43f :2 440 :8 441
:6 442 :6 443 :c 444 :b 445
:9 447 :11 448 :9 449 :13 44a
:2 44b :8 44c :6 44d :6 44e
:b 44f :b 450 :7 451 :7 452
:3 43c :11 453 :b 454 :3 453
:3 456 457 3b0 108
:b 457 :6 459 :5 45a 458
45c :5 45d :3 45c :2 45e
:5 460 :11 461 :24 462 :3 461
:2 45f :6 45e 45b :3 457
:a 467 :c 468 :c 469 :2 46a
:7 46b :7 46c :7 46d :3 46e
:8 470 :e 471 :6 472 :b 473
:c 474 :8 476 :e 477 :6 478
:b 479 :c 47a :2 47b :3 468
:11 47c :b 47d :3 47c :3 47f
:3 467 481 457 108
:9 481 :b 482 :a 483 :9 484
:5 485 :a 486 :c 487 :4 488
:5 489 :9 48a 48b :a 48c
:6 48d :a 48e :6 48f :9 490
:11 491 :a 492 :b 493 :17 494
:a 495 :4 496 :8 497 :8 498
:c 499 :f 49a :2 49b :3 49c
:2 49d :5 49e :5 49f :c 4a0
:9 4a1 :c 4a2 :9 4a3 :9 4a4
:9 4a5 :9 4a6 :2 4a7 :3 482
:11 4a8 :b 4a9 :3 4a8 :3 4ab
4ac 481 108 :9 4ac
:7 4ad :a 4ae :a 4af :9 4b0
:4 4b1 :4 4b2 4b3 :8 4b4
:5 4b5 :5 4b6 :5 4b7 :5 4b8
:4 4b9 :7 4ba :e 4bb :4 4bc
:a 4bd 4be :3 4bf :5 4c0
:4 4c1 :6 4c2 4c3 :2 4c4
:9 4c5 :c 4c6 :5 4c7 :2 4c8
:3 4ad :11 4c9 :b 4ca :3 4c9
:3 4cc 4cd 4ac 108
:9 4cd :5 4d1 :5 4d2 :4 4d5
:3 4d6 4d7 :2 4d8 4d9
:3 4da :2 4db 4d5 :6 4dc
:5 4dd 4dc :5 4df 4de
:3 4dc 4d4 4e2 :5 4e3
:3 4e2 :2 4e4 :5 4e6 :11 4e7
:24 4e8 :3 4e7 :2 4e5 :6 4e4
4e1 :3 4cd :5 4ee :5 4ef
:4 4f2 :3 4f3 4f4 :2 4f5
:2 4f6 :2 4f7 4f2 :6 4f8
:5 4f9 4f8 :5 4fb 4fa
:3 4f8 4f1 4fe :5 4ff
:3 4fe :2 500 :5 502 :11 503
:24 504 :3 503 :2 501 :6 500
4fd :3 4cd :5 50a :5 50b
:4 50e :6 50f :b 510 :6 512
:b 513 50e :6 514 :5 515
514 :5 517 516 :3 514
50d 51a :5 51b :3 51a
:2 51c :5 51e :11 51f :24 520
:3 51f :2 51d :6 51c 519
:3 4cd :d 525 :b 526 :9 527
:a 52b :b 52c :7 52d :7 52e
:9 52f :a 533 :4 534 :3 535
:4 536 :8 537 :2 538 :3 525
:11 539 :b 53a :3 539 :3 53c
53d 4cd 108 :9 53d
:c 540 :b 542 :5 543 :4 544
:2 545 :3 546 547 :3 542
:11 548 :b 549 :3 548 :3 54b
54c 53d 108 :d 54c
:2 54d :2 54c :6 54d :3 54c
:e 551 :4 552 :3 553 :4 554
555 :3 551 :11 556 :b 557
:3 556 :3 559 54d 108
:11 55b :30 55c :3 55b :a 55e
55a :3 108 43 :3 563
:11 564 :b 565 :17 566 :3 564
:2 568 :3 569 :3 56a 56b
569 568 569 :3 56c
:3 563 :2 56d :5 56f :11 570
:b 571 :18 572 :3 570 :2 574
575 :3 576 577 575
574 575 :3 578 :2 56e
:6 56d 562 :7 1 
78e5
4
:3 0 1 :3 0 2
:a 0 207d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 207d 2 14
:2 0 e :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 207b
0 b :6 0 e
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 207b
0 d :6 0 e
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 207b
0 f :6 0 12
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 207b
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 207b
0 11 :6 0 16
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 207b
0 13 :6 0 16
:2 0 25 6 :3 0
41 :7 0 45 42
43 207b 0 15
:6 0 16 :2 0 27
6 :3 0 47 :7 0
4b 48 49 207b
0 17 :6 0 16
:2 0 29 6 :3 0
4d :7 0 51 4e
4f 207b 0 18
:6 0 16 :2 0 2b
6 :3 0 53 :7 0
57 54 55 207b
0 19 :6 0 16
:2 0 2d 6 :3 0
59 :7 0 5d 5a
5b 207b 0 1a
:6 0 65 66 0
2f 6 :3 0 5f
:7 0 63 60 61
207b 0 1b :6 0
6c 6d 0 31
9 :3 0 a :2 0
4 67 :7 0 6a
68 0 207b 0
1c :6 0 73 74
0 33 9 :3 0
a :2 0 4 6e
:7 0 71 6f 0
207b 0 1d :6 0
7a 7b 0 35
9 :3 0 a :2 0
4 75 :7 0 78
76 0 207b 0
1e :6 0 81 82
0 37 9 :3 0
a :2 0 4 7c
:7 0 7f 7d 0
207b 0 1f :6 0
88 89 0 39
9 :3 0 a :2 0
4 83 :7 0 86
84 0 207b 0
20 :6 0 8f 90
0 3b 9 :3 0
a :2 0 4 8a
:7 0 8d 8b 0
207b 0 21 :6 0
96 97 0 3d
9 :3 0 a :2 0
4 91 :7 0 94
92 0 207b 0
22 :6 0 9d 9e
0 3f 9 :3 0
a :2 0 4 98
:7 0 9b 99 0
207b 0 23 :6 0
a4 a5 0 41
9 :3 0 a :2 0
4 9f :7 0 a2
a0 0 207b 0
24 :6 0 ab ac
0 43 9 :3 0
a :2 0 4 a6
:7 0 a9 a7 0
207b 0 25 :6 0
b2 b3 0 45
9 :3 0 a :2 0
4 ad :7 0 b0
ae 0 207b 0
26 :6 0 b9 ba
0 47 9 :3 0
a :2 0 4 b4
:7 0 b7 b5 0
207b 0 27 :6 0
c0 c1 0 49
9 :3 0 a :2 0
4 bb :7 0 be
bc 0 207b 0
28 :6 0 c7 c8
0 4b 9 :3 0
a :2 0 4 c2
:7 0 c5 c3 0
207b 0 29 :6 0
ce cf 0 4d
9 :3 0 a :2 0
4 c9 :7 0 cc
ca 0 207b 0
2a :6 0 d4 d5
0 4f 9 :3 0
a :2 0 4 d0
:7 0 d3 d1 0
207b 0 2b :6 0
2c :3 0 2d :3 0
2c :3 0 2e :3 0
d7 d8 0 2
:4 0 51 d9 db
d6 dd dc :2 0
2f :3 0 30 :3 0
df e0 0 31
:4 0 2c :3 0 32
:3 0 e3 e4 0
2 :4 0 53 e5
e7 33 :4 0 34
:2 0 35 :3 0 55
ea ec :3 0 36
:4 0 34 :2 0 37
:4 0 58 ef f1
:3 0 34 :2 0 3
:3 0 5b f3 f5
:3 0 34 :2 0 37
:4 0 5e f7 f9
:3 0 34 :2 0 38
:4 0 61 fb fd
:3 0 34 :2 0 39
:3 0 3a :3 0 5
:3 0 64 101 103
3b :4 0 66 100
106 69 ff 108
:3 0 34 :2 0 38
:4 0 6c 10a 10c
:3 0 34 :2 0 37
:4 0 6f 10e 110
:3 0 34 :2 0 7
:3 0 72 112 114
:3 0 34 :2 0 37
:4 0 75 116 118
:3 0 34 :2 0 3c
:4 0 78 11a 11c
:3 0 7b e1 11e
:2 0 120 80 121
de 120 0 122
82 0 1fdb 2c
:3 0 2d :3 0 123
124 0 2c :3 0
3d :3 0 126 127
0 14 :2 0 2
:4 0 3e :2 0 3f
:2 0 14 :2 0 84
12c 12e :3 0 87
128 130 125 132
131 :2 0 2f :3 0
40 :3 0 134 135
0 31 :4 0 41
:4 0 34 :2 0 35
:3 0 8b 139 13b
:3 0 8e 136 13d
:2 0 13f 91 140
133 13f 0 141
93 0 1fdb 3
:3 0 42 :2 0 95
143 144 :3 0 145
:2 0 2c :3 0 2d
:3 0 147 148 0
2c :3 0 3d :3 0
14a 14b 0 e
:2 0 2 :4 0 43
:2 0 3f :2 0 14
:2 0 97 150 152
:3 0 9a 14c 154
149 156 155 :2 0
2f :3 0 40 :3 0
158 159 0 31
:4 0 44 :4 0 34
:2 0 35 :3 0 9e
15d 15f :3 0 34
:2 0 45 :4 0 a1
161 163 :3 0 34
:2 0 46 :4 0 a4
165 167 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 16c 16d 0
a7 16b 16f 3b
:4 0 a9 16a 172
ac 169 174 :3 0
34 :2 0 49 :4 0
af 176 178 :3 0
34 :2 0 37 :4 0
b2 17a 17c :3 0
34 :2 0 3 :3 0
b5 17e 180 :3 0
34 :2 0 37 :4 0
b8 182 184 :3 0
bb 15a 186 :2 0
188 be 189 157
188 0 18a c0
0 1b4 2c :3 0
2d :3 0 18b 18c
0 2c :3 0 3d
:3 0 18e 18f 0
14 :2 0 2 :4 0
4a :2 0 3f :2 0
14 :2 0 c2 194
196 :3 0 c5 190
198 18d 19a 199
:2 0 2f :3 0 40
:3 0 19c 19d 0
31 :4 0 4b :4 0
34 :2 0 35 :3 0
c9 1a1 1a3 :3 0
cc 19e 1a5 :2 0
1a7 cf 1a8 19b
1a7 0 1a9 d1
0 1b4 4c :3 0
4d :3 0 1aa 1ab
0 47 :3 0 48
:3 0 1ad 1ae 0
3 :3 0 4e :3 0
d3 1ac 1b2 :2 0
1b4 d7 1b5 146
1b4 0 1b6 db
0 1fdb d :3 0
3 :3 0 1b7 1b8
0 1fdb 15 :3 0
5 :3 0 1ba 1bb
0 1fdb f :3 0
7 :3 0 1bd 1be
0 1fdb 39 :3 0
15 :3 0 16 :2 0
dd 1c0 1c3 4f
:2 0 50 :2 0 e2
1c5 1c7 :3 0 1c8
:2 0 39 :3 0 15
:3 0 16 :2 0 e5
1ca 1cd 4f :2 0
51 :2 0 ea 1cf
1d1 :3 0 1d2 :2 0
1c9 1d4 1d3 :2 0
52 :3 0 53 :3 0
52 :3 0 54 :3 0
39 :3 0 55 :3 0
56 :3 0 52 :3 0
57 :3 0 10 :3 0
18 :3 0 17 :3 0
1b :3 0 58 :3 0
55 :3 0 58 :3 0
52 :3 0 52 :3 0
59 :3 0 d :3 0
55 :3 0 59 :3 0
52 :3 0 53 :4 0
5a 1 :8 0 1f4
9 :3 0 5b :3 0
1ef 1f0 0 5c
:3 0 1f1 1f2 0
1f4 ed 247 5d
:3 0 9 :3 0 5b
:3 0 1f6 1f7 0
5c :3 0 1f8 1f9
0 1fb f0 1fd
f2 1fc 1fb :2 0
245 5e :3 0 9
:3 0 5b :3 0 200
201 0 5c :3 0
202 203 0 23d
2c :3 0 2d :3 0
205 206 0 2c
:3 0 3d :3 0 208
209 0 5f :2 0
2 :4 0 60 :2 0
3f :2 0 14 :2 0
f4 20e 210 :3 0
f7 20a 212 207
214 213 :2 0 2f
:3 0 40 :3 0 216
217 0 31 :4 0
61 :4 0 34 :2 0
35 :3 0 fb 21b
21d :3 0 34 :2 0
45 :4 0 fe 21f
221 :3 0 34 :2 0
62 :4 0 101 223
225 :3 0 34 :2 0
5c :3 0 104 227
229 :3 0 34 :2 0
63 :4 0 107 22b
22d :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
10a 230 234 10e
22f 236 :3 0 111
218 238 :2 0 23a
114 23b 215 23a
0 23c 116 0
23d 118 240 :3 0
240 0 240 23f
23d 23e :6 0 242
2 :3 0 11b 244
11d 243 242 :2 0
245 11f :2 0 247
0 247 246 1f4
245 :6 0 3ad 1
:3 0 9 :3 0 5b
:3 0 249 24a 0
9 :3 0 4f :2 0
67 :3 0 24c 24e
0 124 24d 250
:3 0 251 :2 0 52
:3 0 53 :3 0 52
:3 0 54 :3 0 39
:3 0 55 :3 0 56
:3 0 10 :3 0 18
:3 0 17 :3 0 58
:3 0 55 :3 0 68
:3 0 52 :3 0 52
:3 0 59 :3 0 d
:3 0 55 :3 0 59
:3 0 52 :3 0 53
:4 0 69 1 :8 0
26e 9 :3 0 5b
:3 0 269 26a 0
5c :3 0 26b 26c
0 26e 127 2c1
5d :3 0 9 :3 0
5b :3 0 270 271
0 5c :3 0 272
273 0 275 12a
277 12c 276 275
:2 0 2bf 5e :3 0
9 :3 0 5b :3 0
27a 27b 0 5c
:3 0 27c 27d 0
2b7 2c :3 0 2d
:3 0 27f 280 0
2c :3 0 3d :3 0
282 283 0 5f
:2 0 2 :4 0 6a
:2 0 3f :2 0 14
:2 0 12e 288 28a
:3 0 131 284 28c
281 28e 28d :2 0
2f :3 0 40 :3 0
290 291 0 31
:4 0 6b :4 0 34
:2 0 35 :3 0 135
295 297 :3 0 34
:2 0 45 :4 0 138
299 29b :3 0 34
:2 0 62 :4 0 13b
29d 29f :3 0 34
:2 0 5c :3 0 13e
2a1 2a3 :3 0 34
:2 0 63 :4 0 141
2a5 2a7 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 144 2aa 2ae
148 2a9 2b0 :3 0
14b 292 2b2 :2 0
2b4 14e 2b5 28f
2b4 0 2b6 150
0 2b7 152 2ba
:3 0 2ba 0 2ba
2b9 2b7 2b8 :6 0
2bc 4 :3 0 155
2be 157 2bd 2bc
:2 0 2bf 159 :2 0
2c1 0 2c1 2c0
26e 2bf :6 0 3a9
1 :3 0 9 :3 0
5b :3 0 2c3 2c4
0 9 :3 0 4f
:2 0 67 :3 0 2c6
2c8 0 15e 2c7
2ca :3 0 2cb :2 0
17 :3 0 6c :3 0
59 :3 0 d :4 0
6d 1 :8 0 2d7
9 :3 0 5b :3 0
2d2 2d3 0 5c
:3 0 2d4 2d5 0
2d7 161 32a 5d
:3 0 9 :3 0 5b
:3 0 2d9 2da 0
5c :3 0 2db 2dc
0 2de 164 2e0
166 2df 2de :2 0
328 5e :3 0 9
:3 0 5b :3 0 2e3
2e4 0 5c :3 0
2e5 2e6 0 320
2c :3 0 2d :3 0
2e8 2e9 0 2c
:3 0 3d :3 0 2eb
2ec 0 5f :2 0
2 :4 0 6e :2 0
3f :2 0 14 :2 0
168 2f1 2f3 :3 0
16b 2ed 2f5 2ea
2f7 2f6 :2 0 2f
:3 0 40 :3 0 2f9
2fa 0 31 :4 0
6f :4 0 34 :2 0
35 :3 0 16f 2fe
300 :3 0 34 :2 0
45 :4 0 172 302
304 :3 0 34 :2 0
62 :4 0 175 306
308 :3 0 34 :2 0
5c :3 0 178 30a
30c :3 0 34 :2 0
63 :4 0 17b 30e
310 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
17e 313 317 182
312 319 :3 0 185
2fb 31b :2 0 31d
188 31e 2f8 31d
0 31f 18a 0
320 18c 323 :3 0
323 0 323 322
320 321 :6 0 325
6 :3 0 18f 327
191 326 325 :2 0
328 193 :2 0 32a
0 32a 329 2d7
328 :6 0 3a6 1
:3 0 9 :3 0 5b
:3 0 32c 32d 0
9 :3 0 4f :2 0
67 :3 0 32f 331
0 198 330 333
:3 0 334 :2 0 2c
:3 0 2d :3 0 336
337 0 2c :3 0
3d :3 0 339 33a
0 e :2 0 2
:4 0 70 :2 0 3f
:2 0 14 :2 0 19b
33f 341 :3 0 19e
33b 343 338 345
344 :2 0 2f :3 0
40 :3 0 347 348
0 31 :4 0 71
:4 0 34 :2 0 35
:3 0 1a2 34c 34e
:3 0 34 :2 0 45
:4 0 1a5 350 352
:3 0 34 :2 0 46
:4 0 1a8 354 356
:3 0 34 :2 0 39
:3 0 3a :3 0 47
:3 0 48 :3 0 35b
35c 0 1ab 35a
35e 3b :4 0 1ad
359 361 1b0 358
363 :3 0 34 :2 0
49 :4 0 1b3 365
367 :3 0 34 :2 0
37 :4 0 1b6 369
36b :3 0 34 :2 0
d :3 0 1b9 36d
36f :3 0 34 :2 0
37 :4 0 1bc 371
373 :3 0 1bf 349
375 :2 0 377 1c2
378 346 377 0
379 1c4 0 3a3
2c :3 0 2d :3 0
37a 37b 0 2c
:3 0 3d :3 0 37d
37e 0 14 :2 0
2 :4 0 72 :2 0
3f :2 0 14 :2 0
1c6 383 385 :3 0
1c9 37f 387 37c
389 388 :2 0 2f
:3 0 40 :3 0 38b
38c 0 31 :4 0
73 :4 0 34 :2 0
35 :3 0 1cd 390
392 :3 0 1d0 38d
394 :2 0 396 1d3
397 38a 396 0
398 1d5 0 3a3
4c :3 0 4d :3 0
399 39a 0 47
:3 0 48 :3 0 39c
39d 0 d :3 0
4e :3 0 1d7 39b
3a1 :2 0 3a3 1db
3a4 335 3a3 0
3a5 1df 0 3a6
1e1 3a7 2cc 3a6
0 3a8 1e4 0
3a9 1e6 3aa 252
3a9 0 3ab 1e9
0 3ad 74 :3 0
1eb 6f3 39 :3 0
15 :3 0 16 :2 0
1ee 3ae 3b1 4f
:2 0 75 :2 0 1f3
3b3 3b5 :3 0 53
:3 0 10 :3 0 76
:3 0 77 :3 0 d
:4 0 78 1 :8 0
3c2 9 :3 0 5b
:3 0 3bd 3be 0
5c :3 0 3bf 3c0
0 3c2 1f6 415
5d :3 0 9 :3 0
5b :3 0 3c4 3c5
0 5c :3 0 3c6
3c7 0 3c9 1f9
3cb 1fb 3ca 3c9
:2 0 413 5e :3 0
9 :3 0 5b :3 0
3ce 3cf 0 5c
:3 0 3d0 3d1 0
40b 2c :3 0 2d
:3 0 3d3 3d4 0
2c :3 0 3d :3 0
3d6 3d7 0 5f
:2 0 2 :4 0 79
:2 0 3f :2 0 14
:2 0 1fd 3dc 3de
:3 0 200 3d8 3e0
3d5 3e2 3e1 :2 0
2f :3 0 40 :3 0
3e4 3e5 0 31
:4 0 7a :4 0 34
:2 0 35 :3 0 204
3e9 3eb :3 0 34
:2 0 45 :4 0 207
3ed 3ef :3 0 34
:2 0 62 :4 0 20a
3f1 3f3 :3 0 34
:2 0 5c :3 0 20d
3f5 3f7 :3 0 34
:2 0 63 :4 0 210
3f9 3fb :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 213 3fe 402
217 3fd 404 :3 0
21a 3e6 406 :2 0
408 21d 409 3e3
408 0 40a 21f
0 40b 221 40e
:3 0 40e 0 40e
40d 40b 40c :6 0
410 8 :3 0 224
412 226 411 410
:2 0 413 228 :2 0
415 0 415 414
3c2 413 :6 0 4f5
1 :3 0 9 :3 0
5b :3 0 417 418
0 9 :3 0 4f
:2 0 67 :3 0 41a
41c 0 22d 41b
41e :3 0 41f :2 0
2c :3 0 2d :3 0
421 422 0 2c
:3 0 3d :3 0 424
425 0 e :2 0
2 :4 0 7b :2 0
3f :2 0 14 :2 0
230 42a 42c :3 0
233 426 42e 423
430 42f :2 0 2f
:3 0 40 :3 0 432
433 0 31 :4 0
7c :4 0 34 :2 0
35 :3 0 237 437
439 :3 0 34 :2 0
45 :4 0 23a 43b
43d :3 0 34 :2 0
46 :4 0 23d 43f
441 :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
446 447 0 240
445 449 3b :4 0
242 444 44c 245
443 44e :3 0 34
:2 0 49 :4 0 248
450 452 :3 0 34
:2 0 37 :4 0 24b
454 456 :3 0 34
:2 0 3 :3 0 24e
458 45a :3 0 34
:2 0 37 :4 0 251
45c 45e :3 0 254
434 460 :2 0 462
257 463 431 462
0 464 259 0
48e 2c :3 0 2d
:3 0 465 466 0
2c :3 0 3d :3 0
468 469 0 14
:2 0 2 :4 0 7d
:2 0 3f :2 0 14
:2 0 25b 46e 470
:3 0 25e 46a 472
467 474 473 :2 0
2f :3 0 40 :3 0
476 477 0 31
:4 0 7e :4 0 34
:2 0 35 :3 0 262
47b 47d :3 0 265
478 47f :2 0 481
268 482 475 481
0 483 26a 0
48e 4c :3 0 4d
:3 0 484 485 0
47 :3 0 48 :3 0
487 488 0 3
:3 0 4e :3 0 26c
486 48c :2 0 48e
270 48f 420 48e
0 490 274 0
4f5 39 :3 0 56
:3 0 57 :3 0 17
:3 0 1b :3 0 58
:3 0 59 :3 0 d
:4 0 7f 1 :8 0
49f 9 :3 0 5b
:3 0 49a 49b 0
5c :3 0 49c 49d
0 49f 276 4f2
5d :3 0 9 :3 0
5b :3 0 4a1 4a2
0 5c :3 0 4a3
4a4 0 4a6 279
4a8 27b 4a7 4a6
:2 0 4f0 5e :3 0
9 :3 0 5b :3 0
4ab 4ac 0 5c
:3 0 4ad 4ae 0
4e8 2c :3 0 2d
:3 0 4b0 4b1 0
2c :3 0 3d :3 0
4b3 4b4 0 5f
:2 0 2 :4 0 c
:2 0 3f :2 0 14
:2 0 27d 4b9 4bb
:3 0 280 4b5 4bd
4b2 4bf 4be :2 0
2f :3 0 40 :3 0
4c1 4c2 0 31
:4 0 80 :4 0 34
:2 0 35 :3 0 284
4c6 4c8 :3 0 34
:2 0 45 :4 0 287
4ca 4cc :3 0 34
:2 0 62 :4 0 28a
4ce 4d0 :3 0 34
:2 0 5c :3 0 28d
4d2 4d4 :3 0 34
:2 0 63 :4 0 290
4d6 4d8 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 293 4db 4df
297 4da 4e1 :3 0
29a 4c3 4e3 :2 0
4e5 29d 4e6 4c0
4e5 0 4e7 29f
0 4e8 2a1 4eb
:3 0 4eb 0 4eb
4ea 4e8 4e9 :6 0
4ed a :3 0 2a4
4ef 2a6 4ee 4ed
:2 0 4f0 2a8 :2 0
4f2 0 4f2 4f1
49f 4f0 :6 0 4f5
1 :3 0 74 :3 0
2ab 4f6 3b6 4f5
0 6f4 39 :3 0
15 :3 0 16 :2 0
2af 4f7 4fa 4f
:2 0 81 :2 0 2b4
4fc 4fe :3 0 82
:3 0 b :3 0 6c
:3 0 59 :3 0 d
:4 0 83 1 :8 0
50b 9 :3 0 5b
:3 0 506 507 0
5c :3 0 508 509
0 50b 2b7 55e
5d :3 0 9 :3 0
5b :3 0 50d 50e
0 5c :3 0 50f
510 0 512 2ba
514 2bc 513 512
:2 0 55c 5e :3 0
9 :3 0 5b :3 0
517 518 0 5c
:3 0 519 51a 0
554 2c :3 0 2d
:3 0 51c 51d 0
2c :3 0 3d :3 0
51f 520 0 5f
:2 0 2 :4 0 84
:2 0 3f :2 0 14
:2 0 2be 525 527
:3 0 2c1 521 529
51e 52b 52a :2 0
2f :3 0 40 :3 0
52d 52e 0 31
:4 0 85 :4 0 34
:2 0 35 :3 0 2c5
532 534 :3 0 34
:2 0 45 :4 0 2c8
536 538 :3 0 34
:2 0 62 :4 0 2cb
53a 53c :3 0 34
:2 0 5c :3 0 2ce
53e 540 :3 0 34
:2 0 63 :4 0 2d1
542 544 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 2d4 547 54b
2d8 546 54d :3 0
2db 52f 54f :2 0
551 2de 552 52c
551 0 553 2e0
0 554 2e2 557
:3 0 557 0 557
556 554 555 :6 0
559 c :3 0 2e5
55b 2e7 55a 559
:2 0 55c 2e9 :2 0
55e 0 55e 55d
50b 55c :6 0 5de
1 :3 0 9 :3 0
5b :3 0 560 561
0 9 :3 0 4f
:2 0 67 :3 0 563
565 0 2ee 564
567 :3 0 568 :2 0
2c :3 0 2d :3 0
56a 56b 0 2c
:3 0 3d :3 0 56d
56e 0 e :2 0
2 :4 0 86 :2 0
3f :2 0 14 :2 0
2f1 573 575 :3 0
2f4 56f 577 56c
579 578 :2 0 2f
:3 0 40 :3 0 57b
57c 0 31 :4 0
87 :4 0 34 :2 0
35 :3 0 2f8 580
582 :3 0 34 :2 0
45 :4 0 2fb 584
586 :3 0 34 :2 0
46 :4 0 2fe 588
58a :3 0 34 :2 0
39 :3 0 3a :3 0
47 :3 0 48 :3 0
58f 590 0 301
58e 592 3b :4 0
303 58d 595 306
58c 597 :3 0 34
:2 0 49 :4 0 309
599 59b :3 0 34
:2 0 37 :4 0 30c
59d 59f :3 0 34
:2 0 3 :3 0 30f
5a1 5a3 :3 0 34
:2 0 37 :4 0 312
5a5 5a7 :3 0 315
57d 5a9 :2 0 5ab
318 5ac 57a 5ab
0 5ad 31a 0
5d7 2c :3 0 2d
:3 0 5ae 5af 0
2c :3 0 3d :3 0
5b1 5b2 0 14
:2 0 2 :4 0 88
:2 0 3f :2 0 14
:2 0 31c 5b7 5b9
:3 0 31f 5b3 5bb
5b0 5bd 5bc :2 0
2f :3 0 40 :3 0
5bf 5c0 0 31
:4 0 89 :4 0 34
:2 0 35 :3 0 323
5c4 5c6 :3 0 326
5c1 5c8 :2 0 5ca
329 5cb 5be 5ca
0 5cc 32b 0
5d7 4c :3 0 4d
:3 0 5cd 5ce 0
47 :3 0 48 :3 0
5d0 5d1 0 3
:3 0 4e :3 0 32d
5cf 5d5 :2 0 5d7
331 5d8 569 5d7
0 5d9 335 0
5de 17 :3 0 8a
:2 0 5da 5db 0
5de 74 :3 0 337
5df 4ff 5de 0
6f4 39 :3 0 15
:3 0 16 :2 0 33b
5e0 5e3 47 :3 0
8b :2 0 8c :3 0
5e5 5e7 0 340
5e6 5e9 :3 0 5ea
:2 0 39 :3 0 15
:3 0 16 :2 0 343
5ec 5ef 8b :2 0
8d :2 0 348 5f1
5f3 :3 0 5f4 :2 0
5eb 5f6 5f5 :2 0
39 :3 0 15 :3 0
16 :2 0 34b 5f8
5fb 47 :3 0 8b
:2 0 8e :3 0 5fd
5ff 0 350 5fe
601 :3 0 602 :2 0
5f7 604 603 :2 0
39 :3 0 15 :3 0
16 :2 0 353 606
609 47 :3 0 8b
:2 0 8f :3 0 60b
60d 0 358 60c
60f :3 0 610 :2 0
605 612 611 :2 0
39 :3 0 56 :3 0
57 :3 0 17 :3 0
1b :3 0 58 :3 0
59 :3 0 3 :4 0
90 1 :8 0 622
9 :3 0 5b :3 0
61d 61e 0 5c
:3 0 61f 620 0
622 35b 675 5d
:3 0 9 :3 0 5b
:3 0 624 625 0
5c :3 0 626 627
0 629 35e 62b
360 62a 629 :2 0
673 5e :3 0 9
:3 0 5b :3 0 62e
62f 0 5c :3 0
630 631 0 66b
2c :3 0 2d :3 0
633 634 0 2c
:3 0 3d :3 0 636
637 0 5f :2 0
2 :4 0 91 :2 0
3f :2 0 14 :2 0
362 63c 63e :3 0
365 638 640 635
642 641 :2 0 2f
:3 0 40 :3 0 644
645 0 31 :4 0
92 :4 0 34 :2 0
35 :3 0 369 649
64b :3 0 34 :2 0
45 :4 0 36c 64d
64f :3 0 34 :2 0
62 :4 0 36f 651
653 :3 0 34 :2 0
5c :3 0 372 655
657 :3 0 34 :2 0
63 :4 0 375 659
65b :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
378 65e 662 37c
65d 664 :3 0 37f
646 666 :2 0 668
382 669 643 668
0 66a 384 0
66b 386 66e :3 0
66e 0 66e 66d
66b 66c :6 0 670
e :3 0 389 672
38b 671 670 :2 0
673 38d :2 0 675
0 675 674 622
673 :6 0 6f1 1
:3 0 9 :3 0 5b
:3 0 677 678 0
9 :3 0 4f :2 0
67 :3 0 67a 67c
0 392 67b 67e
:3 0 67f :2 0 2c
:3 0 2d :3 0 681
682 0 2c :3 0
3d :3 0 684 685
0 e :2 0 2
:4 0 93 :2 0 3f
:2 0 14 :2 0 395
68a 68c :3 0 398
686 68e 683 690
68f :2 0 2f :3 0
40 :3 0 692 693
0 31 :4 0 94
:4 0 34 :2 0 35
:3 0 39c 697 699
:3 0 34 :2 0 45
:4 0 39f 69b 69d
:3 0 34 :2 0 46
:4 0 3a2 69f 6a1
:3 0 34 :2 0 39
:3 0 3a :3 0 47
:3 0 48 :3 0 6a6
6a7 0 3a5 6a5
6a9 3b :4 0 3a7
6a4 6ac 3aa 6a3
6ae :3 0 34 :2 0
49 :4 0 3ad 6b0
6b2 :3 0 34 :2 0
37 :4 0 3b0 6b4
6b6 :3 0 34 :2 0
3 :3 0 3b3 6b8
6ba :3 0 34 :2 0
37 :4 0 3b6 6bc
6be :3 0 3b9 694
6c0 :2 0 6c2 3bc
6c3 691 6c2 0
6c4 3be 0 6ee
2c :3 0 2d :3 0
6c5 6c6 0 2c
:3 0 3d :3 0 6c8
6c9 0 14 :2 0
2 :4 0 12 :2 0
3f :2 0 14 :2 0
3c0 6ce 6d0 :3 0
3c3 6ca 6d2 6c7
6d4 6d3 :2 0 2f
:3 0 40 :3 0 6d6
6d7 0 31 :4 0
95 :4 0 34 :2 0
35 :3 0 3c7 6db
6dd :3 0 3ca 6d8
6df :2 0 6e1 3cd
6e2 6d5 6e1 0
6e3 3cf 0 6ee
4c :3 0 4d :3 0
6e4 6e5 0 47
:3 0 48 :3 0 6e7
6e8 0 3 :3 0
4e :3 0 3d1 6e6
6ec :2 0 6ee 3d5
6ef 680 6ee 0
6f0 3d9 0 6f1
3db 6f2 613 6f1
0 6f4 1d5 3ad
0 6f4 3de 0
1fdb 39 :3 0 15
:3 0 16 :2 0 3e3
6f5 6f8 4f :2 0
16 :2 0 3e8 6fa
6fc :3 0 96 :3 0
97 :3 0 98 :4 0
700 :4 0 701 :2 0
964 9 :3 0 5b
:3 0 703 704 0
16 :2 0 705 706
0 964 99 :3 0
9a :3 0 9b :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 55 :3 0
9a :3 0 a1 :3 0
9b :3 0 a1 :3 0
9c :3 0 a1 :3 0
9d :3 0 a1 :3 0
9e :3 0 a1 :3 0
9f :3 0 a1 :3 0
a0 :3 0 a2 :3 0
55 :3 0 a3 :3 0
a4 :3 0 a1 :3 0
55 :3 0 9a :3 0
a1 :3 0 9a :3 0
53 :3 0 d :3 0
a5 :4 0 a6 1
:8 0 740 a7 :4 0
72b :3 0 4e :3 0
4f :2 0 3ed 72e
72f :3 0 9 :3 0
5b :3 0 731 732
0 16 :2 0 733
734 0 736 3f0
73d 9 :3 0 5b
:3 0 737 738 0
a8 :2 0 739 73a
0 73c 3f2 73e
730 736 0 73f
0 73c 0 73f
3f4 0 740 3f7
793 5d :3 0 9
:3 0 5b :3 0 742
743 0 5c :3 0
744 745 0 747
3fa 749 3fc 748
747 :2 0 791 5e
:3 0 9 :3 0 5b
:3 0 74c 74d 0
5c :3 0 74e 74f
0 789 2c :3 0
2d :3 0 751 752
0 2c :3 0 3d
:3 0 754 755 0
5f :2 0 2 :4 0
a9 :2 0 3f :2 0
14 :2 0 3fe 75a
75c :3 0 401 756
75e 753 760 75f
:2 0 2f :3 0 40
:3 0 762 763 0
31 :4 0 aa :4 0
34 :2 0 35 :3 0
405 767 769 :3 0
34 :2 0 45 :4 0
408 76b 76d :3 0
34 :2 0 62 :4 0
40b 76f 771 :3 0
34 :2 0 5c :3 0
40e 773 775 :3 0
34 :2 0 63 :4 0
411 777 779 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 414 77c
780 418 77b 782
:3 0 41b 764 784
:2 0 786 41e 787
761 786 0 788
420 0 789 422
78c :3 0 78c 0
78c 78b 789 78a
:6 0 78e 10 :3 0
425 790 427 78f
78e :2 0 791 429
:2 0 793 0 793
792 740 791 :6 0
964 1 :3 0 96
:3 0 97 :3 0 ab
:4 0 797 :4 0 798
:2 0 964 9 :3 0
5b :3 0 79a 79b
0 16 :2 0 79c
79d 0 964 ac
:3 0 ad :3 0 9a
:3 0 a2 :3 0 53
:3 0 d :3 0 a5
:4 0 ae 1 :8 0
7bc a7 :4 0 7a7
:3 0 4e :3 0 4f
:2 0 42e 7aa 7ab
:3 0 9 :3 0 5b
:3 0 7ad 7ae 0
16 :2 0 7af 7b0
0 7b2 431 7b9
9 :3 0 5b :3 0
7b3 7b4 0 a8
:2 0 7b5 7b6 0
7b8 433 7ba 7ac
7b2 0 7bb 0
7b8 0 7bb 435
0 7bc 438 80f
5d :3 0 9 :3 0
5b :3 0 7be 7bf
0 5c :3 0 7c0
7c1 0 7c3 43b
7c5 43d 7c4 7c3
:2 0 80d 5e :3 0
9 :3 0 5b :3 0
7c8 7c9 0 5c
:3 0 7ca 7cb 0
805 2c :3 0 2d
:3 0 7cd 7ce 0
2c :3 0 3d :3 0
7d0 7d1 0 5f
:2 0 2 :4 0 af
:2 0 3f :2 0 14
:2 0 43f 7d6 7d8
:3 0 442 7d2 7da
7cf 7dc 7db :2 0
2f :3 0 40 :3 0
7de 7df 0 31
:4 0 b0 :4 0 34
:2 0 35 :3 0 446
7e3 7e5 :3 0 34
:2 0 45 :4 0 449
7e7 7e9 :3 0 34
:2 0 62 :4 0 44c
7eb 7ed :3 0 34
:2 0 5c :3 0 44f
7ef 7f1 :3 0 34
:2 0 63 :4 0 452
7f3 7f5 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 455 7f8 7fc
459 7f7 7fe :3 0
45c 7e0 800 :2 0
802 45f 803 7dd
802 0 804 461
0 805 463 808
:3 0 808 0 808
807 805 806 :6 0
80a 12 :3 0 466
80c 468 80b 80a
:2 0 80d 46a :2 0
80f 0 80f 80e
7bc 80d :6 0 964
1 :3 0 b1 :3 0
1c :3 0 76 :3 0
b2 :3 0 b2 :3 0
53 :3 0 d :3 0
b2 :3 0 9a :3 0
b3 :3 0 9a :3 0
b4 :3 0 b3 :3 0
9a :3 0 b5 :3 0
b6 :3 0 b7 :3 0
b5 :3 0 b8 :3 0
b5 :3 0 b9 :3 0
ba :3 0 54 :3 0
ba :3 0 b7 :3 0
bb :3 0 b3 :3 0
9d :3 0 b3 :3 0
9e :3 0 b3 :3 0
9f :3 0 b3 :3 0
a0 :3 0 bc :3 0
bd :3 0 be :3 0
bd :3 0 bf :3 0
bd :3 0 c0 :3 0
bd :3 0 c1 :3 0
c2 :3 0 82 :3 0
99 :3 0 b3 :3 0
a3 :3 0 c3 :3 0
b5 :3 0 b3 :3 0
9a :3 0 b5 :3 0
9a :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
b3 :3 0 9b :3 0
a3 :3 0 a4 :3 0
ba :3 0 ba :3 0
59 :3 0 c4 :3 0
9b :3 0 c5 :3 0
c6 :3 0 a3 :3 0
c7 :3 0 bd :3 0
bd :3 0 9c :3 0
b3 :3 0 9c :3 0
b4 :3 0 c8 :3 0
ad :3 0 9a :3 0
b5 :3 0 c9 :3 0
b7 :3 0 b8 :3 0
b9 :3 0 c4 :3 0
54 :3 0 c4 :3 0
b7 :3 0 bb :3 0
a1 :3 0 9d :3 0
a1 :3 0 9e :3 0
a1 :3 0 9f :3 0
a1 :3 0 a0 :3 0
bc :3 0 bd :3 0
be :3 0 bd :3 0
bf :3 0 bd :3 0
c0 :3 0 bd :3 0
c1 :3 0 c2 :3 0
82 :3 0 ac :3 0
c8 :3 0 a3 :3 0
ca :3 0 b5 :3 0
c8 :3 0 ad :3 0
b5 :3 0 ad :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
a1 :3 0 b5 :3 0
cb :3 0 a1 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
a1 :3 0 9b :3 0
c5 :3 0 c6 :3 0
a3 :3 0 c7 :3 0
bd :3 0 bd :3 0
9c :3 0 a1 :3 0
9c :3 0 b4 :3 0
c8 :3 0 ad :3 0
9a :3 0 b5 :3 0
c9 :3 0 b7 :3 0
b8 :3 0 b9 :3 0
c4 :3 0 54 :3 0
c4 :3 0 b7 :3 0
bb :3 0 a1 :3 0
9d :3 0 a1 :3 0
9e :3 0 a1 :3 0
9f :3 0 a1 :3 0
a0 :3 0 bc :3 0
bd :3 0 be :3 0
bd :3 0 bf :3 0
bd :3 0 c0 :3 0
bd :3 0 c1 :3 0
c2 :3 0 82 :3 0
ac :3 0 c8 :3 0
a3 :3 0 ca :3 0
b5 :3 0 c8 :3 0
ad :3 0 b5 :3 0
ad :3 0 a3 :3 0
cc :3 0 cd :3 0
b5 :3 0 ad :3 0
cd :3 0 ce :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
a1 :3 0 cd :3 0
cf :3 0 a1 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
a1 :3 0 9b :3 0
c5 :3 0 c6 :3 0
a3 :3 0 c7 :3 0
bd :3 0 bd :3 0
9c :3 0 a1 :3 0
9c :3 0 b4 :3 0
c8 :3 0 ad :3 0
9a :3 0 b5 :3 0
c9 :3 0 b7 :3 0
b8 :3 0 b9 :3 0
c4 :3 0 54 :3 0
c4 :3 0 b7 :3 0
bb :3 0 a1 :3 0
9d :3 0 a1 :3 0
9e :3 0 a1 :3 0
9f :3 0 a1 :3 0
a0 :3 0 bc :3 0
bd :3 0 be :3 0
bd :3 0 bf :3 0
bd :3 0 c0 :3 0
bd :3 0 c1 :3 0
c2 :3 0 82 :3 0
ac :3 0 c8 :3 0
a3 :3 0 ca :3 0
b5 :3 0 c8 :3 0
ad :3 0 b5 :3 0
ad :3 0 a3 :3 0
d0 :3 0 cd :3 0
b5 :3 0 ad :3 0
cd :3 0 ce :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
a1 :3 0 cd :3 0
cb :3 0 a1 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 c4 :3 0
c4 :3 0 59 :3 0
a1 :3 0 9b :3 0
c5 :3 0 c6 :3 0
a3 :3 0 c7 :3 0
bd :3 0 bd :3 0
9c :3 0 a1 :3 0
9c :3 0 b4 :3 0
9a :3 0 54 :4 0
d1 1 :a 0 940
:2 0 964 812 93e
:2 0 2c :3 0 2d
:3 0 941 942 0
2c :3 0 3d :3 0
944 945 0 14
:2 0 2 :4 0 d2
:2 0 3f :2 0 14
:2 0 46d 94a 94c
:3 0 470 946 94e
943 950 94f :2 0
2f :3 0 40 :3 0
952 953 0 31
:4 0 d3 :4 0 34
:2 0 35 :3 0 474
957 959 :3 0 477
954 95b :2 0 95d
47a 95e 951 95d
0 95f 47c 0
964 8 :3 0 1c
:3 0 961 :2 0 964
74 :3 0 47e 1fd8
39 :3 0 15 :3 0
16 :2 0 488 965
968 4f :2 0 14
:2 0 48d 96a 96c
:3 0 96d :2 0 39
:3 0 15 :3 0 16
:2 0 490 96f 972
4f :2 0 d4 :2 0
495 974 976 :3 0
977 :2 0 96e 979
978 :2 0 96 :3 0
97 :3 0 d5 :4 0
97d :4 0 97e :2 0
b25 9 :3 0 5b
:3 0 980 981 0
16 :2 0 982 983
0 b25 d6 :3 0
9a :3 0 54 :3 0
d7 :3 0 9a :3 0
b2 :3 0 77 :3 0
54 :3 0 a2 :3 0
d7 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
76 :3 0 b2 :3 0
b2 :3 0 53 :3 0
d :3 0 d7 :3 0
9a :3 0 b2 :3 0
9a :3 0 d7 :3 0
53 :3 0 d :3 0
d7 :3 0 a5 :3 0
b2 :3 0 d8 :3 0
76 :3 0 d9 :3 0
d7 :3 0 9a :3 0
d9 :3 0 9a :3 0
d9 :3 0 da :3 0
d :4 0 db 1
:8 0 9c1 a7 :4 0
9ac :3 0 4e :3 0
4f :2 0 49a 9af
9b0 :3 0 9 :3 0
5b :3 0 9b2 9b3
0 16 :2 0 9b4
9b5 0 9b7 49d
9be 9 :3 0 5b
:3 0 9b8 9b9 0
a8 :2 0 9ba 9bb
0 9bd 49f 9bf
9b1 9b7 0 9c0
0 9bd 0 9c0
4a1 0 9c1 4a4
a14 5d :3 0 9
:3 0 5b :3 0 9c3
9c4 0 5c :3 0
9c5 9c6 0 9c8
4a7 9ca 4a9 9c9
9c8 :2 0 a12 5e
:3 0 9 :3 0 5b
:3 0 9cd 9ce 0
5c :3 0 9cf 9d0
0 a0a 2c :3 0
2d :3 0 9d2 9d3
0 2c :3 0 3d
:3 0 9d5 9d6 0
5f :2 0 2 :4 0
dc :2 0 3f :2 0
14 :2 0 4ab 9db
9dd :3 0 4ae 9d7
9df 9d4 9e1 9e0
:2 0 2f :3 0 40
:3 0 9e3 9e4 0
31 :4 0 dd :4 0
34 :2 0 35 :3 0
4b2 9e8 9ea :3 0
34 :2 0 45 :4 0
4b5 9ec 9ee :3 0
34 :2 0 62 :4 0
4b8 9f0 9f2 :3 0
34 :2 0 5c :3 0
4bb 9f4 9f6 :3 0
34 :2 0 63 :4 0
4be 9f8 9fa :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 4c1 9fd
a01 4c5 9fc a03
:3 0 4c8 9e5 a05
:2 0 a07 4cb a08
9e2 a07 0 a09
4cd 0 a0a 4cf
a0d :3 0 a0d 0
a0d a0c a0a a0b
:6 0 a0f 14 :3 0
4d2 a11 4d4 a10
a0f :2 0 a12 4d6
:2 0 a14 0 a14
a13 9c1 a12 :6 0
b25 1 :3 0 9
:3 0 5b :3 0 a16
a17 0 de :4 0
a19 a1a :3 0 a18
a1b 0 b25 df
:3 0 59 :3 0 b7
:3 0 a1 :3 0 ad
:3 0 a1 :3 0 c9
:3 0 a2 :3 0 55
:3 0 a3 :3 0 ca
:3 0 a1 :3 0 55
:3 0 a5 :3 0 a1
:3 0 ad :3 0 55
:3 0 9a :3 0 a3
:3 0 a4 :3 0 c4
:3 0 c4 :3 0 59
:3 0 a1 :3 0 cb
:3 0 a3 :3 0 a4
:3 0 ba :3 0 ba
:3 0 59 :3 0 c4
:3 0 9b :3 0 a3
:3 0 76 :3 0 d9
:3 0 d9 :3 0 ce
:3 0 55 :3 0 ce
:3 0 d9 :3 0 d8
:3 0 55 :3 0 53
:3 0 d :3 0 55
:3 0 e0 :4 0 e1
1 :8 0 a61 a7
:4 0 a4c :3 0 4e
:3 0 4f :2 0 4db
a4f a50 :3 0 9
:3 0 5b :3 0 a52
a53 0 16 :2 0
a54 a55 0 a57
4de a5e 9 :3 0
5b :3 0 a58 a59
0 a8 :2 0 a5a
a5b 0 a5d 4e0
a5f a51 a57 0
a60 0 a5d 0
a60 4e2 0 a61
4e5 ab4 5d :3 0
9 :3 0 5b :3 0
a63 a64 0 5c
:3 0 a65 a66 0
a68 4e8 a6a 4ea
a69 a68 :2 0 ab2
5e :3 0 9 :3 0
5b :3 0 a6d a6e
0 5c :3 0 a6f
a70 0 aaa 2c
:3 0 2d :3 0 a72
a73 0 2c :3 0
3d :3 0 a75 a76
0 5f :2 0 2
:4 0 e2 :2 0 3f
:2 0 14 :2 0 4ec
a7b a7d :3 0 4ef
a77 a7f a74 a81
a80 :2 0 2f :3 0
40 :3 0 a83 a84
0 31 :4 0 e3
:4 0 34 :2 0 35
:3 0 4f3 a88 a8a
:3 0 34 :2 0 45
:4 0 4f6 a8c a8e
:3 0 34 :2 0 62
:4 0 4f9 a90 a92
:3 0 34 :2 0 5c
:3 0 4fc a94 a96
:3 0 34 :2 0 63
:4 0 4ff a98 a9a
:3 0 34 :2 0 64
:3 0 65 :3 0 14
:2 0 66 :2 0 502
a9d aa1 506 a9c
aa3 :3 0 509 a85
aa5 :2 0 aa7 50c
aa8 a82 aa7 0
aa9 50e 0 aaa
510 aad :3 0 aad
0 aad aac aaa
aab :6 0 aaf 16
:3 0 513 ab1 515
ab0 aaf :2 0 ab2
517 :2 0 ab4 0
ab4 ab3 a61 ab2
:6 0 b25 1 :3 0
b1 :3 0 1d :3 0
55 :3 0 9a :3 0
59 :3 0 ce :3 0
b5 :3 0 b6 :3 0
b7 :3 0 55 :3 0
54 :3 0 b5 :3 0
b9 :3 0 e4 :3 0
e5 :3 0 e4 :3 0
e6 :3 0 e7 :3 0
e4 :3 0 e8 :3 0
e4 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 17 :3 0
56 :3 0 ed :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 c2 :3 0
82 :3 0 d6 :3 0
55 :3 0 a3 :3 0
c3 :3 0 b5 :3 0
55 :3 0 9a :3 0
b5 :3 0 9a :3 0
59 :3 0 ce :3 0
b7 :3 0 54 :3 0
b9 :3 0 e4 :3 0
e5 :3 0 e4 :3 0
e6 :3 0 e7 :3 0
e4 :3 0 e8 :3 0
e4 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 17 :3 0
56 :3 0 ed :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 c2 :3 0
82 :3 0 df :3 0
54 :4 0 f3 1
:a 0 b01 :2 0 b25
ab7 aff :2 0 2c
:3 0 2d :3 0 b02
b03 0 2c :3 0
3d :3 0 b05 b06
0 14 :2 0 2
:4 0 f4 :2 0 3f
:2 0 14 :2 0 51a
b0b b0d :3 0 51d
b07 b0f b04 b11
b10 :2 0 2f :3 0
40 :3 0 b13 b14
0 31 :4 0 f5
:4 0 34 :2 0 35
:3 0 521 b18 b1a
:3 0 524 b15 b1c
:2 0 b1e 527 b1f
b12 b1e 0 b20
529 0 b25 8
:3 0 1d :3 0 b22
:2 0 b25 74 :3 0
52b b26 97a b25
0 1fda 39 :3 0
15 :3 0 16 :2 0
534 b27 b2a 4f
:2 0 50 :2 0 539
b2c b2e :3 0 b1
:3 0 1e :3 0 d9
:3 0 77 :3 0 d9
:3 0 77 :3 0 55
:3 0 ce :3 0 59
:3 0 55 :3 0 ad
:3 0 b5 :3 0 c9
:3 0 b7 :3 0 54
:3 0 55 :3 0 ce
:3 0 55 :3 0 f6
:3 0 d9 :3 0 e5
:3 0 d9 :3 0 e6
:3 0 d9 :3 0 f0
:3 0 d9 :3 0 f7
:3 0 d9 :3 0 f8
:3 0 17 :3 0 56
:3 0 55 :3 0 f9
:3 0 55 :3 0 fa
:3 0 fb :3 0 b7
:3 0 fc :3 0 39
:3 0 55 :3 0 fd
:3 0 55 :3 0 fa
:3 0 fd :3 0 fe
:3 0 b7 :3 0 ff
:3 0 d9 :3 0 be
:3 0 d9 :3 0 100
:3 0 d9 :3 0 c0
:3 0 d9 :3 0 101
:3 0 102 :3 0 55
:3 0 103 :3 0 d9
:3 0 f2 :3 0 d9
:3 0 d8 :3 0 d9
:3 0 104 :3 0 105
:3 0 b7 :3 0 106
:3 0 d9 :3 0 ec
:3 0 d9 :3 0 107
:3 0 d9 :3 0 108
:3 0 d9 :3 0 109
:3 0 d9 :3 0 10a
:3 0 d9 :3 0 10b
:3 0 10c :3 0 d9
:3 0 10d :3 0 a2
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 76 :3 0 d9
:3 0 d9 :3 0 da
:3 0 d :3 0 55
:3 0 ce :3 0 d9
:3 0 ce :3 0 c5
:3 0 c6 :3 0 a3
:3 0 ca :3 0 b5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 ad
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10f :3 0 105
:3 0 105 :3 0 59
:3 0 d9 :3 0 104
:3 0 55 :3 0 59
:3 0 d :3 0 55
:3 0 a5 :3 0 b7
:4 0 110 1 :a 0
bbf :2 0 be3 b31
bbd :2 0 2c :3 0
2d :3 0 bc0 bc1
0 2c :3 0 3d
:3 0 bc3 bc4 0
14 :2 0 2 :4 0
111 :2 0 3f :2 0
14 :2 0 53c bc9
bcb :3 0 53f bc5
bcd bc2 bcf bce
:2 0 2f :3 0 40
:3 0 bd1 bd2 0
31 :4 0 112 :4 0
34 :2 0 35 :3 0
543 bd6 bd8 :3 0
546 bd3 bda :2 0
bdc 549 bdd bd0
bdc 0 bde 54b
0 be3 8 :3 0
1e :3 0 be0 :2 0
be3 74 :3 0 54d
be4 b2f be3 0
1fda 39 :3 0 15
:3 0 16 :2 0 551
be5 be8 4f :2 0
51 :2 0 556 bea
bec :3 0 113 :3 0
39 :3 0 18 :3 0
16 :2 0 559 bef
bf2 55c bee bf4
8b :2 0 16 :2 0
560 bf6 bf8 :3 0
19 :3 0 16 :2 0
bfa bfb 0 faa
114 :3 0 19 :3 0
76 :3 0 53 :3 0
10 :3 0 da :3 0
d :4 0 115 1
:8 0 c0a 9 :3 0
5b :3 0 c05 c06
0 5c :3 0 c07
c08 0 c0a 563
c5d 5d :3 0 9
:3 0 5b :3 0 c0c
c0d 0 5c :3 0
c0e c0f 0 c11
566 c13 568 c12
c11 :2 0 c5b 5e
:3 0 9 :3 0 5b
:3 0 c16 c17 0
5c :3 0 c18 c19
0 c53 2c :3 0
2d :3 0 c1b c1c
0 2c :3 0 3d
:3 0 c1e c1f 0
5f :2 0 2 :4 0
116 :2 0 3f :2 0
14 :2 0 56a c24
c26 :3 0 56d c20
c28 c1d c2a c29
:2 0 2f :3 0 40
:3 0 c2c c2d 0
31 :4 0 117 :4 0
34 :2 0 35 :3 0
571 c31 c33 :3 0
34 :2 0 45 :4 0
574 c35 c37 :3 0
34 :2 0 62 :4 0
577 c39 c3b :3 0
34 :2 0 5c :3 0
57a c3d c3f :3 0
34 :2 0 63 :4 0
57d c41 c43 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 580 c46
c4a 584 c45 c4c
:3 0 587 c2e c4e
:2 0 c50 58a c51
c2b c50 0 c52
58c 0 c53 58e
c56 :3 0 c56 0
c56 c55 c53 c54
:6 0 c58 18 :3 0
591 c5a 593 c59
c58 :2 0 c5b 595
:2 0 c5d 0 c5d
c5c c0a c5b :6 0
faa 1 :3 0 39
:3 0 19 :3 0 16
:2 0 598 c5f c62
4f :2 0 16 :2 0
59d c64 c66 :3 0
13 :3 0 14 :4 0
c68 c69 0 c6b
5a0 d70 19 :3 0
16 :2 0 c6c c6d
0 d6f 114 :3 0
19 :3 0 118 :3 0
76 :3 0 53 :3 0
10 :3 0 da :3 0
d :3 0 119 :4 0
11a 1 :8 0 c7e
9 :3 0 5b :3 0
c79 c7a 0 5c
:3 0 c7b c7c 0
c7e 5a2 cd1 5d
:3 0 9 :3 0 5b
:3 0 c80 c81 0
5c :3 0 c82 c83
0 c85 5a5 c87
5a7 c86 c85 :2 0
ccf 5e :3 0 9
:3 0 5b :3 0 c8a
c8b 0 5c :3 0
c8c c8d 0 cc7
2c :3 0 2d :3 0
c8f c90 0 2c
:3 0 3d :3 0 c92
c93 0 5f :2 0
2 :4 0 11b :2 0
3f :2 0 14 :2 0
5a9 c98 c9a :3 0
5ac c94 c9c c91
c9e c9d :2 0 2f
:3 0 40 :3 0 ca0
ca1 0 31 :4 0
11c :4 0 34 :2 0
35 :3 0 5b0 ca5
ca7 :3 0 34 :2 0
45 :4 0 5b3 ca9
cab :3 0 34 :2 0
62 :4 0 5b6 cad
caf :3 0 34 :2 0
5c :3 0 5b9 cb1
cb3 :3 0 34 :2 0
63 :4 0 5bc cb5
cb7 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
5bf cba cbe 5c3
cb9 cc0 :3 0 5c6
ca2 cc2 :2 0 cc4
5c9 cc5 c9f cc4
0 cc6 5cb 0
cc7 5cd cca :3 0
cca 0 cca cc9
cc7 cc8 :6 0 ccc
1a :3 0 5d0 cce
5d2 ccd ccc :2 0
ccf 5d4 :2 0 cd1
0 cd1 cd0 c7e
ccf :6 0 d6f 1
:3 0 39 :3 0 19
:3 0 16 :2 0 5d7
cd3 cd6 4f :2 0
16 :2 0 5dc cd8
cda :3 0 114 :3 0
19 :3 0 118 :3 0
76 :3 0 b2 :3 0
a3 :3 0 11d :3 0
11e :3 0 11e :3 0
59 :3 0 b2 :3 0
53 :3 0 11e :3 0
9a :3 0 b2 :3 0
9a :3 0 b2 :3 0
53 :3 0 10 :3 0
b2 :3 0 da :3 0
d :3 0 11f :3 0
64 :3 0 b2 :3 0
120 :3 0 11e :3 0
121 :4 0 122 1
:8 0 cfe 9 :3 0
5b :3 0 cf9 cfa
0 5c :3 0 cfb
cfc 0 cfe 5df
d51 5d :3 0 9
:3 0 5b :3 0 d00
d01 0 5c :3 0
d02 d03 0 d05
5e2 d07 5e4 d06
d05 :2 0 d4f 5e
:3 0 9 :3 0 5b
:3 0 d0a d0b 0
5c :3 0 d0c d0d
0 d47 2c :3 0
2d :3 0 d0f d10
0 2c :3 0 3d
:3 0 d12 d13 0
5f :2 0 2 :4 0
123 :2 0 3f :2 0
14 :2 0 5e6 d18
d1a :3 0 5e9 d14
d1c d11 d1e d1d
:2 0 2f :3 0 40
:3 0 d20 d21 0
31 :4 0 124 :4 0
34 :2 0 35 :3 0
5ed d25 d27 :3 0
34 :2 0 45 :4 0
5f0 d29 d2b :3 0
34 :2 0 62 :4 0
5f3 d2d d2f :3 0
34 :2 0 5c :3 0
5f6 d31 d33 :3 0
34 :2 0 63 :4 0
5f9 d35 d37 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 5fc d3a
d3e 600 d39 d40
:3 0 603 d22 d42
:2 0 d44 606 d45
d1f d44 0 d46
608 0 d47 60a
d4a :3 0 d4a 0
d4a d49 d47 d48
:6 0 d4c 1c :3 0
60d d4e 60f d4d
d4c :2 0 d4f 611
:2 0 d51 0 d51
d50 cfe d4f :6 0
d67 1 :3 0 39
:3 0 19 :3 0 16
:2 0 614 d53 d56
4f :2 0 16 :2 0
619 d58 d5a :3 0
13 :3 0 50 :4 0
d5c d5d 0 d5f
61c d64 13 :3 0
14 :4 0 d60 d61
0 d63 61e d65
d5b d5f 0 d66
0 d63 0 d66
620 0 d67 623
d6c 13 :3 0 14
:4 0 d68 d69 0
d6b 626 d6d cdb
d67 0 d6e 0
d6b 0 d6e 628
0 d6f 62b d71
c67 c6b 0 d72
0 d6f 0 d72
62f 0 faa b1
:3 0 1f :3 0 d9
:3 0 59 :3 0 55
:3 0 9a :3 0 d9
:3 0 b7 :3 0 d9
:3 0 54 :3 0 ce
:3 0 55 :3 0 f6
:3 0 d9 :3 0 f7
:3 0 d9 :3 0 f8
:3 0 d9 :3 0 125
:3 0 d9 :3 0 126
:3 0 d9 :3 0 f7
:3 0 e5 :3 0 d9
:3 0 f8 :3 0 e6
:3 0 d9 :3 0 127
:3 0 d9 :3 0 e7
:3 0 f0 :3 0 d9
:3 0 127 :3 0 d9
:3 0 e7 :3 0 d9
:3 0 128 :3 0 eb
:3 0 129 :3 0 d9
:3 0 12a :3 0 d9
:3 0 128 :3 0 12b
:3 0 12c :3 0 d9
:3 0 128 :3 0 12c
:3 0 d9 :3 0 127
:3 0 d9 :3 0 e7
:3 0 12d :3 0 e4
:3 0 12e :3 0 e4
:3 0 12f :3 0 130
:3 0 d9 :3 0 131
:3 0 d9 :3 0 132
:3 0 d9 :3 0 133
:3 0 d9 :3 0 120
:3 0 d9 :3 0 134
:3 0 d9 :3 0 128
:3 0 135 :3 0 d9
:3 0 136 :3 0 d9
:3 0 137 :3 0 d9
:3 0 138 :3 0 139
:3 0 17 :3 0 56
:3 0 f9 :3 0 fa
:3 0 fc :3 0 fd
:3 0 ff :3 0 be
:3 0 100 :3 0 c0
:3 0 101 :3 0 102
:3 0 d9 :3 0 103
:3 0 13a :3 0 13b
:3 0 f2 :3 0 d9
:3 0 13c :3 0 d9
:3 0 13d :3 0 d9
:3 0 13e :3 0 13f
:3 0 d8 :3 0 104
:3 0 140 :3 0 ec
:3 0 107 :3 0 108
:3 0 109 :3 0 10a
:3 0 10b :3 0 10c
:3 0 141 :3 0 10d
:3 0 13 :3 0 119
:3 0 142 :3 0 d9
:3 0 143 :3 0 d9
:3 0 144 :3 0 1b
:3 0 d9 :3 0 145
:3 0 e4 :3 0 145
:3 0 1b :3 0 d9
:3 0 146 :3 0 e4
:3 0 146 :3 0 1b
:3 0 d9 :3 0 147
:3 0 148 :3 0 d9
:3 0 12d :3 0 149
:3 0 14a :3 0 14b
:3 0 14c :3 0 14d
:3 0 14e :3 0 14f
:3 0 150 :3 0 151
:3 0 152 :3 0 153
:3 0 58 :3 0 d9
:3 0 c5 :3 0 a3
:3 0 a2 :3 0 55
:3 0 55 :3 0 59
:3 0 d9 :3 0 59
:3 0 55 :3 0 9a
:3 0 f :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fb
:3 0 55 :3 0 fa
:3 0 fb :3 0 59
:3 0 d9 :3 0 53
:3 0 10 :3 0 d9
:3 0 59 :3 0 d
:3 0 d9 :3 0 77
:3 0 d9 :3 0 77
:3 0 55 :3 0 ce
:3 0 59 :3 0 55
:3 0 9a :3 0 55
:3 0 a5 :3 0 b5
:3 0 c9 :3 0 ca
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 ad :3 0 a1
:3 0 b6 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 b7
:3 0 55 :3 0 a5
:3 0 d9 :3 0 77
:3 0 54 :3 0 55
:3 0 ce :3 0 55
:3 0 f6 :3 0 d9
:3 0 f7 :3 0 39
:3 0 e6 :3 0 154
:3 0 f8 :3 0 d9
:3 0 125 :3 0 47
:3 0 155 :3 0 d9
:3 0 125 :3 0 47
:3 0 156 :3 0 47
:3 0 157 :3 0 d9
:3 0 125 :3 0 125
:3 0 d9 :3 0 126
:3 0 47 :3 0 158
:3 0 47 :3 0 159
:3 0 d9 :3 0 126
:3 0 126 :3 0 39
:3 0 e5 :3 0 15a
:3 0 e5 :3 0 39
:3 0 e6 :3 0 154
:3 0 e6 :3 0 d9
:3 0 119 :3 0 d9
:3 0 15b :3 0 d9
:3 0 f0 :3 0 f0
:3 0 d9 :3 0 119
:3 0 d9 :3 0 15b
:3 0 d9 :3 0 128
:3 0 d9 :3 0 f0
:3 0 eb :3 0 d9
:3 0 15c :3 0 d9
:3 0 15d :3 0 d9
:3 0 15c :3 0 d9
:3 0 15d :3 0 129
:3 0 12a :3 0 d9
:3 0 128 :3 0 12b
:3 0 12c :3 0 d9
:3 0 128 :3 0 12c
:3 0 f0 :3 0 15b
:3 0 12d :3 0 d9
:3 0 12e :3 0 d9
:3 0 12f :3 0 d9
:3 0 130 :3 0 d9
:3 0 131 :3 0 d9
:3 0 132 :3 0 d9
:3 0 133 :3 0 d9
:3 0 120 :3 0 d9
:3 0 134 :3 0 d9
:3 0 128 :3 0 135
:3 0 136 :3 0 137
:3 0 139 :3 0 17
:3 0 56 :3 0 55
:3 0 f9 :3 0 55
:3 0 fa :3 0 fb
:3 0 b7 :3 0 fc
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fd
:3 0 fe :3 0 b7
:3 0 ff :3 0 d9
:3 0 be :3 0 d9
:3 0 100 :3 0 d9
:3 0 c0 :3 0 d9
:3 0 101 :3 0 55
:3 0 a5 :3 0 a1
:3 0 102 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 102
:3 0 55 :3 0 103
:3 0 d9 :3 0 f2
:3 0 d9 :3 0 13c
:3 0 d9 :3 0 13d
:3 0 d9 :3 0 13f
:3 0 d9 :3 0 d8
:3 0 d9 :3 0 104
:3 0 105 :3 0 b7
:3 0 140 :3 0 d9
:3 0 ec :3 0 d9
:3 0 107 :3 0 d9
:3 0 108 :3 0 d9
:3 0 109 :3 0 d9
:3 0 10a :3 0 d9
:3 0 10b :3 0 d9
:3 0 10c :3 0 d9
:3 0 141 :3 0 d9
:3 0 10d :3 0 d9
:3 0 119 :3 0 d9
:3 0 119 :3 0 119
:3 0 d9 :3 0 142
:3 0 143 :3 0 d9
:3 0 119 :3 0 d9
:3 0 15e :3 0 d9
:3 0 15f :3 0 144
:3 0 1b :3 0 39
:3 0 d9 :3 0 145
:3 0 d9 :3 0 160
:3 0 e4 :3 0 145
:3 0 1b :3 0 39
:3 0 d9 :3 0 146
:3 0 d9 :3 0 161
:3 0 e4 :3 0 146
:3 0 1b :3 0 d9
:3 0 148 :3 0 d9
:3 0 133 :3 0 d9
:3 0 148 :3 0 148
:3 0 d9 :3 0 12a
:3 0 149 :3 0 14a
:3 0 14b :3 0 d9
:3 0 14c :3 0 162
:3 0 b7 :3 0 14d
:3 0 d9 :3 0 14e
:3 0 163 :3 0 b7
:3 0 14f :3 0 d9
:3 0 150 :3 0 d9
:3 0 151 :3 0 164
:3 0 b7 :3 0 152
:3 0 55 :3 0 a5
:3 0 a1 :3 0 153
:3 0 c3 :3 0 a1
:3 0 55 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 153 :3 0 a2
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 76 :3 0 d9
:3 0 55 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10f :3 0 105
:3 0 105 :3 0 59
:3 0 d9 :3 0 104
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 165
:3 0 162 :3 0 162
:3 0 59 :3 0 d9
:3 0 14c :3 0 c5
:3 0 c6 :3 0 a3
:3 0 165 :3 0 163
:3 0 163 :3 0 59
:3 0 d9 :3 0 14e
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 166
:3 0 164 :3 0 164
:3 0 59 :3 0 d9
:3 0 151 :3 0 55
:3 0 53 :3 0 10
:3 0 55 :3 0 59
:3 0 d :3 0 55
:3 0 103 :3 0 14a
:3 0 b7 :4 0 167
1 :a 0 f87 :2 0
faa d74 f85 :2 0
2c :3 0 2d :3 0
f88 f89 0 2c
:3 0 3d :3 0 f8b
f8c 0 14 :2 0
2 :4 0 168 :2 0
3f :2 0 14 :2 0
632 f91 f93 :3 0
635 f8d f95 f8a
f97 f96 :2 0 2f
:3 0 40 :3 0 f99
f9a 0 31 :4 0
169 :4 0 34 :2 0
35 :3 0 639 f9e
fa0 :3 0 63c f9b
fa2 :2 0 fa4 63f
fa5 f98 fa4 0
fa6 641 0 faa
8 :3 0 1f :3 0
fa8 :2 0 faa 643
111f b1 :3 0 20
:3 0 d9 :3 0 77
:3 0 d9 :3 0 77
:3 0 55 :3 0 ce
:3 0 59 :3 0 55
:3 0 9a :3 0 55
:3 0 a5 :3 0 a1
:3 0 b6 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 55
:3 0 a5 :3 0 b5
:3 0 c9 :3 0 ca
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 ad :3 0 55
:3 0 a5 :3 0 b5
:3 0 b7 :3 0 6c
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b5
:3 0 b7 :3 0 16a
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b7
:3 0 55 :3 0 a5
:3 0 47 :3 0 16b
:3 0 55 :3 0 a5
:3 0 47 :3 0 16c
:3 0 55 :3 0 a5
:3 0 47 :3 0 16d
:3 0 d9 :3 0 77
:3 0 47 :3 0 16e
:3 0 54 :3 0 55
:3 0 ce :3 0 55
:3 0 f6 :3 0 d9
:3 0 f7 :3 0 d9
:3 0 f8 :3 0 d9
:3 0 125 :3 0 d9
:3 0 126 :3 0 39
:3 0 e5 :3 0 15a
:3 0 e5 :3 0 39
:3 0 e6 :3 0 154
:3 0 e6 :3 0 d9
:3 0 16f :3 0 f0
:3 0 d9 :3 0 119
:3 0 d9 :3 0 15b
:3 0 d9 :3 0 f0
:3 0 eb :3 0 d9
:3 0 15d :3 0 129
:3 0 d9 :3 0 12a
:3 0 12d :3 0 d9
:3 0 12e :3 0 d9
:3 0 12f :3 0 d9
:3 0 130 :3 0 d9
:3 0 131 :3 0 d9
:3 0 132 :3 0 d9
:3 0 133 :3 0 d9
:3 0 120 :3 0 d9
:3 0 134 :3 0 d9
:3 0 128 :3 0 135
:3 0 136 :3 0 137
:3 0 139 :3 0 17
:3 0 56 :3 0 55
:3 0 f9 :3 0 55
:3 0 fa :3 0 fb
:3 0 b7 :3 0 fc
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fd
:3 0 fe :3 0 b7
:3 0 ff :3 0 d9
:3 0 be :3 0 d9
:3 0 100 :3 0 d9
:3 0 c0 :3 0 d9
:3 0 101 :3 0 55
:3 0 a5 :3 0 a1
:3 0 102 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 102
:3 0 55 :3 0 103
:3 0 d9 :3 0 f2
:3 0 d9 :3 0 13c
:3 0 d9 :3 0 13d
:3 0 d9 :3 0 13f
:3 0 d9 :3 0 d8
:3 0 d9 :3 0 104
:3 0 105 :3 0 b7
:3 0 140 :3 0 d9
:3 0 ec :3 0 d9
:3 0 107 :3 0 d9
:3 0 108 :3 0 d9
:3 0 109 :3 0 d9
:3 0 10a :3 0 d9
:3 0 10b :3 0 d9
:3 0 10c :3 0 d9
:3 0 141 :3 0 d9
:3 0 10d :3 0 d9
:3 0 119 :3 0 d9
:3 0 119 :3 0 119
:3 0 d9 :3 0 142
:3 0 143 :3 0 144
:3 0 d9 :3 0 145
:3 0 d9 :3 0 146
:3 0 d9 :3 0 148
:3 0 d9 :3 0 12a
:3 0 149 :3 0 14a
:3 0 d9 :3 0 77
:3 0 d9 :3 0 d8
:3 0 d9 :3 0 77
:3 0 d9 :3 0 145
:3 0 d9 :3 0 160
:3 0 d9 :3 0 146
:3 0 d9 :3 0 161
:3 0 14b :3 0 d9
:3 0 14c :3 0 162
:3 0 b7 :3 0 14d
:3 0 d9 :3 0 14e
:3 0 163 :3 0 b7
:3 0 14f :3 0 d9
:3 0 150 :3 0 d9
:3 0 151 :3 0 164
:3 0 b7 :3 0 152
:3 0 55 :3 0 a5
:3 0 a1 :3 0 153
:3 0 c3 :3 0 a1
:3 0 55 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 153 :3 0 a2
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 76 :3 0 d9
:3 0 55 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10f :3 0 105
:3 0 105 :3 0 59
:3 0 d9 :3 0 104
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 165
:3 0 162 :3 0 162
:3 0 59 :3 0 d9
:3 0 14c :3 0 c5
:3 0 c6 :3 0 a3
:3 0 165 :3 0 163
:3 0 163 :3 0 59
:3 0 d9 :3 0 14e
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 166
:3 0 164 :3 0 164
:3 0 59 :3 0 d9
:3 0 151 :3 0 55
:3 0 103 :3 0 55
:3 0 59 :3 0 d
:3 0 54 :3 0 b7
:4 0 170 1 :a 0
10fb :2 0 111e fac
10f9 :2 0 2c :3 0
2d :3 0 10fc 10fd
0 2c :3 0 3d
:3 0 10ff 1100 0
14 :2 0 2 :4 0
171 :2 0 3f :2 0
14 :2 0 64a 1105
1107 :3 0 64d 1101
1109 10fe 110b 110a
:2 0 2f :3 0 40
:3 0 110d 110e 0
31 :4 0 172 :4 0
34 :2 0 35 :3 0
651 1112 1114 :3 0
654 110f 1116 :2 0
1118 657 1119 110c
1118 0 111a 659
0 111e 8 :3 0
20 :3 0 111c :2 0
111e 65b 1120 bf9
faa 0 1121 0
111e 0 1121 65f
0 1123 74 :3 0
662 1124 bed 1123
0 1fda 39 :3 0
15 :3 0 16 :2 0
664 1125 1128 4f
:2 0 173 :2 0 669
112a 112c :3 0 96
:3 0 97 :3 0 174
:4 0 1130 :4 0 1131
:2 0 12e3 9 :3 0
5b :3 0 1133 1134
0 16 :2 0 1135
1136 0 12e3 175
:3 0 9a :3 0 a5
:3 0 e5 :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 9a
:3 0 a5 :3 0 176
:3 0 e5 :3 0 e5
:3 0 177 :3 0 e6
:3 0 e6 :3 0 178
:3 0 f0 :3 0 e7
:3 0 176 :3 0 15a
:3 0 e8 :3 0 177
:3 0 154 :3 0 e9
:3 0 178 :3 0 15b
:3 0 ea :3 0 178
:3 0 133 :3 0 eb
:3 0 76 :3 0 53
:3 0 d :3 0 d8
:3 0 9a :3 0 a5
:4 0 179 1 :8 0
1175 a7 :4 0 1160
:3 0 4e :3 0 4f
:2 0 66e 1163 1164
:3 0 9 :3 0 5b
:3 0 1166 1167 0
16 :2 0 1168 1169
0 116b 671 1172
9 :3 0 5b :3 0
116c 116d 0 a8
:2 0 116e 116f 0
1171 673 1173 1165
116b 0 1174 0
1171 0 1174 675
0 1175 678 11c8
5d :3 0 9 :3 0
5b :3 0 1177 1178
0 5c :3 0 1179
117a 0 117c 67b
117e 67d 117d 117c
:2 0 11c6 5e :3 0
9 :3 0 5b :3 0
1181 1182 0 5c
:3 0 1183 1184 0
11be 2c :3 0 2d
:3 0 1186 1187 0
2c :3 0 3d :3 0
1189 118a 0 5f
:2 0 2 :4 0 17a
:2 0 3f :2 0 14
:2 0 67f 118f 1191
:3 0 682 118b 1193
1188 1195 1194 :2 0
2f :3 0 40 :3 0
1197 1198 0 31
:4 0 17b :4 0 34
:2 0 35 :3 0 686
119c 119e :3 0 34
:2 0 45 :4 0 689
11a0 11a2 :3 0 34
:2 0 62 :4 0 68c
11a4 11a6 :3 0 34
:2 0 5c :3 0 68f
11a8 11aa :3 0 34
:2 0 63 :4 0 692
11ac 11ae :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 695 11b1 11b5
699 11b0 11b7 :3 0
69c 1199 11b9 :2 0
11bb 69f 11bc 1196
11bb 0 11bd 6a1
0 11be 6a3 11c1
:3 0 11c1 0 11c1
11c0 11be 11bf :6 0
11c3 1e :3 0 6a6
11c5 6a8 11c4 11c3
:2 0 11c6 6aa :2 0
11c8 0 11c8 11c7
1175 11c6 :6 0 12e3
1 :3 0 9 :3 0
5b :3 0 11ca 11cb
0 de :4 0 11cd
11ce :3 0 11cc 11cf
0 12e3 df :3 0
59 :3 0 b7 :3 0
e5 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 a1 :3 0
ad :3 0 a1 :3 0
c9 :3 0 55 :3 0
e5 :3 0 55 :3 0
e6 :3 0 55 :3 0
e7 :3 0 55 :3 0
e8 :3 0 55 :3 0
e9 :3 0 55 :3 0
ea :3 0 55 :3 0
eb :3 0 175 :3 0
55 :3 0 a3 :3 0
ca :3 0 a1 :3 0
55 :3 0 a5 :3 0
a1 :3 0 ad :3 0
55 :3 0 9a :3 0
a3 :3 0 a4 :3 0
c4 :3 0 c4 :3 0
59 :3 0 a1 :3 0
cb :3 0 a3 :3 0
a4 :3 0 ba :3 0
ba :3 0 59 :3 0
c4 :3 0 9b :4 0
17c 1 :8 0 121c
a7 :4 0 1207 :3 0
4e :3 0 4f :2 0
6af 120a 120b :3 0
9 :3 0 5b :3 0
120d 120e 0 16
:2 0 120f 1210 0
1212 6b2 1219 9
:3 0 5b :3 0 1213
1214 0 a8 :2 0
1215 1216 0 1218
6b4 121a 120c 1212
0 121b 0 1218
0 121b 6b6 0
121c 6b9 126f 5d
:3 0 9 :3 0 5b
:3 0 121e 121f 0
5c :3 0 1220 1221
0 1223 6bc 1225
6be 1224 1223 :2 0
126d 5e :3 0 9
:3 0 5b :3 0 1228
1229 0 5c :3 0
122a 122b 0 1265
2c :3 0 2d :3 0
122d 122e 0 2c
:3 0 3d :3 0 1230
1231 0 5f :2 0
2 :4 0 17d :2 0
3f :2 0 14 :2 0
6c0 1236 1238 :3 0
6c3 1232 123a 122f
123c 123b :2 0 2f
:3 0 40 :3 0 123e
123f 0 31 :4 0
17e :4 0 34 :2 0
35 :3 0 6c7 1243
1245 :3 0 34 :2 0
45 :4 0 6ca 1247
1249 :3 0 34 :2 0
62 :4 0 6cd 124b
124d :3 0 34 :2 0
5c :3 0 6d0 124f
1251 :3 0 34 :2 0
63 :4 0 6d3 1253
1255 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
6d6 1258 125c 6da
1257 125e :3 0 6dd
1240 1260 :2 0 1262
6e0 1263 123d 1262
0 1264 6e2 0
1265 6e4 1268 :3 0
1268 0 1268 1267
1265 1266 :6 0 126a
20 :3 0 6e7 126c
6e9 126b 126a :2 0
126d 6eb :2 0 126f
0 126f 126e 121c
126d :6 0 12e3 1
:3 0 b1 :3 0 21
:3 0 55 :3 0 9a
:3 0 59 :3 0 ce
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 54
:3 0 b5 :3 0 b9
:3 0 55 :3 0 e5
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 e8
:3 0 55 :3 0 e9
:3 0 55 :3 0 ea
:3 0 55 :3 0 eb
:3 0 ec :3 0 17
:3 0 56 :3 0 ed
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 b5
:3 0 102 :3 0 c2
:3 0 82 :3 0 175
:3 0 55 :3 0 a3
:3 0 c3 :3 0 b5
:3 0 55 :3 0 a5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 59 :3 0 ce
:3 0 b7 :3 0 54
:3 0 b9 :3 0 e5
:3 0 e6 :3 0 e7
:3 0 e8 :3 0 e9
:3 0 ea :3 0 eb
:3 0 ec :3 0 17
:3 0 56 :3 0 ed
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 102
:3 0 c2 :3 0 82
:3 0 df :3 0 54
:4 0 17f 1 :a 0
12bf :2 0 12e3 1272
12bd :2 0 2c :3 0
2d :3 0 12c0 12c1
0 2c :3 0 3d
:3 0 12c3 12c4 0
14 :2 0 2 :4 0
180 :2 0 3f :2 0
14 :2 0 6ee 12c9
12cb :3 0 6f1 12c5
12cd 12c2 12cf 12ce
:2 0 2f :3 0 40
:3 0 12d1 12d2 0
31 :4 0 181 :4 0
34 :2 0 35 :3 0
6f5 12d6 12d8 :3 0
6f8 12d3 12da :2 0
12dc 6fb 12dd 12d0
12dc 0 12de 6fd
0 12e3 8 :3 0
21 :3 0 12e0 :2 0
12e3 74 :3 0 6ff
12e4 112d 12e3 0
1fda 39 :3 0 15
:3 0 16 :2 0 708
12e5 12e8 4f :2 0
182 :2 0 70d 12ea
12ec :3 0 96 :3 0
97 :3 0 174 :4 0
12f0 :4 0 12f1 :2 0
14ee 9 :3 0 5b
:3 0 12f3 12f4 0
16 :2 0 12f5 12f6
0 14ee 175 :3 0
9a :3 0 a5 :3 0
e5 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 9a :3 0
a5 :3 0 176 :3 0
e5 :3 0 e5 :3 0
177 :3 0 e6 :3 0
e6 :3 0 178 :3 0
f0 :3 0 e7 :3 0
176 :3 0 15a :3 0
e8 :3 0 177 :3 0
154 :3 0 e9 :3 0
178 :3 0 15b :3 0
ea :3 0 178 :3 0
133 :3 0 eb :3 0
76 :3 0 53 :3 0
d :3 0 d8 :3 0
9a :3 0 a5 :4 0
179 1 :8 0 1335
a7 :4 0 1320 :3 0
4e :3 0 4f :2 0
712 1323 1324 :3 0
9 :3 0 5b :3 0
1326 1327 0 16
:2 0 1328 1329 0
132b 715 1332 9
:3 0 5b :3 0 132c
132d 0 a8 :2 0
132e 132f 0 1331
717 1333 1325 132b
0 1334 0 1331
0 1334 719 0
1335 71c 1388 5d
:3 0 9 :3 0 5b
:3 0 1337 1338 0
5c :3 0 1339 133a
0 133c 71f 133e
721 133d 133c :2 0
1386 5e :3 0 9
:3 0 5b :3 0 1341
1342 0 5c :3 0
1343 1344 0 137e
2c :3 0 2d :3 0
1346 1347 0 2c
:3 0 3d :3 0 1349
134a 0 5f :2 0
2 :4 0 183 :2 0
3f :2 0 14 :2 0
723 134f 1351 :3 0
726 134b 1353 1348
1355 1354 :2 0 2f
:3 0 40 :3 0 1357
1358 0 31 :4 0
184 :4 0 34 :2 0
35 :3 0 72a 135c
135e :3 0 34 :2 0
45 :4 0 72d 1360
1362 :3 0 34 :2 0
62 :4 0 730 1364
1366 :3 0 34 :2 0
5c :3 0 733 1368
136a :3 0 34 :2 0
63 :4 0 736 136c
136e :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
739 1371 1375 73d
1370 1377 :3 0 740
1359 1379 :2 0 137b
743 137c 1356 137b
0 137d 745 0
137e 747 1381 :3 0
1381 0 1381 1380
137e 137f :6 0 1383
22 :3 0 74a 1385
74c 1384 1383 :2 0
1386 74e :2 0 1388
0 1388 1387 1335
1386 :6 0 14ee 1
:3 0 9 :3 0 5b
:3 0 138a 138b 0
de :4 0 138d 138e
:3 0 138c 138f 0
14ee df :3 0 59
:3 0 b7 :3 0 a5
:3 0 54 :3 0 b9
:3 0 e5 :3 0 e6
:3 0 e7 :3 0 e8
:3 0 e9 :3 0 ea
:3 0 eb :3 0 102
:3 0 a1 :3 0 ad
:3 0 a1 :3 0 c9
:3 0 55 :3 0 e5
:3 0 55 :3 0 e6
:3 0 55 :3 0 e7
:3 0 55 :3 0 e8
:3 0 55 :3 0 e9
:3 0 55 :3 0 ea
:3 0 55 :3 0 eb
:3 0 175 :3 0 55
:3 0 a3 :3 0 ca
:3 0 a1 :3 0 55
:3 0 a5 :3 0 a1
:3 0 ad :3 0 55
:3 0 9a :3 0 a3
:3 0 a4 :3 0 c4
:3 0 c4 :3 0 59
:3 0 a1 :3 0 cb
:3 0 a3 :3 0 a4
:3 0 ba :3 0 ba
:3 0 59 :3 0 c4
:3 0 9b :3 0 d7
:3 0 9a :3 0 b5
:3 0 b6 :3 0 b5
:3 0 b9 :3 0 e4
:3 0 e4 :3 0 e4
:3 0 e4 :3 0 b5
:3 0 102 :3 0 a2
:3 0 d7 :3 0 c3
:3 0 b5 :3 0 d7
:3 0 53 :3 0 d
:3 0 d7 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 b2 :3 0 77
:3 0 76 :3 0 b2
:3 0 b2 :3 0 ce
:3 0 55 :3 0 ce
:3 0 a2 :3 0 55
:3 0 55 :3 0 53
:3 0 d7 :3 0 53
:3 0 55 :3 0 9a
:3 0 d7 :3 0 9a
:4 0 185 1 :8 0
1409 a7 :4 0 13f4
:3 0 4e :3 0 4f
:2 0 753 13f7 13f8
:3 0 9 :3 0 5b
:3 0 13fa 13fb 0
16 :2 0 13fc 13fd
0 13ff 756 1406
9 :3 0 5b :3 0
1400 1401 0 a8
:2 0 1402 1403 0
1405 758 1407 13f9
13ff 0 1408 0
1405 0 1408 75a
0 1409 75d 145c
5d :3 0 9 :3 0
5b :3 0 140b 140c
0 5c :3 0 140d
140e 0 1410 760
1412 762 1411 1410
:2 0 145a 5e :3 0
9 :3 0 5b :3 0
1415 1416 0 5c
:3 0 1417 1418 0
1452 2c :3 0 2d
:3 0 141a 141b 0
2c :3 0 3d :3 0
141d 141e 0 5f
:2 0 2 :4 0 186
:2 0 3f :2 0 14
:2 0 764 1423 1425
:3 0 767 141f 1427
141c 1429 1428 :2 0
2f :3 0 40 :3 0
142b 142c 0 31
:4 0 187 :4 0 34
:2 0 35 :3 0 76b
1430 1432 :3 0 34
:2 0 45 :4 0 76e
1434 1436 :3 0 34
:2 0 62 :4 0 771
1438 143a :3 0 34
:2 0 5c :3 0 774
143c 143e :3 0 34
:2 0 63 :4 0 777
1440 1442 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 77a 1445 1449
77e 1444 144b :3 0
781 142d 144d :2 0
144f 784 1450 142a
144f 0 1451 786
0 1452 788 1455
:3 0 1455 0 1455
1454 1452 1453 :6 0
1457 24 :3 0 78b
1459 78d 1458 1457
:2 0 145a 78f :2 0
145c 0 145c 145b
1409 145a :6 0 14ee
1 :3 0 b1 :3 0
22 :3 0 55 :3 0
9a :3 0 59 :3 0
ce :3 0 b5 :3 0
b6 :3 0 b7 :3 0
54 :3 0 b5 :3 0
b9 :3 0 55 :3 0
e5 :3 0 55 :3 0
e6 :3 0 55 :3 0
e7 :3 0 55 :3 0
e8 :3 0 55 :3 0
e9 :3 0 55 :3 0
ea :3 0 55 :3 0
eb :3 0 ec :3 0
17 :3 0 56 :3 0
ed :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
b5 :3 0 102 :3 0
c2 :3 0 82 :3 0
175 :3 0 55 :3 0
a3 :3 0 c3 :3 0
b5 :3 0 55 :3 0
a5 :3 0 55 :3 0
9a :3 0 b5 :3 0
9a :3 0 59 :3 0
ce :3 0 b7 :3 0
54 :3 0 b9 :3 0
e5 :3 0 e6 :3 0
e7 :3 0 e8 :3 0
e9 :3 0 ea :3 0
eb :3 0 ec :3 0
17 :3 0 56 :3 0
ed :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
102 :3 0 c2 :3 0
82 :3 0 df :3 0
a5 :3 0 54 :3 0
59 :3 0 ce :3 0
b7 :3 0 54 :3 0
b9 :3 0 e5 :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 17 :3 0
56 :3 0 ed :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 102 :3 0
c2 :3 0 82 :3 0
df :3 0 a5 :3 0
54 :3 0 54 :3 0
b7 :4 0 188 1
:a 0 14ca :2 0 14ee
145f 14c8 :2 0 2c
:3 0 2d :3 0 14cb
14cc 0 2c :3 0
3d :3 0 14ce 14cf
0 14 :2 0 2
:4 0 189 :2 0 3f
:2 0 14 :2 0 792
14d4 14d6 :3 0 795
14d0 14d8 14cd 14da
14d9 :2 0 2f :3 0
40 :3 0 14dc 14dd
0 31 :4 0 18a
:4 0 34 :2 0 35
:3 0 799 14e1 14e3
:3 0 79c 14de 14e5
:2 0 14e7 79f 14e8
14db 14e7 0 14e9
7a1 0 14ee 8
:3 0 22 :3 0 14eb
:2 0 14ee 74 :3 0
7a3 14ef 12ed 14ee
0 1fda 39 :3 0
15 :3 0 16 :2 0
7ac 14f0 14f3 4f
:2 0 18b :2 0 7b1
14f5 14f7 :3 0 b1
:3 0 23 :3 0 d9
:3 0 9a :3 0 59
:3 0 d9 :3 0 ce
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 54
:3 0 b5 :3 0 b9
:3 0 52 :3 0 e5
:3 0 52 :3 0 e6
:3 0 52 :3 0 16f
:3 0 e7 :3 0 52
:3 0 f0 :3 0 18c
:3 0 55 :3 0 12e
:3 0 e8 :3 0 55
:3 0 12f :3 0 e9
:3 0 55 :3 0 16f
:3 0 ea :3 0 55
:3 0 15b :3 0 eb
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 13a
:3 0 13b :3 0 f2
:3 0 b5 :3 0 102
:3 0 c2 :3 0 82
:3 0 18d :3 0 be
:3 0 18d :3 0 100
:3 0 18d :3 0 c0
:3 0 18d :3 0 101
:3 0 18d :3 0 18e
:3 0 18d :3 0 18f
:3 0 18d :3 0 190
:3 0 18d :3 0 191
:3 0 18d :3 0 192
:3 0 18d :3 0 193
:3 0 18d :3 0 194
:3 0 18d :3 0 195
:3 0 18d :3 0 196
:3 0 18d :3 0 197
:3 0 18d :3 0 198
:3 0 b5 :3 0 153
:3 0 a2 :3 0 d9
:3 0 a3 :3 0 199
:3 0 18d :3 0 18d
:3 0 53 :3 0 d
:3 0 18d :3 0 9a
:3 0 d9 :3 0 9a
:3 0 c5 :3 0 a3
:3 0 76 :3 0 55
:3 0 55 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 55 :3 0 119
:3 0 c5 :3 0 a3
:3 0 76 :3 0 52
:3 0 52 :3 0 ce
:3 0 d9 :3 0 ce
:3 0 52 :3 0 119
:3 0 a3 :3 0 c3
:3 0 b5 :3 0 d9
:3 0 9a :3 0 b5
:3 0 9a :3 0 d9
:3 0 59 :3 0 d
:3 0 d9 :3 0 a5
:3 0 55 :3 0 77
:3 0 52 :3 0 77
:3 0 d9 :3 0 9a
:3 0 59 :3 0 55
:3 0 ce :3 0 b5
:3 0 c9 :3 0 b7
:3 0 54 :3 0 b9
:3 0 d9 :3 0 e5
:3 0 d9 :3 0 e6
:3 0 d9 :3 0 16f
:3 0 e7 :3 0 d9
:3 0 f0 :3 0 18c
:3 0 e4 :3 0 e8
:3 0 e4 :3 0 e9
:3 0 ea :3 0 eb
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 d9
:3 0 f2 :3 0 102
:3 0 c2 :3 0 82
:3 0 18d :3 0 be
:3 0 18d :3 0 100
:3 0 18d :3 0 c0
:3 0 18d :3 0 101
:3 0 18d :3 0 18e
:3 0 18d :3 0 18f
:3 0 18d :3 0 190
:3 0 18d :3 0 191
:3 0 18d :3 0 192
:3 0 18d :3 0 193
:3 0 18d :3 0 194
:3 0 18d :3 0 195
:3 0 18d :3 0 196
:3 0 18d :3 0 197
:3 0 18d :3 0 198
:3 0 153 :3 0 a2
:3 0 55 :3 0 a3
:3 0 ca :3 0 b5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 ad
:3 0 a3 :3 0 76
:3 0 d9 :3 0 d9
:3 0 ce :3 0 55
:3 0 ce :3 0 a3
:3 0 199 :3 0 18d
:3 0 18d :3 0 53
:3 0 d :3 0 18d
:3 0 9a :3 0 55
:3 0 9a :3 0 55
:3 0 59 :3 0 d
:3 0 55 :3 0 a5
:3 0 54 :3 0 b7
:4 0 19a 1 :a 0
15e2 :2 0 1606 14fa
15e0 :2 0 2c :3 0
2d :3 0 15e3 15e4
0 2c :3 0 3d
:3 0 15e6 15e7 0
14 :2 0 2 :4 0
19b :2 0 3f :2 0
14 :2 0 7b4 15ec
15ee :3 0 7b7 15e8
15f0 15e5 15f2 15f1
:2 0 2f :3 0 40
:3 0 15f4 15f5 0
31 :4 0 19c :4 0
34 :2 0 35 :3 0
7bb 15f9 15fb :3 0
7be 15f6 15fd :2 0
15ff 7c1 1600 15f3
15ff 0 1601 7c3
0 1606 8 :3 0
23 :3 0 1603 :2 0
1606 74 :3 0 7c5
1607 14f8 1606 0
1fda 39 :3 0 15
:3 0 16 :2 0 7c9
1608 160b 4f :2 0
19d :2 0 7ce 160d
160f :3 0 96 :3 0
97 :3 0 19e :4 0
1613 :4 0 1614 :2 0
1914 9 :3 0 5b
:3 0 1616 1617 0
16 :2 0 1618 1619
0 1914 19f :3 0
9a :3 0 a5 :3 0
1a0 :3 0 1a1 :3 0
18c :3 0 e7 :3 0
1a2 :3 0 1a3 :3 0
1a4 :3 0 ea :3 0
54 :3 0 9a :3 0
a5 :3 0 176 :3 0
e5 :3 0 1a0 :3 0
177 :3 0 e6 :3 0
1a1 :3 0 178 :3 0
f0 :3 0 18c :3 0
178 :3 0 119 :3 0
16f :3 0 e7 :3 0
176 :3 0 15a :3 0
1a2 :3 0 177 :3 0
154 :3 0 1a3 :3 0
178 :3 0 15b :3 0
1a4 :3 0 178 :3 0
119 :3 0 16f :3 0
ea :3 0 76 :3 0
53 :3 0 d :3 0
da :3 0 d :3 0
9a :3 0 a5 :4 0
1a5 1 :8 0 1660
a7 :4 0 164b :3 0
4e :3 0 4f :2 0
7d3 164e 164f :3 0
9 :3 0 5b :3 0
1651 1652 0 16
:2 0 1653 1654 0
1656 7d6 165d 9
:3 0 5b :3 0 1657
1658 0 a8 :2 0
1659 165a 0 165c
7d8 165e 1650 1656
0 165f 0 165c
0 165f 7da 0
1660 7dd 16b3 5d
:3 0 9 :3 0 5b
:3 0 1662 1663 0
5c :3 0 1664 1665
0 1667 7e0 1669
7e2 1668 1667 :2 0
16b1 5e :3 0 9
:3 0 5b :3 0 166c
166d 0 5c :3 0
166e 166f 0 16a9
2c :3 0 2d :3 0
1671 1672 0 2c
:3 0 3d :3 0 1674
1675 0 5f :2 0
2 :4 0 1a6 :2 0
3f :2 0 14 :2 0
7e4 167a 167c :3 0
7e7 1676 167e 1673
1680 167f :2 0 2f
:3 0 40 :3 0 1682
1683 0 31 :4 0
1a7 :4 0 34 :2 0
35 :3 0 7eb 1687
1689 :3 0 34 :2 0
45 :4 0 7ee 168b
168d :3 0 34 :2 0
62 :4 0 7f1 168f
1691 :3 0 34 :2 0
5c :3 0 7f4 1693
1695 :3 0 34 :2 0
63 :4 0 7f7 1697
1699 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
7fa 169c 16a0 7fe
169b 16a2 :3 0 801
1684 16a4 :2 0 16a6
804 16a7 1681 16a6
0 16a8 806 0
16a9 808 16ac :3 0
16ac 0 16ac 16ab
16a9 16aa :6 0 16ae
26 :3 0 80b 16b0
80d 16af 16ae :2 0
16b1 80f :2 0 16b3
0 16b3 16b2 1660
16b1 :6 0 1914 1
:3 0 96 :3 0 97
:3 0 1a8 :4 0 16b7
:4 0 16b8 :2 0 1914
9 :3 0 5b :3 0
16ba 16bb 0 16
:2 0 16bc 16bd 0
1914 1a9 :3 0 9a
:3 0 a5 :3 0 e5
:3 0 e6 :3 0 e7
:3 0 e8 :3 0 e9
:3 0 ea :3 0 eb
:3 0 1a0 :3 0 1a1
:3 0 18c :3 0 1a2
:3 0 1a3 :3 0 1a4
:3 0 18f :3 0 190
:3 0 191 :3 0 192
:3 0 193 :3 0 194
:3 0 195 :3 0 196
:3 0 197 :3 0 198
:3 0 be :3 0 100
:3 0 c0 :3 0 101
:3 0 54 :3 0 18e
:3 0 55 :3 0 9a
:3 0 55 :3 0 a5
:3 0 55 :3 0 e5
:3 0 55 :3 0 e6
:3 0 55 :3 0 f0
:3 0 55 :3 0 15a
:3 0 55 :3 0 154
:3 0 55 :3 0 15b
:3 0 55 :3 0 133
:3 0 52 :3 0 1a0
:3 0 52 :3 0 1a1
:3 0 52 :3 0 18c
:3 0 52 :3 0 1a2
:3 0 52 :3 0 1a3
:3 0 52 :3 0 1a4
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 191
:3 0 55 :3 0 192
:3 0 55 :3 0 193
:3 0 55 :3 0 194
:3 0 55 :3 0 195
:3 0 55 :3 0 196
:3 0 55 :3 0 197
:3 0 55 :3 0 198
:3 0 55 :3 0 be
:3 0 55 :3 0 100
:3 0 55 :3 0 c0
:3 0 55 :3 0 101
:3 0 39 :3 0 52
:3 0 54 :3 0 55
:3 0 f0 :3 0 55
:3 0 15b :3 0 55
:3 0 18e :3 0 199
:3 0 55 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 19f :3 0 52
:3 0 55 :3 0 9a
:3 0 52 :3 0 9a
:3 0 55 :3 0 53
:3 0 d :4 0 1aa
1 :8 0 1746 a7
:4 0 1731 :3 0 4e
:3 0 4f :2 0 814
1734 1735 :3 0 9
:3 0 5b :3 0 1737
1738 0 16 :2 0
1739 173a 0 173c
817 1743 9 :3 0
5b :3 0 173d 173e
0 a8 :2 0 173f
1740 0 1742 819
1744 1736 173c 0
1745 0 1742 0
1745 81b 0 1746
81e 1799 5d :3 0
9 :3 0 5b :3 0
1748 1749 0 5c
:3 0 174a 174b 0
174d 821 174f 823
174e 174d :2 0 1797
5e :3 0 9 :3 0
5b :3 0 1752 1753
0 5c :3 0 1754
1755 0 178f 2c
:3 0 2d :3 0 1757
1758 0 2c :3 0
3d :3 0 175a 175b
0 5f :2 0 2
:4 0 1ab :2 0 3f
:2 0 14 :2 0 825
1760 1762 :3 0 828
175c 1764 1759 1766
1765 :2 0 2f :3 0
40 :3 0 1768 1769
0 31 :4 0 1ac
:4 0 34 :2 0 35
:3 0 82c 176d 176f
:3 0 34 :2 0 45
:4 0 82f 1771 1773
:3 0 34 :2 0 62
:4 0 832 1775 1777
:3 0 34 :2 0 5c
:3 0 835 1779 177b
:3 0 34 :2 0 63
:4 0 838 177d 177f
:3 0 34 :2 0 64
:3 0 65 :3 0 14
:2 0 66 :2 0 83b
1782 1786 83f 1781
1788 :3 0 842 176a
178a :2 0 178c 845
178d 1767 178c 0
178e 847 0 178f
849 1792 :3 0 1792
0 1792 1791 178f
1790 :6 0 1794 28
:3 0 84c 1796 84e
1795 1794 :2 0 1797
850 :2 0 1799 0
1799 1798 1746 1797
:6 0 1914 1 :3 0
1a9 :3 0 1ad :3 0
54 :3 0 54 :3 0
da :3 0 76 :3 0
d9 :3 0 d9 :3 0
53 :3 0 d :3 0
d9 :3 0 9a :3 0
1ad :3 0 9a :3 0
d9 :3 0 a5 :4 0
1ae 1 :8 0 17c1
a7 :4 0 17ac :3 0
4e :3 0 4f :2 0
855 17af 17b0 :3 0
9 :3 0 5b :3 0
17b2 17b3 0 16
:2 0 17b4 17b5 0
17b7 858 17be 9
:3 0 5b :3 0 17b8
17b9 0 a8 :2 0
17ba 17bb 0 17bd
85a 17bf 17b1 17b7
0 17c0 0 17bd
0 17c0 85c 0
17c1 85f 1814 5d
:3 0 9 :3 0 5b
:3 0 17c3 17c4 0
5c :3 0 17c5 17c6
0 17c8 862 17ca
864 17c9 17c8 :2 0
1812 5e :3 0 9
:3 0 5b :3 0 17cd
17ce 0 5c :3 0
17cf 17d0 0 180a
2c :3 0 2d :3 0
17d2 17d3 0 2c
:3 0 3d :3 0 17d5
17d6 0 5f :2 0
2 :4 0 1af :2 0
3f :2 0 14 :2 0
866 17db 17dd :3 0
869 17d7 17df 17d4
17e1 17e0 :2 0 2f
:3 0 40 :3 0 17e3
17e4 0 31 :4 0
1b0 :4 0 34 :2 0
35 :3 0 86d 17e8
17ea :3 0 34 :2 0
45 :4 0 870 17ec
17ee :3 0 34 :2 0
62 :4 0 873 17f0
17f2 :3 0 34 :2 0
5c :3 0 876 17f4
17f6 :3 0 34 :2 0
63 :4 0 879 17f8
17fa :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
87c 17fd 1801 880
17fc 1803 :3 0 883
17e5 1805 :2 0 1807
886 1808 17e2 1807
0 1809 888 0
180a 88a 180d :3 0
180d 0 180d 180c
180a 180b :6 0 180f
2a :3 0 88d 1811
88f 1810 180f :2 0
1812 891 :2 0 1814
0 1814 1813 17c1
1812 :6 0 1914 1
:3 0 b1 :3 0 24
:3 0 55 :3 0 9a
:3 0 59 :3 0 ce
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 55
:3 0 54 :3 0 b5
:3 0 b9 :3 0 55
:3 0 e5 :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 ec
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 b5 :3 0 102
:3 0 c2 :3 0 82
:3 0 55 :3 0 1a0
:3 0 55 :3 0 1a2
:3 0 55 :3 0 9a
:3 0 d8 :3 0 55
:3 0 1a0 :3 0 55
:3 0 1a1 :3 0 55
:3 0 18c :3 0 55
:3 0 1a2 :3 0 55
:3 0 1a3 :3 0 55
:3 0 1a4 :3 0 d
:3 0 53 :3 0 55
:3 0 18f :3 0 55
:3 0 190 :3 0 55
:3 0 191 :3 0 55
:3 0 192 :3 0 55
:3 0 193 :3 0 55
:3 0 194 :3 0 55
:3 0 195 :3 0 55
:3 0 196 :3 0 55
:3 0 197 :3 0 55
:3 0 198 :3 0 55
:3 0 be :3 0 55
:3 0 100 :3 0 55
:3 0 c0 :3 0 55
:3 0 101 :3 0 55
:3 0 18e :3 0 b5
:3 0 153 :3 0 1a9
:3 0 55 :3 0 a3
:3 0 c3 :3 0 b5
:3 0 55 :3 0 a5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 a1 :3 0 ad
:3 0 59 :3 0 ce
:3 0 a1 :3 0 c9
:3 0 b7 :3 0 54
:3 0 b9 :3 0 55
:3 0 e5 :3 0 55
:3 0 e6 :3 0 55
:3 0 e7 :3 0 55
:3 0 e8 :3 0 55
:3 0 e9 :3 0 55
:3 0 ea :3 0 55
:3 0 eb :3 0 ec
:3 0 17 :3 0 56
:3 0 ed :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 102 :3 0 c2
:3 0 82 :3 0 55
:3 0 1a0 :3 0 55
:3 0 1a2 :3 0 55
:3 0 9a :3 0 d8
:3 0 55 :3 0 1a0
:3 0 55 :3 0 1a1
:3 0 55 :3 0 18c
:3 0 55 :3 0 1a2
:3 0 55 :3 0 1a3
:3 0 55 :3 0 1a4
:3 0 d :3 0 53
:3 0 55 :3 0 18f
:3 0 55 :3 0 190
:3 0 55 :3 0 191
:3 0 55 :3 0 192
:3 0 55 :3 0 193
:3 0 55 :3 0 194
:3 0 55 :3 0 195
:3 0 55 :3 0 196
:3 0 55 :3 0 197
:3 0 55 :3 0 198
:3 0 55 :3 0 be
:3 0 55 :3 0 100
:3 0 55 :3 0 c0
:3 0 55 :3 0 101
:3 0 55 :3 0 18e
:3 0 153 :3 0 1a9
:3 0 55 :3 0 a3
:3 0 ca :3 0 a1
:3 0 55 :3 0 a5
:3 0 a1 :3 0 ad
:3 0 55 :3 0 9a
:3 0 a3 :3 0 a4
:3 0 c4 :3 0 c4
:3 0 59 :3 0 a1
:3 0 cb :3 0 a3
:3 0 a4 :3 0 ba
:3 0 ba :3 0 59
:3 0 c4 :3 0 9b
:4 0 1b1 1 :a 0
18f0 :2 0 1914 1817
18ee :2 0 2c :3 0
2d :3 0 18f1 18f2
0 2c :3 0 3d
:3 0 18f4 18f5 0
14 :2 0 2 :4 0
1b2 :2 0 3f :2 0
14 :2 0 894 18fa
18fc :3 0 897 18f6
18fe 18f3 1900 18ff
:2 0 2f :3 0 40
:3 0 1902 1903 0
31 :4 0 1b3 :4 0
34 :2 0 35 :3 0
89b 1907 1909 :3 0
89e 1904 190b :2 0
190d 8a1 190e 1901
190d 0 190f 8a3
0 1914 8 :3 0
24 :3 0 1911 :2 0
1914 74 :3 0 8a5
1915 1610 1914 0
1fda 39 :3 0 15
:3 0 16 :2 0 8b0
1916 1919 47 :3 0
4f :2 0 8c :3 0
191b 191d 0 8b5
191c 191f :3 0 c9
:3 0 11 :3 0 ca
:3 0 ad :3 0 d
:4 0 1b4 1 :8 0
192c 9 :3 0 5b
:3 0 1927 1928 0
5c :3 0 1929 192a
0 192c 8b8 197f
5d :3 0 9 :3 0
5b :3 0 192e 192f
0 5c :3 0 1930
1931 0 1933 8bb
1935 8bd 1934 1933
:2 0 197d 5e :3 0
9 :3 0 5b :3 0
1938 1939 0 5c
:3 0 193a 193b 0
1975 2c :3 0 2d
:3 0 193d 193e 0
2c :3 0 3d :3 0
1940 1941 0 5f
:2 0 2 :4 0 1b5
:2 0 3f :2 0 14
:2 0 8bf 1946 1948
:3 0 8c2 1942 194a
193f 194c 194b :2 0
2f :3 0 40 :3 0
194e 194f 0 31
:4 0 1b6 :4 0 34
:2 0 35 :3 0 8c6
1953 1955 :3 0 34
:2 0 45 :4 0 8c9
1957 1959 :3 0 34
:2 0 62 :4 0 8cc
195b 195d :3 0 34
:2 0 5c :3 0 8cf
195f 1961 :3 0 34
:2 0 63 :4 0 8d2
1963 1965 :3 0 34
:2 0 64 :3 0 65
:3 0 14 :2 0 66
:2 0 8d5 1968 196c
8d9 1967 196e :3 0
8dc 1950 1970 :2 0
1972 8df 1973 194d
1972 0 1974 8e1
0 1975 8e3 1978
:3 0 1978 0 1978
1977 1975 1976 :6 0
197a 2c :3 0 8e6
197c 8e8 197b 197a
:2 0 197d 8ea :2 0
197f 0 197f 197e
192c 197d :6 0 1a4e
1 :3 0 9 :3 0
5b :3 0 1981 1982
0 9 :3 0 4f
:2 0 1b7 :3 0 1984
1986 0 8ef 1985
1988 :3 0 1989 :2 0
b1 :3 0 25 :3 0
d :3 0 59 :3 0
11 :3 0 b7 :3 0
54 :3 0 1b8 :3 0
b5 :3 0 cb :3 0
11 :3 0 bb :3 0
1b9 :3 0 1ba :3 0
b7 :3 0 1bb :3 0
1bc :3 0 1bd :3 0
b7 :3 0 1be :3 0
1bf :3 0 1c0 :3 0
b7 :3 0 1c1 :3 0
ca :3 0 b5 :3 0
c5 :3 0 a3 :3 0
16a :3 0 1ba :3 0
1ba :3 0 59 :3 0
1b9 :3 0 c5 :3 0
a3 :3 0 1c2 :3 0
1bd :3 0 1bd :3 0
59 :3 0 1bc :3 0
c5 :3 0 a3 :3 0
6c :3 0 1c0 :3 0
1c0 :3 0 59 :3 0
1bf :3 0 b5 :3 0
ad :3 0 d :3 0
d :3 0 59 :3 0
11 :3 0 b7 :3 0
54 :3 0 1c3 :3 0
54 :3 0 1b8 :3 0
1c4 :3 0 59 :3 0
cb :3 0 1c5 :3 0
1c6 :3 0 1c5 :3 0
1c6 :3 0 1c7 :3 0
1c3 :3 0 b7 :3 0
1c7 :3 0 1c4 :3 0
b7 :3 0 bb :3 0
1b9 :3 0 1bb :3 0
1bc :3 0 1be :3 0
1bf :3 0 1c1 :3 0
d0 :3 0 a1 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
1c4 :3 0 a1 :3 0
cb :3 0 1c4 :3 0
59 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 1c3 :3 0
1c3 :3 0 59 :3 0
1c4 :3 0 9b :3 0
a1 :3 0 ce :3 0
d :3 0 d :3 0
59 :3 0 11 :3 0
b7 :3 0 54 :3 0
1c3 :3 0 54 :3 0
1b8 :3 0 1c4 :3 0
59 :3 0 cb :3 0
1c5 :3 0 1c6 :3 0
1c5 :3 0 1c6 :3 0
1c7 :3 0 1c3 :3 0
b7 :3 0 1c7 :3 0
1c4 :3 0 b7 :3 0
bb :3 0 1b9 :3 0
1bb :3 0 1bc :3 0
1be :3 0 1bf :3 0
1c1 :3 0 cc :3 0
cd :3 0 c5 :3 0
c6 :3 0 a3 :3 0
a4 :3 0 1c4 :3 0
cd :3 0 cf :3 0
1c4 :3 0 59 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 a4 :3 0
1c3 :3 0 1c3 :3 0
59 :3 0 1c4 :3 0
9b :3 0 cd :3 0
ce :3 0 d :3 0
59 :3 0 54 :4 0
1c8 1 :a 0 1a27
:2 0 1a4a 198c 1a25
:2 0 2c :3 0 2d
:3 0 1a28 1a29 0
2c :3 0 3d :3 0
1a2b 1a2c 0 14
:2 0 2 :4 0 1c9
:2 0 3f :2 0 14
:2 0 8f2 1a31 1a33
:3 0 8f5 1a2d 1a35
1a2a 1a37 1a36 :2 0
2f :3 0 40 :3 0
1a39 1a3a 0 31
:4 0 1ca :4 0 34
:2 0 35 :3 0 8f9
1a3e 1a40 :3 0 8fc
1a3b 1a42 :2 0 1a44
8ff 1a45 1a38 1a44
0 1a46 901 0
1a4a 8 :3 0 25
:3 0 1a48 :2 0 1a4a
903 1a4b 198a 1a4a
0 1a4c 907 0
1a4e 74 :3 0 909
1a4f 1920 1a4e 0
1fda 39 :3 0 15
:3 0 16 :2 0 90c
1a50 1a53 4f :2 0
75 :2 0 911 1a55
1a57 :3 0 b1 :3 0
26 :3 0 d9 :3 0
77 :3 0 d9 :3 0
77 :3 0 55 :3 0
ce :3 0 59 :3 0
55 :3 0 9a :3 0
55 :3 0 a5 :3 0
b5 :3 0 c9 :3 0
ca :3 0 b5 :3 0
55 :3 0 9a :3 0
b5 :3 0 ad :3 0
a1 :3 0 b6 :3 0
c3 :3 0 a1 :3 0
55 :3 0 9a :3 0
a1 :3 0 9a :3 0
b7 :3 0 d9 :3 0
77 :3 0 55 :3 0
a5 :3 0 54 :3 0
55 :3 0 ce :3 0
55 :3 0 f6 :3 0
d9 :3 0 f7 :3 0
39 :3 0 e6 :3 0
154 :3 0 f8 :3 0
d9 :3 0 125 :3 0
d9 :3 0 126 :3 0
39 :3 0 e5 :3 0
15a :3 0 e5 :3 0
39 :3 0 e6 :3 0
154 :3 0 e6 :3 0
119 :3 0 15b :3 0
f0 :3 0 f0 :3 0
119 :3 0 15b :3 0
128 :3 0 f0 :3 0
eb :3 0 d9 :3 0
15c :3 0 d9 :3 0
15d :3 0 d9 :3 0
15c :3 0 d9 :3 0
15d :3 0 129 :3 0
12a :3 0 d9 :3 0
128 :3 0 12b :3 0
12c :3 0 d9 :3 0
128 :3 0 12c :3 0
f0 :3 0 15b :3 0
12d :3 0 d9 :3 0
12e :3 0 d9 :3 0
12f :3 0 d9 :3 0
130 :3 0 d9 :3 0
131 :3 0 d9 :3 0
132 :3 0 d9 :3 0
133 :3 0 d9 :3 0
120 :3 0 d9 :3 0
134 :3 0 d9 :3 0
128 :3 0 135 :3 0
136 :3 0 137 :3 0
139 :3 0 17 :3 0
56 :3 0 55 :3 0
f9 :3 0 55 :3 0
fa :3 0 fb :3 0
b7 :3 0 fc :3 0
39 :3 0 55 :3 0
fd :3 0 55 :3 0
fa :3 0 fd :3 0
fe :3 0 b7 :3 0
ff :3 0 d9 :3 0
be :3 0 d9 :3 0
100 :3 0 d9 :3 0
c0 :3 0 d9 :3 0
101 :3 0 55 :3 0
a5 :3 0 a1 :3 0
102 :3 0 c3 :3 0
a1 :3 0 55 :3 0
9a :3 0 a1 :3 0
9a :3 0 102 :3 0
55 :3 0 103 :3 0
d9 :3 0 f2 :3 0
d9 :3 0 13c :3 0
d9 :3 0 13d :3 0
d9 :3 0 13f :3 0
d9 :3 0 d8 :3 0
d9 :3 0 104 :3 0
105 :3 0 b7 :3 0
140 :3 0 d9 :3 0
ec :3 0 d9 :3 0
107 :3 0 d9 :3 0
108 :3 0 d9 :3 0
109 :3 0 d9 :3 0
10a :3 0 d9 :3 0
10b :3 0 d9 :3 0
10c :3 0 d9 :3 0
141 :3 0 d9 :3 0
10d :3 0 d9 :3 0
119 :3 0 d9 :3 0
119 :3 0 119 :3 0
d9 :3 0 142 :3 0
143 :3 0 119 :3 0
15e :3 0 15f :3 0
144 :3 0 1b :3 0
39 :3 0 d9 :3 0
145 :3 0 d9 :3 0
160 :3 0 e4 :3 0
145 :3 0 1b :3 0
39 :3 0 d9 :3 0
146 :3 0 d9 :3 0
161 :3 0 e4 :3 0
146 :3 0 1b :3 0
d9 :3 0 148 :3 0
d9 :3 0 133 :3 0
d9 :3 0 148 :3 0
148 :3 0 d9 :3 0
12a :3 0 149 :3 0
14a :3 0 d9 :3 0
77 :3 0 d9 :3 0
d8 :3 0 d9 :3 0
77 :3 0 d9 :3 0
145 :3 0 d9 :3 0
160 :3 0 d9 :3 0
146 :3 0 d9 :3 0
161 :3 0 14b :3 0
d9 :3 0 14c :3 0
162 :3 0 b7 :3 0
14d :3 0 d9 :3 0
14e :3 0 163 :3 0
b7 :3 0 14f :3 0
d9 :3 0 150 :3 0
d9 :3 0 151 :3 0
164 :3 0 b7 :3 0
152 :3 0 a2 :3 0
55 :3 0 a3 :3 0
76 :3 0 d9 :3 0
d9 :3 0 77 :3 0
d :3 0 55 :3 0
ce :3 0 d9 :3 0
ce :3 0 c5 :3 0
c6 :3 0 a3 :3 0
10e :3 0 fb :3 0
55 :3 0 fa :3 0
fb :3 0 59 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 10e :3 0
fe :3 0 39 :3 0
55 :3 0 fd :3 0
55 :3 0 fa :3 0
fe :3 0 59 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 10f :3 0
105 :3 0 105 :3 0
59 :3 0 d9 :3 0
104 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
165 :3 0 162 :3 0
162 :3 0 59 :3 0
d9 :3 0 14c :3 0
c5 :3 0 c6 :3 0
a3 :3 0 165 :3 0
163 :3 0 163 :3 0
59 :3 0 d9 :3 0
14e :3 0 c5 :3 0
c6 :3 0 a3 :3 0
166 :3 0 164 :3 0
164 :3 0 59 :3 0
d9 :3 0 151 :3 0
54 :3 0 b7 :4 0
1cb 1 :a 0 1b9e
:2 0 1bc2 1a5a 1b9c
:2 0 2c :3 0 2d
:3 0 1b9f 1ba0 0
2c :3 0 3d :3 0
1ba2 1ba3 0 14
:2 0 2 :4 0 1cc
:2 0 3f :2 0 14
:2 0 914 1ba8 1baa
:3 0 917 1ba4 1bac
1ba1 1bae 1bad :2 0
2f :3 0 40 :3 0
1bb0 1bb1 0 31
:4 0 1cd :4 0 34
:2 0 35 :3 0 91b
1bb5 1bb7 :3 0 91e
1bb2 1bb9 :2 0 1bbb
921 1bbc 1baf 1bbb
0 1bbd 923 0
1bc2 8 :3 0 26
:3 0 1bbf :2 0 1bc2
74 :3 0 925 1bc3
1a58 1bc2 0 1fda
39 :3 0 15 :3 0
16 :2 0 929 1bc4
1bc7 4f :2 0 8d
:2 0 92e 1bc9 1bcb
:3 0 b1 :3 0 27
:3 0 55 :3 0 ce
:3 0 59 :3 0 55
:3 0 9a :3 0 55
:3 0 a5 :3 0 a1
:3 0 b6 :3 0 c3
:3 0 a1 :3 0 55
:3 0 9a :3 0 a1
:3 0 9a :3 0 55
:3 0 a5 :3 0 b5
:3 0 b7 :3 0 6c
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b5
:3 0 b7 :3 0 16a
:3 0 b5 :3 0 55
:3 0 9a :3 0 b5
:3 0 59 :3 0 b7
:3 0 55 :3 0 a5
:3 0 47 :3 0 16c
:3 0 55 :3 0 a5
:3 0 47 :3 0 16d
:3 0 54 :3 0 55
:3 0 ce :3 0 55
:3 0 f6 :3 0 e4
:3 0 e5 :3 0 e4
:3 0 e6 :3 0 f0
:3 0 e4 :3 0 f7
:3 0 e4 :3 0 f8
:3 0 e4 :3 0 15a
:3 0 e4 :3 0 154
:3 0 15b :3 0 e4
:3 0 12e :3 0 e4
:3 0 12f :3 0 130
:3 0 e4 :3 0 131
:3 0 e4 :3 0 132
:3 0 133 :3 0 e4
:3 0 120 :3 0 e4
:3 0 134 :3 0 135
:3 0 17 :3 0 56
:3 0 55 :3 0 f9
:3 0 e4 :3 0 1ce
:3 0 55 :3 0 fa
:3 0 fb :3 0 b7
:3 0 fc :3 0 39
:3 0 55 :3 0 fd
:3 0 55 :3 0 fa
:3 0 fd :3 0 fe
:3 0 b7 :3 0 ff
:3 0 be :3 0 100
:3 0 c0 :3 0 101
:3 0 55 :3 0 a5
:3 0 a1 :3 0 102
:3 0 c3 :3 0 a1
:3 0 55 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 102 :3 0 55
:3 0 103 :3 0 f2
:3 0 e4 :3 0 13c
:3 0 e4 :3 0 13d
:3 0 13f :3 0 d8
:3 0 104 :3 0 140
:3 0 ec :3 0 107
:3 0 108 :3 0 109
:3 0 10a :3 0 10b
:3 0 10c :3 0 1cf
:3 0 a2 :3 0 55
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 10e
:3 0 fb :3 0 55
:3 0 fa :3 0 fb
:3 0 59 :3 0 c5
:3 0 c6 :3 0 a3
:3 0 10e :3 0 fe
:3 0 39 :3 0 55
:3 0 fd :3 0 55
:3 0 fa :3 0 fe
:3 0 59 :3 0 55
:3 0 103 :3 0 55
:3 0 59 :3 0 d
:3 0 54 :3 0 b7
:4 0 1d0 1 :a 0
1c71 :2 0 1c95 1bce
1c6f :2 0 2c :3 0
2d :3 0 1c72 1c73
0 2c :3 0 3d
:3 0 1c75 1c76 0
14 :2 0 2 :4 0
1d1 :2 0 3f :2 0
14 :2 0 931 1c7b
1c7d :3 0 934 1c77
1c7f 1c74 1c81 1c80
:2 0 2f :3 0 40
:3 0 1c83 1c84 0
31 :4 0 1d2 :4 0
34 :2 0 35 :3 0
938 1c88 1c8a :3 0
93b 1c85 1c8c :2 0
1c8e 93e 1c8f 1c82
1c8e 0 1c90 940
0 1c95 8 :3 0
27 :3 0 1c92 :2 0
1c95 74 :3 0 942
1c96 1bcc 1c95 0
1fda 39 :3 0 15
:3 0 16 :2 0 946
1c97 1c9a 4f :2 0
1d3 :2 0 94b 1c9c
1c9e :3 0 96 :3 0
97 :3 0 1d4 :4 0
1ca2 :4 0 1ca3 :2 0
1ed5 9 :3 0 5b
:3 0 1ca5 1ca6 0
16 :2 0 1ca7 1ca8
0 1ed5 1d5 :3 0
9a :3 0 a5 :3 0
1d6 :3 0 9a :3 0
a5 :3 0 1d6 :3 0
76 :3 0 53 :3 0
d :3 0 d8 :3 0
1d7 :3 0 47 :3 0
1d8 :3 0 9a :3 0
a5 :4 0 1d9 1
:8 0 1cd0 a7 :4 0
1cbb :3 0 4e :3 0
4f :2 0 950 1cbe
1cbf :3 0 9 :3 0
5b :3 0 1cc1 1cc2
0 16 :2 0 1cc3
1cc4 0 1cc6 953
1ccd 9 :3 0 5b
:3 0 1cc7 1cc8 0
a8 :2 0 1cc9 1cca
0 1ccc 955 1cce
1cc0 1cc6 0 1ccf
0 1ccc 0 1ccf
957 0 1cd0 95a
1d23 5d :3 0 9
:3 0 5b :3 0 1cd2
1cd3 0 5c :3 0
1cd4 1cd5 0 1cd7
95d 1cd9 95f 1cd8
1cd7 :2 0 1d21 5e
:3 0 9 :3 0 5b
:3 0 1cdc 1cdd 0
5c :3 0 1cde 1cdf
0 1d19 2c :3 0
2d :3 0 1ce1 1ce2
0 2c :3 0 3d
:3 0 1ce4 1ce5 0
5f :2 0 2 :4 0
1da :2 0 3f :2 0
14 :2 0 961 1cea
1cec :3 0 964 1ce6
1cee 1ce3 1cf0 1cef
:2 0 2f :3 0 40
:3 0 1cf2 1cf3 0
31 :4 0 1db :4 0
34 :2 0 35 :3 0
968 1cf7 1cf9 :3 0
34 :2 0 45 :4 0
96b 1cfb 1cfd :3 0
34 :2 0 62 :4 0
96e 1cff 1d01 :3 0
34 :2 0 5c :3 0
971 1d03 1d05 :3 0
34 :2 0 63 :4 0
974 1d07 1d09 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 977 1d0c
1d10 97b 1d0b 1d12
:3 0 97e 1cf4 1d14
:2 0 1d16 981 1d17
1cf1 1d16 0 1d18
983 0 1d19 985
1d1c :3 0 1d1c 0
1d1c 1d1b 1d19 1d1a
:6 0 1d1e 2e :3 0
988 1d20 98a 1d1f
1d1e :2 0 1d21 98c
:2 0 1d23 0 1d23
1d22 1cd0 1d21 :6 0
1ed5 1 :3 0 96
:3 0 97 :3 0 1dc
:4 0 1d27 :4 0 1d28
:2 0 1ed5 9 :3 0
5b :3 0 1d2a 1d2b
0 16 :2 0 1d2c
1d2d 0 1ed5 1dd
:3 0 9a :3 0 a5
:3 0 1d6 :3 0 9a
:3 0 a5 :3 0 1d6
:3 0 76 :3 0 53
:3 0 d :3 0 da
:3 0 d :3 0 9a
:3 0 a5 :4 0 1de
1 :8 0 1d53 a7
:4 0 1d3e :3 0 4e
:3 0 4f :2 0 991
1d41 1d42 :3 0 9
:3 0 5b :3 0 1d44
1d45 0 16 :2 0
1d46 1d47 0 1d49
994 1d50 9 :3 0
5b :3 0 1d4a 1d4b
0 a8 :2 0 1d4c
1d4d 0 1d4f 996
1d51 1d43 1d49 0
1d52 0 1d4f 0
1d52 998 0 1d53
99b 1da6 5d :3 0
9 :3 0 5b :3 0
1d55 1d56 0 5c
:3 0 1d57 1d58 0
1d5a 99e 1d5c 9a0
1d5b 1d5a :2 0 1da4
5e :3 0 9 :3 0
5b :3 0 1d5f 1d60
0 5c :3 0 1d61
1d62 0 1d9c 2c
:3 0 2d :3 0 1d64
1d65 0 2c :3 0
3d :3 0 1d67 1d68
0 5f :2 0 2
:4 0 1df :2 0 3f
:2 0 14 :2 0 9a2
1d6d 1d6f :3 0 9a5
1d69 1d71 1d66 1d73
1d72 :2 0 2f :3 0
40 :3 0 1d75 1d76
0 31 :4 0 1e0
:4 0 34 :2 0 35
:3 0 9a9 1d7a 1d7c
:3 0 34 :2 0 45
:4 0 9ac 1d7e 1d80
:3 0 34 :2 0 62
:4 0 9af 1d82 1d84
:3 0 34 :2 0 5c
:3 0 9b2 1d86 1d88
:3 0 34 :2 0 63
:4 0 9b5 1d8a 1d8c
:3 0 34 :2 0 64
:3 0 65 :3 0 14
:2 0 66 :2 0 9b8
1d8f 1d93 9bc 1d8e
1d95 :3 0 9bf 1d77
1d97 :2 0 1d99 9c2
1d9a 1d74 1d99 0
1d9b 9c4 0 1d9c
9c6 1d9f :3 0 1d9f
0 1d9f 1d9e 1d9c
1d9d :6 0 1da1 30
:3 0 9c9 1da3 9cb
1da2 1da1 :2 0 1da4
9cd :2 0 1da6 0
1da6 1da5 1d53 1da4
:6 0 1ed5 1 :3 0
96 :3 0 97 :3 0
1e1 :4 0 1daa :4 0
1dab :2 0 1ed5 9
:3 0 5b :3 0 1dad
1dae 0 16 :2 0
1daf 1db0 0 1ed5
1e2 :3 0 9a :3 0
a5 :3 0 1d6 :3 0
55 :3 0 9a :3 0
55 :3 0 a5 :3 0
55 :3 0 1d6 :3 0
1d5 :3 0 55 :3 0
c5 :3 0 c6 :3 0
a3 :3 0 1dd :3 0
52 :3 0 55 :3 0
9a :3 0 52 :3 0
9a :3 0 52 :3 0
9a :3 0 52 :3 0
a5 :3 0 52 :3 0
1d6 :3 0 1dd :3 0
52 :3 0 c5 :3 0
c6 :3 0 a3 :3 0
1d5 :3 0 55 :3 0
55 :3 0 9a :3 0
52 :3 0 9a :4 0
1e3 1 :8 0 1dee
a7 :4 0 1dd9 :3 0
4e :3 0 4f :2 0
9d2 1ddc 1ddd :3 0
9 :3 0 5b :3 0
1ddf 1de0 0 16
:2 0 1de1 1de2 0
1de4 9d5 1deb 9
:3 0 5b :3 0 1de5
1de6 0 a8 :2 0
1de7 1de8 0 1dea
9d7 1dec 1dde 1de4
0 1ded 0 1dea
0 1ded 9d9 0
1dee 9dc 1e41 5d
:3 0 9 :3 0 5b
:3 0 1df0 1df1 0
5c :3 0 1df2 1df3
0 1df5 9df 1df7
9e1 1df6 1df5 :2 0
1e3f 5e :3 0 9
:3 0 5b :3 0 1dfa
1dfb 0 5c :3 0
1dfc 1dfd 0 1e37
2c :3 0 2d :3 0
1dff 1e00 0 2c
:3 0 3d :3 0 1e02
1e03 0 5f :2 0
2 :4 0 1e4 :2 0
3f :2 0 14 :2 0
9e3 1e08 1e0a :3 0
9e6 1e04 1e0c 1e01
1e0e 1e0d :2 0 2f
:3 0 40 :3 0 1e10
1e11 0 31 :4 0
1e5 :4 0 34 :2 0
35 :3 0 9ea 1e15
1e17 :3 0 34 :2 0
45 :4 0 9ed 1e19
1e1b :3 0 34 :2 0
62 :4 0 9f0 1e1d
1e1f :3 0 34 :2 0
5c :3 0 9f3 1e21
1e23 :3 0 34 :2 0
63 :4 0 9f6 1e25
1e27 :3 0 34 :2 0
64 :3 0 65 :3 0
14 :2 0 66 :2 0
9f9 1e2a 1e2e 9fd
1e29 1e30 :3 0 a00
1e12 1e32 :2 0 1e34
a03 1e35 1e0f 1e34
0 1e36 a05 0
1e37 a07 1e3a :3 0
1e3a 0 1e3a 1e39
1e37 1e38 :6 0 1e3c
32 :3 0 a0a 1e3e
a0c 1e3d 1e3c :2 0
1e3f a0e :2 0 1e41
0 1e41 1e40 1dee
1e3f :6 0 1ed5 1
:3 0 b1 :3 0 28
:3 0 55 :3 0 9a
:3 0 59 :3 0 b5
:3 0 b6 :3 0 b7
:3 0 54 :3 0 b5
:3 0 1e6 :3 0 55
:3 0 1d6 :3 0 1e2
:3 0 55 :3 0 a3
:3 0 c3 :3 0 b5
:3 0 55 :3 0 a5
:3 0 55 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 1dd
:3 0 1e7 :3 0 55
:3 0 9a :3 0 1e7
:3 0 9a :3 0 a1
:3 0 ad :3 0 59
:3 0 a1 :3 0 c9
:3 0 b7 :3 0 54
:3 0 1e6 :3 0 55
:3 0 1d6 :3 0 1e2
:3 0 55 :3 0 a3
:3 0 ca :3 0 a1
:3 0 55 :3 0 a5
:3 0 a1 :3 0 ad
:3 0 55 :3 0 9a
:3 0 a3 :3 0 a4
:3 0 c4 :3 0 c4
:3 0 59 :3 0 a1
:3 0 cb :3 0 a3
:3 0 a4 :3 0 ba
:3 0 ba :3 0 59
:3 0 c4 :3 0 9b
:3 0 c5 :3 0 c6
:3 0 a3 :3 0 1dd
:3 0 1e7 :3 0 55
:3 0 9a :3 0 1e7
:3 0 9a :3 0 d7
:3 0 9a :3 0 59
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 54
:3 0 b5 :3 0 1e6
:3 0 1d6 :3 0 a2
:3 0 d7 :3 0 c3
:3 0 b5 :3 0 d7
:3 0 53 :3 0 d
:3 0 d7 :3 0 9a
:3 0 b5 :3 0 9a
:3 0 1e8 :3 0 9a
:3 0 1e2 :3 0 1e8
:3 0 d7 :3 0 9a
:3 0 1e8 :3 0 9a
:3 0 54 :3 0 b7
:4 0 1e9 1 :a 0
1eb1 :2 0 1ed5 1e44
1eaf :2 0 2c :3 0
2d :3 0 1eb2 1eb3
0 2c :3 0 3d
:3 0 1eb5 1eb6 0
14 :2 0 2 :4 0
1ea :2 0 3f :2 0
14 :2 0 a11 1ebb
1ebd :3 0 a14 1eb7
1ebf 1eb4 1ec1 1ec0
:2 0 2f :3 0 40
:3 0 1ec3 1ec4 0
31 :4 0 1eb :4 0
34 :2 0 35 :3 0
a18 1ec8 1eca :3 0
a1b 1ec5 1ecc :2 0
1ece a1e 1ecf 1ec2
1ece 0 1ed0 a20
0 1ed5 8 :3 0
28 :3 0 1ed2 :2 0
1ed5 74 :3 0 a22
1ed6 1c9f 1ed5 0
1fda 39 :3 0 15
:3 0 16 :2 0 a2f
1ed7 1eda 4f :2 0
81 :2 0 a34 1edc
1ede :3 0 b :3 0
64 :3 0 b :3 0
34 :2 0 1ec :4 0
a37 1ee3 1ee5 :3 0
14 :2 0 c :2 0
a3a 1ee1 1ee9 1ee0
1eea 0 1f2c b1
:3 0 29 :3 0 d9
:3 0 59 :3 0 b5
:3 0 b6 :3 0 b7
:3 0 54 :3 0 b5
:3 0 1e6 :3 0 1d6
:3 0 6c :3 0 d9
:3 0 a3 :3 0 c3
:3 0 b5 :3 0 d9
:3 0 59 :3 0 b5
:3 0 9a :3 0 d9
:3 0 54 :3 0 d9
:3 0 82 :3 0 b
:3 0 b7 :4 0 1ed
1 :a 0 1f08 :2 0
1f2c 1eed 1f06 :2 0
2c :3 0 2d :3 0
1f09 1f0a 0 2c
:3 0 3d :3 0 1f0c
1f0d 0 14 :2 0
2 :4 0 1ee :2 0
3f :2 0 14 :2 0
a3e 1f12 1f14 :3 0
a41 1f0e 1f16 1f0b
1f18 1f17 :2 0 2f
:3 0 40 :3 0 1f1a
1f1b 0 31 :4 0
1ef :4 0 34 :2 0
35 :3 0 a45 1f1f
1f21 :3 0 a48 1f1c
1f23 :2 0 1f25 a4b
1f26 1f19 1f25 0
1f27 a4d 0 1f2c
8 :3 0 29 :3 0
1f29 :2 0 1f2c 74
:3 0 a4f 1f2d 1edf
1f2c 0 1fda 39
:3 0 15 :3 0 16
:2 0 a54 1f2e 1f31
47 :3 0 4f :2 0
8e :3 0 1f33 1f35
0 a59 1f34 1f37
:3 0 1f38 :2 0 39
:3 0 15 :3 0 16
:2 0 a5c 1f3a 1f3d
47 :3 0 4f :2 0
8f :3 0 1f3f 1f41
0 a61 1f40 1f43
:3 0 1f44 :2 0 1f39
1f46 1f45 :2 0 b1
:3 0 2a :3 0 a1
:3 0 9a :3 0 59
:3 0 a1 :3 0 b6
:3 0 b7 :3 0 47
:3 0 16e :3 0 54
:3 0 a1 :3 0 1e6
:3 0 1d6 :3 0 199
:3 0 d7 :3 0 c3
:3 0 a1 :3 0 d7
:3 0 53 :3 0 d
:3 0 d7 :3 0 9a
:3 0 a1 :3 0 9a
:3 0 b7 :4 0 1f0
1 :a 0 1f64 :2 0
1f87 1f49 1f62 :2 0
2c :3 0 2d :3 0
1f65 1f66 0 2c
:3 0 3d :3 0 1f68
1f69 0 14 :2 0
2 :4 0 1f1 :2 0
3f :2 0 14 :2 0
a64 1f6e 1f70 :3 0
a67 1f6a 1f72 1f67
1f74 1f73 :2 0 2f
:3 0 40 :3 0 1f76
1f77 0 31 :4 0
1f2 :4 0 34 :2 0
35 :3 0 a6b 1f7b
1f7d :3 0 a6e 1f78
1f7f :2 0 1f81 a71
1f82 1f75 1f81 0
1f83 a73 0 1f87
8 :3 0 2a :3 0
1f85 :2 0 1f87 a75
1f88 1f47 1f87 0
1fda 2c :3 0 2d
:3 0 1f89 1f8a 0
2c :3 0 3d :3 0
1f8c 1f8d 0 173
:2 0 2 :4 0 1f3
:2 0 3f :2 0 14
:2 0 a79 1f92 1f94
:3 0 a7c 1f8e 1f96
1f8b 1f98 1f97 :2 0
2f :3 0 40 :3 0
1f9a 1f9b 0 31
:4 0 1f4 :4 0 34
:2 0 35 :3 0 a80
1f9f 1fa1 :3 0 34
:2 0 45 :4 0 a83
1fa3 1fa5 :3 0 34
:2 0 46 :4 0 a86
1fa7 1fa9 :3 0 34
:2 0 39 :3 0 3a
:3 0 47 :3 0 48
:3 0 1fae 1faf 0
a89 1fad 1fb1 3b
:4 0 a8b 1fac 1fb4
a8e 1fab 1fb6 :3 0
34 :2 0 49 :4 0
a91 1fb8 1fba :3 0
34 :2 0 37 :4 0
a94 1fbc 1fbe :3 0
34 :2 0 3 :3 0
a97 1fc0 1fc2 :3 0
34 :2 0 37 :4 0
a9a 1fc4 1fc6 :3 0
a9d 1f9c 1fc8 :2 0
1fca aa0 1fcb 1f99
1fca 0 1fcc aa2
0 1fd7 4c :3 0
1f5 :3 0 1fcd 1fce
0 47 :3 0 48
:3 0 1fd0 1fd1 0
3 :3 0 4e :3 0
aa4 1fcf 1fd5 :2 0
1fd7 aa8 1fd9 6fd
964 0 1fda 0
1fd7 0 1fda aab
0 1fdb abb 207c
9 :3 0 1f6 :2 0
4 1fdc 1fdd 0
2c :3 0 2d :3 0
1fdf 1fe0 0 2c
:3 0 3d :3 0 1fe2
1fe3 0 5f :2 0
2 :4 0 1f7 :2 0
3f :2 0 14 :2 0
ac4 1fe8 1fea :3 0
ac7 1fe4 1fec 1fe1
1fee 1fed :2 0 2f
:3 0 40 :3 0 1ff0
1ff1 0 31 :4 0
1f8 :4 0 34 :2 0
35 :3 0 acb 1ff5
1ff7 :3 0 ace 1ff2
1ff9 :2 0 2012 2f
:3 0 40 :3 0 1ffb
1ffc 0 31 :4 0
1f9 :4 0 34 :2 0
9 :3 0 1fa :3 0
2001 2002 0 ad1
2000 2004 :3 0 34
:2 0 49 :4 0 ad4
2006 2008 :3 0 34
:2 0 9 :3 0 1fb
:3 0 200b 200c 0
ad7 200a 200e :3 0
ada 1ffd 2010 :2 0
2012 add 2013 1fef
2012 0 2014 ae0
0 2024 b1 :3 0
2b :3 0 9 :3 0
1fa :3 0 1fc :3 0
9 :3 0 1fb :3 0
3 :3 0 118 :4 0
1fd 1 :a 0 2020
:2 0 2024 2016 201e
:2 0 8 :3 0 2b
:3 0 2022 :2 0 2024
ae2 2026 ae6 2025
2024 :2 0 207a 5e
:3 0 9 :3 0 5b
:3 0 2029 202a 0
5c :3 0 202b 202c
0 2072 2c :3 0
2d :3 0 202e 202f
0 2c :3 0 3d
:3 0 2031 2032 0
5f :2 0 2 :4 0
1fe :2 0 3f :2 0
14 :2 0 ae8 2037
2039 :3 0 aeb 2033
203b 2030 203d 203c
:2 0 2f :3 0 40
:3 0 203f 2040 0
31 :4 0 1ff :4 0
34 :2 0 35 :3 0
aef 2044 2046 :3 0
af2 2041 2048 :2 0
2062 2f :3 0 40
:3 0 204a 204b 0
31 :4 0 62 :4 0
34 :2 0 5c :3 0
af5 204f 2051 :3 0
34 :2 0 63 :4 0
af8 2053 2055 :3 0
34 :2 0 64 :3 0
65 :3 0 14 :2 0
66 :2 0 afb 2058
205c aff 2057 205e
:3 0 b02 204c 2060
:2 0 2062 b05 2063
203e 2062 0 2064
b08 0 2072 b1
:3 0 2b :3 0 1fc
:3 0 9 :3 0 1fb
:3 0 3 :3 0 118
:4 0 200 1 :a 0
206e :2 0 2072 2066
206c :2 0 8 :3 0
2b :3 0 2070 :2 0
2072 b0a 2075 :3 0
2075 0 2075 2074
2072 2073 :6 0 2077
1 :3 0 b0f 2079
b11 2078 2077 :2 0
207a b13 :2 0 207c
b16 207c 207b 1fdb
207a :6 0 207d :2 0
2 14 207c 2080
:3 0 207f 207d 2081
:8 0 
b33
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 46 1
4c 1 52 1
58 1 5e 1
64 1 6b 1
72 1 79 1
80 1 87 1
8e 1 95 1
9c 1 a3 1
aa 1 b1 1
b8 1 bf 1
c6 1 cd 1
da 1 e6 2
e9 eb 2 ee
f0 2 f2 f4
2 f6 f8 2
fa fc 1 102
2 104 105 2
fe 107 2 109
10b 2 10d 10f
2 111 113 2
115 117 2 119
11b 4 e2 e8
ed 11d 1 11f
1 121 2 12b
12d 3 129 12a
12f 2 138 13a
2 137 13c 1
13e 1 140 1
142 2 14f 151
3 14d 14e 153
2 15c 15e 2
160 162 2 164
166 1 16e 2
170 171 2 168
173 2 175 177
2 179 17b 2
17d 17f 2 181
183 2 15b 185
1 187 1 189
2 193 195 3
191 192 197 2
1a0 1a2 2 19f
1a4 1 1a6 1
1a8 3 1af 1b0
1b1 3 18a 1a9
1b3 1 1b5 2
1c1 1c2 1 1c6
2 1c4 1c6 2
1cb 1cc 1 1d0
2 1ce 1d0 2
1ee 1f3 1 1fa
1 1f5 2 20d
20f 3 20b 20c
211 2 21a 21c
2 21e 220 2
222 224 2 226
228 2 22a 22c
3 231 232 233
2 22e 235 2
219 237 1 239
1 23b 2 204
23c 1 240 1
1ff 2 1fd 244
1 24f 2 24b
24f 2 268 26d
1 274 1 26f
2 287 289 3
285 286 28b 2
294 296 2 298
29a 2 29c 29e
2 2a0 2a2 2
2a4 2a6 3 2ab
2ac 2ad 2 2a8
2af 2 293 2b1
1 2b3 1 2b5
2 27e 2b6 1
2ba 1 279 2
277 2be 1 2c9
2 2c5 2c9 2
2d1 2d6 1 2dd
1 2d8 2 2f0
2f2 3 2ee 2ef
2f4 2 2fd 2ff
2 301 303 2
305 307 2 309
30b 2 30d 30f
3 314 315 316
2 311 318 2
2fc 31a 1 31c
1 31e 2 2e7
31f 1 323 1
2e2 2 2e0 327
1 332 2 32e
332 2 33e 340
3 33c 33d 342
2 34b 34d 2
34f 351 2 353
355 1 35d 2
35f 360 2 357
362 2 364 366
2 368 36a 2
36c 36e 2 370
372 2 34a 374
1 376 1 378
2 382 384 3
380 381 386 2
38f 391 2 38e
393 1 395 1
397 3 39e 39f
3a0 3 379 398
3a2 1 3a4 2
32a 3a5 1 3a7
2 2c1 3a8 1
3aa 2 247 3ab
2 3af 3b0 1
3b4 2 3b2 3b4
2 3bc 3c1 1
3c8 1 3c3 2
3db 3dd 3 3d9
3da 3df 2 3e8
3ea 2 3ec 3ee
2 3f0 3f2 2
3f4 3f6 2 3f8
3fa 3 3ff 400
401 2 3fc 403
2 3e7 405 1
407 1 409 2
3d2 40a 1 40e
1 3cd 2 3cb
412 1 41d 2
419 41d 2 429
42b 3 427 428
42d 2 436 438
2 43a 43c 2
43e 440 1 448
2 44a 44b 2
442 44d 2 44f
451 2 453 455
2 457 459 2
45b 45d 2 435
45f 1 461 1
463 2 46d 46f
3 46b 46c 471
2 47a 47c 2
479 47e 1 480
1 482 3 489
48a 48b 3 464
483 48d 1 48f
2 499 49e 1
4a5 1 4a0 2
4b8 4ba 3 4b6
4b7 4bc 2 4c5
4c7 2 4c9 4cb
2 4cd 4cf 2
4d1 4d3 2 4d5
4d7 3 4dc 4dd
4de 2 4d9 4e0
2 4c4 4e2 1
4e4 1 4e6 2
4af 4e7 1 4eb
1 4aa 2 4a8
4ef 3 415 490
4f2 2 4f8 4f9
1 4fd 2 4fb
4fd 2 505 50a
1 511 1 50c
2 524 526 3
522 523 528 2
531 533 2 535
537 2 539 53b
2 53d 53f 2
541 543 3 548
549 54a 2 545
54c 2 530 54e
1 550 1 552
2 51b 553 1
557 1 516 2
514 55b 1 566
2 562 566 2
572 574 3 570
571 576 2 57f
581 2 583 585
2 587 589 1
591 2 593 594
2 58b 596 2
598 59a 2 59c
59e 2 5a0 5a2
2 5a4 5a6 2
57e 5a8 1 5aa
1 5ac 2 5b6
5b8 3 5b4 5b5
5ba 2 5c3 5c5
2 5c2 5c7 1
5c9 1 5cb 3
5d2 5d3 5d4 3
5ad 5cc 5d6 1
5d8 3 55e 5d9
5dc 2 5e1 5e2
1 5e8 2 5e4
5e8 2 5ed 5ee
1 5f2 2 5f0
5f2 2 5f9 5fa
1 600 2 5fc
600 2 607 608
1 60e 2 60a
60e 2 61c 621
1 628 1 623
2 63b 63d 3
639 63a 63f 2
648 64a 2 64c
64e 2 650 652
2 654 656 2
658 65a 3 65f
660 661 2 65c
663 2 647 665
1 667 1 669
2 632 66a 1
66e 1 62d 2
62b 672 1 67d
2 679 67d 2
689 68b 3 687
688 68d 2 696
698 2 69a 69c
2 69e 6a0 1
6a8 2 6aa 6ab
2 6a2 6ad 2
6af 6b1 2 6b3
6b5 2 6b7 6b9
2 6bb 6bd 2
695 6bf 1 6c1
1 6c3 2 6cd
6cf 3 6cb 6cc
6d1 2 6da 6dc
2 6d9 6de 1
6e0 1 6e2 3
6e9 6ea 6eb 3
6c4 6e3 6ed 1
6ef 2 675 6f0
4 6f3 4f6 5df
6f2 2 6f6 6f7
1 6fb 2 6f9
6fb 1 72d 2
72c 72d 1 735
1 73b 2 73d
73e 2 72a 73f
1 746 1 741
2 759 75b 3
757 758 75d 2
766 768 2 76a
76c 2 76e 770
2 772 774 2
776 778 3 77d
77e 77f 2 77a
781 2 765 783
1 785 1 787
2 750 788 1
78c 1 74b 2
749 790 1 7a9
2 7a8 7a9 1
7b1 1 7b7 2
7b9 7ba 2 7a6
7bb 1 7c2 1
7bd 2 7d5 7d7
3 7d3 7d4 7d9
2 7e2 7e4 2
7e6 7e8 2 7ea
7ec 2 7ee 7f0
2 7f2 7f4 3
7f9 7fa 7fb 2
7f6 7fd 2 7e1
7ff 1 801 1
803 2 7cc 804
1 808 1 7c7
2 7c5 80c 2
949 94b 3 947
948 94d 2 956
958 2 955 95a
1 95c 1 95e
9 702 707 793
799 79e 80f 93f
95f 962 2 966
967 1 96b 2
969 96b 2 970
971 1 975 2
973 975 1 9ae
2 9ad 9ae 1
9b6 1 9bc 2
9be 9bf 2 9ab
9c0 1 9c7 1
9c2 2 9da 9dc
3 9d8 9d9 9de
2 9e7 9e9 2
9eb 9ed 2 9ef
9f1 2 9f3 9f5
2 9f7 9f9 3
9fe 9ff a00 2
9fb a02 2 9e6
a04 1 a06 1
a08 2 9d1 a09
1 a0d 1 9cc
2 9ca a11 1
a4e 2 a4d a4e
1 a56 1 a5c
2 a5e a5f 2
a4b a60 1 a67
1 a62 2 a7a
a7c 3 a78 a79
a7e 2 a87 a89
2 a8b a8d 2
a8f a91 2 a93
a95 2 a97 a99
3 a9e a9f aa0
2 a9b aa2 2
a86 aa4 1 aa6
1 aa8 2 a71
aa9 1 aad 1
a6c 2 a6a ab1
2 b0a b0c 3
b08 b09 b0e 2
b17 b19 2 b16
b1b 1 b1d 1
b1f 8 97f 984
a14 a1c ab4 b00
b20 b23 2 b28
b29 1 b2d 2
b2b b2d 2 bc8
bca 3 bc6 bc7
bcc 2 bd5 bd7
2 bd4 bd9 1
bdb 1 bdd 3
bbe bde be1 2
be6 be7 1 beb
2 be9 beb 2
bf0 bf1 1 bf3
1 bf7 2 bf5
bf7 2 c04 c09
1 c10 1 c0b
2 c23 c25 3
c21 c22 c27 2
c30 c32 2 c34
c36 2 c38 c3a
2 c3c c3e 2
c40 c42 3 c47
c48 c49 2 c44
c4b 2 c2f c4d
1 c4f 1 c51
2 c1a c52 1
c56 1 c15 2
c13 c5a 2 c60
c61 1 c65 2
c63 c65 1 c6a
2 c78 c7d 1
c84 1 c7f 2
c97 c99 3 c95
c96 c9b 2 ca4
ca6 2 ca8 caa
2 cac cae 2
cb0 cb2 2 cb4
cb6 3 cbb cbc
cbd 2 cb8 cbf
2 ca3 cc1 1
cc3 1 cc5 2
c8e cc6 1 cca
1 c89 2 c87
cce 2 cd4 cd5
1 cd9 2 cd7
cd9 2 cf8 cfd
1 d04 1 cff
2 d17 d19 3
d15 d16 d1b 2
d24 d26 2 d28
d2a 2 d2c d2e
2 d30 d32 2
d34 d36 3 d3b
d3c d3d 2 d38
d3f 2 d23 d41
1 d43 1 d45
2 d0e d46 1
d4a 1 d09 2
d07 d4e 2 d54
d55 1 d59 2
d57 d59 1 d5e
1 d62 2 d64
d65 2 d51 d66
1 d6a 2 d6c
d6d 3 c6e cd1
d6e 2 d70 d71
2 f90 f92 3
f8e f8f f94 2
f9d f9f 2 f9c
fa1 1 fa3 1
fa5 6 bfc c5d
d72 f86 fa6 fa9
2 1104 1106 3
1102 1103 1108 2
1111 1113 2 1110
1115 1 1117 1
1119 3 10fa 111a
111d 2 111f 1120
1 1121 2 1126
1127 1 112b 2
1129 112b 1 1162
2 1161 1162 1
116a 1 1170 2
1172 1173 2 115f
1174 1 117b 1
1176 2 118e 1190
3 118c 118d 1192
2 119b 119d 2
119f 11a1 2 11a3
11a5 2 11a7 11a9
2 11ab 11ad 3
11b2 11b3 11b4 2
11af 11b6 2 119a
11b8 1 11ba 1
11bc 2 1185 11bd
1 11c1 1 1180
2 117e 11c5 1
1209 2 1208 1209
1 1211 1 1217
2 1219 121a 2
1206 121b 1 1222
1 121d 2 1235
1237 3 1233 1234
1239 2 1242 1244
2 1246 1248 2
124a 124c 2 124e
1250 2 1252 1254
3 1259 125a 125b
2 1256 125d 2
1241 125f 1 1261
1 1263 2 122c
1264 1 1268 1
1227 2 1225 126c
2 12c8 12ca 3
12c6 12c7 12cc 2
12d5 12d7 2 12d4
12d9 1 12db 1
12dd 8 1132 1137
11c8 11d0 126f 12be
12de 12e1 2 12e6
12e7 1 12eb 2
12e9 12eb 1 1322
2 1321 1322 1
132a 1 1330 2
1332 1333 2 131f
1334 1 133b 1
1336 2 134e 1350
3 134c 134d 1352
2 135b 135d 2
135f 1361 2 1363
1365 2 1367 1369
2 136b 136d 3
1372 1373 1374 2
136f 1376 2 135a
1378 1 137a 1
137c 2 1345 137d
1 1381 1 1340
2 133e 1385 1
13f6 2 13f5 13f6
1 13fe 1 1404
2 1406 1407 2
13f3 1408 1 140f
1 140a 2 1422
1424 3 1420 1421
1426 2 142f 1431
2 1433 1435 2
1437 1439 2 143b
143d 2 143f 1441
3 1446 1447 1448
2 1443 144a 2
142e 144c 1 144e
1 1450 2 1419
1451 1 1455 1
1414 2 1412 1459
2 14d3 14d5 3
14d1 14d2 14d7 2
14e0 14e2 2 14df
14e4 1 14e6 1
14e8 8 12f2 12f7
1388 1390 145c 14c9
14e9 14ec 2 14f1
14f2 1 14f6 2
14f4 14f6 2 15eb
15ed 3 15e9 15ea
15ef 2 15f8 15fa
2 15f7 15fc 1
15fe 1 1600 3
15e1 1601 1604 2
1609 160a 1 160e
2 160c 160e 1
164d 2 164c 164d
1 1655 1 165b
2 165d 165e 2
164a 165f 1 1666
1 1661 2 1679
167b 3 1677 1678
167d 2 1686 1688
2 168a 168c 2
168e 1690 2 1692
1694 2 1696 1698
3 169d 169e 169f
2 169a 16a1 2
1685 16a3 1 16a5
1 16a7 2 1670
16a8 1 16ac 1
166b 2 1669 16b0
1 1733 2 1732
1733 1 173b 1
1741 2 1743 1744
2 1730 1745 1
174c 1 1747 2
175f 1761 3 175d
175e 1763 2 176c
176e 2 1770 1772
2 1774 1776 2
1778 177a 2 177c
177e 3 1783 1784
1785 2 1780 1787
2 176b 1789 1
178b 1 178d 2
1756 178e 1 1792
1 1751 2 174f
1796 1 17ae 2
17ad 17ae 1 17b6
1 17bc 2 17be
17bf 2 17ab 17c0
1 17c7 1 17c2
2 17da 17dc 3
17d8 17d9 17de 2
17e7 17e9 2 17eb
17ed 2 17ef 17f1
2 17f3 17f5 2
17f7 17f9 3 17fe
17ff 1800 2 17fb
1802 2 17e6 1804
1 1806 1 1808
2 17d1 1809 1
180d 1 17cc 2
17ca 1811 2 18f9
18fb 3 18f7 18f8
18fd 2 1906 1908
2 1905 190a 1
190c 1 190e a
1615 161a 16b3 16b9
16be 1799 1814 18ef
190f 1912 2 1917
1918 1 191e 2
191a 191e 2 1926
192b 1 1932 1
192d 2 1945 1947
3 1943 1944 1949
2 1952 1954 2
1956 1958 2 195a
195c 2 195e 1960
2 1962 1964 3
1969 196a 196b 2
1966 196d 2 1951
196f 1 1971 1
1973 2 193c 1974
1 1978 1 1937
2 1935 197c 1
1987 2 1983 1987
2 1a30 1a32 3
1a2e 1a2f 1a34 2
1a3d 1a3f 2 1a3c
1a41 1 1a43 1
1a45 3 1a26 1a46
1a49 1 1a4b 2
197f 1a4c 2 1a51
1a52 1 1a56 2
1a54 1a56 2 1ba7
1ba9 3 1ba5 1ba6
1bab 2 1bb4 1bb6
2 1bb3 1bb8 1
1bba 1 1bbc 3
1b9d 1bbd 1bc0 2
1bc5 1bc6 1 1bca
2 1bc8 1bca 2
1c7a 1c7c 3 1c78
1c79 1c7e 2 1c87
1c89 2 1c86 1c8b
1 1c8d 1 1c8f
3 1c70 1c90 1c93
2 1c98 1c99 1
1c9d 2 1c9b 1c9d
1 1cbd 2 1cbc
1cbd 1 1cc5 1
1ccb 2 1ccd 1cce
2 1cba 1ccf 1
1cd6 1 1cd1 2
1ce9 1ceb 3 1ce7
1ce8 1ced 2 1cf6
1cf8 2 1cfa 1cfc
2 1cfe 1d00 2
1d02 1d04 2 1d06
1d08 3 1d0d 1d0e
1d0f 2 1d0a 1d11
2 1cf5 1d13 1
1d15 1 1d17 2
1ce0 1d18 1 1d1c
1 1cdb 2 1cd9
1d20 1 1d40 2
1d3f 1d40 1 1d48
1 1d4e 2 1d50
1d51 2 1d3d 1d52
1 1d59 1 1d54
2 1d6c 1d6e 3
1d6a 1d6b 1d70 2
1d79 1d7b 2 1d7d
1d7f 2 1d81 1d83
2 1d85 1d87 2
1d89 1d8b 3 1d90
1d91 1d92 2 1d8d
1d94 2 1d78 1d96
1 1d98 1 1d9a
2 1d63 1d9b 1
1d9f 1 1d5e 2
1d5c 1da3 1 1ddb
2 1dda 1ddb 1
1de3 1 1de9 2
1deb 1dec 2 1dd8
1ded 1 1df4 1
1def 2 1e07 1e09
3 1e05 1e06 1e0b
2 1e14 1e16 2
1e18 1e1a 2 1e1c
1e1e 2 1e20 1e22
2 1e24 1e26 3
1e2b 1e2c 1e2d 2
1e28 1e2f 2 1e13
1e31 1 1e33 1
1e35 2 1dfe 1e36
1 1e3a 1 1df9
2 1df7 1e3e 2
1eba 1ebc 3 1eb8
1eb9 1ebe 2 1ec7
1ec9 2 1ec6 1ecb
1 1ecd 1 1ecf
c 1ca4 1ca9 1d23
1d29 1d2e 1da6 1dac
1db1 1e41 1eb0 1ed0
1ed3 2 1ed8 1ed9
1 1edd 2 1edb
1edd 2 1ee2 1ee4
3 1ee6 1ee7 1ee8
2 1f11 1f13 3
1f0f 1f10 1f15 2
1f1e 1f20 2 1f1d
1f22 1 1f24 1
1f26 4 1eeb 1f07
1f27 1f2a 2 1f2f
1f30 1 1f36 2
1f32 1f36 2 1f3b
1f3c 1 1f42 2
1f3e 1f42 2 1f6d
1f6f 3 1f6b 1f6c
1f71 2 1f7a 1f7c
2 1f79 1f7e 1
1f80 1 1f82 3
1f63 1f83 1f86 2
1f91 1f93 3 1f8f
1f90 1f95 2 1f9e
1fa0 2 1fa2 1fa4
2 1fa6 1fa8 1
1fb0 2 1fb2 1fb3
2 1faa 1fb5 2
1fb7 1fb9 2 1fbb
1fbd 2 1fbf 1fc1
2 1fc3 1fc5 2
1f9d 1fc7 1 1fc9
1 1fcb 3 1fd2
1fd3 1fd4 2 1fcc
1fd6 f 1fd8 b26
be4 1124 12e4 14ef
1607 1915 1a4f 1bc3
1c96 1ed6 1f2d 1f88
1fd9 8 122 141
1b6 1b9 1bc 1bf
6f4 1fda 2 1fe7
1fe9 3 1fe5 1fe6
1feb 2 1ff4 1ff6
2 1ff3 1ff8 2
1fff 2003 2 2005
2007 2 2009 200d
2 1ffe 200f 2
1ffa 2011 1 2013
3 2014 201f 2023
1 1fde 2 2036
2038 3 2034 2035
203a 2 2043 2045
2 2042 2047 2
204e 2050 2 2052
2054 3 2059 205a
205b 2 2056 205d
2 204d 205f 2
2049 2061 1 2063
4 202d 2064 206d
2071 1 2075 1
2028 2 2026 2079
1c 1b 22 29
30 37 3e 44
4a 50 56 5c
62 69 70 77
7e 85 8c 93
9a a1 a8 af
b6 bd c4 cb
d2 
1
4
0 
2080
0
1
50
34
20
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 4552 4f53 5255 4543
495f 2944 5420 4548 204e 3331 4520 534c
2045 3831 2035 4e45 2044 5341 5220 5345
545f 5059 2c45 200a 2020 2020 5220 5345

3 1 0
c6 1 0
b 1 0
bf 1 0
52 1 0
2 0 1
64 1 0
6b 1 0
72 1 0
58 1 0
80 1 0
4c 1 0
87 1 0
8e 1 0
95 1 0
9c 1 0
a3 1 0
aa 1 0
b1 1 0
b8 1 0
79 1 0
40 1 0
1d 1 0
16 1 0
5e 1 0
39 1 0
32 1 0
2b 1 0
46 1 0
7 1 0
24 1 0
cd 1 0
0

/
SHOW ERRORS FUNCTION SP_S_PROFILE;
ALTER FUNCTION SP_S_PROFILE COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_U_NAMES ==
CREATE OR REPLACE FUNCTION FC_U_NAMES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
6f
2 :e:
1FUNCTION:
1FC_U_NAMES:
1A_ELEMENT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_FULL_NAME:
1A_PARTICIPANT_ID:
1SH_H_TABLE_TYPE:
1PLS_INTEGER:
1RETURN:
1H_TABLE_TYPE:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_NAMES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
119:
1+:
1FPUT:
1               ENTER:: FC_U_NAMES(20) :: cplan.sql(14764) :: :
1PMO_CNST:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1ASSIGN_NAMES:
1INSTR:
1REPLACE:
1LENGTH:
1ELEMENT_ID:
1UPDATE TMT_ASSIGNED_SCORECARDS SET ASSIGN_NAMES =:n            CASE:n        +
1    WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_ful+
1l_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            +
1ELSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_+
1NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIG+
1N_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_e+
1lement_id:
1FOUND:
1TRUE:
1=:
1PMO_DB2M:
1SC_STATE:
10:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
148:
1           EXCEPTION:: FC_U_NAMES(49) :: cplan.sql(14793) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_TABLE_POL:
1TMT_POOLS:
1MANAGER_ID:
1UPDATE TMT_POOLS SET MANAGER_ID = a_participant_id, ASSIGN_NAMES =:n         +
1   CASE:n            WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n     +
1       THEN h_full_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', +
1''):n            ELSE:n            CASE:n            WHEN LENGTH(h_full_name)+
1 + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_nam+
1e || ';' || ASSIGN_NAMES:n            END:n            END:n            WHERE+
1 ELEMENT_ID = a_element_id:
180:
1           EXCEPTION:: FC_U_NAMES(81) :: cplan.sql(14825) :: :
1SC_TABLE_CRI:
1TMT_CRI:
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1111:
1           EXCEPTION:: FC_U_NAMES(112) :: cplan.sql(14856) :: :
1SC_TABLE_DOC:
1TMT_DOCUMENTS:
1UPDATE TMT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            WHEN I+
1nStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || +
1';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n    +
1        CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2+
1040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n +
1           END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1143:
1           EXCEPTION:: FC_U_NAMES(144) :: cplan.sql(14888) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1UPDATE TMT_POOL_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            W+
1HEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_nam+
1e || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1175:
1           EXCEPTION:: FC_U_NAMES(176) :: cplan.sql(14920) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1UPDATE TMT_RESOURCE_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n         +
1   WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full+
1_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            E+
1LSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_N+
1AMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN+
1_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_el+
1ement_id:
1207:
1           EXCEPTION:: FC_U_NAMES(208) :: cplan.sql(14952) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1UPDATE TMT_ASSET_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            +
1WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_na+
1me || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1239:
1           EXCEPTION:: FC_U_NAMES(240) :: cplan.sql(14984) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1UPDATE TMT_CLIENT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1271:
1           EXCEPTION:: FC_U_NAMES(272) :: cplan.sql(15016) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1UPDATE TMT_VENDOR_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1303:
1           EXCEPTION:: FC_U_NAMES(304) :: cplan.sql(15048) :: :
1TMT_WBS:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1335:
1           EXCEPTION:: FC_U_NAMES(336) :: cplan.sql(15080) :: :
1343:
1                EXIT:: FC_U_NAMES(344) :: cplan.sql(15088) :: :
1STATE:: :
0

0
0
5fc
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a6 9 :2 a0 6b
:14 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a6 9 :2 a0 6b :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a6 9
:2 a0 6b :12 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 :2 a0 6b :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a6 9 :2 a0 6b :12 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :2 a0
6b :12 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a6 9 :2 a0 6b :12 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a6
9 :2 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a6 9 :12 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 9
a4 14 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
5fc
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 6e 80 84 88 8c a9 94
98 a0 a4 6b 90 b0 b4 b7
bb bf c2 c7 c8 1 ca cf
d3 d7 da df e3 e7 ea ef
f0 f2 f7 fa fe ff 104 109
10c 111 112 117 11a 11e 11f 124
127 12c 12d 132 135 13a 13b 140
143 148 149 14e 151 155 156 15b
15e 163 164 169 16c 171 172 177
17a 17f 180 185 188 18c 18d 192
195 19a 19b 1a0 1a3 1a8 1a9 1ae
1b1 1b5 1b9 1bd 1be 1c0 1c5 1c6
1c8 1c9 1ce 1d1 1d6 1d7 1dc 1dd
1e2 1e4 1e8 1eb 1ef 1f3 1f6 1fa
1fe 201 204 209 20c 20f 212 213
218 219 1 21b 220 224 228 22b
230 235 238 23c 23d 242 243 248
24a 24e 251 255 259 25d 260 264
268 26c 270 274 278 27c 280 284
288 28c 290 294 298 29c 2a0 2a4
2a8 2b4 2b8 2bd 2c1 2c4 2c5 2ca
2ce 2d2 2d5 2d8 2dc 2de 2e2 2e6
2e9 2ec 2f0 2f2 2f6 2fa 2fd 2ff
303 307 30b 30e 312 316 318 319
31e 1 322 326 32a 32d 331 335
339 33d 340 344 348 34b 34e 353
356 359 35c 35d 362 363 1 365
36a 36e 372 375 37a 37f 382 386
387 38c 38f 394 395 39a 39d 3a2
3a3 3a8 3ab 3af 3b0 3b5 3b8 3bd
3be 3c3 3c6 3ca 3ce 3d1 3d4 3d5
3d7 3d8 3dd 3de 3e3 3e5 3e9 3ec
3ee 3f2 3f4 400 402 404 405 40a
40e 410 41c 41e 420 421 426 42a
42e 431 435 439 43d 441 445 449
44d 451 455 459 45d 461 465 469
46d 471 475 479 47d 481 48d 491
496 49a 49d 49e 4a3 4a7 4ab 4ae
4b1 4b5 4b7 4bb 4bf 4c2 4c5 4c9
4cb 4cf 4d3 4d6 4d8 4dc 4e0 4e4
4e7 4eb 4ef 4f1 4f2 4f7 1 4fb
4ff 503 506 50a 50e 512 516 519
51d 521 524 527 52c 52f 532 535
536 53b 53c 1 53e 543 547 54b
54e 553 558 55b 55f 560 565 568
56d 56e 573 576 57b 57c 581 584
588 589 58e 591 596 597 59c 59f
5a3 5a7 5aa 5ad 5ae 5b0 5b1 5b6
5b7 5bc 5be 5c2 5c5 5c7 5cb 5cd
5d9 5db 5dd 5de 5e3 5e7 5e9 5f5
5f7 5f9 5fa 5ff 603 607 60a 60e
612 616 61a 61e 622 626 62a 62e
632 636 63a 63e 642 646 64a 64e
652 65e 662 667 66b 66e 66f 674
678 67c 67f 682 686 688 68c 690
693 696 69a 69c 6a0 6a4 6a7 6a9
6ad 6b1 6b5 6b8 6bc 6c0 6c2 6c3
6c8 1 6cc 6d0 6d4 6d7 6db 6df
6e3 6e7 6ea 6ee 6f2 6f5 6f8 6fd
700 703 706 707 70c 70d 1 70f
714 718 71c 71f 724 729 72c 730
731 736 739 73e 73f 744 747 74c
74d 752 755 759 75a 75f 762 767
768 76d 770 774 778 77b 77e 77f
781 782 787 788 78d 78f 793 796
798 79c 79e 7aa 7ac 7ae 7af 7b4
7b8 7ba 7c6 7c8 7ca 7cb 7d0 7d4
7d8 7db 7df 7e3 7e7 7eb 7ef 7f3
7f7 7fb 7ff 803 807 80b 80f 813
817 81b 81f 823 82f 833 838 83c
83f 840 845 849 84d 850 853 857
859 85d 861 864 867 86b 86d 871
875 878 87a 87e 882 886 889 88d
891 893 894 899 1 89d 8a1 8a5
8a8 8ac 8b0 8b4 8b8 8bb 8bf 8c3
8c6 8c9 8ce 8d1 8d4 8d7 8d8 8dd
8de 1 8e0 8e5 8e9 8ed 8f0 8f5
8fa 8fd 901 902 907 90a 90f 910
915 918 91d 91e 923 926 92a 92b
930 933 938 939 93e 941 945 949
94c 94f 950 952 953 958 959 95e
960 964 967 969 96d 96f 97b 97d
97f 980 985 989 98b 997 999 99b
99c 9a1 9a5 9a9 9ac 9b0 9b4 9b8
9bc 9c0 9c4 9c8 9cc 9d0 9d4 9d8
9dc 9e0 9e4 9e8 9ec 9f0 9f4 a00
a04 a09 a0d a10 a11 a16 a1a a1e
a21 a24 a28 a2a a2e a32 a35 a38
a3c a3e a42 a46 a49 a4b a4f a53
a57 a5a a5e a62 a64 a65 a6a 1
a6e a72 a76 a79 a7d a81 a85 a89
a8c a90 a94 a97 a9a a9f aa2 aa5
aa8 aa9 aae aaf 1 ab1 ab6 aba
abe ac1 ac6 acb ace ad2 ad3 ad8
adb ae0 ae1 ae6 ae9 aee aef af4
af7 afb afc b01 b04 b09 b0a b0f
b12 b16 b1a b1d b20 b21 b23 b24
b29 b2a b2f b31 b35 b38 b3a b3e
b40 b4c b4e b50 b51 b56 b5a b5c
b68 b6a b6c b6d b72 b76 b7a b7d
b81 b85 b89 b8d b91 b95 b99 b9d
ba1 ba5 ba9 bad bb1 bb5 bb9 bbd
bc1 bc5 bd1 bd5 bda bde be1 be2
be7 beb bef bf2 bf5 bf9 bfb bff
c03 c06 c09 c0d c0f c13 c17 c1a
c1c c20 c24 c28 c2b c2f c33 c35
c36 c3b 1 c3f c43 c47 c4a c4e
c52 c56 c5a c5d c61 c65 c68 c6b
c70 c73 c76 c79 c7a c7f c80 1
c82 c87 c8b c8f c92 c97 c9c c9f
ca3 ca4 ca9 cac cb1 cb2 cb7 cba
cbf cc0 cc5 cc8 ccc ccd cd2 cd5
cda cdb ce0 ce3 ce7 ceb cee cf1
cf2 cf4 cf5 cfa cfb d00 d02 d06
d09 d0b d0f d11 d1d d1f d21 d22
d27 d2b d2d d39 d3b d3d d3e d43
d47 d4b d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 da2 da6 dab
daf db2 db3 db8 dbc dc0 dc3 dc6
dca dcc dd0 dd4 dd7 dda dde de0
de4 de8 deb ded df1 df5 df9 dfc
e00 e04 e06 e07 e0c 1 e10 e14
e18 e1b e1f e23 e27 e2b e2e e32
e36 e39 e3c e41 e44 e47 e4a e4b
e50 e51 1 e53 e58 e5c e60 e63
e68 e6d e70 e74 e75 e7a e7d e82
e83 e88 e8b e90 e91 e96 e99 e9d
e9e ea3 ea6 eab eac eb1 eb4 eb8
ebc ebf ec2 ec3 ec5 ec6 ecb ecc
ed1 ed3 ed7 eda edc ee0 ee2 eee
ef0 ef2 ef3 ef8 efc efe f0a f0c
f0e f0f f14 f18 f1c f1f f23 f27
f2b f2f f33 f37 f3b f3f f43 f47
f4b f4f f53 f57 f5b f5f f63 f67
f73 f77 f7c f80 f83 f84 f89 f8d
f91 f94 f97 f9b f9d fa1 fa5 fa8
fab faf fb1 fb5 fb9 fbc fbe fc2
fc6 fca fcd fd1 fd5 fd7 fd8 fdd
1 fe1 fe5 fe9 fec ff0 ff4 ff8
ffc fff 1003 1007 100a 100d 1012 1015
1018 101b 101c 1021 1022 1 1024 1029
102d 1031 1034 1039 103e 1041 1045 1046
104b 104e 1053 1054 1059 105c 1061 1062
1067 106a 106e 106f 1074 1077 107c 107d
1082 1085 1089 108d 1090 1093 1094 1096
1097 109c 109d 10a2 10a4 10a8 10ab 10ad
10b1 10b3 10bf 10c1 10c3 10c4 10c9 10cd
10cf 10db 10dd 10df 10e0 10e5 10e9 10ed
10f0 10f4 10f8 10fc 1100 1104 1108 110c
1110 1114 1118 111c 1120 1124 1128 112c
1130 1134 1138 1144 1148 114d 1151 1154
1155 115a 115e 1162 1165 1168 116c 116e
1172 1176 1179 117c 1180 1182 1186 118a
118d 118f 1193 1197 119b 119e 11a2 11a6
11a8 11a9 11ae 1 11b2 11b6 11ba 11bd
11c1 11c5 11c9 11cd 11d0 11d4 11d8 11db
11de 11e3 11e6 11e9 11ec 11ed 11f2 11f3
1 11f5 11fa 11fe 1202 1205 120a 120f
1212 1216 1217 121c 121f 1224 1225 122a
122d 1232 1233 1238 123b 123f 1240 1245
1248 124d 124e 1253 1256 125a 125e 1261
1264 1265 1267 1268 126d 126e 1273 1275
1279 127c 127e 1282 1284 1290 1292 1294
1295 129a 129e 12a0 12ac 12ae 12b0 12b1
12b6 12ba 12be 12c2 12c6 12ca 12ce 12d2
12d6 12da 12de 12e2 12e6 12ea 12ee 12f2
12f6 12fa 12fe 130a 130e 1313 1317 131a
131b 1320 1324 1328 132b 132e 1332 1334
1338 133c 133f 1342 1346 1348 134c 1350
1353 1355 1359 135d 1361 1364 1368 136c
136e 136f 1374 1 1378 137c 1380 1383
1387 138b 138f 1393 1396 139a 139e 13a1
13a4 13a9 13ac 13af 13b2 13b3 13b8 13b9
1 13bb 13c0 13c4 13c8 13cb 13d0 13d5
13d8 13dc 13dd 13e2 13e5 13ea 13eb 13f0
13f3 13f8 13f9 13fe 1401 1405 1406 140b
140e 1413 1414 1419 141c 1420 1424 1427
142a 142b 142d 142e 1433 1434 1439 143b
143f 1442 1444 1448 144a 1456 1458 145a
145b 1460 1464 1466 1472 1474 1476 147b
147f 1484 1488 148c 148f 1493 1497 149a
149d 14a2 14a5 14a8 14ab 14ac 14b1 14b2
1 14b4 14b9 14bd 14c1 14c4 14c9 14ce
14d1 14d5 14d6 14db 14de 14e3 14e4 14e9
14ec 14f1 14f2 14f7 14fa 14fe 1502 1505
1506 150b 150c 1511 1513 1517 151a 151e
1522 1526 1529 152d 152f 1533 1535 1541
1545 1547 1548 1551 
5fc
2
0 1 a 6 16 1a 21 :3 6
15 19 20 :3 6 1a 1e 25 :3 6
16 :2 6 1 3 a :2 1 4 :2 11
20 11 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
52 58 5b :2 52 69 7d 8 :2 69
d 10 :2 69 1d 20 :2 69 b e
:2 69 13 16 :2 69 1b 1e :2 69 2a
2d :2 69 b e :2 69 13 16 :2 69
1b 1e :2 69 2f 32 :2 69 b e
:2 69 13 16 1f 27 :2 1f 39 :2 16
:2 69 41 44 :2 69 :2 7 48 :2 4 7
:2 11 23 :2 2d 39 3c 4a 4c 4d
:2 4a :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 50 :2 4 9 c :2 15 14
30 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 59 5a :2 57 :2 2f
:3 13 :2 19 1e 2a 67 6a :2 2a 77
7a :2 2a 7e 81 :2 2a 8d 90 :2 2a
98 9b :2 2a a7 aa b1 ba bd
:2 aa :2 2a :2 13 5d :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 22 2f
41 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 59 5a :2 57 :2 2f
:3 13 :2 19 1e 2a 67 6a :2 2a 77
7a :2 2a 7e 81 :2 2a 8d 90 :2 2a
98 9b :2 2a a7 aa b1 ba bd
:2 aa :2 2a :2 13 5d :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 20 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 22
:2 7 c :2 15 14 26 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 22 :2 7 c
:2 15 14 2b 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5e :2 10 :2 d
:4 19 :2 d a :4 26 :2 7 c :2 15 14
2f 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 5a 5b :2 57 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5e :2 10 :2 d :4 19 :2 d
a :4 26 :2 7 c :2 15 14 2c 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 26
:2 7 c :2 15 14 2d 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 26 :2 7 c
:2 15 14 2d 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5e :2 10 :2 d
:4 19 :2 d a :4 26 :2 7 14 20 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 7
:3 4 7 :2 11 23 :2 2d 39 3c 4a
4d 4e :2 4a :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e 6c 6f :2 1e 73 76
:2 1e 80 83 :2 8c :2 1e :2 7 51 :3 4
b :2 14 4 :9 1 
5fc
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 2 :2 7
:2 1 :6 9 :b b :11 c
d :2 c :2 d :2 c
:2 d :2 c :2 e :2 c
:2 e :2 c :2 e :2 c
:2 e :2 c :2 f :2 c
:2 f :2 c :2 f :2 c
:2 f :2 c :2 10 :2 c
:9 10 :2 c :2 10 :4 c
:3 b :11 13 :b 14 :3 13
17 :3 18 :2 1a :3 1c
:4 1d :5 20 :2 21 :2 24
1a :6 25 :5 26 25
:5 28 27 :3 25 19
2b :5 2c :3 2b :2 2d
:5 2f :11 30 :24 31 :3 30
:2 2e :6 2d 2a :6 18
:3 38 :4 3a :3 3c :4 3d
:5 40 :2 41 :2 44 3a
:6 45 :5 46 45 :5 48
47 :3 45 39 4b
:5 4c :3 4b :2 4d :5 4f
:11 50 :24 51 :3 50 :2 4e
:6 4d 4a :6 38 :3 57
:2 59 :3 5b :4 5c :5 5f
:2 60 :2 63 59 :6 64
:5 65 64 :5 67 66
:3 64 58 6a :5 6b
:3 6a :2 6c :5 6e :11 6f
:24 70 :3 6f :2 6d :6 6c
69 :6 57 :3 77 :2 79
:3 7b :4 7c :5 7f :2 80
:2 83 79 :6 84 :5 85
84 :5 87 86 :3 84
78 8a :5 8b :3 8a
:2 8c :5 8e :11 8f :24 90
:3 8f :2 8d :6 8c 89
:6 77 :3 97 :2 99 :3 9b
:4 9c :5 9f :2 a0 :2 a3
99 :6 a4 :5 a5 a4
:5 a7 a6 :3 a4 98
aa :5 ab :3 aa :2 ac
:5 ae :11 af :24 b0 :3 af
:2 ad :6 ac a9 :6 97
:3 b7 :2 b9 :3 bb :4 bc
:5 bf :2 c0 :2 c3 b9
:6 c4 :5 c5 c4 :5 c7
c6 :3 c4 b8 ca
:5 cb :3 ca :2 cc :5 ce
:11 cf :24 d0 :3 cf :2 cd
:6 cc c9 :6 b7 :3 d7
:2 d9 :3 db :4 dc :5 df
:2 e0 :2 e3 d9 :6 e4
:5 e5 e4 :5 e7 e6
:3 e4 d8 ea :5 eb
:3 ea :2 ec :5 ee :11 ef
:24 f0 :3 ef :2 ed :6 ec
e9 :6 d7 :3 f7 :2 f9
:3 fb :4 fc :5 ff :2 100
:2 103 f9 :6 104 :5 105
104 :5 107 106 :3 104
f8 10a :5 10b :3 10a
:2 10c :5 10e :11 10f :24 110
:3 10f :2 10d :6 10c 109
:6 f7 :3 117 :2 119 :3 11b
:4 11c :5 11f :2 120 :2 123
119 :6 124 :5 125 124
:5 127 126 :3 124 118
12a :5 12b :3 12a :2 12c
:5 12e :11 12f :24 130 :3 12f
:2 12d :6 12c 129 :6 117
:2 139 :3 13b :4 13c :5 13f
:2 140 :2 143 139 :6 144
:5 145 144 :5 147 146
:3 144 138 14a :5 14b
:3 14a :2 14c :5 14e :11 14f
:24 150 :3 14f :2 14d :6 14c
149 :4 137 :3 17 :11 157
:19 158 :3 157 :5 15a :2 a
:7 1 
1553
4
:3 0 1 :3 0 2
:a 0 5f7 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
10 90 0 b
a :3 0 9 :7 0
17 16 :3 0 b
:3 0 a :3 0 19
1b 0 5f7 2
1c :2 0 d :3 0
a :3 0 1f :7 0
9 :3 0 23 20
21 5f5 0 c
:6 0 e :3 0 24
25 0 d :3 0
f :3 0 27 28
0 2 :4 0 12
29 2b 26 2d
2c :2 0 10 :3 0
11 :3 0 2f 30
0 12 :4 0 d
:3 0 13 :3 0 33
34 0 2 :4 0
14 35 37 14
:4 0 15 :2 0 16
:3 0 16 3a 3c
:3 0 17 :4 0 15
:2 0 18 :4 0 19
3f 41 :3 0 15
:2 0 3 :3 0 1c
43 45 :3 0 15
:2 0 18 :4 0 1f
47 49 :3 0 15
:2 0 19 :4 0 22
4b 4d :3 0 15
:2 0 18 :4 0 25
4f 51 :3 0 15
:2 0 7 :3 0 28
53 55 :3 0 15
:2 0 18 :4 0 2b
57 59 :3 0 15
:2 0 19 :4 0 2e
5b 5d :3 0 15
:2 0 18 :4 0 31
5f 61 :3 0 15
:2 0 8 :3 0 34
63 65 :3 0 15
:2 0 18 :4 0 37
67 69 :3 0 15
:2 0 19 :4 0 3a
6b 6d :3 0 15
:2 0 1a :3 0 1b
:3 0 9 :3 0 3d
71 73 1c :4 0
3f 70 76 42
6f 78 :3 0 15
:2 0 1d :4 0 45
7a 7c :3 0 48
31 7e :2 0 80
4d 81 2e 80
0 82 4f 0
5f3 d :3 0 e
:3 0 83 84 0
d :3 0 1e :3 0
86 87 0 1f
:2 0 2 :4 0 20
:2 0 21 :2 0 1f
:2 0 51 8c 8e
:3 0 54 88 90
85 92 91 :2 0
10 :3 0 22 :3 0
94 95 0 12
:4 0 23 :4 0 15
:2 0 16 :3 0 58
99 9b :3 0 5b
96 9d :2 0 9f
5e a0 93 9f
0 a1 60 0
5f3 c :3 0 24
:3 0 25 :3 0 a3
a4 0 26 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 2c 1
:8 0 ce 2d :4 0
b9 :3 0 2e :3 0
2f :2 0 64 bc
bd :3 0 30 :3 0
31 :3 0 bf c0
0 32 :2 0 c1
c2 0 c4 67
cb 30 :3 0 31
:3 0 c5 c6 0
33 :2 0 c7 c8
0 ca 69 cc
be c4 0 cd
0 ca 0 cd
6b 0 ce 6e
121 34 :3 0 30
:3 0 31 :3 0 d0
d1 0 35 :3 0
d2 d3 0 d5
71 d7 73 d6
d5 :2 0 11f 36
:3 0 30 :3 0 31
:3 0 da db 0
35 :3 0 dc dd
0 117 d :3 0
e :3 0 df e0
0 d :3 0 1e
:3 0 e2 e3 0
37 :2 0 2 :4 0
38 :2 0 21 :2 0
1f :2 0 75 e8
ea :3 0 78 e4
ec e1 ee ed
:2 0 10 :3 0 22
:3 0 f0 f1 0
12 :4 0 39 :4 0
15 :2 0 16 :3 0
7c f5 f7 :3 0
15 :2 0 3a :4 0
7f f9 fb :3 0
15 :2 0 3b :4 0
82 fd ff :3 0
15 :2 0 35 :3 0
85 101 103 :3 0
15 :2 0 3c :4 0
88 105 107 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 8b 10a
10e 8f 109 110
:3 0 92 f2 112
:2 0 114 95 115
ef 114 0 116
97 0 117 99
11a :3 0 11a 0
11a 119 117 118
:6 0 11c 2 :3 0
9c 11e 9e 11d
11c :2 0 11f a0
:2 0 121 0 121
120 ce 11f :6 0
123 1 :3 0 a3
125 a5 124 123
:2 0 5bf 24 :3 0
40 :3 0 126 127
0 41 :3 0 42
:3 0 8 :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 43 1 :8 0
153 2d :4 0 13e
:3 0 2e :3 0 2f
:2 0 a9 141 142
:3 0 30 :3 0 31
:3 0 144 145 0
32 :2 0 146 147
0 149 ac 150
30 :3 0 31 :3 0
14a 14b 0 33
:2 0 14c 14d 0
14f ae 151 143
149 0 152 0
14f 0 152 b0
0 153 b3 1a6
34 :3 0 30 :3 0
31 :3 0 155 156
0 35 :3 0 157
158 0 15a b6
15c b8 15b 15a
:2 0 1a4 36 :3 0
30 :3 0 31 :3 0
15f 160 0 35
:3 0 161 162 0
19c d :3 0 e
:3 0 164 165 0
d :3 0 1e :3 0
167 168 0 37
:2 0 2 :4 0 44
:2 0 21 :2 0 1f
:2 0 ba 16d 16f
:3 0 bd 169 171
166 173 172 :2 0
10 :3 0 22 :3 0
175 176 0 12
:4 0 45 :4 0 15
:2 0 16 :3 0 c1
17a 17c :3 0 15
:2 0 3a :4 0 c4
17e 180 :3 0 15
:2 0 3b :4 0 c7
182 184 :3 0 15
:2 0 35 :3 0 ca
186 188 :3 0 15
:2 0 3c :4 0 cd
18a 18c :3 0 15
:2 0 3d :3 0 3e
:3 0 1f :2 0 3f
:2 0 d0 18f 193
d4 18e 195 :3 0
d7 177 197 :2 0
199 da 19a 174
199 0 19b dc
0 19c de 19f
:3 0 19f 0 19f
19e 19c 19d :6 0
1a1 4 :3 0 e1
1a3 e3 1a2 1a1
:2 0 1a4 e5 :2 0
1a6 0 1a6 1a5
153 1a4 :6 0 1a8
1 :3 0 e8 1aa
ea 1a9 1a8 :2 0
5bf 24 :3 0 46
:3 0 1ab 1ac 0
47 :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
48 1 :8 0 1d6
2d :4 0 1c1 :3 0
2e :3 0 2f :2 0
ee 1c4 1c5 :3 0
30 :3 0 31 :3 0
1c7 1c8 0 32
:2 0 1c9 1ca 0
1cc f1 1d3 30
:3 0 31 :3 0 1cd
1ce 0 33 :2 0
1cf 1d0 0 1d2
f3 1d4 1c6 1cc
0 1d5 0 1d2
0 1d5 f5 0
1d6 f8 229 34
:3 0 30 :3 0 31
:3 0 1d8 1d9 0
35 :3 0 1da 1db
0 1dd fb 1df
fd 1de 1dd :2 0
227 36 :3 0 30
:3 0 31 :3 0 1e2
1e3 0 35 :3 0
1e4 1e5 0 21f
d :3 0 e :3 0
1e7 1e8 0 d
:3 0 1e :3 0 1ea
1eb 0 37 :2 0
2 :4 0 49 :2 0
21 :2 0 1f :2 0
ff 1f0 1f2 :3 0
102 1ec 1f4 1e9
1f6 1f5 :2 0 10
:3 0 22 :3 0 1f8
1f9 0 12 :4 0
4a :4 0 15 :2 0
16 :3 0 106 1fd
1ff :3 0 15 :2 0
3a :4 0 109 201
203 :3 0 15 :2 0
3b :4 0 10c 205
207 :3 0 15 :2 0
35 :3 0 10f 209
20b :3 0 15 :2 0
3c :4 0 112 20d
20f :3 0 15 :2 0
3d :3 0 3e :3 0
1f :2 0 3f :2 0
115 212 216 119
211 218 :3 0 11c
1fa 21a :2 0 21c
11f 21d 1f7 21c
0 21e 121 0
21f 123 222 :3 0
222 0 222 221
21f 220 :6 0 224
6 :3 0 126 226
128 225 224 :2 0
227 12a :2 0 229
0 229 228 1d6
227 :6 0 22b 1
:3 0 12d 22d 12f
22c 22b :2 0 5bf
24 :3 0 4b :3 0
22e 22f 0 4c
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 4d
1 :8 0 259 2d
:4 0 244 :3 0 2e
:3 0 2f :2 0 133
247 248 :3 0 30
:3 0 31 :3 0 24a
24b 0 32 :2 0
24c 24d 0 24f
136 256 30 :3 0
31 :3 0 250 251
0 33 :2 0 252
253 0 255 138
257 249 24f 0
258 0 255 0
258 13a 0 259
13d 2ac 34 :3 0
30 :3 0 31 :3 0
25b 25c 0 35
:3 0 25d 25e 0
260 140 262 142
261 260 :2 0 2aa
36 :3 0 30 :3 0
31 :3 0 265 266
0 35 :3 0 267
268 0 2a2 d
:3 0 e :3 0 26a
26b 0 d :3 0
1e :3 0 26d 26e
0 37 :2 0 2
:4 0 4e :2 0 21
:2 0 1f :2 0 144
273 275 :3 0 147
26f 277 26c 279
278 :2 0 10 :3 0
22 :3 0 27b 27c
0 12 :4 0 4f
:4 0 15 :2 0 16
:3 0 14b 280 282
:3 0 15 :2 0 3a
:4 0 14e 284 286
:3 0 15 :2 0 3b
:4 0 151 288 28a
:3 0 15 :2 0 35
:3 0 154 28c 28e
:3 0 15 :2 0 3c
:4 0 157 290 292
:3 0 15 :2 0 3d
:3 0 3e :3 0 1f
:2 0 3f :2 0 15a
295 299 15e 294
29b :3 0 161 27d
29d :2 0 29f 164
2a0 27a 29f 0
2a1 166 0 2a2
168 2a5 :3 0 2a5
0 2a5 2a4 2a2
2a3 :6 0 2a7 8
:3 0 16b 2a9 16d
2a8 2a7 :2 0 2aa
16f :2 0 2ac 0
2ac 2ab 259 2aa
:6 0 2ae 1 :3 0
172 2b0 174 2af
2ae :2 0 5bf 24
:3 0 50 :3 0 2b1
2b2 0 51 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 52 1
:8 0 2dc 2d :4 0
2c7 :3 0 2e :3 0
2f :2 0 178 2ca
2cb :3 0 30 :3 0
31 :3 0 2cd 2ce
0 32 :2 0 2cf
2d0 0 2d2 17b
2d9 30 :3 0 31
:3 0 2d3 2d4 0
33 :2 0 2d5 2d6
0 2d8 17d 2da
2cc 2d2 0 2db
0 2d8 0 2db
17f 0 2dc 182
32f 34 :3 0 30
:3 0 31 :3 0 2de
2df 0 35 :3 0
2e0 2e1 0 2e3
185 2e5 187 2e4
2e3 :2 0 32d 36
:3 0 30 :3 0 31
:3 0 2e8 2e9 0
35 :3 0 2ea 2eb
0 325 d :3 0
e :3 0 2ed 2ee
0 d :3 0 1e
:3 0 2f0 2f1 0
37 :2 0 2 :4 0
53 :2 0 21 :2 0
1f :2 0 189 2f6
2f8 :3 0 18c 2f2
2fa 2ef 2fc 2fb
:2 0 10 :3 0 22
:3 0 2fe 2ff 0
12 :4 0 54 :4 0
15 :2 0 16 :3 0
190 303 305 :3 0
15 :2 0 3a :4 0
193 307 309 :3 0
15 :2 0 3b :4 0
196 30b 30d :3 0
15 :2 0 35 :3 0
199 30f 311 :3 0
15 :2 0 3c :4 0
19c 313 315 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 19f 318
31c 1a3 317 31e
:3 0 1a6 300 320
:2 0 322 1a9 323
2fd 322 0 324
1ab 0 325 1ad
328 :3 0 328 0
328 327 325 326
:6 0 32a a :3 0
1b0 32c 1b2 32b
32a :2 0 32d 1b4
:2 0 32f 0 32f
32e 2dc 32d :6 0
331 1 :3 0 1b7
333 1b9 332 331
:2 0 5bf 24 :3 0
55 :3 0 334 335
0 56 :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 57 1 :8 0
35f 2d :4 0 34a
:3 0 2e :3 0 2f
:2 0 1bd 34d 34e
:3 0 30 :3 0 31
:3 0 350 351 0
32 :2 0 352 353
0 355 1c0 35c
30 :3 0 31 :3 0
356 357 0 33
:2 0 358 359 0
35b 1c2 35d 34f
355 0 35e 0
35b 0 35e 1c4
0 35f 1c7 3b2
34 :3 0 30 :3 0
31 :3 0 361 362
0 35 :3 0 363
364 0 366 1ca
368 1cc 367 366
:2 0 3b0 36 :3 0
30 :3 0 31 :3 0
36b 36c 0 35
:3 0 36d 36e 0
3a8 d :3 0 e
:3 0 370 371 0
d :3 0 1e :3 0
373 374 0 37
:2 0 2 :4 0 58
:2 0 21 :2 0 1f
:2 0 1ce 379 37b
:3 0 1d1 375 37d
372 37f 37e :2 0
10 :3 0 22 :3 0
381 382 0 12
:4 0 59 :4 0 15
:2 0 16 :3 0 1d5
386 388 :3 0 15
:2 0 3a :4 0 1d8
38a 38c :3 0 15
:2 0 3b :4 0 1db
38e 390 :3 0 15
:2 0 35 :3 0 1de
392 394 :3 0 15
:2 0 3c :4 0 1e1
396 398 :3 0 15
:2 0 3d :3 0 3e
:3 0 1f :2 0 3f
:2 0 1e4 39b 39f
1e8 39a 3a1 :3 0
1eb 383 3a3 :2 0
3a5 1ee 3a6 380
3a5 0 3a7 1f0
0 3a8 1f2 3ab
:3 0 3ab 0 3ab
3aa 3a8 3a9 :6 0
3ad c :3 0 1f5
3af 1f7 3ae 3ad
:2 0 3b0 1f9 :2 0
3b2 0 3b2 3b1
35f 3b0 :6 0 3b4
1 :3 0 1fc 3b6
1fe 3b5 3b4 :2 0
5bf 24 :3 0 5a
:3 0 3b7 3b8 0
5b :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
5c 1 :8 0 3e2
2d :4 0 3cd :3 0
2e :3 0 2f :2 0
202 3d0 3d1 :3 0
30 :3 0 31 :3 0
3d3 3d4 0 32
:2 0 3d5 3d6 0
3d8 205 3df 30
:3 0 31 :3 0 3d9
3da 0 33 :2 0
3db 3dc 0 3de
207 3e0 3d2 3d8
0 3e1 0 3de
0 3e1 209 0
3e2 20c 435 34
:3 0 30 :3 0 31
:3 0 3e4 3e5 0
35 :3 0 3e6 3e7
0 3e9 20f 3eb
211 3ea 3e9 :2 0
433 36 :3 0 30
:3 0 31 :3 0 3ee
3ef 0 35 :3 0
3f0 3f1 0 42b
d :3 0 e :3 0
3f3 3f4 0 d
:3 0 1e :3 0 3f6
3f7 0 37 :2 0
2 :4 0 5d :2 0
21 :2 0 1f :2 0
213 3fc 3fe :3 0
216 3f8 400 3f5
402 401 :2 0 10
:3 0 22 :3 0 404
405 0 12 :4 0
5e :4 0 15 :2 0
16 :3 0 21a 409
40b :3 0 15 :2 0
3a :4 0 21d 40d
40f :3 0 15 :2 0
3b :4 0 220 411
413 :3 0 15 :2 0
35 :3 0 223 415
417 :3 0 15 :2 0
3c :4 0 226 419
41b :3 0 15 :2 0
3d :3 0 3e :3 0
1f :2 0 3f :2 0
229 41e 422 22d
41d 424 :3 0 230
406 426 :2 0 428
233 429 403 428
0 42a 235 0
42b 237 42e :3 0
42e 0 42e 42d
42b 42c :6 0 430
e :3 0 23a 432
23c 431 430 :2 0
433 23e :2 0 435
0 435 434 3e2
433 :6 0 437 1
:3 0 241 439 243
438 437 :2 0 5bf
24 :3 0 5f :3 0
43a 43b 0 60
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 61
1 :8 0 465 2d
:4 0 450 :3 0 2e
:3 0 2f :2 0 247
453 454 :3 0 30
:3 0 31 :3 0 456
457 0 32 :2 0
458 459 0 45b
24a 462 30 :3 0
31 :3 0 45c 45d
0 33 :2 0 45e
45f 0 461 24c
463 455 45b 0
464 0 461 0
464 24e 0 465
251 4b8 34 :3 0
30 :3 0 31 :3 0
467 468 0 35
:3 0 469 46a 0
46c 254 46e 256
46d 46c :2 0 4b6
36 :3 0 30 :3 0
31 :3 0 471 472
0 35 :3 0 473
474 0 4ae d
:3 0 e :3 0 476
477 0 d :3 0
1e :3 0 479 47a
0 37 :2 0 2
:4 0 62 :2 0 21
:2 0 1f :2 0 258
47f 481 :3 0 25b
47b 483 478 485
484 :2 0 10 :3 0
22 :3 0 487 488
0 12 :4 0 63
:4 0 15 :2 0 16
:3 0 25f 48c 48e
:3 0 15 :2 0 3a
:4 0 262 490 492
:3 0 15 :2 0 3b
:4 0 265 494 496
:3 0 15 :2 0 35
:3 0 268 498 49a
:3 0 15 :2 0 3c
:4 0 26b 49c 49e
:3 0 15 :2 0 3d
:3 0 3e :3 0 1f
:2 0 3f :2 0 26e
4a1 4a5 272 4a0
4a7 :3 0 275 489
4a9 :2 0 4ab 278
4ac 486 4ab 0
4ad 27a 0 4ae
27c 4b1 :3 0 4b1
0 4b1 4b0 4ae
4af :6 0 4b3 10
:3 0 27f 4b5 281
4b4 4b3 :2 0 4b6
283 :2 0 4b8 0
4b8 4b7 465 4b6
:6 0 4ba 1 :3 0
286 4bc 288 4bb
4ba :2 0 5bf 24
:3 0 64 :3 0 4bd
4be 0 65 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 66 1
:8 0 4e8 2d :4 0
4d3 :3 0 2e :3 0
2f :2 0 28c 4d6
4d7 :3 0 30 :3 0
31 :3 0 4d9 4da
0 32 :2 0 4db
4dc 0 4de 28f
4e5 30 :3 0 31
:3 0 4df 4e0 0
33 :2 0 4e1 4e2
0 4e4 291 4e6
4d8 4de 0 4e7
0 4e4 0 4e7
293 0 4e8 296
53b 34 :3 0 30
:3 0 31 :3 0 4ea
4eb 0 35 :3 0
4ec 4ed 0 4ef
299 4f1 29b 4f0
4ef :2 0 539 36
:3 0 30 :3 0 31
:3 0 4f4 4f5 0
35 :3 0 4f6 4f7
0 531 d :3 0
e :3 0 4f9 4fa
0 d :3 0 1e
:3 0 4fc 4fd 0
37 :2 0 2 :4 0
67 :2 0 21 :2 0
1f :2 0 29d 502
504 :3 0 2a0 4fe
506 4fb 508 507
:2 0 10 :3 0 22
:3 0 50a 50b 0
12 :4 0 68 :4 0
15 :2 0 16 :3 0
2a4 50f 511 :3 0
15 :2 0 3a :4 0
2a7 513 515 :3 0
15 :2 0 3b :4 0
2aa 517 519 :3 0
15 :2 0 35 :3 0
2ad 51b 51d :3 0
15 :2 0 3c :4 0
2b0 51f 521 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 2b3 524
528 2b7 523 52a
:3 0 2ba 50c 52c
:2 0 52e 2bd 52f
509 52e 0 530
2bf 0 531 2c1
534 :3 0 534 0
534 533 531 532
:6 0 536 12 :3 0
2c4 538 2c6 537
536 :2 0 539 2c8
:2 0 53b 0 53b
53a 4e8 539 :6 0
53d 1 :3 0 2cb
53f 2cd 53e 53d
:2 0 5bf 69 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 6a 1
:8 0 568 2d :4 0
553 :3 0 2e :3 0
2f :2 0 2d1 556
557 :3 0 30 :3 0
31 :3 0 559 55a
0 32 :2 0 55b
55c 0 55e 2d4
565 30 :3 0 31
:3 0 55f 560 0
33 :2 0 561 562
0 564 2d6 566
558 55e 0 567
0 564 0 567
2d8 0 568 2db
5bb 34 :3 0 30
:3 0 31 :3 0 56a
56b 0 35 :3 0
56c 56d 0 56f
2de 571 2e0 570
56f :2 0 5b9 36
:3 0 30 :3 0 31
:3 0 574 575 0
35 :3 0 576 577
0 5b1 d :3 0
e :3 0 579 57a
0 d :3 0 1e
:3 0 57c 57d 0
37 :2 0 2 :4 0
6b :2 0 21 :2 0
1f :2 0 2e2 582
584 :3 0 2e5 57e
586 57b 588 587
:2 0 10 :3 0 22
:3 0 58a 58b 0
12 :4 0 6c :4 0
15 :2 0 16 :3 0
2e9 58f 591 :3 0
15 :2 0 3a :4 0
2ec 593 595 :3 0
15 :2 0 3b :4 0
2ef 597 599 :3 0
15 :2 0 35 :3 0
2f2 59b 59d :3 0
15 :2 0 3c :4 0
2f5 59f 5a1 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 2f8 5a4
5a8 2fc 5a3 5aa
:3 0 2ff 58c 5ac
:2 0 5ae 302 5af
589 5ae 0 5b0
304 0 5b1 306
5b4 :3 0 5b4 0
5b4 5b3 5b1 5b2
:6 0 5b6 14 :3 0
309 5b8 30b 5b7
5b6 :2 0 5b9 30d
:2 0 5bb 0 5bb
5ba 568 5b9 :6 0
5bd 1 :3 0 310
5be 0 5bd :2 0
5bf 312 :2 0 5c0
a2 5bf 0 5f3
0 d :3 0 e
:3 0 5c1 5c2 0
d :3 0 1e :3 0
5c4 5c5 0 1f
:2 0 2 :4 0 6d
:2 0 21 :2 0 1f
:2 0 31d 5ca 5cc
:3 0 320 5c6 5ce
5c3 5d0 5cf :2 0
10 :3 0 22 :3 0
5d2 5d3 0 12
:4 0 6e :4 0 15
:2 0 16 :3 0 324
5d7 5d9 :3 0 15
:2 0 3a :4 0 327
5db 5dd :3 0 15
:2 0 6f :4 0 32a
5df 5e1 :3 0 15
:2 0 30 :3 0 31
:3 0 5e4 5e5 0
32d 5e3 5e7 :3 0
330 5d4 5e9 :2 0
5eb 333 5ec 5d1
5eb 0 5ed 335
0 5f3 b :3 0
30 :3 0 31 :3 0
5ef 5f0 0 5f1
:2 0 5f3 337 5f6
:3 0 5f6 33d 5f6
5f5 5f3 5f4 :6 0
5f7 :2 0 2 1c
5f6 5fa :3 0 5f9
5f7 5fb :8 0 
33f
4
:3 0 1 3 1
9 1 f 1
15 4 8 e
14 18 1 1e
1 2a 1 36
2 39 3b 2
3e 40 2 42
44 2 46 48
2 4a 4c 2
4e 50 2 52
54 2 56 58
2 5a 5c 2
5e 60 2 62
64 2 66 68
2 6a 6c 1
72 2 74 75
2 6e 77 2
79 7b 4 32
38 3d 7d 1
7f 1 81 2
8b 8d 3 89
8a 8f 2 98
9a 2 97 9c
1 9e 1 a0
1 bb 2 ba
bb 1 c3 1
c9 2 cb cc
2 b8 cd 1
d4 1 cf 2
e7 e9 3 e5
e6 eb 2 f4
f6 2 f8 fa
2 fc fe 2
100 102 2 104
106 3 10b 10c
10d 2 108 10f
2 f3 111 1
113 1 115 2
de 116 1 11a
1 d9 2 d7
11e 1 121 1
a5 1 140 2
13f 140 1 148
1 14e 2 150
151 2 13d 152
1 159 1 154
2 16c 16e 3
16a 16b 170 2
179 17b 2 17d
17f 2 181 183
2 185 187 2
189 18b 3 190
191 192 2 18d
194 2 178 196
1 198 1 19a
2 163 19b 1
19f 1 15e 2
15c 1a3 1 1a6
1 128 1 1c3
2 1c2 1c3 1
1cb 1 1d1 2
1d3 1d4 2 1c0
1d5 1 1dc 1
1d7 2 1ef 1f1
3 1ed 1ee 1f3
2 1fc 1fe 2
200 202 2 204
206 2 208 20a
2 20c 20e 3
213 214 215 2
210 217 2 1fb
219 1 21b 1
21d 2 1e6 21e
1 222 1 1e1
2 1df 226 1
229 1 1ad 1
246 2 245 246
1 24e 1 254
2 256 257 2
243 258 1 25f
1 25a 2 272
274 3 270 271
276 2 27f 281
2 283 285 2
287 289 2 28b
28d 2 28f 291
3 296 297 298
2 293 29a 2
27e 29c 1 29e
1 2a0 2 269
2a1 1 2a5 1
264 2 262 2a9
1 2ac 1 230
1 2c9 2 2c8
2c9 1 2d1 1
2d7 2 2d9 2da
2 2c6 2db 1
2e2 1 2dd 2
2f5 2f7 3 2f3
2f4 2f9 2 302
304 2 306 308
2 30a 30c 2
30e 310 2 312
314 3 319 31a
31b 2 316 31d
2 301 31f 1
321 1 323 2
2ec 324 1 328
1 2e7 2 2e5
32c 1 32f 1
2b3 1 34c 2
34b 34c 1 354
1 35a 2 35c
35d 2 349 35e
1 365 1 360
2 378 37a 3
376 377 37c 2
385 387 2 389
38b 2 38d 38f
2 391 393 2
395 397 3 39c
39d 39e 2 399
3a0 2 384 3a2
1 3a4 1 3a6
2 36f 3a7 1
3ab 1 36a 2
368 3af 1 3b2
1 336 1 3cf
2 3ce 3cf 1
3d7 1 3dd 2
3df 3e0 2 3cc
3e1 1 3e8 1
3e3 2 3fb 3fd
3 3f9 3fa 3ff
2 408 40a 2
40c 40e 2 410
412 2 414 416
2 418 41a 3
41f 420 421 2
41c 423 2 407
425 1 427 1
429 2 3f2 42a
1 42e 1 3ed
2 3eb 432 1
435 1 3b9 1
452 2 451 452
1 45a 1 460
2 462 463 2
44f 464 1 46b
1 466 2 47e
480 3 47c 47d
482 2 48b 48d
2 48f 491 2
493 495 2 497
499 2 49b 49d
3 4a2 4a3 4a4
2 49f 4a6 2
48a 4a8 1 4aa
1 4ac 2 475
4ad 1 4b1 1
470 2 46e 4b5
1 4b8 1 43c
1 4d5 2 4d4
4d5 1 4dd 1
4e3 2 4e5 4e6
2 4d2 4e7 1
4ee 1 4e9 2
501 503 3 4ff
500 505 2 50e
510 2 512 514
2 516 518 2
51a 51c 2 51e
520 3 525 526
527 2 522 529
2 50d 52b 1
52d 1 52f 2
4f8 530 1 534
1 4f3 2 4f1
538 1 53b 1
4bf 1 555 2
554 555 1 55d
1 563 2 565
566 2 552 567
1 56e 1 569
2 581 583 3
57f 580 585 2
58e 590 2 592
594 2 596 598
2 59a 59c 2
59e 5a0 3 5a5
5a6 5a7 2 5a2
5a9 2 58d 5ab
1 5ad 1 5af
2 578 5b0 1
5b4 1 573 2
571 5b8 1 5bb
a 125 1aa 22d
2b0 333 3b6 439
4bc 53f 5be 2
5c9 5cb 3 5c7
5c8 5cd 2 5d6
5d8 2 5da 5dc
2 5de 5e0 2
5e2 5e6 2 5d5
5e8 1 5ea 1
5ec 5 82 a1
5c0 5ed 5f2 1
22 
1
4
0 
5fa
0
1
28
15
6
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2 0 1
f 1 0
3 1 0
1e 1 0
9 1 0
15 1 0
0

/
SHOW ERRORS FUNCTION FC_U_NAMES;
ALTER FUNCTION FC_U_NAMES COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_DATES ==
CREATE OR REPLACE FUNCTION SP_U_WP_DATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
f0
2 :e:
1FUNCTION:
1SP_U_WP_DATES:
1ASSIGN_ID:
1VARCHAR2:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BILLABLE:
1PLS_INTEGER:
10:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_SKIP:
1H_LAST_DAY:
1H_MINUTES:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_DATES(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1);:
1CHECK_TRACE:
174:
1+:
1FPUT:
1               ENTER:: SP_U_WP_DATES(75) :: cplan.sql(15178) :: :
1PROJECT_ASSIGNMENT_ID:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID,:n      RESOURCE_TYPE, +
1BIT_FLAG, LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT,:n      UNITS_M+
1SP, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UNRESOLVED_FINISH,:n      CA+
1SE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SCHED_WORK END, ASSIGNMENT_DELA+
1Y, LAST_SCHED_MIN,:n      TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_C+
1OST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECI+
1AL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID:n +
1     INTO h_prj_assign_id, h_project_id, h_res_id,:n      h_res_type, h_bit_f+
1lag, h_last_submitted, h_contour, h_work, h_eunit, h_unit,:n      h_percent_u+
1nits, h_actual_start, h_work_todate, h_start_date, h_finish_date,:n      h_ef+
1fort, h_delay, h_last_day,:n      h_SD, h_FD, h_billable, h_capital_expense,+
1:n      h_reg_cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost+
1, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_i+
1d:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_tsk_assignm+
1ent_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1110:
1           EXCEPTION:: SP_U_WP_DATES(111) :: cplan.sql(15214) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1118:
1        RETURN_ERROR:: SP_U_WP_DATES(119) :: cplan.sql(15222) :: :
1STATE:: :
1TO_CHAR:
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1121:
1                EXIT:: SP_U_WP_DATES(122) :: cplan.sql(15225) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1134:
1        RETURN_ERROR:: SP_U_WP_DATES(135) :: cplan.sql(15238) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1137:
1                EXIT:: SP_U_WP_DATES(138) :: cplan.sql(15241) :: :
1MINUTE_PER_DAY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, MINUTE_PER_DAY:n         INTO h_project_id, h_per_day:n   +
1      FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1155:
1           EXCEPTION:: SP_U_WP_DATES(156) :: cplan.sql(15259) :: :
18:
1167:
1      RETURN_INVALID:: SP_U_WP_DATES(168) :: cplan.sql(15271) :: :
1INVALID_PARAMS:
1170:
1                EXIT:: SP_U_WP_DATES(171) :: cplan.sql(15274) :: :
1PMO_RETURN_INVALID_SP:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1FC_U_TDY_LAST_ACTUAL:
1FC_DEL_NOACTUAL:
12:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n         INTO h_start_date:n         FRO+
1M DUAL:
1211:
1           EXCEPTION:: SP_U_WP_DATES(212) :: cplan.sql(15315) :: :
1FC_RESCHEDULE:
1228:
1        RETURN_ERROR:: SP_U_WP_DATES(229) :: cplan.sql(15332) :: :
1TASK_ASSIGNMENT_ERROR:
1231:
1                EXIT:: SP_U_WP_DATES(232) :: cplan.sql(15335) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n              BAK_ASSIGN_STRING = NULL:n        +
1 WHERE TSK_ASSIGNMENT_ID = H_TSK_ASSIGNMENT_ID:
1CONSIDER:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1BAK_START_DT:
1SCHED_START:
1PLANNED_START:
1BAK_FINISH_DT:
1SCHED_FINISH:
1PLANNED_FINISH:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(pmo_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)),:n         BAK_START_+
1DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(SCHED_FINI+
1SH,PLANNED_FINISH),:n         BAK_ASSIGN_STRING = ASSIGN_STRING:n         WHE+
1RE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1257:
1           EXCEPTION:: SP_U_WP_DATES(258) :: cplan.sql(15361) :: :
1FC_ROLLUP:
1265:
1        RETURN_ERROR:: SP_U_WP_DATES(266) :: cplan.sql(15369) :: :
1268:
1                EXIT:: SP_U_WP_DATES(269) :: cplan.sql(15372) :: :
14:
1274:
1       RETURN_STATUS:: SP_U_WP_DATES(275) :: cplan.sql(15378) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1281:
1           EXCEPTION:: SP_U_WP_DATES(282) :: cplan.sql(15385) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1293:
1           EXCEPTION:: SP_U_WP_DATES(294) :: cplan.sql(15397) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
7f4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6e 7e a0 b4 2e 7e
6e b4 2e 6e a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :49 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
7e b4 2e 5a a0 7e b4 2e
5a a 10 :2 a0 d :2 a0 d :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d a0
51 d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 :2 19 3c b7 19 3c
a0 7e 51 b4 2e d :c a0 a5
b d :2 a0 51 a5 b 7e 51
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :9 a0 51 a5 b d b7
19 3c a0 7e b4 2e 5a :4 a0
51 a5 b d b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :4 a0 51 a5
b d b7 :4 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c a0 7e
b4 2e 5a :a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d b7 19 3c a0 51 d :a a0
51 a5 b :2 a0 51 a5 b a5
b d :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :4 a0 12a :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :3 a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
7f4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ee
dd e1 e9 bc 106 f5 f9 101
dc 122 111 115 11d d9 13a 129
12d 135 110 156 145 149 151 10d
16e 15d 161 169 144 18a 179 17d
185 141 1a6 191 195 198 199 1a1
178 1c3 1b1 175 1b5 1b6 1be 1b0
1df 1ce 1d2 1ad 1da 1cd 1fb 1ea
1ee 1ca 1f6 1e9 217 206 20a 1e6
212 205 233 222 226 22e 202 24b
23a 23e 246 221 267 256 25a 21e
262 255 283 272 276 252 27e 271
29f 28e 292 26e 29a 28d 2bb 2aa
2ae 28a 2b6 2a9 2d8 2c6 2a6 2ca
2cb 2d3 2c5 2f5 2e3 2c2 2e7 2e8
2f0 2e2 312 300 2df 304 305 30d
2ff 32e 31d 321 2fc 329 31c 34a
339 33d 319 345 338 366 355 359
335 361 354 382 371 375 351 37d
370 39e 38d 391 36d 399 38c 3ba
3a9 3ad 389 3b5 3a8 3d6 3c5 3c9
3a5 3d1 3c4 3f2 3e1 3e5 3c1 3ed
3e0 40e 3fd 401 3dd 409 3fc 42a
419 41d 3f9 425 418 446 435 439
415 441 434 462 451 455 431 45d
450 47e 46d 471 44d 479 46c 49a
489 48d 469 495 488 4b6 4a5 4a9
485 4b1 4a4 4d2 4c1 4c5 4a1 4cd
4c0 4ee 4dd 4e1 4bd 4e9 4dc 50a
4f9 4fd 4d9 505 4f8 526 515 519
4f5 521 514 542 531 535 511 53d
530 55e 54d 551 52d 559 54c 57a
569 56d 549 575 568 596 585 589
565 591 584 5b2 5a1 5a5 581 5ad
5a0 5ce 5bd 5c1 59d 5c9 5bc 5ea
5d9 5dd 5b9 5e5 5d8 606 5f5 5f9
5d5 601 5f4 622 611 615 5f1 61d
610 63e 62d 631 60d 639 62c 65a
649 64d 629 655 648 67a 665 669
645 66d 675 664 681 685 661 689
68d 691 694 699 69a 1 69c 6a1
6a5 6a9 6ac 6b1 6b5 6b9 6bc 6c1
6c2 6c4 6c9 6cc 6d0 6d1 6d6 6db
6de 6e3 6e4 6e9 6ec 6f0 6f1 6f6
6f9 6fe 6ff 704 707 70c 70d 712
715 719 71d 722 725 729 72a 72f
732 737 738 73d 742 743 745 74a
74b 74d 74e 753 756 75b 75c 761
764 768 76c 771 774 778 779 77e
781 786 787 78c 791 792 794 799
79a 79c 79d 7a2 7a5 7aa 7ab 7b0
7b3 7b8 7b9 7be 7c1 7c5 7c6 7cb
7ce 7d3 7d4 7d9 7dc 7e1 7e2 7e7
7e8 7ed 7ef 7f3 7f6 7fa 7fe 801
805 809 80c 80f 814 817 81a 81d
81e 823 824 1 826 82b 82f 833
836 83b 840 843 847 848 84d 84e
853 855 859 85c 860 864 868 86c
870 874 878 87c 880 884 888 88c
890 894 898 89c 8a0 8a4 8a8 8ac
8b0 8b4 8b8 8bc 8c0 8c4 8c8 8cc
8d0 8d4 8d8 8dc 8e0 8e4 8e8 8ec
8f0 8f4 8f8 8fc 900 904 908 90c
910 914 918 91c 920 924 928 92c
930 934 938 93c 940 944 948 94c
950 954 958 95c 960 964 968 96c
970 974 978 97c 980 984 988 98c
990 994 998 9a4 9a8 9ac 9af 9b3
9b7 9b9 9bd 9c1 9c5 9c8 9cc 9d0
9d2 9d3 9d8 1 9dc 9e0 9e4 9e7
9eb 9ef 9f3 9f7 9fa 9fe a02 a05
a08 a0d a10 a13 a16 a17 a1c a1d
1 a1f a24 a28 a2c a2f a34 a39
a3c a40 a41 a46 a49 a4e a4f a54
a57 a5c a5d a62 a65 a69 a6a a6f
a72 a77 a78 a7d a80 a84 a88 a8b
a8e a8f a91 a92 a97 a98 a9d a9f
aa3 aa6 aa8 aac aae aba abc abe
abf ac4 ac8 aca ad6 ad8 adc ae0
ae3 ae7 aea aee af1 af2 af7 afa
afe b02 b05 b09 b0d b10 b13 b18
b1b b1e b21 b22 b27 b28 1 b2a
b2f b33 b37 b3a b3f b44 b47 b4b
b4c b51 b54 b59 b5a b5f b62 b67
b68 b6d b70 b74 b78 b7c b80 b83
b84 b86 b8b b8c b8e b8f b94 b97
b9c b9d ba2 ba5 baa bab bb0 bb3
bb7 bb8 bbd bc0 bc5 bc6 bcb bcc
bd1 bd3 bd7 bda bde be2 be5 be9
bed bf0 bf3 bf8 bfb bfe c01 c02
c07 c08 1 c0a c0f c13 c17 c1a
c1f c24 c27 c2b c2c c31 c32 c37
c39 c3d c40 c44 c48 c4b c4f c53
c56 c5a c5e c5f c64 c66 c6a c6d
c71 c74 c75 c7a c7d c81 c84 c85
c8a 1 c8d c92 c96 c9a c9e ca2
ca6 caa cae cb2 cb5 cb9 cbd cc0
cc1 cc3 cc6 cc9 cca ccf cd2 cd6
cda cdd ce1 ce5 ce8 ce9 ceb cee
cf1 cf2 cf7 1 cfa cff d03 d07
d0a d0e d12 d15 d18 d1d d20 d23
d26 d27 d2c d2d 1 d2f d34 d38
d3c d3f d44 d49 d4c d50 d51 d56
d59 d5e d5f d64 d67 d6c d6d d72
d75 d79 d7d d81 d85 d88 d89 d8b
d90 d91 d93 d94 d99 d9c da1 da2
da7 daa daf db0 db5 db8 dbc dbd
dc2 dc5 dca dcb dd0 dd1 dd6 dd8
ddc ddf de3 de7 dea dee df2 df5
df8 dfd e00 e03 e06 e07 e0c e0d
1 e0f e14 e18 e1c e1f e24 e29
e2c e30 e31 e36 e37 e3c e3e e42
e45 e49 e4d e50 e54 e58 e5b e5f
e63 e64 e69 e6b e6f e72 e76 e7a
e7e e82 e86 e8a e8e e92 e96 ea2
ea6 eaa ead eb1 eb5 eb7 ebb ebf
ec3 ec6 eca ece ed0 ed1 ed6 1
eda ede ee2 ee5 ee9 eed ef1 ef5
ef8 efc f00 f03 f06 f0b f0e f11
f14 f15 f1a f1b 1 f1d f22 f26
f2a f2d f32 f37 f3a f3e f3f f44
f47 f4c f4d f52 f55 f5a f5b f60
f63 f67 f68 f6d f70 f75 f76 f7b
f7e f82 f86 f89 f8c f8d f8f f90
f95 f96 f9b f9d fa1 fa4 fa6 faa
fac fb8 fba fbc fbd fc2 fc6 fc8
fd4 fd6 fda fde fe1 fe5 fe9 fec
fed fef ff2 ff5 ff6 ffb fff 1003
1007 100b 100e 1012 1014 1018 101c 101f
1023 1027 102a 102d 1032 1035 1038 103b
103c 1041 1042 1 1044 1049 104d 1051
1054 1059 105e 1061 1065 1066 106b 106e
1073 1074 1079 107c 1081 1082 1087 108a
108e 1092 1096 109a 109d 109e 10a0 10a5
10a6 10a8 10a9 10ae 10af 10b4 10b6 10ba
10bd 10c1 10c5 10c8 10cc 10d0 10d3 10d6
10db 10de 10e1 10e4 10e5 10ea 10eb 1
10ed 10f2 10f6 10fa 10fd 1102 1107 110a
110e 110f 1114 1115 111a 111c 1120 1123
1127 112b 112e 1132 1136 1139 113d 113e
1143 1145 1149 114d 1150 1152 1156 1159
115d 1160 1163 1164 1169 116d 1171 1175
1179 117d 1181 1185 1189 118d 1191 1195
1199 119d 119e 11a0 11a4 11a8 11ac 11af
11b0 11b2 11b5 11b8 11b9 11be 11c1 11c5
11c8 11c9 11ce 11d1 1 11d4 11d9 11dd
11e1 11e5 11e9 11ed 11f1 11f5 11f9 11fd
1200 1201 1203 1207 1209 120d 1210 1214
1217 1218 121d 1220 1224 1228 122c 1230
1233 1234 1236 123a 123c 1240 1244 1247
124a 124b 124d 1250 1255 1256 125b 125f
1263 1267 126b 126e 126f 1271 1275 1277
127b 127f 1283 1287 128a 128b 128d 1291
1293 1297 129b 129e 12a0 12a4 12a8 12ab
12af 12b2 12b3 12b8 12bb 12bf 12c3 12c7
12cb 12cf 12d3 12d7 12db 12df 12e3 12ef
12f3 12f7 12fa 12fe 1302 1304 1308 130c
1310 1313 1317 131b 131d 131e 1323 1
1327 132b 132f 1332 1336 133a 133e 1342
1345 1349 134d 1350 1353 1358 135b 135e
1361 1362 1367 1368 1 136a 136f 1373
1377 137a 137f 1384 1387 138b 138c 1391
1394 1399 139a 139f 13a2 13a7 13a8 13ad
13b0 13b4 13b5 13ba 13bd 13c2 13c3 13c8
13cb 13cf 13d3 13d6 13d9 13da 13dc 13dd
13e2 13e3 13e8 13ea 13ee 13f1 13f3 13f7
13f9 1405 1407 1409 140a 140f 1413 1415
1421 1423 1427 142b 142f 1432 1433 1435
1438 143c 1440 1443 1444 1446 1447 144c
1450 1452 1456 1459 145d 1460 1464 1468
146c 1470 1474 1478 147c 1480 1484 1488
148c 148f 1490 1492 1496 149a 149d 149e
14a0 14a1 14a3 14a7 14ab 14af 14b2 14b3
14b5 14b8 14bb 14bc 14c1 14c5 14c9 14cc
14d0 14d4 14d7 14da 14df 14e2 14e5 14e8
14e9 14ee 14ef 1 14f1 14f6 14fa 14fe
1501 1506 150b 150e 1512 1513 1518 151b
1520 1521 1526 1529 152e 152f 1534 1537
153b 153f 1543 1547 154a 154b 154d 1552
1553 1555 1556 155b 155e 1563 1564 1569
156c 1571 1572 1577 157a 157e 157f 1584
1587 158c 158d 1592 1593 1598 159a 159e
15a1 15a5 15a9 15ac 15b0 15b4 15b7 15ba
15bf 15c2 15c5 15c8 15c9 15ce 15cf 1
15d1 15d6 15da 15de 15e1 15e6 15eb 15ee
15f2 15f3 15f8 15f9 15fe 1600 1604 1607
160b 160f 1612 1616 161a 161d 1621 1625
1626 162b 162d 1631 1635 1639 163d 1649
164d 1651 1655 1659 165d 1661 1665 1669
166d 1671 1675 1679 167d 1681 1685 1689
168d 1691 1695 1699 169d 16a1 16ad 16b1
16b6 16ba 16bd 16be 16c3 16c7 16cb 16ce
16d1 16d5 16d7 16db 16df 16e2 16e5 16e9
16eb 16ef 16f3 16f6 16f8 16fc 1700 1704
1707 170b 170f 1711 1712 1717 1 171b
171f 1723 1726 172a 172e 1732 1736 1739
173d 1741 1744 1747 174c 174f 1752 1755
1756 175b 175c 1 175e 1763 1767 176b
176e 1773 1778 177b 177f 1780 1785 1788
178d 178e 1793 1796 179b 179c 17a1 17a4
17a8 17a9 17ae 17b1 17b6 17b7 17bc 17bf
17c3 17c7 17ca 17cd 17ce 17d0 17d1 17d6
17d7 17dc 17de 17e2 17e5 17e7 17eb 17ed
17f9 17fb 17fd 17fe 1803 1807 1809 1815
1817 1819 181d 1821 1824 1828 182c 1830
1831 1833 1837 183b 183f 1842 1846 184a
184d 1850 1855 1858 185b 185e 185f 1864
1865 1 1867 186c 1870 1874 1877 187c
1881 1884 1888 1889 188e 1891 1896 1897
189c 189f 18a4 18a5 18aa 18ad 18b1 18b5
18b9 18ba 18bc 18c1 18c2 18c4 18c5 18ca
18cd 18d2 18d3 18d8 18db 18e0 18e1 18e6
18e9 18ed 18ee 18f3 18f6 18fb 18fc 1901
1902 1907 1909 190d 1910 1914 1918 191b
191f 1923 1926 1929 192e 1931 1934 1937
1938 193d 193e 1 1940 1945 1949 194d
1950 1955 195a 195d 1961 1962 1967 1968
196d 196f 1973 1976 197a 197e 1981 1985
1989 198c 198d 198f 1993 1997 1998 199d
19a1 19a5 19a8 19ac 19b0 19b3 19b6 19bb
19be 19c1 19c4 19c5 19ca 19cb 1 19cd
19d2 19d6 19da 19dd 19e2 19e7 19ea 19ee
19ef 19f4 19f7 19fc 19fd 1a02 1a05 1a0a
1a0b 1a10 1a13 1a17 1a1b 1a1f 1a23 1a26
1a27 1a29 1a2e 1a2f 1a31 1a32 1a37 1a3a
1a3f 1a40 1a45 1a48 1a4d 1a4e 1a53 1a56
1a5a 1a5b 1a60 1a63 1a68 1a69 1a6e 1a6f
1a74 1a76 1a7a 1a7d 1a81 1a85 1a88 1a8c
1a90 1a93 1a97 1a9b 1a9c 1aa1 1aa3 1aa7
1aab 1aae 1ab2 1ab6 1ab9 1abd 1ac1 1ac4
1ac7 1acc 1acf 1ad2 1ad5 1ad6 1adb 1adc
1 1ade 1ae3 1ae7 1aeb 1aee 1af3 1af8
1afb 1aff 1b00 1b05 1b06 1b0b 1b0f 1b13
1b16 1b1b 1b20 1b23 1b27 1b2b 1b2e 1b2f
1b34 1b37 1b3c 1b3d 1b42 1b45 1b49 1b4d
1b50 1b51 1b56 1b57 1b5c 1b5e 1b62 1b65
1b69 1b6d 1b71 1b75 1b79 1b7d 1b81 1b85
1b89 1b95 1b9a 1b9e 1ba2 1ba6 1baa 1bac
1bad 1bb2 1 1bb6 1bba 1bbe 1bc1 1bc5
1bc9 1bcd 1bd1 1bd4 1bd8 1bdc 1bdf 1be2
1be7 1bea 1bed 1bf0 1bf1 1bf6 1bf7 1
1bf9 1bfe 1c02 1c06 1c09 1c0e 1c13 1c16
1c1a 1c1b 1c20 1c21 1c26 1c2a 1c2e 1c31
1c36 1c3b 1c3e 1c42 1c43 1c48 1c4b 1c50
1c51 1c56 1c59 1c5d 1c61 1c64 1c67 1c68
1c6a 1c6b 1c70 1c71 1c76 1c78 1c7c 1c7f
1c83 1c87 1c8b 1c8f 1c93 1c97 1c9b 1ca7
1cac 1cb0 1cb4 1cb8 1cbc 1cbe 1cc2 1cc4
1cd0 1cd2 1cd4 1cd5 1cda 1cde 1ce0 1cec
1cf0 1cf2 1cf3 1cfc 
7f4
2
0 1 a 6 10 :3 6 16 :3 6
17 :3 6 10 :2 6 1 3 a 13
a :2 1 4 18 21 20 :2 18 :2 4
14 1d 1c :2 14 :2 4 11 1a 19
:2 11 :2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4
:3 12 :2 4 :3 13 :2 4 :3 9 :2 4 :3 9 :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 13 22 13
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 :2 f 1e f
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :2 10 1a 10 :2 4 :2 10 1a 10
:2 4 :2 11 1b 11 :2 4 :2 11 1b 11
:2 4 :2 12 1c 12 :2 4 :2 12 1c 12
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 55 5b 5e :2 55 6c 83
8 :2 6c d 10 :2 6c 1a 1d :2 6c
b e :2 6c 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6c b e :2 6c 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 28 2b :2 6c
30 33 :2 6c :2 7 4b :2 4 7 :2 11
23 :2 2d 39 3c 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5e 61 :2 1e
:2 7 53 :3 4 1b :2 4 12 4 e
25 31 7 16 20 30 3b 45
4d 7 12 20 2d 3f 11 25
37 47 59 7 f 16 31 39
40 5c 66 7 15 23 31 7
17 27 37 7 1a c 1d 2b
7 13 1f 31 3c 44 4d 7
18 28 37 45 7 11 1a 7
d 13 1f 7 13 20 2c 7
15 24 32 7 17 c d 21
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 54
57 58 :2 54 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5b
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 a :2 14 26
:2 30 3c 40 51 54 55 :2 51 :2 26
:3 a :2 10 15 21 62 65 :2 21 72
75 :2 21 79 7c :2 21 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 21 be c1
:2 21 c9 cc :2 21 d1 d4 :2 21 e8
eb :2 21 :2 a 58 :2 7 a :2 14 26
:2 30 3c 3f 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
57 :3 7 :2 12 26 :2 2f 41 f :2 7
35 :2 4 :4 8 7 :4 2a 29 :3 7 18
:2 7 19 7 b :2 16 1e 2d 3d
:2 b 41 43 :2 41 a 4b :2 56 d
1d 2c :2 4b 30 33 :2 30 4a :2 a
d :2 17 29 :2 33 3f 43 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
89 8c 95 9d :2 a6 :2 95 c3 :2 8c
:2 24 cb ce :2 24 d6 d9 :2 24 de
e1 :2 24 f5 f8 :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 65
68 :2 24 :2 d 5a :3 a :2 15 29 :2 32
4e 12 :2 a 36 :2 7 11 1d f
1d f 1d 2a 3b 48 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 68 6b
:2 27 78 7b :2 27 7f 82 :2 27 8e
91 :2 27 99 9c :2 27 a8 ab b2
bb be :2 ab :2 27 :2 10 5e :2 d :2 a
:4 16 :2 a 7 :3 48 a :2 15 1d 2c
3a :2 a 3e 41 :2 3e a 1a :2 a
15 a 43 d :2 17 29 :2 33 3f
42 53 56 57 :2 53 :2 29 :3 d :2 13
18 24 65 68 :2 24 75 78 :2 24
7c 7f :2 24 89 8c 95 9d :2 a6
:2 95 b7 :2 8c :2 24 :2 d 5a :2 a d
:2 17 29 :2 33 3f 42 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 65 68
:2 24 :2 d 5a :3 a :2 15 2b :2 34 44
:2 a :4 7 48 :3 4 14 15 :2 14 :2 4
17 2e 3c 47 5c 62 2d 39
45 53 2d :2 17 4 8 11 1d
:2 8 20 22 :2 20 7 :4 2b 2a 29
:3 7 15 2a 38 43 4d 26 3b
4d 59 :2 15 7 4a :2 4 :4 8 :2 7
1a 2a 38 4d :2 1a 7 25 a
11 1d 20 :2 a 23 25 :2 23 a
1d 2d 3b 50 :2 1d a 29 a
1d 2d 3b 50 :2 1d a :4 7 :4 4
:4 8 7 11 1c 29 31 38 53
5e 63 :2 f :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 57 5a 5b :2 57 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 26 7 13 1c 26 :2 13 29 2b
34 43 :2 2b :2 13 7 26 :3 4 12
:2 4 17 25 3a 48 52 5e 24
30 39 42 :2 30 46 4f 60 :2 46
:2 17 4 7 10 21 :2 7 24 27
:2 24 a :2 14 26 :2 30 3c 40 51
54 55 :2 51 :2 26 :3 a :2 10 15 21
62 65 :2 21 72 75 :2 21 79 7c
:2 21 86 89 92 9a :2 a3 :2 92 bb
:2 89 :2 21 c3 c6 :2 21 ce d1 :2 21
d6 d9 :2 21 ed f0 :2 21 :2 a 58
:2 7 a :2 14 26 :2 30 3c 3f 50
53 54 :2 50 :2 26 :3 a :2 10 15 21
62 65 :2 21 :2 a 57 :3 7 :2 12 26
:2 2f 46 f :2 7 29 e f 10
24 7 11 26 34 42 4b 52
5f 68 75 7e a 19 22 2e
3e 4e 57 64 a 1e 10 24
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 57 5a 5b :2 57 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:8 4 12 1c :2 12 4 7 :2 11 23
:2 2d 39 3d 4e 51 52 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 8f a4 :2 86 :2 1e ac af :2 1e
b7 ba :2 1e bf c2 :2 1e d6 d9
:2 1e :2 7 55 :2 4 7 :2 11 23 :2 2d
39 3c 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e :2 7 54
:3 4 :2 f 23 2c 38 :2 23 3c c
:2 4 7 :2 11 23 :2 2d 39 3c 4d
50 51 :2 4d :2 23 :3 7 :2 d 12 1e
5f 62 :2 1e 6f 72 :2 1e 76 79
:2 1e 83 86 8f 97 :2 a0 :2 8f ab
:2 86 :2 1e b3 b6 :2 1e be c1 :2 1e
c6 c9 :2 1e dd e0 :2 1e :2 7 54
:3 4 :2 f 21 :2 2a 34 49 :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 51 54 55 :2 51 :2 26 :3 a :2 10
15 21 62 65 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 58 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4e 51 52 :2 4e :2 23 :3 7 :2 d
12 1e 5f 62 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 55
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
7f4
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:5 c :5 d :5 e :5 f
:5 10 :5 11 :5 12 :7 13
:7 14 :6 15 :6 16 :6 17
:5 18 :5 19 :6 1a :6 1b
:6 1c :6 1d :7 1e :7 1f
:7 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :7 40
:b 42 :11 43 44 :2 43
:2 44 :2 43 :2 44 :2 43
:2 45 :2 43 :12 45 :2 43
:2 46 :2 43 :12 46 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :4 43 :3 42 :11 4a
:b 4b :3 4a :3 51 :3 52
:3 55 :7 56 :5 57 :5 58
:8 59 :4 5a :4 5b :2 5c
:3 5d :7 5e :5 5f :3 60
:4 61 :4 62 :4 63 :2 64
65 :2 66 55 :5 67
54 69 :5 6a :3 69
:2 6b :5 6d :11 6e :24 6f
:3 6e :2 6c :6 6b 68
:3 41 :a 75 :11 76 :30 77
:3 76 :11 79 :b 7a :3 79
:7 7c 7d :2 7c :3 75
:c 80 :3 81 :3 82 :10 84
:3 85 :2 84 :4 85 :3 84
:11 86 :30 87 :3 86 :11 89
:b 8a :3 89 :7 8c 8d
:2 8c 85 :2 84 :2 91
:2 92 :5 93 91 :5 94
90 96 :5 97 :3 96
:2 98 :5 9a :11 9b :24 9c
:3 9b :2 99 :6 98 95
:3 80 :c a3 :3 a4 :3 a5
a3 :11 a7 :20 a8 :3 a7
:11 aa :b ab :3 aa :9 ad
a6 :3 a3 :3 80 :6 b2
:7 b3 :4 b4 b5 :3 b3
:12 b7 :6 b8 :4 b9 :3 b8
:3 b7 :5 bd :8 be bd
:a c0 :8 c1 c0 :8 c3
c2 :3 c0 bf :3 bd
:5 c7 :8 c9 ca cb
c9 :5 cc c8 ce
:5 cf :3 ce :2 d0 :5 d2
:11 d3 :24 d4 :3 d3 :2 d1
:6 d0 cd :3 c7 :f d9
:3 c7 :3 de :7 df :b e0
:3 df :9 e3 :11 e4 :30 e5
:3 e4 :11 e7 :b e8 :3 e7
:7 ea eb :2 ea e3
ed ee :2 ef ed
:a f2 :8 f3 :2 f4 :2 f5
f2 :6 f6 :5 f7 f6
:5 f9 f8 :3 f6 f1
fc :5 fd :3 fc :2 fe
:5 100 :11 101 :24 102 :3 101
:2 ff :6 fe fb :4 ec
:3 e3 :6 108 :11 109 :2e 10a
:3 109 :11 10c :b 10d :3 10c
:9 10f 110 :2 10f :11 112
:30 113 :3 112 :a 115 41
:3 118 :11 119 :b 11a :17 11b
:3 119 :2 11d :3 11e :3 11f
120 11e 11d 11e
:3 121 :3 118 :2 122 :5 124
:11 125 :b 126 :18 127 :3 125
:2 129 12a :3 12b 12c
12a 129 12a :3 12d
:2 123 :6 122 117 :7 1

1cfe
4
:3 0 1 :3 0 2
:a 0 7ef 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 4 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 7ef 2
18 :2 0 d :2 0
12 4 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
7ed 0 c :6 0
d :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
7ed 0 e :6 0
1c d9 0 1a
4 :3 0 18 29
2b :6 0 2e 2c
0 7ed 0 f
:6 0 20 10d 0
1e 6 :3 0 30
:7 0 33 31 0
7ed 0 10 :6 0
6 :3 0 35 :7 0
38 36 0 7ed
0 11 :6 0 24
141 0 22 6
:3 0 3a :7 0 3d
3b 0 7ed 0
12 :6 0 6 :3 0
3f :7 0 42 40
0 7ed 0 13
:6 0 28 175 0
26 6 :3 0 44
:7 0 47 45 0
7ed 0 14 :6 0
16 :3 0 49 :7 0
4c 4a 0 7ed
0 15 :6 0 19
:2 0 2c 16 :3 0
4e :7 0 51 4f
0 7ed 0 17
:6 0 4 :3 0 19
:2 0 2a 53 55
:6 0 58 56 0
7ed 0 18 :6 0
1d :2 0 30 4
:3 0 2e 5a 5c
:6 0 5f 5d 0
7ed 0 1a :6 0
1d :2 0 32 1c
:3 0 61 :7 0 65
62 63 7ed 0
1b :6 0 1d :2 0
34 1c :3 0 67
:7 0 6b 68 69
7ed 0 1e :6 0
38 21e 0 36
1c :3 0 6d :7 0
71 6e 6f 7ed
0 1f :6 0 1d
:2 0 3a 16 :3 0
73 :7 0 76 74
0 7ed 0 20
:6 0 16 :3 0 78
:7 0 7b 79 0
7ed 0 21 :6 0
1d :2 0 3c 1c
:3 0 7d :7 0 81
7e 7f 7ed 0
22 :6 0 1d :2 0
3e 1c :3 0 83
:7 0 87 84 85
7ed 0 23 :6 0
1d :2 0 40 1c
:3 0 89 :7 0 8d
8a 8b 7ed 0
24 :6 0 d :2 0
42 1c :3 0 8f
:7 0 93 90 91
7ed 0 25 :6 0
d :2 0 46 4
:3 0 44 95 97
:6 0 9a 98 0
7ed 0 26 :6 0
d :2 0 4a 4
:3 0 48 9c 9e
:6 0 a1 9f 0
7ed 0 27 :6 0
1d :2 0 4e 4
:3 0 4c a3 a5
:6 0 a8 a6 0
7ed 0 28 :6 0
1d :2 0 50 1c
:3 0 aa :7 0 ae
ab ac 7ed 0
29 :6 0 1d :2 0
52 1c :3 0 b0
:7 0 b4 b1 b2
7ed 0 2a :6 0
1d :2 0 54 1c
:3 0 b6 :7 0 ba
b7 b8 7ed 0
2b :6 0 1d :2 0
56 1c :3 0 bc
:7 0 c0 bd be
7ed 0 2c :6 0
1d :2 0 58 1c
:3 0 c2 :7 0 c6
c3 c4 7ed 0
2d :6 0 1d :2 0
5a 1c :3 0 c8
:7 0 cc c9 ca
7ed 0 2e :6 0
1d :2 0 5c 1c
:3 0 ce :7 0 d2
cf d0 7ed 0
2f :6 0 1d :2 0
5e 1c :3 0 d4
:7 0 d8 d5 d6
7ed 0 30 :6 0
1d :2 0 60 1c
:3 0 da :7 0 de
db dc 7ed 0
31 :6 0 1d :2 0
62 1c :3 0 e0
:7 0 e4 e1 e2
7ed 0 32 :6 0
1d :2 0 64 1c
:3 0 e6 :7 0 ea
e7 e8 7ed 0
33 :6 0 1d :2 0
66 1c :3 0 ec
:7 0 f0 ed ee
7ed 0 34 :6 0
1d :2 0 68 1c
:3 0 f2 :7 0 f6
f3 f4 7ed 0
35 :6 0 1d :2 0
6a 1c :3 0 f8
:7 0 fc f9 fa
7ed 0 36 :6 0
1d :2 0 6c 1c
:3 0 fe :7 0 102
ff 100 7ed 0
37 :6 0 1d :2 0
6e 1c :3 0 104
:7 0 108 105 106
7ed 0 38 :6 0
1d :2 0 70 1c
:3 0 10a :7 0 10e
10b 10c 7ed 0
39 :6 0 1d :2 0
72 1c :3 0 110
:7 0 114 111 112
7ed 0 3a :6 0
1d :2 0 74 1c
:3 0 116 :7 0 11a
117 118 7ed 0
3b :6 0 1d :2 0
76 1c :3 0 11c
:7 0 120 11d 11e
7ed 0 3c :6 0
1d :2 0 78 1c
:3 0 122 :7 0 126
123 124 7ed 0
3d :6 0 1d :2 0
7a 1c :3 0 128
:7 0 12c 129 12a
7ed 0 3e :6 0
1d :2 0 7c 40
:3 0 12e :7 0 132
12f 130 7ed 0
3f :6 0 1d :2 0
7e 40 :3 0 134
:7 0 138 135 136
7ed 0 41 :6 0
1d :2 0 80 40
:3 0 13a :7 0 13e
13b 13c 7ed 0
42 :6 0 1d :2 0
82 40 :3 0 140
:7 0 144 141 142
7ed 0 43 :6 0
1d :2 0 84 40
:3 0 146 :7 0 14a
147 148 7ed 0
44 :6 0 1d :2 0
86 40 :3 0 14c
:7 0 150 14d 14e
7ed 0 45 :6 0
1d :2 0 88 40
:3 0 152 :7 0 156
153 154 7ed 0
46 :6 0 15e 15f
0 8a 40 :3 0
158 :7 0 15c 159
15a 7ed 0 47
:6 0 164 165 0
8c a :3 0 b
:2 0 4 160 :7 0
163 161 0 7ed
0 48 :6 0 49
:3 0 4a :3 0 49
:3 0 4b :3 0 167
168 0 2 :4 0
8e 169 16b 166
16d 16c :2 0 4c
:3 0 4d :3 0 16f
170 0 4e :4 0
49 :3 0 4f :3 0
173 174 0 2
:4 0 90 175 177
50 :4 0 51 :2 0
52 :3 0 92 17a
17c :3 0 53 :4 0
51 :2 0 54 :4 0
95 17f 181 :3 0
51 :2 0 3 :3 0
98 183 185 :3 0
51 :2 0 54 :4 0
9b 187 189 :3 0
51 :2 0 55 :4 0
9e 18b 18d :3 0
51 :2 0 56 :3 0
57 :3 0 54 :4 0
51 :2 0 5 :3 0
a1 193 195 :3 0
51 :2 0 54 :4 0
a4 197 199 :3 0
58 :4 0 a7 191
19c 59 :4 0 aa
190 19f ad 18f
1a1 :3 0 51 :2 0
55 :4 0 b0 1a3
1a5 :3 0 51 :2 0
56 :3 0 57 :3 0
54 :4 0 51 :2 0
7 :3 0 b3 1ab
1ad :3 0 51 :2 0
54 :4 0 b6 1af
1b1 :3 0 58 :4 0
b9 1a9 1b4 59
:4 0 bc 1a8 1b7
bf 1a7 1b9 :3 0
51 :2 0 55 :4 0
c2 1bb 1bd :3 0
51 :2 0 54 :4 0
c5 1bf 1c1 :3 0
51 :2 0 8 :3 0
c8 1c3 1c5 :3 0
51 :2 0 54 :4 0
cb 1c7 1c9 :3 0
51 :2 0 5a :4 0
ce 1cb 1cd :3 0
d1 171 1cf :2 0
1d1 d6 1d2 16e
1d1 0 1d3 d8
0 74d 49 :3 0
4a :3 0 1d4 1d5
0 49 :3 0 5b
:3 0 1d7 1d8 0
19 :2 0 2 :4 0
5c :2 0 5d :2 0
19 :2 0 da 1dd
1df :3 0 dd 1d9
1e1 1d6 1e3 1e2
:2 0 4c :3 0 5e
:3 0 1e5 1e6 0
4e :4 0 5f :4 0
51 :2 0 52 :3 0
e1 1ea 1ec :3 0
e4 1e7 1ee :2 0
1f0 e7 1f1 1e4
1f0 0 1f2 e9
0 74d c :3 0
3 :3 0 1f3 1f4
0 74d 28 :3 0
8 :3 0 1f6 1f7
0 74d 60 :3 0
61 :3 0 62 :3 0
63 :3 0 64 :3 0
65 :3 0 66 :3 0
67 :3 0 68 :3 0
69 :3 0 6a :3 0
6b :3 0 6c :3 0
6d :3 0 6e :3 0
64 :3 0 6f :3 0
70 :3 0 71 :3 0
72 :3 0 73 :3 0
74 :3 0 6d :3 0
73 :3 0 74 :3 0
6e :3 0 75 :3 0
76 :3 0 77 :3 0
78 :3 0 79 :3 0
7a :3 0 7b :3 0
7c :3 0 7d :3 0
7e :3 0 7f :3 0
80 :3 0 e :3 0
f :3 0 27 :3 0
1a :3 0 18 :3 0
21 :3 0 2a :3 0
30 :3 0 3a :3 0
3b :3 0 2c :3 0
10 :3 0 2e :3 0
11 :3 0 12 :3 0
29 :3 0 2b :3 0
32 :3 0 15 :3 0
17 :3 0 1b :3 0
1e :3 0 3f :3 0
42 :3 0 41 :3 0
43 :3 0 44 :3 0
46 :3 0 45 :3 0
47 :3 0 2d :3 0
26 :3 0 81 :3 0
82 :3 0 c :4 0
83 1 :8 0 248
a :3 0 84 :3 0
243 244 0 85
:3 0 245 246 0
248 eb 29b 86
:3 0 a :3 0 84
:3 0 24a 24b 0
85 :3 0 24c 24d
0 24f ee 251
f0 250 24f :2 0
299 87 :3 0 a
:3 0 84 :3 0 254
255 0 85 :3 0
256 257 0 291
49 :3 0 4a :3 0
259 25a 0 49
:3 0 5b :3 0 25c
25d 0 88 :2 0
2 :4 0 89 :2 0
5d :2 0 19 :2 0
f2 262 264 :3 0
f5 25e 266 25b
268 267 :2 0 4c
:3 0 5e :3 0 26a
26b 0 4e :4 0
8a :4 0 51 :2 0
52 :3 0 f9 26f
271 :3 0 51 :2 0
8b :4 0 fc 273
275 :3 0 51 :2 0
8c :4 0 ff 277
279 :3 0 51 :2 0
85 :3 0 102 27b
27d :3 0 51 :2 0
8d :4 0 105 27f
281 :3 0 51 :2 0
74 :3 0 8e :3 0
19 :2 0 8f :2 0
108 284 288 10c
283 28a :3 0 10f
26c 28c :2 0 28e
112 28f 269 28e
0 290 114 0
291 116 294 :3 0
294 0 294 293
291 292 :6 0 296
2 :3 0 119 298
11b 297 296 :2 0
299 11d :2 0 29b
0 29b 29a 248
299 :6 0 74d 1
:3 0 a :3 0 84
:3 0 29d 29e 0
a :3 0 90 :2 0
91 :3 0 2a0 2a2
0 122 2a1 2a4
:3 0 2a5 :2 0 49
:3 0 4a :3 0 2a7
2a8 0 49 :3 0
5b :3 0 2aa 2ab
0 d :2 0 2
:4 0 92 :2 0 5d
:2 0 19 :2 0 125
2b0 2b2 :3 0 128
2ac 2b4 2a9 2b6
2b5 :2 0 4c :3 0
5e :3 0 2b8 2b9
0 4e :4 0 93
:4 0 51 :2 0 52
:3 0 12c 2bd 2bf
:3 0 51 :2 0 8b
:4 0 12f 2c1 2c3
:3 0 51 :2 0 94
:4 0 132 2c5 2c7
:3 0 51 :2 0 56
:3 0 95 :3 0 96
:3 0 97 :3 0 2cc
2cd 0 135 2cb
2cf 59 :4 0 137
2ca 2d2 13a 2c9
2d4 :3 0 51 :2 0
98 :4 0 13d 2d6
2d8 :3 0 51 :2 0
54 :4 0 140 2da
2dc :3 0 51 :2 0
c :3 0 143 2de
2e0 :3 0 51 :2 0
54 :4 0 146 2e2
2e4 :3 0 149 2ba
2e6 :2 0 2e8 14c
2e9 2b7 2e8 0
2ea 14e 0 314
49 :3 0 4a :3 0
2eb 2ec 0 49
:3 0 5b :3 0 2ee
2ef 0 19 :2 0
2 :4 0 99 :2 0
5d :2 0 19 :2 0
150 2f4 2f6 :3 0
153 2f0 2f8 2ed
2fa 2f9 :2 0 4c
:3 0 5e :3 0 2fc
2fd 0 4e :4 0
9a :4 0 51 :2 0
52 :3 0 157 301
303 :3 0 15a 2fe
305 :2 0 307 15d
308 2fb 307 0
309 15f 0 314
9b :3 0 9c :3 0
30a 30b 0 96
:3 0 97 :3 0 30d
30e 0 c :3 0
9d :3 0 161 30c
312 :2 0 314 165
315 2a6 314 0
316 169 0 74d
5 :3 0 9e :2 0
16b 318 319 :3 0
31a :2 0 7 :3 0
9e :2 0 16d 31d
31e :3 0 31f :2 0
31b 321 320 :2 0
13 :3 0 5 :3 0
323 324 0 48c
14 :3 0 7 :3 0
326 327 0 48c
9f :3 0 a0 :3 0
329 32a 0 13
:3 0 14 :3 0 a1
:2 0 16f 32b 32f
a2 :2 0 1d :2 0
175 331 333 :3 0
334 :2 0 9f :3 0
a0 :3 0 336 337
0 14 :3 0 12
:3 0 a1 :2 0 178
338 33c a3 :2 0
1d :2 0 17e 33e
340 :3 0 341 :2 0
335 343 342 :2 0
49 :3 0 4a :3 0
345 346 0 49
:3 0 5b :3 0 348
349 0 d :2 0
2 :4 0 a4 :2 0
5d :2 0 19 :2 0
181 34e 350 :3 0
184 34a 352 347
354 353 :2 0 4c
:3 0 5e :3 0 356
357 0 4e :4 0
a5 :4 0 51 :2 0
52 :3 0 188 35b
35d :3 0 51 :2 0
8b :4 0 18b 35f
361 :3 0 51 :2 0
94 :4 0 18e 363
365 :3 0 51 :2 0
56 :3 0 95 :3 0
96 :3 0 a6 :3 0
36a 36b 0 191
369 36d 59 :4 0
193 368 370 196
367 372 :3 0 51
:2 0 98 :4 0 199
374 376 :3 0 51
:2 0 54 :4 0 19c
378 37a :3 0 51
:2 0 c :3 0 19f
37c 37e :3 0 51
:2 0 54 :4 0 1a2
380 382 :3 0 1a5
358 384 :2 0 386
1a8 387 355 386
0 388 1aa 0
3b2 49 :3 0 4a
:3 0 389 38a 0
49 :3 0 5b :3 0
38c 38d 0 19
:2 0 2 :4 0 a7
:2 0 5d :2 0 19
:2 0 1ac 392 394
:3 0 1af 38e 396
38b 398 397 :2 0
4c :3 0 5e :3 0
39a 39b 0 4e
:4 0 a8 :4 0 51
:2 0 52 :3 0 1b3
39f 3a1 :3 0 1b6
39c 3a3 :2 0 3a5
1b9 3a6 399 3a5
0 3a7 1bb 0
3b2 9b :3 0 9c
:3 0 3a8 3a9 0
96 :3 0 a6 :3 0
3ab 3ac 0 c
:3 0 9d :3 0 1bd
3aa 3b0 :2 0 3b2
1c1 3b3 344 3b2
0 3b4 1c5 0
48c 61 :3 0 a9
:3 0 f :3 0 34
:3 0 aa :3 0 61
:3 0 f :3 0 ab
:3 0 26 :4 0 ac
1 :8 0 3c4 a
:3 0 84 :3 0 3bf
3c0 0 85 :3 0
3c1 3c2 0 3c4
1c7 417 86 :3 0
a :3 0 84 :3 0
3c6 3c7 0 85
:3 0 3c8 3c9 0
3cb 1ca 3cd 1cc
3cc 3cb :2 0 415
87 :3 0 a :3 0
84 :3 0 3d0 3d1
0 85 :3 0 3d2
3d3 0 40d 49
:3 0 4a :3 0 3d5
3d6 0 49 :3 0
5b :3 0 3d8 3d9
0 88 :2 0 2
:4 0 ad :2 0 5d
:2 0 19 :2 0 1ce
3de 3e0 :3 0 1d1
3da 3e2 3d7 3e4
3e3 :2 0 4c :3 0
5e :3 0 3e6 3e7
0 4e :4 0 ae
:4 0 51 :2 0 52
:3 0 1d5 3eb 3ed
:3 0 51 :2 0 8b
:4 0 1d8 3ef 3f1
:3 0 51 :2 0 8c
:4 0 1db 3f3 3f5
:3 0 51 :2 0 85
:3 0 1de 3f7 3f9
:3 0 51 :2 0 8d
:4 0 1e1 3fb 3fd
:3 0 51 :2 0 74
:3 0 8e :3 0 19
:2 0 8f :2 0 1e4
400 404 1e8 3ff
406 :3 0 1eb 3e8
408 :2 0 40a 1ee
40b 3e5 40a 0
40c 1f0 0 40d
1f2 410 :3 0 410
0 410 40f 40d
40e :6 0 412 4
:3 0 1f5 414 1f7
413 412 :2 0 415
1f9 :2 0 417 0
417 416 3c4 415
:6 0 48c 1 :3 0
9f :3 0 a0 :3 0
419 41a 0 13
:3 0 11 :3 0 a1
:2 0 1fc 41b 41f
a3 :2 0 1d :2 0
202 421 423 :3 0
11 :3 0 13 :3 0
425 426 0 42b
2b :3 0 1d :2 0
428 429 0 42b
205 489 49 :3 0
4a :3 0 42c 42d
0 49 :3 0 5b
:3 0 42f 430 0
af :2 0 2 :4 0
b0 :2 0 5d :2 0
19 :2 0 208 435
437 :3 0 20b 431
439 42e 43b 43a
:2 0 4c :3 0 5e
:3 0 43d 43e 0
4e :4 0 b1 :4 0
51 :2 0 52 :3 0
20f 442 444 :3 0
51 :2 0 8b :4 0
212 446 448 :3 0
51 :2 0 94 :4 0
215 44a 44c :3 0
51 :2 0 56 :3 0
95 :3 0 96 :3 0
b2 :3 0 451 452
0 218 450 454
59 :4 0 21a 44f
457 21d 44e 459
:3 0 220 43f 45b
:2 0 45d 223 45e
43c 45d 0 45f
225 0 488 49
:3 0 4a :3 0 460
461 0 49 :3 0
5b :3 0 463 464
0 19 :2 0 2
:4 0 b3 :2 0 5d
:2 0 19 :2 0 227
469 46b :3 0 22a
465 46d 462 46f
46e :2 0 4c :3 0
5e :3 0 471 472
0 4e :4 0 b4
:4 0 51 :2 0 52
:3 0 22e 476 478
:3 0 231 473 47a
:2 0 47c 234 47d
470 47c 0 47e
236 0 488 9b
:3 0 b5 :3 0 47f
480 0 96 :3 0
b2 :3 0 482 483
0 9d :3 0 238
481 486 :2 0 488
23b 48a 424 42b
0 48b 0 488
0 48b 23f 0
48c 242 48d 322
48c 0 48e 248
0 74d 1f :3 0
b6 :2 0 19 :2 0
24a 490 492 :3 0
48f 493 0 74d
3d :3 0 b7 :3 0
f :3 0 26 :3 0
c :3 0 15 :3 0
17 :3 0 3f :3 0
41 :3 0 1f :3 0
1e :3 0 1b :3 0
24c 496 4a1 495
4a2 0 74d 56
:3 0 32 :3 0 1d
:2 0 257 4a4 4a7
a2 :2 0 1d :2 0
25c 4a9 4ab :3 0
4ac :2 0 21 :3 0
9e :2 0 25f 4af
4b0 :3 0 4b1 :2 0
4b2 :2 0 4ad 4b4
4b3 :2 0 3e :3 0
b8 :3 0 f :3 0
26 :3 0 27 :3 0
e :3 0 c :3 0
21 :3 0 32 :3 0
1d :2 0 261 4b7
4c0 4b6 4c1 0
4c3 26a 4c4 4b5
4c3 0 4c5 26c
0 74d e :3 0
9e :2 0 26e 4c7
4c8 :3 0 4c9 :2 0
3d :3 0 b9 :3 0
f :3 0 c :3 0
ba :2 0 270 4cc
4d0 4cb 4d1 0
4d3 274 4f4 74
:3 0 18 :3 0 19
:2 0 19 :2 0 276
4d4 4d8 90 :2 0
ba :4 0 27c 4da
4dc :3 0 3d :3 0
b9 :3 0 f :3 0
c :3 0 1d :2 0
27f 4df 4e3 4de
4e4 0 4e6 283
4f0 3d :3 0 b9
:3 0 f :3 0 c
:3 0 19 :2 0 285
4e8 4ec 4e7 4ed
0 4ef 289 4f1
4dd 4e6 0 4f2
0 4ef 0 4f2
28b 0 4f3 28e
4f5 4ca 4d3 0
4f6 0 4f3 0
4f6 290 0 74d
21 :3 0 9e :2 0
293 4f8 4f9 :3 0
4fa :2 0 9f :3 0
bb :3 0 73 :3 0
74 :3 0 21 :3 0
9f :3 0 bc :3 0
11 :3 0 11 :3 0
bd :4 0 be 1
:8 0 50c a :3 0
84 :3 0 507 508
0 85 :3 0 509
50a 0 50c 295
55f 86 :3 0 a
:3 0 84 :3 0 50e
50f 0 85 :3 0
510 511 0 513
298 515 29a 514
513 :2 0 55d 87
:3 0 a :3 0 84
:3 0 518 519 0
85 :3 0 51a 51b
0 555 49 :3 0
4a :3 0 51d 51e
0 49 :3 0 5b
:3 0 520 521 0
88 :2 0 2 :4 0
bf :2 0 5d :2 0
19 :2 0 29c 526
528 :3 0 29f 522
52a 51f 52c 52b
:2 0 4c :3 0 5e
:3 0 52e 52f 0
4e :4 0 c0 :4 0
51 :2 0 52 :3 0
2a3 533 535 :3 0
51 :2 0 8b :4 0
2a6 537 539 :3 0
51 :2 0 8c :4 0
2a9 53b 53d :3 0
51 :2 0 85 :3 0
2ac 53f 541 :3 0
51 :2 0 8d :4 0
2af 543 545 :3 0
51 :2 0 74 :3 0
8e :3 0 19 :2 0
8f :2 0 2b2 548
54c 2b6 547 54e
:3 0 2b9 530 550
:2 0 552 2bc 553
52d 552 0 554
2be 0 555 2c0
558 :3 0 558 0
558 557 555 556
:6 0 55a 6 :3 0
2c3 55c 2c5 55b
55a :2 0 55d 2c7
:2 0 55f 0 55f
55e 50c 55d :6 0
570 1 :3 0 29
:3 0 56 :3 0 29
:3 0 1d :2 0 2ca
562 565 b6 :2 0
56 :3 0 2e :3 0
1d :2 0 2cd 568
56b 2d0 567 56d
:3 0 561 56e 0
570 2d3 571 4fb
570 0 572 2d6
0 74d 3e :3 0
ba :2 0 573 574
0 74d 3d :3 0
c1 :3 0 c :3 0
11 :3 0 29 :3 0
3e :3 0 2a :3 0
28 :3 0 56 :3 0
2b :3 0 1d :2 0
2d8 57e 581 56
:3 0 2c :3 0 1d
:2 0 2db 583 586
2de 577 588 576
589 0 74d 56
:3 0 3d :3 0 1d
:2 0 2e7 58b 58e
a3 :2 0 1d :2 0
2ec 590 592 :3 0
49 :3 0 4a :3 0
594 595 0 49
:3 0 5b :3 0 597
598 0 d :2 0
2 :4 0 c2 :2 0
5d :2 0 19 :2 0
2ef 59d 59f :3 0
2f2 599 5a1 596
5a3 5a2 :2 0 4c
:3 0 5e :3 0 5a5
5a6 0 4e :4 0
c3 :4 0 51 :2 0
52 :3 0 2f6 5aa
5ac :3 0 51 :2 0
8b :4 0 2f9 5ae
5b0 :3 0 51 :2 0
94 :4 0 2fc 5b2
5b4 :3 0 51 :2 0
56 :3 0 95 :3 0
96 :3 0 c4 :3 0
5b9 5ba 0 2ff
5b8 5bc 59 :4 0
301 5b7 5bf 304
5b6 5c1 :3 0 51
:2 0 98 :4 0 307
5c3 5c5 :3 0 51
:2 0 54 :4 0 30a
5c7 5c9 :3 0 51
:2 0 c :3 0 30d
5cb 5cd :3 0 51
:2 0 54 :4 0 310
5cf 5d1 :3 0 313
5a7 5d3 :2 0 5d5
316 5d6 5a4 5d5
0 5d7 318 0
601 49 :3 0 4a
:3 0 5d8 5d9 0
49 :3 0 5b :3 0
5db 5dc 0 19
:2 0 2 :4 0 c5
:2 0 5d :2 0 19
:2 0 31a 5e1 5e3
:3 0 31d 5dd 5e5
5da 5e7 5e6 :2 0
4c :3 0 5e :3 0
5e9 5ea 0 4e
:4 0 c6 :4 0 51
:2 0 52 :3 0 321
5ee 5f0 :3 0 324
5eb 5f2 :2 0 5f4
327 5f5 5e8 5f4
0 5f6 329 0
601 9b :3 0 9c
:3 0 5f7 5f8 0
96 :3 0 c4 :3 0
5fa 5fb 0 c
:3 0 9d :3 0 32b
5f9 5ff :2 0 601
32f 689 81 :3 0
c7 :3 0 82 :3 0
c :4 0 c8 1
:8 0 688 81 :3 0
c9 :3 0 ca :3 0
cb :3 0 cc :3 0
ca :3 0 96 :3 0
cd :3 0 96 :3 0
ce :3 0 cf :3 0
56 :3 0 d0 :3 0
d1 :3 0 d2 :3 0
56 :3 0 d3 :3 0
d4 :3 0 c7 :3 0
d5 :3 0 82 :3 0
c :4 0 d6 1
:8 0 633 d7 :4 0
61e :3 0 9d :3 0
90 :2 0 335 621
622 :3 0 a :3 0
84 :3 0 624 625
0 1d :2 0 626
627 0 629 338
630 a :3 0 84
:3 0 62a 62b 0
d8 :2 0 62c 62d
0 62f 33a 631
623 629 0 632
0 62f 0 632
33c 0 633 33f
686 86 :3 0 a
:3 0 84 :3 0 635
636 0 85 :3 0
637 638 0 63a
342 63c 344 63b
63a :2 0 684 87
:3 0 a :3 0 84
:3 0 63f 640 0
85 :3 0 641 642
0 67c 49 :3 0
4a :3 0 644 645
0 49 :3 0 5b
:3 0 647 648 0
88 :2 0 2 :4 0
d9 :2 0 5d :2 0
19 :2 0 346 64d
64f :3 0 349 649
651 646 653 652
:2 0 4c :3 0 5e
:3 0 655 656 0
4e :4 0 da :4 0
51 :2 0 52 :3 0
34d 65a 65c :3 0
51 :2 0 8b :4 0
350 65e 660 :3 0
51 :2 0 8c :4 0
353 662 664 :3 0
51 :2 0 85 :3 0
356 666 668 :3 0
51 :2 0 8d :4 0
359 66a 66c :3 0
51 :2 0 74 :3 0
8e :3 0 19 :2 0
8f :2 0 35c 66f
673 360 66e 675
:3 0 363 657 677
:2 0 679 366 67a
654 679 0 67b
368 0 67c 36a
67f :3 0 67f 0
67f 67e 67c 67d
:6 0 681 8 :3 0
36d 683 36f 682
681 :2 0 684 371
:2 0 686 0 686
685 633 684 :6 0
688 1 :3 0 374
68a 593 601 0
68b 0 688 0
68b 377 0 74d
3e :3 0 db :3 0
f :3 0 37a 68d
68f 68c 690 0
74d 49 :3 0 4a
:3 0 692 693 0
49 :3 0 5b :3 0
695 696 0 d
:2 0 2 :4 0 dc
:2 0 5d :2 0 19
:2 0 37c 69b 69d
:3 0 37f 697 69f
694 6a1 6a0 :2 0
4c :3 0 5e :3 0
6a3 6a4 0 4e
:4 0 dd :4 0 51
:2 0 52 :3 0 383
6a8 6aa :3 0 51
:2 0 8b :4 0 386
6ac 6ae :3 0 51
:2 0 94 :4 0 389
6b0 6b2 :3 0 51
:2 0 56 :3 0 95
:3 0 3e :3 0 38c
6b6 6b8 59 :4 0
38e 6b5 6bb 391
6b4 6bd :3 0 51
:2 0 98 :4 0 394
6bf 6c1 :3 0 51
:2 0 54 :4 0 397
6c3 6c5 :3 0 51
:2 0 c :3 0 39a
6c7 6c9 :3 0 51
:2 0 54 :4 0 39d
6cb 6cd :3 0 3a0
6a5 6cf :2 0 6d1
3a3 6d2 6a2 6d1
0 6d3 3a5 0
74d 49 :3 0 4a
:3 0 6d4 6d5 0
49 :3 0 5b :3 0
6d7 6d8 0 19
:2 0 2 :4 0 de
:2 0 5d :2 0 19
:2 0 3a7 6dd 6df
:3 0 3aa 6d9 6e1
6d6 6e3 6e2 :2 0
4c :3 0 5e :3 0
6e5 6e6 0 4e
:4 0 df :4 0 51
:2 0 52 :3 0 3ae
6ea 6ec :3 0 3b1
6e7 6ee :2 0 6f0
3b4 6f1 6e4 6f0
0 6f2 3b6 0
74d 9b :3 0 9c
:3 0 6f3 6f4 0
56 :3 0 3e :3 0
1d :2 0 3b8 6f6
6f9 c :3 0 9d
:3 0 3bb 6f5 6fd
:2 0 74d 49 :3 0
4a :3 0 6ff 700
0 49 :3 0 5b
:3 0 702 703 0
e0 :2 0 2 :4 0
e1 :2 0 5d :2 0
19 :2 0 3bf 708
70a :3 0 3c2 704
70c 701 70e 70d
:2 0 4c :3 0 5e
:3 0 710 711 0
4e :4 0 e2 :4 0
51 :2 0 52 :3 0
3c6 715 717 :3 0
51 :2 0 8b :4 0
3c9 719 71b :3 0
51 :2 0 94 :4 0
3cc 71d 71f :3 0
51 :2 0 56 :3 0
95 :3 0 a :3 0
84 :3 0 724 725
0 3cf 723 727
59 :4 0 3d1 722
72a 3d4 721 72c
:3 0 51 :2 0 98
:4 0 3d7 72e 730
:3 0 51 :2 0 54
:4 0 3da 732 734
:3 0 51 :2 0 c
:3 0 3dd 736 738
:3 0 51 :2 0 54
:4 0 3e0 73a 73c
:3 0 3e3 712 73e
:2 0 740 3e6 741
70f 740 0 742
3e8 0 74d 9b
:3 0 e3 :3 0 743
744 0 a :3 0
84 :3 0 746 747
0 c :3 0 9d
:3 0 3ea 745 74b
:2 0 74d 3ee 7ee
a :3 0 e4 :2 0
4 74e 74f 0
49 :3 0 4a :3 0
751 752 0 49
:3 0 5b :3 0 754
755 0 88 :2 0
2 :4 0 e5 :2 0
5d :2 0 19 :2 0
404 75a 75c :3 0
407 756 75e 753
760 75f :2 0 4c
:3 0 5e :3 0 762
763 0 4e :4 0
e6 :4 0 51 :2 0
52 :3 0 40b 767
769 :3 0 40e 764
76b :2 0 784 4c
:3 0 5e :3 0 76d
76e 0 4e :4 0
e7 :4 0 51 :2 0
a :3 0 e8 :3 0
773 774 0 411
772 776 :3 0 51
:2 0 98 :4 0 414
778 77a :3 0 51
:2 0 a :3 0 e9
:3 0 77d 77e 0
417 77c 780 :3 0
41a 76f 782 :2 0
784 41d 785 761
784 0 786 420
0 796 ea :3 0
48 :3 0 a :3 0
e8 :3 0 eb :3 0
a :3 0 e9 :3 0
ec :3 0 bd :4 0
ed 1 :a 0 792
:2 0 796 788 790
:2 0 9 :3 0 48
:3 0 794 :2 0 796
422 798 426 797
796 :2 0 7ec 87
:3 0 a :3 0 84
:3 0 79b 79c 0
85 :3 0 79d 79e
0 7e4 49 :3 0
4a :3 0 7a0 7a1
0 49 :3 0 5b
:3 0 7a3 7a4 0
88 :2 0 2 :4 0
ee :2 0 5d :2 0
19 :2 0 428 7a9
7ab :3 0 42b 7a5
7ad 7a2 7af 7ae
:2 0 4c :3 0 5e
:3 0 7b1 7b2 0
4e :4 0 ef :4 0
51 :2 0 52 :3 0
42f 7b6 7b8 :3 0
432 7b3 7ba :2 0
7d4 4c :3 0 5e
:3 0 7bc 7bd 0
4e :4 0 8c :4 0
51 :2 0 85 :3 0
435 7c1 7c3 :3 0
51 :2 0 8d :4 0
438 7c5 7c7 :3 0
51 :2 0 74 :3 0
8e :3 0 19 :2 0
8f :2 0 43b 7ca
7ce 43f 7c9 7d0
:3 0 442 7be 7d2
:2 0 7d4 445 7d5
7b0 7d4 0 7d6
448 0 7e4 ea
:3 0 48 :3 0 eb
:3 0 a :3 0 e9
:3 0 ec :3 0 bd
:4 0 f0 1 :a 0
7e0 :2 0 7e4 7d8
7de :2 0 9 :3 0
48 :3 0 7e2 :2 0
7e4 44a 7e7 :3 0
7e7 0 7e7 7e6
7e4 7e5 :6 0 7e9
1 :3 0 44f 7eb
451 7ea 7e9 :2 0
7ec 453 :2 0 7ee
456 7ee 7ed 74d
7ec :6 0 7ef :2 0
2 18 7ee 7f2
:3 0 7f1 7ef 7f3
:8 0 
48e
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 2f
1 34 1 39
1 3e 1 43
1 48 1 4d
1 54 1 52
1 5b 1 59
1 60 1 66
1 6c 1 72
1 77 1 7c
1 82 1 88
1 8e 1 96
1 94 1 9d
1 9b 1 a4
1 a2 1 a9
1 af 1 b5
1 bb 1 c1
1 c7 1 cd
1 d3 1 d9
1 df 1 e5
1 eb 1 f1
1 f7 1 fd
1 103 1 109
1 10f 1 115
1 11b 1 121
1 127 1 12d
1 133 1 139
1 13f 1 145
1 14b 1 151
1 157 1 15d
1 16a 1 176
2 179 17b 2
17e 180 2 182
184 2 186 188
2 18a 18c 2
192 194 2 196
198 2 19a 19b
2 19d 19e 2
18e 1a0 2 1a2
1a4 2 1aa 1ac
2 1ae 1b0 2
1b2 1b3 2 1b5
1b6 2 1a6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 4
172 178 17d 1ce
1 1d0 1 1d2
2 1dc 1de 3
1da 1db 1e0 2
1e9 1eb 2 1e8
1ed 1 1ef 1
1f1 2 242 247
1 24e 1 249
2 261 263 3
25f 260 265 2
26e 270 2 272
274 2 276 278
2 27a 27c 2
27e 280 3 285
286 287 2 282
289 2 26d 28b
1 28d 1 28f
2 258 290 1
294 1 253 2
251 298 1 2a3
2 29f 2a3 2
2af 2b1 3 2ad
2ae 2b3 2 2bc
2be 2 2c0 2c2
2 2c4 2c6 1
2ce 2 2d0 2d1
2 2c8 2d3 2
2d5 2d7 2 2d9
2db 2 2dd 2df
2 2e1 2e3 2
2bb 2e5 1 2e7
1 2e9 2 2f3
2f5 3 2f1 2f2
2f7 2 300 302
2 2ff 304 1
306 1 308 3
30f 310 311 3
2ea 309 313 1
315 1 317 1
31c 3 32c 32d
32e 1 332 2
330 332 3 339
33a 33b 1 33f
2 33d 33f 2
34d 34f 3 34b
34c 351 2 35a
35c 2 35e 360
2 362 364 1
36c 2 36e 36f
2 366 371 2
373 375 2 377
379 2 37b 37d
2 37f 381 2
359 383 1 385
1 387 2 391
393 3 38f 390
395 2 39e 3a0
2 39d 3a2 1
3a4 1 3a6 3
3ad 3ae 3af 3
388 3a7 3b1 1
3b3 2 3be 3c3
1 3ca 1 3c5
2 3dd 3df 3
3db 3dc 3e1 2
3ea 3ec 2 3ee
3f0 2 3f2 3f4
2 3f6 3f8 2
3fa 3fc 3 401
402 403 2 3fe
405 2 3e9 407
1 409 1 40b
2 3d4 40c 1
410 1 3cf 2
3cd 414 3 41c
41d 41e 1 422
2 420 422 2
427 42a 2 434
436 3 432 433
438 2 441 443
2 445 447 2
449 44b 1 453
2 455 456 2
44d 458 2 440
45a 1 45c 1
45e 2 468 46a
3 466 467 46c
2 475 477 2
474 479 1 47b
1 47d 2 484
485 3 45f 47e
487 2 489 48a
5 325 328 3b4
417 48b 1 48d
1 491 a 497
498 499 49a 49b
49c 49d 49e 49f
4a0 2 4a5 4a6
1 4aa 2 4a8
4aa 1 4ae 8
4b8 4b9 4ba 4bb
4bc 4bd 4be 4bf
1 4c2 1 4c4
1 4c6 3 4cd
4ce 4cf 1 4d2
3 4d5 4d6 4d7
1 4db 2 4d9
4db 3 4e0 4e1
4e2 1 4e5 3
4e9 4ea 4eb 1
4ee 2 4f0 4f1
1 4f2 2 4f4
4f5 1 4f7 2
506 50b 1 512
1 50d 2 525
527 3 523 524
529 2 532 534
2 536 538 2
53a 53c 2 53e
540 2 542 544
3 549 54a 54b
2 546 54d 2
531 54f 1 551
1 553 2 51c
554 1 558 1
517 2 515 55c
2 563 564 2
569 56a 2 566
56c 2 55f 56f
1 571 2 57f
580 2 584 585
8 578 579 57a
57b 57c 57d 582
587 2 58c 58d
1 591 2 58f
591 2 59c 59e
3 59a 59b 5a0
2 5a9 5ab 2
5ad 5af 2 5b1
5b3 1 5bb 2
5bd 5be 2 5b5
5c0 2 5c2 5c4
2 5c6 5c8 2
5ca 5cc 2 5ce
5d0 2 5a8 5d2
1 5d4 1 5d6
2 5e0 5e2 3
5de 5df 5e4 2
5ed 5ef 2 5ec
5f1 1 5f3 1
5f5 3 5fc 5fd
5fe 3 5d7 5f6
600 1 620 2
61f 620 1 628
1 62e 2 630
631 2 61d 632
1 639 1 634
2 64c 64e 3
64a 64b 650 2
659 65b 2 65d
65f 2 661 663
2 665 667 2
669 66b 3 670
671 672 2 66d
674 2 658 676
1 678 1 67a
2 643 67b 1
67f 1 63e 2
63c 683 2 606
686 2 689 68a
1 68e 2 69a
69c 3 698 699
69e 2 6a7 6a9
2 6ab 6ad 2
6af 6b1 1 6b7
2 6b9 6ba 2
6b3 6bc 2 6be
6c0 2 6c2 6c4
2 6c6 6c8 2
6ca 6cc 2 6a6
6ce 1 6d0 1
6d2 2 6dc 6de
3 6da 6db 6e0
2 6e9 6eb 2
6e8 6ed 1 6ef
1 6f1 2 6f7
6f8 3 6fa 6fb
6fc 2 707 709
3 705 706 70b
2 714 716 2
718 71a 2 71c
71e 1 726 2
728 729 2 720
72b 2 72d 72f
2 731 733 2
735 737 2 739
73b 2 713 73d
1 73f 1 741
3 748 749 74a
15 1d3 1f2 1f5
1f8 29b 316 48e
494 4a3 4c5 4f6
572 575 58a 68b
691 6d3 6f2 6fe
742 74c 2 759
75b 3 757 758
75d 2 766 768
2 765 76a 2
771 775 2 777
779 2 77b 77f
2 770 781 2
76c 783 1 785
3 786 791 795
1 750 2 7a8
7aa 3 7a6 7a7
7ac 2 7b5 7b7
2 7b4 7b9 2
7c0 7c2 2 7c4
7c6 3 7cb 7cc
7cd 2 7c8 7cf
2 7bf 7d1 2
7bb 7d3 1 7d5
4 79f 7d6 7df
7e3 1 7e7 1
79a 2 798 7eb
37 1f 26 2d
32 37 3c 41
46 4b 50 57
5e 64 6a 70
75 7a 80 86
8c 92 99 a0
a7 ad b3 b9
bf c5 cb d1
d7 dd e3 e9
ef f5 fb 101
107 10d 113 119
11f 125 12b 131
137 13d 143 149
14f 155 15b 162

1
4
0 
7f2
0
1
14
a
3c
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
11b 1 0
157 1 0
43 1 0
b5 1 0
127 1 0
d9 1 0
b 1 0
109 1 0
39 1 0
1a 1 0
6c 1 0
cd 1 0
df 1 0
f 1 0
59 1 0
3e 1 0
133 1 0
82 1 0
139 1 0
7c 1 0
72 1 0
121 1 0
e5 1 0
bb 1 0
f7 1 0
115 1 0
77 1 0
a9 1 0
c1 1 0
34 1 0
145 1 0
8e 1 0
60 1 0
103 1 0
4d 1 0
151 1 0
3 1 0
66 1 0
94 1 0
2f 1 0
c7 1 0
10f 1 0
d3 1 0
f1 1 0
52 1 0
13f 1 0
88 1 0
9b 1 0
28 1 0
eb 1 0
7 1 0
21 1 0
2 0 1
12d 1 0
48 1 0
fd 1 0
a2 1 0
af 1 0
14b 1 0
15d 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_DATES;
ALTER FUNCTION SP_U_WP_DATES COMPILE DEBUG;
/**************************************************************************/
Prompt == FUNCTION FC_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION FC_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
16b
2 :e:
1FUNCTION:
1FC_U_WP_ACTUAL:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_NEW_WORK_PERCENT:
1PLS_INTEGER:
1SH_H_ACTUAL:
1SH_H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RETURN:
1H_NEW_WORK_PERCENT:
1H_ACTUAL:
1H_UNITS:
1H_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_SD:
1DATE:
1H_FD:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_DAYOFYEAR:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_REC_STATUS:
1H_LAST_MINUTES:
10:
1H_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_EFFORT:
1H_WORK_PERCENT:
1H_PERCENT_UNITS:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_LAST_DAY:
1H_PER_DAY:
1H_TASK_TYPE:
1H_TPH_DELETE:
1H_TEMP_VAR:
1H_MINUTES:
1H_DURATION:
1H_CONTOUR:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_WORK:
1H_SCHED_EFFORT:
1H_WORK_TYPE:
1H_ETC:
1H_CLOSE_TASK:
1H_REMAINING:
1H_ROLLUP_BITS:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_ASSIGN_STRING:
18192:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1DEBUG_PERFTIMING:
1T_TOTAL:
1S_TIME_1:
1S_TIME_2:
1S_TIME_3:
1S_TIME_4:
1H_CONF_FLAG:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
186:
1+:
1FPUT:
1               ENTER:: FC_U_WP_ACTUAL(87) :: cplan.sql(15500) :: :
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1WORK_TODATE:
1SCHED_WORK:
1ETC:
1LAST_SCHED_MIN:
1PROJECT_ASSIGNMENT_ID:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1ASSIGN_UNITS:
1UNITS_MSP:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RESOURCE_ID, RESOURCE_TYPE, BIT_FLAG, LAST_SUBMITTED, WORK+
1_TODATE, SCHED_WORK-WORK_TODATE, ETC,:n      SCHED_WORK, LAST_SCHED_MIN, PROJ+
1ECT_ASSIGNMENT_ID, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT, CASE WHEN ASSIGN_UNIT+
1S > UNITS_MSP THEN ASSIGN_UNITS ELSE UNITS_MSP END,:n      UNRESOLVED_START, +
1UNRESOLVED_FINISH, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(U+
1NRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_COST, SP+
1ECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECIAL_COST+
1, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID, ROLLUP_B+
1ITS:n      INTO h_project_id, h_res_id, h_res_type, h_bit_flag, h_last_submit+
1ted, h_work_todate, h_remaining, h_etc,:n      h_effort, h_last_day, h_prj_as+
1sign_id, h_contour, h_work, h_eunit, h_unit, h_percent_units,:n      h_start_+
1date, h_finish_date, h_SD, h_FD, h_billable, h_capital_expense,:n      h_reg_+
1cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost, h_b_spec_cos+
1t, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_id, h_rollup_bi+
1ts:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1114:
1           EXCEPTION:: FC_U_WP_ACTUAL(115) :: cplan.sql(15528) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TASK_TYPE:
1SCHED_EFFORT:
1SCHED_DURATION:
1MINUTE_PER_DAY:
1REC_STATUS:
1CONFIG_FLAG:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TASK_TYPE, SCHED_EFFORT, WORK_TODATE, MILESTONE_PERCENT, S+
1CHED_DURATION, MINUTE_PER_DAY, REC_STATUS, CONFIG_FLAG:n         INTO h_proje+
1ct_id, h_task_type, h_effort, h_work_todate, h_work_percent, h_duration, h_pe+
1r_day, h_rec_status, h_conf_flag:n         FROM TMT_WBS:n         WHERE ELEME+
1NT_ID = h_id:
1133:
1           EXCEPTION:: FC_U_WP_ACTUAL(134) :: cplan.sql(15547) :: :
1141:
1                EXIT:: FC_U_WP_ACTUAL(142) :: cplan.sql(15555) :: :
1RECORD_NOT_FOUND:
1T:
1148:
1                EXIT:: FC_U_WP_ACTUAL(149) :: cplan.sql(15562) :: :
1CANNOT_UPDATE_LOCKED_RECORD:
1BITAND:
1SC_WBS_ENFORCE_TC_TS:
1156:
1                EXIT:: FC_U_WP_ACTUAL(157) :: cplan.sql(15570) :: :
1SC_TIMESHEET_STEP_EXISTS:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK:n         INTO h_temp_var:n         FROM PROJECT_DETAILS:n +
1        WHERE PROJECT_ID = h_project_id:
1175:
1           EXCEPTION:: FC_U_WP_ACTUAL(176) :: cplan.sql(15589) :: :
1>:
1SELECT REC_STATUS:n            INTO h_rec_status:n            FROM TMT_WBS:n +
1           WHERE ELEMENT_ID = h_project_id:
1194:
1           EXCEPTION:: FC_U_WP_ACTUAL(195) :: cplan.sql(15608) :: :
1PMO_ORASTD:
1STRCMP:
1L:
1202:
1                EXIT:: FC_U_WP_ACTUAL(203) :: cplan.sql(15616) :: :
1LEV_LOCKED_BY_COPY:
1COUNT:
1DUAL:
1A:
1TA:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT A.ELEMENT_ID:n         FROM TASK_ASSIGNMENTS TA, +
1ACTIVITIES A:n         WHERE TA.PROJECT_ID = h_project_id:n         AND TA.TA+
1SK_ID = h_id:n         AND TA.TSK_ASSIGNMENT_ID = A.TSK_ASSIGNMENT_ID:n      +
1   AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT_ID:n         AND A.TYPE_ID = pmo_cnst+
1.SC_TIMESHEET_ACTIVITY):
1230:
1           EXCEPTION:: FC_U_WP_ACTUAL(231) :: cplan.sql(15644) :: :
1238:
1                EXIT:: FC_U_WP_ACTUAL(239) :: cplan.sql(15652) :: :
18:
1245:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(246) :: cplan.sql(15659) :: :
1STATE:: :
1INVALID_PARAMS:
1248:
1                EXIT:: FC_U_WP_ACTUAL(249) :: cplan.sql(15662) :: :
1PMODEFINES:
1PMO_RETURN_INVALID:
1FALSE:
1ELSIF:
1!=:
1256:
1                EXIT:: FC_U_WP_ACTUAL(257) :: cplan.sql(15670) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1FC_U_TASK_PERCENT:
1268:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(269) :: cplan.sql(15682) :: :
1271:
1                EXIT:: FC_U_WP_ACTUAL(272) :: cplan.sql(15685) :: :
1279:
1                EXIT:: FC_U_WP_ACTUAL(280) :: cplan.sql(15693) :: :
1298:
1           EXCEPTION:: FC_U_WP_ACTUAL(299) :: cplan.sql(15712) :: :
1317:
1           EXCEPTION:: FC_U_WP_ACTUAL(318) :: cplan.sql(15731) :: :
1325:
1                EXIT:: FC_U_WP_ACTUAL(326) :: cplan.sql(15739) :: :
1SELECT MINUTE_PER_DAY, TASK_TYPE, REC_STATUS, CONFIG_FLAG:n         INTO h_pe+
1r_day, h_task_type, h_rec_status, h_conf_flag:n         FROM TMT_WBS:n       +
1  WHERE PROJECT_ID = h_project_id :n         AND ELEMENT_ID = h_task_id:
1345:
1           EXCEPTION:: FC_U_WP_ACTUAL(346) :: cplan.sql(15759) :: :
1353:
1                EXIT:: FC_U_WP_ACTUAL(354) :: cplan.sql(15767) :: :
1361:
1                EXIT:: FC_U_WP_ACTUAL(362) :: cplan.sql(15775) :: :
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT ELEMENT_ID:n         FROM ACTIVITIES:n         WH+
1ERE TSK_ASSIGNMENT_ID = h_id:n         AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n +
1        AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
1386:
1           EXCEPTION:: FC_U_WP_ACTUAL(387) :: cplan.sql(15800) :: :
1394:
1                EXIT:: FC_U_WP_ACTUAL(395) :: cplan.sql(15808) :: :
1SC_FD_EFFORT_DRIVEN:
1SC_FIXED_DURATION:
1DAY_YEAR:
1MIN:
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) :n                  INTO h_count, h_day+
1ofyear :n                  FROM TASK_DAY_OF_YEAR:n                  WHERE PRO+
1JECT_ID = h_project_id:n                  AND TSK_ASSIGNMENT_ID = h_id:n     +
1             AND ACTUAL_FLAG = 0:
1422:
1           EXCEPTION:: FC_U_WP_ACTUAL(423) :: cplan.sql(15836) :: :
1IS NOT NULL:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SCHED_MIN:
1ACTUAL_MIN:
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                        FROM TA+
1SK_DAY_OF_YEAR :n                        WHERE PROJECT_ID = h_project_id AND +
1TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = TO_DATE(SubStr(h_last_submitted, 1, 1+
10)):
1449:
1           EXCEPTION:: FC_U_WP_ACTUAL(450) :: cplan.sql(15863) :: :
110000:
1TRUNC:
1TO_NUMBER:
1/:
10.49:
1*:
1FC_FD_U_TDY:
110000.00:
1PMO_FUNC:
1BIT_OR:
1SC_BIT_30:
1U_ASSIGN_STRING:
1<:
1CONSIDER:
1PMO_STPU:
1SC_SCHED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 h_etc,:n                           MILESTONE_PERCENT = 10000:n              +
1             WHERE TSK_ASSIGNMENT_ID = h_id:
1FOUND:
1TRUE:
1100:
1513:
1           EXCEPTION:: FC_U_WP_ACTUAL(514) :: cplan.sql(15927) :: :
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 0,:n                           MILESTONE_PERCENT = 10000:n                  +
1         WHERE TSK_ASSIGNMENT_ID = h_id:
1541:
1           EXCEPTION:: FC_U_WP_ACTUAL(542) :: cplan.sql(15955) :: :
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_etc,:n                  +
1         WORK_TODATE = h_new_actual:n                           WHERE TSK_ASS+
1IGNMENT_ID = h_id:
1571:
1           EXCEPTION:: FC_U_WP_ACTUAL(572) :: cplan.sql(15985) :: :
1600:
1           EXCEPTION:: FC_U_WP_ACTUAL(601) :: cplan.sql(16014) :: :
1UPDATE TASK_ASSIGNMENTS:n                     SET CONSIDER = 7,:n            +
1         ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SCHED_BIT),:n +
1                    SCHED_WORK = h_new_actual,:n                     WORK_TOD+
1ATE = h_new_actual,:n                     ETC = 0,:n                     MILE+
1STONE_PERCENT = 10000:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
1631:
1           EXCEPTION:: FC_U_WP_ACTUAL(632) :: cplan.sql(16045) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1SELECT MAX(WEEK_OF):n                     INTO h_week_of:n                   +
1  FROM TIMESHEET_APPROVAL_STATUS:n                     WHERE ELEMENT_ID = h_p+
1roject_id:n                     AND RESOURCE_ID = h_res_id:
1653:
1           EXCEPTION:: FC_U_WP_ACTUAL(654) :: cplan.sql(16067) :: :
1SELECT TO_DATE(SubStr(h_week_of, 1, 10)) + 7      INTO h_week_of FROM DUAL:
1669:
1           EXCEPTION:: FC_U_WP_ACTUAL(670) :: cplan.sql(16083) :: :
1STRNCMP:
110:
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                        INTO h_start_date:n      +
1                  FROM DUAL:
1692:
1           EXCEPTION:: FC_U_WP_ACTUAL(693) :: cplan.sql(16106) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
1709:
1           EXCEPTION:: FC_U_WP_ACTUAL(710) :: cplan.sql(16123) :: :
1FC_DEL_NOACTUAL:
12:
1FC_RESCHEDULE:
1733:
1                EXIT:: FC_U_WP_ACTUAL(734) :: cplan.sql(16147) :: :
1FC_U_ASSIGN_PERCENT:
1755:
1                EXIT:: FC_U_WP_ACTUAL(756) :: cplan.sql(16169) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS:n            SET MILESTONE_PERCENT = h_new_work_perce+
1nt,:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCEN+
1T_COMPLETE_BIT):n            WHERE TSK_ASSIGNMENT_ID = h_id:
1809:
1           EXCEPTION:: FC_U_WP_ACTUAL(810) :: cplan.sql(16223) :: :
1UPDATE TMT_WBS:n            SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo+
1_cnst.SC_PERCENT_COMPLETE_BIT):n            WHERE PROJECT_ID = h_project_id:n+
1            AND ELEMENT_ID = h_task_id:
1836:
1           EXCEPTION:: FC_U_WP_ACTUAL(837) :: cplan.sql(16250) :: :
1103079040:
1849:
1                EXIT:: FC_U_WP_ACTUAL(850) :: cplan.sql(16263) :: :
1SELECT UNITS_MSP:n               INTO h_temp_var:n               FROM TASK_AS+
1SIGNMENTS:n               WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1871:
1           EXCEPTION:: FC_U_WP_ACTUAL(872) :: cplan.sql(16285) :: :
1SC_SQL_SUCCESS:
1881:
1                EXIT:: FC_U_WP_ACTUAL(882) :: cplan.sql(16295) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_U_TDY_LAST_ACTUAL:
1SC_BIT_29:
1SELECT TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FI+
1NISH, 1, 10)) INTO h_SD, h_FD:n               FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1917:
1           EXCEPTION:: FC_U_WP_ACTUAL(918) :: cplan.sql(16331) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                  INTO h_start_date:n   +
1               FROM DUAL:
1959:
1           EXCEPTION:: FC_U_WP_ACTUAL(960) :: cplan.sql(16373) :: :
1978:
1                EXIT:: FC_U_WP_ACTUAL(979) :: cplan.sql(16392) :: :
1CONTOUR_TYPE:
1SC_PLANNED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                  SET CONSIDER = 7,:n               +
1   UNITS_MSP = h_percent_units,:n                  C_EFFORT = 0,:n           +
1       C_UNIT = 0,:n                  C_CONTOUR = 0,:n                  CONTO+
1UR_TYPE = 0,:n                  ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,(pm+
1o_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)):n                  WHERE TSK_AS+
1SIGNMENT_ID = h_id:
11004:
1           EXCEPTION:: FC_U_WP_ACTUAL(1005) :: cplan.sql(16418) :: :
1FC_ROLLUP:
11022:
1                EXIT:: FC_U_WP_ACTUAL(1023) :: cplan.sql(16436) :: :
0

0
0
1713
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c :2 a0 6b 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 d :4d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :15 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c a0 51 d :1b a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b :2 a0 6b
a0 a5 b 65 a0 b7 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e a0 51 d :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 a0 b7 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e a0
51 d b7 :2 19 3c :2 a0 d :8 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b a5 b d b7 19
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b :2 a0 6b a0 a5 b 65
b7 :2 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c a0
51 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 6e a5 b 7e 51 b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :d a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :3 a0 51 a5
b d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
52 10 a0 4d d :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
7e b4 2e 5a :2 a0 d b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 7e 51 b4 2e d :c a0
a5 b d :2 a0 51 a5 b 7e
51 b4 2e 5a a0 7e b4 2e
:2 5a a 10 :c a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
7e :2 a0 51 a5 b b4 2e d
a0 51 d b7 19 3c :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e a5 b d :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
7e :2 a0 51 a5 b b4 2e d
b7 :3 a0 51 a5 b d b7 :2 19
3c :9 a0 51 a5 b d :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e a5 b d :3 a0 6b :2 a0
51 a5 b :2 a0 6b a5 b d
:7 a0 51 a5 b :2 a0 51 a5 b
a5 b d a0 51 d :c a0 a5
b d b7 19 3c b7 a0 7e
51 b4 2e d :c a0 a5 b d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :2 a0 6b :2 a0 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d :2 a0 51 a5 b
7e :2 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 5a b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e d :11 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b :2 a0 51 a5
b :2 a0 6b a5 b d b7 :10 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 a0 51 a5 b 7e
:2 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d :5 a0 a5 b 51 a5 b
7e :3 a0 a5 b 51 a5 b b4
2e 5a 7e 51 b4 2e 5a 7e
51 b4 2e a5 b d :e a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d a0 51 d :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c b7 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d a0 51 d :10 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c a0
7e b4 2e 5a a0 4d d :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 7e b4 2e 5a :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d b7 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b 5a d :a a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 19
3c a0 7e b4 2e 5a :4 a0 51
a5 b d b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :4 a0 51 a5 b
d b7 :4 a0 51 a5 b d b7
:2 19 3c b7 :2 19 3c a0 51 d
:8 a0 51 :2 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 51
a5 b 65 b7 19 3c b7 :2 19
3c :2 a0 d b7 :5 a0 a5 b 51
a5 b 7e :3 a0 a5 b 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
b7 :2 19 3c :1b a0 51 a5 b :2 a0
51 a5 b a5 b d :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 51 a5 b 65
a0 b7 :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
19 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
:3 a0 51 a5 b d b7 :2 19 3c
a0 7e b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 5a a 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c b7 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e 52 10 a0 7e 51 b4 2e
d :c a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e 5a a0 7e
b4 2e :2 5a a 10 :9 a0 51 a5
b d b7 19 3c :4 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e 51
b4 2e a5 b d :9 a0 51 a5
b d :3 a0 6b :2 a0 51 a5 b
:2 a0 6b a5 b d :5 a0 :2 51 a5
b d :b a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :c a0
a5 b d b7 a0 7e 51 b4
2e d :c a0 a5 b d :2 a0 51
a5 b 7e 51 b4 2e 5a a0
7e b4 2e :2 5a a 10 :9 a0 51
a5 b d b7 19 3c a0 7e
b4 2e 5a :4 a0 51 a5 b d
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :4 a0 51 a5 b d b7 :4 a0
51 a5 b d b7 :2 19 3c b7
:2 19 3c a0 7e b4 2e 5a :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
a0 51 d a0 51 d :8 a0 51
:2 a0 51 a5 b a5 b d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
:12 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c b7 :2 19
3c b7 :2 19 3c :2 a0 6b :2 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
1713
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 50 4c 3a
58 65 61 37 6d 7e 72 76
7a 60 85 9a 8e 92 96 5d
a1 8d a6 aa ae b2 cf ba
be c6 ca 8a eb d6 da e2
e6 b9 10b f6 fa 102 106 b6
127 112 116 119 11a 122 f5 144
132 f2 136 137 13f 131 161 14f
12e 153 154 15c 14e 17e 16c 14b
170 171 179 16b 19b 189 168 18d
18e 196 188 1b7 1a6 1aa 1b2 185
1cf 1be 1c2 1ca 1a5 1eb 1da 1de
1e6 1a2 203 1f2 1f6 1fe 1d9 21f
20e 212 21a 1d6 237 226 22a 232
20d 253 242 246 24e 20a 26f 25a
25e 261 262 26a 241 28c 27a 23e
27e 27f 287 279 2a9 297 276 29b
29c 2a4 296 2c5 2b4 2b8 293 2c0
2b3 2e1 2d0 2d4 2b0 2dc 2cf 2fd
2ec 2f0 2cc 2f8 2eb 319 308 30c
2e8 314 307 335 324 328 304 330
323 351 340 344 320 34c 33f 36d
35c 360 33c 368 35b 389 378 37c
358 384 377 3a5 394 398 374 3a0
393 3c1 3b0 3b4 390 3bc 3af 3dd
3cc 3d0 3ac 3d8 3cb 3f9 3e8 3ec
3c8 3f4 3e7 415 404 408 3e4 410
403 431 420 424 400 42c 41f 44d
43c 440 41c 448 43b 469 458 45c
438 464 457 485 474 478 454 480
473 4a1 490 494 470 49c 48f 4bd
4ac 4b0 48c 4b8 4ab 4d9 4c8 4cc
4a8 4d4 4c7 4f5 4e4 4e8 4c4 4f0
4e3 511 500 504 4e0 50c 4ff 52d
51c 520 4fc 528 51b 549 538 53c
518 544 537 565 554 558 534 560
553 581 570 574 550 57c 56f 59d
58c 590 56c 598 58b 5b9 5a8 5ac
588 5b4 5a7 5e1 5c4 5a4 5c8 5c9
5d1 5d5 5d9 5dc 5c3 609 5ec 5c0
5f0 5f1 5f9 5fd 601 604 5eb 626
614 5e8 618 619 621 613 642 631
635 610 63d 630 65e 64d 651 62d
659 64c 67a 669 66d 649 675 668
696 685 689 665 691 684 6b2 6a1
6a5 681 6ad 6a0 6ce 6bd 6c1 69d
6c9 6bc 6ea 6d9 6dd 6b9 6e5 6d8
706 6f5 6f9 6d5 701 6f4 722 711
715 6f1 71d 710 73e 72d 731 70d
739 72c 75a 749 74d 729 755 748
776 765 769 745 771 764 792 781
785 761 78d 780 7ae 79d 7a1 77d
7a9 79c 7ca 7b9 7bd 799 7c5 7b8
7d1 7d5 7b5 7d9 7dd 7e1 7e4 7e9
7ea 1 7ec 7f1 7f5 7f9 7fc 801
805 809 80c 811 812 814 819 81c
820 821 826 82b 82e 833 834 839
83c 840 841 846 849 84e 84f 854
857 85c 85d 862 865 869 86d 871
872 874 879 87a 87c 87d 882 885
88a 88b 890 893 897 89b 89f 8a0
8a2 8a7 8a8 8aa 8ab 8b0 8b3 8b8
8b9 8be 8c1 8c5 8c9 8cd 8ce 8d0
8d5 8d6 8d8 8d9 8de 8e1 8e6 8e7
8ec 8ef 8f4 8f5 8fa 8fd 901 902
907 90a 90f 910 915 918 91d 91e
923 926 92b 92c 931 934 938 939
93e 941 946 947 94c 94f 954 955
95a 95b 960 962 966 969 96d 971
974 978 97c 97f 982 987 98a 98d
990 991 996 997 1 999 99e 9a2
9a6 9a9 9ae 9b3 9b6 9ba 9bb 9c0
9c1 9c6 9c8 9cc 9cf 9d3 9d7 9db
9df 9e3 9e7 9eb 9ef 9f3 9f7 9fb
9ff a03 a07 a0b a0f a13 a17 a1b
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a6b a6f a73 a77 a7b
a7f a83 a87 a8b a8f a93 a97 a9b
a9f aa3 aa7 aab aaf ab3 ab7 abb
abf ac3 ac7 acb acf ad3 ad7 adb
adf ae3 ae7 aeb aef af3 af7 afb
aff b03 b07 b0b b0f b1b b1f b23
b26 b2a b2e b30 b34 b38 b3c b3f
b43 b47 b49 b4a b4f 1 b53 b57
b5b b5e b62 b66 b6a b6e b71 b75
b79 b7c b7f b84 b87 b8a b8d b8e
b93 b94 1 b96 b9b b9f ba3 ba6
bab bb0 bb3 bb7 bb8 bbd bc0 bc5
bc6 bcb bce bd3 bd4 bd9 bdc be0
be1 be6 be9 bee bef bf4 bf7 bfb
bff c02 c05 c06 c08 c09 c0e c0f
c14 c16 c1a c1d c1f c23 c25 c31
c33 c35 c36 c3b c3f c41 c4d c4f
c53 c57 c5a c5e c61 c65 c68 c69
c6e c71 c75 c79 c7d c81 c85 c89
c8d c91 c95 c99 c9d ca1 ca5 ca9
cad cb1 cb5 cb9 cbd cc1 cc5 cd1
cd5 cd9 cdc ce0 ce4 ce6 cea cee
cf2 cf5 cf9 cfd cff d00 d05 1
d09 d0d d11 d14 d18 d1c d20 d24
d27 d2b d2f d32 d35 d3a d3d d40
d43 d44 d49 d4a 1 d4c d51 d55
d59 d5c d61 d66 d69 d6d d6e d73
d76 d7b d7c d81 d84 d89 d8a d8f
d92 d96 d97 d9c d9f da4 da5 daa
dad db1 db5 db8 dbb dbc dbe dbf
dc4 dc5 dca dcc dd0 dd3 dd5 dd9
ddb de7 de9 deb dec df1 df5 df7
e03 e05 e09 e0d e10 e14 e17 e1b
e1e e1f e24 e27 e2b e2f e33 e37
e3b e3e e42 e46 e49 e4c e51 e54
e57 e5a e5b e60 e61 1 e63 e68
e6c e70 e73 e78 e7d e80 e84 e85
e8a e8b e90 e92 e96 e99 e9d ea1
ea5 ea8 eac eae eb2 eb5 eb9 ebd
ec0 ec3 ec4 ec6 ec9 ece ecf ed4
ed8 edc ee0 ee4 ee8 eeb eef ef3
ef6 ef9 efe f01 f04 f07 f08 f0d
f0e 1 f10 f15 f19 f1d f20 f25
f2a f2d f31 f32 f37 f38 f3d f3f
f43 f46 f4a f4e f52 f55 f59 f5b
f5f f62 f66 f6a f6e f71 f72 f74
f78 f7c f7f f80 f82 f85 f89 f8c
f90 f93 f94 f99 f9d fa1 fa5 fa9
fad fb0 fb4 fb8 fbb fbe fc3 fc6
fc9 fcc fcd fd2 fd3 1 fd5 fda
fde fe2 fe5 fea fef ff2 ff6 ff7
ffc ffd 1002 1004 1008 100b 100f 1013
1017 101a 101e 1020 1024 1027 102b 102e
1032 1036 103a 103e 1042 1046 1052 1056
105a 105d 1061 1065 1067 106b 106f 1073
1076 107a 107e 1080 1081 1086 1 108a
108e 1092 1095 1099 109d 10a1 10a5 10a8
10ac 10b0 10b3 10b6 10bb 10be 10c1 10c4
10c5 10ca 10cb 1 10cd 10d2 10d6 10da
10dd 10e2 10e7 10ea 10ee 10ef 10f4 10f7
10fc 10fd 1102 1105 110a 110b 1110 1113
1117 1118 111d 1120 1125 1126 112b 112e
1132 1136 1139 113c 113d 113f 1140 1145
1146 114b 114d 1151 1154 1156 115a 115c
1168 116a 116c 116d 1172 1176 1178 1184
1186 118a 118e 1191 1192 1194 1197 119a
119b 11a0 11a4 11a8 11ac 11b0 11b4 11c0
11c4 11c8 11cb 11cf 11d3 11d5 11d9 11dd
11e1 11e4 11e8 11ec 11ee 11ef 11f4 1
11f8 11fc 1200 1203 1207 120b 120f 1213
1216 121a 121e 1221 1224 1229 122c 122f
1232 1233 1238 1239 1 123b 1240 1244
1248 124b 1250 1255 1258 125c 125d 1262
1265 126a 126b 1270 1273 1278 1279 127e
1281 1285 1286 128b 128e 1293 1294 1299
129c 12a0 12a4 12a7 12aa 12ab 12ad 12ae
12b3 12b4 12b9 12bb 12bf 12c2 12c4 12c8
12ca 12d6 12d8 12da 12db 12e0 12e4 12e6
12f2 12f4 12f8 12fc 12ff 1303 1308 1309
130b 130e 1311 1312 1317 131b 131f 1323
1327 132b 132e 1332 1336 1339 133c 1341
1344 1347 134a 134b 1350 1351 1 1353
1358 135c 1360 1363 1368 136d 1370 1374
1375 137a 137b 1380 1382 1386 1389 138d
1391 1395 1398 139c 139e 13a2 13a5 13a7
13ab 13ae 13b2 13b5 13b9 13bd 13c1 13c5
13c9 13cd 13d1 13d5 13d9 13dd 13e1 13e5
13e9 13ed 13f1 13f5 13f9 13fd 1401 1405
1409 140d 1411 1415 1419 141d 1421 1425
1431 1435 1439 143c 1440 1444 1446 144a
144e 1452 1455 1459 145d 145f 1460 1465
1 1469 146d 1471 1474 1478 147c 1480
1484 1487 148b 148f 1492 1495 149a 149d
14a0 14a3 14a4 14a9 14aa 1 14ac 14b1
14b5 14b9 14bc 14c1 14c6 14c9 14cd 14ce
14d3 14d6 14db 14dc 14e1 14e4 14e9 14ea
14ef 14f2 14f6 14f7 14fc 14ff 1504 1505
150a 150d 1511 1515 1518 151b 151c 151e
151f 1524 1525 152a 152c 1530 1533 1535
1539 153b 1547 1549 154b 154c 1551 1555
1557 1563 1565 1569 156d 1570 1571 1573
1576 1579 157a 157f 1583 1587 158b 158f
1593 1596 159a 159e 15a1 15a4 15a9 15ac
15af 15b2 15b3 15b8 15b9 1 15bb 15c0
15c4 15c8 15cb 15d0 15d5 15d8 15dc 15dd
15e2 15e3 15e8 15ea 15ee 15f1 15f5 15f9
15fd 1600 1604 1606 160a 160d 1611 1615
1618 1619 161b 161e 1621 1622 1627 162b
162f 1632 1636 163a 163d 1640 1645 1648
164b 164e 164f 1654 1655 1 1657 165c
1660 1664 1667 166c 1671 1674 1678 1679
167e 1681 1686 1687 168c 168f 1694 1695
169a 169d 16a1 16a5 16a9 16ad 16b0 16b1
16b3 16b8 16b9 16bb 16bc 16c1 16c2 16c7
16c9 16cd 16d0 16d4 16d8 16db 16df 16e3
16e6 16e9 16ee 16f1 16f4 16f7 16f8 16fd
16fe 1 1700 1705 1709 170d 1710 1715
171a 171d 1721 1722 1727 1728 172d 172f
1733 1736 173a 173e 1742 1745 1749 174d
1750 1754 1755 1757 175b 175f 1761 1765
1769 176c 176d 176f 1773 1776 177a 177d
177e 1780 1781 1786 178a 178d 1791 1795
1799 179c 179d 179f 17a3 17a6 17aa 17ad
17ae 17b0 17b1 17b6 17ba 17be 17c2 17c6
17ca 17cd 17d1 17d5 17d8 17db 17e0 17e3
17e6 17e9 17ea 17ef 17f0 1 17f2 17f7
17fb 17ff 1802 1807 180c 180f 1813 1814
1819 181a 181f 1821 1825 1828 182c 1830
1834 1837 183b 183f 1841 1845 1849 184c
184d 184f 1853 1856 185a 185d 185e 1860
1861 1866 186a 186d 1871 1873 1877 187b
187e 1882 1886 188a 188e 1892 1896 189a
189e 18a2 18a6 18aa 18ad 18ae 18b0 18b4
18b8 18bb 18bc 18be 18c2 18c6 18c9 18ca
18cc 18cd 18cf 18d3 18d5 18d9 18dd 18e1
18e4 18e8 18ec 18ef 18f2 18f7 18fa 18fd
1900 1901 1906 1907 1 1909 190e 1912
1916 1919 191e 1923 1926 192a 192b 1930
1933 1938 1939 193e 1941 1946 1947 194c
194f 1953 1957 195b 195f 1962 1963 1965
196a 196b 196d 196e 1973 1974 1979 197b
197f 1982 1986 198a 198d 1991 1995 1998
199b 19a0 19a3 19a6 19a9 19aa 19af 19b0
1 19b2 19b7 19bb 19bf 19c2 19c7 19cc
19cf 19d3 19d4 19d9 19da 19df 19e1 19e5
19e8 19ec 19f0 19f4 19f7 19fb 19ff 1a02
1a06 1a07 1a09 1a0d 1a0f 1a13 1a17 1a1a
1a1c 1a20 1a24 1a27 1a28 1a2a 1a2d 1a30
1a31 1a36 1a3a 1a3e 1a42 1a46 1a4a 1a4d
1a51 1a55 1a58 1a5b 1a60 1a63 1a66 1a69
1a6a 1a6f 1a70 1 1a72 1a77 1a7b 1a7f
1a82 1a87 1a8c 1a8f 1a93 1a94 1a99 1a9a
1a9f 1aa1 1aa5 1aa8 1aac 1ab0 1ab4 1ab7
1abb 1abd 1ac1 1ac4 1ac8 1acb 1acf 1ad3
1ad7 1adb 1adf 1ae3 1aef 1af3 1af7 1afa
1afe 1b02 1b04 1b08 1b0c 1b10 1b13 1b17
1b1b 1b1d 1b1e 1b23 1 1b27 1b2b 1b2f
1b32 1b36 1b3a 1b3e 1b42 1b45 1b49 1b4d
1b50 1b53 1b58 1b5b 1b5e 1b61 1b62 1b67
1b68 1 1b6a 1b6f 1b73 1b77 1b7a 1b7f
1b84 1b87 1b8b 1b8c 1b91 1b94 1b99 1b9a
1b9f 1ba2 1ba7 1ba8 1bad 1bb0 1bb4 1bb5
1bba 1bbd 1bc2 1bc3 1bc8 1bcb 1bcf 1bd3
1bd6 1bd9 1bda 1bdc 1bdd 1be2 1be3 1be8
1bea 1bee 1bf1 1bf3 1bf7 1bf9 1c05 1c07
1c09 1c0a 1c0f 1c13 1c15 1c21 1c23 1c27
1c2b 1c2e 1c2f 1c31 1c34 1c37 1c38 1c3d
1c41 1c45 1c49 1c4d 1c51 1c5d 1c61 1c65
1c68 1c6c 1c70 1c72 1c76 1c7a 1c7e 1c81
1c85 1c89 1c8b 1c8c 1c91 1 1c95 1c99
1c9d 1ca0 1ca4 1ca8 1cac 1cb0 1cb3 1cb7
1cbb 1cbe 1cc1 1cc6 1cc9 1ccc 1ccf 1cd0
1cd5 1cd6 1 1cd8 1cdd 1ce1 1ce5 1ce8
1ced 1cf2 1cf5 1cf9 1cfa 1cff 1d02 1d07
1d08 1d0d 1d10 1d15 1d16 1d1b 1d1e 1d22
1d23 1d28 1d2b 1d30 1d31 1d36 1d39 1d3d
1d41 1d44 1d47 1d48 1d4a 1d4b 1d50 1d51
1d56 1d58 1d5c 1d5f 1d61 1d65 1d67 1d73
1d75 1d77 1d78 1d7d 1d81 1d83 1d8f 1d91
1d95 1d99 1d9c 1da0 1da5 1da6 1da8 1dab
1dae 1daf 1db4 1db8 1dbc 1dc0 1dc4 1dc8
1dcb 1dcf 1dd3 1dd6 1dd9 1dde 1de1 1de4
1de7 1de8 1ded 1dee 1 1df0 1df5 1df9
1dfd 1e00 1e05 1e0a 1e0d 1e11 1e12 1e17
1e18 1e1d 1e1f 1e23 1e26 1e2a 1e2e 1e32
1e35 1e39 1e3b 1e3f 1e42 1e44 1e48 1e4b
1e4f 1e53 1e57 1e5b 1e5f 1e63 1e67 1e6b
1e6f 1e73 1e77 1e7b 1e7f 1e8b 1e8f 1e93
1e96 1e9a 1e9e 1ea0 1ea4 1ea8 1eac 1eaf
1eb3 1eb7 1eb9 1eba 1ebf 1 1ec3 1ec7
1ecb 1ece 1ed2 1ed6 1eda 1ede 1ee1 1ee5
1ee9 1eec 1eef 1ef4 1ef7 1efa 1efd 1efe
1f03 1f04 1 1f06 1f0b 1f0f 1f13 1f16
1f1b 1f20 1f23 1f27 1f28 1f2d 1f30 1f35
1f36 1f3b 1f3e 1f43 1f44 1f49 1f4c 1f50
1f51 1f56 1f59 1f5e 1f5f 1f64 1f67 1f6b
1f6f 1f72 1f75 1f76 1f78 1f79 1f7e 1f7f
1f84 1f86 1f8a 1f8d 1f8f 1f93 1f95 1fa1
1fa3 1fa5 1fa6 1fab 1faf 1fb1 1fbd 1fbf
1fc3 1fc7 1fca 1fcd 1fce 1fd0 1fd3 1fd8
1fd9 1fde 1fe2 1fe6 1fea 1fee 1ff2 1ff5
1ff9 1ffd 2000 2003 2008 200b 200e 2011
2012 2017 2018 1 201a 201f 2023 2027
202a 202f 2034 2037 203b 203c 2041 2042
2047 2049 204d 2050 2054 2058 205c 205f
2063 2065 2069 206c 2070 2074 2078 207b
207c 207e 2082 2086 2089 208a 208c 208f
2093 2096 209a 209d 209e 20a3 20a7 20ab
20af 20b3 20b7 20ba 20be 20c2 20c5 20c8
20cd 20d0 20d3 20d6 20d7 20dc 20dd 1
20df 20e4 20e8 20ec 20ef 20f4 20f9 20fc
2100 2101 2106 2107 210c 210e 2112 2115
2119 211d 2121 2124 2128 212a 212e 2131
2135 2138 213c 2140 2144 2148 214c 2150
2154 2158 215c 2160 2164 2168 216c 2178
217c 2180 2183 2187 218b 218d 2191 2195
2199 219c 21a0 21a4 21a6 21a7 21ac 1
21b0 21b4 21b8 21bb 21bf 21c3 21c7 21cb
21ce 21d2 21d6 21d9 21dc 21e1 21e4 21e7
21ea 21eb 21f0 21f1 1 21f3 21f8 21fc
2200 2203 2208 220d 2210 2214 2215 221a
221d 2222 2223 2228 222b 2230 2231 2236
2239 223d 223e 2243 2246 224b 224c 2251
2254 2258 225c 225f 2262 2263 2265 2266
226b 226c 2271 2273 2277 227a 227c 2280
2282 228e 2290 2292 2293 2298 229c 229e
22aa 22ac 22b0 22b4 22b7 22b8 22ba 22bd
22c0 22c1 22c6 22ca 22ce 22d2 22d6 22da
22dd 22e1 22e5 22e8 22eb 22f0 22f3 22f6
22f9 22fa 22ff 2300 1 2302 2307 230b
230f 2312 2317 231c 231f 2323 2324 2329
232a 232f 2331 2335 2338 233c 2340 2344
2347 234b 234d 2351 2354 2358 235c 2360
2363 2364 2366 236a 236e 2372 2375 2376
2378 237c 237f 2383 2386 2387 2389 238a
238f 2393 2397 239b 239f 23a3 23a6 23a7
23a9 23ad 23b0 23b4 23b7 23b8 23ba 23bb
23c0 23c4 23c8 23cb 23cc 23ce 23d2 23d5
23d9 23dc 23dd 23e2 23e6 23ea 23ed 23ee
23f0 23f4 23f7 23fb 23fe 23ff 1 2404
2409 240d 240e 2412 2416 241a 241e 2422
2426 242a 242e 2432 2436 243a 243e 2442
244e 2452 2456 2459 245d 2461 2463 2467
246b 246f 2472 2476 247a 247c 247d 2482
1 2486 248a 248e 2491 2495 2499 249d
24a1 24a4 24a8 24ac 24af 24b2 24b7 24ba
24bd 24c0 24c1 24c6 24c7 1 24c9 24ce
24d2 24d6 24d9 24de 24e3 24e6 24ea 24eb
24f0 24f3 24f8 24f9 24fe 2501 2506 2507
250c 250f 2513 2514 2519 251c 2521 2522
2527 252a 252e 2532 2535 2538 2539 253b
253c 2541 2542 2547 2549 254d 2550 2552
2556 2558 2564 2566 2568 2569 256e 2572
2574 2580 2582 2586 2589 258a 258f 2592
2596 259a 259e 25a0 25a4 25a7 25ab 25af
25b2 25b3 25b5 25b8 25bb 25bc 25c1 25c5
25c8 25cb 25cc 25d1 25d5 25d9 25dd 25e1
25e5 25e9 25ed 25f1 25f5 25f9 25fd 2601
2605 2606 2608 260c 2610 2614 2617 2618
261a 261d 2620 2621 2626 2629 262d 2630
2631 2636 2639 1 263c 2641 2645 2649
264d 2651 2655 2659 265d 2661 2665 2669
266d 2671 267d 2681 2685 2688 268c 2690
2692 2696 269a 269e 26a1 26a5 26a9 26ab
26ac 26b1 1 26b5 26b9 26bd 26c0 26c4
26c8 26cc 26d0 26d3 26d7 26db 26de 26e1
26e6 26e9 26ec 26ef 26f0 26f5 26f6 1
26f8 26fd 2701 2705 2708 270d 2712 2715
2719 271a 271f 2722 2727 2728 272d 2730
2735 2736 273b 273e 2742 2743 2748 274b
2750 2751 2756 2759 275d 2761 2764 2767
2768 276a 276b 2770 2771 2776 2778 277c
277f 2781 2785 2787 2793 2795 2797 2798
279d 27a1 27a3 27af 27b1 27b5 27b9 27bd
27c0 27c1 27c3 27c6 27ca 27ce 27d1 27d2
27d4 27d5 27da 27dd 27e1 27e5 27e8 27e9
27eb 27ec 27f1 27f5 27f9 27fc 2800 2802
2806 2809 280d 2811 2815 2819 281d 281e
2820 2823 2824 2826 2829 282d 2831 2835
2836 2838 283b 283c 283e 283f 2844 2847
284a 284d 284e 2853 2854 2856 285a 285e
2862 2866 2869 286a 286c 286f 2873 2877
287a 287b 287d 287e 2883 2887 288b 288f
2892 2893 2895 2899 289c 28a0 28a3 28a4
28a6 28a7 28ac 28b0 28b4 28b8 28bb 28bc
28be 28c1 28c5 28c9 28cc 28cd 28cf 28d0
28d5 28d8 28dc 28e0 28e3 28e4 28e6 28e7
28ec 28f0 28f2 28f6 28fa 28fe 2901 2902
2904 2908 290a 290e 2912 2915 2919 291d
2921 2925 2929 292d 2931 2935 2939 293c
293d 293f 2943 2947 294b 294f 2953 2957
2958 295a 295d 295e 2960 2963 2967 296b
296f 2970 2972 2975 2976 2978 2979 297e
2981 2984 2987 2988 298d 298e 2990 2994
2998 299c 29a0 29a3 29a7 29ab 29ae 29af
29b1 29b5 29b9 29bc 29bd 29bf 29c3 29c7
29cb 29cf 29d3 29d7 29db 29df 29e2 29e3
29e5 29e9 29ed 29f0 29f1 29f3 29f4 29f6
29fa 29fe 2a01 2a05 2a09 2a0d 2a11 2a15
2a19 2a1d 2a21 2a25 2a29 2a2d 2a31 2a35
2a36 2a38 2a3c 2a3e 2a42 2a45 2a47 2a4b
2a4e 2a51 2a52 2a57 2a5b 2a5f 2a63 2a67
2a6b 2a6f 2a73 2a77 2a7b 2a7f 2a83 2a87
2a8b 2a8c 2a8e 2a92 2a96 2a9a 2a9d 2a9e
2aa0 2aa4 2aa7 2aab 2aae 2aaf 2ab1 2ab2
2ab7 2abb 2abf 2ac2 2ac6 2aca 2acb 2acd
2ad0 2ad3 2ad4 2ad9 2add 2ae1 2ae5 2ae8
2ae9 2aeb 2aee 2af2 2af6 2af9 2afa 2afc
2afd 2b02 2b06 2b0a 2b0d 2b11 2b15 2b19
2b1c 2b1d 2b1f 2b22 2b26 2b2a 2b2d 2b2e
2b30 2b33 2b37 2b3b 2b3e 2b3f 2b41 2b42
2b47 2b4a 2b4b 2b50 2b54 2b58 2b5c 2b5f
2b60 2b62 2b65 2b69 2b6d 2b70 2b71 2b73
2b74 2b79 2b7c 2b7f 2b83 2b87 2b8a 2b8b
2b8d 2b8e 2b93 2b97 2b9b 2b9f 2ba3 2ba7
2bab 2baf 2bb3 2bb7 2bbb 2bbf 2bc3 2bc7
2bcb 2bcf 2bd3 2bd7 2bdb 2be7 2beb 2bf0
2bf4 2bf7 2bf8 2bfd 2c01 2c05 2c08 2c0b
2c0f 2c11 2c15 2c19 2c1c 2c1f 2c23 2c25
2c29 2c2d 2c30 2c32 2c36 2c3a 2c3e 2c41
2c45 2c49 2c4b 2c4c 2c51 1 2c55 2c59
2c5d 2c60 2c64 2c68 2c6c 2c70 2c73 2c77
2c7b 2c7e 2c81 2c86 2c89 2c8c 2c8f 2c90
2c95 2c96 1 2c98 2c9d 2ca1 2ca5 2ca8
2cad 2cb2 2cb5 2cb9 2cba 2cbf 2cc2 2cc7
2cc8 2ccd 2cd0 2cd5 2cd6 2cdb 2cde 2ce2
2ce3 2ce8 2ceb 2cf0 2cf1 2cf6 2cf9 2cfd
2d01 2d04 2d07 2d08 2d0a 2d0b 2d10 2d11
2d16 2d18 2d1c 2d1f 2d21 2d25 2d27 2d33
2d35 2d37 2d38 2d3d 2d41 2d43 2d4f 2d51
2d55 2d59 2d5d 2d60 2d64 2d68 2d6b 2d6c
2d6e 2d72 2d76 2d79 2d7a 2d7c 2d80 2d82
2d86 2d8a 2d8e 2d92 2d96 2d9a 2d9e 2da2
2da6 2daa 2dae 2db2 2db6 2dba 2dbe 2dc2
2dce 2dd2 2dd7 2ddb 2dde 2ddf 2de4 2de8
2dec 2def 2df2 2df6 2df8 2dfc 2e00 2e03
2e06 2e0a 2e0c 2e10 2e14 2e17 2e19 2e1d
2e21 2e25 2e28 2e2c 2e30 2e32 2e33 2e38
1 2e3c 2e40 2e44 2e47 2e4b 2e4f 2e53
2e57 2e5a 2e5e 2e62 2e65 2e68 2e6d 2e70
2e73 2e76 2e77 2e7c 2e7d 1 2e7f 2e84
2e88 2e8c 2e8f 2e94 2e99 2e9c 2ea0 2ea1
2ea6 2ea9 2eae 2eaf 2eb4 2eb7 2ebc 2ebd
2ec2 2ec5 2ec9 2eca 2ecf 2ed2 2ed7 2ed8
2edd 2ee0 2ee4 2ee8 2eeb 2eee 2eef 2ef1
2ef2 2ef7 2ef8 2efd 2eff 2f03 2f06 2f08
2f0c 2f0e 2f1a 2f1c 2f1e 2f1f 2f24 2f28
2f2a 2f36 2f38 2f3a 2f3e 2f42 2f45 2f47
2f4b 2f4f 2f52 2f53 2f55 2f58 2f5c 2f60
2f63 2f64 2f66 2f69 2f6d 2f71 2f74 2f75
2f77 2f78 2f7d 2f80 2f81 2f86 2f8a 2f8e
2f92 2f95 2f96 2f98 2f9b 2f9f 2fa3 2fa6
2fa7 2fa9 2faa 2faf 2fb3 2fb7 2fbb 2fbf
2fc3 2fc7 2fc8 2fca 2fcd 2fce 2fd0 2fd3
2fd7 2fdb 2fdf 2fe0 2fe2 2fe5 2fe6 2fe8
2fe9 2fee 2ff1 2ff4 2ff7 2ff8 2ffd 3000
3003 3006 3007 300c 300d 300f 3013 3017
301b 301f 3023 3027 302b 302f 3033 3037
303b 303f 3043 3047 304b 3057 305b 3060
3064 3067 3068 306d 3071 3075 3078 307b
307f 3081 3085 3089 308c 308f 3093 3095
3099 309d 30a0 30a2 30a6 30aa 30ae 30b1
30b5 30b9 30bb 30bc 30c1 1 30c5 30c9
30cd 30d0 30d4 30d8 30dc 30e0 30e3 30e7
30eb 30ee 30f1 30f6 30f9 30fc 30ff 3100
3105 3106 1 3108 310d 3111 3115 3118
311d 3122 3125 3129 312a 312f 3132 3137
3138 313d 3140 3145 3146 314b 314e 3152
3153 3158 315b 3160 3161 3166 3169 316d
3171 3174 3177 3178 317a 317b 3180 3181
3186 3188 318c 318f 3191 3195 3197 31a3
31a5 31a7 31a8 31ad 31b1 31b3 31bf 31c1
31c3 31c7 31cb 31cf 31d2 31d3 31d5 31d8
31dc 31e0 31e3 31e4 31e6 31e7 31ec 31f0
31f4 31f7 31fb 31ff 3203 3207 320b 320f
3213 3217 321b 321f 3223 3227 322b 322f
3233 3237 323b 3247 324b 3250 3254 3257
3258 325d 3261 3265 3268 326b 326f 3271
3275 3279 327c 327f 3283 3285 3289 328d
3290 3292 3296 329a 329e 32a1 32a5 32a9
32ab 32ac 32b1 1 32b5 32b9 32bd 32c0
32c4 32c8 32cc 32d0 32d3 32d7 32db 32de
32e1 32e6 32e9 32ec 32ef 32f0 32f5 32f6
1 32f8 32fd 3301 3305 3308 330d 3312
3315 3319 331a 331f 3322 3327 3328 332d
3330 3335 3336 333b 333e 3342 3343 3348
334b 3350 3351 3356 3359 335d 3361 3364
3367 3368 336a 336b 3370 3371 3376 3378
337c 337f 3381 3385 3387 3393 3395 3397
3398 339d 33a1 33a3 33af 33b1 33b3 33b7
33bb 33be 33c0 33c4 33c8 33cb 33cd 33d1
33d5 33d9 33dc 33dd 33df 33e2 33e6 33ea
33ed 33ee 33f0 33f1 33f6 33fa 33fe 3401
3405 3409 340d 3411 3415 3419 341d 3421
3425 3429 342d 3431 3435 3439 343d 3441
3445 3451 3455 345a 345e 3461 3462 3467
346b 346f 3472 3475 3479 347b 347f 3483
3486 3489 348d 348f 3493 3497 349a 349c
34a0 34a4 34a8 34ab 34af 34b3 34b5 34b6
34bb 1 34bf 34c3 34c7 34ca 34ce 34d2
34d6 34da 34dd 34e1 34e5 34e8 34eb 34f0
34f3 34f6 34f9 34fa 34ff 3500 1 3502
3507 350b 350f 3512 3517 351c 351f 3523
3524 3529 352c 3531 3532 3537 353a 353f
3540 3545 3548 354c 354d 3552 3555 355a
355b 3560 3563 3567 356b 356e 3571 3572
3574 3575 357a 357b 3580 3582 3586 3589
358b 358f 3591 359d 359f 35a1 35a2 35a7
35ab 35ad 35b9 35bb 35bd 35c1 35c5 35c8
35cc 35cf 35d0 35d5 35d8 35dc 35dd 35e1
35e5 35e9 35ed 35f1 35f5 35f9 35fd 3601
360d 3611 3615 3618 361c 3620 3622 3626
362a 362e 3631 3635 3639 363b 363c 3641
1 3645 3649 364d 3650 3654 3658 365c
3660 3663 3667 366b 366e 3671 3676 3679
367c 367f 3680 3685 3686 1 3688 368d
3691 3695 3698 369d 36a2 36a5 36a9 36aa
36af 36b2 36b7 36b8 36bd 36c0 36c5 36c6
36cb 36ce 36d2 36d3 36d8 36db 36e0 36e1
36e6 36e9 36ed 36f1 36f4 36f7 36f8 36fa
36fb 3700 3701 3706 3708 370c 370f 3711
3715 3717 3723 3725 3727 3728 372d 3731
3733 373f 3741 3745 3748 3749 374e 3751
3755 3759 375d 3761 3765 3771 3775 3779
377c 3780 3784 3786 378a 378e 3792 3795
3799 379d 379f 37a0 37a5 1 37a9 37ad
37b1 37b4 37b8 37bc 37c0 37c4 37c7 37cb
37cf 37d2 37d5 37da 37dd 37e0 37e3 37e4
37e9 37ea 1 37ec 37f1 37f5 37f9 37fc
3801 3806 3809 380d 380e 3813 3816 381b
381c 3821 3824 3829 382a 382f 3832 3836
3837 383c 383f 3844 3845 384a 384d 3851
3855 3858 385b 385c 385e 385f 3864 3865
386a 386c 3870 3873 3875 3879 387b 3887
3889 388b 388c 3891 3895 3897 38a3 38a5
38a9 38ad 38b0 38b4 38b8 38bb 38bc 38be
38c1 38c4 38c5 38ca 38ce 38d2 38d6 38d8
38dc 38df 38e3 38e5 38e9 38ed 38f0 38f1
38f3 38f6 38f9 38fa 38ff 3903 3907 390b
390e 3912 3916 3919 391a 391c 3920 3924
3927 3928 392a 392d 3931 3935 3939 393d
3941 3945 3949 394d 3951 3955 3959 3965
3969 396d 3970 3974 3978 397a 397e 3982
3986 3989 398d 3991 3993 3994 3999 1
399d 39a1 39a5 39a8 39ac 39b0 39b4 39b8
39bb 39bf 39c3 39c6 39c9 39ce 39d1 39d4
39d7 39d8 39dd 39de 1 39e0 39e5 39e9
39ed 39f0 39f5 39fa 39fd 3a01 3a02 3a07
3a0a 3a0f 3a10 3a15 3a18 3a1d 3a1e 3a23
3a26 3a2a 3a2b 3a30 3a33 3a38 3a39 3a3e
3a41 3a45 3a49 3a4c 3a4f 3a50 3a52 3a53
3a58 3a59 3a5e 3a60 3a64 3a67 3a69 3a6d
3a6f 3a7b 3a7d 3a7f 3a80 3a85 3a89 3a8b
3a97 3a99 3a9b 3a9f 3aa3 3aa7 3aab 3aaf
3ab3 3ab7 3abb 3abf 3ac3 3ac7 3ad3 3ad7
3adb 3ade 3ae2 3ae6 3ae8 3aec 3af0 3af4
3af7 3afb 3aff 3b01 3b02 3b07 1 3b0b
3b0f 3b13 3b16 3b1a 3b1e 3b22 3b26 3b29
3b2d 3b31 3b34 3b37 3b3c 3b3f 3b42 3b45
3b46 3b4b 3b4c 1 3b4e 3b53 3b57 3b5b
3b5e 3b63 3b68 3b6b 3b6f 3b70 3b75 3b78
3b7d 3b7e 3b83 3b86 3b8b 3b8c 3b91 3b94
3b98 3b99 3b9e 3ba1 3ba6 3ba7 3bac 3baf
3bb3 3bb7 3bba 3bbd 3bbe 3bc0 3bc1 3bc6
3bc7 3bcc 3bce 3bd2 3bd5 3bd7 3bdb 3bdd
3be9 3beb 3bed 3bee 3bf3 3bf7 3bf9 3c05
3c07 3c09 3c0d 3c11 3c14 3c16 3c1a 3c1d
3c21 3c24 3c25 3c2a 3c2d 3c31 3c35 3c39
3c3d 3c40 3c41 3c43 3c47 3c49 3c4d 3c51
3c54 3c57 3c58 3c5a 3c5d 3c62 3c63 3c68
3c6c 3c70 3c74 3c78 3c7b 3c7c 3c7e 3c82
3c84 3c88 3c8c 3c90 3c94 3c97 3c98 3c9a
3c9e 3ca0 3ca4 3ca8 3cab 3cad 3cb1 3cb5
3cb8 3cbc 3cbf 3cc3 3cc7 3ccb 3ccf 3cd3
3cd7 3cdb 3cdf 3ce3 3ce6 3cea 3cee 3cf1
3cf2 3cf4 3cf5 3cf7 3cfb 3cff 3d03 3d06
3d07 3d09 3d0c 3d0f 3d10 3d15 3d19 3d1d
3d21 3d25 3d29 3d2c 3d30 3d34 3d37 3d3a
3d3f 3d42 3d45 3d48 3d49 3d4e 3d4f 1
3d51 3d56 3d5a 3d5e 3d61 3d66 3d6b 3d6e
3d72 3d73 3d78 3d79 3d7e 3d80 3d84 3d87
3d8b 3d8f 3d93 3d96 3d97 3d99 3d9d 3d9f
3da3 3da6 3da8 3dac 3db0 3db3 3db7 3dbb
3dbf 3dc1 3dc5 3dc9 3dcd 3dd1 3dd5 3dd6
3dd8 3ddb 3ddc 3dde 3de1 3de5 3de9 3ded
3dee 3df0 3df3 3df4 3df6 3df7 3dfc 3dff
3e02 3e05 3e06 3e0b 3e0e 3e11 3e14 3e15
3e1a 3e1b 3e1d 3e21 3e23 3e27 3e2b 3e2e
3e32 3e36 3e3a 3e3e 3e42 3e46 3e4a 3e4e
3e52 3e56 3e5a 3e5e 3e62 3e66 3e6a 3e6e
3e72 3e76 3e7a 3e7e 3e82 3e86 3e8a 3e8e
3e92 3e96 3e9a 3e9d 3e9e 3ea0 3ea4 3ea8
3eab 3eac 3eae 3eaf 3eb1 3eb5 3eb9 3ebd
3ec1 3ec5 3ec9 3ecc 3ed0 3ed4 3ed7 3eda
3edf 3ee2 3ee5 3ee8 3ee9 3eee 3eef 1
3ef1 3ef6 3efa 3efe 3f01 3f06 3f0b 3f0e
3f12 3f13 3f18 3f19 3f1e 3f20 3f24 3f27
3f2b 3f2f 3f33 3f36 3f37 3f39 3f3d 3f41
3f43 3f47 3f4b 3f4e 3f4f 3f51 3f55 3f58
3f5c 3f5f 3f60 3f62 3f63 3f68 3f6c 3f70
3f74 3f78 3f7c 3f80 3f84 3f88 3f8c 3f90
3f94 3fa0 3fa4 3fa9 3fad 3fb0 3fb1 3fb6
3fba 3fbe 3fc1 3fc4 3fc8 3fca 3fce 3fd2
3fd5 3fd8 3fdc 3fde 3fe2 3fe6 3fe9 3feb
3fef 3ff3 3ff7 3ffa 3ffe 4002 4004 4005
400a 1 400e 4012 4016 4019 401d 4021
4025 4029 402c 4030 4034 4037 403a 403f
4042 4045 4048 4049 404e 404f 1 4051
4056 405a 405e 4061 4066 406b 406e 4072
4073 4078 407b 4080 4081 4086 4089 408e
408f 4094 4097 409b 409c 40a1 40a4 40a9
40aa 40af 40b2 40b6 40ba 40bd 40c0 40c1
40c3 40c4 40c9 40ca 40cf 40d1 40d5 40d8
40da 40de 40e0 40ec 40ee 40f0 40f1 40f6
40fa 40fc 4108 410a 410e 4112 4116 411a
411e 4122 4126 412a 412e 4132 4136 4142
4146 414b 414f 4152 4153 4158 415c 4160
4163 4166 416a 416c 4170 4174 4177 417a
417e 4180 4184 4188 418b 418d 4191 4195
4199 419c 41a0 41a4 41a6 41a7 41ac 1
41b0 41b4 41b8 41bb 41bf 41c3 41c7 41cb
41ce 41d2 41d6 41d9 41dc 41e1 41e4 41e7
41ea 41eb 41f0 41f1 1 41f3 41f8 41fc
4200 4203 4208 420d 4210 4214 4215 421a
421d 4222 4223 4228 422b 4230 4231 4236
4239 423d 423e 4243 4246 424b 424c 4251
4254 4258 425c 425f 4262 4263 4265 4266
426b 426c 4271 4273 4277 427a 427c 4280
4282 428e 4290 4292 4293 4298 429c 429e
42aa 42ac 42b0 42b2 42b6 42ba 42be 42c1
42c2 42c4 42c8 42cb 42cf 42d2 42d3 42d5
42d6 42db 42df 42e3 42e6 42e7 42e9 42ec
42ef 42f0 42f5 42f9 42fc 4300 4302 4306
430a 430d 430e 4310 4313 4316 4317 431c
431f 4323 4327 432a 432b 432d 4330 4333
4334 4339 1 433c 4341 4345 4349 434d
4351 4355 4358 435c 4360 4363 4366 436b
436e 4371 4374 4375 437a 437b 1 437d
4382 4386 438a 438d 4392 4397 439a 439e
439f 43a4 43a5 43aa 43ac 43b0 43b3 43b7
43bb 43bf 43c2 43c6 43c8 43cc 43cf 43d3
43d7 43db 43de 43df 43e1 43e5 43e7 43eb
43ef 43f2 43f6 43f9 43fa 43ff 4402 4406
440a 440e 4412 4416 4422 4426 442a 442d
4431 4435 4437 443b 443f 4443 4446 444a
444e 4450 4451 4456 1 445a 445e 4462
4465 4469 446d 4471 4475 4478 447c 4480
4483 4486 448b 448e 4491 4494 4495 449a
449b 1 449d 44a2 44a6 44aa 44ad 44b2
44b7 44ba 44be 44bf 44c4 44c7 44cc 44cd
44d2 44d5 44da 44db 44e0 44e3 44e7 44e8
44ed 44f0 44f5 44f6 44fb 44fe 4502 4506
4509 450c 450d 450f 4510 4515 4516 451b
451d 4521 4524 4526 452a 452c 4538 453a
453c 453d 4542 4546 4548 4554 4556 455a
455e 4561 4565 4568 456c 456f 4570 4575
4578 457c 4580 4583 4584 4586 458a 458d
4591 4594 4595 4597 4598 459d 1 45a0
45a5 45a9 45ad 45b1 45b5 45b9 45bc 45c0
45c4 45c7 45ca 45cf 45d2 45d5 45d8 45d9
45de 45df 1 45e1 45e6 45ea 45ee 45f1
45f6 45fb 45fe 4602 4603 4608 4609 460e
4610 4614 4617 461b 461f 4623 4626 462a
462c 4630 4633 4635 4639 463c 4640 4644
4647 4648 464a 464e 4651 4655 4658 4659
465e 4662 4666 4669 466a 466c 4670 4673
4677 467a 467b 1 4680 4685 4689 468c
468f 4690 4695 4699 469d 46a1 46a5 46a9
46ad 46b1 46b5 46b9 46bd 46c1 46c5 46c9
46ca 46cc 46d0 46d4 46d8 46db 46dc 46de
46e1 46e4 46e5 46ea 46ed 46f1 46f4 46f5
46fa 46fd 1 4700 4705 4709 470d 4711
4715 4719 471d 4721 4725 4729 472c 472d
472f 4733 4735 4739 473c 4740 4744 4748
474c 474f 4750 4752 4755 4759 475d 4760
4761 4763 4764 4769 476c 476f 4772 4773
4778 477b 477e 4781 4782 4787 4788 478a
478e 4792 4796 479a 479e 47a2 47a6 47aa
47ae 47b2 47b5 47b6 47b8 47bc 47c0 47c4
47c8 47cb 47cf 47d3 47d6 47d7 47d9 47dd
47e1 47e4 47e5 47e7 47eb 47ef 47f3 47f7
47fb 47ff 4802 4805 4806 4808 480c 4810
4814 4818 481c 4820 4824 4828 482c 4830
4834 4838 4844 4848 484c 484f 4853 4857
4859 485d 4861 4865 4868 486c 4870 4872
4873 4878 1 487c 4880 4884 4887 488b
488f 4893 4897 489a 489e 48a2 48a5 48a8
48ad 48b0 48b3 48b6 48b7 48bc 48bd 1
48bf 48c4 48c8 48cc 48cf 48d4 48d9 48dc
48e0 48e1 48e6 48e9 48ee 48ef 48f4 48f7
48fc 48fd 4902 4905 4909 490a 490f 4912
4917 4918 491d 4920 4924 4928 492b 492e
492f 4931 4932 4937 4938 493d 493f 4943
4946 4948 494c 494e 495a 495c 495e 495f
4964 4968 496a 4976 4978 497c 497f 4983
4987 498b 498f 4993 4997 499b 499f 49a3
49a7 49ab 49af 49b3 49b4 49b6 49ba 49bc
49c0 49c3 49c6 49c7 49cc 49d0 49d4 49d8
49dc 49e0 49e4 49e8 49ec 49f0 49f4 49f8
49fc 4a00 4a01 4a03 4a07 4a0b 4a0f 4a12
4a13 4a15 4a18 4a1b 4a1c 4a21 4a24 4a28
4a2b 4a2c 4a31 4a34 1 4a37 4a3c 4a40
4a44 4a48 4a4c 4a50 4a54 4a58 4a5c 4a60
4a63 4a64 4a66 4a6a 4a6c 4a70 4a73 4a77
4a7a 4a7b 4a80 4a83 4a87 4a8b 4a8f 4a93
4a96 4a97 4a99 4a9d 4a9f 4aa3 4aa7 4aaa
4aad 4aae 4ab0 4ab3 4ab8 4ab9 4abe 4ac2
4ac6 4aca 4ace 4ad1 4ad2 4ad4 4ad8 4ada
4ade 4ae2 4ae6 4aea 4aed 4aee 4af0 4af4
4af6 4afa 4afe 4b01 4b03 4b07 4b0b 4b0e
4b12 4b15 4b16 4b1b 4b1e 4b22 4b26 4b2a
4b2e 4b32 4b36 4b3a 4b3e 4b42 4b46 4b52
4b56 4b5a 4b5d 4b61 4b65 4b67 4b6b 4b6f
4b73 4b76 4b7a 4b7e 4b80 4b81 4b86 1
4b8a 4b8e 4b92 4b95 4b99 4b9d 4ba1 4ba5
4ba8 4bac 4bb0 4bb3 4bb6 4bbb 4bbe 4bc1
4bc4 4bc5 4bca 4bcb 1 4bcd 4bd2 4bd6
4bda 4bdd 4be2 4be7 4bea 4bee 4bef 4bf4
4bf7 4bfc 4bfd 4c02 4c05 4c0a 4c0b 4c10
4c13 4c17 4c18 4c1d 4c20 4c25 4c26 4c2b
4c2e 4c32 4c36 4c39 4c3c 4c3d 4c3f 4c40
4c45 4c46 4c4b 4c4d 4c51 4c54 4c56 4c5a
4c5c 4c68 4c6a 4c6c 4c6d 4c72 4c76 4c78
4c84 4c86 4c8a 4c8e 4c92 4c95 4c96 4c98
4c9b 4c9f 4ca3 4ca6 4ca7 4ca9 4caa 4caf
4cb3 4cb5 4cb9 4cbc 4cc0 4cc3 4cc7 4ccb
4cce 4cd2 4cd6 4cda 4cde 4ce2 4ce6 4cea
4cee 4cf2 4cf5 4cf9 4cfd 4d00 4d01 4d03
4d04 4d06 4d0a 4d0e 4d12 4d15 4d16 4d18
4d1b 4d1e 4d1f 4d24 4d28 4d2c 4d30 4d34
4d38 4d3b 4d3f 4d43 4d46 4d49 4d4e 4d51
4d54 4d57 4d58 4d5d 4d5e 1 4d60 4d65
4d69 4d6d 4d70 4d75 4d7a 4d7d 4d81 4d82
4d87 4d88 4d8d 4d8f 4d93 4d96 4d9a 4d9e
4da2 4da5 4da9 4dab 4daf 4db3 4db7 4dbb
4dbf 4dc3 4dc7 4dcb 4dcf 4dd3 4dd7 4ddb
4ddf 4de3 4de7 4deb 4def 4df3 4dff 4e03
4e08 4e0c 4e0f 4e10 4e15 4e19 4e1d 4e20
4e23 4e27 4e29 4e2d 4e31 4e34 4e37 4e3b
4e3d 4e41 4e45 4e48 4e4a 4e4e 4e52 4e56
4e59 4e5d 4e61 4e63 4e64 4e69 1 4e6d
4e71 4e75 4e78 4e7c 4e80 4e84 4e88 4e8b
4e8f 4e93 4e96 4e99 4e9e 4ea1 4ea4 4ea7
4ea8 4ead 4eae 1 4eb0 4eb5 4eb9 4ebd
4ec0 4ec5 4eca 4ecd 4ed1 4ed2 4ed7 4eda
4edf 4ee0 4ee5 4ee8 4eed 4eee 4ef3 4ef6
4efa 4efb 4f00 4f03 4f08 4f09 4f0e 4f11
4f15 4f19 4f1c 4f1f 4f20 4f22 4f23 4f28
4f29 4f2e 4f30 4f34 4f37 4f39 4f3d 4f3f
4f4b 4f4d 4f4f 4f50 4f55 4f59 4f5b 4f67
4f69 4f6b 4f6f 4f73 4f76 4f78 4f7c 4f80
4f83 4f85 4f89 4f8d 4f90 4f92 4f96 4f9a
4f9d 4fa1 4fa5 4fa8 4fac 4fb0 4fb1 4fb3
4fb7 4fbb 4fbf 4fc2 4fc6 4fca 4fcd 4fd0
4fd5 4fd8 4fdb 4fde 4fdf 4fe4 4fe5 1
4fe7 4fec 4ff0 4ff4 4ff7 4ffc 5001 5004
5008 5009 500e 5011 5016 5017 501c 501f
5024 5025 502a 502d 5031 5035 5038 5039
503e 503f 5044 5046 504a 504d 5051 5055
5059 505c 5060 5062 5066 5068 5074 5078
507a 507b 5084 
1713
2
0 1 a 6 15 19 20 :3 6
1c :3 6 12 :3 6 11 :3 6 14 18
1f :3 6 14 18 1f :2 6 1 3
a :2 1 4 :2 17 26 17 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 9
12 11 :2 9 :2 4 14 1d 1c :2 14
:2 4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 d 16 15 :2 d :2 4
:3 9 :2 4 :3 9 :2 4 :3 11 :2 4 :3 12 :2 4
:3 15 :2 4 :3 e :2 4 :3 10 :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 :2 13 22 13
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 d 1c d
:2 4 :2 13 22 13 :2 4 :2 14 23 14
:2 4 :2 12 21 12 :2 4 :2 11 20 11
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 11 20 11
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 11 20 11 :2 4 :2 10 1f 10
:2 4 :2 12 21 12 :2 4 c 10 f
c 20 :2 29 c :2 4 d 11 10
d 21 :2 2a d :2 4 14 1d 1c
:2 14 :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 10 1a 10 :2 4 :2 10 1a
10 :2 4 :2 11 1b 11 :2 4 :2 11 1b
11 :2 4 :2 12 1c 12 :2 4 :2 12 1c
12 :2 4 :2 15 24 15 :2 4 :2 c 16
c :2 4 :2 d 1c d :2 4 :2 d 1c
d :2 4 :2 d 1c d :2 4 :2 d 1c
d :2 4 :2 10 1f 10 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 56 5c 5f :2 56 6d
85 8 :2 6d d 10 :2 6d 1c 1f
:2 6d b e :2 6d 13 16 1f 27
:2 1f 3f :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 35 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 34
:2 16 :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 29 2c :2 6d b e
:2 6d 13 16 :2 6d 1b 1e :2 6d 29
2c :2 6d 31 34 :2 6d :2 7 4c :2 4
7 :2 11 23 :2 2d 39 3c 4e 50
51 :2 4e :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :2 7 54 :3 4 c 4 e
1a 27 36 40 50 5d 68 75
7 13 23 3a 45 4f 57 69
78 87 99 7 19 2c 34 3b
56 5e 65 81 8b 7 15 23
31 7 17 27 37 7 1a 23
c 1a 24 30 3c 4e 5d 6a
7 11 1d 2e 39 41 4a 52
7 15 24 2a 30 3c 7 13
20 2c 7 15 24 32 7 17
22 c d 21 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 66 69 :2 24 76
79 :2 24 7d 80 :2 24 8c 8f :2 24
97 9a :2 24 a6 a9 b0 b9 bc
:2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 11 1d 28 36 43 56 66
76 82 f 1d 2a 34 43 53
5f 6a 78 f 10 1d :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d :2 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 :2 1a a 38 :2 7 a
11 1f 22 :2 a 25 27 :2 25 a
18 a d :2 17 29 :2 33 3f 42
54 57 58 :2 54 :2 29 :3 d :2 13 18
24 66 69 :2 24 :2 d 5b :3 a 11
:2 1a a 2b :2 7 b 12 d 1a
:2 12 1e :2 27 :2 b a 40 3e :2 49
:2 3e a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 5e :3 7 15 7
11 :2 f 10 1d :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 35 a 13 1f :2 a 22 24
:2 22 14 :2 12 13 20 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
7c 7f :2 2a 83 86 :2 2a 92 95
:2 2a 9d a0 :2 2a ac af b6 bf
c2 :2 af :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 26 d :2 18 1f 2d :2 d
32 34 :2 32 d 1b d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 69 6c :2 27
:2 10 5e :3 d 14 :2 1d d 36 :2 a
26 :3 7 15 7 11 :2 f 11 13
f 20 24 2f 10 13 20 e
11 1b e 11 25 27 e 10
25 27 e 10 1a 23 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 a 13 1f :2 a
22 24 :2 22 a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 26 :2 7
a 13 1d :2 a 20 22 :2 20 d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8a
8d 96 9e :2 a7 :2 96 b8 :2 8d :2 24
:2 d 5b :2 a d :2 17 29 :2 33 3f
42 54 57 58 :2 54 :2 29 :3 d :2 13
18 24 66 69 :2 24 :2 d 5b :3 a
11 :2 1c 2f :2 38 48 :2 11 a 7
24 d 16 20 :2 d 26 23 2f
3e :2 26 :2 23 a 1a a d 16
20 :2 d 25 23 2e 38 :2 25 :2 23
d 1b d 10 :2 1a 2c :2 36 42
45 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 69 6c :2 27 :2 10 5e :3 d
14 :2 1d d a 3b 10 19 23
:2 10 28 26 31 3b :2 28 :2 26 d
1d d 3e 3b :3 a 1a :2 a 18
2a 38 3e 4c 58 21 2f :2 58
33 3c 47 :2 33 4b 54 61 :2 4b
:2 18 a 41 24 d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 76 79
:2 24 7d 80 :2 24 8a 8d 96 9e
:2 a7 :2 96 b8 :2 8d :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1c 2f
:2 38 48 :2 11 a :4 7 35 a 13
1d :2 a 20 22 :2 20 a 18 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1a a
24 :3 7 15 7 11 :2 f 10 1d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 4 a 13
1f :2 a 22 24 :2 22 14 :2 12 13
20 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a 7c 7f :2 2a 83
86 :2 2a 92 95 :2 2a 9d a0 :2 2a
ac af b6 bf c2 :2 af :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 26 d
:2 18 1f 2d :2 d 32 34 :2 32 d
1b d 10 :2 1a 2c :2 36 42 45
57 5a 5b :2 57 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 :2 10 5e :3 d 14
:2 1d d 36 :2 a 26 :2 7 11 21
2c 38 f 1a 27 35 f 10
1d e 1b :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 79 7c
:2 27 80 83 :2 27 8f 92 :2 27 9a
9d :2 27 a9 ac b3 bc bf :2 ac
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 4 a 11 1f 22 :2 a 25 27
:2 25 a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 2b :2 7 b 12
d 1a :2 12 1e :2 27 :2 b a 40
3e :2 49 :2 3e a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 5e :3 7
15 7 11 :2 f 11 f 10 24
e 23 e 18 21 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 69 6c :2 27
79 7c :2 27 80 83 :2 27 8f 92
:2 27 9a 9d :2 27 a9 ac b3 bc
bf :2 ac :2 27 :2 10 5f :2 d :2 a :4 16
:2 a 7 :3 4 a 13 1f :2 a 22
24 :2 22 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 :2 1a a 26 :3 7 19
22 2c :2 19 7 a 13 1d :2 a
23 20 2c 3b :2 23 :2 20 a 1a
a d 16 24 :2 d 29 27 32
3c :2 29 :2 27 10 19 26 :2 10 2b
29 :2 34 :2 29 4b 13 20 :2 4b 25
23 :2 2e :2 23 :3 10 1f 10 1a 20
2b 2f 18 21 18 19 26 17
2b 17 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 64 65 :2 61 :2 35 :3 19 :2 1f
24 30 72 75 :2 30 82 85 :2 30
89 8c :2 30 98 9b :2 30 a3 a6
:2 30 b2 b5 bc c5 c8 :2 b5 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :3 40
:4 14 :2 13 23 13 2d :2 10 13 1c
25 :2 13 28 2a :2 28 13 23 24
:2 23 :2 13 21 38 46 51 57 5d
63 28 34 42 55 :2 21 13 17
20 2c :2 17 2f 31 :2 2f 16 :4 3a
39 38 :2 16 20 2c 3c 1e 1f
2c 3d 51 5a 65 6d 74 :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6a
6b :2 67 :2 3b :3 1f :2 25 2a 36 78
7b :2 36 88 8b :2 36 8f 92 :2 36
9e a1 :2 36 a9 ac :2 36 b8 bb
c2 cb ce :2 bb :2 36 :2 1f 6e :2 1c
:2 19 :4 25 :2 19 16 :3 59 16 22 2b
39 :2 22 3c 3e 47 56 :2 3e :2 22
59 5b 64 6f :2 5b :2 22 :2 16 28
16 59 :3 13 20 27 30 3a :2 30
45 :2 27 48 4a 53 5d :2 53 67
:2 4a :2 27 26 6b 6d :2 26 :2 20 :2 13
21 2a 35 :2 21 38 3a 43 4c
:2 3a :2 21 13 16 1f 2b :2 16 31
2e 3a 44 :2 31 :2 2e 16 28 31
3c :2 28 3f 41 4a 56 :2 41 :2 28
59 5b 64 6e :2 5b :2 28 16 47
16 28 31 3c :2 28 16 :5 13 21
2d 3b 4c 52 60 1d 2d 38
:2 21 :2 13 26 2d 36 40 :2 36 4c
:2 2d 4f 51 5a 64 :2 5a 70 :2 51
:2 2d 2c 24 26 :2 2c :2 26 :2 13 21
:2 2a 31 3a 4b :2 31 4f :2 58 :2 21
:2 13 21 31 3f 45 51 5a 65
:2 51 69 1f 30 :2 69 :2 21 :2 13 23
:2 13 21 38 46 51 57 5d 63
28 34 42 55 :2 21 13 2c :2 10
40 10 20 21 :2 20 :2 10 1e 35
43 4e 54 5a 60 28 34 42
55 :2 1e 10 13 1c 29 :2 13 2f
2c 38 3f :2 2f :2 2c 16 :2 21 28
32 :2 16 3e 40 :2 3e 16 22 2b
39 :2 22 3c 3e 47 51 :2 3e :2 22
:2 16 28 16 19 22 30 :2 19 33
36 3f 4e :2 36 51 53 5c 63
:2 53 :2 36 35 :2 33 19 23 2c 3b
:2 23 3e 40 49 50 :2 40 :2 23 22
54 56 5f 6d :2 56 :2 22 19 23
20 1c 2a 33 3a 46 4f 1c
29 1c 2a 1c 22 1c 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6d 6e :2 6a :2 3e :3 22
:2 28 2d 39 7b 7e :2 39 8b 8e
:2 39 92 95 :2 39 a1 a4 :2 39 ac
af :2 39 bb be c5 ce d1 :2 be
:2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c 19
:3 67 19 2b :2 34 3b 44 54 :2 3b
58 :2 61 :2 2b 19 67 23 20 1c
2a 33 3a 46 4f 1c 29 1c
2a :2 1c 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6a 6d
6e :2 6a :2 3e :3 22 :2 28 2d 39 7b
7e :2 39 8b 8e :2 39 92 95 :2 39
a1 a4 :2 39 ac af :2 39 bb be
c5 ce d1 :2 be :2 39 :2 22 71 :2 1f
:2 1c :4 28 :2 1c 19 :7 16 42 19 22
30 :2 19 33 36 3f 4e :2 36 51
53 5c 63 :2 53 :2 36 35 :2 33 19
25 2e 35 :2 25 38 3a 43 4d
:2 3a :2 25 :2 19 2b 33 3c 46 :2 3c
55 :2 33 58 5a 63 6d :2 63 78
:2 5a :2 33 32 24 26 :2 32 31 30
32 :2 31 :2 2b 19 23 20 1c 2a
33 3a 46 4f 1c 29 1c 2a
22 36 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 21 1f :2 28 34 1f 2f
:2 1c :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6d 6e :2 6a
:2 3e :3 22 :2 28 2d 39 7b 7e :2 39
8b 8e :2 39 92 95 :2 39 a1 a4
:2 39 ac af :2 39 bb be c5 ce
d1 :2 be :2 39 :2 22 71 :2 1f :2 1c :4 28
:2 1c 19 :4 67 19 25 2e 3c :2 25
3f 41 4a 54 :2 41 :2 25 :2 19 2b
19 23 20 1c 2a 33 3a 46
4f 1c 29 1c 2a :2 1c 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6d 6e :2 6a :2 3e :3 22
:2 28 2d 39 7b 7e :2 39 8b 8e
:2 39 92 95 :2 39 a1 a4 :2 39 ac
af :2 39 bb be c5 ce d1 :2 be
:2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c 19
:7 16 :4 13 42 13 1f 28 36 :2 1f
39 3b 44 53 :2 3b :2 1f :2 13 25
13 1d 1a 16 24 2d 34 40
49 16 23 16 24 :2 16 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 67 68 :2 64 :2 38 :3 1c
:2 22 27 33 75 78 :2 33 85 88
:2 33 8c 8f :2 33 9b 9e :2 33 a6
a9 :2 33 b5 b8 bf c8 cb :2 b8
:2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16 13
:7 10 :4 14 :2 13 20 13 1d 21 :2 1b
1c 29 1a 28 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 67 68 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :3 32 :4 17 16 20 28 2f 50
5f :2 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6a 6b :2 67 :2 3b :3 1f :2 25 2a
36 78 7b :2 36 88 8b :2 36 8f
92 :2 36 9e a1 :2 36 a9 ac :2 36
b8 bb c2 cb ce :2 bb :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :3 2e 19
:2 24 2c 3e 49 :2 19 4d 4f :2 4d
19 29 19 51 :2 16 13 2e 19
22 2d :2 19 30 32 :2 30 16 24
:2 2d 34 3d 48 :2 34 4c :2 55 :2 24
23 16 20 2b 38 40 47 62
6d 72 :2 1e :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6a 6b :2 67 :2 3b :3 1f
:2 25 2a 36 78 7b :2 36 88 8b
:2 36 8f 92 :2 36 9e a1 :2 36 a9
ac :2 36 b8 bb c2 cb ce :2 bb
:2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19 16
:4 34 2e 20 2b 38 40 47 62
6d 72 :2 1e :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6a 6b :2 67 :2 3b :3 1f
:2 25 2a 36 78 7b :2 36 88 8b
:2 36 8f 92 :2 36 9e a1 :2 36 a9
ac :2 36 b8 bb c2 cb ce :2 bb
:2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19 16
:7 13 32 :2 10 :4 14 :2 13 21 31 3f
45 :2 21 13 31 16 1d 29 2c
:2 16 2f 31 :2 2f 16 24 34 42
48 :2 24 16 35 16 24 34 42
48 :2 24 16 :4 13 :5 10 1e :2 10 1e
2c 32 40 4a 56 61 6d 1f
28 39 :2 1f :2 1e 10 13 1c 28
:2 13 2b 2e :2 2b 13 21 13 16
:2 20 32 :2 3c 48 4b 5d 60 61
:2 5d :2 32 :3 16 :2 1c 21 2d 6f 72
:2 2d :2 16 64 :3 13 1a 23 2f :2 1a
13 30 :2 10 :5 d 19 d 3f d
1f 27 30 3a :2 30 49 :2 27 4c
4e 57 61 :2 57 6c :2 4e :2 27 26
24 :3 26 25 30 32 :2 25 :2 1f d
:5 a 18 2c 3a 45 4f 55 25
31 3b 49 25 34 44 50 25
31 3e 4c 25 33 42 55 25
31 3d 46 51 :2 3d 55 23 30
:2 55 :2 18 :2 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 1a 26 :2 11 a 7
3e d 16 2a :2 d 30 2d 39
49 :2 30 :2 2d 14 11 25 d 1b
24 2b 37 40 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a 7c 7f :2 2a 83
86 :2 2a 92 95 :2 2a 9d a0 :2 2a
ac af b6 bf c2 :2 af :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 4c 14
11 1f 28 2f 3b 44 13 20
11 1e d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
7c 7f :2 2a 83 86 :2 2a 92 95
:2 2a 9d a0 :2 2a ac af b6 bf
c2 :2 af :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 4c 7 4c 3e d 16
1f :2 d 25 22 2e 3f :2 25 :2 22
d 16 1f :2 d 22 24 :2 22 d
20 d 26 11 1a 23 :2 11 26
28 :2 26 10 2f 38 41 :2 2f 44
46 :2 44 2e :3 10 1e 10 13 :2 1d
2f :2 39 45 48 5a 5d 5e :2 5a
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
:2 13 61 :3 10 17 :2 20 10 51 :3 d
20 29 32 :2 20 d :4 a :4 e d
17 :2 15 16 2a :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 61 62 :2 5e :2 32
:3 16 :2 1c 21 2d 6f 72 :2 2d 7f
82 :2 2d 86 89 :2 2d 95 98 :2 2d
a0 a3 :2 2d af b2 b9 c2 c5
:2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10
d :3 2b 11 :2 1a 25 23 :2 2e :2 23
10 43 4c 5d :2 43 62 60 13
1f :2 62 :2 60 42 :3 10 1e 10 13
:2 1d 2f :2 39 45 48 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a :2 13 61 :3 10 17 :2 20 10 23
:2 d 2b :2 a d 16 23 :2 d 28
26 :2 31 :2 26 46 10 1d :2 46 22
20 :2 2b :2 20 :3 d 1d 1e :2 1d :2 d
1b 32 40 4b 51 57 5d 28
34 42 55 :2 1b d 11 1a 26
:2 11 29 2b :2 29 10 :4 34 33 32
:3 10 1e 33 41 4c 56 67 26
38 44 :2 1e 10 53 :3 d 1a 22
2b 3c :2 22 3f 41 4a 55 :2 41
:2 22 21 59 5b :2 21 20 65 67
:2 20 :2 1a :2 d 1b 27 35 46 4c
5a 1d 28 33 :2 1b :2 d 1b :2 24
2b 34 45 :2 2b 49 :2 52 :2 1b :2 d
1b 2b 39 3f 4b 4e :2 1b d
17 1f 26 41 49 50 70 76
15 2c 40 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 61 62 :2 5e :2 32 :3 16
:2 1c 21 2d 6f 72 :2 2d 7f 82
:2 2d 86 89 :2 2d 95 98 :2 2d a0
a3 :2 2d af b2 b9 c2 c5 :2 b2
:2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10 d
:3 3f d 1d :2 d 1b 32 40 4b
51 57 5d 28 34 42 55 :2 1b
d 3f d 1d 1e :2 1d :2 d 1b
32 40 4b 51 57 5d 28 34
42 55 :2 1b d 11 1a 26 :2 11
29 2b :2 29 10 :4 34 33 32 :3 10
1e 33 41 4c 56 67 26 38
44 :2 1e 10 53 :2 d :4 11 :2 10 1e
2e 3c 42 :2 1e 10 2e 13 1a
26 29 :2 13 2c 2e :2 2c 13 21
31 3f 45 :2 21 13 32 13 21
31 3f 45 :2 21 13 :4 10 :4 d :4 11
10 1a 25 32 3a 41 5c 67
6c :2 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 64 65 :2 61 :2 35 :3 19 :2 1f
24 30 72 75 :2 30 82 85 :2 30
89 8c :2 30 98 9b :2 30 a3 a6
:2 30 b2 b5 bc c5 c8 :2 b5 :2 30
:2 19 68 :2 16 :2 13 :4 1f :2 13 10 :3 2f
10 1c 25 2f :2 1c 32 34 3d
4c :2 34 :2 1c 10 2f :3 d 1a :2 d
1b :2 d 1b 29 2f 3d 47 53
5e 6a 1f 28 39 :2 1f :2 1b d
10 19 25 :2 10 28 2b :2 28 10
1e 10 13 :2 1d 2f :2 39 45 48
5a 5d 5e :2 5a :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a :2 13 61 :3 10 17
:2 20 10 2d 1a 17 13 1f :5 13
21 2a 31 3e 47 54 5d 19
2d 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :7 d :4 a 42 3e :2 7 :5 4 :2 d
19 23 :2 19 4 7 :2 11 23 :2 2d
39 3c 4e 52 53 :2 4e :2 23 :3 7
:2 d 12 1e 61 64 :2 1e 71 74
:2 1e 78 7b :2 1e 85 88 :2 91 :2 1e
:2 7 56 :3 4 b :2 14 4 :9 1 
1713
4
0 :2 1 :6 3 :4 4
:4 5 :4 6 :6 7 :6 8
2 :2 9 :2 1 :6 b
:6 c :6 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :5 19 :7 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :a 39 :a 3a :7 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :b 4c
:11 4d 4e :2 4d :2 4e
:2 4d :2 4e :2 4d :2 4f
:2 4d :9 4f :2 4d :2 50
:2 4d :9 50 :2 4d :2 51
:2 4d :9 51 :2 4d :2 52
:2 4d :2 52 :2 4d :2 52
:2 4d :2 52 :2 4d :2 53
:2 4d :2 53 :2 4d :2 53
:2 4d :2 53 :2 4d :2 53
:4 4d :3 4c :11 56 :b 57
:3 56 :3 5a :9 5d :b 5e
:a 5f :4 60 :4 61 :3 62
:8 63 :8 64 :6 65 :4 66
:4 67 :3 68 69 :2 6a
5d :5 6b 5c 6d
:5 6e :3 6d :2 6f :5 71
:11 72 :24 73 :3 72 :2 70
:6 6f 6c :3 4b :a 78
:9 7a :9 7b 7c :2 7d
7a :5 7e 79 80
:5 81 :3 80 :2 82 :5 84
:11 85 :24 86 :3 85 :2 83
:6 82 7f :3 78 :a 8b
:3 8c :11 8d :b 8e :3 8d
:5 90 :3 8b :a 92 :3 93
:11 94 :b 95 :3 94 :5 97
:3 92 :2 99 :2 9a :2 99
:3 9a :3 99 :6 9a :3 9b
:11 9c :b 9d :3 9c :5 9f
9a :2 99 :3 a2 a4
a5 a6 :2 a7 a4
:5 a8 a3 aa :5 ab
:3 aa :2 ac :5 ae :11 af
:24 b0 :3 af :2 ad :6 ac
a9 :3 78 :9 b5 b7
b8 b9 :2 ba b7
:5 bb b6 bd :5 be
:3 bd :2 bf :5 c1 :11 c2
:24 c3 :3 c2 :2 c0 :6 bf
bc :3 b5 :b c8 :3 c9
:11 ca :b cb :3 ca :5 cd
:3 c8 :3 b5 :3 d2 d4
d5 d6 :2 d8 :4 d9
:3 da :3 db :4 dc :4 dd
:4 de d4 :5 df d3
e1 :5 e2 :3 e1 :2 e3
:5 e5 :11 e6 :24 e7 :3 e6
:2 e4 :6 e3 e0 :3 78
:9 ec :3 ed :11 ee :b ef
:3 ee :5 f1 :3 ec :9 f4
:11 f5 :20 f6 :3 f5 :11 f8
:b f9 :3 f8 :b fb fc
f4 :d fc :3 fd :d fe
:3 ff :11 100 :b 101 :3 100
:5 103 104 fe :d 104
:3 105 104 :3 fe :3 108
:7 109 :2 10a :2 109 :a 10a
:3 109 fc f4 :11 10c
:20 10d :3 10c :11 10f :b 110
:3 10f :b 112 10b :3 f4
78 :9 115 :3 116 :11 117
:b 118 :3 117 :5 11a :3 115
:3 11d 11f 120 121
:2 122 11f :5 123 11e
125 :5 126 :3 125 :2 127
:5 129 :11 12a :24 12b :3 12a
:2 128 :6 127 124 :3 114
:9 130 132 133 134
:2 135 132 :5 136 131
138 :5 139 :3 138 :2 13a
:5 13c :11 13d :24 13e :3 13d
:2 13b :6 13a 137 :3 130
:b 143 :3 144 :11 145 :b 146
:3 145 :5 148 :3 143 :3 130
:4 14d :4 14e 14f :2 150
:2 151 14d :5 152 14c
154 :5 155 :3 154 :2 156
:5 158 :11 159 :24 15a :3 159
:2 157 :6 156 153 :3 114
:a 15f :3 160 :11 161 :b 162
:3 161 :5 164 :3 15f :2 166
:2 167 :2 166 :3 167 :3 166
:6 167 :3 168 :11 169 :b 16a
:3 169 :5 16c 167 :2 166
:3 170 172 173 174
176 177 :2 178 :2 179
:3 17a 172 :5 17b 171
17d :5 17e :3 17d :2 17f
:5 181 :11 182 :24 183 :3 182
:2 180 :6 17f 17c :3 114
:9 188 :3 189 :11 18a :b 18b
:3 18a :5 18d :3 188 :7 190
:d 191 :3 192 :d 194 :c 195
:2 196 :2 195 :6 196 :2 195
:3 197 :4 199 :2 19a 19b
:2 19c :2 19d 19e 199
:5 19f 198 1a1 :5 1a2
:3 1a1 :2 1a3 :5 1a5 :11 1a6
:24 1a7 :3 1a6 :2 1a4 :6 1a3
1a0 :3 196 :5 1ac :3 1ad
:3 1ac :9 1b0 :6 1b1 :8 1b2
:4 1b3 :3 1b2 :12 1b5 :3 1b7
1b8 :8 1b9 1b7 :5 1ba
1b6 1bc :5 1bd :3 1bc
:2 1be :5 1c0 :11 1c1 :24 1c2
:3 1c1 :2 1bf :6 1be 1bb
:3 1b5 :17 1c7 :3 1c8 :3 1b5
:1d 1cb :f 1cc :d 1cd :17 1ce
1cd :7 1d0 1cf :3 1cd
:7 1d3 :3 1d4 :3 1d3 :16 1d7
:2 1d8 :5 1d7 :f 1d9 :b 1da
:2 1db :5 1da :3 1dd :8 1de
:4 1df :3 1de :3 1b0 196
:6 1e2 :8 1e3 :4 1e4 :3 1e3
:d 1e6 :b 1e7 :f 1e8 :3 1e9
:16 1eb :18 1ec 1ee 1ef
:6 1f0 :2 1f1 :2 1f2 :2 1f3
1f4 :2 1f5 1ee :6 1f6
:5 1f7 1f6 :5 1f9 1f8
:3 1f6 1ed 1fc :5 1fd
:3 1fc :2 1fe :5 200 :11 201
:24 202 :3 201 :2 1ff :6 1fe
1fb :3 1eb :f 207 1eb
20a 20b :6 20c :2 20d
:2 20e 20f 210 :2 211
20a :6 212 :5 213 212
:5 215 214 :3 212 209
218 :5 219 :3 218 :2 21a
:5 21c :11 21d :24 21e :3 21d
:2 21b :6 21a 217 :4 208
:3 1eb 1e7 :16 224 :f 225
:16 226 :2 227 :3 226 :2 227
:5 226 22a 22b :6 22c
:2 22d :2 22e :2 22f 22a
:6 230 :5 231 230 :5 233
232 :3 230 229 236
:5 237 :3 236 :2 238 :5 23a
:11 23b :24 23c :3 23b :2 239
:6 238 235 :4 224 :f 241
:3 242 245 246 :6 247
:2 248 :2 249 24a 24b
:2 24c 245 :6 24d :5 24e
24d :5 250 24f :3 24d
244 253 :5 254 :3 253
:2 255 :5 257 :11 258 :24 259
:3 258 :2 256 :6 255 252
:4 240 :3 224 223 :3 1e7
1e6 :f 260 :3 261 264
265 :6 266 :2 267 :2 268
269 26a :2 26b 264
:6 26c :5 26d 26c :5 26f
26e :3 26c 263 272
:5 273 :3 272 :2 274 :5 276
:11 277 :24 278 :3 277 :2 275
:6 274 271 :4 25f :3 1e6
:5 27e :3 27f :2 281 282
283 :2 284 :2 285 281
:5 286 280 288 :5 289
:3 288 :2 28a :5 28c :11 28d
:24 28e :3 28d :2 28b :6 28a
287 :3 27e :5 293 :6 295
:5 296 294 298 :5 299
:3 298 :2 29a :5 29c :11 29d
:24 29e :3 29d :2 29b :6 29a
297 :3 293 :c 2a3 :3 2a4
:3 2a3 2a6 293 :9 2a6
:10 2a7 :8 2aa 2ab 2ac
2aa :5 2ad 2a9 2af
:5 2b0 :3 2af :2 2b1 :5 2b3
:11 2b4 :24 2b5 :3 2b4 :2 2b2
:6 2b1 2ae :4 2a6 293
:8 2bb 2bc 2bd 2bb
:5 2be 2ba 2c0 :5 2c1
:3 2c0 :2 2c2 :5 2c4 :11 2c5
:24 2c6 :3 2c5 :2 2c3 :6 2c2
2bf :4 2b9 :3 293 :3 27e
:5 2cd :8 2ce 2cd :a 2d0
:8 2d1 2d0 :8 2d3 2d2
:3 2d0 2cf :3 2cd :3 2d7
:9 2d8 :5 2d9 :3 2d8 :9 2db
:3 2dc :11 2dd :b 2de :3 2dd
:7 2e0 :3 2db 1e1 :3 195
:3 2e4 194 :16 2e6 :2 2e7
:3 2e6 :2 2e7 :5 2e6 2e5
:3 194 :7 2ea :4 2eb :4 2ec
:4 2ed :4 2ee :8 2ef :2 2f0
:2 2ef :3 2ea :3 2f2 :11 2f3
:b 2f4 :3 2f3 :7 2f6 2f7
191 :d 2f7 31a :2 31b
:6 31c :2 31d 31a :6 31e
:5 31f 31e :5 321 320
:3 31e 319 324 :5 325
:3 324 :2 326 :5 328 :11 329
:24 32a :3 329 :2 327 :6 326
323 :3 2f7 335 :6 336
:2 337 :2 338 335 :6 339
:5 33a 339 :5 33c 33b
:3 339 334 33f :5 340
:3 33f :2 341 :5 343 :11 344
:24 345 :3 344 :2 342 :6 341
33e :3 2f7 34b 2f7
191 :d 34b :9 34c :3 34d
34c :16 34f :3 350 :11 351
:b 352 :3 351 :5 354 :3 34f
:7 357 34e :3 34c :5 35a
35c 35d 35e :2 35f
35c :5 360 35b 362
:5 363 :3 362 :2 364 :5 366
:11 367 :24 368 :3 367 :2 365
:6 364 361 :3 35a :11 36e
:2 36f :7 36e :3 370 :11 371
:b 372 :3 371 :5 374 36f
:2 36e :3 35a :c 378 :2 379
:2 378 :6 379 :2 378 :6 37a
:8 37b :4 37c :3 37b :12 37e
:7 37f :3 380 :3 37f :3 37e
:1c 384 :7 385 :3 386 :3 385
:f 388 :a 389 :8 38c :3 38d
38c :5 38e 38b 390
:5 391 :3 390 :2 392 :5 394
:11 395 :24 396 :3 395 :2 393
:6 392 38f :3 379 :3 39b
:8 39c :4 39d :3 39c 379
:6 39f :8 3a0 :4 3a1 :3 3a0
:12 3a3 :7 3a4 :3 3a5 :3 3a4
:3 3a3 :5 3a9 :8 3aa 3a9
:a 3ac :8 3ad 3ac :8 3af
3ae :3 3ac 3ab :3 3a9
:5 3b3 :8 3b5 3b6 3b7
3b5 :5 3b8 3b4 3ba
:5 3bb :3 3ba :2 3bc :5 3be
:11 3bf :24 3c0 :3 3bf :2 3bd
:6 3bc 3b9 :3 3b3 :f 3c5
:3 3b3 :3 3ca :3 3cb :9 3cc
:5 3cd :3 3cc :9 3d0 :3 3d1
:11 3d2 :b 3d3 :3 3d2 :5 3d5
3d0 3d8 3d9 :2 3da
3db 3dc 3dd 3de
:8 3df :2 3e0 3d8 :6 3e1
:5 3e2 3e1 :5 3e4 3e3
:3 3e1 3d7 3e7 :5 3e8
:3 3e7 :2 3e9 :5 3eb :11 3ec
:24 3ed :3 3ec :2 3ea :6 3e9
3e6 :4 3d6 :3 3d0 39e
:3 378 34b :3 191 114
:3 78 :8 3f7 :11 3fe :19 3ff
:3 3fe :5 401 :2 4b :7 1

5086
4
:3 0 1 :3 0 2
:a 0 170e 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 5d 0 7
8 :3 0 7 :7 0
b a :3 0 8
:3 0 9 :7 0 f
e :3 0 d 8a
0 b 8 :3 0
a :7 0 13 12
:3 0 4 :3 0 5
:3 0 6 :3 0 b
:5 0 1 19 18
:3 0 16 b6 0
f 4 :3 0 5
:3 0 6 :3 0 c
:5 0 1 1f 1e
:3 0 d :3 0 8
:3 0 21 23 0
170e 2 24 :2 0
1a f2 0 18
8 :3 0 27 :7 0
7 :3 0 2b 28
29 170c 0 e
:6 0 8 :3 0 2d
:7 0 9 :3 0 31
2e 2f 170c 0
f :6 0 12 :2 0
1e 8 :3 0 33
:7 0 a :3 0 37
34 35 170c 0
10 :6 0 6 :3 0
12 :2 0 1c 39
3b :6 0 3e 3c
0 170c 0 11
:6 0 12 :2 0 22
6 :3 0 20 40
42 :6 0 45 43
0 170c 0 13
:6 0 12 :2 0 26
6 :3 0 24 47
49 :6 0 4c 4a
0 170c 0 14
:6 0 12 :2 0 2a
6 :3 0 28 4e
50 :6 0 53 51
0 170c 0 15
:6 0 30 1a2 0
2e 6 :3 0 2c
55 57 :6 0 5a
58 0 170c 0
16 :6 0 34 1d6
0 32 18 :3 0
5c :7 0 5f 5d
0 170c 0 17
:6 0 18 :3 0 61
:7 0 64 62 0
170c 0 19 :6 0
38 20a 0 36
1b :3 0 66 :7 0
69 67 0 170c
0 1a :6 0 1b
:3 0 6b :7 0 6e
6c 0 170c 0
1c :6 0 3c 23e
0 3a 18 :3 0
70 :7 0 73 71
0 170c 0 1d
:6 0 18 :3 0 75
:7 0 78 76 0
170c 0 1e :6 0
21 :2 0 40 18
:3 0 7a :7 0 7d
7b 0 170c 0
1f :6 0 6 :3 0
21 :2 0 3e 7f
81 :6 0 84 82
0 170c 0 20
:6 0 21 :2 0 44
6 :3 0 42 86
88 :6 0 8b 89
0 170c 0 22
:6 0 25 :2 0 48
6 :3 0 46 8d
8f :6 0 92 90
0 170c 0 23
:6 0 25 :2 0 4a
8 :3 0 94 :7 0
98 95 96 170c
0 24 :6 0 25
:2 0 4c 8 :3 0
9a :7 0 9e 9b
9c 170c 0 26
:6 0 25 :2 0 4e
8 :3 0 a0 :7 0
a4 a1 a2 170c
0 27 :6 0 25
:2 0 50 8 :3 0
a6 :7 0 aa a7
a8 170c 0 28
:6 0 25 :2 0 52
8 :3 0 ac :7 0
b0 ad ae 170c
0 29 :6 0 25
:2 0 54 8 :3 0
b2 :7 0 b6 b3
b4 170c 0 2a
:6 0 25 :2 0 56
8 :3 0 b8 :7 0
bc b9 ba 170c
0 2b :6 0 25
:2 0 58 8 :3 0
be :7 0 c2 bf
c0 170c 0 2c
:6 0 25 :2 0 5a
8 :3 0 c4 :7 0
c8 c5 c6 170c
0 2d :6 0 25
:2 0 5c 8 :3 0
ca :7 0 ce cb
cc 170c 0 2e
:6 0 25 :2 0 5e
8 :3 0 d0 :7 0
d4 d1 d2 170c
0 2f :6 0 25
:2 0 60 8 :3 0
d6 :7 0 da d7
d8 170c 0 30
:6 0 25 :2 0 62
8 :3 0 dc :7 0
e0 dd de 170c
0 31 :6 0 25
:2 0 64 8 :3 0
e2 :7 0 e6 e3
e4 170c 0 32
:6 0 25 :2 0 66
8 :3 0 e8 :7 0
ec e9 ea 170c
0 33 :6 0 25
:2 0 68 8 :3 0
ee :7 0 f2 ef
f0 170c 0 34
:6 0 25 :2 0 6a
8 :3 0 f4 :7 0
f8 f5 f6 170c
0 35 :6 0 25
:2 0 6c 8 :3 0
fa :7 0 fe fb
fc 170c 0 36
:6 0 25 :2 0 6e
8 :3 0 100 :7 0
104 101 102 170c
0 37 :6 0 25
:2 0 70 8 :3 0
106 :7 0 10a 107
108 170c 0 38
:6 0 25 :2 0 72
8 :3 0 10c :7 0
110 10d 10e 170c
0 39 :6 0 25
:2 0 74 8 :3 0
112 :7 0 116 113
114 170c 0 3a
:6 0 25 :2 0 76
8 :3 0 118 :7 0
11c 119 11a 170c
0 3b :6 0 25
:2 0 78 8 :3 0
11e :7 0 122 11f
120 170c 0 3c
:6 0 25 :2 0 7a
8 :3 0 124 :7 0
128 125 126 170c
0 3d :6 0 25
:2 0 7c 8 :3 0
12a :7 0 12e 12b
12c 170c 0 3e
:6 0 25 :2 0 7e
8 :3 0 130 :7 0
134 131 132 170c
0 3f :6 0 43
:2 0 80 8 :3 0
136 :7 0 13a 137
138 170c 0 40
:6 0 43 :2 0 84
42 :3 0 82 13c
13e 2 :5 0 44
:3 0 45 :3 0 140
141 0 144 13f
142 170c 0 41
:6 0 48 :2 0 88
42 :3 0 86 146
148 2 :5 0 44
:3 0 45 :3 0 14a
14b 0 14e 149
14c 170c 0 46
:6 0 25 :2 0 8c
6 :3 0 8a 150
152 :6 0 155 153
0 170c 0 47
:6 0 25 :2 0 8e
4a :3 0 157 :7 0
15b 158 159 170c
0 49 :6 0 25
:2 0 90 4a :3 0
15d :7 0 161 15e
15f 170c 0 4b
:6 0 25 :2 0 92
4a :3 0 163 :7 0
167 164 165 170c
0 4c :6 0 25
:2 0 94 4a :3 0
169 :7 0 16d 16a
16b 170c 0 4d
:6 0 25 :2 0 96
4a :3 0 16f :7 0
173 170 171 170c
0 4e :6 0 25
:2 0 98 4a :3 0
175 :7 0 179 176
177 170c 0 4f
:6 0 25 :2 0 9a
4a :3 0 17b :7 0
17f 17c 17d 170c
0 50 :6 0 25
:2 0 9c 4a :3 0
181 :7 0 185 182
183 170c 0 51
:6 0 25 :2 0 9e
8 :3 0 187 :7 0
18b 188 189 170c
0 52 :6 0 25
:2 0 a0 4a :3 0
18d :7 0 191 18e
18f 170c 0 53
:6 0 25 :2 0 a2
8 :3 0 193 :7 0
197 194 195 170c
0 54 :6 0 25
:2 0 a4 8 :3 0
199 :7 0 19d 19a
19b 170c 0 55
:6 0 25 :2 0 a6
8 :3 0 19f :7 0
1a3 1a0 1a1 170c
0 56 :6 0 25
:2 0 a8 8 :3 0
1a5 :7 0 1a9 1a6
1a7 170c 0 57
:6 0 1b0 1b1 0
aa 8 :3 0 1ab
:7 0 1af 1ac 1ad
170c 0 58 :6 0
59 :3 0 5a :3 0
59 :3 0 5b :3 0
1b3 1b4 0 2
:4 0 ac 1b5 1b7
1b2 1b9 1b8 :2 0
5c :3 0 5d :3 0
1bb 1bc 0 5e
:4 0 59 :3 0 5f
:3 0 1bf 1c0 0
2 :4 0 ae 1c1
1c3 60 :4 0 61
:2 0 62 :3 0 b0
1c6 1c8 :3 0 63
:4 0 61 :2 0 64
:4 0 b3 1cb 1cd
:3 0 61 :2 0 3
:3 0 b6 1cf 1d1
:3 0 61 :2 0 64
:4 0 b9 1d3 1d5
:3 0 61 :2 0 65
:4 0 bc 1d7 1d9
:3 0 61 :2 0 66
:3 0 67 :3 0 7
:3 0 bf 1dd 1df
68 :4 0 c1 1dc
1e2 c4 1db 1e4
:3 0 61 :2 0 65
:4 0 c7 1e6 1e8
:3 0 61 :2 0 66
:3 0 67 :3 0 9
:3 0 ca 1ec 1ee
68 :4 0 cc 1eb
1f1 cf 1ea 1f3
:3 0 61 :2 0 65
:4 0 d2 1f5 1f7
:3 0 61 :2 0 66
:3 0 67 :3 0 a
:3 0 d5 1fb 1fd
68 :4 0 d7 1fa
200 da 1f9 202
:3 0 61 :2 0 65
:4 0 dd 204 206
:3 0 61 :2 0 64
:4 0 e0 208 20a
:3 0 61 :2 0 b
:3 0 e3 20c 20e
:3 0 61 :2 0 64
:4 0 e6 210 212
:3 0 61 :2 0 65
:4 0 e9 214 216
:3 0 61 :2 0 64
:4 0 ec 218 21a
:3 0 61 :2 0 c
:3 0 ef 21c 21e
:3 0 61 :2 0 64
:4 0 f2 220 222
:3 0 61 :2 0 69
:4 0 f5 224 226
:3 0 f8 1bd 228
:2 0 22a fd 22b
1ba 22a 0 22c
ff 0 170a 59
:3 0 5a :3 0 22d
22e 0 59 :3 0
6a :3 0 230 231
0 21 :2 0 2
:4 0 6b :2 0 6c
:2 0 21 :2 0 101
236 238 :3 0 104
232 23a 22f 23c
23b :2 0 5c :3 0
6d :3 0 23e 23f
0 5e :4 0 6e
:4 0 61 :2 0 62
:3 0 108 243 245
:3 0 10b 240 247
:2 0 249 10e 24a
23d 249 0 24b
110 0 170a 11
:3 0 3 :3 0 24c
24d 0 170a 6f
:3 0 70 :3 0 71
:3 0 72 :3 0 73
:3 0 74 :3 0 75
:3 0 74 :3 0 76
:3 0 75 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7d
:3 0 7e :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 7f
:3 0 81 :3 0 82
:3 0 80 :3 0 83
:3 0 84 :3 0 85
:3 0 86 :3 0 87
:3 0 88 :3 0 89
:3 0 8a :3 0 8b
:3 0 8c :3 0 8d
:3 0 8e :3 0 8f
:3 0 14 :3 0 16
:3 0 22 :3 0 20
:3 0 1d :3 0 2c
:3 0 3f :3 0 3d
:3 0 29 :3 0 2e
:3 0 13 :3 0 35
:3 0 3a :3 0 38
:3 0 39 :3 0 2b
:3 0 1a :3 0 1c
:3 0 17 :3 0 19
:3 0 27 :3 0 28
:3 0 49 :3 0 4c
:3 0 4b :3 0 4d
:3 0 4e :3 0 50
:3 0 4f :3 0 51
:3 0 2a :3 0 15
:3 0 40 :3 0 90
:3 0 91 :3 0 11
:4 0 92 1 :8 0
2a2 93 :3 0 94
:3 0 29d 29e 0
95 :3 0 29f 2a0
0 2a2 112 2f5
96 :3 0 93 :3 0
94 :3 0 2a4 2a5
0 95 :3 0 2a6
2a7 0 2a9 115
2ab 117 2aa 2a9
:2 0 2f3 97 :3 0
93 :3 0 94 :3 0
2ae 2af 0 95
:3 0 2b0 2b1 0
2eb 59 :3 0 5a
:3 0 2b3 2b4 0
59 :3 0 6a :3 0
2b6 2b7 0 98
:2 0 2 :4 0 99
:2 0 6c :2 0 21
:2 0 119 2bc 2be
:3 0 11c 2b8 2c0
2b5 2c2 2c1 :2 0
5c :3 0 6d :3 0
2c4 2c5 0 5e
:4 0 9a :4 0 61
:2 0 62 :3 0 120
2c9 2cb :3 0 61
:2 0 9b :4 0 123
2cd 2cf :3 0 61
:2 0 9c :4 0 126
2d1 2d3 :3 0 61
:2 0 95 :3 0 129
2d5 2d7 :3 0 61
:2 0 9d :4 0 12c
2d9 2db :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 12f 2de 2e2
133 2dd 2e4 :3 0
136 2c6 2e6 :2 0
2e8 139 2e9 2c3
2e8 0 2ea 13b
0 2eb 13d 2ee
:3 0 2ee 0 2ee
2ed 2eb 2ec :6 0
2f0 2 :3 0 140
2f2 142 2f1 2f0
:2 0 2f3 144 :2 0
2f5 0 2f5 2f4
2a2 2f3 :6 0 170a
1 :3 0 93 :3 0
94 :3 0 2f7 2f8
0 93 :3 0 a0
:2 0 a1 :3 0 2fa
2fc 0 149 2fb
2fe :3 0 2ff :2 0
6f :3 0 a2 :3 0
a3 :3 0 74 :3 0
8d :3 0 a4 :3 0
a5 :3 0 a6 :3 0
a7 :3 0 14 :3 0
30 :3 0 29 :3 0
2c :3 0 2a :3 0
34 :3 0 2f :3 0
23 :3 0 58 :3 0
a8 :3 0 a9 :3 0
11 :4 0 aa 1
:8 0 31c 93 :3 0
94 :3 0 317 318
0 95 :3 0 319
31a 0 31c 14c
36f 96 :3 0 93
:3 0 94 :3 0 31e
31f 0 95 :3 0
320 321 0 323
14f 325 151 324
323 :2 0 36d 97
:3 0 93 :3 0 94
:3 0 328 329 0
95 :3 0 32a 32b
0 365 59 :3 0
5a :3 0 32d 32e
0 59 :3 0 6a
:3 0 330 331 0
98 :2 0 2 :4 0
ab :2 0 6c :2 0
21 :2 0 153 336
338 :3 0 156 332
33a 32f 33c 33b
:2 0 5c :3 0 6d
:3 0 33e 33f 0
5e :4 0 ac :4 0
61 :2 0 62 :3 0
15a 343 345 :3 0
61 :2 0 9b :4 0
15d 347 349 :3 0
61 :2 0 9c :4 0
160 34b 34d :3 0
61 :2 0 95 :3 0
163 34f 351 :3 0
61 :2 0 9d :4 0
166 353 355 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 169 358
35c 16d 357 35e
:3 0 170 340 360
:2 0 362 173 363
33d 362 0 364
175 0 365 177
368 :3 0 368 0
368 367 365 366
:6 0 36a 4 :3 0
17a 36c 17c 36b
36a :2 0 36d 17e
:2 0 36f 0 36f
36e 31c 36d :6 0
707 1 :3 0 93
:3 0 94 :3 0 371
372 0 93 :3 0
a0 :2 0 a1 :3 0
374 376 0 183
375 378 :3 0 379
:2 0 c :3 0 11
:3 0 37b 37c 0
3a2 59 :3 0 5a
:3 0 37e 37f 0
59 :3 0 6a :3 0
381 382 0 21
:2 0 2 :4 0 ad
:2 0 6c :2 0 21
:2 0 186 387 389
:3 0 189 383 38b
380 38d 38c :2 0
5c :3 0 6d :3 0
38f 390 0 5e
:4 0 ae :4 0 61
:2 0 62 :3 0 18d
394 396 :3 0 190
391 398 :2 0 39a
193 39b 38e 39a
0 39c 195 0
3a2 d :3 0 44
:3 0 af :3 0 39e
39f 0 3a0 :2 0
3a2 197 3a3 37a
3a2 0 3a4 19b
0 707 82 :3 0
23 :3 0 21 :2 0
21 :2 0 19d 3a5
3a9 a0 :2 0 b0
:4 0 1a3 3ab 3ad
:3 0 c :3 0 11
:3 0 3af 3b0 0
3d6 59 :3 0 5a
:3 0 3b2 3b3 0
59 :3 0 6a :3 0
3b5 3b6 0 21
:2 0 2 :4 0 b1
:2 0 6c :2 0 21
:2 0 1a6 3bb 3bd
:3 0 1a9 3b7 3bf
3b4 3c1 3c0 :2 0
5c :3 0 6d :3 0
3c3 3c4 0 5e
:4 0 b2 :4 0 61
:2 0 62 :3 0 1ad
3c8 3ca :3 0 1b0
3c5 3cc :2 0 3ce
1b3 3cf 3c2 3ce
0 3d0 1b5 0
3d6 d :3 0 44
:3 0 b3 :3 0 3d2
3d3 0 3d4 :2 0
3d6 1b7 3d7 3ae
3d6 0 3d8 1bb
0 707 b4 :3 0
66 :3 0 58 :3 0
25 :2 0 1bd 3da
3dd 44 :3 0 b5
:3 0 3df 3e0 0
1c0 3d9 3e2 3e3
:2 0 44 :3 0 a0
:2 0 b5 :3 0 3e5
3e7 0 1c5 3e6
3e9 :3 0 c :3 0
15 :3 0 3eb 3ec
0 412 59 :3 0
5a :3 0 3ee 3ef
0 59 :3 0 6a
:3 0 3f1 3f2 0
21 :2 0 2 :4 0
b6 :2 0 6c :2 0
21 :2 0 1c8 3f7
3f9 :3 0 1cb 3f3
3fb 3f0 3fd 3fc
:2 0 5c :3 0 6d
:3 0 3ff 400 0
5e :4 0 b7 :4 0
61 :2 0 62 :3 0
1cf 404 406 :3 0
1d2 401 408 :2 0
40a 1d5 40b 3fe
40a 0 40c 1d7
0 412 d :3 0
44 :3 0 b8 :3 0
40e 40f 0 410
:2 0 412 1d9 413
3ea 412 0 414
1dd 0 707 32
:3 0 25 :2 0 415
416 0 707 b9
:3 0 32 :3 0 ba
:3 0 6f :3 0 14
:4 0 bb 1 :8 0
423 93 :3 0 94
:3 0 41e 41f 0
95 :3 0 420 421
0 423 1df 476
96 :3 0 93 :3 0
94 :3 0 425 426
0 95 :3 0 427
428 0 42a 1e2
42c 1e4 42b 42a
:2 0 474 97 :3 0
93 :3 0 94 :3 0
42f 430 0 95
:3 0 431 432 0
46c 59 :3 0 5a
:3 0 434 435 0
59 :3 0 6a :3 0
437 438 0 98
:2 0 2 :4 0 bc
:2 0 6c :2 0 21
:2 0 1e6 43d 43f
:3 0 1e9 439 441
436 443 442 :2 0
5c :3 0 6d :3 0
445 446 0 5e
:4 0 bd :4 0 61
:2 0 62 :3 0 1ed
44a 44c :3 0 61
:2 0 9b :4 0 1f0
44e 450 :3 0 61
:2 0 9c :4 0 1f3
452 454 :3 0 61
:2 0 95 :3 0 1f6
456 458 :3 0 61
:2 0 9d :4 0 1f9
45a 45c :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 1fc 45f 463
200 45e 465 :3 0
203 447 467 :2 0
469 206 46a 444
469 0 46b 208
0 46c 20a 46f
:3 0 46f 0 46f
46e 46c 46d :6 0
471 6 :3 0 20d
473 20f 472 471
:2 0 474 211 :2 0
476 0 476 475
423 474 :6 0 707
1 :3 0 66 :3 0
32 :3 0 25 :2 0
214 478 47b be
:2 0 25 :2 0 219
47d 47f :3 0 a6
:3 0 23 :3 0 a8
:3 0 a9 :3 0 14
:4 0 bf 1 :8 0
48c 93 :3 0 94
:3 0 487 488 0
95 :3 0 489 48a
0 48c 21c 4df
96 :3 0 93 :3 0
94 :3 0 48e 48f
0 95 :3 0 490
491 0 493 21f
495 221 494 493
:2 0 4dd 97 :3 0
93 :3 0 94 :3 0
498 499 0 95
:3 0 49a 49b 0
4d5 59 :3 0 5a
:3 0 49d 49e 0
59 :3 0 6a :3 0
4a0 4a1 0 98
:2 0 2 :4 0 c0
:2 0 6c :2 0 21
:2 0 223 4a6 4a8
:3 0 226 4a2 4aa
49f 4ac 4ab :2 0
5c :3 0 6d :3 0
4ae 4af 0 5e
:4 0 c1 :4 0 61
:2 0 62 :3 0 22a
4b3 4b5 :3 0 61
:2 0 9b :4 0 22d
4b7 4b9 :3 0 61
:2 0 9c :4 0 230
4bb 4bd :3 0 61
:2 0 95 :3 0 233
4bf 4c1 :3 0 61
:2 0 9d :4 0 236
4c3 4c5 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 239 4c8 4cc
23d 4c7 4ce :3 0
240 4b0 4d0 :2 0
4d2 243 4d3 4ad
4d2 0 4d4 245
0 4d5 247 4d8
:3 0 4d8 0 4d8
4d7 4d5 4d6 :6 0
4da 8 :3 0 24a
4dc 24c 4db 4da
:2 0 4dd 24e :2 0
4df 0 4df 4de
48c 4dd :6 0 516
1 :3 0 c2 :3 0
c3 :3 0 4e1 4e2
0 23 :3 0 c4
:4 0 251 4e3 4e6
a0 :2 0 25 :2 0
256 4e8 4ea :3 0
c :3 0 14 :3 0
4ec 4ed 0 513
59 :3 0 5a :3 0
4ef 4f0 0 59
:3 0 6a :3 0 4f2
4f3 0 21 :2 0
2 :4 0 c5 :2 0
6c :2 0 21 :2 0
259 4f8 4fa :3 0
25c 4f4 4fc 4f1
4fe 4fd :2 0 5c
:3 0 6d :3 0 500
501 0 5e :4 0
c6 :4 0 61 :2 0
62 :3 0 260 505
507 :3 0 263 502
509 :2 0 50b 266
50c 4ff 50b 0
50d 268 0 513
d :3 0 44 :3 0
c7 :3 0 50f 510
0 511 :2 0 513
26a 514 4eb 513
0 515 26e 0
516 270 517 480
516 0 518 273
0 707 32 :3 0
25 :2 0 519 51a
0 707 c8 :3 0
32 :3 0 c9 :3 0
ca :3 0 a9 :3 0
90 :3 0 cb :3 0
cc :3 0 ca :3 0
cb :3 0 6f :3 0
14 :3 0 cb :3 0
8e :3 0 11 :3 0
cb :3 0 91 :3 0
ca :3 0 91 :3 0
ca :3 0 91 :3 0
ca :3 0 a9 :3 0
ca :3 0 cd :3 0
44 :3 0 ce :4 0
cf 1 :8 0 53d
93 :3 0 94 :3 0
538 539 0 95
:3 0 53a 53b 0
53d 275 590 96
:3 0 93 :3 0 94
:3 0 53f 540 0
95 :3 0 541 542
0 544 278 546
27a 545 544 :2 0
58e 97 :3 0 93
:3 0 94 :3 0 549
54a 0 95 :3 0
54b 54c 0 586
59 :3 0 5a :3 0
54e 54f 0 59
:3 0 6a :3 0 551
552 0 98 :2 0
2 :4 0 d0 :2 0
6c :2 0 21 :2 0
27c 557 559 :3 0
27f 553 55b 550
55d 55c :2 0 5c
:3 0 6d :3 0 55f
560 0 5e :4 0
d1 :4 0 61 :2 0
62 :3 0 283 564
566 :3 0 61 :2 0
9b :4 0 286 568
56a :3 0 61 :2 0
9c :4 0 289 56c
56e :3 0 61 :2 0
95 :3 0 28c 570
572 :3 0 61 :2 0
9d :4 0 28f 574
576 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
292 579 57d 296
578 57f :3 0 299
561 581 :2 0 583
29c 584 55e 583
0 585 29e 0
586 2a0 589 :3 0
589 0 589 588
586 587 :6 0 58b
a :3 0 2a3 58d
2a5 58c 58b :2 0
58e 2a7 :2 0 590
0 590 58f 53d
58e :6 0 707 1
:3 0 66 :3 0 32
:3 0 25 :2 0 2aa
592 595 be :2 0
25 :2 0 2af 597
599 :3 0 c :3 0
11 :3 0 59b 59c
0 5c2 59 :3 0
5a :3 0 59e 59f
0 59 :3 0 6a
:3 0 5a1 5a2 0
21 :2 0 2 :4 0
d2 :2 0 6c :2 0
21 :2 0 2b2 5a7
5a9 :3 0 2b5 5a3
5ab 5a0 5ad 5ac
:2 0 5c :3 0 6d
:3 0 5af 5b0 0
5e :4 0 d3 :4 0
61 :2 0 62 :3 0
2b9 5b4 5b6 :3 0
2bc 5b1 5b8 :2 0
5ba 2bf 5bb 5ae
5ba 0 5bc 2c1
0 5c2 d :3 0
44 :3 0 b8 :3 0
5be 5bf 0 5c0
:2 0 5c2 2c3 5c3
59a 5c2 0 5c4
2c7 0 707 66
:3 0 29 :3 0 25
:2 0 2c9 5c5 5c8
a0 :2 0 25 :2 0
2ce 5ca 5cc :3 0
59 :3 0 5a :3 0
5ce 5cf 0 59
:3 0 6a :3 0 5d1
5d2 0 d4 :2 0
2 :4 0 d5 :2 0
6c :2 0 21 :2 0
2d1 5d7 5d9 :3 0
2d4 5d3 5db 5d0
5dd 5dc :2 0 5c
:3 0 6d :3 0 5df
5e0 0 5e :4 0
d6 :4 0 61 :2 0
62 :3 0 2d8 5e4
5e6 :3 0 61 :2 0
9b :4 0 2db 5e8
5ea :3 0 61 :2 0
d7 :4 0 2de 5ec
5ee :3 0 61 :2 0
66 :3 0 67 :3 0
44 :3 0 d8 :3 0
5f3 5f4 0 2e1
5f2 5f6 68 :4 0
2e3 5f1 5f9 2e6
5f0 5fb :3 0 2e9
5e1 5fd :2 0 5ff
2ec 600 5de 5ff
0 601 2ee 0
62d 59 :3 0 5a
:3 0 602 603 0
59 :3 0 6a :3 0
605 606 0 21
:2 0 2 :4 0 d9
:2 0 6c :2 0 21
:2 0 2f0 60b 60d
:3 0 2f3 607 60f
604 611 610 :2 0
5c :3 0 6d :3 0
613 614 0 5e
:4 0 da :4 0 61
:2 0 62 :3 0 2f7
618 61a :3 0 2fa
615 61c :2 0 61e
2fd 61f 612 61e
0 620 2ff 0
62d d :3 0 db
:3 0 dc :3 0 622
623 0 44 :3 0
d8 :3 0 625 626
0 dd :3 0 301
624 629 62a :2 0
62d de :3 0 304
704 66 :3 0 f
:3 0 25 :2 0 308
62e 631 66 :3 0
df :2 0 2c :3 0
25 :2 0 30b 633
637 310 634 639
:3 0 3e :3 0 25
:2 0 63b 63c 0
6a3 66 :3 0 f
:3 0 25 :2 0 313
63e 641 66 :3 0
be :2 0 29 :3 0
25 :2 0 316 643
647 31b 644 649
:3 0 c :3 0 11
:3 0 64b 64c 0
673 59 :3 0 5a
:3 0 64e 64f 0
59 :3 0 6a :3 0
651 652 0 21
:2 0 2 :4 0 e0
:2 0 6c :2 0 21
:2 0 31e 657 659
:3 0 321 653 65b
650 65d 65c :2 0
5c :3 0 6d :3 0
65f 660 0 5e
:4 0 e1 :4 0 61
:2 0 62 :3 0 325
664 666 :3 0 328
661 668 :2 0 66a
32b 66b 65e 66a
0 66c 32d 0
673 d :3 0 44
:3 0 e2 :3 0 66e
66f 0 670 :2 0
673 de :3 0 32f
686 66 :3 0 f
:3 0 25 :2 0 333
674 677 66 :3 0
a0 :2 0 29 :3 0
25 :2 0 336 679
67d 33b 67a 67f
:3 0 3e :3 0 21
:2 0 681 682 0
684 33e 685 680
684 0 687 64a
673 0 687 340
0 6a3 2d :3 0
f :3 0 688 689
0 6a3 32 :3 0
e3 :3 0 14 :3 0
11 :3 0 2d :3 0
b :3 0 66 :3 0
3e :3 0 25 :2 0
343 691 694 66
:3 0 2f :3 0 25
:2 0 346 696 699
66 :3 0 30 :3 0
25 :2 0 349 69b
69e 34c 68c 6a0
68b 6a1 0 6a3
354 6a4 63a 6a3
0 706 59 :3 0
5a :3 0 6a5 6a6
0 59 :3 0 6a
:3 0 6a8 6a9 0
d4 :2 0 2 :4 0
e4 :2 0 6c :2 0
21 :2 0 359 6ae
6b0 :3 0 35c 6aa
6b2 6a7 6b4 6b3
:2 0 5c :3 0 6d
:3 0 6b6 6b7 0
5e :4 0 e5 :4 0
61 :2 0 62 :3 0
360 6bb 6bd :3 0
61 :2 0 9b :4 0
363 6bf 6c1 :3 0
61 :2 0 d7 :4 0
366 6c3 6c5 :3 0
61 :2 0 66 :3 0
67 :3 0 44 :3 0
d8 :3 0 6ca 6cb
0 369 6c9 6cd
68 :4 0 36b 6c8
6d0 36e 6c7 6d2
:3 0 371 6b8 6d4
:2 0 6d6 374 6d7
6b5 6d6 0 6d8
376 0 703 59
:3 0 5a :3 0 6d9
6da 0 59 :3 0
6a :3 0 6dc 6dd
0 21 :2 0 2
:4 0 e6 :2 0 6c
:2 0 21 :2 0 378
6e2 6e4 :3 0 37b
6de 6e6 6db 6e8
6e7 :2 0 5c :3 0
6d :3 0 6ea 6eb
0 5e :4 0 e7
:4 0 61 :2 0 62
:3 0 37f 6ef 6f1
:3 0 382 6ec 6f3
:2 0 6f5 385 6f6
6e9 6f5 0 6f7
387 0 703 d
:3 0 db :3 0 dc
:3 0 6f9 6fa 0
44 :3 0 d8 :3 0
6fc 6fd 0 dd
:3 0 389 6fb 700
701 :2 0 703 38c
705 5cd 62d 0
706 0 703 0
706 390 0 707
394 16cd 66 :3 0
29 :3 0 25 :2 0
3a0 708 70b a0
:2 0 25 :2 0 3a5
70d 70f :3 0 c
:3 0 11 :3 0 711
712 0 738 59
:3 0 5a :3 0 714
715 0 59 :3 0
6a :3 0 717 718
0 21 :2 0 2
:4 0 e8 :2 0 6c
:2 0 21 :2 0 3a8
71d 71f :3 0 3ab
719 721 716 723
722 :2 0 5c :3 0
6d :3 0 725 726
0 5e :4 0 e9
:4 0 61 :2 0 62
:3 0 3af 72a 72c
:3 0 3b2 727 72e
:2 0 730 3b5 731
724 730 0 732
3b7 0 738 d
:3 0 44 :3 0 d8
:3 0 734 735 0
736 :2 0 738 3b9
739 710 738 0
73a 3bd 0 16cc
32 :3 0 25 :2 0
73b 73c 0 16cc
b9 :3 0 32 :3 0
ba :3 0 6f :3 0
14 :4 0 bb 1
:8 0 749 93 :3 0
94 :3 0 744 745
0 95 :3 0 746
747 0 749 3bf
79c 96 :3 0 93
:3 0 94 :3 0 74b
74c 0 95 :3 0
74d 74e 0 750
3c2 752 3c4 751
750 :2 0 79a 97
:3 0 93 :3 0 94
:3 0 755 756 0
95 :3 0 757 758
0 792 59 :3 0
5a :3 0 75a 75b
0 59 :3 0 6a
:3 0 75d 75e 0
98 :2 0 2 :4 0
ea :2 0 6c :2 0
21 :2 0 3c6 763
765 :3 0 3c9 75f
767 75c 769 768
:2 0 5c :3 0 6d
:3 0 76b 76c 0
5e :4 0 eb :4 0
61 :2 0 62 :3 0
3cd 770 772 :3 0
61 :2 0 9b :4 0
3d0 774 776 :3 0
61 :2 0 9c :4 0
3d3 778 77a :3 0
61 :2 0 95 :3 0
3d6 77c 77e :3 0
61 :2 0 9d :4 0
3d9 780 782 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 3dc 785
789 3e0 784 78b
:3 0 3e3 76d 78d
:2 0 78f 3e6 790
76a 78f 0 791
3e8 0 792 3ea
795 :3 0 795 0
795 794 792 793
:6 0 797 c :3 0
3ed 799 3ef 798
797 :2 0 79a 3f1
:2 0 79c 0 79c
79b 749 79a :6 0
16cc 1 :3 0 66
:3 0 32 :3 0 25
:2 0 3f4 79e 7a1
be :2 0 25 :2 0
3f9 7a3 7a5 :3 0
a6 :3 0 23 :3 0
a8 :3 0 a9 :3 0
14 :4 0 bf 1
:8 0 7b2 93 :3 0
94 :3 0 7ad 7ae
0 95 :3 0 7af
7b0 0 7b2 3fc
805 96 :3 0 93
:3 0 94 :3 0 7b4
7b5 0 95 :3 0
7b6 7b7 0 7b9
3ff 7bb 401 7ba
7b9 :2 0 803 97
:3 0 93 :3 0 94
:3 0 7be 7bf 0
95 :3 0 7c0 7c1
0 7fb 59 :3 0
5a :3 0 7c3 7c4
0 59 :3 0 6a
:3 0 7c6 7c7 0
98 :2 0 2 :4 0
ec :2 0 6c :2 0
21 :2 0 403 7cc
7ce :3 0 406 7c8
7d0 7c5 7d2 7d1
:2 0 5c :3 0 6d
:3 0 7d4 7d5 0
5e :4 0 ed :4 0
61 :2 0 62 :3 0
40a 7d9 7db :3 0
61 :2 0 9b :4 0
40d 7dd 7df :3 0
61 :2 0 9c :4 0
410 7e1 7e3 :3 0
61 :2 0 95 :3 0
413 7e5 7e7 :3 0
61 :2 0 9d :4 0
416 7e9 7eb :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 419 7ee
7f2 41d 7ed 7f4
:3 0 420 7d6 7f6
:2 0 7f8 423 7f9
7d3 7f8 0 7fa
425 0 7fb 427
7fe :3 0 7fe 0
7fe 7fd 7fb 7fc
:6 0 800 e :3 0
42a 802 42c 801
800 :2 0 803 42e
:2 0 805 0 805
804 7b2 803 :6 0
83c 1 :3 0 c2
:3 0 c3 :3 0 807
808 0 23 :3 0
c4 :4 0 431 809
80c a0 :2 0 25
:2 0 436 80e 810
:3 0 c :3 0 14
:3 0 812 813 0
839 59 :3 0 5a
:3 0 815 816 0
59 :3 0 6a :3 0
818 819 0 21
:2 0 2 :4 0 ee
:2 0 6c :2 0 21
:2 0 439 81e 820
:3 0 43c 81a 822
817 824 823 :2 0
5c :3 0 6d :3 0
826 827 0 5e
:4 0 ef :4 0 61
:2 0 62 :3 0 440
82b 82d :3 0 443
828 82f :2 0 831
446 832 825 831
0 833 448 0
839 d :3 0 44
:3 0 c7 :3 0 835
836 0 837 :2 0
839 44a 83a 811
839 0 83b 44e
0 83c 450 83d
7a6 83c 0 83e
453 0 16cc a5
:3 0 a2 :3 0 a6
:3 0 a7 :3 0 2f
:3 0 30 :3 0 23
:3 0 58 :3 0 a8
:3 0 6f :3 0 14
:3 0 a9 :3 0 15
:4 0 f0 1 :8 0
852 93 :3 0 94
:3 0 84d 84e 0
95 :3 0 84f 850
0 852 455 8a5
96 :3 0 93 :3 0
94 :3 0 854 855
0 95 :3 0 856
857 0 859 458
85b 45a 85a 859
:2 0 8a3 97 :3 0
93 :3 0 94 :3 0
85e 85f 0 95
:3 0 860 861 0
89b 59 :3 0 5a
:3 0 863 864 0
59 :3 0 6a :3 0
866 867 0 98
:2 0 2 :4 0 f1
:2 0 6c :2 0 21
:2 0 45c 86c 86e
:3 0 45f 868 870
865 872 871 :2 0
5c :3 0 6d :3 0
874 875 0 5e
:4 0 f2 :4 0 61
:2 0 62 :3 0 463
879 87b :3 0 61
:2 0 9b :4 0 466
87d 87f :3 0 61
:2 0 9c :4 0 469
881 883 :3 0 61
:2 0 95 :3 0 46c
885 887 :3 0 61
:2 0 9d :4 0 46f
889 88b :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 472 88e 892
476 88d 894 :3 0
479 876 896 :2 0
898 47c 899 873
898 0 89a 47e
0 89b 480 89e
:3 0 89e 0 89e
89d 89b 89c :6 0
8a0 10 :3 0 483
8a2 485 8a1 8a0
:2 0 8a3 487 :2 0
8a5 0 8a5 8a4
852 8a3 :6 0 16cc
1 :3 0 82 :3 0
23 :3 0 21 :2 0
21 :2 0 48a 8a7
8ab a0 :2 0 b0
:4 0 490 8ad 8af
:3 0 c :3 0 11
:3 0 8b1 8b2 0
8d8 59 :3 0 5a
:3 0 8b4 8b5 0
59 :3 0 6a :3 0
8b7 8b8 0 21
:2 0 2 :4 0 f3
:2 0 6c :2 0 21
:2 0 493 8bd 8bf
:3 0 496 8b9 8c1
8b6 8c3 8c2 :2 0
5c :3 0 6d :3 0
8c5 8c6 0 5e
:4 0 f4 :4 0 61
:2 0 62 :3 0 49a
8ca 8cc :3 0 49d
8c7 8ce :2 0 8d0
4a0 8d1 8c4 8d0
0 8d2 4a2 0
8d8 d :3 0 44
:3 0 b3 :3 0 8d4
8d5 0 8d6 :2 0
8d8 4a4 8d9 8b0
8d8 0 8da 4a8
0 16cc b4 :3 0
66 :3 0 58 :3 0
25 :2 0 4aa 8dc
8df 44 :3 0 b5
:3 0 8e1 8e2 0
4ad 8db 8e4 8e5
:2 0 44 :3 0 a0
:2 0 b5 :3 0 8e7
8e9 0 4b2 8e8
8eb :3 0 c :3 0
15 :3 0 8ed 8ee
0 914 59 :3 0
5a :3 0 8f0 8f1
0 59 :3 0 6a
:3 0 8f3 8f4 0
21 :2 0 2 :4 0
f5 :2 0 6c :2 0
21 :2 0 4b5 8f9
8fb :3 0 4b8 8f5
8fd 8f2 8ff 8fe
:2 0 5c :3 0 6d
:3 0 901 902 0
5e :4 0 f6 :4 0
61 :2 0 62 :3 0
4bc 906 908 :3 0
4bf 903 90a :2 0
90c 4c2 90d 900
90c 0 90e 4c4
0 914 d :3 0
44 :3 0 b8 :3 0
910 911 0 912
:2 0 914 4c6 915
8ec 914 0 916
4ca 0 16cc 32
:3 0 25 :2 0 917
918 0 16cc c8
:3 0 32 :3 0 c9
:3 0 a9 :3 0 cc
:3 0 91 :3 0 11
:3 0 91 :3 0 a9
:3 0 cd :3 0 44
:3 0 ce :4 0 f7
1 :8 0 92c 93
:3 0 94 :3 0 927
928 0 95 :3 0
929 92a 0 92c
4cc 97f 96 :3 0
93 :3 0 94 :3 0
92e 92f 0 95
:3 0 930 931 0
933 4cf 935 4d1
934 933 :2 0 97d
97 :3 0 93 :3 0
94 :3 0 938 939
0 95 :3 0 93a
93b 0 975 59
:3 0 5a :3 0 93d
93e 0 59 :3 0
6a :3 0 940 941
0 98 :2 0 2
:4 0 f8 :2 0 6c
:2 0 21 :2 0 4d3
946 948 :3 0 4d6
942 94a 93f 94c
94b :2 0 5c :3 0
6d :3 0 94e 94f
0 5e :4 0 f9
:4 0 61 :2 0 62
:3 0 4da 953 955
:3 0 61 :2 0 9b
:4 0 4dd 957 959
:3 0 61 :2 0 9c
:4 0 4e0 95b 95d
:3 0 61 :2 0 95
:3 0 4e3 95f 961
:3 0 61 :2 0 9d
:4 0 4e6 963 965
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 4e9
968 96c 4ed 967
96e :3 0 4f0 950
970 :2 0 972 4f3
973 94d 972 0
974 4f5 0 975
4f7 978 :3 0 978
0 978 977 975
976 :6 0 97a 12
:3 0 4fa 97c 4fc
97b 97a :2 0 97d
4fe :2 0 97f 0
97f 97e 92c 97d
:6 0 16cc 1 :3 0
66 :3 0 32 :3 0
25 :2 0 501 981
984 be :2 0 25
:2 0 506 986 988
:3 0 c :3 0 11
:3 0 98a 98b 0
9b1 59 :3 0 5a
:3 0 98d 98e 0
59 :3 0 6a :3 0
990 991 0 21
:2 0 2 :4 0 fa
:2 0 6c :2 0 21
:2 0 509 996 998
:3 0 50c 992 99a
98f 99c 99b :2 0
5c :3 0 6d :3 0
99e 99f 0 5e
:4 0 fb :4 0 61
:2 0 62 :3 0 510
9a3 9a5 :3 0 513
9a0 9a7 :2 0 9a9
516 9aa 99d 9a9
0 9ab 518 0
9b1 d :3 0 44
:3 0 b8 :3 0 9ad
9ae 0 9af :2 0
9b1 51a 9b2 989
9b1 0 9b3 51e
0 16cc 3b :3 0
66 :3 0 29 :3 0
25 :2 0 520 9b5
9b8 9b4 9b9 0
16cc 66 :3 0 f
:3 0 25 :2 0 523
9bb 9be 66 :3 0
df :2 0 2c :3 0
25 :2 0 526 9c0
9c4 52b 9c1 9c6
:3 0 2d :3 0 f
:3 0 9c8 9c9 0
11ff 66 :3 0 2d
:3 0 25 :2 0 52e
9cb 9ce 66 :3 0
be :2 0 29 :3 0
25 :2 0 531 9d0
9d4 536 9d1 9d6
:3 0 66 :3 0 30
:3 0 25 :2 0 539
9d8 9db 44 :3 0
a0 :2 0 fc :3 0
9dd 9df 0 53e
9de 9e1 :3 0 66
:3 0 30 :3 0 25
:2 0 541 9e3 9e6
44 :3 0 a0 :2 0
fd :3 0 9e8 9ea
0 546 9e9 9ec
:3 0 9e2 9ee 9ed
:2 0 1f :4 0 9f0
9f1 0 bd5 c8
:3 0 fe :3 0 ff
:3 0 fe :3 0 26
:3 0 1f :3 0 100
:3 0 6f :3 0 14
:3 0 91 :3 0 11
:3 0 101 :4 0 102
1 :8 0 a05 93
:3 0 94 :3 0 a00
a01 0 95 :3 0
a02 a03 0 a05
549 a58 96 :3 0
93 :3 0 94 :3 0
a07 a08 0 95
:3 0 a09 a0a 0
a0c 54c a0e 54e
a0d a0c :2 0 a56
97 :3 0 93 :3 0
94 :3 0 a11 a12
0 95 :3 0 a13
a14 0 a4e 59
:3 0 5a :3 0 a16
a17 0 59 :3 0
6a :3 0 a19 a1a
0 98 :2 0 2
:4 0 103 :2 0 6c
:2 0 21 :2 0 550
a1f a21 :3 0 553
a1b a23 a18 a25
a24 :2 0 5c :3 0
6d :3 0 a27 a28
0 5e :4 0 104
:4 0 61 :2 0 62
:3 0 557 a2c a2e
:3 0 61 :2 0 9b
:4 0 55a a30 a32
:3 0 61 :2 0 9c
:4 0 55d a34 a36
:3 0 61 :2 0 95
:3 0 560 a38 a3a
:3 0 61 :2 0 9d
:4 0 563 a3c a3e
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 566
a41 a45 56a a40
a47 :3 0 56d a29
a49 :2 0 a4b 570
a4c a26 a4b 0
a4d 572 0 a4e
574 a51 :3 0 a51
0 a51 a50 a4e
a4f :6 0 a53 14
:3 0 577 a55 579
a54 a53 :2 0 a56
57b :2 0 a58 0
a58 a57 a05 a56
:6 0 bd5 1 :3 0
1f :3 0 105 :2 0
57e a5b a5c :3 0
a5d :2 0 1a :3 0
1f :3 0 a5f a60
0 a62 580 a63
a5e a62 0 a64
582 0 bd5 66
:3 0 26 :3 0 25
:2 0 584 a65 a68
be :2 0 25 :2 0
589 a6a a6c :3 0
31 :3 0 106 :2 0
21 :2 0 58c a6f
a71 :3 0 a6e a72
0 bd2 32 :3 0
107 :3 0 14 :3 0
15 :3 0 11 :3 0
17 :3 0 19 :3 0
49 :3 0 4b :3 0
31 :3 0 28 :3 0
27 :3 0 58e a75
a80 a74 a81 0
bd2 66 :3 0 2e
:3 0 25 :2 0 599
a83 a86 be :2 0
25 :2 0 59e a88
a8a :3 0 a8b :2 0
1d :3 0 105 :2 0
5a1 a8e a8f :3 0
a90 :2 0 a91 :2 0
a8c a93 a92 :2 0
108 :3 0 109 :3 0
33 :3 0 100 :3 0
6f :3 0 14 :3 0
91 :3 0 11 :3 0
fe :3 0 81 :3 0
82 :3 0 1d :4 0
10a 1 :8 0 aa7
93 :3 0 94 :3 0
aa2 aa3 0 95
:3 0 aa4 aa5 0
aa7 5a3 afa 96
:3 0 93 :3 0 94
:3 0 aa9 aaa 0
95 :3 0 aab aac
0 aae 5a6 ab0
5a8 aaf aae :2 0
af8 97 :3 0 93
:3 0 94 :3 0 ab3
ab4 0 95 :3 0
ab5 ab6 0 af0
59 :3 0 5a :3 0
ab8 ab9 0 59
:3 0 6a :3 0 abb
abc 0 98 :2 0
2 :4 0 10b :2 0
6c :2 0 21 :2 0
5aa ac1 ac3 :3 0
5ad abd ac5 aba
ac7 ac6 :2 0 5c
:3 0 6d :3 0 ac9
aca 0 5e :4 0
10c :4 0 61 :2 0
62 :3 0 5b1 ace
ad0 :3 0 61 :2 0
9b :4 0 5b4 ad2
ad4 :3 0 61 :2 0
9c :4 0 5b7 ad6
ad8 :3 0 61 :2 0
95 :3 0 5ba ada
adc :3 0 61 :2 0
9d :4 0 5bd ade
ae0 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
5c0 ae3 ae7 5c4
ae2 ae9 :3 0 5c7
acb aeb :2 0 aed
5ca aee ac8 aed
0 aef 5cc 0
af0 5ce af3 :3 0
af3 0 af3 af2
af0 af1 :6 0 af5
16 :3 0 5d1 af7
5d3 af6 af5 :2 0
af8 5d5 :2 0 afa
0 afa af9 aa7
af8 :6 0 b16 1
:3 0 29 :3 0 66
:3 0 2d :3 0 25
:2 0 5d8 afd b00
106 :2 0 66 :3 0
2c :3 0 25 :2 0
5db b03 b06 5de
b02 b08 :3 0 106
:2 0 66 :3 0 33
:3 0 25 :2 0 5e1
b0b b0e 5e4 b0a
b10 :3 0 afc b11
0 b16 2a :3 0
10d :2 0 b13 b14
0 b16 5e7 b17
a94 b16 0 b18
5eb 0 bd2 33
:3 0 10e :3 0 66
:3 0 10f :3 0 29
:3 0 5ed b1c b1e
25 :2 0 5ef b1b
b21 110 :2 0 66
:3 0 10f :3 0 26
:3 0 5f2 b25 b27
25 :2 0 5f4 b24
b2a 5f7 b23 b2c
:3 0 b2d :2 0 6c
:2 0 111 :2 0 5fa
b2f b31 :3 0 5fd
b1a b33 b19 b34
0 bd2 32 :3 0
66 :3 0 33 :3 0
25 :2 0 5ff b37
b3a 112 :2 0 66
:3 0 26 :3 0 25
:2 0 602 b3d b40
605 b3c b42 :3 0
b36 b43 0 bd2
66 :3 0 32 :3 0
25 :2 0 608 b45
b48 66 :3 0 df
:2 0 29 :3 0 25
:2 0 60b b4a b4e
610 b4b b50 :3 0
24 :3 0 66 :3 0
33 :3 0 25 :2 0
613 b53 b56 6c
:2 0 66 :3 0 32
:3 0 25 :2 0 616
b59 b5c 619 b58
b5e :3 0 106 :2 0
66 :3 0 29 :3 0
25 :2 0 61c b61
b64 61f b60 b66
:3 0 b52 b67 0
b69 622 b72 24
:3 0 66 :3 0 33
:3 0 25 :2 0 624
b6b b6e b6a b6f
0 b71 627 b73
b51 b69 0 b74
0 b71 0 b74
629 0 bd2 32
:3 0 113 :3 0 14
:3 0 13 :3 0 11
:3 0 1a :3 0 1c
:3 0 24 :3 0 33
:3 0 25 :2 0 62c
b76 b7f b75 b80
0 bd2 2b :3 0
10e :3 0 66 :3 0
10f :3 0 33 :3 0
635 b85 b87 25
:2 0 637 b84 b8a
110 :2 0 66 :3 0
10f :3 0 2f :3 0
63a b8e b90 25
:2 0 63c b8d b93
63f b8c b95 :3 0
b96 :2 0 112 :2 0
114 :2 0 642 b98
b9a :3 0 645 b83
b9c b82 b9d 0
bd2 32 :3 0 115
:3 0 116 :3 0 ba0
ba1 0 66 :3 0
2b :3 0 25 :2 0
647 ba3 ba6 44
:3 0 117 :3 0 ba8
ba9 0 64a ba2
bab b9f bac 0
bd2 32 :3 0 118
:3 0 14 :3 0 11
:3 0 32 :3 0 66
:3 0 2f :3 0 25
:2 0 64d bb3 bb6
66 :3 0 2b :3 0
25 :2 0 650 bb8
bbb 653 baf bbd
bae bbe 0 bd2
31 :3 0 25 :2 0
bc0 bc1 0 bd2
32 :3 0 107 :3 0
14 :3 0 15 :3 0
11 :3 0 17 :3 0
19 :3 0 49 :3 0
4b :3 0 31 :3 0
28 :3 0 27 :3 0
659 bc4 bcf bc3
bd0 0 bd2 664
bd3 a6d bd2 0
bd4 671 0 bd5
673 1182 31 :3 0
106 :2 0 21 :2 0
678 bd7 bd9 :3 0
bd6 bda 0 1181
32 :3 0 107 :3 0
14 :3 0 15 :3 0
11 :3 0 17 :3 0
19 :3 0 49 :3 0
4b :3 0 31 :3 0
28 :3 0 27 :3 0
67a bdd be8 bdc
be9 0 1181 66
:3 0 3f :3 0 25
:2 0 685 beb bee
66 :3 0 df :2 0
3d :3 0 25 :2 0
688 bf0 bf4 68d
bf1 bf6 :3 0 c2
:3 0 c3 :3 0 bf8
bf9 0 16 :3 0
b :3 0 690 bfa
bfd a0 :2 0 25
:2 0 695 bff c01
:3 0 29 :3 0 66
:3 0 2d :3 0 25
:2 0 698 c04 c07
106 :2 0 66 :3 0
29 :3 0 25 :2 0
69b c0a c0d 69e
c09 c0f :3 0 c03
c10 0 d4e 2a
:3 0 10d :2 0 c12
c13 0 d4e 66
:3 0 2d :3 0 25
:2 0 6a1 c15 c18
119 :2 0 66 :3 0
2c :3 0 25 :2 0
6a4 c1b c1e 6c
:2 0 66 :3 0 3d
:3 0 25 :2 0 6a7
c21 c24 6aa c20
c26 :3 0 c27 :2 0
6af c1a c29 :3 0
3d :3 0 66 :3 0
2c :3 0 25 :2 0
6b2 c2c c2f 6c
:2 0 66 :3 0 3d
:3 0 25 :2 0 6b5
c32 c35 6b8 c31
c37 :3 0 c38 :2 0
106 :2 0 66 :3 0
2d :3 0 25 :2 0
6bb c3b c3e 6be
c3a c40 :3 0 c2b
c41 0 cce 90
:3 0 11a :3 0 8f
:3 0 11b :3 0 116
:3 0 8f :3 0 44
:3 0 11c :3 0 75
:3 0 2d :3 0 74
:3 0 2d :3 0 76
:3 0 3d :3 0 8d
:3 0 91 :3 0 11
:4 0 11d 1 :8 0
c6a 11e :4 0 c55
:3 0 11f :3 0 a0
:2 0 6c3 c58 c59
:3 0 93 :3 0 94
:3 0 c5b c5c 0
25 :2 0 c5d c5e
0 c60 6c6 c67
93 :3 0 94 :3 0
c61 c62 0 120
:2 0 c63 c64 0
c66 6c8 c68 c5a
c60 0 c69 0
c66 0 c69 6ca
0 c6a 6cd cbd
96 :3 0 93 :3 0
94 :3 0 c6c c6d
0 95 :3 0 c6e
c6f 0 c71 6d0
c73 6d2 c72 c71
:2 0 cbb 97 :3 0
93 :3 0 94 :3 0
c76 c77 0 95
:3 0 c78 c79 0
cb3 59 :3 0 5a
:3 0 c7b c7c 0
59 :3 0 6a :3 0
c7e c7f 0 98
:2 0 2 :4 0 121
:2 0 6c :2 0 21
:2 0 6d4 c84 c86
:3 0 6d7 c80 c88
c7d c8a c89 :2 0
5c :3 0 6d :3 0
c8c c8d 0 5e
:4 0 122 :4 0 61
:2 0 62 :3 0 6db
c91 c93 :3 0 61
:2 0 9b :4 0 6de
c95 c97 :3 0 61
:2 0 9c :4 0 6e1
c99 c9b :3 0 61
:2 0 95 :3 0 6e4
c9d c9f :3 0 61
:2 0 9d :4 0 6e7
ca1 ca3 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 6ea ca6 caa
6ee ca5 cac :3 0
6f1 c8e cae :2 0
cb0 6f4 cb1 c8b
cb0 0 cb2 6f6
0 cb3 6f8 cb6
:3 0 cb6 0 cb6
cb5 cb3 cb4 :6 0
cb8 18 :3 0 6fb
cba 6fd cb9 cb8
:2 0 cbb 6ff :2 0
cbd 0 cbd cbc
c6a cbb :6 0 cce
1 :3 0 2a :3 0
115 :3 0 116 :3 0
cc0 cc1 0 66
:3 0 2a :3 0 25
:2 0 702 cc3 cc6
44 :3 0 117 :3 0
cc8 cc9 0 705
cc2 ccb cbf ccc
0 cce 708 d4b
90 :3 0 11a :3 0
8f :3 0 11b :3 0
116 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 2d :3 0
74 :3 0 2d :3 0
76 :3 0 8d :3 0
91 :3 0 11 :4 0
123 1 :8 0 cf5
11e :4 0 ce0 :3 0
11f :3 0 a0 :2 0
70e ce3 ce4 :3 0
93 :3 0 94 :3 0
ce6 ce7 0 25
:2 0 ce8 ce9 0
ceb 711 cf2 93
:3 0 94 :3 0 cec
ced 0 120 :2 0
cee cef 0 cf1
713 cf3 ce5 ceb
0 cf4 0 cf1
0 cf4 715 0
cf5 718 d48 96
:3 0 93 :3 0 94
:3 0 cf7 cf8 0
95 :3 0 cf9 cfa
0 cfc 71b cfe
71d cfd cfc :2 0
d46 97 :3 0 93
:3 0 94 :3 0 d01
d02 0 95 :3 0
d03 d04 0 d3e
59 :3 0 5a :3 0
d06 d07 0 59
:3 0 6a :3 0 d09
d0a 0 98 :2 0
2 :4 0 124 :2 0
6c :2 0 21 :2 0
71f d0f d11 :3 0
722 d0b d13 d08
d15 d14 :2 0 5c
:3 0 6d :3 0 d17
d18 0 5e :4 0
125 :4 0 61 :2 0
62 :3 0 726 d1c
d1e :3 0 61 :2 0
9b :4 0 729 d20
d22 :3 0 61 :2 0
9c :4 0 72c d24
d26 :3 0 61 :2 0
95 :3 0 72f d28
d2a :3 0 61 :2 0
9d :4 0 732 d2c
d2e :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
735 d31 d35 739
d30 d37 :3 0 73c
d19 d39 :2 0 d3b
73f d3c d16 d3b
0 d3d 741 0
d3e 743 d41 :3 0
d41 0 d41 d40
d3e d3f :6 0 d43
1a :3 0 746 d45
748 d44 d43 :2 0
d46 74a :2 0 d48
0 d48 d47 cf5
d46 :6 0 d4a 1
:3 0 74d d4c c2a
cce 0 d4d 0
d4a 0 d4d 74f
0 d4e 752 ea2
66 :3 0 2d :3 0
25 :2 0 756 d4f
d52 119 :2 0 66
:3 0 2c :3 0 25
:2 0 759 d55 d58
6c :2 0 66 :3 0
3d :3 0 25 :2 0
75c d5b d5e 75f
d5a d60 :3 0 d61
:2 0 764 d54 d63
:3 0 29 :3 0 66
:3 0 3d :3 0 25
:2 0 767 d66 d69
106 :2 0 66 :3 0
29 :3 0 25 :2 0
76a d6c d6f 76d
d6b d71 :3 0 d65
d72 0 e0f 2a
:3 0 10e :3 0 66
:3 0 10f :3 0 2d
:3 0 770 d77 d79
25 :2 0 772 d76
d7c 110 :2 0 66
:3 0 10f :3 0 29
:3 0 775 d80 d82
25 :2 0 777 d7f
d85 77a d7e d87
:3 0 d88 :2 0 112
:2 0 114 :2 0 77d
d8a d8c :3 0 d8d
:2 0 6c :2 0 111
:2 0 780 d8f d91
:3 0 783 d75 d93
d74 d94 0 e0f
90 :3 0 11a :3 0
8f :3 0 11b :3 0
116 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 3d :3 0
74 :3 0 2d :3 0
91 :3 0 11 :4 0
126 1 :8 0 dba
11e :4 0 da5 :3 0
11f :3 0 a0 :2 0
787 da8 da9 :3 0
93 :3 0 94 :3 0
dab dac 0 25
:2 0 dad dae 0
db0 78a db7 93
:3 0 94 :3 0 db1
db2 0 120 :2 0
db3 db4 0 db6
78c db8 daa db0
0 db9 0 db6
0 db9 78e 0
dba 791 e0d 96
:3 0 93 :3 0 94
:3 0 dbc dbd 0
95 :3 0 dbe dbf
0 dc1 794 dc3
796 dc2 dc1 :2 0
e0b 97 :3 0 93
:3 0 94 :3 0 dc6
dc7 0 95 :3 0
dc8 dc9 0 e03
59 :3 0 5a :3 0
dcb dcc 0 59
:3 0 6a :3 0 dce
dcf 0 98 :2 0
2 :4 0 127 :2 0
6c :2 0 21 :2 0
798 dd4 dd6 :3 0
79b dd0 dd8 dcd
dda dd9 :2 0 5c
:3 0 6d :3 0 ddc
ddd 0 5e :4 0
128 :4 0 61 :2 0
62 :3 0 79f de1
de3 :3 0 61 :2 0
9b :4 0 7a2 de5
de7 :3 0 61 :2 0
9c :4 0 7a5 de9
deb :3 0 61 :2 0
95 :3 0 7a8 ded
def :3 0 61 :2 0
9d :4 0 7ab df1
df3 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
7ae df6 dfa 7b2
df5 dfc :3 0 7b5
dde dfe :2 0 e00
7b8 e01 ddb e00
0 e02 7ba 0
e03 7bc e06 :3 0
e06 0 e06 e05
e03 e04 :6 0 e08
1c :3 0 7bf e0a
7c1 e09 e08 :2 0
e0b 7c3 :2 0 e0d
0 e0d e0c dba
e0b :6 0 e0f 1
:3 0 7c6 e9e 29
:3 0 66 :3 0 2d
:3 0 25 :2 0 7ca
e11 e14 106 :2 0
66 :3 0 29 :3 0
25 :2 0 7cd e17
e1a 7d0 e16 e1c
:3 0 e10 e1d 0
e9d 2a :3 0 10d
:2 0 e1f e20 0
e9d 90 :3 0 11a
:3 0 8f :3 0 11b
:3 0 116 :3 0 8f
:3 0 44 :3 0 11c
:3 0 75 :3 0 2d
:3 0 74 :3 0 2d
:3 0 76 :3 0 8d
:3 0 91 :3 0 11
:4 0 123 1 :8 0
e48 11e :4 0 e33
:3 0 11f :3 0 a0
:2 0 7d5 e36 e37
:3 0 93 :3 0 94
:3 0 e39 e3a 0
25 :2 0 e3b e3c
0 e3e 7d8 e45
93 :3 0 94 :3 0
e3f e40 0 120
:2 0 e41 e42 0
e44 7da e46 e38
e3e 0 e47 0
e44 0 e47 7dc
0 e48 7df e9b
96 :3 0 93 :3 0
94 :3 0 e4a e4b
0 95 :3 0 e4c
e4d 0 e4f 7e2
e51 7e4 e50 e4f
:2 0 e99 97 :3 0
93 :3 0 94 :3 0
e54 e55 0 95
:3 0 e56 e57 0
e91 59 :3 0 5a
:3 0 e59 e5a 0
59 :3 0 6a :3 0
e5c e5d 0 98
:2 0 2 :4 0 129
:2 0 6c :2 0 21
:2 0 7e6 e62 e64
:3 0 7e9 e5e e66
e5b e68 e67 :2 0
5c :3 0 6d :3 0
e6a e6b 0 5e
:4 0 12a :4 0 61
:2 0 62 :3 0 7ed
e6f e71 :3 0 61
:2 0 9b :4 0 7f0
e73 e75 :3 0 61
:2 0 9c :4 0 7f3
e77 e79 :3 0 61
:2 0 95 :3 0 7f6
e7b e7d :3 0 61
:2 0 9d :4 0 7f9
e7f e81 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 7fc e84 e88
800 e83 e8a :3 0
803 e6c e8c :2 0
e8e 806 e8f e69
e8e 0 e90 808
0 e91 80a e94
:3 0 e94 0 e94
e93 e91 e92 :6 0
e96 1e :3 0 80d
e98 80f e97 e96
:2 0 e99 811 :2 0
e9b 0 e9b e9a
e48 e99 :6 0 e9d
1 :3 0 814 e9f
d64 e0f 0 ea0
0 e9d 0 ea0
818 0 ea1 81b
ea3 c02 d4e 0
ea4 0 ea1 0
ea4 81d 0 ea5
820 f34 29 :3 0
66 :3 0 2d :3 0
25 :2 0 822 ea7
eaa 106 :2 0 66
:3 0 2c :3 0 25
:2 0 825 ead eb0
828 eac eb2 :3 0
ea6 eb3 0 f33
2a :3 0 10d :2 0
eb5 eb6 0 f33
90 :3 0 11a :3 0
8f :3 0 11b :3 0
116 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 2d :3 0
74 :3 0 2d :3 0
76 :3 0 8d :3 0
91 :3 0 11 :4 0
12b 1 :8 0 ede
11e :4 0 ec9 :3 0
11f :3 0 a0 :2 0
82d ecc ecd :3 0
93 :3 0 94 :3 0
ecf ed0 0 25
:2 0 ed1 ed2 0
ed4 830 edb 93
:3 0 94 :3 0 ed5
ed6 0 120 :2 0
ed7 ed8 0 eda
832 edc ece ed4
0 edd 0 eda
0 edd 834 0
ede 837 f31 96
:3 0 93 :3 0 94
:3 0 ee0 ee1 0
95 :3 0 ee2 ee3
0 ee5 83a ee7
83c ee6 ee5 :2 0
f2f 97 :3 0 93
:3 0 94 :3 0 eea
eeb 0 95 :3 0
eec eed 0 f27
59 :3 0 5a :3 0
eef ef0 0 59
:3 0 6a :3 0 ef2
ef3 0 98 :2 0
2 :4 0 12c :2 0
6c :2 0 21 :2 0
83e ef8 efa :3 0
841 ef4 efc ef1
efe efd :2 0 5c
:3 0 6d :3 0 f00
f01 0 5e :4 0
12d :4 0 61 :2 0
62 :3 0 845 f05
f07 :3 0 61 :2 0
9b :4 0 848 f09
f0b :3 0 61 :2 0
9c :4 0 84b f0d
f0f :3 0 61 :2 0
95 :3 0 84e f11
f13 :3 0 61 :2 0
9d :4 0 851 f15
f17 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
854 f1a f1e 858
f19 f20 :3 0 85b
f02 f22 :2 0 f24
85e f25 eff f24
0 f26 860 0
f27 862 f2a :3 0
f2a 0 f2a f29
f27 f28 :6 0 f2c
20 :3 0 865 f2e
867 f2d f2c :2 0
f2f 869 :2 0 f31
0 f31 f30 ede
f2f :6 0 f33 1
:3 0 86c f35 bf7
ea5 0 f36 0
f33 0 f36 870
0 1181 1d :3 0
105 :2 0 873 f38
f39 :3 0 f3a :2 0
1e :4 0 f3c f3d
0 1104 12e :3 0
12f :3 0 1e :3 0
130 :3 0 a9 :3 0
14 :3 0 70 :3 0
16 :4 0 131 1
:8 0 f4d 93 :3 0
94 :3 0 f48 f49
0 95 :3 0 f4a
f4b 0 f4d 875
fa0 96 :3 0 93
:3 0 94 :3 0 f4f
f50 0 95 :3 0
f51 f52 0 f54
878 f56 87a f55
f54 :2 0 f9e 97
:3 0 93 :3 0 94
:3 0 f59 f5a 0
95 :3 0 f5b f5c
0 f96 59 :3 0
5a :3 0 f5e f5f
0 59 :3 0 6a
:3 0 f61 f62 0
98 :2 0 2 :4 0
132 :2 0 6c :2 0
21 :2 0 87c f67
f69 :3 0 87f f63
f6b f60 f6d f6c
:2 0 5c :3 0 6d
:3 0 f6f f70 0
5e :4 0 133 :4 0
61 :2 0 62 :3 0
883 f74 f76 :3 0
61 :2 0 9b :4 0
886 f78 f7a :3 0
61 :2 0 9c :4 0
889 f7c f7e :3 0
61 :2 0 95 :3 0
88c f80 f82 :3 0
61 :2 0 9d :4 0
88f f84 f86 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 892 f89
f8d 896 f88 f8f
:3 0 899 f71 f91
:2 0 f93 89c f94
f6e f93 0 f95
89e 0 f96 8a0
f99 :3 0 f99 0
f99 f98 f96 f97
:6 0 f9b 22 :3 0
8a3 f9d 8a5 f9c
f9b :2 0 f9e 8a7
:2 0 fa0 0 fa0
f9f f4d f9e :6 0
1104 1 :3 0 1e
:3 0 105 :2 0 8aa
fa3 fa4 :3 0 fa5
:2 0 81 :3 0 82
:3 0 1e :3 0 1e
:3 0 c9 :4 0 134
1 :8 0 fb2 93
:3 0 94 :3 0 fad
fae 0 95 :3 0
faf fb0 0 fb2
8ac 1005 96 :3 0
93 :3 0 94 :3 0
fb4 fb5 0 95
:3 0 fb6 fb7 0
fb9 8af fbb 8b1
fba fb9 :2 0 1003
97 :3 0 93 :3 0
94 :3 0 fbe fbf
0 95 :3 0 fc0
fc1 0 ffb 59
:3 0 5a :3 0 fc3
fc4 0 59 :3 0
6a :3 0 fc6 fc7
0 98 :2 0 2
:4 0 135 :2 0 6c
:2 0 21 :2 0 8b3
fcc fce :3 0 8b6
fc8 fd0 fc5 fd2
fd1 :2 0 5c :3 0
6d :3 0 fd4 fd5
0 5e :4 0 136
:4 0 61 :2 0 62
:3 0 8ba fd9 fdb
:3 0 61 :2 0 9b
:4 0 8bd fdd fdf
:3 0 61 :2 0 9c
:4 0 8c0 fe1 fe3
:3 0 61 :2 0 95
:3 0 8c3 fe5 fe7
:3 0 61 :2 0 9d
:4 0 8c6 fe9 feb
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 8c9
fee ff2 8cd fed
ff4 :3 0 8d0 fd6
ff6 :2 0 ff8 8d3
ff9 fd3 ff8 0
ffa 8d5 0 ffb
8d7 ffe :3 0 ffe
0 ffe ffd ffb
ffc :6 0 1000 24
:3 0 8da 1002 8dc
1001 1000 :2 0 1003
8de :2 0 1005 0
1005 1004 fb2 1003
:6 0 101a 1 :3 0
c2 :3 0 137 :3 0
1007 1008 0 1d
:3 0 1e :3 0 138
:2 0 8e1 1009 100d
119 :2 0 25 :2 0
8e7 100f 1011 :3 0
1a :3 0 1e :3 0
1013 1014 0 1016
8ea 1017 1012 1016
0 1018 8ec 0
101a de :3 0 8ee
1101 66 :3 0 35
:3 0 25 :2 0 8f1
101b 101e be :2 0
25 :2 0 8f6 1020
1022 :3 0 35 :3 0
115 :3 0 116 :3 0
1025 1026 0 66
:3 0 35 :3 0 25
:2 0 8f9 1028 102b
44 :3 0 117 :3 0
102d 102e 0 8fc
1027 1030 1031 :2 0
1024 1032 0 1099
c2 :3 0 139 :3 0
81 :3 0 82 :3 0
1d :3 0 c2 :3 0
13a :3 0 1a :3 0
1a :3 0 c9 :4 0
13b 1 :8 0 1044
93 :3 0 94 :3 0
103f 1040 0 95
:3 0 1041 1042 0
1044 8ff 1097 96
:3 0 93 :3 0 94
:3 0 1046 1047 0
95 :3 0 1048 1049
0 104b 902 104d
904 104c 104b :2 0
1095 97 :3 0 93
:3 0 94 :3 0 1050
1051 0 95 :3 0
1052 1053 0 108d
59 :3 0 5a :3 0
1055 1056 0 59
:3 0 6a :3 0 1058
1059 0 98 :2 0
2 :4 0 13c :2 0
6c :2 0 21 :2 0
906 105e 1060 :3 0
909 105a 1062 1057
1064 1063 :2 0 5c
:3 0 6d :3 0 1066
1067 0 5e :4 0
13d :4 0 61 :2 0
62 :3 0 90d 106b
106d :3 0 61 :2 0
9b :4 0 910 106f
1071 :3 0 61 :2 0
9c :4 0 913 1073
1075 :3 0 61 :2 0
95 :3 0 916 1077
1079 :3 0 61 :2 0
9d :4 0 919 107b
107d :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
91c 1080 1084 920
107f 1086 :3 0 923
1068 1088 :2 0 108a
926 108b 1065 108a
0 108c 928 0
108d 92a 1090 :3 0
1090 0 1090 108f
108d 108e :6 0 1092
26 :3 0 92d 1094
92f 1093 1092 :2 0
1095 931 :2 0 1097
0 1097 1096 1044
1095 :6 0 1099 1
:3 0 934 109a 1023
1099 0 1103 c2
:3 0 139 :3 0 81
:3 0 82 :3 0 1d
:3 0 c2 :3 0 13a
:3 0 1a :3 0 1a
:3 0 c9 :4 0 13e
1 :8 0 10ab 93
:3 0 94 :3 0 10a6
10a7 0 95 :3 0
10a8 10a9 0 10ab
937 10fe 96 :3 0
93 :3 0 94 :3 0
10ad 10ae 0 95
:3 0 10af 10b0 0
10b2 93a 10b4 93c
10b3 10b2 :2 0 10fc
97 :3 0 93 :3 0
94 :3 0 10b7 10b8
0 95 :3 0 10b9
10ba 0 10f4 59
:3 0 5a :3 0 10bc
10bd 0 59 :3 0
6a :3 0 10bf 10c0
0 98 :2 0 2
:4 0 13f :2 0 6c
:2 0 21 :2 0 93e
10c5 10c7 :3 0 941
10c1 10c9 10be 10cb
10ca :2 0 5c :3 0
6d :3 0 10cd 10ce
0 5e :4 0 140
:4 0 61 :2 0 62
:3 0 945 10d2 10d4
:3 0 61 :2 0 9b
:4 0 948 10d6 10d8
:3 0 61 :2 0 9c
:4 0 94b 10da 10dc
:3 0 61 :2 0 95
:3 0 94e 10de 10e0
:3 0 61 :2 0 9d
:4 0 951 10e2 10e4
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 954
10e7 10eb 958 10e6
10ed :3 0 95b 10cf
10ef :2 0 10f1 95e
10f2 10cc 10f1 0
10f3 960 0 10f4
962 10f7 :3 0 10f7
0 10f7 10f6 10f4
10f5 :6 0 10f9 28
:3 0 965 10fb 967
10fa 10f9 :2 0 10fc
969 :2 0 10fe 0
10fe 10fd 10ab 10fc
:6 0 1100 1 :3 0
96c 1102 fa6 101a
0 1103 0 1100
0 1103 96e 0
1104 972 1105 f3b
1104 0 1106 976
0 1181 13 :3 0
105 :2 0 978 1108
1109 :3 0 110a :2 0
32 :3 0 141 :3 0
14 :3 0 11 :3 0
142 :2 0 97a 110d
1111 110c 1112 0
1114 97e 1135 82
:3 0 20 :3 0 21
:2 0 21 :2 0 980
1115 1119 a0 :2 0
142 :4 0 986 111b
111d :3 0 32 :3 0
141 :3 0 14 :3 0
11 :3 0 25 :2 0
989 1120 1124 111f
1125 0 1127 98d
1131 32 :3 0 141
:3 0 14 :3 0 11
:3 0 21 :2 0 98f
1129 112d 1128 112e
0 1130 993 1132
111e 1127 0 1133
0 1130 0 1133
995 0 1134 998
1136 110b 1114 0
1137 0 1134 0
1137 99a 0 1181
32 :3 0 142 :2 0
1138 1139 0 1181
32 :3 0 143 :3 0
11 :3 0 1a :3 0
29 :3 0 32 :3 0
35 :3 0 b :3 0
25 :2 0 66 :3 0
2b :3 0 25 :2 0
99d 1144 1147 9a0
113c 1149 113b 114a
0 1181 66 :3 0
32 :3 0 25 :2 0
9a9 114c 114f df
:2 0 25 :2 0 9ae
1151 1153 :3 0 c
:3 0 11 :3 0 1155
1156 0 117e 59
:3 0 5a :3 0 1158
1159 0 59 :3 0
6a :3 0 115b 115c
0 21 :2 0 2
:4 0 144 :2 0 6c
:2 0 21 :2 0 9b1
1161 1163 :3 0 9b4
115d 1165 115a 1167
1166 :2 0 5c :3 0
6d :3 0 1169 116a
0 5e :4 0 145
:4 0 61 :2 0 62
:3 0 9b8 116e 1170
:3 0 9bb 116b 1172
:2 0 1174 9be 1175
1168 1174 0 1176
9c0 0 117e d
:3 0 66 :3 0 32
:3 0 25 :2 0 9c2
1178 117b 117c :2 0
117e 9c5 117f 1154
117e 0 1180 9c9
0 1181 9cb 1183
9ef bd5 0 1184
0 1181 0 1184
9d4 0 1188 29
:3 0 2d :3 0 1185
1186 0 1188 9d7
11ac 2a :3 0 10e
:3 0 66 :3 0 10f
:3 0 2d :3 0 9da
118c 118e 25 :2 0
9dc 118b 1191 110
:2 0 66 :3 0 10f
:3 0 29 :3 0 9df
1195 1197 25 :2 0
9e1 1194 119a 9e4
1193 119c :3 0 119d
:2 0 112 :2 0 114
:2 0 9e7 119f 11a1
:3 0 11a2 :2 0 6c
:2 0 111 :2 0 9ea
11a4 11a6 :3 0 9ed
118a 11a8 1189 11a9
0 11ab 9ef 11ad
9d7 1188 0 11ae
0 11ab 0 11ae
9f1 0 11ff 32
:3 0 146 :3 0 14
:3 0 15 :3 0 16
:3 0 11 :3 0 1d
:3 0 20 :3 0 29
:3 0 2d :3 0 3b
:3 0 2c :3 0 2a
:3 0 49 :3 0 4c
:3 0 4b :3 0 4d
:3 0 4e :3 0 50
:3 0 4f :3 0 51
:3 0 28 :3 0 27
:3 0 2e :3 0 b
:3 0 66 :3 0 2f
:3 0 25 :2 0 9f4
11c8 11cb 66 :3 0
30 :3 0 25 :2 0
9f7 11cd 11d0 9fa
11b0 11d2 11af 11d3
0 11ff c :3 0
11 :3 0 11d5 11d6
0 11ff 59 :3 0
5a :3 0 11d8 11d9
0 59 :3 0 6a
:3 0 11db 11dc 0
21 :2 0 2 :4 0
147 :2 0 6c :2 0
21 :2 0 a14 11e1
11e3 :3 0 a17 11dd
11e5 11da 11e7 11e6
:2 0 5c :3 0 6d
:3 0 11e9 11ea 0
5e :4 0 148 :4 0
61 :2 0 62 :3 0
a1b 11ee 11f0 :3 0
a1e 11eb 11f2 :2 0
11f4 a21 11f5 11e8
11f4 0 11f6 a23
0 11ff d :3 0
66 :3 0 32 :3 0
25 :2 0 a25 11f8
11fb 11fc :2 0 11ff
de :3 0 a28 16ca
66 :3 0 e :3 0
25 :2 0 a2f 1200
1203 66 :3 0 df
:2 0 2a :3 0 25
:2 0 a32 1205 1209
a37 1206 120b :3 0
90 :3 0 8d :3 0
e :3 0 8f :3 0
11b :3 0 116 :3 0
8f :3 0 44 :3 0
149 :3 0 91 :3 0
11 :4 0 14a 1
:8 0 122e 11e :4 0
1219 :3 0 11f :3 0
a0 :2 0 a3c 121c
121d :3 0 93 :3 0
94 :3 0 121f 1220
0 25 :2 0 1221
1222 0 1224 a3f
122b 93 :3 0 94
:3 0 1225 1226 0
120 :2 0 1227 1228
0 122a a41 122c
121e 1224 0 122d
0 122a 0 122d
a43 0 122e a46
1281 96 :3 0 93
:3 0 94 :3 0 1230
1231 0 95 :3 0
1232 1233 0 1235
a49 1237 a4b 1236
1235 :2 0 127f 97
:3 0 93 :3 0 94
:3 0 123a 123b 0
95 :3 0 123c 123d
0 1277 59 :3 0
5a :3 0 123f 1240
0 59 :3 0 6a
:3 0 1242 1243 0
98 :2 0 2 :4 0
14b :2 0 6c :2 0
21 :2 0 a4d 1248
124a :3 0 a50 1244
124c 1241 124e 124d
:2 0 5c :3 0 6d
:3 0 1250 1251 0
5e :4 0 14c :4 0
61 :2 0 62 :3 0
a54 1255 1257 :3 0
61 :2 0 9b :4 0
a57 1259 125b :3 0
61 :2 0 9c :4 0
a5a 125d 125f :3 0
61 :2 0 95 :3 0
a5d 1261 1263 :3 0
61 :2 0 9d :4 0
a60 1265 1267 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 a63 126a
126e a67 1269 1270
:3 0 a6a 1252 1272
:2 0 1274 a6d 1275
124f 1274 0 1276
a6f 0 1277 a71
127a :3 0 127a 0
127a 1279 1277 1278
:6 0 127c 2a :3 0
a74 127e a76 127d
127c :2 0 127f a78
:2 0 1281 0 1281
1280 122e 127f :6 0
12fa 1 :3 0 a8
:3 0 8f :3 0 11b
:3 0 116 :3 0 8f
:3 0 44 :3 0 149
:3 0 6f :3 0 14
:3 0 a9 :3 0 15
:4 0 14d 1 :8 0
12a4 11e :4 0 128f
:3 0 11f :3 0 a0
:2 0 a7d 1292 1293
:3 0 93 :3 0 94
:3 0 1295 1296 0
25 :2 0 1297 1298
0 129a a80 12a1
93 :3 0 94 :3 0
129b 129c 0 120
:2 0 129d 129e 0
12a0 a82 12a2 1294
129a 0 12a3 0
12a0 0 12a3 a84
0 12a4 a87 12f7
96 :3 0 93 :3 0
94 :3 0 12a6 12a7
0 95 :3 0 12a8
12a9 0 12ab a8a
12ad a8c 12ac 12ab
:2 0 12f5 97 :3 0
93 :3 0 94 :3 0
12b0 12b1 0 95
:3 0 12b2 12b3 0
12ed 59 :3 0 5a
:3 0 12b5 12b6 0
59 :3 0 6a :3 0
12b8 12b9 0 98
:2 0 2 :4 0 14e
:2 0 6c :2 0 21
:2 0 a8e 12be 12c0
:3 0 a91 12ba 12c2
12b7 12c4 12c3 :2 0
5c :3 0 6d :3 0
12c6 12c7 0 5e
:4 0 14f :4 0 61
:2 0 62 :3 0 a95
12cb 12cd :3 0 61
:2 0 9b :4 0 a98
12cf 12d1 :3 0 61
:2 0 9c :4 0 a9b
12d3 12d5 :3 0 61
:2 0 95 :3 0 a9e
12d7 12d9 :3 0 61
:2 0 9d :4 0 aa1
12db 12dd :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 aa4 12e0 12e4
aa8 12df 12e6 :3 0
aab 12c8 12e8 :2 0
12ea aae 12eb 12c5
12ea 0 12ec ab0
0 12ed ab2 12f0
:3 0 12f0 0 12f0
12ef 12ed 12ee :6 0
12f2 2c :3 0 ab5
12f4 ab7 12f3 12f2
:2 0 12f5 ab9 :2 0
12f7 0 12f7 12f6
12a4 12f5 :6 0 12fa
1 :3 0 de :3 0
abc 12fb 120c 12fa
0 16cb 66 :3 0
10 :3 0 25 :2 0
abf 12fc 12ff 66
:3 0 df :2 0 2b
:3 0 25 :2 0 ac2
1301 1305 ac7 1302
1307 :3 0 66 :3 0
10 :3 0 25 :2 0
aca 1309 130c a0
:2 0 25 :2 0 acf
130e 1310 :3 0 2b
:3 0 120 :2 0 1312
1313 0 1315 ad2
135e 66 :3 0 10
:3 0 25 :2 0 ad4
1316 1319 119 :2 0
21 :2 0 ad9 131b
131d :3 0 131e :2 0
66 :3 0 10 :3 0
25 :2 0 adc 1320
1323 be :2 0 150
:2 0 ae1 1325 1327
:3 0 1328 :2 0 131f
132a 1329 :2 0 c
:3 0 11 :3 0 132c
132d 0 1353 59
:3 0 5a :3 0 132f
1330 0 59 :3 0
6a :3 0 1332 1333
0 21 :2 0 2
:4 0 151 :2 0 6c
:2 0 21 :2 0 ae4
1338 133a :3 0 ae7
1334 133c 1331 133e
133d :2 0 5c :3 0
6d :3 0 1340 1341
0 5e :4 0 152
:4 0 61 :2 0 62
:3 0 aeb 1345 1347
:3 0 aee 1342 1349
:2 0 134b af1 134c
133f 134b 0 134d
af3 0 1353 d
:3 0 44 :3 0 d8
:3 0 134f 1350 0
1351 :2 0 1353 af5
1354 132b 1353 0
1355 af9 0 135d
2b :3 0 66 :3 0
10 :3 0 25 :2 0
afb 1357 135a 1356
135b 0 135d afe
135f 1311 1315 0
1360 0 135d 0
1360 b01 0 16c8
13 :3 0 105 :2 0
b04 1362 1363 :3 0
1364 :2 0 7e :3 0
32 :3 0 90 :3 0
91 :3 0 13 :4 0
153 1 :8 0 1371
93 :3 0 94 :3 0
136c 136d 0 95
:3 0 136e 136f 0
1371 b06 13c4 96
:3 0 93 :3 0 94
:3 0 1373 1374 0
95 :3 0 1375 1376
0 1378 b09 137a
b0b 1379 1378 :2 0
13c2 97 :3 0 93
:3 0 94 :3 0 137d
137e 0 95 :3 0
137f 1380 0 13ba
59 :3 0 5a :3 0
1382 1383 0 59
:3 0 6a :3 0 1385
1386 0 98 :2 0
2 :4 0 154 :2 0
6c :2 0 21 :2 0
b0d 138b 138d :3 0
b10 1387 138f 1384
1391 1390 :2 0 5c
:3 0 6d :3 0 1393
1394 0 5e :4 0
155 :4 0 61 :2 0
62 :3 0 b14 1398
139a :3 0 61 :2 0
9b :4 0 b17 139c
139e :3 0 61 :2 0
9c :4 0 b1a 13a0
13a2 :3 0 61 :2 0
95 :3 0 b1d 13a4
13a6 :3 0 61 :2 0
9d :4 0 b20 13a8
13aa :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
b23 13ad 13b1 b27
13ac 13b3 :3 0 b2a
1395 13b5 :2 0 13b7
b2d 13b8 1392 13b7
0 13b9 b2f 0
13ba b31 13bd :3 0
13bd 0 13bd 13bc
13ba 13bb :6 0 13bf
2e :3 0 b34 13c1
b36 13c0 13bf :2 0
13c2 b38 :2 0 13c4
0 13c4 13c3 1371
13c2 :6 0 140a 1
:3 0 93 :3 0 94
:3 0 13c6 13c7 0
93 :3 0 a0 :2 0
156 :3 0 13c9 13cb
0 b3d 13ca 13cd
:3 0 13ce :2 0 66
:3 0 2b :3 0 25
:2 0 b40 13d0 13d3
66 :3 0 be :2 0
32 :3 0 25 :2 0
b43 13d5 13d9 b48
13d6 13db :3 0 13dc
:2 0 13cf 13de 13dd
:2 0 c :3 0 13
:3 0 13e0 13e1 0
1407 59 :3 0 5a
:3 0 13e3 13e4 0
59 :3 0 6a :3 0
13e6 13e7 0 21
:2 0 2 :4 0 157
:2 0 6c :2 0 21
:2 0 b4b 13ec 13ee
:3 0 b4e 13e8 13f0
13e5 13f2 13f1 :2 0
5c :3 0 6d :3 0
13f4 13f5 0 5e
:4 0 158 :4 0 61
:2 0 62 :3 0 b52
13f9 13fb :3 0 b55
13f6 13fd :2 0 13ff
b58 1400 13f3 13ff
0 1401 b5a 0
1407 d :3 0 44
:3 0 159 :3 0 1403
1404 0 1405 :2 0
1407 b5c 1408 13df
1407 0 1409 b60
0 140a b62 140b
1365 140a 0 140c
b65 0 16c8 66
:3 0 30 :3 0 25
:2 0 b67 140d 1410
44 :3 0 a0 :2 0
fd :3 0 1412 1414
0 b6c 1413 1416
:3 0 66 :3 0 30
:3 0 25 :2 0 b6f
1418 141b 44 :3 0
a0 :2 0 fc :3 0
141d 141f 0 b74
141e 1421 :3 0 1417
1423 1422 :2 0 31
:3 0 106 :2 0 21
:2 0 b77 1426 1428
:3 0 1425 1429 0
1516 32 :3 0 107
:3 0 14 :3 0 15
:3 0 11 :3 0 17
:3 0 19 :3 0 49
:3 0 4b :3 0 31
:3 0 28 :3 0 27
:3 0 b79 142c 1437
142b 1438 0 1516
66 :3 0 2e :3 0
25 :2 0 b84 143a
143d be :2 0 25
:2 0 b89 143f 1441
:3 0 1442 :2 0 1d
:3 0 105 :2 0 b8c
1445 1446 :3 0 1447
:2 0 1448 :2 0 1443
144a 1449 :2 0 32
:3 0 15a :3 0 14
:3 0 15 :3 0 16
:3 0 13 :3 0 11
:3 0 1d :3 0 2e
:3 0 25 :2 0 b8e
144d 1456 144c 1457
0 1459 b97 145a
144b 1459 0 145b
b99 0 1516 33
:3 0 10e :3 0 66
:3 0 2b :3 0 25
:2 0 b9b 145e 1461
112 :2 0 66 :3 0
2f :3 0 25 :2 0
b9e 1464 1467 ba1
1463 1469 :3 0 146a
:2 0 110 :2 0 114
:2 0 ba4 146c 146e
:3 0 146f :2 0 6c
:2 0 111 :2 0 ba7
1471 1473 :3 0 baa
145d 1475 145c 1476
0 1516 32 :3 0
113 :3 0 14 :3 0
13 :3 0 11 :3 0
1a :3 0 1c :3 0
33 :3 0 33 :3 0
25 :2 0 bac 1479
1482 1478 1483 0
1516 32 :3 0 115
:3 0 116 :3 0 1486
1487 0 66 :3 0
2b :3 0 25 :2 0
bb5 1489 148c 44
:3 0 15b :3 0 148e
148f 0 bb8 1488
1491 1485 1492 0
1516 32 :3 0 118
:3 0 14 :3 0 11
:3 0 32 :3 0 25
:2 0 25 :2 0 bbb
1495 149b 1494 149c
0 1516 81 :3 0
82 :3 0 7f :3 0
81 :3 0 82 :3 0
80 :3 0 17 :3 0
19 :3 0 90 :3 0
91 :3 0 11 :4 0
15c 1 :8 0 14af
93 :3 0 94 :3 0
14aa 14ab 0 95
:3 0 14ac 14ad 0
14af bc1 1502 96
:3 0 93 :3 0 94
:3 0 14b1 14b2 0
95 :3 0 14b3 14b4
0 14b6 bc4 14b8
bc6 14b7 14b6 :2 0
1500 97 :3 0 93
:3 0 94 :3 0 14bb
14bc 0 95 :3 0
14bd 14be 0 14f8
59 :3 0 5a :3 0
14c0 14c1 0 59
:3 0 6a :3 0 14c3
14c4 0 98 :2 0
2 :4 0 15d :2 0
6c :2 0 21 :2 0
bc8 14c9 14cb :3 0
bcb 14c5 14cd 14c2
14cf 14ce :2 0 5c
:3 0 6d :3 0 14d1
14d2 0 5e :4 0
15e :4 0 61 :2 0
62 :3 0 bcf 14d6
14d8 :3 0 61 :2 0
9b :4 0 bd2 14da
14dc :3 0 61 :2 0
9c :4 0 bd5 14de
14e0 :3 0 61 :2 0
95 :3 0 bd8 14e2
14e4 :3 0 61 :2 0
9d :4 0 bdb 14e6
14e8 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
bde 14eb 14ef be2
14ea 14f1 :3 0 be5
14d3 14f3 :2 0 14f5
be8 14f6 14d0 14f5
0 14f7 bea 0
14f8 bec 14fb :3 0
14fb 0 14fb 14fa
14f8 14f9 :6 0 14fd
30 :3 0 bef 14ff
bf1 14fe 14fd :2 0
1500 bf3 :2 0 1502
0 1502 1501 14af
1500 :6 0 1516 1
:3 0 31 :3 0 25
:2 0 1504 1505 0
1516 32 :3 0 107
:3 0 14 :3 0 15
:3 0 11 :3 0 17
:3 0 19 :3 0 49
:3 0 4b :3 0 31
:3 0 28 :3 0 27
:3 0 bf6 1508 1513
1507 1514 0 1516
c01 16c5 31 :3 0
106 :2 0 21 :2 0
c0c 1518 151a :3 0
1517 151b 0 16c4
32 :3 0 107 :3 0
14 :3 0 15 :3 0
11 :3 0 17 :3 0
19 :3 0 49 :3 0
4b :3 0 31 :3 0
28 :3 0 27 :3 0
c0e 151e 1529 151d
152a 0 16c4 66
:3 0 2e :3 0 25
:2 0 c19 152c 152f
be :2 0 25 :2 0
c1e 1531 1533 :3 0
1534 :2 0 1d :3 0
105 :2 0 c21 1537
1538 :3 0 1539 :2 0
153a :2 0 1535 153c
153b :2 0 32 :3 0
15a :3 0 14 :3 0
15 :3 0 16 :3 0
13 :3 0 11 :3 0
1d :3 0 2e :3 0
25 :2 0 c23 153f
1548 153e 1549 0
154b c2c 154c 153d
154b 0 154d c2e
0 16c4 13 :3 0
105 :2 0 c30 154f
1550 :3 0 1551 :2 0
32 :3 0 141 :3 0
14 :3 0 11 :3 0
142 :2 0 c32 1554
1558 1553 1559 0
155b c36 157c 82
:3 0 20 :3 0 21
:2 0 21 :2 0 c38
155c 1560 a0 :2 0
142 :4 0 c3e 1562
1564 :3 0 32 :3 0
141 :3 0 14 :3 0
11 :3 0 25 :2 0
c41 1567 156b 1566
156c 0 156e c45
1578 32 :3 0 141
:3 0 14 :3 0 11
:3 0 21 :2 0 c47
1570 1574 156f 1575
0 1577 c4b 1579
1565 156e 0 157a
0 1577 0 157a
c4d 0 157b c50
157d 1552 155b 0
157e 0 157b 0
157e c52 0 16c4
1d :3 0 105 :2 0
c55 1580 1581 :3 0
1582 :2 0 c2 :3 0
139 :3 0 81 :3 0
82 :3 0 1d :3 0
c2 :3 0 13a :3 0
1a :3 0 1a :3 0
c9 :4 0 15f 1
:8 0 1594 93 :3 0
94 :3 0 158f 1590
0 95 :3 0 1591
1592 0 1594 c57
15e7 96 :3 0 93
:3 0 94 :3 0 1596
1597 0 95 :3 0
1598 1599 0 159b
c5a 159d c5c 159c
159b :2 0 15e5 97
:3 0 93 :3 0 94
:3 0 15a0 15a1 0
95 :3 0 15a2 15a3
0 15dd 59 :3 0
5a :3 0 15a5 15a6
0 59 :3 0 6a
:3 0 15a8 15a9 0
98 :2 0 2 :4 0
160 :2 0 6c :2 0
21 :2 0 c5e 15ae
15b0 :3 0 c61 15aa
15b2 15a7 15b4 15b3
:2 0 5c :3 0 6d
:3 0 15b6 15b7 0
5e :4 0 161 :4 0
61 :2 0 62 :3 0
c65 15bb 15bd :3 0
61 :2 0 9b :4 0
c68 15bf 15c1 :3 0
61 :2 0 9c :4 0
c6b 15c3 15c5 :3 0
61 :2 0 95 :3 0
c6e 15c7 15c9 :3 0
61 :2 0 9d :4 0
c71 15cb 15cd :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 c74 15d0
15d4 c78 15cf 15d6
:3 0 c7b 15b8 15d8
:2 0 15da c7e 15db
15b5 15da 0 15dc
c80 0 15dd c82
15e0 :3 0 15e0 0
15e0 15df 15dd 15de
:6 0 15e2 32 :3 0
c85 15e4 c87 15e3
15e2 :2 0 15e5 c89
:2 0 15e7 0 15e7
15e6 1594 15e5 :6 0
15f8 1 :3 0 29
:3 0 66 :3 0 29
:3 0 25 :2 0 c8c
15ea 15ed 106 :2 0
66 :3 0 2c :3 0
25 :2 0 c8f 15f0
15f3 c92 15ef 15f5
:3 0 15e9 15f6 0
15f8 c95 15f9 1583
15f8 0 15fa c98
0 16c4 35 :3 0
25 :2 0 15fb 15fc
0 16c4 32 :3 0
142 :2 0 15fe 15ff
0 16c4 32 :3 0
143 :3 0 11 :3 0
1a :3 0 29 :3 0
32 :3 0 35 :3 0
b :3 0 25 :2 0
66 :3 0 2b :3 0
25 :2 0 c9a 160a
160d c9d 1602 160f
1601 1610 0 16c4
66 :3 0 32 :3 0
25 :2 0 ca6 1612
1615 df :2 0 25
:2 0 cab 1617 1619
:3 0 c :3 0 11
:3 0 161b 161c 0
1642 59 :3 0 5a
:3 0 161e 161f 0
59 :3 0 6a :3 0
1621 1622 0 21
:2 0 2 :4 0 162
:2 0 6c :2 0 21
:2 0 cae 1627 1629
:3 0 cb1 1623 162b
1620 162d 162c :2 0
5c :3 0 6d :3 0
162f 1630 0 5e
:4 0 163 :4 0 61
:2 0 62 :3 0 cb5
1634 1636 :3 0 cb8
1631 1638 :2 0 163a
cbb 163b 162e 163a
0 163c cbd 0
1642 d :3 0 44
:3 0 159 :3 0 163e
163f 0 1640 :2 0
1642 cbf 16c1 90
:3 0 11a :3 0 7e
:3 0 2b :3 0 7a
:3 0 7c :3 0 79
:3 0 164 :3 0 8f
:3 0 11b :3 0 116
:3 0 8f :3 0 44
:3 0 11c :3 0 44
:3 0 165 :3 0 91
:3 0 11 :4 0 166
1 :8 0 166b 11e
:4 0 1656 :3 0 11f
:3 0 a0 :2 0 cc5
1659 165a :3 0 93
:3 0 94 :3 0 165c
165d 0 25 :2 0
165e 165f 0 1661
cc8 1668 93 :3 0
94 :3 0 1662 1663
0 120 :2 0 1664
1665 0 1667 cca
1669 165b 1661 0
166a 0 1667 0
166a ccc 0 166b
ccf 16be 96 :3 0
93 :3 0 94 :3 0
166d 166e 0 95
:3 0 166f 1670 0
1672 cd2 1674 cd4
1673 1672 :2 0 16bc
97 :3 0 93 :3 0
94 :3 0 1677 1678
0 95 :3 0 1679
167a 0 16b4 59
:3 0 5a :3 0 167c
167d 0 59 :3 0
6a :3 0 167f 1680
0 98 :2 0 2
:4 0 167 :2 0 6c
:2 0 21 :2 0 cd6
1685 1687 :3 0 cd9
1681 1689 167e 168b
168a :2 0 5c :3 0
6d :3 0 168d 168e
0 5e :4 0 168
:4 0 61 :2 0 62
:3 0 cdd 1692 1694
:3 0 61 :2 0 9b
:4 0 ce0 1696 1698
:3 0 61 :2 0 9c
:4 0 ce3 169a 169c
:3 0 61 :2 0 95
:3 0 ce6 169e 16a0
:3 0 61 :2 0 9d
:4 0 ce9 16a2 16a4
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 cec
16a7 16ab cf0 16a6
16ad :3 0 cf3 168f
16af :2 0 16b1 cf6
16b2 168c 16b1 0
16b3 cf8 0 16b4
cfa 16b7 :3 0 16b7
0 16b7 16b6 16b4
16b5 :6 0 16b9 34
:3 0 cfd 16bb cff
16ba 16b9 :2 0 16bc
d01 :2 0 16be 0
16be 16bd 166b 16bc
:6 0 16c0 1 :3 0
d04 16c2 161a 1642
0 16c3 0 16c0
0 16c3 d06 0
16c4 d09 16c6 1424
1516 0 16c7 0
16c4 0 16c7 d13
0 16c8 d16 16c9
1308 16c8 0 16cb
9c7 11ff 0 16cb
d1a 0 16cc d1e
16ce 300 707 0
16cf 0 16cc 0
16cf d2b 0 170a
93 :3 0 94 :3 0
16d0 16d1 0 169
:3 0 14 :3 0 d2e
16d3 16d5 16d2 16d6
0 170a 59 :3 0
5a :3 0 16d8 16d9
0 59 :3 0 6a
:3 0 16db 16dc 0
21 :2 0 2 :4 0
16a :2 0 6c :2 0
21 :2 0 d30 16e1
16e3 :3 0 d33 16dd
16e5 16da 16e7 16e6
:2 0 5c :3 0 6d
:3 0 16e9 16ea 0
5e :4 0 16b :4 0
61 :2 0 62 :3 0
d37 16ee 16f0 :3 0
61 :2 0 9b :4 0
d3a 16f2 16f4 :3 0
61 :2 0 d7 :4 0
d3d 16f6 16f8 :3 0
61 :2 0 93 :3 0
94 :3 0 16fb 16fc
0 d40 16fa 16fe
:3 0 d43 16eb 1700
:2 0 1702 d46 1703
16e8 1702 0 1704
d48 0 170a d
:3 0 93 :3 0 94
:3 0 1706 1707 0
1708 :2 0 170a d4a
170d :3 0 170d d53
170d 170c 170a 170b
:6 0 170e :2 0 2
24 170d 1711 :3 0
1710 170e 1712 :8 0

d94
4
:3 0 1 3 1
9 1 d 1
11 1 15 1
1b 6 8 c
10 14 1a 20
1 26 1 2c
1 32 1 3a
1 38 1 41
1 3f 1 48
1 46 1 4f
1 4d 1 56
1 54 1 5b
1 60 1 65
1 6a 1 6f
1 74 1 79
1 80 1 7e
1 87 1 85
1 8e 1 8c
1 93 1 99
1 9f 1 a5
1 ab 1 b1
1 b7 1 bd
1 c3 1 c9
1 cf 1 d5
1 db 1 e1
1 e7 1 ed
1 f3 1 f9
1 ff 1 105
1 10b 1 111
1 117 1 11d
1 123 1 129
1 12f 1 135
1 13d 1 13b
1 147 1 145
1 151 1 14f
1 156 1 15c
1 162 1 168
1 16e 1 174
1 17a 1 180
1 186 1 18c
1 192 1 198
1 19e 1 1a4
1 1aa 1 1b6
1 1c2 2 1c5
1c7 2 1ca 1cc
2 1ce 1d0 2
1d2 1d4 2 1d6
1d8 1 1de 2
1e0 1e1 2 1da
1e3 2 1e5 1e7
1 1ed 2 1ef
1f0 2 1e9 1f2
2 1f4 1f6 1
1fc 2 1fe 1ff
2 1f8 201 2
203 205 2 207
209 2 20b 20d
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 4 1be
1c4 1c9 227 1
229 1 22b 2
235 237 3 233
234 239 2 242
244 2 241 246
1 248 1 24a
2 29c 2a1 1
2a8 1 2a3 2
2bb 2bd 3 2b9
2ba 2bf 2 2c8
2ca 2 2cc 2ce
2 2d0 2d2 2
2d4 2d6 2 2d8
2da 3 2df 2e0
2e1 2 2dc 2e3
2 2c7 2e5 1
2e7 1 2e9 2
2b2 2ea 1 2ee
1 2ad 2 2ab
2f2 1 2fd 2
2f9 2fd 2 316
31b 1 322 1
31d 2 335 337
3 333 334 339
2 342 344 2
346 348 2 34a
34c 2 34e 350
2 352 354 3
359 35a 35b 2
356 35d 2 341
35f 1 361 1
363 2 32c 364
1 368 1 327
2 325 36c 1
377 2 373 377
2 386 388 3
384 385 38a 2
393 395 2 392
397 1 399 1
39b 3 37d 39c
3a1 1 3a3 3
3a6 3a7 3a8 1
3ac 2 3aa 3ac
2 3ba 3bc 3
3b8 3b9 3be 2
3c7 3c9 2 3c6
3cb 1 3cd 1
3cf 3 3b1 3d0
3d5 1 3d7 2
3db 3dc 2 3de
3e1 1 3e8 2
3e4 3e8 2 3f6
3f8 3 3f4 3f5
3fa 2 403 405
2 402 407 1
409 1 40b 3
3ed 40c 411 1
413 2 41d 422
1 429 1 424
2 43c 43e 3
43a 43b 440 2
449 44b 2 44d
44f 2 451 453
2 455 457 2
459 45b 3 460
461 462 2 45d
464 2 448 466
1 468 1 46a
2 433 46b 1
46f 1 42e 2
42c 473 2 479
47a 1 47e 2
47c 47e 2 486
48b 1 492 1
48d 2 4a5 4a7
3 4a3 4a4 4a9
2 4b2 4b4 2
4b6 4b8 2 4ba
4bc 2 4be 4c0
2 4c2 4c4 3
4c9 4ca 4cb 2
4c6 4cd 2 4b1
4cf 1 4d1 1
4d3 2 49c 4d4
1 4d8 1 497
2 495 4dc 2
4e4 4e5 1 4e9
2 4e7 4e9 2
4f7 4f9 3 4f5
4f6 4fb 2 504
506 2 503 508
1 50a 1 50c
3 4ee 50d 512
1 514 2 4df
515 1 517 2
537 53c 1 543
1 53e 2 556
558 3 554 555
55a 2 563 565
2 567 569 2
56b 56d 2 56f
571 2 573 575
3 57a 57b 57c
2 577 57e 2
562 580 1 582
1 584 2 54d
585 1 589 1
548 2 546 58d
2 593 594 1
598 2 596 598
2 5a6 5a8 3
5a4 5a5 5aa 2
5b3 5b5 2 5b2
5b7 1 5b9 1
5bb 3 59d 5bc
5c1 1 5c3 2
5c6 5c7 1 5cb
2 5c9 5cb 2
5d6 5d8 3 5d4
5d5 5da 2 5e3
5e5 2 5e7 5e9
2 5eb 5ed 1
5f5 2 5f7 5f8
2 5ef 5fa 2
5e2 5fc 1 5fe
1 600 2 60a
60c 3 608 609
60e 2 617 619
2 616 61b 1
61d 1 61f 2
627 628 3 601
620 62b 2 62f
630 2 635 636
1 638 2 632
638 2 63f 640
2 645 646 1
648 2 642 648
2 656 658 3
654 655 65a 2
663 665 2 662
667 1 669 1
66b 3 64d 66c
671 2 675 676
2 67b 67c 1
67e 2 678 67e
1 683 2 686
685 2 692 693
2 697 698 2
69c 69d 7 68d
68e 68f 690 695
69a 69f 4 63d
687 68a 6a2 2
6ad 6af 3 6ab
6ac 6b1 2 6ba
6bc 2 6be 6c0
2 6c2 6c4 1
6cc 2 6ce 6cf
2 6c6 6d1 2
6b9 6d3 1 6d5
1 6d7 2 6e1
6e3 3 6df 6e0
6e5 2 6ee 6f0
2 6ed 6f2 1
6f4 1 6f6 2
6fe 6ff 3 6d8
6f7 702 3 704
6a4 705 b 36f
3a4 3d8 414 417
476 518 51b 590
5c4 706 2 709
70a 1 70e 2
70c 70e 2 71c
71e 3 71a 71b
720 2 729 72b
2 728 72d 1
72f 1 731 3
713 732 737 1
739 2 743 748
1 74f 1 74a
2 762 764 3
760 761 766 2
76f 771 2 773
775 2 777 779
2 77b 77d 2
77f 781 3 786
787 788 2 783
78a 2 76e 78c
1 78e 1 790
2 759 791 1
795 1 754 2
752 799 2 79f
7a0 1 7a4 2
7a2 7a4 2 7ac
7b1 1 7b8 1
7b3 2 7cb 7cd
3 7c9 7ca 7cf
2 7d8 7da 2
7dc 7de 2 7e0
7e2 2 7e4 7e6
2 7e8 7ea 3
7ef 7f0 7f1 2
7ec 7f3 2 7d7
7f5 1 7f7 1
7f9 2 7c2 7fa
1 7fe 1 7bd
2 7bb 802 2
80a 80b 1 80f
2 80d 80f 2
81d 81f 3 81b
81c 821 2 82a
82c 2 829 82e
1 830 1 832
3 814 833 838
1 83a 2 805
83b 1 83d 2
84c 851 1 858
1 853 2 86b
86d 3 869 86a
86f 2 878 87a
2 87c 87e 2
880 882 2 884
886 2 888 88a
3 88f 890 891
2 88c 893 2
877 895 1 897
1 899 2 862
89a 1 89e 1
85d 2 85b 8a2
3 8a8 8a9 8aa
1 8ae 2 8ac
8ae 2 8bc 8be
3 8ba 8bb 8c0
2 8c9 8cb 2
8c8 8cd 1 8cf
1 8d1 3 8b3
8d2 8d7 1 8d9
2 8dd 8de 2
8e0 8e3 1 8ea
2 8e6 8ea 2
8f8 8fa 3 8f6
8f7 8fc 2 905
907 2 904 909
1 90b 1 90d
3 8ef 90e 913
1 915 2 926
92b 1 932 1
92d 2 945 947
3 943 944 949
2 952 954 2
956 958 2 95a
95c 2 95e 960
2 962 964 3
969 96a 96b 2
966 96d 2 951
96f 1 971 1
973 2 93c 974
1 978 1 937
2 935 97c 2
982 983 1 987
2 985 987 2
995 997 3 993
994 999 2 9a2
9a4 2 9a1 9a6
1 9a8 1 9aa
3 98c 9ab 9b0
1 9b2 2 9b6
9b7 2 9bc 9bd
2 9c2 9c3 1
9c5 2 9bf 9c5
2 9cc 9cd 2
9d2 9d3 1 9d5
2 9cf 9d5 2
9d9 9da 1 9e0
2 9dc 9e0 2
9e4 9e5 1 9eb
2 9e7 9eb 2
9ff a04 1 a0b
1 a06 2 a1e
a20 3 a1c a1d
a22 2 a2b a2d
2 a2f a31 2
a33 a35 2 a37
a39 2 a3b a3d
3 a42 a43 a44
2 a3f a46 2
a2a a48 1 a4a
1 a4c 2 a15
a4d 1 a51 1
a10 2 a0e a55
1 a5a 1 a61
1 a63 2 a66
a67 1 a6b 2
a69 a6b 1 a70
a a76 a77 a78
a79 a7a a7b a7c
a7d a7e a7f 2
a84 a85 1 a89
2 a87 a89 1
a8d 2 aa1 aa6
1 aad 1 aa8
2 ac0 ac2 3
abe abf ac4 2
acd acf 2 ad1
ad3 2 ad5 ad7
2 ad9 adb 2
add adf 3 ae4
ae5 ae6 2 ae1
ae8 2 acc aea
1 aec 1 aee
2 ab7 aef 1
af3 1 ab2 2
ab0 af7 2 afe
aff 2 b04 b05
2 b01 b07 2
b0c b0d 2 b09
b0f 3 afa b12
b15 1 b17 1
b1d 2 b1f b20
1 b26 2 b28
b29 2 b22 b2b
2 b2e b30 1
b32 2 b38 b39
2 b3e b3f 2
b3b b41 2 b46
b47 2 b4c b4d
1 b4f 2 b49
b4f 2 b54 b55
2 b5a b5b 2
b57 b5d 2 b62
b63 2 b5f b65
1 b68 2 b6c
b6d 1 b70 2
b72 b73 8 b77
b78 b79 b7a b7b
b7c b7d b7e 1
b86 2 b88 b89
1 b8f 2 b91
b92 2 b8b b94
2 b97 b99 1
b9b 2 ba4 ba5
2 ba7 baa 2
bb4 bb5 2 bb9
bba 5 bb0 bb1
bb2 bb7 bbc a
bc5 bc6 bc7 bc8
bc9 bca bcb bcc
bcd bce c a73
a82 b18 b35 b44
b74 b81 b9e bad
bbf bc2 bd1 1
bd3 4 9f2 a58
a64 bd4 1 bd8
a bde bdf be0
be1 be2 be3 be4
be5 be6 be7 2
bec bed 2 bf2
bf3 1 bf5 2
bef bf5 2 bfb
bfc 1 c00 2
bfe c00 2 c05
c06 2 c0b c0c
2 c08 c0e 2
c16 c17 2 c1c
c1d 2 c22 c23
2 c1f c25 1
c28 2 c19 c28
2 c2d c2e 2
c33 c34 2 c30
c36 2 c3c c3d
2 c39 c3f 1
c57 2 c56 c57
1 c5f 1 c65
2 c67 c68 2
c54 c69 1 c70
1 c6b 2 c83
c85 3 c81 c82
c87 2 c90 c92
2 c94 c96 2
c98 c9a 2 c9c
c9e 2 ca0 ca2
3 ca7 ca8 ca9
2 ca4 cab 2
c8f cad 1 caf
1 cb1 2 c7a
cb2 1 cb6 1
c75 2 c73 cba
2 cc4 cc5 2
cc7 cca 3 c42
cbd ccd 1 ce2
2 ce1 ce2 1
cea 1 cf0 2
cf2 cf3 2 cdf
cf4 1 cfb 1
cf6 2 d0e d10
3 d0c d0d d12
2 d1b d1d 2
d1f d21 2 d23
d25 2 d27 d29
2 d2b d2d 3
d32 d33 d34 2
d2f d36 2 d1a
d38 1 d3a 1
d3c 2 d05 d3d
1 d41 1 d00
2 cfe d45 1
d48 2 d4b d4c
3 c11 c14 d4d
2 d50 d51 2
d56 d57 2 d5c
d5d 2 d59 d5f
1 d62 2 d53
d62 2 d67 d68
2 d6d d6e 2
d6a d70 1 d78
2 d7a d7b 1
d81 2 d83 d84
2 d7d d86 2
d89 d8b 2 d8e
d90 1 d92 1
da7 2 da6 da7
1 daf 1 db5
2 db7 db8 2
da4 db9 1 dc0
1 dbb 2 dd3
dd5 3 dd1 dd2
dd7 2 de0 de2
2 de4 de6 2
de8 dea 2 dec
dee 2 df0 df2
3 df7 df8 df9
2 df4 dfb 2
ddf dfd 1 dff
1 e01 2 dca
e02 1 e06 1
dc5 2 dc3 e0a
3 d73 d95 e0d
2 e12 e13 2
e18 e19 2 e15
e1b 1 e35 2
e34 e35 1 e3d
1 e43 2 e45
e46 2 e32 e47
1 e4e 1 e49
2 e61 e63 3
e5f e60 e65 2
e6e e70 2 e72
e74 2 e76 e78
2 e7a e7c 2
e7e e80 3 e85
e86 e87 2 e82
e89 2 e6d e8b
1 e8d 1 e8f
2 e58 e90 1
e94 1 e53 2
e51 e98 3 e1e
e21 e9b 2 e9e
e9f 1 ea0 2
ea2 ea3 1 ea4
2 ea8 ea9 2
eae eaf 2 eab
eb1 1 ecb 2
eca ecb 1 ed3
1 ed9 2 edb
edc 2 ec8 edd
1 ee4 1 edf
2 ef7 ef9 3
ef5 ef6 efb 2
f04 f06 2 f08
f0a 2 f0c f0e
2 f10 f12 2
f14 f16 3 f1b
f1c f1d 2 f18
f1f 2 f03 f21
1 f23 1 f25
2 eee f26 1
f2a 1 ee9 2
ee7 f2e 3 eb4
eb7 f31 2 f34
f35 1 f37 2
f47 f4c 1 f53
1 f4e 2 f66
f68 3 f64 f65
f6a 2 f73 f75
2 f77 f79 2
f7b f7d 2 f7f
f81 2 f83 f85
3 f8a f8b f8c
2 f87 f8e 2
f72 f90 1 f92
1 f94 2 f5d
f95 1 f99 1
f58 2 f56 f9d
1 fa2 2 fac
fb1 1 fb8 1
fb3 2 fcb fcd
3 fc9 fca fcf
2 fd8 fda 2
fdc fde 2 fe0
fe2 2 fe4 fe6
2 fe8 fea 3
fef ff0 ff1 2
fec ff3 2 fd7
ff5 1 ff7 1
ff9 2 fc2 ffa
1 ffe 1 fbd
2 fbb 1002 3
100a 100b 100c 1
1010 2 100e 1010
1 1015 1 1017
2 1005 1018 2
101c 101d 1 1021
2 101f 1021 2
1029 102a 2 102c
102f 2 103e 1043
1 104a 1 1045
2 105d 105f 3
105b 105c 1061 2
106a 106c 2 106e
1070 2 1072 1074
2 1076 1078 2
107a 107c 3 1081
1082 1083 2 107e
1085 2 1069 1087
1 1089 1 108b
2 1054 108c 1
1090 1 104f 2
104d 1094 2 1033
1097 2 10a5 10aa
1 10b1 1 10ac
2 10c4 10c6 3
10c2 10c3 10c8 2
10d1 10d3 2 10d5
10d7 2 10d9 10db
2 10dd 10df 2
10e1 10e3 3 10e8
10e9 10ea 2 10e5
10ec 2 10d0 10ee
1 10f0 1 10f2
2 10bb 10f3 1
10f7 1 10b6 2
10b4 10fb 1 10fe
3 1101 109a 1102
3 f3e fa0 1103
1 1105 1 1107
3 110e 110f 1110
1 1113 3 1116
1117 1118 1 111c
2 111a 111c 3
1121 1122 1123 1
1126 3 112a 112b
112c 1 112f 2
1131 1132 1 1133
2 1135 1136 2
1145 1146 8 113d
113e 113f 1140 1141
1142 1143 1148 2
114d 114e 1 1152
2 1150 1152 2
1160 1162 3 115e
115f 1164 2 116d
116f 2 116c 1171
1 1173 1 1175
2 1179 117a 3
1157 1176 117d 1
117f 8 bdb bea
f36 1106 1137 113a
114b 1180 2 1182
1183 2 1184 1187
1 118d 2 118f
1190 1 1196 2
1198 1199 2 1192
119b 2 119e 11a0
2 11a3 11a5 1
11a7 1 11aa 2
11ac 11ad 2 11c9
11ca 2 11ce 11cf
19 11b1 11b2 11b3
11b4 11b5 11b6 11b7
11b8 11b9 11ba 11bb
11bc 11bd 11be 11bf
11c0 11c1 11c2 11c3
11c4 11c5 11c6 11c7
11cc 11d1 2 11e0
11e2 3 11de 11df
11e4 2 11ed 11ef
2 11ec 11f1 1
11f3 1 11f5 2
11f9 11fa 6 9ca
11ae 11d4 11d7 11f6
11fd 2 1201 1202
2 1207 1208 1
120a 2 1204 120a
1 121b 2 121a
121b 1 1223 1
1229 2 122b 122c
2 1218 122d 1
1234 1 122f 2
1247 1249 3 1245
1246 124b 2 1254
1256 2 1258 125a
2 125c 125e 2
1260 1262 2 1264
1266 3 126b 126c
126d 2 1268 126f
2 1253 1271 1
1273 1 1275 2
123e 1276 1 127a
1 1239 2 1237
127e 1 1291 2
1290 1291 1 1299
1 129f 2 12a1
12a2 2 128e 12a3
1 12aa 1 12a5
2 12bd 12bf 3
12bb 12bc 12c1 2
12ca 12cc 2 12ce
12d0 2 12d2 12d4
2 12d6 12d8 2
12da 12dc 3 12e1
12e2 12e3 2 12de
12e5 2 12c9 12e7
1 12e9 1 12eb
2 12b4 12ec 1
12f0 1 12af 2
12ad 12f4 2 1281
12f7 2 12fd 12fe
2 1303 1304 1
1306 2 1300 1306
2 130a 130b 1
130f 2 130d 130f
1 1314 2 1317
1318 1 131c 2
131a 131c 2 1321
1322 1 1326 2
1324 1326 2 1337
1339 3 1335 1336
133b 2 1344 1346
2 1343 1348 1
134a 1 134c 3
132e 134d 1352 1
1354 2 1358 1359
2 1355 135c 2
135e 135f 1 1361
2 136b 1370 1
1377 1 1372 2
138a 138c 3 1388
1389 138e 2 1397
1399 2 139b 139d
2 139f 13a1 2
13a3 13a5 2 13a7
13a9 3 13ae 13af
13b0 2 13ab 13b2
2 1396 13b4 1
13b6 1 13b8 2
1381 13b9 1 13bd
1 137c 2 137a
13c1 1 13cc 2
13c8 13cc 2 13d1
13d2 2 13d7 13d8
1 13da 2 13d4
13da 2 13eb 13ed
3 13e9 13ea 13ef
2 13f8 13fa 2
13f7 13fc 1 13fe
1 1400 3 13e2
1401 1406 1 1408
2 13c4 1409 1
140b 2 140e 140f
1 1415 2 1411
1415 2 1419 141a
1 1420 2 141c
1420 1 1427 a
142d 142e 142f 1430
1431 1432 1433 1434
1435 1436 2 143b
143c 1 1440 2
143e 1440 1 1444
8 144e 144f 1450
1451 1452 1453 1454
1455 1 1458 1
145a 2 145f 1460
2 1465 1466 2
1462 1468 2 146b
146d 2 1470 1472
1 1474 8 147a
147b 147c 147d 147e
147f 1480 1481 2
148a 148b 2 148d
1490 5 1496 1497
1498 1499 149a 2
14a9 14ae 1 14b5
1 14b0 2 14c8
14ca 3 14c6 14c7
14cc 2 14d5 14d7
2 14d9 14db 2
14dd 14df 2 14e1
14e3 2 14e5 14e7
3 14ec 14ed 14ee
2 14e9 14f0 2
14d4 14f2 1 14f4
1 14f6 2 14bf
14f7 1 14fb 1
14ba 2 14b8 14ff
a 1509 150a 150b
150c 150d 150e 150f
1510 1511 1512 a
142a 1439 145b 1477
1484 1493 149d 1502
1506 1515 1 1519
a 151f 1520 1521
1522 1523 1524 1525
1526 1527 1528 2
152d 152e 1 1532
2 1530 1532 1
1536 8 1540 1541
1542 1543 1544 1545
1546 1547 1 154a
1 154c 1 154e
3 1555 1556 1557
1 155a 3 155d
155e 155f 1 1563
2 1561 1563 3
1568 1569 156a 1
156d 3 1571 1572
1573 1 1576 2
1578 1579 1 157a
2 157c 157d 1
157f 2 158e 1593
1 159a 1 1595
2 15ad 15af 3
15ab 15ac 15b1 2
15ba 15bc 2 15be
15c0 2 15c2 15c4
2 15c6 15c8 2
15ca 15cc 3 15d1
15d2 15d3 2 15ce
15d5 2 15b9 15d7
1 15d9 1 15db
2 15a4 15dc 1
15e0 1 159f 2
159d 15e4 2 15eb
15ec 2 15f1 15f2
2 15ee 15f4 2
15e7 15f7 1 15f9
2 160b 160c 8
1603 1604 1605 1606
1607 1608 1609 160e
2 1613 1614 1
1618 2 1616 1618
2 1626 1628 3
1624 1625 162a 2
1633 1635 2 1632
1637 1 1639 1
163b 3 161d 163c
1641 1 1658 2
1657 1658 1 1660
1 1666 2 1668
1669 2 1655 166a
1 1671 1 166c
2 1684 1686 3
1682 1683 1688 2
1691 1693 2 1695
1697 2 1699 169b
2 169d 169f 2
16a1 16a3 3 16a8
16a9 16aa 2 16a5
16ac 2 1690 16ae
1 16b0 1 16b2
2 167b 16b3 1
16b7 1 1676 2
1674 16bb 1 16be
2 16c1 16c2 9
151c 152b 154d 157e
15fa 15fd 1600 1611
16c3 2 16c5 16c6
3 1360 140c 16c7
3 16ca 12fb 16c9
c 73a 73d 79c
83e 8a5 8da 916
919 97f 9b3 9ba
16cb 2 16cd 16ce
1 16d4 2 16e0
16e2 3 16de 16df
16e4 2 16ed 16ef
2 16f1 16f3 2
16f5 16f7 2 16f9
16fd 2 16ec 16ff
1 1701 1 1703
8 22c 24b 24e
2f5 16cf 16d7 1704
1709 40 2a 30
36 3d 44 4b
52 59 5e 63
68 6d 72 77
7c 83 8a 91
97 9d a3 a9
af b5 bb c1
c7 cd d3 d9
df e5 eb f1
f7 fd 103 109
10f 115 11b 121
127 12d 133 139
143 14d 154 15a
160 166 16c 172
178 17e 184 18a
190 196 19c 1a2
1a8 1ae 
1
4
0 
1711
0
1
50
35
47
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

117 1 0
1b 1 0
180 1 0
12f 1 0
e1 1 0
ff 1 0
6a 1 0
129 1 0
db 1 0
c3 1 0
123 1 0
c9 1 0
145 1 0
85 1 0
186 1 0
99 1 0
15c 1 0
18c 1 0
3 1 0
26 1 0
162 1 0
13b 1 0
79 1 0
e7 1 0
d 1 0
b7 1 0
10b 1 0
6f 1 0
ab 1 0
1aa 1 0
8c 1 0
b1 1 0
65 1 0
16e 1 0
9f 1 0
9 1 0
f9 1 0
93 1 0
135 1 0
11 1 0
60 1 0
17a 1 0
2c 1 0
a5 1 0
4d 1 0
38 1 0
bd 1 0
105 1 0
2 0 1
111 1 0
32 1 0
11d 1 0
7e 1 0
74 1 0
168 1 0
d5 1 0
54 1 0
46 1 0
cf 1 0
3f 1 0
156 1 0
5b 1 0
192 1 0
198 1 0
ed 1 0
15 1 0
19e 1 0
1a4 1 0
14f 1 0
f3 1 0
174 1 0
0

/
SHOW ERRORS FUNCTION FC_U_WP_ACTUAL;
ALTER FUNCTION FC_U_WP_ACTUAL COMPILE DEBUG;
/******************************************************************************************************************
update Actual Work, %W, %C in Work Packages
assign_id:      TSK_ASSIGNMENT_ID or TASK_ID
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION SP_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
4d
2 :e:
1FUNCTION:
1SP_U_WP_ACTUAL:
1ASSIGN_ID:
1VARCHAR2:
1P_WORK_PERCENT:
1PLS_INTEGER:
1P_ACTUAL:
1P_UNITS:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_NEW_WORK_PERCENT:
10:
1H_ACTUAL:
1H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
128:
1+:
1FPUT:
1               ENTER:: SP_U_WP_ACTUAL(29) :: cplan.sql(16478) :: :
1SC_STATE:
1FC_U_WP_ACTUAL:
14:
143:
1       RETURN_STATUS:: SP_U_WP_ACTUAL(44) :: cplan.sql(16493) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
150:
1           EXCEPTION:: SP_U_WP_ACTUAL(51) :: cplan.sql(16500) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
162:
1           EXCEPTION:: SP_U_WP_ACTUAL(63) :: cplan.sql(16512) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1ec
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
4d d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :7 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
1ec
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c8 b7 bb
93 c3 b6 e4 d3 d7 b3 df
d2 100 ef f3 cf fb ee 11d
10b eb 10f 110 118 10a 13a 128
107 12c 12d 135 127 15a 145 149
124 14d 155 144 161 165 141 169
16d 171 174 179 17a 1 17c 181
185 189 18c 191 195 199 19c 1a1
1a2 1a4 1a9 1ac 1b0 1b1 1b6 1bb
1be 1c3 1c4 1c9 1cc 1d0 1d1 1d6
1d9 1de 1df 1e4 1e7 1ec 1ed 1f2
1f5 1f9 1fd 201 202 204 209 20a
20c 20d 212 215 21a 21b 220 223
227 22b 22f 230 232 237 238 23a
23b 240 243 248 249 24e 251 255
259 25d 25e 260 265 266 268 269
26e 271 276 277 27c 27f 284 285
28a 28d 291 292 297 29a 29f 2a0
2a5 2a8 2ad 2ae 2b3 2b4 2b9 2bb
2bf 2c2 2c6 2ca 2cd 2d1 2d5 2d8
2db 2e0 2e3 2e6 2e9 2ea 2ef 2f0
1 2f2 2f7 2fb 2ff 302 307 30c
30f 313 314 319 31a 31f 321 325
328 32c 32d 331 335 339 33d 341
345 349 34d 351 355 359 35d 361
365 369 36d 371 375 378 37c 380
384 388 38c 390 394 395 397 39b
39f 3a3 3a6 3aa 3ae 3b1 3b4 3b9
3bc 3bf 3c2 3c3 3c8 3c9 1 3cb
3d0 3d4 3d8 3db 3e0 3e5 3e8 3ec
3ed 3f2 3f5 3fa 3fb 400 403 408
409 40e 411 415 419 41d 421 424
425 427 42c 42d 42f 430 435 438
43d 43e 443 446 44b 44c 451 454
458 459 45e 461 466 467 46c 46d
472 474 478 47b 47f 483 486 48a
48e 491 495 499 49a 49f 4a1 4a5
4a9 4ac 4b0 4b4 4b7 4bb 4bf 4c2
4c5 4ca 4cd 4d0 4d3 4d4 4d9 4da
1 4dc 4e1 4e5 4e9 4ec 4f1 4f6
4f9 4fd 4fe 503 504 509 50d 511
514 519 51e 521 525 529 52c 52d
532 535 53a 53b 540 543 547 54b
54e 54f 554 555 55a 55c 560 563
567 56b 56f 573 577 57b 57f 583
587 593 598 59c 5a0 5a4 5a8 5aa
5ab 5b0 1 5b4 5b8 5bc 5bf 5c3
5c7 5cb 5cf 5d2 5d6 5da 5dd 5e0
5e5 5e8 5eb 5ee 5ef 5f4 5f5 1
5f7 5fc 600 604 607 60c 611 614
618 619 61e 61f 624 628 62c 62f
634 639 63c 640 641 646 649 64e
64f 654 657 65b 65f 662 665 666
668 669 66e 66f 674 676 67a 67d
681 685 689 68d 691 695 699 6a5
6aa 6ae 6b2 6b6 6ba 6bc 6c0 6c2
6ce 6d0 6d2 6d3 6d8 6dc 6de 6ea
6ee 6f0 6f1 6fa 
1ec
2
0 1 a 6 10 :3 6 15 :3 6
f :3 6 e :3 6 10 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 :2 17 26 17 :2 4 :2 d 1c
d :2 4 :2 c 1b c :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 56 5c 5f :2 56 6d 85 8
:2 6d d 10 :2 6d 1a 1d :2 6d b
e :2 6d 13 16 1f 27 :2 1f 38
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 32 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 31 :2 16 :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 28 2b :2 6d 30 33 :2 6d :2 7
4c :2 4 7 :2 11 23 :2 2d 39 3c
4e 50 51 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :2 7 54 :3 4 12
:2 4 13 :2 4 1a :2 4 10 :2 4 f
:2 4 12 :2 4 :2 d 19 28 35 49
53 5c 27 :2 19 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e 6f
72 :2 1e 76 79 :2 1e 83 86 8f
97 :2 a0 :2 8f ab :2 86 :2 1e b3 b6
:2 1e be c1 :2 1e c6 c9 :2 1e d4
d7 :2 1e :2 7 54 :3 4 :2 f 21 :2 2a
34 40 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 52 54 55
:2 52 :2 26 :3 a :2 10 15 21 62 65
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 58 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4f 51 52
:2 4f :2 23 :3 7 :2 d 12 1e 5f 62
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 55 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
1ec
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :6 b
:6 c :6 d :7 e :7 f
:7 11 :b 13 :11 14 15
:2 14 :2 15 :2 14 :2 15
:2 14 :2 16 :2 14 :9 16
:2 14 :2 17 :2 14 :9 17
:2 14 :2 18 :2 14 :9 18
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :2 14 :2 19
:2 14 :2 19 :4 14 :3 13
:11 1c :b 1d :3 1c :3 20
:3 22 :3 23 :3 24 :3 25
:3 26 :9 28 29 :3 28
:11 2b :30 2c :3 2b :a 2e
12 :3 31 :11 32 :b 33
:17 34 :3 32 :2 36 :3 37
:3 38 39 37 36
37 :3 3a :3 31 :2 3b
:5 3d :11 3e :b 3f :18 40
:3 3e :2 42 43 :3 44
45 43 42 43
:3 46 :2 3c :6 3b 30
:7 1 
6fc
4
:3 0 1 :3 0 2
:a 0 1e7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
6 :3 0 8 :7 0
11 10 :3 0 4
:3 0 9 :7 0 15
14 :3 0 a :3 0
b :3 0 c :2 0
4 19 1a 0
17 1b 0 1e7
2 1c :2 0 10
:2 0 15 4 :3 0
e :2 0 13 1f
21 :6 0 24 22
0 1e5 0 d
:6 0 10 :2 0 17
6 :3 0 26 :7 0
2a 27 28 1e5
0 f :6 0 10
:2 0 19 6 :3 0
2c :7 0 30 2d
2e 1e5 0 11
:6 0 e :2 0 1b
6 :3 0 32 :7 0
36 33 34 1e5
0 12 :6 0 e
:2 0 1f 4 :3 0
1d 38 3a :6 0
3d 3b 0 1e5
0 13 :6 0 46
47 0 23 4
:3 0 21 3f 41
:6 0 44 42 0
1e5 0 14 :6 0
4c 4d 0 25
b :3 0 c :2 0
4 48 :7 0 4b
49 0 1e5 0
15 :6 0 16 :3 0
17 :3 0 16 :3 0
18 :3 0 4f 50
0 2 :4 0 27
51 53 4e 55
54 :2 0 19 :3 0
1a :3 0 57 58
0 1b :4 0 16
:3 0 1c :3 0 5b
5c 0 2 :4 0
29 5d 5f 1d
:4 0 1e :2 0 1f
:3 0 2b 62 64
:3 0 20 :4 0 1e
:2 0 21 :4 0 2e
67 69 :3 0 1e
:2 0 3 :3 0 31
6b 6d :3 0 1e
:2 0 21 :4 0 34
6f 71 :3 0 1e
:2 0 22 :4 0 37
73 75 :3 0 1e
:2 0 23 :3 0 24
:3 0 5 :3 0 3a
79 7b 25 :4 0
3c 78 7e 3f
77 80 :3 0 1e
:2 0 22 :4 0 42
82 84 :3 0 1e
:2 0 23 :3 0 24
:3 0 7 :3 0 45
88 8a 25 :4 0
47 87 8d 4a
86 8f :3 0 1e
:2 0 22 :4 0 4d
91 93 :3 0 1e
:2 0 23 :3 0 24
:3 0 8 :3 0 50
97 99 25 :4 0
52 96 9c 55
95 9e :3 0 1e
:2 0 22 :4 0 58
a0 a2 :3 0 1e
:2 0 21 :4 0 5b
a4 a6 :3 0 1e
:2 0 9 :3 0 5e
a8 aa :3 0 1e
:2 0 21 :4 0 61
ac ae :3 0 1e
:2 0 26 :4 0 64
b0 b2 :3 0 67
59 b4 :2 0 b6
6c b7 56 b6
0 b8 6e 0
145 16 :3 0 17
:3 0 b9 ba 0
16 :3 0 27 :3 0
bc bd 0 28
:2 0 2 :4 0 29
:2 0 2a :2 0 28
:2 0 70 c2 c4
:3 0 73 be c6
bb c8 c7 :2 0
19 :3 0 2b :3 0
ca cb 0 1b
:4 0 2c :4 0 1e
:2 0 1f :3 0 77
cf d1 :3 0 7a
cc d3 :2 0 d5
7d d6 c9 d5
0 d7 7f 0
145 14 :4 0 d8
d9 0 145 d
:3 0 3 :3 0 db
dc 0 145 f
:3 0 5 :3 0 de
df 0 145 11
:3 0 7 :3 0 e1
e2 0 145 12
:3 0 8 :3 0 e4
e5 0 145 13
:3 0 9 :3 0 e7
e8 0 145 b
:3 0 2d :3 0 ea
eb 0 2e :3 0
d :3 0 f :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
81 ed f4 ec
f5 0 145 16
:3 0 17 :3 0 f7
f8 0 16 :3 0
27 :3 0 fa fb
0 2f :2 0 2
:4 0 30 :2 0 2a
:2 0 28 :2 0 88
100 102 :3 0 8b
fc 104 f9 106
105 :2 0 19 :3 0
2b :3 0 108 109
0 1b :4 0 31
:4 0 1e :2 0 1f
:3 0 8f 10d 10f
:3 0 1e :2 0 32
:4 0 92 111 113
:3 0 1e :2 0 33
:4 0 95 115 117
:3 0 1e :2 0 23
:3 0 24 :3 0 b
:3 0 2d :3 0 11c
11d 0 98 11b
11f 25 :4 0 9a
11a 122 9d 119
124 :3 0 1e :2 0
34 :4 0 a0 126
128 :3 0 1e :2 0
21 :4 0 a3 12a
12c :3 0 1e :2 0
14 :3 0 a6 12e
130 :3 0 1e :2 0
21 :4 0 a9 132
134 :3 0 ac 10a
136 :2 0 138 af
139 107 138 0
13a b1 0 145
35 :3 0 36 :3 0
13b 13c 0 b
:3 0 2d :3 0 13e
13f 0 14 :3 0
37 :3 0 b3 13d
143 :2 0 145 b7
1e6 b :3 0 38
:2 0 4 146 147
0 16 :3 0 17
:3 0 149 14a 0
16 :3 0 27 :3 0
14c 14d 0 39
:2 0 2 :4 0 3a
:2 0 2a :2 0 28
:2 0 c3 152 154
:3 0 c6 14e 156
14b 158 157 :2 0
19 :3 0 2b :3 0
15a 15b 0 1b
:4 0 3b :4 0 1e
:2 0 1f :3 0 ca
15f 161 :3 0 cd
15c 163 :2 0 17c
19 :3 0 2b :3 0
165 166 0 1b
:4 0 3c :4 0 1e
:2 0 b :3 0 3d
:3 0 16b 16c 0
d0 16a 16e :3 0
1e :2 0 34 :4 0
d3 170 172 :3 0
1e :2 0 b :3 0
3e :3 0 175 176
0 d6 174 178
:3 0 d9 167 17a
:2 0 17c dc 17d
159 17c 0 17e
df 0 18e 3f
:3 0 15 :3 0 b
:3 0 3d :3 0 40
:3 0 b :3 0 3e
:3 0 41 :3 0 42
:4 0 43 1 :a 0
18a :2 0 18e 180
188 :2 0 a :3 0
15 :3 0 18c :2 0
18e e1 190 e5
18f 18e :2 0 1e4
44 :3 0 b :3 0
2d :3 0 193 194
0 45 :3 0 195
196 0 1dc 16
:3 0 17 :3 0 198
199 0 16 :3 0
27 :3 0 19b 19c
0 39 :2 0 2
:4 0 46 :2 0 2a
:2 0 28 :2 0 e7
1a1 1a3 :3 0 ea
19d 1a5 19a 1a7
1a6 :2 0 19 :3 0
2b :3 0 1a9 1aa
0 1b :4 0 47
:4 0 1e :2 0 1f
:3 0 ee 1ae 1b0
:3 0 f1 1ab 1b2
:2 0 1cc 19 :3 0
2b :3 0 1b4 1b5
0 1b :4 0 48
:4 0 1e :2 0 45
:3 0 f4 1b9 1bb
:3 0 1e :2 0 49
:4 0 f7 1bd 1bf
:3 0 1e :2 0 4a
:3 0 4b :3 0 28
:2 0 4c :2 0 fa
1c2 1c6 fe 1c1
1c8 :3 0 101 1b6
1ca :2 0 1cc 104
1cd 1a8 1cc 0
1ce 107 0 1dc
3f :3 0 15 :3 0
40 :3 0 b :3 0
3e :3 0 41 :3 0
42 :4 0 4d 1
:a 0 1d8 :2 0 1dc
1d0 1d6 :2 0 a
:3 0 15 :3 0 1da
:2 0 1dc 109 1df
:3 0 1df 0 1df
1de 1dc 1dd :6 0
1e1 1 :3 0 10e
1e3 110 1e2 1e1
:2 0 1e4 112 :2 0
1e6 115 1e6 1e5
145 1e4 :6 0 1e7
:2 0 2 1c 1e6
1ea :3 0 1e9 1e7
1eb :8 0 
11d
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 25 1
2b 1 31 1
39 1 37 1
40 1 3e 1
45 1 52 1
5e 2 61 63
2 66 68 2
6a 6c 2 6e
70 2 72 74
1 7a 2 7c
7d 2 76 7f
2 81 83 1
89 2 8b 8c
2 85 8e 2
90 92 1 98
2 9a 9b 2
94 9d 2 9f
a1 2 a3 a5
2 a7 a9 2
ab ad 2 af
b1 4 5a 60
65 b3 1 b5
1 b7 2 c1
c3 3 bf c0
c5 2 ce d0
2 cd d2 1
d4 1 d6 6
ee ef f0 f1
f2 f3 2 ff
101 3 fd fe
103 2 10c 10e
2 110 112 2
114 116 1 11e
2 120 121 2
118 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 10b
135 1 137 1
139 3 140 141
142 b b8 d7
da dd e0 e3
e6 e9 f6 13a
144 2 151 153
3 14f 150 155
2 15e 160 2
15d 162 2 169
16d 2 16f 171
2 173 177 2
168 179 2 164
17b 1 17d 3
17e 189 18d 1
148 2 1a0 1a2
3 19e 19f 1a4
2 1ad 1af 2
1ac 1b1 2 1b8
1ba 2 1bc 1be
3 1c3 1c4 1c5
2 1c0 1c7 2
1b7 1c9 2 1b3
1cb 1 1cd 4
197 1ce 1d7 1db
1 1df 1 192
2 190 1e3 7
23 29 2f 35
3c 43 4a 
1
4
0 
1ea
0
1
14
2
d
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3e 1 0
2 0 1
13 1 0
1e 1 0
25 1 0
2b 1 0
3 1 0
31 1 0
f 1 0
7 1 0
b 1 0
37 1 0
45 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_ACTUAL;
ALTER FUNCTION SP_U_WP_ACTUAL COMPILE DEBUG;
Prompt == FUNCTION FC_U_FD_SD ==
CREATE OR REPLACE FUNCTION FC_U_FD_SD wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
81
2 :e:
1FUNCTION:
1FC_U_FD_SD:
1H_SCHED_START:
1OUT:
1NOCOPY:
1TIMESTAMP:
1H_START_DATE:
1H_FINISH_DATE:
1H_PRJ_ASSIGN_ID:
1VARCHAR2:
1H_PROJECT_ID:
1H_TASK_ID:
1A_TEMP_ID:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
1H_RES_ID:
1H_RES_TYPE:
1SH_H_PER_DAY:
1PLS_INTEGER:
1SH_H_PERCENT_UNITS:
1SH_H_REG_COST:
1NUMBER:
1SH_H_REG_SALE:
1SH_H_CAPITAL_EXPENSE:
1SH_H_BILLABLE:
1H_REC_USER:
1SH_H_EFFORT:
1SH_H_WORK_TODATE:
1RETURN:
1H_PER_DAY:
1H_PERCENT_UNITS:
1H_REG_COST:
1H_REG_SALE:
1H_CAPITAL_EXPENSE:
1H_BILLABLE:
1H_EFFORT:
1COALESCE:
10:
1H_WORK_TODATE:
1H_ID:
132:
1H_TPH_DELETE:
1H_COUNT:
1H_WORK_TYPE:
1H_REMAINING:
1H_TEMP_VAR:
1I_BITFLAG:
1PMO_ORASTD:
1STRCMP:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_FD_SD(:
1NULLIF:
1':
1'':
1NULL:
1, :
1TO_CHAR:
1);:
1CHECK_TRACE:
11:
167:
1+:
1FPUT:
1               ENTER:: FC_U_FD_SD(68) :: cplan.sql(16596) :: :
1STRNCMP:
110:
1>:
1IS NOT NULL:
1COUNT:
1DAY_YEAR:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_FLAG:
1TO_DATE:
1SUBSTR:
1SELECT COUNT(DAY_YEAR) INTO h_count :n         FROM TASK_DAY_OF_YEAR:n       +
1  WHERE TSK_ASSIGNMENT_ID = a_temp_id AND ACTUAL_FLAG = 0 :n         AND DAY_+
1YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)) AND DAY_YEAR < TO_DATE(SubStr(h_+
1sched_start, 1, 10)):
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
188:
1           EXCEPTION:: FC_U_FD_SD(89) :: cplan.sql(16617) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SELECT COUNT(DAY_YEAR) INTO h_temp_var FROM TASK_DAY_OF_YEAR:n         WHERE +
1TSK_ASSIGNMENT_ID = h_prj_assign_id AND ACTUAL_FLAG = 0 :n         AND DAY_YE+
1AR > TO_DATE(SubStr(h_finish_date, 1, 10)):
1104:
1           EXCEPTION:: FC_U_FD_SD(105) :: cplan.sql(16633) :: :
1<:
1112:
1                EXIT:: FC_U_FD_SD(113) :: cplan.sql(16641) :: :
1PMO_CNST:
1TASK_ASSIGNMENT_ERROR:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME(h_start_date)):n      INTO h_sched_start:n      FROM DUAL:
1129:
1           EXCEPTION:: FC_U_FD_SD(130) :: cplan.sql(16658) :: :
1=:
12:
1-:
1FC_TPHASE_SCHED_ASSIGN:
1SC_BIT_30:
1FC_FD_TA_TDY:
1TASK_ASSIGNMENTS:
1SELECT TO_DATE(SubStr(h_sched_start, 1, 10)), TO_DATE(SubStr(h_finish_date, 1+
1, 10)) :n      INTO h_SD, h_FD :n      FROM TASK_ASSIGNMENTS:n      WHERE TSK+
1_ASSIGNMENT_ID = a_temp_id:
1171:
1           EXCEPTION:: FC_U_FD_SD(172) :: cplan.sql(16700) :: :
1181:
1                EXIT:: FC_U_FD_SD(182) :: cplan.sql(16710) :: :
1186:
1                EXIT:: FC_U_FD_SD(187) :: cplan.sql(16715) :: :
1STATE:: :
0

0
0
56e
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c :2 a0 51 a5 b 81 b0
a3 a0 1c :2 a0 51 a5 b 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c :2 a0 6b :2 a0 a5 b 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :2 a0 6e
7e a0 b4 2e 7e 6e b4 2e
6e a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a0 7e b4
2e 5a a 10 a0 51 d a0
51 d :f a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c b7 19 3c
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 :2 51 a5 b 7e 6e
b4 2e a0 51 d b7 a0 51
d b7 :2 19 3c a0 7e 51 b4
2e d :c a0 a5 b d :2 a0 7e
a0 b4 2e d a0 7e b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 5a a 10 :3 a0 6b d b7
a0 51 d b7 :2 19 3c :11 a0 51
a5 b 51 :3 a0 51 a5 b a5
b d :b a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :c a0
a5 b d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 a4 b1 11
68 4f 1d 17 b5 
56e
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 7b 6f 73
77 37 82 93 87 8b 8f 6e
9a af a3 a7 ab 6b b6 c7
bb bf c3 a2 ce e3 d7 db
df 9f ea fb ef f3 f7 d6
102 117 10b 10f 113 d3 11e 12f
123 127 12b 10a 136 14b 13f 143
147 107 152 15b 157 13e 163 170
16c 13b 178 181 17d 16b 189 196
192 168 19e 1a7 1a3 191 1af 1bc
1b8 18e 1c4 1d5 1c9 1cd 1d1 1b7
1dc 1e9 1e5 1b4 1f1 1fa 1f6 1e4
202 1e1 207 20b 20f 213 230 21b
21f 227 22b 21a 250 23b 23f 247
24b 217 26c 257 25b 263 267 23a
28c 277 27b 283 287 237 2a8 293
297 29f 2a3 276 2c8 2b3 2b7 2bf
2c3 273 2ee 2cf 2d3 2db 2df 2e3
2e6 2e7 2e9 2b2 315 2f9 2fd 305
309 2af 30d 30e 310 2f8 332 320
2f5 324 325 32d 31f 34e 33d 341
31c 349 33c 36a 359 35d 339 365
358 386 375 379 355 381 374 3a2
391 395 371 39d 390 3be 3ad 3b1
38d 3b9 3ac 3ed 3c9 3cd 3d5 3d9
3a9 3dd 3e1 3e5 3e6 3e8 3c8 3f4
3f8 3c5 3fc 400 404 407 40c 40d
1 40f 414 418 41c 41f 424 428
42c 42f 434 435 437 43c 43f 443
444 449 44e 451 455 459 45e 461
465 466 46b 46e 473 474 479 47e
47f 481 486 487 489 48a 48f 492
497 498 49d 4a0 4a4 4a8 4ad 4b0
4b4 4b5 4ba 4bd 4c2 4c3 4c8 4cd
4ce 4d0 4d5 4d6 4d8 4d9 4de 4e1
4e6 4e7 4ec 4ef 4f3 4f7 4fc 4ff
503 504 509 50c 511 512 517 51c
51d 51f 524 525 527 528 52d 530
535 536 53b 53e 543 544 549 54c
550 551 556 559 55e 55f 564 567
56c 56d 572 575 57a 57b 580 583
587 588 58d 590 595 596 59b 59e
5a3 5a4 5a9 5ac 5b1 5b2 5b7 5ba
5be 5bf 5c4 5c7 5cc 5cd 5d2 5d5
5da 5db 5e0 5e3 5e8 5e9 5ee 5f1
5f5 5f6 5fb 5fe 603 604 609 60c
611 612 617 61a 61e 622 627 62a
62e 62f 634 637 63c 63d 642 647
648 64a 64f 650 652 653 658 65b
660 661 666 669 66d 671 676 679
67d 67e 683 686 68b 68c 691 696
697 699 69e 69f 6a1 6a2 6a7 6aa
6af 6b0 6b5 6b8 6bd 6be 6c3 6c6
6ca 6cb 6d0 6d3 6d8 6d9 6de 6e1
6e6 6e7 6ec 6ef 6f4 6f5 6fa 6fd
701 702 707 70a 70f 710 715 718
71d 71e 723 726 72b 72c 731 734
738 739 73e 741 746 747 74c 74f
754 755 75a 75d 761 765 769 76a
76c 771 772 774 775 77a 77d 782
783 788 78b 78f 793 797 798 79a
79f 7a0 7a2 7a3 7a8 7ab 7b0 7b1
7b6 7b9 7bd 7c1 7c5 7c6 7c8 7cd
7ce 7d0 7d1 7d6 7d9 7de 7df 7e4
7e7 7eb 7ef 7f3 7f4 7f6 7fb 7fc
7fe 7ff 804 807 80c 80d 812 815
819 81d 821 822 824 829 82a 82c
82d 832 835 83a 83b 840 843 847
84b 84f 850 852 857 858 85a 85b
860 863 868 869 86e 871 876 877
87c 87f 883 884 889 88c 891 892
897 89a 89f 8a0 8a5 8a8 8ac 8b0
8b4 8b5 8b7 8bc 8bd 8bf 8c0 8c5
8c8 8cd 8ce 8d3 8d6 8da 8de 8e2
8e3 8e5 8ea 8eb 8ed 8ee 8f3 8f6
8fb 8fc 901 902 907 909 90d 910
914 918 91b 91f 923 926 929 92e
931 934 937 938 93d 93e 1 940
945 949 94d 950 955 95a 95d 961
962 967 968 96d 96f 973 976 97a
97e 981 985 989 98c 98d 98f 992
995 996 99b 99e 9a2 9a5 9a6 9ab
1 9ae 9b3 9b7 9ba 9be 9c2 9c5
9c9 9cd 9d1 9d5 9d9 9dd 9e1 9e5
9e9 9ed 9f1 9f5 9f9 9fd a01 a05
a11 a15 a19 a1c a20 a24 a26 a2a
a2e a32 a35 a39 a3d a3f a40 a45
1 a49 a4d a51 a54 a58 a5c a60
a64 a67 a6b a6f a72 a75 a7a a7d
a80 a83 a84 a89 a8a 1 a8c a91
a95 a99 a9c aa1 aa6 aa9 aad aae
ab3 ab6 abb abc ac1 ac4 ac9 aca
acf ad2 ad6 ad7 adc adf ae4 ae5
aea aed af1 af5 af8 afb afc afe
aff b04 b05 b0a b0c b10 b13 b15
b19 b1b b27 b29 b2b b2c b31 b35
b37 b43 b45 b49 b4d b51 b55 b59
b5d b61 b65 b69 b6d b71 b7d b81
b85 b88 b8c b90 b92 b96 b9a b9e
ba1 ba5 ba9 bab bac bb1 1 bb5
bb9 bbd bc0 bc4 bc8 bcc bd0 bd3
bd7 bdb bde be1 be6 be9 bec bef
bf0 bf5 bf6 1 bf8 bfd c01 c05
c08 c0d c12 c15 c19 c1a c1f c22
c27 c28 c2d c30 c35 c36 c3b c3e
c42 c43 c48 c4b c50 c51 c56 c59
c5d c61 c64 c67 c68 c6a c6b c70
c71 c76 c78 c7c c7f c81 c85 c87
c93 c95 c97 c98 c9d ca1 ca3 caf
cb1 cb5 cb9 cbc cbd cbf cc3 cc6
cca ccd cce cd0 cd1 cd6 cda cde
ce2 ce6 cea ced cf1 cf5 cf8 cfb
d00 d03 d06 d09 d0a d0f d10 1
d12 d17 d1b d1f d22 d27 d2c d2f
d33 d34 d39 d3a d3f d41 d45 d48
d4c d50 d54 d57 d5b d5d d61 d64
d66 d6a d6d d71 d75 d79 d7d d81
d85 d89 d8d d91 d95 da1 da5 da9
dac db0 db4 db6 dba dbe dc2 dc5
dc9 dcd dcf dd0 dd5 1 dd9 ddd
de1 de4 de8 dec df0 df4 df7 dfb
dff e02 e05 e0a e0d e10 e13 e14
e19 e1a 1 e1c e21 e25 e29 e2c
e31 e36 e39 e3d e3e e43 e46 e4b
e4c e51 e54 e59 e5a e5f e62 e66
e67 e6c e6f e74 e75 e7a e7d e81
e85 e88 e8b e8c e8e e8f e94 e95
e9a e9c ea0 ea3 ea5 ea9 eab eb7
eb9 ebb ebc ec1 ec5 ec7 ed3 ed5
ed9 edd ee0 ee3 ee4 ee6 ee9 eee
eef ef4 ef8 efb eff f01 f05 f08
f0c f0e f12 f16 f19 f1d f20 f23
f24 f29 f2d f31 f35 f39 f3d f41
f45 f49 f4d f51 f55 f59 f5d f5e
f60 f64 f68 f6c f6f f73 f74 f79
f7d f81 f84 f85 f8a f8d f91 f95
f98 f9c fa0 fa3 fa4 fa6 fa9 fac
fad fb2 fb5 fb9 fbd fc0 fc4 fc8
fcb fcc fce fd1 fd4 fd5 fda 1
fdd fe2 1 fe5 fea fee ff2 ff6
ff9 ffd fff 1003 1006 100a 100c 1010
1014 1017 101b 101f 1023 1027 102b 102f
1033 1037 103b 103f 1043 1047 104b 104f
1053 1057 105b 105e 105f 1061 1064 1068
106c 1070 1073 1074 1076 1077 1079 107d
1081 1085 1089 108d 1091 1095 1099 109d
10a1 10a5 10a9 10b5 10b9 10bd 10c0 10c4
10c8 10ca 10ce 10d2 10d6 10d9 10dd 10e1
10e3 10e4 10e9 1 10ed 10f1 10f5 10f8
10fc 1100 1104 1108 110b 110f 1113 1116
1119 111e 1121 1124 1127 1128 112d 112e
1 1130 1135 1139 113d 1140 1145 114a
114d 1151 1152 1157 115a 115f 1160 1165
1168 116d 116e 1173 1176 117a 117b 1180
1183 1188 1189 118e 1191 1195 1199 119c
119f 11a0 11a2 11a3 11a8 11a9 11ae 11b0
11b4 11b7 11b9 11bd 11bf 11cb 11cd 11cf
11d0 11d5 11d9 11db 11e7 11e9 11ed 11f0
11f4 11f8 11fc 1200 1204 1208 120c 1210
1214 1218 121c 1220 1224 1225 1227 122b
122f 1233 1236 123a 123e 1241 1244 1249
124c 124f 1252 1253 1258 1259 1 125b
1260 1264 1268 126b 1270 1275 1278 127c
127d 1282 1283 1288 128a 128e 1291 1295
1299 129d 12a0 12a4 12a8 12ac 12af 12b3
12b7 12ba 12bd 12c2 12c5 12c8 12cb 12cc
12d1 12d2 1 12d4 12d9 12dd 12e1 12e4
12e9 12ee 12f1 12f5 12f6 12fb 12fe 1303
1304 1309 130c 1311 1312 1317 131a 131e
1322 1325 1326 132b 132c 1331 1333 1337
133a 133e 1342 1346 1349 134d 134f 1353
1355 1361 1365 1367 1368 1371 
56e
2
0 1 a 6 17 1b 22 :3 6
16 1a 21 :3 6 17 1b 22 :3 6
19 1d 24 :3 6 16 1a 21 :3 6
13 17 1e :3 6 13 17 1e :3 6
e 12 19 :3 6 e 12 19 :3 6
14 18 1f :3 6 12 16 1d :3 6
14 18 1f :3 6 13 :3 6 19 :3 6
14 :3 6 14 :3 6 1b :3 6 14 :3 6
14 18 1f :3 6 12 :3 6 17 :2 6
1 3 a :2 1 4 :2 e 1d e
:2 4 :2 14 23 14 :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :2 16 25 16
:2 4 :2 f 1e f :2 4 :2 d 1c 25
32 :2 1c d :2 4 :2 12 21 2a 3c
:2 21 12 :2 4 9 12 11 :2 9 :2 4
:2 11 20 11 :2 4 :2 c 1b c :2 4
:2 10 1f 10 :2 4 :2 10 1f 10 :2 4
:2 f 1e f :2 4 :2 e 26 :2 31 38
47 :2 26 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 52 58 5b :2 52 69 7d 8
11 18 1d 20 :2 18 2e 31 :2 18
36 :2 11 3f :2 8 :2 69 b e :2 69
13 16 1f 26 2b 2e :2 26 3b
3e :2 26 43 :2 1f 4c :2 16 :2 69 b
e :2 69 13 16 1f 26 2b 2e
:2 26 3c 3f :2 26 44 :2 1f 4d :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 2e 31 :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 2b 2e
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 28 2b
:2 69 b e :2 69 13 16 1f 26
2b 2e :2 26 33 36 :2 26 3b :2 1f
44 :2 16 :2 69 b e :2 69 13 16
1f 26 2b 2e :2 26 33 36 :2 26
3b :2 1f 44 :2 16 :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 29 2c
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 27 2a :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 29 2c
:2 69 b e :2 69 13 16 1f 27
:2 1f 36 :2 16 :2 69 b e :2 69 13
16 1f 27 :2 1f 3c :2 16 :2 69 b
e :2 69 13 16 1f 27 :2 1f 37
:2 16 :2 69 b e :2 69 13 16 1f
27 :2 1f 37 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 3e :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
37 :2 16 :2 69 b e :2 69 13 16
:2 69 1b 1e :2 69 29 2c :2 69 b
e :2 69 13 16 1f 27 :2 1f 35
:2 16 :2 69 b e :2 69 13 16 1f
27 :2 1f 3a :2 16 :2 69 42 45 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
8 :2 13 1b 2a 38 :2 8 3c 3e
:2 3c 7 :4 46 45 :3 7 15 :2 7 12
7 11 17 26 f 10 24 32
e 1a 22 29 43 4e 56 5d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 54
56 57 :2 54 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5a
:2 d :2 a :4 16 :2 a 7 :3 63 11 17
26 36 10 24 38 e 19 21
28 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5b :2 d :2 a :4 16 :2 a 7 :3 63 a
13 1f :2 a 24 22 2d 36 :2 24
:2 22 a 12 a d :2 17 29 :2 33
3f 42 50 53 54 :2 50 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 57
:3 a 11 :2 1a a 39 :2 7 63 :2 4
e 19 26 2e 35 4d 58 5d
:2 c :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 88 8b :2 24 93 96 :2 24
a2 a5 ac b5 b8 :2 a5 :2 24 :2 d
58 :2 a :2 7 :4 13 :2 7 4 :3 1 7
e 1a 1d :2 7 20 22 :2 20 7
16 7 26 7 16 7 :5 4 14
15 :2 14 :2 4 12 29 37 42 4d
53 59 28 34 42 55 :2 12 :2 4
13 1c 1e :2 13 4 :4 8 7 29
:2 34 3c 4b 51 :2 29 55 57 :2 55
28 e :2 19 21 30 36 :2 e 3a
3c :2 3a d :2 28 27 :3 7 15 :2 1e
7 40 7 15 7 :5 4 12 1f
2d 38 43 4d 59 5f 1e 2d
3c 49 54 1e 2a 33 40 :2 2a
44 47 52 1c 28 :2 52 :2 12 4
e 16 1d 35 3d 44 c 12
c d 21 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 72 75
:2 24 79 7c :2 24 88 8b :2 24 93
96 :2 24 a2 a5 ac b5 b8 :2 a5
:2 24 :2 d 58 :2 a :2 7 :4 13 :2 7 4
:3 1 4 14 :2 4 12 29 37 42
4d 53 59 28 34 42 55 :2 12
4 7 :2 11 23 :2 2d 39 3c 4a
4d 4e :2 4a :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e :2 7 51 :3 4 b :2 14
4 7 :2 11 23 :2 2d 39 3c 4a
4d 4e :2 4a :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e 6c 6f :2 1e 73 76
:2 1e 80 83 :2 8c :2 1e :2 7 51 :3 4
b :2 14 4 :9 1 
56e
4
0 :2 1 :6 3 :6 4
:6 5 :6 6 :6 7 :6 8
:6 9 :6 a :6 b :6 c
:6 d :6 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:6 15 :4 16 :4 17 2
:2 18 :2 1 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:a 20 :a 21 :7 22 :6 23
:6 24 :6 25 :6 26 :6 27
:c 28 :b 2a :11 2b :11 2c
:2 2b :2 2d :2 2b :12 2d
:2 2b :2 2e :2 2b :12 2e
:2 2b :2 2f :2 2b :2 2f
:2 2b :2 2f :2 2b :2 2f
:2 2b :2 30 :2 2b :2 30
:2 2b :2 30 :2 2b :2 30
:2 2b :2 31 :2 2b :2 31
:2 2b :2 31 :2 2b :2 31
:2 2b :2 32 :2 2b :2 32
:2 2b :2 32 :2 2b :2 32
:2 2b :2 33 :2 2b :12 33
:2 2b :2 34 :2 2b :12 34
:2 2b :2 35 :2 2b :2 35
:2 2b :2 35 :2 2b :2 35
:2 2b :2 36 :2 2b :2 36
:2 2b :2 36 :2 2b :2 36
:2 2b :2 37 :2 2b :2 37
:2 2b :2 37 :2 2b :2 37
:2 2b :2 38 :2 2b :9 38
:2 2b :2 39 :2 2b :9 39
:2 2b :2 3a :2 2b :9 3a
:2 2b :2 3b :2 2b :9 3b
:2 2b :2 3c :2 2b :9 3c
:2 2b :2 3d :2 2b :9 3d
:2 2b :2 3e :2 2b :2 3e
:2 2b :2 3e :2 2b :2 3e
:2 2b :2 3f :2 2b :9 3f
:2 2b :2 40 :2 2b :9 40
:2 2b :2 40 :4 2b :3 2a
:11 43 :b 44 :3 43 :14 49
:3 4a :3 4b :3 4d 4e
:3 4f :8 50 4d :5 51
4c 53 :5 54 :3 53
:2 55 :5 57 :11 58 :24 59
:3 58 :2 56 :6 55 52
:3 49 :4 5e :3 5f :4 60
5e :5 61 5d 63
:5 64 :3 63 :2 65 :5 67
:11 68 :24 69 :3 68 :2 66
:6 65 62 :3 49 :d 6e
:3 6f :11 70 :b 71 :3 70
:5 73 :3 6e :3 49 :8 77
78 79 77 :5 7a
76 7c :5 7d :3 7c
:2 7e :5 80 :11 81 :24 82
:3 81 :2 7f :6 7e 7b
:3 29 :a 87 :3 88 87
:3 8a 89 :3 87 :6 8e
:8 8f :4 90 :3 8f :7 92
:12 93 :d 94 :5 93 :5 95
94 :3 97 96 :3 93
:9 9a :5 9b :9 9c :2 9d
:2 9c :3 9a :6 a0 :2 a1
a2 :2 a3 a0 :5 a4
9f a6 :5 a7 :3 a6
:2 a8 :5 aa :11 ab :24 ac
:3 ab :2 a9 :6 a8 a5
:3 29 :3 b1 :8 b2 :4 b3
:3 b2 :11 b5 :b b6 :3 b5
:5 b8 :11 ba :19 bb :3 ba
:5 bd :2 29 :7 1 
1373
4
:3 0 1 :3 0 2
:a 0 569 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 9f 0 b
4 :3 0 5 :3 0
a :3 0 9 :5 0
1 19 18 :3 0
4 :3 0 5 :3 0
a :3 0 b :5 0
1 1f 1e :3 0
11 d3 0 f
4 :3 0 5 :3 0
a :3 0 c :5 0
1 25 24 :3 0
4 :3 0 5 :3 0
a :3 0 d :5 0
1 2b 2a :3 0
15 107 0 13
4 :3 0 5 :3 0
f :3 0 e :5 0
1 31 30 :3 0
4 :3 0 5 :3 0
f :3 0 10 :5 0
1 37 36 :3 0
19 13b 0 17
4 :3 0 5 :3 0
a :3 0 11 :5 0
1 3d 3c :3 0
4 :3 0 5 :3 0
a :3 0 12 :5 0
1 43 42 :3 0
1d 168 0 1b
4 :3 0 5 :3 0
a :3 0 13 :5 0
1 49 48 :3 0
15 :3 0 14 :7 0
4d 4c :3 0 21
18e 0 1f 15
:3 0 16 :7 0 51
50 :3 0 18 :3 0
17 :7 0 55 54
:3 0 25 1b4 0
23 18 :3 0 19
:7 0 59 58 :3 0
15 :3 0 1a :7 0
5d 5c :3 0 29
1e1 0 27 15
:3 0 1b :7 0 61
60 :3 0 4 :3 0
5 :3 0 a :3 0
1c :5 0 1 67
66 :3 0 2d :2 0
2b 15 :3 0 1d
:7 0 6b 6a :3 0
15 :3 0 1e :7 0
6f 6e :3 0 1f
:3 0 15 :3 0 71
73 0 569 2
74 :2 0 45 237
0 43 15 :3 0
77 :7 0 14 :3 0
7b 78 79 567
0 20 :6 0 49
273 0 47 15
:3 0 7d :7 0 16
:3 0 81 7e 7f
567 0 21 :6 0
18 :3 0 83 :7 0
17 :3 0 87 84
85 567 0 22
:6 0 4d 2af 0
4b 18 :3 0 89
:7 0 19 :3 0 8d
8a 8b 567 0
23 :6 0 15 :3 0
8f :7 0 1a :3 0
93 90 91 567
0 24 :6 0 28
:2 0 52 15 :3 0
95 :7 0 1b :3 0
99 96 97 567
0 25 :6 0 15
:3 0 9b :7 0 27
:3 0 1d :3 0 28
:2 0 4f 9d a0
a3 9c a1 567
0 26 :6 0 2b
:2 0 57 15 :3 0
a5 :7 0 27 :3 0
1e :3 0 54 a7
aa ad a6 ab
567 0 29 :6 0
28 :2 0 5b a
:3 0 59 af b1
:6 0 b4 b2 0
567 0 2a :6 0
28 :2 0 5d 15
:3 0 b6 :7 0 ba
b7 b8 567 0
2c :6 0 28 :2 0
5f 15 :3 0 bc
:7 0 c0 bd be
567 0 2d :6 0
28 :2 0 61 15
:3 0 c2 :7 0 c6
c3 c4 567 0
2e :6 0 28 :2 0
63 15 :3 0 c8
:7 0 cc c9 ca
567 0 2f :6 0
d6 d7 0 65
15 :3 0 ce :7 0
d2 cf d0 567
0 30 :6 0 df
e0 0 6a 15
:3 0 d4 0 2
:5 0 32 :3 0 33
:3 0 3 :3 0 7
:3 0 67 d8 db
de d5 dc 567
0 31 :6 0 34
:3 0 35 :3 0 34
:3 0 36 :3 0 e2
e3 0 2 :4 0
6c e4 e6 e1
e8 e7 :2 0 37
:3 0 38 :3 0 ea
eb 0 39 :4 0
34 :3 0 3a :3 0
ee ef 0 2
:4 0 6e f0 f2
3b :4 0 3c :2 0
3d :3 0 70 f5
f7 :3 0 3e :4 0
3c :2 0 27 :3 0
3f :3 0 40 :4 0
3c :2 0 3 :3 0
73 fe 100 :3 0
3c :2 0 40 :4 0
76 102 104 :3 0
41 :4 0 79 fc
107 42 :4 0 7c
fb 10a 7f fa
10c :3 0 3c :2 0
43 :4 0 82 10e
110 :3 0 3c :2 0
27 :3 0 3f :3 0
40 :4 0 3c :2 0
7 :3 0 85 116
118 :3 0 3c :2 0
40 :4 0 88 11a
11c :3 0 41 :4 0
8b 114 11f 42
:4 0 8e 113 122
91 112 124 :3 0
3c :2 0 43 :4 0
94 126 128 :3 0
3c :2 0 27 :3 0
3f :3 0 40 :4 0
3c :2 0 8 :3 0
97 12e 130 :3 0
3c :2 0 40 :4 0
9a 132 134 :3 0
41 :4 0 9d 12c
137 42 :4 0 a0
12b 13a a3 12a
13c :3 0 3c :2 0
43 :4 0 a6 13e
140 :3 0 3c :2 0
40 :4 0 a9 142
144 :3 0 3c :2 0
9 :3 0 ac 146
148 :3 0 3c :2 0
40 :4 0 af 14a
14c :3 0 3c :2 0
43 :4 0 b2 14e
150 :3 0 3c :2 0
40 :4 0 b5 152
154 :3 0 3c :2 0
b :3 0 b8 156
158 :3 0 3c :2 0
40 :4 0 bb 15a
15c :3 0 3c :2 0
43 :4 0 be 15e
160 :3 0 3c :2 0
40 :4 0 c1 162
164 :3 0 3c :2 0
c :3 0 c4 166
168 :3 0 3c :2 0
40 :4 0 c7 16a
16c :3 0 3c :2 0
43 :4 0 ca 16e
170 :3 0 3c :2 0
40 :4 0 cd 172
174 :3 0 3c :2 0
d :3 0 d0 176
178 :3 0 3c :2 0
40 :4 0 d3 17a
17c :3 0 3c :2 0
43 :4 0 d6 17e
180 :3 0 3c :2 0
27 :3 0 3f :3 0
40 :4 0 3c :2 0
e :3 0 d9 186
188 :3 0 3c :2 0
40 :4 0 dc 18a
18c :3 0 41 :4 0
df 184 18f 42
:4 0 e2 183 192
e5 182 194 :3 0
3c :2 0 43 :4 0
e8 196 198 :3 0
3c :2 0 27 :3 0
3f :3 0 40 :4 0
3c :2 0 10 :3 0
eb 19e 1a0 :3 0
3c :2 0 40 :4 0
ee 1a2 1a4 :3 0
41 :4 0 f1 19c
1a7 42 :4 0 f4
19b 1aa f7 19a
1ac :3 0 3c :2 0
43 :4 0 fa 1ae
1b0 :3 0 3c :2 0
40 :4 0 fd 1b2
1b4 :3 0 3c :2 0
11 :3 0 100 1b6
1b8 :3 0 3c :2 0
40 :4 0 103 1ba
1bc :3 0 3c :2 0
43 :4 0 106 1be
1c0 :3 0 3c :2 0
40 :4 0 109 1c2
1c4 :3 0 3c :2 0
12 :3 0 10c 1c6
1c8 :3 0 3c :2 0
40 :4 0 10f 1ca
1cc :3 0 3c :2 0
43 :4 0 112 1ce
1d0 :3 0 3c :2 0
40 :4 0 115 1d2
1d4 :3 0 3c :2 0
13 :3 0 118 1d6
1d8 :3 0 3c :2 0
40 :4 0 11b 1da
1dc :3 0 3c :2 0
43 :4 0 11e 1de
1e0 :3 0 3c :2 0
27 :3 0 44 :3 0
14 :3 0 121 1e4
1e6 42 :4 0 123
1e3 1e9 126 1e2
1eb :3 0 3c :2 0
43 :4 0 129 1ed
1ef :3 0 3c :2 0
27 :3 0 44 :3 0
16 :3 0 12c 1f3
1f5 42 :4 0 12e
1f2 1f8 131 1f1
1fa :3 0 3c :2 0
43 :4 0 134 1fc
1fe :3 0 3c :2 0
27 :3 0 44 :3 0
17 :3 0 137 202
204 42 :4 0 139
201 207 13c 200
209 :3 0 3c :2 0
43 :4 0 13f 20b
20d :3 0 3c :2 0
27 :3 0 44 :3 0
19 :3 0 142 211
213 42 :4 0 144
210 216 147 20f
218 :3 0 3c :2 0
43 :4 0 14a 21a
21c :3 0 3c :2 0
27 :3 0 44 :3 0
1a :3 0 14d 220
222 42 :4 0 14f
21f 225 152 21e
227 :3 0 3c :2 0
43 :4 0 155 229
22b :3 0 3c :2 0
27 :3 0 44 :3 0
1b :3 0 158 22f
231 42 :4 0 15a
22e 234 15d 22d
236 :3 0 3c :2 0
43 :4 0 160 238
23a :3 0 3c :2 0
40 :4 0 163 23c
23e :3 0 3c :2 0
1c :3 0 166 240
242 :3 0 3c :2 0
40 :4 0 169 244
246 :3 0 3c :2 0
43 :4 0 16c 248
24a :3 0 3c :2 0
27 :3 0 44 :3 0
1d :3 0 16f 24e
250 42 :4 0 171
24d 253 174 24c
255 :3 0 3c :2 0
43 :4 0 177 257
259 :3 0 3c :2 0
27 :3 0 44 :3 0
1e :3 0 17a 25d
25f 42 :4 0 17c
25c 262 17f 25b
264 :3 0 3c :2 0
45 :4 0 182 266
268 :3 0 185 ec
26a :2 0 26c 18a
26d e9 26c 0
26e 18c 0 565
34 :3 0 35 :3 0
26f 270 0 34
:3 0 46 :3 0 272
273 0 47 :2 0
2 :4 0 48 :2 0
49 :2 0 47 :2 0
18e 278 27a :3 0
191 274 27c 271
27e 27d :2 0 37
:3 0 4a :3 0 280
281 0 39 :4 0
4b :4 0 3c :2 0
3d :3 0 195 285
287 :3 0 198 282
289 :2 0 28b 19b
28c 27f 28b 0
28d 19d 0 565
32 :3 0 4c :3 0
28e 28f 0 3
:3 0 7 :3 0 4d
:2 0 19f 290 294
4e :2 0 28 :2 0
1a5 296 298 :3 0
299 :2 0 9 :3 0
4f :2 0 1a8 29c
29d :3 0 29e :2 0
29a 2a0 29f :2 0
30 :3 0 28 :2 0
2a2 2a3 0 3af
2d :3 0 28 :2 0
2a5 2a6 0 3af
50 :3 0 51 :3 0
2d :3 0 52 :3 0
53 :3 0 d :3 0
54 :3 0 51 :3 0
55 :3 0 56 :3 0
7 :3 0 51 :3 0
55 :3 0 56 :3 0
3 :4 0 57 1
:8 0 2bd 58 :3 0
59 :3 0 2b8 2b9
0 5a :3 0 2ba
2bb 0 2bd 1aa
310 5b :3 0 58
:3 0 59 :3 0 2bf
2c0 0 5a :3 0
2c1 2c2 0 2c4
1ad 2c6 1af 2c5
2c4 :2 0 30e 5c
:3 0 58 :3 0 59
:3 0 2c9 2ca 0
5a :3 0 2cb 2cc
0 306 34 :3 0
35 :3 0 2ce 2cf
0 34 :3 0 46
:3 0 2d1 2d2 0
5d :2 0 2 :4 0
5e :2 0 49 :2 0
47 :2 0 1b1 2d7
2d9 :3 0 1b4 2d3
2db 2d0 2dd 2dc
:2 0 37 :3 0 4a
:3 0 2df 2e0 0
39 :4 0 5f :4 0
3c :2 0 3d :3 0
1b8 2e4 2e6 :3 0
3c :2 0 60 :4 0
1bb 2e8 2ea :3 0
3c :2 0 61 :4 0
1be 2ec 2ee :3 0
3c :2 0 5a :3 0
1c1 2f0 2f2 :3 0
3c :2 0 62 :4 0
1c4 2f4 2f6 :3 0
3c :2 0 56 :3 0
63 :3 0 47 :2 0
64 :2 0 1c7 2f9
2fd 1cb 2f8 2ff
:3 0 1ce 2e1 301
:2 0 303 1d1 304
2de 303 0 305
1d3 0 306 1d5
309 :3 0 309 0
309 308 306 307
:6 0 30b 2 :3 0
1d8 30d 1da 30c
30b :2 0 30e 1dc
:2 0 310 0 310
30f 2bd 30e :6 0
3af 1 :3 0 50
:3 0 51 :3 0 30
:3 0 52 :3 0 53
:3 0 9 :3 0 54
:3 0 51 :3 0 55
:3 0 56 :3 0 8
:4 0 65 1 :8 0
323 58 :3 0 59
:3 0 31e 31f 0
5a :3 0 320 321
0 323 1df 376
5b :3 0 58 :3 0
59 :3 0 325 326
0 5a :3 0 327
328 0 32a 1e2
32c 1e4 32b 32a
:2 0 374 5c :3 0
58 :3 0 59 :3 0
32f 330 0 5a
:3 0 331 332 0
36c 34 :3 0 35
:3 0 334 335 0
34 :3 0 46 :3 0
337 338 0 5d
:2 0 2 :4 0 66
:2 0 49 :2 0 47
:2 0 1e6 33d 33f
:3 0 1e9 339 341
336 343 342 :2 0
37 :3 0 4a :3 0
345 346 0 39
:4 0 67 :4 0 3c
:2 0 3d :3 0 1ed
34a 34c :3 0 3c
:2 0 60 :4 0 1f0
34e 350 :3 0 3c
:2 0 61 :4 0 1f3
352 354 :3 0 3c
:2 0 5a :3 0 1f6
356 358 :3 0 3c
:2 0 62 :4 0 1f9
35a 35c :3 0 3c
:2 0 56 :3 0 63
:3 0 47 :2 0 64
:2 0 1fc 35f 363
200 35e 365 :3 0
203 347 367 :2 0
369 206 36a 344
369 0 36b 208
0 36c 20a 36f
:3 0 36f 0 36f
36e 36c 36d :6 0
371 4 :3 0 20d
373 20f 372 371
:2 0 374 211 :2 0
376 0 376 375
323 374 :6 0 3af
1 :3 0 27 :3 0
30 :3 0 28 :2 0
214 378 37b 27
:3 0 68 :2 0 2d
:3 0 28 :2 0 217
37d 381 21c 37e
383 :3 0 2a :3 0
9 :3 0 385 386
0 3ac 34 :3 0
35 :3 0 388 389
0 34 :3 0 46
:3 0 38b 38c 0
47 :2 0 2 :4 0
69 :2 0 49 :2 0
47 :2 0 21f 391
393 :3 0 222 38d
395 38a 397 396
:2 0 37 :3 0 4a
:3 0 399 39a 0
39 :4 0 6a :4 0
3c :2 0 3d :3 0
226 39e 3a0 :3 0
229 39b 3a2 :2 0
3a4 22c 3a5 398
3a4 0 3a6 22e
0 3ac 1f :3 0
6b :3 0 6c :3 0
3a8 3a9 0 3aa
:2 0 3ac 230 3ad
384 3ac 0 3ae
234 0 3af 236
3b0 2a1 3af 0
3b1 23c 0 565
32 :3 0 6d :3 0
55 :3 0 56 :3 0
3 :3 0 32 :3 0
6e :3 0 7 :3 0
3 :3 0 6f :4 0
70 1 :8 0 3c2
58 :3 0 59 :3 0
3bd 3be 0 5a
:3 0 3bf 3c0 0
3c2 23e 415 5b
:3 0 58 :3 0 59
:3 0 3c4 3c5 0
5a :3 0 3c6 3c7
0 3c9 241 3cb
243 3ca 3c9 :2 0
413 5c :3 0 58
:3 0 59 :3 0 3ce
3cf 0 5a :3 0
3d0 3d1 0 40b
34 :3 0 35 :3 0
3d3 3d4 0 34
:3 0 46 :3 0 3d6
3d7 0 5d :2 0
2 :4 0 71 :2 0
49 :2 0 47 :2 0
245 3dc 3de :3 0
248 3d8 3e0 3d5
3e2 3e1 :2 0 37
:3 0 4a :3 0 3e4
3e5 0 39 :4 0
72 :4 0 3c :2 0
3d :3 0 24c 3e9
3eb :3 0 3c :2 0
60 :4 0 24f 3ed
3ef :3 0 3c :2 0
61 :4 0 252 3f1
3f3 :3 0 3c :2 0
5a :3 0 255 3f5
3f7 :3 0 3c :2 0
62 :4 0 258 3f9
3fb :3 0 3c :2 0
56 :3 0 63 :3 0
47 :2 0 64 :2 0
25b 3fe 402 25f
3fd 404 :3 0 262
3e6 406 :2 0 408
265 409 3e3 408
0 40a 267 0
40b 269 40e :3 0
40e 0 40e 40d
40b 40c :6 0 410
6 :3 0 26c 412
26e 411 410 :2 0
413 270 :2 0 415
0 415 414 3c2
413 :6 0 565 1
:3 0 56 :3 0 11
:3 0 47 :2 0 47
:2 0 273 417 41b
73 :2 0 74 :4 0
279 41d 41f :3 0
2e :3 0 74 :2 0
421 422 0 424
27c 429 2e :3 0
28 :2 0 425 426
0 428 27e 42a
420 424 0 42b
0 428 0 42b
280 0 565 2c
:3 0 75 :2 0 47
:2 0 283 42d 42f
:3 0 42c 430 0
565 30 :3 0 76
:3 0 b :3 0 c
:3 0 d :3 0 e
:3 0 10 :3 0 22
:3 0 23 :3 0 2c
:3 0 24 :3 0 25
:3 0 285 433 43e
432 43f 0 565
2f :3 0 26 :3 0
75 :2 0 29 :3 0
290 443 445 :3 0
441 446 0 565
8 :3 0 4f :2 0
293 449 44a :3 0
44b :2 0 32 :3 0
4c :3 0 44d 44e
0 3 :3 0 10
:3 0 4d :2 0 295
44f 453 4e :2 0
28 :2 0 29b 455
457 :3 0 458 :2 0
32 :3 0 4c :3 0
45a 45b 0 8
:3 0 e :3 0 4d
:2 0 29e 45c 460
68 :2 0 28 :2 0
2a4 462 464 :3 0
465 :2 0 459 467
466 :2 0 468 :2 0
44c 46a 469 :2 0
30 :3 0 6b :3 0
77 :3 0 46d 46e
0 46c 46f 0
471 2a7 476 30
:3 0 28 :2 0 472
473 0 475 2a9
477 46b 471 0
478 0 475 0
478 2ab 0 565
30 :3 0 78 :3 0
b :3 0 c :3 0
d :3 0 12 :3 0
13 :3 0 e :3 0
10 :3 0 3 :3 0
8 :3 0 2e :3 0
20 :3 0 21 :3 0
1c :3 0 27 :3 0
2f :3 0 28 :2 0
2ae 488 48b 47
:2 0 31 :3 0 27
:3 0 30 :3 0 28
:2 0 2b1 48f 492
2b4 47a 494 479
495 0 565 55
:3 0 56 :3 0 3
:3 0 55 :3 0 56
:3 0 8 :3 0 e
:3 0 10 :3 0 79
:3 0 53 :3 0 d
:4 0 7a 1 :8 0
4a8 58 :3 0 59
:3 0 4a3 4a4 0
5a :3 0 4a5 4a6
0 4a8 2c6 4fb
5b :3 0 58 :3 0
59 :3 0 4aa 4ab
0 5a :3 0 4ac
4ad 0 4af 2c9
4b1 2cb 4b0 4af
:2 0 4f9 5c :3 0
58 :3 0 59 :3 0
4b4 4b5 0 5a
:3 0 4b6 4b7 0
4f1 34 :3 0 35
:3 0 4b9 4ba 0
34 :3 0 46 :3 0
4bc 4bd 0 5d
:2 0 2 :4 0 7b
:2 0 49 :2 0 47
:2 0 2cd 4c2 4c4
:3 0 2d0 4be 4c6
4bb 4c8 4c7 :2 0
37 :3 0 4a :3 0
4ca 4cb 0 39
:4 0 7c :4 0 3c
:2 0 3d :3 0 2d4
4cf 4d1 :3 0 3c
:2 0 60 :4 0 2d7
4d3 4d5 :3 0 3c
:2 0 61 :4 0 2da
4d7 4d9 :3 0 3c
:2 0 5a :3 0 2dd
4db 4dd :3 0 3c
:2 0 62 :4 0 2e0
4df 4e1 :3 0 3c
:2 0 56 :3 0 63
:3 0 47 :2 0 64
:2 0 2e3 4e4 4e8
2e7 4e3 4ea :3 0
2ea 4cc 4ec :2 0
4ee 2ed 4ef 4c9
4ee 0 4f0 2ef
0 4f1 2f1 4f4
:3 0 4f4 0 4f4
4f3 4f1 4f2 :6 0
4f6 8 :3 0 2f4
4f8 2f6 4f7 4f6
:2 0 4f9 2f8 :2 0
4fb 0 4fb 4fa
4a8 4f9 :6 0 565
1 :3 0 2c :3 0
28 :2 0 4fd 4fe
0 565 30 :3 0
76 :3 0 b :3 0
c :3 0 d :3 0
e :3 0 10 :3 0
22 :3 0 23 :3 0
2c :3 0 24 :3 0
25 :3 0 2fb 501
50c 500 50d 0
565 34 :3 0 35
:3 0 50f 510 0
34 :3 0 46 :3 0
512 513 0 47
:2 0 2 :4 0 7d
:2 0 49 :2 0 47
:2 0 306 518 51a
:3 0 309 514 51c
511 51e 51d :2 0
37 :3 0 4a :3 0
520 521 0 39
:4 0 7e :4 0 3c
:2 0 3d :3 0 30d
525 527 :3 0 310
522 529 :2 0 52b
313 52c 51f 52b
0 52d 315 0
565 1f :3 0 58
:3 0 59 :3 0 52f
530 0 531 :2 0
565 34 :3 0 35
:3 0 533 534 0
34 :3 0 46 :3 0
536 537 0 47
:2 0 2 :4 0 7f
:2 0 49 :2 0 47
:2 0 317 53c 53e
:3 0 31a 538 540
535 542 541 :2 0
37 :3 0 4a :3 0
544 545 0 39
:4 0 80 :4 0 3c
:2 0 3d :3 0 31e
549 54b :3 0 3c
:2 0 60 :4 0 321
54d 54f :3 0 3c
:2 0 81 :4 0 324
551 553 :3 0 3c
:2 0 58 :3 0 59
:3 0 556 557 0
327 555 559 :3 0
32a 546 55b :2 0
55d 32d 55e 543
55d 0 55f 32f
0 565 1f :3 0
58 :3 0 59 :3 0
561 562 0 563
:2 0 565 331 568
:3 0 568 343 568
567 565 566 :6 0
569 :2 0 2 74
568 56c :3 0 56b
569 56d :8 0 
353
4
:3 0 1 3 1
9 1 f 1
15 1 1b 1
21 1 27 1
2d 1 33 1
39 1 3f 1
45 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
69 1 6d 15
8 e 14 1a
20 26 2c 32
38 3e 44 4a
4e 52 56 5a
5e 62 68 6c
70 1 76 1
7c 1 82 1
88 1 8e 1
94 2 9e 9f
1 9a 2 a8
a9 1 a4 1
b0 1 ae 1
b5 1 bb 1
c1 1 c7 1
cd 2 d9 da
1 d3 1 e5
1 f1 2 f4
f6 2 fd ff
2 101 103 2
105 106 2 108
109 2 f9 10b
2 10d 10f 2
115 117 2 119
11b 2 11d 11e
2 120 121 2
111 123 2 125
127 2 12d 12f
2 131 133 2
135 136 2 138
139 2 129 13b
2 13d 13f 2
141 143 2 145
147 2 149 14b
2 14d 14f 2
151 153 2 155
157 2 159 15b
2 15d 15f 2
161 163 2 165
167 2 169 16b
2 16d 16f 2
171 173 2 175
177 2 179 17b
2 17d 17f 2
185 187 2 189
18b 2 18d 18e
2 190 191 2
181 193 2 195
197 2 19d 19f
2 1a1 1a3 2
1a5 1a6 2 1a8
1a9 2 199 1ab
2 1ad 1af 2
1b1 1b3 2 1b5
1b7 2 1b9 1bb
2 1bd 1bf 2
1c1 1c3 2 1c5
1c7 2 1c9 1cb
2 1cd 1cf 2
1d1 1d3 2 1d5
1d7 2 1d9 1db
2 1dd 1df 1
1e5 2 1e7 1e8
2 1e1 1ea 2
1ec 1ee 1 1f4
2 1f6 1f7 2
1f0 1f9 2 1fb
1fd 1 203 2
205 206 2 1ff
208 2 20a 20c
1 212 2 214
215 2 20e 217
2 219 21b 1
221 2 223 224
2 21d 226 2
228 22a 1 230
2 232 233 2
22c 235 2 237
239 2 23b 23d
2 23f 241 2
243 245 2 247
249 1 24f 2
251 252 2 24b
254 2 256 258
1 25e 2 260
261 2 25a 263
2 265 267 4
ed f3 f8 269
1 26b 1 26d
2 277 279 3
275 276 27b 2
284 286 2 283
288 1 28a 1
28c 3 291 292
293 1 297 2
295 297 1 29b
2 2b7 2bc 1
2c3 1 2be 2
2d6 2d8 3 2d4
2d5 2da 2 2e3
2e5 2 2e7 2e9
2 2eb 2ed 2
2ef 2f1 2 2f3
2f5 3 2fa 2fb
2fc 2 2f7 2fe
2 2e2 300 1
302 1 304 2
2cd 305 1 309
1 2c8 2 2c6
30d 2 31d 322
1 329 1 324
2 33c 33e 3
33a 33b 340 2
349 34b 2 34d
34f 2 351 353
2 355 357 2
359 35b 3 360
361 362 2 35d
364 2 348 366
1 368 1 36a
2 333 36b 1
36f 1 32e 2
32c 373 2 379
37a 2 37f 380
1 382 2 37c
382 2 390 392
3 38e 38f 394
2 39d 39f 2
39c 3a1 1 3a3
1 3a5 3 387
3a6 3ab 1 3ad
5 2a4 2a7 310
376 3ae 1 3b0
2 3bc 3c1 1
3c8 1 3c3 2
3db 3dd 3 3d9
3da 3df 2 3e8
3ea 2 3ec 3ee
2 3f0 3f2 2
3f4 3f6 2 3f8
3fa 3 3ff 400
401 2 3fc 403
2 3e7 405 1
407 1 409 2
3d2 40a 1 40e
1 3cd 2 3cb
412 3 418 419
41a 1 41e 2
41c 41e 1 423
1 427 2 429
42a 1 42e a
434 435 436 437
438 439 43a 43b
43c 43d 2 442
444 1 448 3
450 451 452 1
456 2 454 456
3 45d 45e 45f
1 463 2 461
463 1 470 1
474 2 476 477
2 489 48a 2
490 491 11 47b
47c 47d 47e 47f
480 481 482 483
484 485 486 487
48c 48d 48e 493
2 4a2 4a7 1
4ae 1 4a9 2
4c1 4c3 3 4bf
4c0 4c5 2 4ce
4d0 2 4d2 4d4
2 4d6 4d8 2
4da 4dc 2 4de
4e0 3 4e5 4e6
4e7 2 4e2 4e9
2 4cd 4eb 1
4ed 1 4ef 2
4b8 4f0 1 4f4
1 4b3 2 4b1
4f8 a 502 503
504 505 506 507
508 509 50a 50b
2 517 519 3
515 516 51b 2
524 526 2 523
528 1 52a 1
52c 2 53b 53d
3 539 53a 53f
2 548 54a 2
54c 54e 2 550
552 2 554 558
2 547 55a 1
55c 1 55e 11
26e 28d 3b1 415
42b 431 440 447
478 496 4fb 4ff
50e 52d 532 55f
564 f 7a 80
86 8c 92 98
a2 ac b3 b9
bf c5 cb d1
dd 
1
4
0 
56c
0
1
14
9
25
0 1 2 1 4 1 6 1
8 0 0 0 0 0 0 0
0 0 0 0 
6d 1 0
2 0 1
c7 1 0
cd 1 0
d3 1 0
f 1 0
b5 1 0
69 1 0
45 1 0
bb 1 0
3 1 0
88 1 0
4b 1 0
57 1 0
7c 1 0
9a 1 0
27 1 0
9 1 0
94 1 0
5f 1 0
33 1 0
8e 1 0
ae 1 0
21 1 0
4f 1 0
a4 1 0
c1 1 0
39 1 0
5b 1 0
3f 1 0
1b 1 0
76 1 0
15 1 0
82 1 0
2d 1 0
63 1 0
53 1 0
0

/
SHOW ERRORS FUNCTION FC_U_FD_SD;
ALTER FUNCTION FC_U_FD_SD COMPILE DEBUG;
Prompt == FUNCTION FC_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION FC_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
237
2 :e:
1FUNCTION:
1FC_U_PARTICIPANT:
1H_P_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_P_SECURITY_ID:
1H_P_PLANNED_START:
1TIMESTAMP:
1H_P_PLANNED_FINISH:
1SH_H_P_DELAY:
1PLS_INTEGER:
1SH_H_P_UNITS:
1SH_H_P_WORK_PERCENT:
1SH_H_P_ACTUAL:
1H_P_RES_ID:
1H_ID:
1RETURN:
1H_P_DELAY:
1H_P_UNITS:
1H_P_WORK_PERCENT:
1H_P_ACTUAL:
1H_SECURITY_ID:
132:
1A_ELEMENT_ID:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_PRJ_ASSIGN_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1H_CRI_SECURITY_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_START_DT:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_SD:
1DATE:
1H_FD:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_TASK_ACTUAL:
10:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1A_ASSIGNMENT_COUNT:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_LAST_DAY:
1H_MINUTES:
1H_LAST_MINUTES:
1H_TASK_TYPE:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_ETC:
1H_ROLLUP_BITS:
1H_CLOSE_TASK:
1H_DAY_MIN:
1H_COUNT:
1H_REMAINING:
1H_PRIORITY:
1H_PA_UNITS:
1H_CONF_FLAG:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1STMT:
17999:
1I_GET_DATE:
1I_RESCHED:
1I_BITFLAG:
1CURSOR:
1C_FD1:
1DAY_YEAR:
1ROW_NUMBER:
1OVER:
1CNT:
1CALENDAR_DAY_OF_YEAR:
1ELEMENT_ID:
1MOD:
1ROWNUM:
1SELECT * FROM (SELECT DAY_YEAR FROM (SELECT DAY_YEAR,ROW_NUMBER() OVER (ORDER+
1 BY DAY_YEAR) AS CNT   :n         FROM CALENDAR_DAY_OF_YEAR:n         WHERE E+
1LEMENT_ID = h_id AND DAY_YEAR >= h_SD ORDER BY DAY_YEAR ) :n         WHERE  M+
1OD(CNT,h_delay) = 0:n          ) WHERE ROWNUM<=1:
1C_P_DELAY:
1PMO_DB2M:
1REF_CURSOR:
1C_R_DELAY:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
1144:
1+:
1FPUT:
1               ENTER:: FC_U_PARTICIPANT(145) :: cplan.sql(16870) :: :
1:
1RA:
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1ELEMENT_TYPE:
1RESOURCE_TYPE:
1CRI_SECURITY_ID:
1RESOURCE_ID:
1PROJECT_ID:
1TABLE_TYPE:
1RESOURCE_ASSIGNMENTS:
1SELECT ra.RES_ASSIGNMENT_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,+
1:n      CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n      CASE WHEN +
1ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n      ra.RESOURCE_ID,:n      r+
1a.PROJECT_ID, ra.TABLE_TYPE:n      INTO a_res_assignment_id, a_participant, a+
1_element_id, a_element_type,:n      a_resource_type,:n      h_transfed_cri,:n+
1      a_participant_id,:n      h_project_id, h_table_type:n      FROM RESOURC+
1E_ASSIGNMENTS ra:n      WHERE ra.RES_ASSIGNMENT_ID = a_temp_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1178:
1           EXCEPTION:: FC_U_PARTICIPANT(179) :: cplan.sql(16904) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1PROJECT_ASSIGNMENT_ID:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1CONTOUR_TYPE:
1ASSIGN_UNITS:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID, RES+
1OURCE_TYPE, BIT_FLAG, :n         LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT,+
1 C_UNIT, CONTOUR_TYPE, :n         CASE WHEN ASSIGN_UNITS > UNITS_MSP THEN ASS+
1IGN_UNITS ELSE UNITS_MSP END, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UN+
1RESOLVED_FINISH,:n         CASE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SC+
1HED_WORK END, ASSIGNMENT_DELAY,LAST_SCHED_MIN,:n         TO_DATE(SubStr(UNRES+
1OLVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CA+
1PITAL_EXPENSE,:n         REGULAR_COST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RA+
1TE,:n         B_REGULAR_COST, B_SPECIAL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,+
1:n         MILESTONE_PERCENT, TASK_ID, ROLLUP_BITS:n         INTO a_res_assig+
1nment_id, h_prj_assign_id, h_project_id, h_res_id,h_res_type, h_bit_flag, :n +
1        h_last_submitted, h_contour, h_work, h_eunit, h_unit, h_bitflag,:n   +
1      h_percent_units, h_actual_start, h_work_todate, h_start_date, h_finish_+
1date,:n         h_effort, h_delay, h_last_day,:n         h_SD, h_FD, h_billab+
1le, h_capital_expense,:n         h_reg_cost, h_spec_cost, h_reg_sale, h_spec_+
1sale,:n         h_b_reg_cost, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n  +
1       h_work_percent, h_task_id, h_rollup_bits:n         FROM TASK_ASSIGNMEN+
1TS:n         WHERE TSK_ASSIGNMENT_ID = a_temp_id:
1211:
1           EXCEPTION:: FC_U_PARTICIPANT(212) :: cplan.sql(16937) :: :
1TASK_TYPE:
1MINUTE_PER_DAY:
1START_DT:
1FINISH_DT:
1UNRESOLVED_DURATION:
1PRIORITY:
1CONFIG_FLAG:
1ASSIGN_COUNT:
1SD:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1WORK_PERCENT:
1ETC:
1FORECAST_START:
1FORECAST_FINISH:
1TMT_WBS:
1SELECT PROJECT_ID, TASK_TYPE, MINUTE_PER_DAY, START_DT, FINISH_DT, UNRESOLVED+
1_DURATION, PRIORITY, CONFIG_FLAG, :n            ASSIGN_COUNT, SD, WORK_TODATE+
1, PLANNED_EFFORT + SCHED_EFFORT, WORK_PERCENT, ETC, COALESCE(FORECAST_START,F+
1ORECAST_FINISH):n            INTO h_project_id, h_task_type, h_per_day, h_sta+
1rt_date, h_finish_date, h_duration, h_priority, h_conf_flag,:n            h_a+
1ssign_count, h_work_type, h_work_todate, h_effort, h_work_percent, h_etc, h_s+
1tart_DT:n            FROM TMT_WBS WHERE ELEMENT_ID = a_temp_id:
1231:
1           EXCEPTION:: FC_U_PARTICIPANT(232) :: cplan.sql(16957) :: :
1239:
1                EXIT:: FC_U_PARTICIPANT(240) :: cplan.sql(16965) :: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1BITAND:
1SC_WBS_ENFORCE_TC_TS:
1247:
1                EXIT:: FC_U_PARTICIPANT(248) :: cplan.sql(16973) :: :
1SC_TIMESHEET_STEP_EXISTS:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1258:
1                EXIT:: FC_U_PARTICIPANT(259) :: cplan.sql(16984) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1IS NOT NULL:
1-:
1267:
1                EXIT:: FC_U_PARTICIPANT(268) :: cplan.sql(16993) :: :
1CANNOT_UPDATE_ASSIGN_ACCEPT_RE:
1DB2TIMESTAMP:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_sched_start:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_start, 1, 10)):
1289:
1           EXCEPTION:: FC_U_PARTICIPANT(290) :: cplan.sql(17015) :: :
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME('08::00')) INTO h_sched_start:n                        FROM DUAL:
1306:
1           EXCEPTION:: FC_U_PARTICIPANT(307) :: cplan.sql(17032) :: :
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_sched_finish:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_finish, 1, 10)):
1329:
1           EXCEPTION:: FC_U_PARTICIPANT(330) :: cplan.sql(17055) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME('17::00')) INTO h_sched_finish:n                        FROM DUAL:
1346:
1           EXCEPTION:: FC_U_PARTICIPANT(347) :: cplan.sql(17072) :: :
1SC_SS:
1SCHED_START:
1SCHED_FINISH:
1SCHED_DURATION:
1UPDATE TMT_WBS SET SCHED_START = h_sched_start, SCHED_FINISH = h_sched_finish+
1, SCHED_DURATION = h_duration:n                     WHERE ELEMENT_ID = a_temp+
1_id:
1FOUND:
1TRUE:
1100:
1371:
1           EXCEPTION:: FC_U_PARTICIPANT(372) :: cplan.sql(17097) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_DURATION:
1UPDATE TMT_WBS SET PLANNED_START = h_sched_start, PLANNED_FINISH = h_sched_fi+
1nish, PLANNED_DURATION = h_duration:n                     WHERE ELEMENT_ID = +
1a_temp_id:
1391:
1           EXCEPTION:: FC_U_PARTICIPANT(392) :: cplan.sql(17117) :: :
1SC_SQL_SUCCESS:
1FC_ROLLUP:
1SC_FIXED_DURATION:
1SC_FD_EFFORT_DRIVEN:
1COUNT:
1SELECT COUNT(DAY_YEAR) INTO h_count :n                     FROM CALENDAR_DAY_+
1OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n              +
1       AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_date, 1, 10)) AND TO_DATE(+
1SubStr(h_finish_date, 1, 10)):
1418:
1           EXCEPTION:: FC_U_PARTICIPANT(419) :: cplan.sql(17144) :: :
1438:
1           EXCEPTION:: FC_U_PARTICIPANT(439) :: cplan.sql(17164) :: :
1455:
1           EXCEPTION:: FC_U_PARTICIPANT(456) :: cplan.sql(17181) :: :
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1       SELECT 'X' FROM TASK_DAY_OF_YEAR:n                        WHERE PROJEC+
1T_ID = h_project_id AND TASK_ID = a_temp_id :n                        AND ACT+
1UAL_FLAG = 1 AND DAY_YEAR > TO_DATE(SubStr(h_sched_finish, 1, 10))):
1483:
1           EXCEPTION:: FC_U_PARTICIPANT(484) :: cplan.sql(17209) :: :
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1          SELECT 'X' FROM TASK_ASSIGNMENTS:n                           WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = a_temp_id :n                         +
1  AND TO_DATE(SubStr(START_DT, 1, 10)) > TO_DATE(SubStr(h_sched_finish, 1, 10+
1))):
1502:
1           EXCEPTION:: FC_U_PARTICIPANT(503) :: cplan.sql(17228) :: :
1511:
1                EXIT:: FC_U_PARTICIPANT(512) :: cplan.sql(17237) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1530:
1           EXCEPTION:: FC_U_PARTICIPANT(531) :: cplan.sql(17256) :: :
1547:
1           EXCEPTION:: FC_U_PARTICIPANT(548) :: cplan.sql(17273) :: :
1FC_START_FINISH_DT:
1TA:
1PA:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1 SELECT 'X' FROM TASK_ASSIGNMENTS ta:n                  WHERE ta.PROJECT_ID =+
1 h_project_id AND ta.TASK_ID = a_temp_id:n                  AND ta.PROJECT_AS+
1SIGNMENT_ID IS NOT NuLL AND EXISTS (:n                  SELECT 'X' FROM TASK_+
1ASSIGNMENTS pa:n                  WHERE pa.PROJECT_ID = h_project_id AND pa.T+
1SK_ASSIGNMENT_ID = ta.PROJECT_ASSIGNMENT_ID :n                  AND (TO_DATE(+
1SubStr(h_sched_start, 1, 10)) < TO_DATE(SubStr(pa.START_DT, 1, 10)) OR TO_DAT+
1E(SubStr(h_sched_finish, 1, 10)) > TO_DATE(SubStr(pa.FINISH_DT, 1, 10))))):
1584:
1           EXCEPTION:: FC_U_PARTICIPANT(585) :: cplan.sql(17310) :: :
1592:
1                EXIT:: FC_U_PARTICIPANT(593) :: cplan.sql(17318) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_CHANGE_TA_DATES:
1605:
1                EXIT:: FC_U_PARTICIPANT(606) :: cplan.sql(17331) :: :
1ELSIF:
1615:
1                EXIT:: FC_U_PARTICIPANT(616) :: cplan.sql(17341) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1A:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT A.ELEMENT_ID FROM TASK_ASSIGNMENTS TA, ACTIVITIES A:n     +
1          WHERE TA.TASK_ID = a_temp_id:n               AND TA.TSK_ASSIGNMENT_+
1ID = A.TSK_ASSIGNMENT_ID:n               AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT+
1_ID:n               AND A.TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
1641:
1           EXCEPTION:: FC_U_PARTICIPANT(642) :: cplan.sql(17367) :: :
1649:
1                EXIT:: FC_U_PARTICIPANT(650) :: cplan.sql(17375) :: :
1JOIN:
1TIMESHEET_APPROVAL_STATUS:
1APV:
1WEEK_OF:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n               SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1        ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURCE_I+
1D:n               WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = a_temp_+
1id AND:n               (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     ) <= +
1apv.WEEK_OF):
1670:
1           EXCEPTION:: FC_U_PARTICIPANT(671) :: cplan.sql(17396) :: :
1678:
1                EXIT:: FC_U_PARTICIPANT(679) :: cplan.sql(17404) :: :
1TS_APPROVAL_ERROR:
1FC_U_TASK_PERCENT:
1695:
1                EXIT:: FC_U_PARTICIPANT(696) :: cplan.sql(17421) :: :
1706:
1                EXIT:: FC_U_PARTICIPANT(707) :: cplan.sql(17432) :: :
1SELECT UNRESOLVED_START, UNRESOLVED_FINISH, UNITS_MSP INTO h_ta_start_DT, h_t+
1a_finish_DT, h_pa_units:n               FROM TASK_ASSIGNMENTS:n              +
1 WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1723:
1           EXCEPTION:: FC_U_PARTICIPANT(724) :: cplan.sql(17449) :: :
1731:
1                EXIT:: FC_U_PARTICIPANT(732) :: cplan.sql(17457) :: :
1<:
1740:
1                EXIT:: FC_U_PARTICIPANT(741) :: cplan.sql(17466) :: :
1747:
1                EXIT:: FC_U_PARTICIPANT(748) :: cplan.sql(17473) :: :
1SELECT MINUTE_PER_DAY, TASK_TYPE, WORK_TODATE, START_DT, FINISH_DT, CONFIG_FL+
1AG :n            INTO h_per_day, h_task_type, h_task_actual, h_task_start_DT,+
1 h_task_finish_DT, h_conf_flag:n            FROM TMT_WBS:n            WHERE P+
1ROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1766:
1           EXCEPTION:: FC_U_PARTICIPANT(767) :: cplan.sql(17492) :: :
1775:
1                EXIT:: FC_U_PARTICIPANT(776) :: cplan.sql(17501) :: :
1796:
1                EXIT:: FC_U_PARTICIPANT(797) :: cplan.sql(17522) :: :
1SELECT COUNT(DAY_YEAR) INTO h_count :n                     FROM CALENDAR_DAY_+
1OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n              +
1       AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_task_start_DT, 1, 10)) AND TO_DA+
1TE(SubStr(h_task_finish_DT, 1, 10)):
1817:
1           EXCEPTION:: FC_U_PARTICIPANT(818) :: cplan.sql(17543) :: :
1FC_U_FD_SD:
1838:
1                EXIT:: FC_U_PARTICIPANT(839) :: cplan.sql(17564) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME(h_finish_date)):n                  INTO h_sched_finish:n           +
1       FROM DUAL:
1859:
1           EXCEPTION:: FC_U_PARTICIPANT(860) :: cplan.sql(17585) :: :
1STRCMP:
1FC_TPHASE_SCHED_ASSIGN:
1FC_U_TDY_LAST_ACTUAL:
12:
1FC_FD_TA_TDY:
1FD:
1SC_UHF:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET FD = pmo_cnst.SC_UHF, ACTUAL_FINISH = h_sched_fin+
1ish, ETC = 0, :n                        MILESTONE_PERCENT = 10000, SCHED_WORK+
1 = WORK_TODATE, SCHED_FINISH = h_sched_finish :n                        WHERE+
1 TSK_ASSIGNMENT_ID = a_temp_id:
1905:
1           EXCEPTION:: FC_U_PARTICIPANT(906) :: cplan.sql(17631) :: :
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET FD = pmo_cnst.SC_SF, ACTUAL_FINISH = NULL, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000)/SCHED_WORK :n                        WHER+
1E TSK_ASSIGNMENT_ID = a_temp_id:
1926:
1           EXCEPTION:: FC_U_PARTICIPANT(927) :: cplan.sql(17652) :: :
1SELECT TO_DATE(SubStr(h_start_date, 1, 10)), TO_DATE(SubStr(h_sched_finish, 1+
1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n              +
1    INTO h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n +
1                 FROM TASK_ASSIGNMENTS:n                  WHERE TSK_ASSIGNMEN+
1T_ID = a_temp_id:
1946:
1           EXCEPTION:: FC_U_PARTICIPANT(947) :: cplan.sql(17672) :: :
1960:
1                EXIT:: FC_U_PARTICIPANT(961) :: cplan.sql(17686) :: :
1FC_DELAY:
1OPEN:
1CLOSE:
1997:
1           EXCEPTION:: FC_U_PARTICIPANT(998) :: cplan.sql(17723) :: :
1IS NULL:
11004:
1                EXIT:: FC_U_PARTICIPANT(1005) :: cplan.sql(17730) :: :
1CANNOT_ASSIGN_RESOURCE_CALENDA:
11018:
1                EXIT:: FC_U_PARTICIPANT(1019) :: cplan.sql(17744) :: :
1SELECT START_DT INTO h_start_date:n                  FROM TMT_WBS:n          +
1        WHERE ELEMENT_ID = h_task_id:
11040:
1           EXCEPTION:: FC_U_PARTICIPANT(1041) :: cplan.sql(17766) :: :
1SELECT * FROM (SELECT DAY_YEAR FROM CALENDAR_DAY_OF_YEAR :
1WHERE ELEMENT_ID = ':
1' AND DAY_YEAR < TO_DATE(SubStr(':
1', 1, 10)) :
1ORDER BY DAY_YEAR DESC) WHERE ROWNUM<=:
1LOOP:
1EXIT:
11098:
1           EXCEPTION:: FC_U_PARTICIPANT(1099) :: cplan.sql(17824) :: :
11113:
1           EXCEPTION:: FC_U_PARTICIPANT(1114) :: cplan.sql(17839) :: :
11123:
1                EXIT:: FC_U_PARTICIPANT(1124) :: cplan.sql(17849) :: :
11129:
1                EXIT:: FC_U_PARTICIPANT(1130) :: cplan.sql(17855) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_dayofyear, 1, 10)), PMO_ORAST+
1D.TIME(h_start_date)):n                  INTO h_start_date:n                 +
1 FROM DUAL:
11147:
1           EXCEPTION:: FC_U_PARTICIPANT(1148) :: cplan.sql(17873) :: :
11158:
1                EXIT:: FC_U_PARTICIPANT(1159) :: cplan.sql(17884) :: :
11166:
1                EXIT:: FC_U_PARTICIPANT(1167) :: cplan.sql(17892) :: :
1103079040:
11177:
1                EXIT:: FC_U_PARTICIPANT(1178) :: cplan.sql(17903) :: :
1INVALID_PARAMS:
1TRUNC:
1*:
1/:
110000.00:
10.5:
1SELECT COUNT(*) INTO h_temp_var:n                  FROM TASK_DAY_OF_YEAR:n   +
1               WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = a_temp+
1_id:
11201:
1           EXCEPTION:: FC_U_PARTICIPANT(1202) :: cplan.sql(17927) :: :
11216:
1                EXIT:: FC_U_PARTICIPANT(1217) :: cplan.sql(17942) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                     INTO h_start_date:n         +
1            FROM DUAL:
11249:
1           EXCEPTION:: FC_U_PARTICIPANT(1250) :: cplan.sql(17975) :: :
10.49:
1FC_FD_U_TDY:
1PMO_FUNC:
1BIT_OR:
1SC_BIT_29:
1U_ASSIGN_STRING:
11275:
1           EXCEPTION:: FC_U_PARTICIPANT(1276) :: cplan.sql(18001) :: :
11287:
1                EXIT:: FC_U_PARTICIPANT(1288) :: cplan.sql(18013) :: :
190:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1SC_PERCENT_UNITS_BIT:
1CONSIDER:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, UNITS_MSP = h_percent_units,:n     +
1             C_EFFORT = 0, C_UNIT = 0, C_CONTOUR = 0, CONTOUR_TYPE = 1,:n    +
1              ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,h_rollup_bits):n     +
1             WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11317:
1           EXCEPTION:: FC_U_PARTICIPANT(1318) :: cplan.sql(18043) :: :
1FC_DEL_NOACTUAL:
1SC_BIT_30:
11364:
1           EXCEPTION:: FC_U_PARTICIPANT(1365) :: cplan.sql(18090) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                     INTO h_start_date:n+
1                     FROM DUAL:
11381:
1           EXCEPTION:: FC_U_PARTICIPANT(1382) :: cplan.sql(18107) :: :
1FC_RESCHEDULE:
11397:
1                EXIT:: FC_U_PARTICIPANT(1398) :: cplan.sql(18123) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                       BAK_ASSIGN_STRING = NULL+
1:n                  WHERE TSK_ASSIGNMENT_ID = A_TEMP_ID:
1BAK_START_DT:
1BAK_FINISH_DT:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(pmo_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)),:n                  B+
1AK_START_DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(S+
1CHED_FINISH,PLANNED_FINISH),:n                  BAK_ASSIGN_STRING = ASSIGN_ST+
1RING:n                  WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11422:
1           EXCEPTION:: FC_U_PARTICIPANT(1423) :: cplan.sql(18148) :: :
11431:
1                EXIT:: FC_U_PARTICIPANT(1432) :: cplan.sql(18157) :: :
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT ELEMENT_ID FROM ACTIVITIES:n               WHERE TSK_ASSIG+
1NMENT_ID = a_temp_id:n               AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n   +
1            AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
11454:
1           EXCEPTION:: FC_U_PARTICIPANT(1455) :: cplan.sql(18180) :: :
11462:
1                EXIT:: FC_U_PARTICIPANT(1463) :: cplan.sql(18188) :: :
1MIN:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) :n                     INTO h_count, h_+
1dayofyear :n                     FROM TASK_DAY_OF_YEAR:n                     +
1WHERE PROJECT_ID = h_project_id:n                     AND TSK_ASSIGNMENT_ID =+
1 a_temp_id:n                     AND ACTUAL_FLAG = 0:
11489:
1           EXCEPTION:: FC_U_PARTICIPANT(1490) :: cplan.sql(18215) :: :
1SCHED_MIN:
1ACTUAL_MIN:
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                           FROM+
1 TASK_DAY_OF_YEAR :n                           WHERE PROJECT_ID = h_project_i+
1d AND TSK_ASSIGNMENT_ID = a_temp_id AND DAY_YEAR = TO_DATE(SubStr(h_last_subm+
1itted, 1, 10)):
11516:
1           EXCEPTION:: FC_U_PARTICIPANT(1517) :: cplan.sql(18242) :: :
110000:
1TO_NUMBER:
1FC_U_ASSIGN_PERCENT:
1SELECT  ( TO_DATE(SubStr(h_finish_date, 1, 10)) )  INTO  h_last_submitted FRO+
1M DUAL:
11634:
1           EXCEPTION:: FC_U_PARTICIPANT(1635) :: cplan.sql(18360) :: :
1SELECT  ( PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_finish_date, 1, 10)), PMO_+
1ORASTD.TIME('00::00')) + 1      )  INTO  h_start_date FROM DUAL:
11648:
1           EXCEPTION:: FC_U_PARTICIPANT(1649) :: cplan.sql(18374) :: :
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,pmo_cnst.SC_SCHED_BIT),:n                     SCHED_WORK = h_new_actua+
1l, WORK_TODATE = h_new_actual, ETC = 0, MILESTONE_PERCENT = 10000,:n         +
1            FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION +
1= 0:n                     WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11670:
1           EXCEPTION:: FC_U_PARTICIPANT(1671) :: cplan.sql(18396) :: :
11683:
1                EXIT:: FC_U_PARTICIPANT(1684) :: cplan.sql(18409) :: :
11707:
1                EXIT:: FC_U_PARTICIPANT(1708) :: cplan.sql(18433) :: :
11714:
1                EXIT:: FC_U_PARTICIPANT(1715) :: cplan.sql(18440) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = h_p_work_percent,:n          +
1     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCENT_COMPLETE_B+
1IT):n               WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11768:
1           EXCEPTION:: FC_U_PARTICIPANT(1769) :: cplan.sql(18494) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERC+
1ENT_COMPLETE_BIT):n               WHERE PROJECT_ID = h_project_id AND ELEMENT+
1_ID = h_task_id:
11792:
1           EXCEPTION:: FC_U_PARTICIPANT(1793) :: cplan.sql(18518) :: :
11803:
1                EXIT:: FC_U_PARTICIPANT(1804) :: cplan.sql(18529) :: :
1SECURITY_ID:
1SELECT ra.SECURITY_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,:n     +
1       CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n            CASE +
1WHEN ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n            ra.RESOURCE_I+
1D,:n            ra.PROJECT_ID, ra.TABLE_TYPE:n            INTO h_security_id,+
1 a_participant, a_element_id, a_element_type,:n            a_resource_type,:n+
1            h_transfed_cri,:n            a_participant_id,:n            h_pro+
1ject_id, h_table_type:n            FROM RESOURCE_ASSIGNMENTS ra WHERE ra.RES_+
1ASSIGNMENT_ID = a_res_assignment_id:
11827:
1           EXCEPTION:: FC_U_PARTICIPANT(1828) :: cplan.sql(18553) :: :
1NOT:
11836:
1                EXIT:: FC_U_PARTICIPANT(1837) :: cplan.sql(18562) :: :
11845:
1                EXIT:: FC_U_PARTICIPANT(1846) :: cplan.sql(18571) :: :
1SC_TABLE_WBS:
1FC_U_ASSIGNED_SECURITY:
11861:
1                EXIT:: FC_U_PARTICIPANT(1862) :: cplan.sql(18587) :: :
11866:
1                EXIT:: FC_U_PARTICIPANT(1867) :: cplan.sql(18592) :: :
1STATE:: :
0

0
0
2a06
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a0 f4 b4 bf c8
:10 a0 12a bd b7 11 a4 b1 a3
:2 a0 6b 1c 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6e 7e a0 b4
2e 7e 6e b4 2e 6e a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :2 a0 6e 7e a0 b4 2e
7e 6e b4 2e 6e a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 51 d a0
6e d :2 a0 d :2 a0 d :2 a0 d
:20 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :52 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :24 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :3 a0 51 a5 b
:2 a0 6b a5 b 5a a0 7e a0
6b b4 2e :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 b7 19 3c :2 a0 d
:2 a0 d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 7e b4
2e :2 5a :2 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a a0 7e
a0 51 a5 b b4 2e 5a 52
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e :10 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
a0 4d d b7 19 3c b7 :10 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c a0
51 d b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :3 a0 a5 b d
b7 19 3c b7 a0 51 d a0
51 d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e 52 10
:d a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :10 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 51 a5 b
7e 51 b4 2e d b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e 52 10 a0 6e
d a0 51 d b7 19 3c b7
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d :d a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :e a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c b7 19 3c
:10 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e 52 10 5a a
10 a0 6e d a0 51 d b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 7e 51
b4 2e a 10 5a :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e 52 10 5a a 10 :6 a0 a5
b d b7 19 3c a0 51 d
:24 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :e a0 51 a5
b 51 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 a5 b
d b7 :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
51 a5 b 65 b7 :2 19 3c b7
:2 19 3c a0 b7 :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 a0 51 d :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 a0 b7 :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e a0 51 d b7 :2 19 3c a0
51 d :18 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c a0
51 d :1c a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c :3 a0
51 a5 b d :8 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
a5 b d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 a5
b d b7 19 3c :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 51 a5 b 65 a0
b7 a0 7e b4 2e 5a a0 7e
b4 2e 5a a 10 :2 a0 d :2 a0
d :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c a0 7e b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 a0
b7 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :2 19 3c b7 19 3c :11 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b :2 a0 6b a5
b 5a a0 7e a0 6b b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c a0 51 d
a0 51 d :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e 5a
52 10 :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e 52
10 a0 51 d :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 a0 6e
d :6 a0 a5 b d b7 19 3c
:17 a0 51 a5 b :2 a0 51 a5 b
a5 b d :3 a0 a5 b d :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 51 a5 b
65 b7 :2 a0 d a0 51 d a0
51 d b7 :2 19 3c a0 b7 :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b :2 a0 a5 b
d a0 7e 51 b4 2e d :c a0
a5 b d :2 a0 51 a5 b 7e
51 b4 2e 5a a0 7e b4 2e
:2 5a a 10 :9 a0 51 a5 b d
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :11 a0 51 a5 b 51 a0 51
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :e a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e a 10 :a a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 19
3c :13 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d :c a0 a5
b d :3 a0 a5 b d :2 a0 6b
51 d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 a0 b7 19 :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e 52 10 :2 a0 :2 51 a5 b 7e
6e b4 2e 5a :2 a0 d b7 :2 a0
d b7 :2 19 3c :6 a0 a5 b d
a0 4d d :2 a0 e9 dd b3 :2 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :17 a0 51 a5 b :2 a0 51 a5
b a5 b d :3 a0 a5 b d
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 51 a5
b 65 b7 a0 51 d b7 :2 19
3c a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e a0 51 d a0
51 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 19 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d a0
4d d a0 6e d :2 a0 51 a5
b 7e 51 b4 2e a0 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
d :3 a0 11c 11d b7 a0 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
d :3 a0 11c 11d b7 :2 19 3c :3 a0
51 a5 b 7e 51 b4 2e :2 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :2 a0 e9 d3 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c b7 a0 47 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 :2 19
3c b7 19 3c :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 51
d a0 51 d b7 :2 19 3c a0
b7 :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e a 10 :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
:3 a0 51 a5 b d b7 :2 19 3c
:4 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 51 d :7 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 51
65 b7 19 3c b7 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e 52 10 a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c :4 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d :9 a0 51 a5 b
d :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b d :5 a0 :2 51 a5 b
d :13 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d :c a0 a5
b d :3 a0 a5 b d :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 51 a5 b 65
b7 a0 51 d a0 51 d :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 19 3c :3 a0 6b :2 a0
6b :2 a0 6b :2 a0 6b a5 b :2 a0
6b a5 b d :f a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c b7 :2 19 3c b7 :2 19 3c
a0 7e 51 b4 2e a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :9 a0
51 a5 b d b7 19 3c a0
7e b4 2e 5a :4 a0 51 a5 b
d b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e :4 a0 51 a5 b d b7
:4 a0 51 a5 b d b7 :2 19 3c
b7 :2 19 3c a0 7e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 6b
a5 b 5a d :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
b7 19 3c a0 51 d :a a0 51
a5 b :2 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 a0 b7 a0 7e 51 b4 2e
:4 a0 12a :16 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :3 a0 a5 b
d :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 51
a5 b 65 b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e a0 51 d :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c :3 a0 51 a5 b d :3 a0
51 a5 b d :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e 52 10 a0 4d
d :c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
:2 a0 d b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 7e 51
b4 2e d :c a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :c a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e 7e :2 a0 51 a5
b b4 2e d b7 :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d b7 :2 19 3c a0 51 d :5 a0
a5 b 51 a5 b 7e :3 a0 a5
b 51 a5 b b4 2e 5a 7e
51 b4 2e a5 b d :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e 7e :2 a0 51 a5 b b4 2e
d b7 :3 a0 51 a5 b d b7
:2 19 3c :9 a0 51 a5 b d :5 a0
a5 b 51 a5 b 7e :3 a0 a5
b 51 a5 b b4 2e 5a 7e
51 b4 2e a5 b d :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d :7 a0 51 a5 b :2 a0 51 a5
b a5 b d a0 51 d :c a0
a5 b d b7 19 3c b7 a0
51 d :3 a0 51 a5 b d :1b a0
51 a5 b :2 a0 51 a5 b a5
b d :3 a0 51 a5 b d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :13 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d :8 a0 51 :2 a0 51 a5
b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 51 a5 b 65 b7 19
3c b7 19 3c b7 :2 19 3c :3 a0
51 a5 b d a0 51 d b7
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d b7 :2 19 3c :1b a0
51 a5 b :2 a0 51 a5 b a5
b d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
51 a5 b 65 a0 b7 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :3 a0 a5 b d
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 51 a5
b 65 b7 19 :20 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a 7e
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :2 a0 6b :2 a0
a5 b 7e 51 b4 2e :2 a0 6b
51 d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c b7 :2 19 3c
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :3 a0 6b d :2 a0 6b :5 a0 a5
b d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
2a06
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 7b 6f 73
77 37 82 8b 87 6e 93 a0
9c 6b a8 b1 ad 9b b9 c6
c2 98 ce df d3 d7 db c1
e6 fb ef f3 f7 be 102 ee
107 10b 10f 113 130 11b 11f 127
12b eb 14c 137 13b 143 147 11a
16c 157 15b 163 167 117 188 173
177 17f 183 156 1a5 193 153 197
198 1a0 192 1c2 1b0 18f 1b4 1b5
1bd 1af 1df 1cd 1ac 1d1 1d2 1da
1cc 1fc 1ea 1c9 1ee 1ef 1f7 1e9
219 207 1e6 20b 20c 214 206 236
224 203 228 229 231 223 253 241
220 245 246 24e 240 270 25e 23d
262 263 26b 25d 28d 27b 25a 27f
280 288 27a 2aa 298 277 29c 29d
2a5 297 2c7 2b5 294 2b9 2ba 2c2
2b4 2e4 2d2 2b1 2d6 2d7 2df 2d1
301 2ef 2ce 2f3 2f4 2fc 2ee 31d
30c 310 318 2eb 335 324 328 330
30b 351 340 344 34c 308 369 358
35c 364 33f 385 374 378 380 33c
39d 38c 390 398 373 3b9 3a8 3ac
3b4 370 3d1 3c0 3c4 3cc 3a7 3ed
3dc 3e0 3e8 3a4 405 3f4 3f8 400
3db 421 410 414 41c 3d8 439 428
42c 434 40f 455 444 448 450 40c
471 45c 460 463 464 46c 443 48e
47c 440 480 481 489 47b 4aa 499
49d 478 4a5 498 4c6 4b5 4b9 495
4c1 4b4 4e2 4d1 4d5 4b1 4dd 4d0
4fe 4ed 4f1 4cd 4f9 4ec 51a 509
50d 515 4e9 532 521 525 52d 508
54e 53d 541 505 549 53c 56a 559
55d 539 565 558 586 575 579 555
581 574 5a2 591 595 571 59d 590
5be 5ad 5b1 58d 5b9 5ac 5da 5c9
5cd 5a9 5d5 5c8 5f6 5e5 5e9 5c5
5f1 5e4 612 601 605 5e1 60d 600
62e 61d 621 5fd 629 61c 64a 639
63d 619 645 638 667 655 635 659
65a 662 654 684 672 651 676 677
67f 671 6a1 68f 66e 693 694 69c
68e 6bd 6ac 6b0 68b 6b8 6ab 6d9
6c8 6cc 6a8 6d4 6c7 6f5 6e4 6e8
6c4 6f0 6e3 711 700 704 6e0 70c
6ff 72d 71c 720 6fc 728 71b 749
738 73c 718 744 737 765 754 758
734 760 753 781 770 774 750 77c
76f 79d 78c 790 76c 798 78b 7b9
7a8 7ac 788 7b4 7a7 7d5 7c4 7c8
7a4 7d0 7c3 7f1 7e0 7e4 7c0 7ec
7df 80d 7fc 800 7dc 808 7fb 829
818 81c 7f8 824 817 845 834 838
814 840 833 861 850 854 830 85c
84f 87d 86c 870 84c 878 86b 899
888 88c 868 894 887 8b5 8a4 8a8
884 8b0 8a3 8d1 8c0 8c4 8a0 8cc
8bf 8ed 8dc 8e0 8bc 8e8 8db 909
8f8 8fc 8d8 904 8f7 925 914 918
8f4 920 913 941 930 934 910 93c
92f 95d 94c 950 92c 958 94b 979
968 96c 948 974 967 995 984 988
964 990 983 9b1 9a0 9a4 980 9ac
99f 9cd 9bc 9c0 99c 9c8 9bb 9e9
9d8 9dc 9b8 9e4 9d7 a06 9f4 9d4
9f8 9f9 a01 9f3 a23 a11 9f0 a15
a16 a1e a10 a3f a2e a32 a0d a3a
a2d a5c a4a a2a a4e a4f a57 a49
a78 a67 a6b a46 a73 a66 a94 a83
a87 a63 a8f a82 ab0 a9f aa3 a7f
aab a9e acc abb abf a9b ac7 aba
ae8 ad7 adb ab7 ae3 ad6 b04 af3
af7 ad3 aff af2 b20 b0f b13 aef
b1b b0e b3c b2b b2f b0b b37 b2a
b58 b47 b4b b27 b53 b46 b74 b63
b67 b43 b6f b62 b90 b7f b83 b5f
b8b b7e bad b9b b7b b9f ba0 ba8
b9a bc9 bb8 bbc bc4 b97 be1 bd0
bd4 bdc bb7 bfd bec bf0 bf8 bb4
be8 c04 c15 c16 c19 c1d c21 c25
c29 c2d c31 c35 c39 c3d c41 c45
c49 c4d c51 c55 c59 c5d c69 c6e
c70 c7c c80 c9e c86 c8a c8e c91
c99 c85 cbe ca9 cad c82 cb1 cb9
ca8 cc5 cc9 ca5 ccd cd1 cd5 cd8
cdd cde 1 ce0 ce5 ce9 ced cf0
cf5 cf9 cfd d00 d05 d06 d08 d0d
d10 d14 d15 d1a d1f d22 d27 d28
d2d d30 d34 d35 d3a d3d d42 d43
d48 d4b d50 d51 d56 d59 d5e d5f
d64 d67 d6b d6c d71 d74 d79 d7a
d7f d82 d87 d88 d8d d90 d94 d98
d9d da0 da4 da5 daa dad db2 db3
db8 dbd dbe dc0 dc5 dc6 dc8 dc9
dce dd1 dd6 dd7 ddc ddf de3 de7
dec def df3 df4 df9 dfc e01 e02
e07 e0c e0d e0f e14 e15 e17 e18
e1d e20 e25 e26 e2b e2e e32 e36
e3a e3b e3d e42 e43 e45 e46 e4b
e4e e53 e54 e59 e5c e60 e64 e68
e69 e6b e70 e71 e73 e74 e79 e7c
e81 e82 e87 e8a e8e e92 e96 e97
e99 e9e e9f ea1 ea2 ea7 eaa eaf
eb0 eb5 eb8 ebc ec0 ec4 ec5 ec7
ecc ecd ecf ed0 ed5 ed8 edd ede
ee3 ee6 eeb eec ef1 ef4 ef8 ef9
efe f01 f06 f07 f0c f0f f14 f15
f1a f1d f22 f23 f28 f2b f2f f30
f35 f38 f3d f3e f43 f46 f4b f4c
f51 f52 f57 f59 f5d f60 f64 f68
f6b f6f f73 f76 f79 f7e f81 f84
f87 f88 f8d f8e 1 f90 f95 f99
f9d fa0 fa5 faa fad fb1 fb2 fb7
fb8 fbd fbf fc3 fc6 fca fcd fd1
fd5 fda fde fe2 fe6 fea fee ff2
ff6 ffa ffe 1002 1006 100a 100e 1012
1016 101a 101e 1022 1026 102a 102e 1032
1036 103a 103e 1042 1046 104a 104e 1052
1056 105a 105e 1062 1066 106a 106e 1072
1076 107a 107e 1082 108e 1092 1096 1099
109d 10a1 10a3 10a7 10ab 10af 10b2 10b6
10ba 10bc 10bd 10c2 1 10c6 10ca 10ce
10d1 10d5 10d9 10dd 10e1 10e4 10e8 10ec
10ef 10f2 10f7 10fa 10fd 1100 1101 1106
1107 1 1109 110e 1112 1116 1119 111e
1123 1126 112a 112b 1130 1133 1138 1139
113e 1141 1146 1147 114c 114f 1153 1154
1159 115c 1161 1162 1167 116a 116e 1172
1175 1178 1179 117b 117c 1181 1182 1187
1189 118d 1190 1192 1196 1198 11a4 11a6
11a8 11a9 11ae 11b2 11b4 11c0 11c2 11c6
11ca 11cd 11d1 11d4 11d8 11db 11dc 11e1
11e4 11e8 11ec 11f0 11f4 11f8 11fc 1200
1204 1208 120c 1210 1214 1218 121c 1220
1224 1228 122c 1230 1234 1238 123c 1240
1244 1248 124c 1250 1254 1258 125c 1260
1264 1268 126c 1270 1274 1278 127c 1280
1284 1288 128c 1290 1294 1298 129c 12a0
12a4 12a8 12ac 12b0 12b4 12b8 12bc 12c0
12c4 12c8 12cc 12d0 12d4 12d8 12dc 12e0
12e4 12e8 12ec 12f0 12f4 12f8 12fc 1300
1304 1308 130c 1310 1314 1318 131c 1320
1324 1328 132c 1338 133c 1340 1343 1347
134b 134d 1351 1355 1359 135c 1360 1364
1366 1367 136c 1 1370 1374 1378 137b
137f 1383 1387 138b 138e 1392 1396 1399
139c 13a1 13a4 13a7 13aa 13ab 13b0 13b1
1 13b3 13b8 13bc 13c0 13c3 13c8 13cd
13d0 13d4 13d5 13da 13dd 13e2 13e3 13e8
13eb 13f0 13f1 13f6 13f9 13fd 13fe 1403
1406 140b 140c 1411 1414 1418 141c 141f
1422 1423 1425 1426 142b 142c 1431 1433
1437 143a 143c 1440 1442 144e 1450 1452
1453 1458 145c 145e 146a 146c 1470 1474
1477 147b 147e 1482 1485 1486 148b 148e
1492 1496 149a 149e 14a2 14a6 14aa 14ae
14b2 14b6 14ba 14be 14c2 14c6 14ca 14ce
14d2 14d6 14da 14de 14e2 14e6 14ea 14ee
14f2 14f6 14fa 14fe 1502 1506 150a 150e
1512 1516 151a 151e 152a 152e 1532 1535
1539 153d 153f 1543 1547 154b 154e 1552
1556 1558 1559 155e 1 1562 1566 156a
156d 1571 1575 1579 157d 1580 1584 1588
158b 158e 1593 1596 1599 159c 159d 15a2
15a3 1 15a5 15aa 15ae 15b2 15b5 15ba
15bf 15c2 15c6 15c7 15cc 15cf 15d4 15d5
15da 15dd 15e2 15e3 15e8 15eb 15ef 15f0
15f5 15f8 15fd 15fe 1603 1606 160a 160e
1611 1614 1615 1617 1618 161d 161e 1623
1625 1629 162c 162e 1632 1634 1640 1642
1644 1645 164a 164e 1650 165c 165e 1662
1666 1669 166d 1670 1674 1677 1678 167d
1680 1684 1688 168c 1690 1694 1697 169b
169f 16a2 16a5 16aa 16ad 16b0 16b3 16b4
16b9 16ba 1 16bc 16c1 16c5 16c9 16cc
16d1 16d6 16d9 16dd 16de 16e3 16e4 16e9
16eb 16ef 16f2 16f6 16fa 16fe 1701 1705
1707 170b 170e 1712 1716 171a 171d 171e
1720 1724 1728 172b 172c 172e 1731 1735
1738 173c 173f 1740 1745 1749 174d 1751
1755 1759 175c 1760 1764 1767 176a 176f
1772 1775 1778 1779 177e 177f 1 1781
1786 178a 178e 1791 1796 179b 179e 17a2
17a3 17a8 17a9 17ae 17b0 17b4 17b7 17bb
17bf 17c3 17c6 17ca 17cc 17d0 17d3 17d7
17db 17df 17e3 17e7 17eb 17ef 17f3 17f6
17fa 17fe 1801 1802 1804 1807 180a 180b
1810 1813 1817 181b 181e 1822 1826 1829
182a 182c 182f 1832 1833 1838 1 183b
1840 1844 1848 184c 1850 1854 1857 185b
185f 1862 1865 186a 186d 1870 1873 1874
1879 187a 1 187c 1881 1885 1889 188c
1891 1896 1899 189d 189e 18a3 18a4 18a9
18ab 18af 18b2 18b6 18ba 18be 18c1 18c5
18c7 18cb 18ce 18d2 18d5 18d6 18db 18de
18e1 18e5 18e9 18ec 18ed 18ef 18f2 18f6
18fa 18fd 18fe 1900 1901 1906 1909 190d
1910 1914 1917 1918 191a 191b 1920 1
1923 1928 192c 1930 1934 1938 193c 193f
1943 1947 194a 194d 1952 1955 1958 195b
195c 1961 1962 1 1964 1969 196d 1971
1974 1979 197e 1981 1985 1986 198b 198c
1991 1993 1997 199a 199e 19a2 19a6 19a9
19ad 19af 19b3 19b6 19ba 19be 19c1 19c5
19c9 19cc 19cd 19cf 19d2 19d5 19d6 19db
19de 19e2 19e6 19e9 19ed 19f1 19f4 19f5
19f7 19fa 19fd 19fe 1a03 1 1a06 1a0b
1a0f 1a13 1a16 1a17 1a19 1a1c 1a1f 1a20
1a25 1a29 1a2d 1a30 1a34 1a38 1a3b 1a3c
1a3e 1a41 1a44 1a45 1a4a 1a4e 1a52 1a56
1a5a 1a5e 1a62 1a66 1a6a 1a6e 1a72 1a76
1a7a 1a7e 1a82 1a86 1a8a 1a96 1a9a 1a9e
1aa1 1aa5 1aa9 1aab 1aaf 1ab3 1ab7 1aba
1abe 1ac2 1ac4 1ac5 1aca 1 1ace 1ad2
1ad6 1ad9 1add 1ae1 1ae5 1ae9 1aec 1af0
1af4 1af7 1afa 1aff 1b02 1b05 1b08 1b09
1b0e 1b0f 1 1b11 1b16 1b1a 1b1e 1b21
1b26 1b2b 1b2e 1b32 1b33 1b38 1b3b 1b40
1b41 1b46 1b49 1b4e 1b4f 1b54 1b57 1b5b
1b5c 1b61 1b64 1b69 1b6a 1b6f 1b72 1b76
1b7a 1b7d 1b80 1b81 1b83 1b84 1b89 1b8a
1b8f 1b91 1b95 1b98 1b9a 1b9e 1ba0 1bac
1bae 1bb0 1bb1 1bb6 1bba 1bbc 1bc8 1bca
1bce 1bd2 1bd5 1bd9 1bdc 1be0 1be3 1be4
1be9 1bec 1bf0 1bf4 1bf8 1bfc 1c00 1c04
1c08 1c0c 1c10 1c1c 1c20 1c24 1c27 1c2b
1c2f 1c31 1c35 1c39 1c3d 1c40 1c44 1c48
1c4a 1c4b 1c50 1 1c54 1c58 1c5c 1c5f
1c63 1c67 1c6b 1c6f 1c72 1c76 1c7a 1c7d
1c80 1c85 1c88 1c8b 1c8e 1c8f 1c94 1c95
1 1c97 1c9c 1ca0 1ca4 1ca7 1cac 1cb1
1cb4 1cb8 1cb9 1cbe 1cc1 1cc6 1cc7 1ccc
1ccf 1cd4 1cd5 1cda 1cdd 1ce1 1ce2 1ce7
1cea 1cef 1cf0 1cf5 1cf8 1cfc 1d00 1d03
1d06 1d07 1d09 1d0a 1d0f 1d10 1d15 1d17
1d1b 1d1e 1d20 1d24 1d26 1d32 1d34 1d36
1d37 1d3c 1d40 1d42 1d4e 1d50 1d52 1d56
1d59 1d5d 1d61 1d64 1d68 1d6c 1d6f 1d70
1d72 1d75 1d78 1d79 1d7e 1d82 1d83 1d87
1d89 1d8d 1d90 1d92 1d96 1d9a 1d9e 1da2
1da6 1daa 1dae 1db2 1db6 1dba 1dbe 1dc2
1dc6 1dca 1dce 1dd2 1dde 1de2 1de6 1de9
1ded 1df1 1df3 1df7 1dfb 1dff 1e02 1e06
1e0a 1e0c 1e0d 1e12 1 1e16 1e1a 1e1e
1e21 1e25 1e29 1e2d 1e31 1e34 1e38 1e3c
1e3f 1e42 1e47 1e4a 1e4d 1e50 1e51 1e56
1e57 1 1e59 1e5e 1e62 1e66 1e69 1e6e
1e73 1e76 1e7a 1e7b 1e80 1e83 1e88 1e89
1e8e 1e91 1e96 1e97 1e9c 1e9f 1ea3 1ea4
1ea9 1eac 1eb1 1eb2 1eb7 1eba 1ebe 1ec2
1ec5 1ec8 1ec9 1ecb 1ecc 1ed1 1ed2 1ed7
1ed9 1edd 1ee0 1ee2 1ee6 1ee8 1ef4 1ef6
1ef8 1ef9 1efe 1f02 1f04 1f10 1f12 1f16
1f1a 1f1d 1f21 1f24 1f28 1f2b 1f2c 1f31
1f34 1f38 1f3c 1f40 1f44 1f48 1f4c 1f50
1f54 1f58 1f64 1f68 1f6c 1f6f 1f73 1f77
1f79 1f7d 1f81 1f85 1f88 1f8c 1f90 1f92
1f93 1f98 1 1f9c 1fa0 1fa4 1fa7 1fab
1faf 1fb3 1fb7 1fba 1fbe 1fc2 1fc5 1fc8
1fcd 1fd0 1fd3 1fd6 1fd7 1fdc 1fdd 1
1fdf 1fe4 1fe8 1fec 1fef 1ff4 1ff9 1ffc
2000 2001 2006 2009 200e 200f 2014 2017
201c 201d 2022 2025 2029 202a 202f 2032
2037 2038 203d 2040 2044 2048 204b 204e
204f 2051 2052 2057 2058 205d 205f 2063
2066 2068 206c 206e 207a 207c 207e 207f
2084 2088 208a 2096 2098 209a 209e 20a1
20a5 20a8 20ac 20ae 20b2 20b6 20b9 20bd
20c1 20c4 20c5 20c7 20cb 20ce 20d2 20d5
20d6 20db 20df 20e3 20e7 20eb 20ef 20f3
20f7 20fb 20ff 210b 210f 2114 2118 211b
211c 2121 2125 2129 212c 212f 2133 2135
2139 213d 2140 2143 2147 2149 214d 2151
2154 2156 215a 215e 2162 2165 2169 216d
216f 2170 2175 1 2179 217d 2181 2184
2188 218c 2190 2194 2197 219b 219f 21a2
21a5 21aa 21ad 21b0 21b3 21b4 21b9 21ba
1 21bc 21c1 21c5 21c9 21cc 21d1 21d6
21d9 21dd 21de 21e3 21e6 21eb 21ec 21f1
21f4 21f9 21fa 21ff 2202 2206 2207 220c
220f 2214 2215 221a 221d 2221 2225 2228
222b 222c 222e 222f 2234 2235 223a 223c
2240 2243 2245 2249 224b 2257 2259 225b
225c 2261 2265 2267 2273 2275 2277 227b
227f 2283 2287 228b 228f 2293 2297 229b
22a7 22ab 22b0 22b4 22b7 22b8 22bd 22c1
22c5 22c8 22cb 22cf 22d1 22d5 22d9 22dc
22df 22e3 22e5 22e9 22ed 22f0 22f2 22f6
22fa 22fe 2301 2305 2309 230b 230c 2311
1 2315 2319 231d 2320 2324 2328 232c
2330 2333 2337 233b 233e 2341 2346 2349
234c 234f 2350 2355 2356 1 2358 235d
2361 2365 2368 236d 2372 2375 2379 237a
237f 2382 2387 2388 238d 2390 2395 2396
239b 239e 23a2 23a3 23a8 23ab 23b0 23b1
23b6 23b9 23bd 23c1 23c4 23c7 23c8 23ca
23cb 23d0 23d1 23d6 23d8 23dc 23df 23e1
23e5 23e7 23f3 23f5 23f7 23f8 23fd 2401
2403 240f 2411 2413 2417 241b 241e 2422
2426 2429 242d 2430 2434 2437 2438 243d
2440 2444 2448 244c 244d 244f 2453 2455
2459 245c 245e 2462 2465 2469 246d 2470
2474 2478 247c 247f 2480 2482 2486 2489
248d 2490 2491 2496 249a 249e 24a1 24a2
24a4 24a8 24ab 24af 24b2 24b3 1 24b8
24bd 24c1 24c5 24c9 24cd 24d1 24d5 24d9
24dd 24e1 24e5 24e9 24ed 24f1 24fd 2501
2505 2508 250c 2510 2512 2516 251a 251e
2521 2525 2529 252b 252c 2531 1 2535
2539 253d 2540 2544 2548 254c 2550 2553
2557 255b 255e 2561 2566 2569 256c 256f
2570 2575 2576 1 2578 257d 2581 2585
2588 258d 2592 2595 2599 259a 259f 25a2
25a7 25a8 25ad 25b0 25b5 25b6 25bb 25be
25c2 25c3 25c8 25cb 25d0 25d1 25d6 25d9
25dd 25e1 25e4 25e7 25e8 25ea 25eb 25f0
25f1 25f6 25f8 25fc 25ff 2601 2605 2607
2613 2615 2617 2618 261d 2621 2623 262f
2631 2633 2637 263a 263e 2642 2645 2649
264d 2650 2651 2653 2656 2659 265a 265f
2663 2667 266b 266f 2673 2677 267b 267f
2683 2687 268b 268f 2693 2697 269b 269f
26ab 26af 26b3 26b6 26ba 26be 26c0 26c4
26c8 26cc 26cf 26d3 26d7 26d9 26da 26df
1 26e3 26e7 26eb 26ee 26f2 26f6 26fa
26fe 2701 2705 2709 270c 270f 2714 2717
271a 271d 271e 2723 2724 1 2726 272b
272f 2733 2736 273b 2740 2743 2747 2748
274d 2750 2755 2756 275b 275e 2763 2764
2769 276c 2770 2771 2776 2779 277e 277f
2784 2787 278b 278f 2792 2795 2796 2798
2799 279e 279f 27a4 27a6 27aa 27ad 27af
27b3 27b5 27c1 27c3 27c5 27c6 27cb 27cf
27d1 27dd 27df 27e3 27e7 27ea 27ee 27f1
27f5 27f8 27f9 27fe 2801 2805 2809 280d
2811 2815 2819 281d 2821 2825 2831 2835
2839 283c 2840 2844 2846 284a 284e 2852
2855 2859 285d 285f 2860 2865 1 2869
286d 2871 2874 2878 287c 2880 2884 2887
288b 288f 2892 2895 289a 289d 28a0 28a3
28a4 28a9 28aa 1 28ac 28b1 28b5 28b9
28bc 28c1 28c6 28c9 28cd 28ce 28d3 28d6
28db 28dc 28e1 28e4 28e9 28ea 28ef 28f2
28f6 28f7 28fc 28ff 2904 2905 290a 290d
2911 2915 2918 291b 291c 291e 291f 2924
2925 292a 292c 2930 2933 2935 2939 293b
2947 2949 294b 294c 2951 2955 2957 2963
2965 2969 296d 2971 2974 2975 2977 297a
297d 297e 2983 2987 2989 298d 2990 2994
2998 299b 299c 299e 29a2 29a5 29a9 29ac
29ad 29b2 29b6 29ba 29bd 29be 29c0 29c4
29c7 29cb 29ce 29cf 1 29d4 29d9 29dd
29e2 29e6 29ea 29ed 29f1 29f3 29f7 29fa
29fc 2a00 2a04 2a07 2a08 2a0a 2a0d 2a10
2a11 2a16 2a1a 2a1d 2a21 2a25 2a29 2a2d
2a31 2a35 2a39 2a3d 2a41 2a45 2a49 2a4d
2a51 2a55 2a61 2a65 2a69 2a6c 2a70 2a74
2a76 2a7a 2a7e 2a82 2a85 2a89 2a8d 2a8f
2a90 2a95 1 2a99 2a9d 2aa1 2aa4 2aa8
2aac 2ab0 2ab4 2ab7 2abb 2abf 2ac2 2ac5
2aca 2acd 2ad0 2ad3 2ad4 2ad9 2ada 1
2adc 2ae1 2ae5 2ae9 2aec 2af1 2af6 2af9
2afd 2afe 2b03 2b06 2b0b 2b0c 2b11 2b14
2b19 2b1a 2b1f 2b22 2b26 2b27 2b2c 2b2f
2b34 2b35 2b3a 2b3d 2b41 2b45 2b48 2b4b
2b4c 2b4e 2b4f 2b54 2b55 2b5a 2b5c 2b60
2b63 2b65 2b69 2b6b 2b77 2b79 2b7b 2b7c
2b81 2b85 2b87 2b93 2b95 2b99 2b9d 2ba0
2ba1 2ba3 2ba6 2ba9 2baa 2baf 2bb3 2bb7
2bbb 2bbf 2bc3 2bc7 2bcb 2bcf 2bd3 2bd7
2bdb 2bdf 2be3 2be7 2bf3 2bf7 2bfb 2bfe
2c02 2c06 2c08 2c0c 2c10 2c14 2c17 2c1b
2c1f 2c21 2c22 2c27 1 2c2b 2c2f 2c33
2c36 2c3a 2c3e 2c42 2c46 2c49 2c4d 2c51
2c54 2c57 2c5c 2c5f 2c62 2c65 2c66 2c6b
2c6c 1 2c6e 2c73 2c77 2c7b 2c7e 2c83
2c88 2c8b 2c8f 2c90 2c95 2c98 2c9d 2c9e
2ca3 2ca6 2cab 2cac 2cb1 2cb4 2cb8 2cb9
2cbe 2cc1 2cc6 2cc7 2ccc 2ccf 2cd3 2cd7
2cda 2cdd 2cde 2ce0 2ce1 2ce6 2ce7 2cec
2cee 2cf2 2cf5 2cf7 2cfb 2cfd 2d09 2d0b
2d0d 2d0e 2d13 2d17 2d19 2d25 2d27 2d29
2d2d 2d30 2d34 2d38 2d3b 2d3c 2d3e 2d41
2d44 2d45 2d4a 2d4e 2d52 2d56 2d5a 2d5e
2d61 2d65 2d69 2d6c 2d6f 2d74 2d77 2d7a
2d7d 2d7e 2d83 2d84 1 2d86 2d8b 2d8f
2d93 2d96 2d9b 2da0 2da3 2da7 2da8 2dad
2dae 2db3 2db5 2db9 2dbc 2dc0 2dc4 2dc8
2dcb 2dcf 2dd1 2dd5 2dd8 2dda 2dde 2de1
2de5 2de9 2ded 2df1 2df5 2df9 2dfd 2e01
2e05 2e09 2e0d 2e11 2e15 2e19 2e1d 2e21
2e2d 2e31 2e35 2e38 2e3c 2e40 2e42 2e46
2e4a 2e4e 2e51 2e55 2e59 2e5b 2e5c 2e61
1 2e65 2e69 2e6d 2e70 2e74 2e78 2e7c
2e80 2e83 2e87 2e8b 2e8e 2e91 2e96 2e99
2e9c 2e9f 2ea0 2ea5 2ea6 1 2ea8 2ead
2eb1 2eb5 2eb8 2ebd 2ec2 2ec5 2ec9 2eca
2ecf 2ed2 2ed7 2ed8 2edd 2ee0 2ee5 2ee6
2eeb 2eee 2ef2 2ef3 2ef8 2efb 2f00 2f01
2f06 2f09 2f0d 2f11 2f14 2f17 2f18 2f1a
2f1b 2f20 2f21 2f26 2f28 2f2c 2f2f 2f31
2f35 2f37 2f43 2f45 2f47 2f48 2f4d 2f51
2f53 2f5f 2f61 2f65 2f69 2f6c 2f70 2f73
2f77 2f7a 2f7b 2f80 2f83 2f87 2f8b 2f8f
2f93 2f97 2f9b 2f9f 2fa3 2fa7 2fb3 2fb7
2fbb 2fbe 2fc2 2fc6 2fc8 2fcc 2fd0 2fd4
2fd7 2fdb 2fdf 2fe1 2fe2 2fe7 1 2feb
2fef 2ff3 2ff6 2ffa 2ffe 3002 3006 3009
300d 3011 3014 3017 301c 301f 3022 3025
3026 302b 302c 1 302e 3033 3037 303b
303e 3043 3048 304b 304f 3050 3055 3058
305d 305e 3063 3066 306b 306c 3071 3074
3078 3079 307e 3081 3086 3087 308c 308f
3093 3097 309a 309d 309e 30a0 30a1 30a6
30a7 30ac 30ae 30b2 30b5 30b7 30bb 30bd
30c9 30cb 30cd 30ce 30d3 30d7 30d9 30e5
30e7 30e9 30ed 30f0 30f4 30f8 30fb 30fc
30fe 3101 3104 3105 310a 310e 3112 3115
3116 3118 311c 311f 3123 3126 3127 312c
3130 3134 3137 3138 313a 313e 3141 3145
3148 3149 1 314e 3153 1 3156 315b
315f 3164 3168 316c 316f 3173 3175 3179
317c 317e 3182 3186 3189 318d 3191 3194
3195 3197 319a 319d 319e 31a3 31a7 31aa
31ad 31ae 1 31b3 31b8 31bb 31bf 31c3
31c6 31c7 31c9 31cd 31d0 31d4 31d7 31d8
31dd 31e1 31e5 31e8 31e9 31eb 31ef 31f2
31f6 31f9 31fa 1 31ff 3204 1 3207
320c 3210 3214 3218 321c 3220 3224 3225
3227 322b 322d 3231 3234 3238 323b 323f
3243 3247 324b 324f 3253 3257 325b 325f
3263 3267 326b 326f 3273 3277 327b 327f
3283 3287 328b 328f 3293 3297 329b 329f
32a3 32a7 32ab 32af 32b3 32b7 32bb 32bf
32c3 32c7 32cb 32cf 32db 32df 32e3 32e6
32ea 32ee 32f0 32f4 32f8 32fc 32ff 3303
3307 3309 330a 330f 1 3313 3317 331b
331e 3322 3326 332a 332e 3331 3335 3339
333c 333f 3344 3347 334a 334d 334e 3353
3354 1 3356 335b 335f 3363 3366 336b
3370 3373 3377 3378 337d 3380 3385 3386
338b 338e 3393 3394 3399 339c 33a0 33a1
33a6 33a9 33ae 33af 33b4 33b7 33bb 33bf
33c2 33c5 33c6 33c8 33c9 33ce 33cf 33d4
33d6 33da 33dd 33df 33e3 33e5 33f1 33f3
33f5 33f6 33fb 33ff 3401 340d 340f 3413
3417 341a 341b 341d 3420 3423 3424 3429
342d 3431 3435 3439 343d 3440 3444 3448
344b 344e 3453 3456 3459 345c 345d 3462
3463 1 3465 346a 346e 3472 3475 347a
347f 3482 3486 3487 348c 348d 3492 3494
3498 349b 349f 34a3 34a7 34aa 34ae 34b0
34b4 34b7 34bb 34bf 34c3 34c7 34cb 34cf
34d3 34d7 34db 34df 34e3 34e7 34eb 34ef
34f2 34f3 34f5 34f8 34f9 34fb 34ff 3503
3507 350a 350b 350d 3510 3513 3514 3519
351d 3521 3525 3526 3528 352c 352e 3532
3536 353a 353e 3542 3545 3549 354d 3550
3553 3558 355b 355e 3561 3562 3567 3568
1 356a 356f 3573 3577 357a 357f 3584
3587 358b 358c 3591 3592 3597 3599 359d
35a0 35a4 35a8 35ac 35af 35b0 35b2 35b6
35b8 35bc 35c0 35c3 35c5 35c9 35cd 35d0
35d4 35d6 35da 35de 35e1 35e2 35e4 35e8
35eb 35ef 35f2 35f3 35f5 35f6 35fb 35fe
3602 3606 3609 360a 360c 360f 3612 3613
3618 1 361b 3620 3624 3627 362b 362f
3633 3636 3637 3639 363d 3640 3644 3647
3648 364a 364b 3650 3654 3658 365c 3660
3664 3667 366b 366f 3672 3675 367a 367d
3680 3683 3684 3689 368a 1 368c 3691
3695 3699 369c 36a1 36a6 36a9 36ad 36ae
36b3 36b4 36b9 36bb 36bf 36c2 36c6 36ca
36ce 36d1 36d5 36d9 36db 36df 36e3 36e6
36e7 36e9 36ed 36f0 36f4 36f7 36f8 36fa
36fb 3700 3704 3707 370b 370d 3711 3715
3718 371c 371f 3723 3727 372b 372f 3733
3737 373b 373f 3743 3747 374b 374f 3753
3757 375b 375f 3763 3767 376b 376f 3773
3777 377b 377f 3783 378f 3793 3797 379a
379e 37a2 37a4 37a8 37ac 37b0 37b3 37b7
37bb 37bd 37be 37c3 1 37c7 37cb 37cf
37d2 37d6 37da 37de 37e2 37e5 37e9 37ed
37f0 37f3 37f8 37fb 37fe 3801 3802 3807
3808 1 380a 380f 3813 3817 381a 381f
3824 3827 382b 382c 3831 3834 3839 383a
383f 3842 3847 3848 384d 3850 3854 3855
385a 385d 3862 3863 3868 386b 386f 3873
3876 3879 387a 387c 387d 3882 3883 3888
388a 388e 3891 3893 3897 3899 38a5 38a7
38a9 38aa 38af 38b3 38b5 38c1 38c3 38c7
38cb 38ce 38cf 38d1 38d4 38d7 38d8 38dd
38e1 38e5 38e9 38ed 38f1 38f4 38f8 38fc
38ff 3902 3907 390a 390d 3910 3911 3916
3917 1 3919 391e 3922 3926 3929 392e
3933 3936 393a 393b 3940 3941 3946 3948
394c 394f 3953 3957 395b 395e 3962 3964
3968 396b 396f 3972 3976 397a 397e 3982
3986 398a 398e 3992 3996 399a 399e 39a2
39a6 39aa 39ae 39b2 39b6 39ba 39be 39c2
39c6 39ca 39ce 39d2 39d6 39da 39de 39e2
39e6 39f2 39f6 39fa 39fd 3a01 3a05 3a07
3a0b 3a0f 3a13 3a16 3a1a 3a1e 3a20 3a21
3a26 1 3a2a 3a2e 3a32 3a35 3a39 3a3d
3a41 3a45 3a48 3a4c 3a50 3a53 3a56 3a5b
3a5e 3a61 3a64 3a65 3a6a 3a6b 1 3a6d
3a72 3a76 3a7a 3a7d 3a82 3a87 3a8a 3a8e
3a8f 3a94 3a97 3a9c 3a9d 3aa2 3aa5 3aaa
3aab 3ab0 3ab3 3ab7 3ab8 3abd 3ac0 3ac5
3ac6 3acb 3ace 3ad2 3ad6 3ad9 3adc 3add
3adf 3ae0 3ae5 3ae6 3aeb 3aed 3af1 3af4
3af6 3afa 3afc 3b08 3b0a 3b0c 3b0d 3b12
3b16 3b18 3b24 3b26 3b2a 3b2e 3b31 3b32
3b34 3b37 3b3a 3b3b 3b40 3b44 3b48 3b4c
3b50 3b54 3b57 3b5b 3b5f 3b62 3b65 3b6a
3b6d 3b70 3b73 3b74 3b79 3b7a 1 3b7c
3b81 3b85 3b89 3b8c 3b91 3b96 3b99 3b9d
3b9e 3ba3 3ba4 3ba9 3bab 3baf 3bb2 3bb6
3bba 3bbe 3bc1 3bc5 3bc7 3bcb 3bce 3bd2
3bd6 3bda 3bdd 3bde 3be0 3be4 3be8 3bec
3bf0 3bf4 3bf8 3bfc 3c00 3c04 3c07 3c08
3c0a 3c0e 3c12 3c15 3c16 3c18 3c1c 3c20
3c23 3c24 3c26 3c27 3c29 3c2d 3c2f 3c33
3c37 3c3a 3c3e 3c42 3c45 3c46 3c48 3c4b
3c4e 3c4f 3c54 3c58 3c5c 3c60 3c61 3c63
3c67 3c69 3c6d 3c70 3c74 3c78 3c7c 3c80
3c84 3c87 3c8b 3c8f 3c92 3c95 3c9a 3c9d
3ca0 3ca3 3ca4 3ca9 3caa 1 3cac 3cb1
3cb5 3cb9 3cbc 3cc1 3cc6 3cc9 3ccd 3cce
3cd3 3cd4 3cd9 3cdb 3cdf 3ce2 3ce6 3cea
3cee 3cf1 3cf2 3cf4 3cf8 3cfc 3cfe 3d02
3d05 3d06 3d0b 3d0e 3d12 3d15 3d16 3d1b
1 3d1e 3d23 3d27 3d2b 3d2f 3d33 3d37
3d3b 3d3f 3d43 3d46 3d4a 3d4e 3d51 3d52
3d54 3d57 3d5a 3d5b 3d60 3d63 3d67 3d6b
3d6e 3d72 3d76 3d79 3d7a 3d7c 3d7f 3d82
3d83 3d88 1 3d8b 3d90 3d94 3d98 3d9c
3da0 3da4 3da7 3dab 3daf 3db2 3db5 3dba
3dbd 3dc0 3dc3 3dc4 3dc9 3dca 1 3dcc
3dd1 3dd5 3dd9 3ddc 3de1 3de6 3de9 3ded
3dee 3df3 3df4 3df9 3dfb 3dff 3e02 3e06
3e0a 3e0e 3e11 3e15 3e17 3e1b 3e1e 3e22
3e25 3e26 3e2b 3e2e 3e32 3e36 3e3a 3e3e
3e42 3e46 3e4a 3e4e 3e52 3e5e 3e62 3e66
3e69 3e6d 3e71 3e73 3e77 3e7b 3e7f 3e82
3e86 3e8a 3e8c 3e8d 3e92 1 3e96 3e9a
3e9e 3ea1 3ea5 3ea9 3ead 3eb1 3eb4 3eb8
3ebc 3ebf 3ec2 3ec7 3eca 3ecd 3ed0 3ed1
3ed6 3ed7 1 3ed9 3ede 3ee2 3ee6 3ee9
3eee 3ef3 3ef6 3efa 3efb 3f00 3f03 3f08
3f09 3f0e 3f11 3f16 3f17 3f1c 3f1f 3f23
3f24 3f29 3f2c 3f31 3f32 3f37 3f3a 3f3e
3f42 3f45 3f48 3f49 3f4b 3f4c 3f51 3f52
3f57 3f59 3f5d 3f60 3f62 3f66 3f68 3f74
3f76 3f78 3f79 3f7e 3f82 3f84 3f90 3f92
3f96 3f9a 3f9d 3fa1 3fa4 3fa8 3fab 3fac
3fb1 3fb4 3fb8 3fbc 3fc0 3fc4 3fc8 3fcb
3fcf 3fd3 3fd6 3fd9 3fde 3fe1 3fe4 3fe7
3fe8 3fed 3fee 1 3ff0 3ff5 3ff9 3ffd
4000 4005 400a 400d 4011 4012 4017 4018
401d 401f 4023 4026 402a 402e 4032 4035
4039 403b 403f 4042 4046 404a 404d 4051
4055 4058 4059 405b 405e 4061 4062 4067
406a 406e 4072 4075 4079 407d 4080 4081
4083 4086 4089 408a 408f 1 4092 4097
409b 409f 40a3 40a7 40ab 40ae 40b2 40b6
40b9 40bc 40c1 40c4 40c7 40ca 40cb 40d0
40d1 1 40d3 40d8 40dc 40e0 40e3 40e8
40ed 40f0 40f4 40f5 40fa 40fb 4100 4102
4106 4109 410d 4111 4115 4118 411c 4120
4122 4126 412a 412d 4131 4135 4138 4139
413b 413e 4141 4142 4147 414a 414e 4152
4155 4159 415d 4160 4161 4163 4166 4169
416a 416f 1 4172 4177 417b 417f 4183
4187 418b 418e 4192 4196 4199 419c 41a1
41a4 41a7 41aa 41ab 41b0 41b1 1 41b3
41b8 41bc 41c0 41c3 41c8 41cd 41d0 41d4
41d5 41da 41db 41e0 41e2 41e6 41e9 41ed
41f1 41f5 41f8 41fc 41fe 4202 4206 4209
420b 420f 4212 4216 421a 421e 4222 4226
422a 422e 4232 4236 423a 423e 4242 4246
424a 424e 4252 4256 4262 4266 426a 426d
4271 4275 4277 427b 427f 4283 4286 428a
428e 4290 4291 4296 1 429a 429e 42a2
42a5 42a9 42ad 42b1 42b5 42b8 42bc 42c0
42c3 42c6 42cb 42ce 42d1 42d4 42d5 42da
42db 1 42dd 42e2 42e6 42ea 42ed 42f2
42f7 42fa 42fe 42ff 4304 4307 430c 430d
4312 4315 431a 431b 4320 4323 4327 4328
432d 4330 4335 4336 433b 433e 4342 4346
4349 434c 434d 434f 4350 4355 4356 435b
435d 4361 4364 4366 436a 436c 4378 437a
437c 437d 4382 4386 4388 4394 4396 439a
439e 43a2 43a5 43a6 43a8 43ac 43b0 43b3
43b4 43b6 43b9 43bd 43c0 43c4 43c7 43c8
43cd 43d1 43d5 43d9 43dd 43e1 43e4 43e8
43ec 43ef 43f2 43f7 43fa 43fd 4400 4401
4406 4407 1 4409 440e 4412 4416 4419
441e 4423 4426 442a 442b 4430 4431 4436
4438 443c 443f 4443 4447 444b 444e 4452
4454 4458 445b 445f 4463 4466 4469 446a
446c 446f 4474 4475 447a 447e 4481 4485
4487 448b 448e 4492 4494 4498 449c 449f
44a3 44a6 44aa 44ae 44b1 44b5 44b9 44bd
44c0 44c4 44c8 44cb 44cc 44ce 44d1 44d4
44d5 44da 44dd 44e1 44e5 44e8 44ec 44f0
44f3 44f4 44f6 44f9 44fc 44fd 4502 1
4505 450a 450e 4512 4515 4516 4518 451c
451f 4523 4526 4527 4529 452a 452f 1
4532 4537 453b 453f 4542 4546 454a 454d
454e 4550 4553 4556 4557 455c 4560 4564
4567 4568 456a 456d 4570 4571 4576 457a
457e 4581 4585 4589 458c 458d 458f 4592
4595 4596 1 459b 45a0 45a4 45a8 45ac
45b0 45b4 45b7 45bb 45bf 45c2 45c5 45ca
45cd 45d0 45d3 45d4 45d9 45da 1 45dc
45e1 45e5 45e9 45ec 45f1 45f6 45f9 45fd
45fe 4603 4604 4609 460b 460f 4612 4616
461a 461e 4621 4625 4627 462b 462e 4632
4636 4639 463a 463c 4640 4643 4647 464a
464b 4650 4654 4658 465b 465c 465e 4662
4665 4669 466c 466d 1 4672 4677 467b
467e 4682 4686 468a 468e 4692 4696 469a
469e 46a2 46a6 46aa 46ae 46b2 46b6 46c2
46c6 46ca 46cd 46d1 46d5 46d7 46db 46df
46e3 46e6 46ea 46ee 46f0 46f1 46f6 1
46fa 46fe 4702 4705 4709 470d 4711 4715
4718 471c 4720 4723 4726 472b 472e 4731
4734 4735 473a 473b 1 473d 4742 4746
474a 474d 4752 4757 475a 475e 475f 4764
4767 476c 476d 4772 4775 477a 477b 4780
4783 4787 4788 478d 4790 4795 4796 479b
479e 47a2 47a6 47a9 47ac 47ad 47af 47b0
47b5 47b6 47bb 47bd 47c1 47c4 47c6 47ca
47cc 47d8 47da 47dc 47dd 47e2 47e6 47e8
47f4 47f6 47fa 47fe 4801 4805 4809 480c
480d 480f 4812 4815 4816 481b 481e 4822
4826 4829 482d 4831 4834 4835 4837 483a
483d 483e 4843 1 4846 484b 484f 4854
4858 485c 4860 4864 4868 486c 4870 4871
4873 4877 4879 487d 4880 4884 4888 488c
4890 4894 4898 489c 48a0 48a4 48a8 48ac
48b0 48b4 48b8 48bc 48c0 48c4 48c8 48cc
48d0 48d4 48d8 48dc 48df 48e0 48e2 48e6
48ea 48ed 48ee 48f0 48f1 48f3 48f7 48fb
48ff 4903 4904 4906 490a 490e 4912 4916
491a 491e 4921 4925 4929 492c 492f 4934
4937 493a 493d 493e 4943 4944 1 4946
494b 494f 4953 4956 495b 4960 4963 4967
4968 496d 496e 4973 4975 4979 497c 4980
4984 4988 498b 498c 498e 4992 4994 4998
499c 49a0 49a4 49a7 49ab 49af 49b2 49b6
49b8 49bc 49c0 49c3 49c7 49c9 49cd 49d1
49d4 49d8 49dc 49df 49e0 49e2 49e5 49e8
49e9 49ee 49f2 49f6 49fa 49fe 4a02 4a06
4a0a 4a0e 4a12 4a16 4a22 4a26 4a2a 4a2d
4a31 4a35 4a37 4a3b 4a3f 4a43 4a46 4a4a
4a4e 4a50 4a51 4a56 1 4a5a 4a5e 4a62
4a65 4a69 4a6d 4a71 4a75 4a78 4a7c 4a80
4a83 4a86 4a8b 4a8e 4a91 4a94 4a95 4a9a
4a9b 1 4a9d 4aa2 4aa6 4aaa 4aad 4ab2
4ab7 4aba 4abe 4abf 4ac4 4ac7 4acc 4acd
4ad2 4ad5 4ada 4adb 4ae0 4ae3 4ae7 4ae8
4aed 4af0 4af5 4af6 4afb 4afe 4b02 4b06
4b09 4b0c 4b0d 4b0f 4b10 4b15 4b16 4b1b
4b1d 4b21 4b24 4b26 4b2a 4b2c 4b38 4b3a
4b3c 4b3d 4b42 4b46 4b48 4b54 4b56 4b5a
4b5e 4b62 4b65 4b69 4b6d 4b6e 4b70 4b74
4b78 4b7b 4b7e 4b7f 4b84 4b88 4b8c 4b90
4b94 4b98 4b9c 4ba0 4ba4 4ba8 4bac 4bb0
4bb4 4bb8 4bb9 4bbb 4bbf 4bc3 4bc7 4bca
4bcb 4bcd 4bd0 4bd3 4bd4 4bd9 4bdc 4be0
4be3 4be4 4be9 4bec 1 4bef 4bf4 4bf8
4bfc 4c00 4c04 4c08 4c0c 4c10 4c14 4c18
4c1b 4c1c 4c1e 4c22 4c24 4c28 4c2b 4c2f
4c33 4c36 4c39 4c3a 4c3c 4c3f 4c44 4c45
4c4a 4c4e 4c51 4c55 4c57 4c5b 4c5e 4c62
4c64 4c68 4c6c 4c6f 4c73 4c77 4c7b 4c7e
4c7f 4c81 4c84 4c88 4c8c 4c8f 4c90 4c92
4c93 4c98 4c9c 4ca0 4ca4 4ca8 4cac 4cb0
4cb4 4cb8 4cbc 4cc0 4cc4 4cc8 4ccc 4cd0
4cd4 4cd8 4cdc 4ce0 4ce3 4ce4 4ce6 4ce9
4ced 4cf0 4cf1 4cf3 4cf7 4cfb 4cff 4d02
4d03 4d05 4d08 4d0b 4d0c 4d11 4d15 4d19
4d1c 4d20 4d24 4d27 4d28 4d2a 4d2d 4d30
4d31 4d36 4d3a 4d3e 4d42 4d46 4d4a 4d4e
4d52 4d56 4d5a 4d5e 4d62 4d66 4d6a 4d6e
4d7a 4d7e 4d83 4d87 4d8a 4d8b 4d90 4d94
4d98 4d9b 4d9e 4da2 4da4 4da8 4dac 4daf
4db2 4db6 4db8 4dbc 4dc0 4dc3 4dc5 4dc9
4dcd 4dd1 4dd4 4dd8 4ddc 4dde 4ddf 4de4
1 4de8 4dec 4df0 4df3 4df7 4dfb 4dff
4e03 4e06 4e0a 4e0e 4e11 4e14 4e19 4e1c
4e1f 4e22 4e23 4e28 4e29 1 4e2b 4e30
4e34 4e38 4e3b 4e40 4e45 4e48 4e4c 4e4d
4e52 4e55 4e5a 4e5b 4e60 4e63 4e68 4e69
4e6e 4e71 4e75 4e76 4e7b 4e7e 4e83 4e84
4e89 4e8c 4e90 4e94 4e97 4e9a 4e9b 4e9d
4e9e 4ea3 4ea4 4ea9 4eab 4eaf 4eb2 4eb4
4eb8 4eba 4ec6 4ec8 4eca 4ecb 4ed0 4ed4
4ed6 4ee2 4ee4 4ee8 4eea 4eee 4ef2 4ef5
4ef6 4ef8 4efb 4efe 4eff 4f04 4f08 4f0c
4f0f 4f13 4f17 4f1a 4f1b 4f1d 4f20 4f23
4f24 1 4f29 4f2e 4f32 4f36 4f3a 4f3e
4f42 4f46 4f4a 4f4e 4f52 4f56 4f62 4f66
4f6b 4f6f 4f72 4f73 4f78 4f7c 4f80 4f83
4f86 4f8a 4f8c 4f90 4f94 4f97 4f9a 4f9e
4fa0 4fa4 4fa8 4fab 4fad 4fb1 4fb5 4fb9
4fbc 4fc0 4fc4 4fc6 4fc7 4fcc 1 4fd0
4fd4 4fd8 4fdb 4fdf 4fe3 4fe7 4feb 4fee
4ff2 4ff6 4ff9 4ffc 5001 5004 5007 500a
500b 5010 5011 1 5013 5018 501c 5020
5023 5028 502d 5030 5034 5035 503a 503d
5042 5043 5048 504b 5050 5051 5056 5059
505d 505e 5063 5066 506b 506c 5071 5074
5078 507c 507f 5082 5083 5085 5086 508b
508c 5091 5093 5097 509a 509c 50a0 50a2
50ae 50b0 50b2 50b3 50b8 50bc 50be 50ca
50cc 50ce 50d2 50d6 50d9 50db 50df 50e2
50e6 50ea 50ee 50f2 50f6 50fa 50fe 5102
5106 510a 510e 5112 5116 511a 511e 5122
5126 512a 512e 513a 513e 5142 5145 5149
514d 514f 5153 5157 515b 515e 5162 5166
5168 5169 516e 1 5172 5176 517a 517d
5181 5185 5189 518d 5190 5194 5198 519b
519e 51a3 51a6 51a9 51ac 51ad 51b2 51b3
1 51b5 51ba 51be 51c2 51c5 51ca 51cf
51d2 51d6 51d7 51dc 51df 51e4 51e5 51ea
51ed 51f2 51f3 51f8 51fb 51ff 5200 5205
5208 520d 520e 5213 5216 521a 521e 5221
5224 5225 5227 5228 522d 522e 5233 5235
5239 523c 523e 5242 5244 5250 5252 5254
5255 525a 525e 5260 526c 526e 5272 5275
5279 527d 5281 5285 5289 528d 5291 5295
5299 529d 52a1 52a5 52a9 52aa 52ac 52b0
52b4 52b8 52bc 52bd 52bf 52c3 52c7 52cb
52ce 52d1 52d5 52d9 52dd 52e1 52e5 52e9
52ec 52f0 52f4 52f7 52fa 52ff 5302 5305
5308 5309 530e 530f 1 5311 5316 531a
531e 5321 5326 532b 532e 5332 5333 5338
5339 533e 5340 5344 5347 534b 534f 5353
5356 535a 535e 5360 5364 5368 536c 536f
5370 5372 5376 5379 537d 5380 5381 5383
5384 5389 538d 5391 5395 5398 5399 539b
539e 53a2 53a6 53a9 53aa 53ac 53ad 53b2
53b6 53ba 53be 53c1 53c2 53c4 53c8 53cb
53cf 53d2 53d3 53d8 53dc 53e0 53e3 53e4
53e6 53ea 53ed 53f1 53f4 53f5 1 53fa
53ff 5403 5407 540a 540d 540e 5410 5413
5418 5419 541e 5421 5425 5429 542d 542f
5433 5437 543b 543d 5441 5445 5448 544c
5450 5454 5458 545c 5460 5461 5463 5467
546b 546c 5470 5474 5478 547d 5481 5482
5486 548a 548f 5494 5498 549c 54a1 54a5
54a9 54ac 54af 54b3 54b5 54b9 54bd 54c0
54c3 54c7 54c9 54cd 54d1 54d4 54d8 54dc
54e1 54e3 54e7 54eb 54ee 54f2 54f6 54f8
54fc 5500 5504 5507 550b 550f 5511 5512
5517 1 551b 551f 5523 5526 552a 552e
5532 5536 5539 553d 5541 5544 5547 554c
554f 5552 5555 5556 555b 555c 1 555e
5563 5567 556b 556e 5573 5578 557b 557f
5580 5585 5588 558d 558e 5593 5596 559b
559c 55a1 55a4 55a8 55a9 55ae 55b1 55b6
55b7 55bc 55bf 55c3 55c7 55ca 55cd 55ce
55d0 55d1 55d6 55d7 55dc 55de 55e2 55e5
55e7 55eb 55ed 55f9 55fb 55fd 55fe 5603
5607 5609 5615 5617 561b 561e 561f 5624
5627 562b 562f 5632 5636 563a 563d 5640
5645 5648 564b 564e 564f 5654 5655 1
5657 565c 5660 5664 5667 566c 5671 5674
5678 5679 567e 567f 5684 5686 568a 568d
5691 5695 5699 569c 56a0 56a2 56a6 56a9
56ad 56b1 56b5 56b9 56bd 56c1 56c5 56c9
56cd 56d1 56d5 56d9 56dd 56e1 56e5 56e9
56ed 56f1 56f5 56f9 56fd 5701 5705 5708
5709 570b 570f 5713 5716 5717 5719 571a
571c 5720 5724 5728 572c 572d 572f 5733
5737 573b 573f 5743 5747 574a 574e 5752
5755 5758 575d 5760 5763 5766 5767 576c
576d 1 576f 5774 5778 577c 577f 5784
5789 578c 5790 5791 5796 5797 579c 579e
57a2 57a5 57a9 57ad 57b1 57b4 57b5 57b7
57bb 57bd 57c1 57c4 57c8 57ca 57ce 57d2
57d5 57d9 57db 57df 57e3 57e7 57ea 57eb
57ed 57f0 57f3 57f4 57f9 57fd 5800 5804
5808 580b 580f 5813 5817 581b 581f 5823
582f 5833 5837 583a 583e 5842 5844 5848
584c 5850 5853 5857 585b 585d 585e 5863
1 5867 586b 586f 5872 5876 587a 587e
5882 5885 5889 588d 5890 5893 5898 589b
589e 58a1 58a2 58a7 58a8 1 58aa 58af
58b3 58b7 58ba 58bf 58c4 58c7 58cb 58cc
58d1 58d4 58d9 58da 58df 58e2 58e7 58e8
58ed 58f0 58f4 58f5 58fa 58fd 5902 5903
5908 590b 590f 5913 5916 5919 591a 591c
591d 5922 5923 5928 592a 592e 5931 5933
5937 5939 5945 5947 5949 594a 594f 5953
5955 5961 5963 5967 5969 596d 5971 5975
5978 5979 597b 597f 5982 5986 5989 598a
598c 598d 5992 5996 599a 599e 59a1 59a2
59a4 59a7 59ab 59af 59b2 59b3 59b5 59b6
59bb 59bf 59c3 59c4 59c8 59cc 59d1 59d5
59d9 59dd 59e0 59e1 59e3 59e6 59e9 59ea
59ef 59f3 59f8 59fb 5a00 5a01 5a06 5a09
5a0d 5a0e 5a13 5a16 5a1b 5a1c 5a21 5a24
5a28 5a29 5a2e 5a31 5a36 5a37 5a3c 5a3f
5a44 5a45 5a4a 5a4d 5a51 5a55 5a59 5a5c
5a5d 5a5f 5a60 5a62 5a63 5a68 5a6c 5a70
5a74 5a78 5a7b 5a7f 5a81 5a85 5a8a 5a8d
5a92 5a93 5a98 5a9b 5a9f 5aa0 5aa5 5aa8
5aad 5aae 5ab3 5ab6 5aba 5abb 5ac0 5ac3
5ac8 5ac9 5ace 5ad1 5ad6 5ad7 5adc 5adf
5ae3 5ae7 5aeb 5aee 5aef 5af1 5af2 5af4
5af5 5afa 5afe 5b02 5b06 5b0a 5b0d 5b11
5b13 5b17 5b1b 5b1e 5b22 5b26 5b2a 5b2d
5b2e 5b30 5b33 5b36 5b37 5b3c 5b40 5b44
5b49 5b4e 5b52 5b56 5b5b 5b5f 5b63 5b66
5b69 5b6d 5b6f 5b73 5b77 5b7a 5b7d 5b81
5b83 5b87 5b8b 5b8e 5b90 5b94 5b98 5b9d
5ba2 5ba6 5baa 5baf 5bb3 5bb7 5bba 5bbd
5bc1 5bc3 5bc7 5bcb 5bce 5bd1 5bd5 5bd7
5bdb 5bdf 5be2 5be4 5be8 5bec 5bef 5bf3
5bf7 5bfa 5bfe 5c01 5c05 5c08 5c09 5c0e
5c11 5c15 5c1b 5c1d 5c21 5c24 5c26 5c2a
5c31 5c35 5c39 5c3c 5c3d 5c3f 5c42 5c45
5c46 5c4b 5c4f 5c53 5c58 5c5a 5c5e 5c62
5c65 5c69 5c6d 5c6f 5c73 5c77 5c7b 5c7e
5c82 5c86 5c88 5c89 5c8e 1 5c92 5c96
5c9a 5c9d 5ca1 5ca5 5ca9 5cad 5cb0 5cb4
5cb8 5cbb 5cbe 5cc3 5cc6 5cc9 5ccc 5ccd
5cd2 5cd3 1 5cd5 5cda 5cde 5ce2 5ce5
5cea 5cef 5cf2 5cf6 5cf7 5cfc 5cff 5d04
5d05 5d0a 5d0d 5d12 5d13 5d18 5d1b 5d1f
5d20 5d25 5d28 5d2d 5d2e 5d33 5d36 5d3a
5d3e 5d41 5d44 5d45 5d47 5d48 5d4d 5d4e
5d53 5d55 5d59 5d5c 5d5e 5d62 5d64 5d70
5d72 5d74 5d75 5d7a 5d7e 5d80 5d8c 5d8e
5d90 5d94 5d98 5d9d 5d9f 5da3 5da7 5daa
5dae 5db2 5db4 5db8 5dbc 5dc0 5dc3 5dc7
5dcb 5dcd 5dce 5dd3 1 5dd7 5ddb 5ddf
5de2 5de6 5dea 5dee 5df2 5df5 5df9 5dfd
5e00 5e03 5e08 5e0b 5e0e 5e11 5e12 5e17
5e18 1 5e1a 5e1f 5e23 5e27 5e2a 5e2f
5e34 5e37 5e3b 5e3c 5e41 5e44 5e49 5e4a
5e4f 5e52 5e57 5e58 5e5d 5e60 5e64 5e65
5e6a 5e6d 5e72 5e73 5e78 5e7b 5e7f 5e83
5e86 5e89 5e8a 5e8c 5e8d 5e92 5e93 5e98
5e9a 5e9e 5ea1 5ea3 5ea7 5ea9 5eb5 5eb7
5eb9 5eba 5ebf 5ec3 5ec5 5ed1 5ed3 5ed5
5ed9 5edd 5ee0 5ee4 5ee7 5ee8 5eed 5ef0
5ef4 5ef8 5efb 5efc 5efe 5f01 5f04 5f05
5f0a 5f0e 5f12 5f16 5f1a 5f1e 5f21 5f25
5f29 5f2c 5f2f 5f34 5f37 5f3a 5f3d 5f3e
5f43 5f44 1 5f46 5f4b 5f4f 5f53 5f56
5f5b 5f60 5f63 5f67 5f68 5f6d 5f6e 5f73
5f75 5f79 5f7c 5f80 5f84 5f88 5f8b 5f8f
5f91 5f95 5f99 5f9d 5fa1 5fa5 5fa8 5fac
5fb0 5fb3 5fb6 5fbb 5fbe 5fc1 5fc4 5fc5
5fca 5fcb 1 5fcd 5fd2 5fd6 5fda 5fdd
5fe2 5fe7 5fea 5fee 5fef 5ff4 5ff5 5ffa
5ffc 6000 6003 6007 600b 600f 6012 6016
6018 601c 6020 6023 6025 6029 602c 6030
6034 6038 603c 6040 6044 6048 604c 6050
6054 6060 6064 6068 606b 606f 6073 6075
6079 607d 6081 6084 6088 608c 608e 608f
6094 1 6098 609c 60a0 60a3 60a7 60ab
60af 60b3 60b6 60ba 60be 60c1 60c4 60c9
60cc 60cf 60d2 60d3 60d8 60d9 1 60db
60e0 60e4 60e8 60eb 60f0 60f5 60f8 60fc
60fd 6102 6105 610a 610b 6110 6113 6118
6119 611e 6121 6125 6126 612b 612e 6133
6134 6139 613c 6140 6144 6147 614a 614b
614d 614e 6153 6154 6159 615b 615f 6162
6164 6168 616a 6176 6178 617a 617b 6180
6184 6186 6192 6194 6198 619b 619f 61a3
61a6 61aa 61ac 61b0 61b4 61b7 61bb 61bd
61c1 61c5 61c8 61c9 61cb 61cf 61d2 61d6
61d9 61da 61dc 61dd 61e2 61e6 61ea 61ed
61ee 61f0 61f3 61f6 61f7 61fc 6200 6204
6207 6208 620a 620e 6211 6215 6218 6219
621b 621c 1 6221 6226 622a 622e 6232
6236 623a 623d 6241 6245 6248 624b 6250
6253 6256 6259 625a 625f 6260 1 6262
6267 626b 626f 6272 6277 627c 627f 6283
6284 6289 628a 628f 6291 6295 6298 629c
62a0 62a4 62a7 62ab 62ad 62b1 62b4 62b8
62bc 62bf 62c0 62c2 62c6 62c9 62cd 62d0
62d1 62d3 62d4 62d9 62dd 62e1 62e5 62e9
62ed 62f0 62f4 62f8 62fb 62fe 6303 6306
6309 630c 630d 6312 6313 1 6315 631a
631e 6322 6325 632a 632f 6332 6336 6337
633c 633d 6342 6344 6348 634b 634f 6353
6357 635a 635e 6360 6364 6367 636b 636f
6372 6373 6375 6378 637b 637c 6381 6385
6388 638c 638e 6392 6396 6399 639a 639c
639f 63a2 63a3 63a8 63ab 63af 63b3 63b6
63b7 63b9 63bc 63bf 63c0 63c5 1 63c8
63cd 63d1 63d5 63d9 63dd 63e1 63e4 63e8
63ec 63ef 63f2 63f7 63fa 63fd 6400 6401
6406 6407 1 6409 640e 6412 6416 6419
641e 6423 6426 642a 642b 6430 6431 6436
6438 643c 643f 6443 6447 644b 644e 6452
6454 6458 645b 645f 6463 6467 646a 646b
646d 6471 6473 6477 647b 647e 6482 6486
648a 648e 6491 6492 6494 6497 649b 649f
64a2 64a3 64a5 64a6 64ab 64ae 64b1 64b4
64b5 64ba 64bd 64c0 64c3 64c4 64c9 64ca
64cc 64d0 64d4 64d8 64db 64dc 64de 64e2
64e5 64e9 64ec 64ed 64ef 64f0 64f5 64f9
64fc 6500 6504 6508 650c 6510 6514 6518
651c 6528 652c 6530 6533 6537 653b 653d
6541 6545 6549 654c 6550 6554 6556 6557
655c 1 6560 6564 6568 656b 656f 6573
6577 657b 657e 6582 6586 6589 658c 6591
6594 6597 659a 659b 65a0 65a1 1 65a3
65a8 65ac 65b0 65b3 65b8 65bd 65c0 65c4
65c5 65ca 65cd 65d2 65d3 65d8 65db 65e0
65e1 65e6 65e9 65ed 65ee 65f3 65f6 65fb
65fc 6601 6604 6608 660c 660f 6612 6613
6615 6616 661b 661c 6621 6623 6627 662a
662c 6630 6632 663e 6640 6642 6643 6648
664c 664e 665a 665c 6660 6664 6667 6668
666a 666d 6670 6671 6676 667a 667e 6682
6686 668a 668d 6691 6695 6698 669b 66a0
66a3 66a6 66a9 66aa 66af 66b0 1 66b2
66b7 66bb 66bf 66c2 66c7 66cc 66cf 66d3
66d4 66d9 66da 66df 66e1 66e5 66e8 66ec
66ef 66f3 66f5 66f9 66fc 66fe 6702 6705
6709 670d 6710 6711 6713 6717 671a 671e
6721 6722 6727 672b 672f 6732 6733 6735
6739 673c 6740 6743 6744 1 6749 674e
6752 6755 6758 6759 675e 6762 6766 676a
676e 6772 6776 677a 677e 6782 6786 678a
678e 6792 6793 6795 6799 679d 67a1 67a4
67a5 67a7 67aa 67ad 67ae 67b3 67b6 67ba
67bd 67be 67c3 67c6 1 67c9 67ce 67d2
67d6 67da 67de 67e2 67e6 67ea 67ee 67f2
67f6 6802 6806 680a 680d 6811 6815 6817
681b 681f 6823 6826 682a 682e 6830 6831
6836 1 683a 683e 6842 6845 6849 684d
6851 6855 6858 685c 6860 6863 6866 686b
686e 6871 6874 6875 687a 687b 1 687d
6882 6886 688a 688d 6892 6897 689a 689e
689f 68a4 68a7 68ac 68ad 68b2 68b5 68ba
68bb 68c0 68c3 68c7 68c8 68cd 68d0 68d5
68d6 68db 68de 68e2 68e6 68e9 68ec 68ed
68ef 68f0 68f5 68f6 68fb 68fd 6901 6904
6906 690a 690c 6918 691a 691c 691d 6922
6926 6928 6934 6936 6938 693c 693f 6943
6947 694b 694f 6952 6953 6955 6958 695c
6960 6963 6964 6966 6967 696c 696f 6972
6975 6976 697b 697e 6981 6984 6985 698a
698b 698d 6991 6995 6999 699d 69a1 69a5
69a9 69ad 69b1 69b5 69b8 69b9 69bb 69bf
69c3 69c7 69cb 69ce 69d2 69d6 69d9 69da
69dc 69e0 69e4 69e7 69e8 69ea 69ee 69f2
69f6 69fa 69fe 6a02 6a05 6a08 6a09 6a0b
6a0f 6a13 6a17 6a1b 6a1f 6a23 6a27 6a2b
6a2f 6a33 6a37 6a3b 6a3f 6a43 6a47 6a4b
6a4f 6a53 6a57 6a5b 6a67 6a6b 6a6f 6a72
6a76 6a7a 6a7c 6a80 6a84 6a88 6a8b 6a8f
6a93 6a95 6a96 6a9b 1 6a9f 6aa3 6aa7
6aaa 6aae 6ab2 6ab6 6aba 6abd 6ac1 6ac5
6ac8 6acb 6ad0 6ad3 6ad6 6ad9 6ada 6adf
6ae0 1 6ae2 6ae7 6aeb 6aef 6af2 6af7
6afc 6aff 6b03 6b04 6b09 6b0c 6b11 6b12
6b17 6b1a 6b1f 6b20 6b25 6b28 6b2c 6b2d
6b32 6b35 6b3a 6b3b 6b40 6b43 6b47 6b4b
6b4e 6b51 6b52 6b54 6b55 6b5a 6b5b 6b60
6b62 6b66 6b69 6b6b 6b6f 6b71 6b7d 6b7f
6b81 6b82 6b87 6b8b 6b8d 6b99 6b9b 6b9f
6ba2 6ba6 6baa 6bae 6bb2 6bb6 6bba 6bbe
6bc2 6bc6 6bca 6bce 6bd2 6bd6 6bd7 6bd9
6bdd 6be1 6be5 6be9 6bea 6bec 6bf0 6bf4
6bf8 6bfc 6c00 6c04 6c07 6c0b 6c0f 6c12
6c15 6c1a 6c1d 6c20 6c23 6c24 6c29 6c2a
1 6c2c 6c31 6c35 6c39 6c3c 6c41 6c46
6c49 6c4d 6c4e 6c53 6c54 6c59 6c5b 6c5f
6c62 6c66 6c6a 6c6e 6c71 6c72 6c74 6c78
6c7a 6c7e 6c81 6c85 6c89 6c8c 6c90 6c94
6c98 6c9b 6c9c 6c9e 6ca1 6ca4 6ca5 6caa
6cae 6cb1 6cb5 6cb7 6cbb 6cbe 6cc2 6cc6
6cca 6ccd 6cd1 6cd5 6cd8 6cdc 6ce0 6ce3
6ce7 6ceb 6cee 6cef 6cf1 6cf5 6cf9 6cfc
6cfd 6cff 6d03 6d07 6d0b 6d0f 6d13 6d17
6d1b 6d1f 6d23 6d27 6d2b 6d2f 6d33 6d37
6d3b 6d3f 6d4b 6d4f 6d54 6d58 6d5b 6d5c
6d61 6d65 6d69 6d6c 6d6f 6d73 6d75 6d79
6d7d 6d80 6d83 6d87 6d89 6d8d 6d91 6d94
6d96 6d9a 6d9e 6da2 6da5 6da9 6dad 6daf
6db0 6db5 1 6db9 6dbd 6dc1 6dc4 6dc8
6dcc 6dd0 6dd4 6dd7 6ddb 6ddf 6de2 6de5
6dea 6ded 6df0 6df3 6df4 6df9 6dfa 1
6dfc 6e01 6e05 6e09 6e0c 6e11 6e16 6e19
6e1d 6e1e 6e23 6e26 6e2b 6e2c 6e31 6e34
6e39 6e3a 6e3f 6e42 6e46 6e47 6e4c 6e4f
6e54 6e55 6e5a 6e5d 6e61 6e65 6e68 6e6b
6e6c 6e6e 6e6f 6e74 6e75 6e7a 6e7c 6e80
6e83 6e85 6e89 6e8b 6e97 6e99 6e9b 6e9c
6ea1 6ea5 6ea7 6eb3 6eb5 6eb9 6ebd 6ec0
6ec1 6ec3 6ec6 6ec9 6eca 6ecf 6ed3 6ed6
6eda 6edc 6ee0 6ee3 6ee5 6ee9 6eed 6ef0
6ef2 6ef6 6efa 6efd 6f01 6f04 6f07 6f08
6f0d 6f11 6f14 6f17 6f18 6f1d 6f21 6f25
6f29 6f2d 6f31 6f35 6f39 6f3d 6f41 6f45
6f49 6f4d 6f51 6f52 6f54 6f58 6f5c 6f60
6f63 6f64 6f66 6f69 6f6c 6f6d 6f72 6f75
6f79 6f7c 6f7d 6f82 6f85 1 6f88 6f8d
6f91 6f95 6f99 6f9d 6fa1 6fa5 6fa9 6fad
6fb1 6fb4 6fb5 6fb7 6fbb 6fbd 6fc1 6fc4
6fc8 6fcb 6fcc 6fd1 6fd4 6fd8 6fdc 6fe0
6fe4 6fe7 6fe8 6fea 6fee 6ff0 6ff4 6ff8
6ffb 6ffe 6fff 7001 7004 7009 700a 700f
7013 7017 701b 701f 7022 7023 7025 7029
702b 702f 7033 7037 703b 703e 703f 7041
7045 7047 704b 704f 7052 7054 7058 705c
705f 7063 7066 7067 706c 706f 7073 7077
707a 707b 707d 7080 7083 7084 7089 708d
7091 7095 7098 709c 70a0 70a3 70a4 70a6
70aa 70ae 70b1 70b2 70b4 70b7 70bb 70bf
70c3 70c7 70cb 70cf 70d3 70d7 70db 70df
70e3 70ef 70f3 70f7 70fa 70fe 7102 7104
7108 710c 7110 7113 7117 711b 711d 711e
7123 1 7127 712b 712f 7132 7136 713a
713e 7142 7145 7149 714d 7150 7153 7158
715b 715e 7161 7162 7167 7168 1 716a
716f 7173 7177 717a 717f 7184 7187 718b
718c 7191 7194 7199 719a 719f 71a2 71a7
71a8 71ad 71b0 71b4 71b5 71ba 71bd 71c2
71c3 71c8 71cb 71cf 71d3 71d6 71d9 71da
71dc 71dd 71e2 71e3 71e8 71ea 71ee 71f1
71f3 71f7 71f9 7205 7207 7209 720a 720f
7213 7215 7221 7223 7225 7229 722d 7231
7235 7239 723d 7241 7245 7249 724d 7259
725d 7261 7264 7268 726c 726e 7272 7276
727a 727d 7281 7285 7287 7288 728d 1
7291 7295 7299 729c 72a0 72a4 72a8 72ac
72af 72b3 72b7 72ba 72bd 72c2 72c5 72c8
72cb 72cc 72d1 72d2 1 72d4 72d9 72dd
72e1 72e4 72e9 72ee 72f1 72f5 72f6 72fb
72fe 7303 7304 7309 730c 7311 7312 7317
731a 731e 731f 7324 7327 732c 732d 7332
7335 7339 733d 7340 7343 7344 7346 7347
734c 734d 7352 7354 7358 735b 735d 7361
7363 736f 7371 7373 7374 7379 737d 737f
738b 738d 738f 7393 7397 739a 739e 73a2
73a6 73a9 73aa 73ac 73af 73b3 73b7 73ba
73bb 73bd 73be 73c3 73c7 73c9 73cd 73d0
73d4 73d7 73db 73df 73e3 73e7 73eb 73ef
73f3 73f7 73fb 73ff 7403 7406 7407 7409
740d 7411 7414 7415 7417 7418 741a 741e
7422 7426 7429 742a 742c 742f 7432 7433
7438 743c 7440 7444 7448 744c 744f 7453
7457 745a 745d 7462 7465 7468 746b 746c
7471 7472 1 7474 7479 747d 7481 7484
7489 748e 7491 7495 7496 749b 749c 74a1
74a3 74a7 74aa 74ae 74b2 74b6 74b9 74bd
74c1 74c3 74c7 74ca 74cd 74ce 74d3 74d7
74db 74df 74e3 74ef 74f3 74f7 74fb 74ff
7503 7507 750b 750f 7513 7517 751b 751f
7523 7527 752b 752f 7533 7537 753b 753f
7543 7547 7553 7557 755c 7560 7563 7564
7569 756d 7571 7574 7577 757b 757d 7581
7585 7588 758b 758f 7591 7595 7599 759c
759e 75a2 75a6 75aa 75ad 75b1 75b5 75b7
75b8 75bd 1 75c1 75c5 75c9 75cc 75d0
75d4 75d8 75dc 75df 75e3 75e7 75ea 75ed
75f2 75f5 75f8 75fb 75fc 7601 7602 1
7604 7609 760d 7611 7614 7619 761e 7621
7625 7626 762b 762e 7633 7634 7639 763c
7641 7642 7647 764a 764e 764f 7654 7657
765c 765d 7662 7665 7669 766d 7670 7673
7674 7676 7677 767c 767d 7682 7684 7688
768b 768d 7691 7693 769f 76a1 76a3 76a4
76a9 76ad 76af 76bb 76bd 76bf 76c3 76c7
76ca 76ce 76d2 76d6 76d7 76d9 76dd 76e1
76e5 76e9 76ed 76f1 76f4 76f8 76fc 76ff
7702 7707 770a 770d 7710 7711 7716 7717
1 7719 771e 7722 7726 7729 772e 7733
7736 773a 773b 7740 7741 7746 7748 774c
774f 7753 7757 775b 775e 775f 7761 7765
7767 776b 776e 7772 7776 7779 777a 777c
7780 7783 7787 778a 778b 778d 778e 7793
7797 779a 779e 77a2 77a6 77aa 77ae 77b2
77b6 77ba 77be 77c2 77c6 77ca 77ce 77da
77de 77e2 77e5 77e9 77ed 77ef 77f3 77f7
77fb 77fe 7802 7806 7808 7809 780e 1
7812 7816 781a 781d 7821 7825 7829 782d
7830 7834 7838 783b 783e 7843 7846 7849
784c 784d 7852 7853 1 7855 785a 785e
7862 7865 786a 786f 7872 7876 7877 787c
787f 7884 7885 788a 788d 7892 7893 7898
789b 789f 78a0 78a5 78a8 78ad 78ae 78b3
78b6 78ba 78be 78c1 78c4 78c5 78c7 78c8
78cd 78ce 78d3 78d5 78d9 78dc 78de 78e2
78e4 78f0 78f2 78f4 78f5 78fa 78fe 7900
790c 790e 7912 7916 7919 791a 791c 791f
7922 7923 7928 792c 7930 7934 7938 793c
793f 7943 7947 794a 794d 7952 7955 7958
795b 795c 7961 7962 1 7964 7969 796d
7971 7974 7979 797e 7981 7985 7986 798b
798c 7991 7993 7997 799a 799e 79a2 79a6
79a9 79ad 79af 79b3 79b6 79ba 79be 79c2
79c5 79c6 79c8 79cc 79d0 79d4 79d8 79db
79dc 79de 79e2 79e6 79ea 79ed 79ee 79f0
79f4 79f7 79fb 79fe 79ff 7a01 7a02 7a07
7a0b 7a0f 7a12 7a13 7a15 7a19 7a1c 7a20
7a23 7a24 7a29 7a2d 7a31 7a34 7a35 7a37
7a3b 7a3e 7a42 7a45 7a46 1 7a4b 7a50
7a54 7a55 7a59 7a5d 7a61 7a65 7a69 7a6d
7a71 7a75 7a79 7a7d 7a81 7a85 7a89 7a95
7a99 7a9d 7aa0 7aa4 7aa8 7aaa 7aae 7ab2
7ab6 7ab9 7abd 7ac1 7ac3 7ac4 7ac9 1
7acd 7ad1 7ad5 7ad8 7adc 7ae0 7ae4 7ae8
7aeb 7aef 7af3 7af6 7af9 7afe 7b01 7b04
7b07 7b08 7b0d 7b0e 1 7b10 7b15 7b19
7b1d 7b20 7b25 7b2a 7b2d 7b31 7b32 7b37
7b3a 7b3f 7b40 7b45 7b48 7b4d 7b4e 7b53
7b56 7b5a 7b5b 7b60 7b63 7b68 7b69 7b6e
7b71 7b75 7b79 7b7c 7b7f 7b80 7b82 7b83
7b88 7b89 7b8e 7b90 7b94 7b97 7b99 7b9d
7b9f 7bab 7bad 7baf 7bb0 7bb5 7bb9 7bbb
7bc7 7bc9 7bcd 7bd0 7bd1 7bd6 7bd9 7bdd
7be1 7be5 7be7 7beb 7bee 7bf2 7bf6 7bf9
7bfa 7bfc 7bff 7c02 7c03 7c08 7c0c 7c0f
7c12 7c13 7c18 7c1c 7c20 7c24 7c28 7c2c
7c30 7c34 7c38 7c3c 7c40 7c44 7c48 7c4c
7c4d 7c4f 7c53 7c57 7c5b 7c5e 7c5f 7c61
7c64 7c67 7c68 7c6d 7c70 7c74 7c77 7c78
7c7d 7c80 1 7c83 7c88 7c8c 7c90 7c94
7c98 7c9c 7ca0 7ca4 7ca8 7cac 7cb0 7cb4
7cb8 7cc4 7cc8 7ccc 7ccf 7cd3 7cd7 7cd9
7cdd 7ce1 7ce5 7ce8 7cec 7cf0 7cf2 7cf3
7cf8 1 7cfc 7d00 7d04 7d07 7d0b 7d0f
7d13 7d17 7d1a 7d1e 7d22 7d25 7d28 7d2d
7d30 7d33 7d36 7d37 7d3c 7d3d 1 7d3f
7d44 7d48 7d4c 7d4f 7d54 7d59 7d5c 7d60
7d61 7d66 7d69 7d6e 7d6f 7d74 7d77 7d7c
7d7d 7d82 7d85 7d89 7d8a 7d8f 7d92 7d97
7d98 7d9d 7da0 7da4 7da8 7dab 7dae 7daf
7db1 7db2 7db7 7db8 7dbd 7dbf 7dc3 7dc6
7dc8 7dcc 7dce 7dda 7ddc 7dde 7ddf 7de4
7de8 7dea 7df6 7df8 7dfc 7e00 7e04 7e07
7e08 7e0a 7e0d 7e11 7e15 7e18 7e19 7e1b
7e1c 7e21 7e24 7e28 7e2c 7e2f 7e30 7e32
7e33 7e38 7e3c 7e3e 7e42 7e46 7e4a 7e4d
7e4e 7e50 7e53 7e57 7e5b 7e5e 7e5f 7e61
7e62 7e67 7e6b 7e6d 7e71 7e75 7e78 7e7c
7e7f 7e83 7e87 7e8b 7e8f 7e93 7e97 7e98
7e9a 7e9d 7e9e 7ea0 7ea3 7ea7 7eab 7eaf
7eb0 7eb2 7eb5 7eb6 7eb8 7eb9 7ebe 7ec1
7ec4 7ec7 7ec8 7ecd 7ece 7ed0 7ed4 7ed8
7edc 7ee0 7ee3 7ee4 7ee6 7ee9 7eed 7ef1
7ef4 7ef5 7ef7 7ef8 7efd 7f01 7f05 7f09
7f0c 7f0d 7f0f 7f13 7f16 7f1a 7f1d 7f1e
7f20 7f21 7f26 7f2a 7f2e 7f32 7f35 7f36
7f38 7f3b 7f3f 7f43 7f46 7f47 7f49 7f4a
7f4f 7f52 7f56 7f5a 7f5d 7f5e 7f60 7f61
7f66 7f6a 7f6c 7f70 7f74 7f78 7f7b 7f7c
7f7e 7f82 7f84 7f88 7f8c 7f8f 7f93 7f97
7f9b 7f9f 7fa3 7fa7 7fab 7faf 7fb3 7fb6
7fb7 7fb9 7fbd 7fc1 7fc5 7fc9 7fcd 7fd1
7fd2 7fd4 7fd7 7fd8 7fda 7fdd 7fe1 7fe5
7fe9 7fea 7fec 7fef 7ff0 7ff2 7ff3 7ff8
7ffb 7ffe 8001 8002 8007 8008 800a 800e
8012 8016 801a 801d 8021 8025 8028 8029
802b 802f 8033 8036 8037 8039 803d 8041
8045 8049 804d 8051 8055 8059 805c 805d
805f 8063 8067 806a 806b 806d 806e 8070
8074 8078 807b 807f 8083 8087 808b 808f
8093 8097 809b 809f 80a3 80a7 80ab 80af
80b0 80b2 80b6 80b8 80bc 80bf 80c1 80c5
80c8 80cc 80d0 80d4 80d8 80db 80dc 80de
80e2 80e6 80ea 80ee 80f2 80f6 80fa 80fe
8102 8106 810a 810e 8112 8116 811a 811e
8122 8126 812a 812e 8132 8136 813a 813e
8142 8146 814a 814e 8151 8152 8154 8158
815c 815f 8160 8162 8163 8165 8169 816d
8171 8175 8178 8179 817b 817f 8183 8187
818b 818e 818f 8191 8194 8198 819c 819f
81a0 81a2 81a3 81a8 81ac 81b0 81b4 81b8
81bc 81c0 81cc 81d0 81d4 81d7 81db 81df
81e1 81e5 81e9 81ed 81f0 81f4 81f8 81fa
81fb 8200 1 8204 8208 820c 820f 8213
8217 821b 821f 8222 8226 822a 822d 8230
8235 8238 823b 823e 823f 8244 8245 1
8247 824c 8250 8254 8257 825c 8261 8264
8268 8269 826e 8271 8276 8277 827c 827f
8284 8285 828a 828d 8291 8292 8297 829a
829f 82a0 82a5 82a8 82ac 82b0 82b3 82b6
82b7 82b9 82ba 82bf 82c0 82c5 82c7 82cb
82ce 82d0 82d4 82d6 82e2 82e4 82e6 82e7
82ec 82f0 82f2 82fe 8300 8304 8308 830c
8310 8314 8318 831c 8320 8324 8330 8334
8338 833b 833f 8343 8345 8349 834d 8351
8354 8358 835c 835e 835f 8364 1 8368
836c 8370 8373 8377 837b 837f 8383 8386
838a 838e 8391 8394 8399 839c 839f 83a2
83a3 83a8 83a9 1 83ab 83b0 83b4 83b8
83bb 83c0 83c5 83c8 83cc 83cd 83d2 83d5
83da 83db 83e0 83e3 83e8 83e9 83ee 83f1
83f5 83f6 83fb 83fe 8403 8404 8409 840c
8410 8414 8417 841a 841b 841d 841e 8423
8424 8429 842b 842f 8432 8434 8438 843a
8446 8448 844a 844b 8450 8454 8456 8462
8464 8468 846c 8470 8474 8478 847c 8480
8484 8488 848c 8490 8494 8498 849c 84a0
84a4 84a8 84ac 84b0 84bc 84c0 84c5 84c9
84cc 84cd 84d2 84d6 84da 84dd 84e0 84e4
84e6 84ea 84ee 84f1 84f4 84f8 84fa 84fe
8502 8505 8507 850b 850f 8513 8516 851a
851e 8520 8521 8526 1 852a 852e 8532
8535 8539 853d 8541 8545 8548 854c 8550
8553 8556 855b 855e 8561 8564 8565 856a
856b 1 856d 8572 8576 857a 857d 8582
8587 858a 858e 858f 8594 8597 859c 859d
85a2 85a5 85aa 85ab 85b0 85b3 85b7 85b8
85bd 85c0 85c5 85c6 85cb 85ce 85d2 85d6
85d9 85dc 85dd 85df 85e0 85e5 85e6 85eb
85ed 85f1 85f4 85f6 85fa 85fc 8608 860a
860c 860d 8612 8616 8618 8624 8626 862a
862e 8631 8635 8638 863c 863f 8640 8645
8648 864c 864f 8653 8657 865b 865f 8663
8667 866b 866f 8673 8676 867a 867e 8681
8682 8684 8685 8687 868b 868f 8693 8696
8697 8699 869c 869f 86a0 86a5 86a9 86ad
86b1 86b5 86b9 86bc 86c0 86c4 86c7 86ca
86cf 86d2 86d5 86d8 86d9 86de 86df 1
86e1 86e6 86ea 86ee 86f1 86f6 86fb 86fe
8702 8703 8708 8709 870e 8710 8714 8717
871b 871f 8723 8726 8727 8729 872d 872f
8733 8736 8738 873c 873f 8741 8745 8749
874c 8750 8754 8758 875b 875c 875e 8762
8766 8769 876d 876f 8773 8777 877b 877f
8783 8784 8786 8789 878a 878c 878f 8793
8797 879b 879c 879e 87a1 87a2 87a4 87a5
87aa 87ad 87b0 87b3 87b4 87b9 87bc 87bf
87c2 87c3 87c8 87c9 87cb 87cf 87d1 87d5
87d9 87dc 87e0 87e4 87e8 87ec 87f0 87f4
87f8 87fc 8800 8804 8808 880c 8810 8814
8818 881c 8820 8824 8828 882c 8830 8834
8838 883c 8840 8844 8848 884b 884c 884e
8852 8856 8859 885a 885c 885d 885f 8863
8867 886b 886f 8873 8877 887a 887e 8882
8885 8888 888d 8890 8893 8896 8897 889c
889d 1 889f 88a4 88a8 88ac 88af 88b4
88b9 88bc 88c0 88c1 88c6 88c7 88cc 88ce
88d2 88d5 88d9 88dd 88e1 88e4 88e5 88e7
88eb 88ef 88f1 88f5 88f9 88fc 88fd 88ff
8903 8906 890a 890d 890e 8910 8911 8916
891a 891e 8921 8922 8924 8927 892a 892b
8930 8933 8937 893b 893e 893f 8941 8944
8947 8948 894d 1 8950 8955 8959 895d
8961 8965 8969 896c 8970 8974 8977 897a
897f 8982 8985 8988 8989 898e 898f 1
8991 8996 899a 899e 89a1 89a6 89ab 89ae
89b2 89b3 89b8 89b9 89be 89c0 89c4 89c7
89cb 89cf 89d3 89d6 89da 89dc 89e0 89e3
89e7 89eb 89ef 89f3 89f7 89fb 89ff 8a03
8a07 8a0b 8a0f 8a1b 8a1f 8a24 8a28 8a2b
8a2c 8a31 8a35 8a39 8a3c 8a3f 8a43 8a45
8a49 8a4d 8a50 8a53 8a57 8a59 8a5d 8a61
8a64 8a66 8a6a 8a6e 8a72 8a75 8a79 8a7d
8a7f 8a80 8a85 1 8a89 8a8d 8a91 8a94
8a98 8a9c 8aa0 8aa4 8aa7 8aab 8aaf 8ab2
8ab5 8aba 8abd 8ac0 8ac3 8ac4 8ac9 8aca
1 8acc 8ad1 8ad5 8ad9 8adc 8ae1 8ae6
8ae9 8aed 8aee 8af3 8af6 8afb 8afc 8b01
8b04 8b09 8b0a 8b0f 8b12 8b16 8b17 8b1c
8b1f 8b24 8b25 8b2a 8b2d 8b31 8b35 8b38
8b3b 8b3c 8b3e 8b3f 8b44 8b45 8b4a 8b4c
8b50 8b53 8b55 8b59 8b5b 8b67 8b69 8b6b
8b6c 8b71 8b75 8b77 8b83 8b85 8b89 8b8d
8b91 8b95 8b99 8b9d 8ba1 8ba5 8ba9 8bad
8bb1 8bbd 8bc1 8bc6 8bca 8bcd 8bce 8bd3
8bd7 8bdb 8bde 8be1 8be5 8be7 8beb 8bef
8bf2 8bf5 8bf9 8bfb 8bff 8c03 8c06 8c08
8c0c 8c10 8c14 8c17 8c1b 8c1f 8c21 8c22
8c27 1 8c2b 8c2f 8c33 8c36 8c3a 8c3e
8c42 8c46 8c49 8c4d 8c51 8c54 8c57 8c5c
8c5f 8c62 8c65 8c66 8c6b 8c6c 1 8c6e
8c73 8c77 8c7b 8c7e 8c83 8c88 8c8b 8c8f
8c90 8c95 8c98 8c9d 8c9e 8ca3 8ca6 8cab
8cac 8cb1 8cb4 8cb8 8cb9 8cbe 8cc1 8cc6
8cc7 8ccc 8ccf 8cd3 8cd7 8cda 8cdd 8cde
8ce0 8ce1 8ce6 8ce7 8cec 8cee 8cf2 8cf5
8cf7 8cfb 8cfd 8d09 8d0b 8d0d 8d0e 8d13
8d17 8d19 8d25 8d27 8d29 8d2d 8d31 8d34
8d38 8d3c 8d40 8d41 8d43 8d47 8d4b 8d4f
8d53 8d57 8d5b 8d5e 8d62 8d66 8d69 8d6c
8d71 8d74 8d77 8d7a 8d7b 8d80 8d81 1
8d83 8d88 8d8c 8d90 8d93 8d98 8d9d 8da0
8da4 8da5 8daa 8dab 8db0 8db2 8db6 8db9
8dbd 8dc1 8dc5 8dc8 8dc9 8dcb 8dcf 8dd1
8dd5 8dd9 8ddd 8de1 8de5 8de9 8ded 8df1
8df5 8df9 8dfd 8e01 8e05 8e09 8e0d 8e11
8e15 8e19 8e1d 8e21 8e25 8e29 8e2d 8e31
8e35 8e39 8e3d 8e41 8e45 8e49 8e4d 8e51
8e55 8e61 8e65 8e69 8e6c 8e70 8e74 8e76
8e7a 8e7e 8e82 8e85 8e89 8e8d 8e8f 8e90
8e95 1 8e99 8e9d 8ea1 8ea4 8ea8 8eac
8eb0 8eb4 8eb7 8ebb 8ebf 8ec2 8ec5 8eca
8ecd 8ed0 8ed3 8ed4 8ed9 8eda 1 8edc
8ee1 8ee5 8ee9 8eec 8ef1 8ef6 8ef9 8efd
8efe 8f03 8f06 8f0b 8f0c 8f11 8f14 8f19
8f1a 8f1f 8f22 8f26 8f27 8f2c 8f2f 8f34
8f35 8f3a 8f3d 8f41 8f45 8f48 8f4b 8f4c
8f4e 8f4f 8f54 8f55 8f5a 8f5c 8f60 8f63
8f65 8f69 8f6b 8f77 8f79 8f7b 8f7c 8f81
8f85 8f87 8f93 8f95 8f99 8f9d 8fa0 8fa4
8fa7 8fab 8fae 8faf 8fb4 8fb7 8fba 8fbb
8fc0 8fc4 8fc8 8fcc 8fd0 8fd4 8fd7 8fdb
8fdf 8fe2 8fe5 8fea 8fed 8ff0 8ff3 8ff4
8ff9 8ffa 1 8ffc 9001 9005 9009 900c
9011 9016 9019 901d 901e 9023 9024 9029
902b 902f 9032 9036 903a 903e 9041 9045
9047 904b 904e 9052 9056 9059 905d 9061
9062 9064 9067 906a 906b 9070 9074 9078
907b 907e 9082 9086 908a 908e 9092 9096
9099 909d 90a1 90a4 90a7 90ac 90af 90b2
90b5 90b6 90bb 90bc 1 90be 90c3 90c7
90cb 90ce 90d3 90d8 90db 90df 90e0 90e5
90e6 90eb 90ed 90f1 90f4 90f8 90fc 9100
9103 9107 9109 910d 9110 9112 9116 911a
911d 911f 9123 9126 912a 912e 9132 9136
913a 913e 9142 9146 914a 914e 9152 9156
9159 915d 9161 9165 9168 916c 9170 9174
9178 917c 917d 917f 9183 9187 918b 918f
9193 9197 919a 919e 91a2 91a5 91a8 91ad
91b0 91b3 91b6 91b7 91bc 91bd 1 91bf
91c4 91c8 91cc 91cf 91d4 91d9 91dc 91e0
91e1 91e6 91e7 91ec 91ee 91f2 91f5 91f9
91fd 9201 9204 9208 920c 9210 9213 9217
921b 921e 9221 9226 9229 922c 922f 9230
9235 9236 1 9238 923d 9241 9245 9248
924d 9252 9255 9259 925a 925f 9262 9267
9268 926d 9270 9275 9276 927b 927e 9282
9286 9289 928a 928f 9290 9295 9297 929b
929e 92a2 92a6 92aa 92ad 92b1 92b3 92b7
92b9 92c5 92c9 92cb 92cc 92d5 
2a06
2
0 1 a 6 17 1b 22 :3 6
19 1d 24 :3 6 1b 1f 26 :3 6
1c 20 27 :3 6 13 :3 6 13 :3 6
1a :3 6 14 :3 6 14 18 1f :3 6
e 12 19 :2 6 1 3 a :2 1
4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 15 24 15 :2 4 :2 f 1e f
:2 4 12 1b 1a :2 12 :2 4 11 1a
19 :2 11 :2 4 15 1e 1d :2 15 :2 4
17 20 1f :2 17 :2 4 14 1d 1c
:2 14 :2 4 10 19 18 :2 10 :2 4 18
21 20 :2 18 :2 4 12 1b 1a :2 12
:2 4 e 17 16 :2 e :2 4 14 1d
1c :2 14 :2 4 11 1a 19 :2 11 :2 4
11 1a 19 :2 11 :2 4 16 1f 1e
:2 16 :2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4
:3 12 :2 4 :3 13 :2 4 :3 f :2 4 :3 12 :2 4
:3 13 :2 4 :3 14 :2 4 :3 15 :2 4 :3 9 :2 4
:3 9 :2 4 :3 e :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :2 12 21
12 :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 17 26 17 :2 4 :2 13 22
13 :2 4 :2 12 21 12 :2 4 :2 12 21
12 :2 4 :2 14 23 14 :2 4 :2 15 24
15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 13 22 13 :2 4 :2 10 1f 10
:2 4 :2 e 1d e :2 4 :2 10 1f 10
:2 4 :2 13 22 13 :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 13 22 13 :2 4 :2 a 19 a
:2 4 :2 12 21 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 10 1f 10 :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 10 1f 10
:2 4 14 1d 1c :2 14 :2 4 14 1d
1c :2 14 :2 4 :2 17 26 17 :2 4 17
20 1f :2 17 :2 4 :2 13 22 13 :2 4
:2 14 23 14 :2 4 :2 f 1e f :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:2 10 1a 10 :2 4 :2 10 1a 10 :2 4
:2 11 1b 11 :2 4 :2 11 1b 11 :2 4
:2 12 1c 12 :2 4 :2 12 1c 12 :2 4
9 12 11 :2 9 :2 4 :3 f :2 4 :3 e
:2 4 :3 e 4 7 e 0 :2 7 20
36 3f 4c 5b 68 f 10 1d
26 32 40 11 15 19 13 a
:6 7 11 1a :3 11 :2 7 11 1a :3 11
:2 7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 58 5e 61
:2 58 6f 89 8 :2 6f d 10 :2 6f
1e 21 :2 6f b e :2 6f 13 16
:2 6f 1b 1e :2 6f 2e 31 :2 6f b
e :2 6f 13 16 1f 26 2b 2e
:2 26 40 43 :2 26 48 :2 1f 51 :2 16
:2 6f b e :2 6f 13 16 1f 26
2b 2e :2 26 41 44 :2 26 49 :2 1f
52 :2 16 :2 6f b e :2 6f 13 16
1f 27 :2 1f 36 :2 16 :2 6f b e
:2 6f 13 16 1f 27 :2 1f 36 :2 16
:2 6f b e :2 6f 13 16 1f 27
:2 1f 3d :2 16 :2 6f b e :2 6f 13
16 1f 27 :2 1f 37 :2 16 :2 6f b
e :2 6f 13 16 :2 6f 1b 1e :2 6f
29 2c :2 6f b e :2 6f 13 16
:2 6f 1b 1e :2 6f 23 26 :2 6f 2b
2e :2 6f :2 7 4e :2 4 7 :2 11 23
:2 2d 39 3c 50 53 54 :2 50 :2 23
:3 7 :2 d 12 1e 62 65 :2 1e :2 7
57 :3 4 13 :2 4 14 :2 4 12 :2 4
15 :2 4 11 4 e 11 24 27
34 37 43 46 11 14 11 14
7 a 7 a 16 19 c 21
30 3e :4 7 15 c 21 d 10
24 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
57 5a 5b :2 57 :2 29 :3 d :2 13 18
24 68 6b :2 24 78 7b :2 24 7f
82 :2 24 8e 91 :2 24 99 9c :2 24
a8 ab b2 bb be :2 ab :2 24 :2 d
5e :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 11 24
3b 47 54 63 a 1a 25 2f
37 3f 14 23 32 44 53 61
6e 80 14 28 3a 4a 5b a
12 19 34 3c 43 5f 69 a
18 26 34 a 1a 2a 3a a
1d 26 f 24 35 43 4c 58
a 1c 27 2f 38 40 a 1b
2b 3a 48 a 14 1d a 10
16 22 a 16 23 2f a 18
27 35 a 1a 25 f 10 24
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 91 94 :2 27 9c 9f :2 27 ab
ae b5 be c1 :2 ae :2 27 :2 10 61
:2 d :2 a :4 16 :2 a 7 :3 35 b :2 14
1f 1d :2 28 :2 1d a 14 20 2b
3b 45 50 65 6f d 1b 1f
2c 3d 4b 59 5e 67 76 12
20 2d 38 46 55 61 6d d
1d 2a 39 43 53 5a 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 94 97 :2 2a 9f a2 :2 2a
ae b1 b8 c1 c4 :2 b1 :2 2a :2 13
64 :2 10 :2 d :4 19 :2 d a :3 38 e
:2 17 22 20 :2 2b :2 20 :2 d 15 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d 14 :2 1d d
3b :2 a e 15 10 1d :2 15 21
:2 2a :2 e d 43 41 :2 4c :2 41 d
15 d 10 :2 1a 2c :2 36 42 45
59 5c 5d :2 59 :2 2c :3 10 :2 16 1b
27 6b 6e :2 27 :2 10 60 :3 d 14
:2 1d d 61 :3 a 1b :2 a 1c a
e :2 19 21 30 40 :2 e 44 46
:2 44 d 4e :2 59 10 20 2f :2 4e
33 36 :2 33 4d :3 d 15 d 10
:2 1a 2c :2 36 42 45 59 5c 5d
:2 59 :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 :2 10 60 :3 d 14 :2 1d d 39
:2 a :4 f e d 2d 36 40 :2 2d
43 45 4e 5d :2 45 :2 2d 2c 64
61 10 17 :2 64 :2 61 2b :3 d 15
d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d 14 :2 1d
d 1b :2 a e :2 19 21 30 3e
:2 e 42 45 :2 42 d 4c :2 57 5f
12 21 :2 4c 25 28 :2 25 4b :2 d
10 19 29 :2 10 2c 2e :2 2c 13
:2 1e 26 35 43 :2 13 47 4a :2 47
1d 28 35 3f 4a 4f 58 69
7b 1b 1c 29 1a 25 2d 34
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 4c 17 :2 20
2b 29 :2 34 :2 29 16 20 2b 38
40 47 5f 6a 7e 1e :2 19 :2 22
2e 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 69 6c 6d
:2 69 :2 3b :3 1f :2 25 2a 36 7a 7d
:2 36 8a 8d :2 36 91 94 :2 36 a0
a3 :2 36 ab ae :2 36 ba bd c4
cd d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19
:4 25 :2 19 16 :4 44 :2 13 16 :2 21 29
38 48 :2 16 4c 4e :2 4c 16 28
16 50 :2 13 4c 1d 28 35 3f
4a 4f 58 68 7a 1b 1c 29
1a 25 2d 34 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 10 17 :2 20 2b 29 :2 34 :2 29
16 20 2b 38 40 47 60 6b
7f 1e :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 69 6c 6d :2 69 :2 3b :3 1f :2 25
2a 36 7a 7d :2 36 8a 8d :2 36
91 94 :2 36 a0 a3 :2 36 ab ae
:2 36 ba bd c4 cd d0 :2 bd :2 36
:2 1f 70 :2 1c :2 19 :4 25 :2 19 16 :4 44
:3 13 21 13 :4 10 13 1c 29 :2 13
2e 2c :2 37 :2 2c 1d 29 37 46
55 65 76 1c 29 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 3d 1d 29
39 48 59 69 7c 1c 29 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :7 10
14 :2 1d 28 26 :2 31 :2 26 :2 13 21
2b :2 21 13 41 :2 10 30 10 1e
:2 10 1b 10 13 1c 29 :2 13 2e
2c :2 37 :2 2c 4c 16 23 :2 4c 28
26 :2 31 :2 26 :2 13 1d 23 32 1b
1c 29 1a 2b 33 3a 54 5c
63 :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :4 45 :2 10
13 :2 1e 26 35 43 :2 13 47 4a
:2 47 1d 28 35 3f 4a 4f 58
69 7b 1b 1c 29 1a 25 2d
34 :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :3 4c 17
:2 20 2b 29 :2 34 :2 29 16 20 2b
38 40 47 5f 6a 7e 1e :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 69 6c
6d :2 69 :2 3b :3 1f :2 25 2a 36 7a
7d :2 36 8a 8d :2 36 91 94 :2 36
a0 a3 :2 36 ab ae :2 36 ba bd
c4 cd d0 :2 bd :2 36 :2 1f 70 :2 1c
:2 19 :4 25 :2 19 16 :3 44 16 21 2a
33 :2 21 36 38 :2 21 16 44 :2 13
16 1f 2c :2 16 31 2f :2 3a :2 2f
4f 19 26 :2 4f 2b 29 :2 34 :2 29
:3 16 28 :2 16 24 16 48 :2 13 4c
16 1f 2e :2 16 31 33 :2 31 16
24 16 20 30 40 29 1f 2c
3d 47 1d 31 3c 44 4b :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 69 6c
6d :2 69 :2 3b :3 1f :2 25 2a 36 7a
7d :2 36 8a 8d :2 36 91 94 :2 36
a0 a3 :2 36 ab ae :2 36 ba bd
c4 cd d0 :2 bd :2 36 :2 1f 70 :2 1c
:2 19 :4 25 :2 19 16 :3 35 19 22 2e
:2 19 31 33 :2 31 23 33 43 2c
22 2f 40 4a 20 28 2f 43
4b 52 :2 1c :2 25 31 1c 19 21
1f :2 28 34 1f 2f :2 1c :2 21 1f
:2 28 34 1f 22 :2 2c 3e :2 48 54
58 6c 6f 70 :2 6c :2 3e :3 22 :2 28
2d 39 7d 80 :2 39 8d 90 :2 39
94 97 :2 39 a3 a6 :2 39 ae b1
:2 39 bd c0 c7 d0 d3 :2 c0 :2 39
:2 22 73 :2 1f :2 1c :4 28 :2 1c 19 :4 35
:2 16 19 22 2e :2 19 31 33 :2 31
19 21 19 1c :2 26 38 :2 42 4e
51 65 68 69 :2 65 :2 38 :3 1c :2 22
27 33 77 7a :2 33 :2 1c 6c :3 19
20 :2 29 19 35 :2 16 35 :2 13 1d
28 35 3f 4a 4f 58 68 7a
1b 1c 29 1a 25 2d 34 :2 16
:2 1f 2b 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 66 69
6a :2 66 :2 38 :3 1c :2 22 27 33 77
7a :2 33 87 8a :2 33 8e 91 :2 33
9d a0 :2 33 a8 ab :2 33 b7 ba
c1 ca cd :2 ba :2 33 :2 1c 6d :2 19
:2 16 :4 22 :2 16 13 :3 10 17 :2 20 2b
29 :2 34 :2 29 16 20 2b 38 40
47 60 6b 7f 1e :2 19 :2 22 2e
19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6c 6d :2 69
:2 3b :3 1f :2 25 2a 36 7a 7d :2 36
8a 8d :2 36 91 94 :2 36 a0 a3
:2 36 ab ae :2 36 ba bd c4 cd
d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25
:2 19 16 :4 44 :2 13 16 1f 2e :2 16
31 33 :2 31 3a 43 50 :2 3a 55
53 :2 5e :2 53 1c 25 32 :2 1c 37
35 :2 40 :2 35 :2 3a 39 :3 16 27 :2 16
24 16 55 :2 13 :4 10 14 1d 26
:2 14 29 2b :2 29 31 3c 3e :2 3c
:2 14 13 46 16 23 :2 46 28 26
:2 31 :2 26 46 16 23 :2 46 28 26
:2 31 :2 26 :2 46 45 :3 13 21 34 42
51 5a :2 21 13 46 :3 10 1e 10
1a 2a 3a 23 34 19 1c 29
3a 3d 47 17 1a 23 34 19
1c 29 3a 3d 51 54 18 20
27 40 48 4f 52 67 6f 76
90 98 9f a2 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 d 13 1c 28 :2 13 2b 2d
:2 2b 13 1b 13 16 :2 20 32 :2 3c
48 4b 5f 62 63 :2 5f :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d :2 16 66
:3 13 1a :2 23 13 2f :3 10 1e 31
3f 4a 58 67 24 34 3f 4b
57 24 2d 3a :2 24 3e :2 1e 10
13 1c 28 :2 13 2b 2d :2 2b 13
21 2b :2 21 13 2f 13 1b 13
16 :2 20 32 :2 3c 48 4b 5f 62
63 :2 5f :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d :2 16 66 :3 13 1a 23 2f
:2 1a 13 :4 10 :4 d a 2b 11 1a
26 :2 11 2c 29 35 44 :2 2c :2 29
10 4d 56 60 :2 4d 63 65 :2 63
4c :2 10 d 1d d 10 19 25
:2 10 2a 28 33 3d :2 2a :2 28 10
18 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 17
:2 20 10 d 40 13 1c 28 :2 13
2d 2b 36 40 :2 2d :2 2b 10 20
10 43 40 :3 d 1b d 17 27
15 24 26 36 47 4b 56 16
19 23 14 17 2b 2d 14 16
2b 2d 14 16 20 29 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :3 68 10 19 25 :2 10
28 2a :2 28 10 18 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
:2 13 63 :3 10 17 :2 20 10 2c :3 d
1b d 17 27 37 20 31 34
39 53 13 17 24 27 36 3a
48 4b 16 19 26 37 3a 44
11 19 20 23 46 4a :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :3 68 10 19 25 :2 10
28 2a :2 28 10 18 10 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
:2 13 63 :3 10 17 :2 20 10 2c :3 d
1d 26 32 :2 1d :2 d 1b 2d 3b
46 54 60 21 2f :2 60 33 3c
47 :2 33 4b 54 61 :2 4b :2 1b d
68 2b :2 a d 16 22 :2 d 25
27 :2 25 d 1b 25 :2 1b d 29
:3 a 12 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
11 1a 26 :2 11 a 7 38 :4 e
d :4 32 31 :2 d a 1b :2 a 1c
a e :2 19 21 30 40 :2 e 44
46 :2 44 d 4e :2 59 10 20 2f
:2 4e 33 36 :2 33 4d :3 d 15 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d 14 :2 1d d
39 :2 a :4 e d 17 29 3c 4b
5a 6a 15 16 2a :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 2b 11 :2 1a 26 23 :2 2f
:2 23 :2 10 18 10 13 :2 1d 2f :2 39
45 48 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a :2 13 63
:3 10 17 :2 20 10 3f :2 d 11 :2 1c
24 33 42 :2 11 46 48 :2 46 10
4f :2 5a 62 15 25 :2 4f 29 2b
:2 29 4e :3 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 17 :2 20 10 d 2e 14
:2 1f 27 37 46 :2 14 4a 4c :2 4a
13 53 :2 5e 13 23 33 :2 53 37
39 :2 37 52 :2 13 10 18 10 13
:2 1d 2f :2 39 45 48 5c 5f 60
:2 5c :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a :2 13 63 :3 10 17 :2 20 10 3c
2e :2 d 2b :2 a 14 24 2f 3c
46 51 12 1d 2a 39 4a 5c
12 13 20 31 3e :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 94 97
:2 2a 9f a2 :2 2a ae b1 b8 c1
c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d :4 19
:2 d a :3 52 e 15 10 1d :2 15
21 :2 2a :2 e d 43 41 :2 4c :2 41
d 15 d 10 :2 1a 2c :2 36 42
45 59 5c 5d :2 59 :2 2c :3 10 :2 16
1b 27 6b 6e :2 27 :2 10 60 :3 d
14 :2 1d d 61 :2 a d 14 20
23 :2 d 26 28 :2 26 d 20 d
2c d 20 d :5 a 17 :2 a 17
a e :2 19 21 30 3e :2 e 42
45 :2 42 d 4c :2 57 5f 12 21
:2 4c 25 28 :2 25 4b :2 d 2f 38
43 :2 2f 49 46 52 5b :2 49 :2 46
2e :2 d 10 :2 1b 23 32 40 :2 10
44 47 :2 44 13 1c 2b :2 13 2e
30 :2 2e 36 :2 41 49 58 18 :2 36
1c 1e :2 1c :3 13 1b 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
:2 16 66 :3 13 1a :2 23 13 20 :2 10
13 1c 29 :2 13 2e 2c :2 37 :2 2c
4c 16 23 :2 4c 28 26 :2 31 :2 26
:3 13 1e 13 1d 23 32 1b 1c
29 1a 2b 33 3a 57 5f 66
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 45 17 :2 22
2a 39 4a :2 17 4e 50 :2 4e 16
57 :2 62 6a 1b 2d :2 57 31 33
:2 31 56 :3 16 27 :2 16 24 37 45
54 5d :2 24 16 36 :3 13 26 31
40 4e 5d 21 2f 3a 45 4b
51 5d 21 2d 38 49 55 21
34 40 4c 55 5f :2 4c 21 2a
39 :2 21 :2 26 :2 13 21 2b :2 21 :2 13
1b 13 16 :2 20 32 :2 3c 48 4b
5f 62 63 :2 5f :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d :2 16 66 :3 13 1a
23 2f :2 1a 13 45 13 23 :2 13
1e :2 13 20 13 :4 10 d 49 13
:2 1e 26 36 45 :2 13 49 4c :2 49
1a 25 32 3a 41 5a 65 6a
:2 18 :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 4e 10
1d :2 28 2f 3f :2 1d :2 10 20 21
:2 20 :2 10 1e 35 43 4e 59 5f
65 28 34 42 55 :2 1e 10 14
1d 29 :2 14 2c 2e :2 2c 13 :4 37
36 35 :3 13 21 36 44 4f 59
6a 26 38 44 :2 21 13 56 :2 10
13 1a 26 29 :2 13 2c 2e :2 2c
13 22 13 32 13 22 13 :5 10
1f 28 32 :2 1f 35 37 40 4f
:2 37 :2 1f :2 10 1e 2b 39 44 4f
59 65 6b 1e 2c 3c 49 54
1e 2a 33 40 :2 2a 44 47 52
:2 1e 10 13 1c 28 :2 13 2b 2d
:2 2b 16 :2 21 29 3b 4b :2 16 4f
51 :2 4f 20 35 3a 43 4b 5b
6b 19 34 41 4e 5d 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:3 53 13 53 19 22 2f :2 19 32
34 :2 32 3a :2 45 4d 5f 1b :2 3a
1f 21 :2 1f :2 19 20 35 3a 43
4a 60 75 8a 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :4 23 53
:2 13 2f :2 10 1a 22 29 40 48
4f 68 72 83 91 18 1e 24
30 43 4f 18 19 2d :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 66 67
:2 63 :2 35 :3 19 :2 1f 24 30 74 77
:2 30 84 87 :2 30 8b 8e :2 30 9a
9d :2 30 a5 a8 :2 30 b4 b7 be
c7 ca :2 b7 :2 30 :2 19 6a :2 16 :2 13
:4 1f :2 13 10 :3 4e 10 20 :2 10 1e
35 43 4e 59 5f 65 28 34
42 55 :2 1e :2 10 1e 28 :2 1e :2 10
:2 19 25 :2 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 17 :2 20 10 d 4e 49
13 1c 25 :2 13 2a 28 33 3e
:2 2a :2 28 10 1b 24 2f :2 1b 32
34 3d 46 :2 34 :2 1b 10 13 1c
29 :2 13 2e 2c :2 37 :2 2c 4c 16
23 :2 4c 28 26 :2 31 :2 26 :2 13 17
1e 2a 2d :2 17 30 32 :2 30 :2 16
1e 16 37 16 1e 16 :5 13 21
2a 30 3f 48 :2 21 :2 13 25 :2 13
18 :3 13 19 24 :2 13 16 1c :2 16
:2 1f 2b 16 22 16 :2 1f 2b 16
:4 13 16 1c :3 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:3 45 :4 17 16 19 :2 23 35 :2 3f 4b
4e 62 66 67 :2 62 :2 35 :3 19 :2 1f
24 30 75 78 :2 30 :2 19 6a :3 16
1d :2 26 16 2f :3 13 26 31 40
4e 5e 21 2f 3a 45 4b 51
5d 21 2d 38 49 55 21 34
40 4c 55 5f :2 4c 21 2a 39
:2 21 :2 26 :2 13 21 2b :2 21 :2 13 1b
13 16 :2 20 32 :2 3c 48 4b 5f
63 64 :2 5f :2 32 :3 16 :2 1c 21 2d
72 75 :2 2d :2 16 67 :3 13 1a 23
2f :2 1a 13 45 13 20 13 :4 10
d 41 49 13 1c 27 :2 13 2a
2c :2 2a 10 1b :2 10 1d 10 1a
28 18 19 26 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 67 68 :2 63 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 85
88 :2 30 8c 8f :2 30 9b 9e :2 30
a6 a9 :2 30 b5 b8 bf c8 cb
:2 b8 :2 30 :2 19 6b :2 16 :2 13 :4 1f :2 13
10 :3 2e d 2e 49 13 1c 25
:2 13 2a 28 33 3e :2 2a :2 28 10
1b 24 2d :2 1b 30 32 3b 46
:2 32 :2 1b :2 10 1f :2 10 18 10 13
1c 2d :2 13 30 32 :2 30 13 1b
1a 1d :2 1b 35 38 :2 1b 45 48
:2 1b 1f 22 :2 1b 2f 32 :2 1b 1a
1d :2 1b 46 49 51 5a 63 :2 51
:2 49 :2 1b :2 13 18 :2 26 13 34 13
1b 1a 1d :2 1b 35 38 :2 1b 41
44 :2 1b 6a 6d :2 1b 1f 22 :2 1b
1a 1d :2 1b 46 49 51 5a 63
:2 51 :2 49 :2 1b :2 13 18 :2 26 13 :5 10
16 1f 30 :2 16 33 35 :2 33 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 37 1c
2b :2 16 19 23 :2 19 :2 22 2e 19
29 19 :2 22 2e 19 :4 16 :4 13 17
:2 20 2c 29 :2 35 :2 29 :3 16 45 :2 13
10 14 41 13 1c 2d :2 13 30
32 :2 30 16 1c :3 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :4 34 16 1c :3 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 14 13 16 1f 30 :2 16
33 35 :2 33 16 1e 16 19 :2 23
35 :2 3f 4b 4e 62 66 67 :2 62
:2 35 :3 19 :2 1f 24 30 75 78 :2 30
:2 19 6a :3 16 1d :2 26 16 37 16
1e 16 19 :2 23 35 :2 3f 4b 4e
62 66 67 :2 62 :2 35 :3 19 :2 1f 24
30 75 78 :2 30 :2 19 6a :3 16 1d
:2 26 16 :4 13 29 :2 10 1a 25 32
3a 41 57 62 67 :2 18 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 67 68
:2 63 :2 35 :3 19 :2 1f 24 30 75 78
:2 30 85 88 :2 30 8c 8f :2 30 9b
9e :2 30 a6 a9 :2 30 b5 b8 bf
c8 cb :2 b8 :2 30 :2 19 6b :2 16 :2 13
:4 1f :2 13 10 :3 41 10 1b :2 10 1d
10 41 49 :2 d a 5f 10 19
24 :2 10 2a 27 33 44 :2 2a :2 27
10 19 25 :2 10 28 2a :2 28 30
39 44 :2 30 49 47 52 5e :2 49
:2 47 :3 10 18 10 13 :2 1d 2f :2 39
45 48 5c 60 61 :2 5c :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a :2 13 64
:3 10 17 :2 20 10 61 :2 d 10 19
28 :2 10 2d 2b 36 40 :2 2d :2 2b
10 18 10 13 :2 1d 2f :2 39 45
48 5c 60 61 :2 5c :2 2f :3 13 :2 19
1e 2a 6f 72 :2 2a :2 13 64 :3 10
17 :2 20 10 43 :2 d 10 19 24
:2 10 27 29 :2 27 10 23 10 2b
14 1d 28 :2 14 2b 2d :2 2b 13
34 3d 48 :2 34 4b 4d :2 4b 33
:3 13 1b 13 16 :2 20 32 :2 3c 48
4b 5f 63 64 :2 5f :2 32 :3 16 :2 1c
21 2d 72 75 :2 2d :2 16 67 :3 13
1a :2 23 13 58 :3 10 23 2c 37
:2 23 10 :5 d 1a 22 2b 36 :2 22
39 3b 44 55 :2 3b :2 22 21 59
5b :2 21 20 65 67 :2 20 :2 1a d
10 19 24 :2 10 29 27 32 3c
:2 29 :2 27 10 1e 10 1a 28 18
19 26 37 4b :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 67 68 :2 63 :2 35
:3 19 :2 1f 24 30 75 78 :2 30 85
88 :2 30 8c 8f :2 30 9b 9e :2 30
a6 a9 :2 30 b5 b8 bf c8 cb
:2 b8 :2 30 :2 19 6b :2 16 :2 13 :4 1f :2 13
10 :3 3f 13 1c 28 :2 13 2b 2d
:2 2b 13 1b 13 16 :2 20 32 :2 3c
48 4b 5f 63 64 :2 5f :2 32 :3 16
:2 1c 21 2d 72 75 :2 2d :2 16 67
:3 13 1a 13 2f :2 10 3f :2 d 10
19 26 :2 10 2b 29 :2 34 :2 29 49
13 20 :2 49 25 23 :2 2e :2 23 :3 10
20 21 :2 20 :2 10 23 3a 48 53
5e 64 6a 2d 39 47 5a :2 23
10 14 1d 29 :2 14 2c 2e :2 2c
13 :4 37 36 35 :2 13 1d 28 35
3d 44 5f 6a 6f :2 1b :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 6a 6b
:2 66 :2 38 :3 1c :2 22 27 33 78 7b
:2 33 88 8b :2 33 8f 92 :2 33 9e
a1 :2 33 a9 ac :2 33 b8 bb c2
cb ce :2 bb :2 33 :2 1c 6e :2 19 :2 16
:4 22 :2 16 13 :4 56 :3 10 1d 25 2e
3f :2 25 42 44 4d 58 :2 44 :2 25
24 5c 5e :2 24 23 68 6a :2 23
:2 1d :2 10 1e 2a 38 49 54 62
1d 28 33 :2 1e :2 10 1e :2 27 2e
37 48 :2 2e 4c :2 55 :2 1e :2 10 1e
2e 3c 47 53 56 :2 1e 10 1a
22 29 40 48 4f 68 72 83
91 18 1e 24 30 43 4f 18
19 2d :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 67 68 :2 63 :2 35 :3 19 :2 1f
24 30 75 78 :2 30 85 88 :2 30
8c 8f :2 30 9b 9e :2 30 a6 a9
:2 30 b5 b8 bf c8 cb :2 b8 :2 30
:2 19 6b :2 16 :2 13 :4 1f :2 13 10 :3 42
10 20 :2 10 1e 35 43 4e 59
5f 65 28 34 42 55 :2 1e :2 10
1e 28 :2 1e :2 10 18 10 13 :2 1d
2f :2 39 45 48 5c 60 61 :2 5c
:2 2f :3 13 :2 19 1e 2a 6f 72 :2 2a
:2 13 64 :3 10 17 20 2c :2 17 10
42 10 1b :2 10 1d 10 13 1c
27 :2 13 2a 2c :2 2a 13 20 13
2f :3 10 21 :2 2a 31 :2 3a 41 :2 4a
58 :2 61 :2 31 72 :2 7b :2 21 10 1a
2f 3d 49 13 21 2d 3c 13
21 2a 31 3d 19 2d 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 67 68 :2 63 :2 35 :3 19 :2 1f 24
30 75 78 :2 30 85 88 :2 30 8c
8f :2 30 9b 9e :2 30 a6 a9 :2 30
b5 b8 bf c8 cb :2 b8 :2 30 :2 19
6b :2 16 :2 13 :4 1f :2 13 10 :3 d 13
1c 27 :2 13 2a 2d :2 2a 13 20
13 2f :2 10 :4 d 47 5f :2 a d
17 19 :2 17 d 1d 1e :2 1d :2 d
20 37 45 50 5b 61 67 2d
39 47 5a :2 20 d 11 1a 26
:2 11 29 2b :2 29 10 :4 34 33 32
:3 10 1e 33 41 4c 56 67 26
38 44 :2 1e 10 53 :2 d :4 11 :2 10
23 33 41 4c :2 23 10 2e 13
1a 26 29 :2 13 2c 2e :2 2c 13
26 36 44 4f :2 26 13 32 13
26 36 44 4f :2 26 13 :4 10 :4 d
:4 11 10 13 1c 27 :2 13 2a 2c
:2 2a 13 21 :2 2a 31 3a 45 :2 31
49 :2 52 :2 21 20 13 1d 28 35
3d 44 5f 6a 6f :2 1b :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 6a 6b
:2 66 :2 38 :3 1c :2 22 27 33 78 7b
:2 33 88 8b :2 33 8f 92 :2 33 9e
a1 :2 33 a9 ac :2 33 b8 bb c2
cb ce :2 bb :2 33 :2 1c 6e :2 19 :2 16
:4 22 :2 16 13 :4 2e 1d 28 35 3d
44 5f 6a 6f :2 1b :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 6a 6b :2 66
:2 38 :3 1c :2 22 27 33 78 7b :2 33
88 8b :2 33 8f 92 :2 33 9e a1
:2 33 a9 ac :2 33 b8 bb c2 cb
ce :2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22
:2 16 13 :8 10 1c 25 2f :2 1c 32
34 3d 4c :2 34 :2 1c 10 2f :3 d
1f :2 d 20 2e 39 47 51 61
24 30 39 42 :2 30 46 4f 60
:2 46 :2 20 d 10 19 2a :2 10 2d
30 :2 2d 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 60 61 :2 5c :2 2f
:3 13 :2 19 1e 2a 6f 72 :2 2a :2 13
64 :3 10 17 :2 20 10 d 32 13
1d 1f :2 1d 17 18 19 2d 10
1a 2f 3d 4b 54 5b 68 71
7e 87 13 22 2b 37 47 57
60 6d 13 27 19 2d 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 67 68 :2 63 :2 35 :3 19 :2 1f 24
30 75 78 :2 30 85 88 :2 30 8c
8f :2 30 9b 9e :2 30 a6 a9 :2 30
b5 b8 bf c8 cb :2 b8 :2 30 :2 19
6b :2 16 :2 13 :4 1f :2 13 10 :4 21 32
:3 d 1b 25 :2 1b :2 d 15 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d 14 1d 29 :2 14
d 1b :2 a d 16 22 :2 d 28
25 31 40 :2 28 :2 25 d 1b d
17 27 15 24 34 16 2a 14
29 14 1e 27 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 64 65 :2 60 :2 32
:3 16 :2 1c 21 2d 72 75 :2 2d 82
85 :2 2d 89 8c :2 2d 98 9b :2 2d
a3 a6 :2 2d b2 b5 bc c5 c8
:2 b5 :2 2d :2 16 68 :2 13 :2 10 :4 1c :2 10
d :3 43 10 19 25 :2 10 28 2a
:2 28 10 18 10 13 :2 1d 2f :2 39
45 48 5c 60 61 :2 5c :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a :2 13 64
:3 10 17 :2 20 10 2c :3 d 1d 26
32 :2 1d :2 d 1f 28 32 :2 1f d
10 19 27 :2 10 2c 2a 35 3f
:2 2c :2 2a 13 1c 29 :2 13 2e 2c
:2 37 :2 2c 4e 16 23 :2 4e 28 26
:2 31 :2 26 :3 13 22 13 1d 23 2e
32 1b 24 1b 1c 29 1a 2e
1a :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 6a 6b :2 66 :2 38 :3 1c :2 22 27
33 78 7b :2 33 88 8b :2 33 8f
92 :2 33 9e a1 :2 33 a9 ac :2 33
b8 bb c2 cb ce :2 bb :2 33 :2 1c
6e :2 19 :2 16 :4 22 :2 16 13 :3 43 :4 17
:2 16 26 16 30 :2 13 16 1f 28
:2 16 2b 2d :2 2b 16 26 27 :2 26
:2 16 29 40 4e 59 64 6a 70
2d 39 47 5a :2 29 16 1a 23
2f :2 1a 32 34 :2 32 19 :4 3d 3c
3b :2 19 23 2f 3f 21 22 2f
40 54 62 6d 75 7c :2 1c :2 25
31 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6c 70 71
:2 6c :2 3e :3 22 :2 28 2d 39 7e 81
:2 39 8e 91 :2 39 95 98 :2 39 a4
a7 :2 39 af b2 :2 39 be c1 c8
d1 d4 :2 c1 :2 39 :2 22 74 :2 1f :2 1c
:4 28 :2 1c 19 :3 5c 19 25 2e 3c
:2 25 3f 41 4a 59 :2 41 :2 25 5c
5e 67 72 :2 5e :2 25 19 5c 19
25 2e 3c :2 25 3f 41 4a 59
:2 41 :2 25 19 :5 16 28 :2 16 23 2a
33 3d :2 33 48 :2 2a 4b 4d 56
60 :2 56 6a :2 4d :2 2a 29 6e 70
:2 29 :2 23 :2 16 24 2d 38 :2 24 3b
3d 46 4f :2 3d :2 24 16 19 22
2e :2 19 34 31 3d 47 :2 34 :2 31
19 2b 34 3f :2 2b 42 44 4d
59 :2 44 :2 2b 5c 5e 67 71 :2 5e
:2 2b 19 4a 19 2b 34 3f :2 2b
19 :5 16 24 30 3e 4f 5a 68
1e 2e 39 :2 24 :2 16 29 30 39
43 :2 39 4f :2 30 52 54 5d 67
:2 5d 73 :2 54 :2 30 2f 24 26 :2 2f
:2 29 :2 16 24 :2 2d 34 3d 4e :2 34
52 :2 5b :2 24 :2 16 24 34 42 4d
59 62 6d :2 59 71 1f 30 :2 71
:2 24 :2 16 26 :2 16 24 3b 49 54
5f 65 6b 28 34 42 55 :2 24
16 2f :2 13 43 13 25 :2 13 21
2a 34 :2 21 :2 13 26 3a 48 53
5d 2a 3c 48 52 2a 3a 49
59 2a 37 43 50 2a 39 47
2a 3d 49 55 2a 33 3e :2 2a
42 4b 58 :2 42 :2 26 :2 13 24 2d
37 :2 24 :2 13 1f 28 36 :2 1f 39
3b 44 53 :2 3b :2 1f 13 20 28
2f 4f 65 :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 6a 6b :2 66 :2 38 :3 1c
:2 22 27 33 78 7b :2 33 88 8b
:2 33 8f 92 :2 33 9e a1 :2 33 a9
ac :2 33 b8 bb c2 cb ce :2 bb
:2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16 13
:3 10 20 2b 38 40 47 5f 6a
8b 9d :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 6a 6b :2 66 :2 38 :3 1c :2 22
27 33 78 7b :2 33 88 8b :2 33
8f 92 :2 33 9e a1 :2 33 a9 ac
:2 33 b8 bb c2 cb ce :2 bb :2 33
:2 1c 6e :2 19 :2 16 :4 22 :2 16 13 :3 10
1d 32 40 4e 57 5e 6a 73
16 23 31 3f 4d 56 16 2d
45 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 6a 6b
:2 66 :2 38 :3 1c :2 22 27 33 78 7b
:2 33 88 8b :2 33 8f 92 :2 33 9e
a1 :2 33 a9 ac :2 33 b8 bb c2
cb ce :2 bb :2 33 :2 1c 6e :2 19 :2 16
:4 22 :2 16 13 :3 10 17 :2 20 2b 29
:2 34 :2 29 :2 16 28 :2 16 24 32 3d
4b 55 65 70 1f 22 2b 3c
:2 22 :2 24 16 19 22 2e :2 19 31
34 :2 31 19 21 19 1c :2 26 38
:2 42 4e 51 65 69 6a :2 65 :2 38
:3 1c :2 22 27 33 78 7b :2 33 :2 1c
6d :3 19 20 29 35 :2 20 19 36
:2 16 44 :2 13 :5 10 1c 25 33 :2 1c
:2 10 1e 10 42 10 22 2a 33
3d :2 33 4c :2 2a 4f 51 5a 64
:2 5a 6f :2 51 :2 2a 29 24 26 :2 29
28 30 32 :2 28 :2 22 10 :5 d 1b
2f 3d 48 52 5d 25 31 3b
49 25 34 44 50 25 31 3e
4c 25 33 42 55 25 31 3d
46 51 :2 3d 55 23 30 :2 55 :2 1b
:2 d 15 d 10 :2 1a 2c :2 36 42
45 59 5d 5e :2 59 :2 2c :3 10 :2 16
1b 27 6c 6f :2 27 :2 10 61 :3 d
14 1d 29 :2 14 d a 43 10
19 2b :2 10 31 2e 3a 4a :2 31
:2 2e 11 1a 29 :2 11 2c 2e :2 2c
10 36 3f 51 :2 36 54 56 :2 54
35 :3 10 18 10 13 :2 1d 2f :2 39
45 48 5c 60 61 :2 5c :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a :2 13 64
:3 10 17 :2 20 10 59 :2 d 17 2c
40 10 1e 27 2e 3a 43 16
2a 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 64 65 :2 60 :2 32
:3 16 :2 1c 21 2d 72 75 :2 2d 82
85 :2 2d 89 8c :2 2d 98 9b :2 2d
a3 a6 :2 2d b2 b5 bc c5 c8
:2 b5 :2 2d :2 16 68 :2 13 :2 10 :4 1c :2 10
d :3 4d 17 23 31 3a 41 4d
56 16 23 34 41 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 60
64 65 :2 60 :2 32 :3 16 :2 1c 21 2d
72 75 :2 2d 82 85 :2 2d 89 8c
:2 2d 98 9b :2 2d a3 a6 :2 2d b2
b5 bc c5 c8 :2 b5 :2 2d :2 16 68
:2 13 :2 10 :4 1c :2 10 d :4 4d 43 :3 a
18 22 :2 18 :2 a 12 a d :2 17
29 :2 33 3f 42 56 5a 5b :2 56
:2 29 :3 d :2 13 18 24 69 6c :2 24
:2 d 5e :3 a 11 1a 26 :2 11 a
52 38 14 17 24 27 34 37
43 46 17 1a 17 1a d 10
d 10 1c 1f 12 21 30 3e
:4 d 1b 12 27 30 33 47 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5d 61
62 :2 5d :2 2f :3 13 :2 19 1e 2a 6f
72 :2 2a 7f 82 :2 2a 86 89 :2 2a
95 98 :2 2a a0 a3 :2 2a af b2
b9 c2 c5 :2 b2 :2 2a :2 13 65 :2 10
:2 d :4 19 :2 d a :3 7 12 :2 1b 26
24 :2 2f :2 24 11 :4 d 15 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d 14 :2 1d d 3f
:2 a d :2 18 1f 2e :2 d 3d 3f
:2 3d d :2 16 22 :2 d 15 d 10
:2 1a 2c :2 36 42 45 59 5d 5e
:2 59 :2 2c :3 10 :2 16 1b 27 6c 6f
:2 27 :2 10 61 :3 d 14 :2 1d d 41
:2 a :4 7 35 :3 4 11 :2 4 15 :2 4
12 :2 4 14 :2 1d :2 4 :2 d 19 30
3e 49 58 :2 19 :2 4 c 4 7
:2 11 23 :2 2d 39 3c 50 54 55
:2 50 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e :2 7 58 :3 4 b :2 14 4 7
:2 11 23 :2 2d 39 3c 50 54 55
:2 50 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a :2 93 :2 1e :2 7 58 :3 4 b :2 14
4 :9 1 
2a06
4
0 :2 1 :6 3 :6 4
:6 5 :6 6 :4 7 :4 8
:4 9 :4 a :6 b :6 c
2 :2 d :2 1 :6 f
:6 10 :6 11 :6 12 :7 13
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:5 20 :5 21 :5 22 :5 23
:5 24 :5 25 :5 26 :5 27
:5 28 :5 29 :5 2a :5 2b
:5 2c :7 2d :7 2e :6 2f
:6 30 :6 31 :6 32 :5 33
:5 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :7 3f
:7 40 :7 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:7 60 :7 61 :6 62 :7 63
:6 64 :6 65 :6 66 :6 67
:6 68 :6 69 :6 6a :6 6b
:6 6c :6 6d :6 6e :7 6f
:5 70 :5 71 :5 72 :2 74
0 :2 74 :6 75 76
:5 77 :3 78 79 75
:5 74 :7 7c :7 7f :b 82
:11 83 84 :2 83 :2 84
:2 83 :2 84 :2 83 :2 85
:2 83 :2 85 :2 83 :2 85
:2 83 :2 85 :2 83 :2 86
:2 83 :12 86 :2 83 :2 87
:2 83 :12 87 :2 83 :2 88
:2 83 :9 88 :2 83 :2 89
:2 83 :9 89 :2 83 :2 8a
:2 83 :9 8a :2 83 :2 8b
:2 83 :9 8b :2 83 :2 8c
:2 83 :2 8c :2 83 :2 8c
:2 83 :2 8c :2 83 :2 8d
:2 83 :2 8d :2 83 :2 8d
:2 83 :2 8d :2 83 :2 8d
:4 83 :3 82 :11 90 :b 91
:3 90 :3 96 :3 97 :3 98
:3 99 :3 9c :8 9f :2 a0
:2 a1 :2 a2 :4 a3 :4 a4
a5 a6 a7 :2 a8
:2 a9 :3 aa 9f :5 ab
9e ad :5 ae :3 ad
:2 af :5 b1 :11 b2 :24 b3
:3 b2 :2 b0 :6 af ac
:3 81 :a b8 :6 ba :6 bb
:8 bc :5 bd :8 be :4 bf
:4 c0 :3 c1 :6 c2 :6 c3
:5 c4 :3 c5 :4 c6 :4 c7
:4 c8 :3 c9 ca :2 cb
ba :5 cc b9 ce
:5 cf :3 ce :2 d0 :5 d2
:11 d3 :24 d4 :3 d3 :2 d1
:6 d0 cd :3 b8 :a d9
:8 db :a dc :8 dd :7 de
:3 df db :5 e0 da
e2 :5 e3 :3 e2 :2 e4
:5 e6 :11 e7 :24 e8 :3 e7
:2 e5 :6 e4 e1 :3 d9
:a ed :3 ee :11 ef :b f0
:3 ef :5 f2 :3 ed :2 f4
:2 f5 :2 f4 :3 f5 :3 f4
:6 f5 :3 f6 :11 f7 :b f8
:3 f7 :5 fa f5 :2 f4
:3 fd :3 fe :10 ff :3 100
:2 ff :4 100 :3 ff :3 101
:11 102 :b 103 :3 102 :5 105
100 :2 ff :16 108 :2 109
:7 108 :3 10a :11 10b :b 10c
:3 10b :5 10e 109 :2 108
:11 111 :2 112 :2 111 :4 112
:3 111 :9 113 :c 114 :9 116
117 :2 118 :4 119 116
:5 11a 115 11c :5 11d
:3 11c :2 11e :5 120 :11 121
:24 122 :3 121 :2 11f :6 11e
11b :3 114 :a 127 :8 129
12a 129 :5 12b 128
12d :5 12e :3 12d :2 12f
:5 131 :11 132 :24 133 :3 132
:2 130 :6 12f 12c :6 127
:c 139 :3 13a :3 139 114
:9 13e 13f :2 140 :4 141
13e :5 142 13d 144
:5 145 :3 144 :2 146 :5 148
:11 149 :24 14a :3 149 :2 147
:6 146 143 :3 13c :a 14f
:8 151 152 151 :5 153
150 155 :5 156 :3 155
:2 157 :5 159 :11 15a :24 15b
:3 15a :2 158 :6 157 154
:6 14f :3 161 13c :3 114
:b 164 :7 166 :2 167 166
:6 168 :5 169 168 :5 16b
16a :3 168 165 16e
:5 16f :3 16e :2 170 :5 172
:11 173 :24 174 :3 173 :2 171
:6 170 16d :4 164 :7 17a
:2 17b 17a :6 17c :5 17d
17c :5 17f 17e :3 17c
179 182 :5 183 :3 182
:2 184 :5 186 :11 187 :24 188
:3 187 :2 185 :6 184 181
:4 178 :3 164 :a 18e :6 18f
:3 18e 113 :3 192 :3 193
:c 194 :2 195 :2 194 :6 195
:2 194 :3 197 198 :2 199
:7 19a 197 :5 19b 196
19d :5 19e :3 19d :2 19f
:5 1a1 :11 1a2 :24 1a3 :3 1a2
:2 1a0 :6 19f 19c :4 195
:2 194 :c 1a9 :9 1ab 1ac
:2 1ad :4 1ae 1ab :5 1af
1aa 1b1 :5 1b2 :3 1b1
:2 1b3 :5 1b5 :11 1b6 :24 1b7
:3 1b6 :2 1b4 :6 1b3 1b0
:3 1a9 :a 1bc :8 1be 1bf
1be :5 1c0 1bd 1c2
:5 1c3 :3 1c2 :2 1c4 :5 1c6
:11 1c7 :24 1c8 :3 1c7 :2 1c5
:6 1c4 1c1 :3 1bc :b 1cc
:3 1bc :c 1cf :2 1d0 :2 1cf
:6 1d0 :2 1cf :3 1d1 :3 1d2
1d0 :2 1cf 1a9 :9 1d5
:3 1d6 :3 1d8 1d9 :4 1da
:5 1db 1d8 :5 1dc 1d7
1de :5 1df :3 1de :2 1e0
:5 1e2 :11 1e3 :24 1e4 :3 1e3
:2 1e1 :6 1e0 1dd :3 1d5
:9 1e9 :3 1eb 1ec :4 1ed
:6 1ee 1eb :5 1ef 1ea
1f1 :5 1f2 :3 1f1 :2 1f3
:5 1f5 :11 1f6 :24 1f7 :3 1f6
:2 1f4 :6 1f3 1f0 :6 1e9
:9 1fd :3 1fe :11 1ff :b 200
:3 1ff :5 202 :3 1fd :3 1d5
:9 207 208 :2 209 :4 20a
207 :5 20b 206 20d
:5 20e :3 20d :2 20f :5 211
:11 212 :24 213 :3 212 :2 210
:6 20f 20c :3 1d4 :a 218
:8 21a 21b 21a :5 21c
219 21e :5 21f :3 21e
:2 220 :5 222 :11 223 :24 224
:3 223 :2 221 :6 220 21d
:6 218 :14 22a :b 22b :5 22a
:3 22c :3 22d 22b :2 22a
1d4 :3 1a9 :12 232 :2 233
:2 232 :7 233 :2 234 :2 233
:6 234 :5 232 :9 235 234
:2 232 :3 238 :3 23a :2 23b
:6 23c :2 23d :2 23e :7 23f
:e 240 23a :5 241 239
243 :5 244 :3 243 :2 245
:5 247 :11 248 :24 249 :3 248
:2 246 :6 245 242 :3 191
:9 24e :3 24f :11 250 :b 251
:3 250 :5 253 :3 24e :7 256
:5 257 :6 258 :3 256 :9 259
:6 25a 259 :3 25c :11 25d
:b 25e :3 25d :7 260 25b
:3 259 191 :3 113 263
112 :1a 263 :3 264 :d 265
:3 266 :11 267 :b 268 :3 267
:5 26a 26c 265 :d 26c
:3 26d 26c :3 265 :3 271
:2 273 274 :6 275 :3 276
:4 277 :4 278 :4 279 273
:5 27a 272 27c :5 27d
:3 27c :2 27e :5 280 :11 281
:24 282 :3 281 :2 27f :6 27e
27b :3 263 :9 287 :3 288
:11 289 :b 28a :3 289 :5 28c
:3 287 :3 290 :3 292 :5 293
:8 294 :6 295 :6 296 292
:5 297 291 299 :5 29a
:3 299 :2 29b :5 29d :11 29e
:24 29f :3 29e :2 29c :6 29b
298 :3 263 :9 2a4 :3 2a5
:11 2a6 :b 2a7 :3 2a6 :5 2a9
:3 2a4 :7 2ac :7 2ae :2 2af
:2 2ae :a 2af :3 2ae 263
112 :2 111 :9 2b2 :6 2b3
:3 2b2 :3 2b6 :11 2b7 :b 2b8
:3 2b7 :7 2ba 2bb d9
:c 2bb :3 2bc :3 2bd :10 2bf
:3 2c0 :2 2bf :4 2c0 :3 2bf
:3 2c1 :11 2c2 :b 2c3 :3 2c2
:5 2c5 2c0 :2 2bf :5 2c7
:6 2c9 2ca :2 2cb 2c9
:5 2cc 2c8 2ce :5 2cf
:3 2ce :2 2d0 :5 2d2 :11 2d3
:24 2d4 :3 2d3 :2 2d1 :6 2d0
2cd :3 2c7 :a 2d9 :3 2da
:11 2db :b 2dc :3 2db :5 2de
:3 2d9 :11 2e1 :2 2e2 :2 2e1
:4 2e2 :3 2e1 :3 2e3 :11 2e4
:b 2e5 :3 2e4 :5 2e7 2e8
2e2 :10 2e8 :3 2e9 :2 2e8
:4 2e9 :3 2e8 :3 2ea :11 2eb
:b 2ec :3 2eb :5 2ee 2e9
2e2 :2 2e1 :3 2c7 :6 2f3
:6 2f4 2f5 :4 2f6 2f3
:5 2f7 2f2 2f9 :5 2fa
:3 2f9 :2 2fb :5 2fd :11 2fe
:24 2ff :3 2fe :2 2fc :6 2fb
2f8 :3 2bb :2 304 :2 305
:2 304 :3 305 :3 304 :6 305
:3 306 :11 307 :b 308 :3 307
:5 30a 305 :2 304 :a 30d
:3 30e 30d :3 310 30f
:3 30d :3 313 :3 314 :11 316
:2 317 :2 316 :4 317 :3 316
:e 317 :2 316 :c 318 :e 319
31a :2 319 :4 31a :2 319
:3 31b :11 31c :b 31d :3 31c
:5 31f 31a :2 319 :c 322
:2 323 :2 322 :6 323 :2 322
:3 324 :3 326 327 :2 328
:7 329 326 :5 32a 325
32c :5 32d :3 32c :2 32e
:5 330 :11 331 :24 332 :3 331
:2 32f :6 32e 32b :3 323
:11 337 :2 338 :2 337 :4 338
:3 337 :3 33a :9 33b 338
:2 337 :6 33e :7 33f :5 340
:8 341 :5 342 :3 33e :6 344
:3 345 :11 346 :b 347 :3 346
:7 349 323 :3 34b :3 34c
:3 34d 34a :3 322 34f
318 :c 34f :8 351 352
353 351 :5 354 350
356 :5 357 :3 356 :2 358
:5 35a :11 35b :24 35c :3 35b
:2 359 :6 358 355 :3 34f
:9 361 :6 363 :8 364 :4 365
:3 364 :12 367 :7 368 :3 369
:3 368 :3 367 :a 36c :3 36d
36c :3 36f 36e :3 36c
:f 372 :9 374 :5 375 :9 376
:3 374 :9 378 :c 379 :7 37b
:5 37c :2 37d 37b :6 37e
:5 37f 37e :5 381 380
:3 37e 37a 384 :5 385
:3 384 :2 386 :5 388 :11 389
:24 38a :3 389 :2 387 :6 386
383 :3 379 38e 379
:e 38e 38f :2 38e :4 38f
:2 38e :8 391 :2 392 391
:6 393 :5 394 393 :5 396
395 :3 393 390 399
:5 39a :3 399 :2 39b :5 39d
:11 39e :24 39f :3 39e :2 39c
:6 39b 398 :4 38f :3 379
:3 378 :a 3a7 :6 3a8 3a9
:2 3aa 3a7 :5 3ab 3a6
3ad :5 3ae :3 3ad :2 3af
:5 3b1 :11 3b2 :24 3b3 :3 3b2
:2 3b0 :6 3af 3ac :3 34f
:3 3b8 :8 3b9 :4 3ba :3 3b9
:6 3bc :5 3be :3 3bf :11 3c0
:b 3c1 :3 3c0 :5 3c3 3c5
34f 318 :d 3c5 :f 3c6
:c 3c7 :2 3c8 :2 3c7 :6 3c8
:2 3c7 :b 3c9 :3 3ca 3c9
:3 3cc 3cb :3 3c9 :9 3cf
:3 3d1 :5 3d3 :4 3d5 :3 3d6
:5 3d7 3d6 :5 3d9 3d8
:3 3d6 :4 3dd :5 3de 3dc
3e0 :5 3e1 :3 3e0 :2 3e2
:5 3e4 :11 3e5 :24 3e6 :3 3e5
:2 3e3 :6 3e2 3df :3 3c8
:5 3eb :11 3ec :b 3ed :3 3ec
:5 3ef :3 3eb :6 3f2 :7 3f3
:5 3f4 :8 3f5 :5 3f6 :3 3f2
:6 3f8 :3 3f9 :11 3fa :b 3fb
:3 3fa :7 3fd 3c8 :3 3ff
3fe :3 3c7 401 3c5
318 :9 401 :3 402 :3 403
:2 406 407 :2 408 406
:5 409 405 40b :5 40c
:3 40b :2 40d :5 40f :11 410
:24 411 :3 410 :2 40e :6 40d
40a :3 401 415 401
318 :d 415 :f 416 :3 417
:3 418 :9 41a :2 41b :2 41c
:2 41b :2 41c :2 41b :2 41c
:2 41b :2 41d :2 41b :2 41d
:2 41b :2 41e :2 41b :9 41e
:3 41b :5 420 41a :2 422
:2 423 :2 422 :2 423 :2 422
:2 423 :2 422 :2 423 :2 422
:2 424 :2 422 :2 425 :2 422
:9 425 :3 422 :5 427 421
:3 41a 42a :9 42b :4 42c
:3 42d :5 42e 42d :5 430
42f :3 42d 42b :4 433
:3 434 :5 435 434 :5 437
436 :3 434 432 :3 42b
:a 43b :2 43c :3 43b 42a
43e 415 :9 440 :4 442
:5 443 441 445 :5 446
:3 445 :2 447 :5 449 :11 44a
:24 44b :3 44a :2 448 :6 447
444 :4 440 :4 451 :5 452
450 454 :5 455 :3 454
:2 456 :5 458 :11 459 :24 45a
:3 459 :2 457 :6 456 453
:4 44f :3 440 :5 460 :9 461
:3 462 :11 463 :b 464 :3 463
:5 466 461 :3 468 :11 469
:b 46a :3 469 :5 46c 467
:3 461 :3 460 :8 471 472
473 471 :5 474 470
476 :5 477 :3 476 :2 478
:5 47a :11 47b :24 47c :3 47b
:2 479 :6 478 475 :3 415
:3 480 :3 481 415 :3 318
483 317 :d 483 :18 484
:3 485 :11 486 :b 487 :3 486
:5 489 :3 484 :d 48c :3 48d
:11 48e :b 48f :3 48e :5 491
:3 48c :9 494 :3 495 494
:16 497 :3 498 :11 499 :b 49a
:3 499 :5 49c :3 497 :7 4a0
496 :3 494 :1c 4a3 :d 4a4
:3 4a5 :2 4a7 4a8 :4 4a9
4a7 :5 4aa 4a6 4ac
:5 4ad :3 4ac :2 4ae :5 4b0
:11 4b1 :24 4b2 :3 4b1 :2 4af
:6 4ae 4ab :3 4a4 :9 4b7
:3 4bf :11 4c0 :b 4c1 :3 4c0
:3 4c3 :3 4b7 :3 4a4 :c 4c7
:2 4c8 :2 4c7 :6 4c8 :2 4c7
:6 4c9 :8 4ca :4 4cb :3 4ca
:12 4cd :8 4d7 4d8 4d9
4d7 :5 4da 4d6 4dc
:5 4dd :3 4dc :2 4de :5 4e0
:11 4e1 :24 4e2 :3 4e1 :2 4df
:6 4de 4db :6 4cd :1c 4e8
:7 4e9 :3 4ea :3 4e9 :f 4ec
:a 4ed :a 4f0 :6 4f1 4f2
:2 4f3 4f0 :5 4f4 4ef
4f6 :5 4f7 :3 4f6 :2 4f8
:5 4fa :11 4fb :24 4fc :3 4fb
:2 4f9 :6 4f8 4f5 :3 4c8
:3 501 :8 502 :4 503 :3 502
:6 505 :3 506 :11 507 :b 508
:3 507 :7 50a 4c8 :3 50c
:3 50d :9 50e :3 50f :3 50e
:15 514 :4 516 :4 517 :5 518
:2 519 516 :6 51a :5 51b
51a :5 51d 51c :3 51a
515 520 :5 521 :3 520
:2 522 :5 524 :11 525 :24 526
:3 525 :2 523 :6 522 51f
:3 50b :9 52b :3 52c :3 52b
50b :3 4c7 483 317
:2 316 :5 531 :6 532 :8 533
:4 534 :3 533 :12 536 :7 537
:3 538 :3 537 :3 536 :5 53b
:8 53c 53b :a 53e :8 53f
53e :8 541 540 :3 53e
53d :3 53b :5 545 :9 546
:10 547 :8 54a 54b 54c
54a :5 54d 549 54f
:5 550 :3 54f :2 551 :5 553
:11 554 :24 555 :3 554 :2 552
:6 551 54e :4 546 :8 55b
55c 55d 55b :5 55e
55a 560 :5 561 :3 560
:2 562 :5 564 :11 565 :24 566
:3 565 :2 563 :6 562 55f
:4 559 :3 546 :f 56c :3 545
:3 56f :7 570 :b 571 :3 570
:9 573 :3 574 :11 575 :b 576
:3 575 :5 578 579 573
:5 579 57a 57b :2 57c
57a :a 57f :8 580 :2 581
:2 582 57f :6 583 :5 584
583 :5 586 585 :3 583
57e 589 :5 58a :3 589
:2 58b :5 58d :11 58e :24 58f
:3 58e :2 58c :6 58b 588
:4 579 :3 573 :6 595 :3 596
:11 597 :b 598 :3 597 :7 59a
:3 531 :d 59d :3 59f :2 5a1
5a2 :2 5a3 :2 5a4 :2 5a5
:3 5a6 5a1 :5 5a7 5a0
5a9 :5 5aa :3 5a9 :2 5ab
:5 5ad :11 5ae :24 5af :3 5ae
:2 5ac :6 5ab 5a8 :3 59d
:9 5b4 :3 5b5 :11 5b6 :b 5b7
:3 5b6 :5 5b9 :3 5b4 :7 5bc
:7 5be :d 5bf :c 5c0 :2 5c1
:2 5c0 :6 5c1 :2 5c0 :3 5c2
:4 5c4 :2 5c5 5c6 :2 5c7
:2 5c8 5c9 5c4 :5 5ca
5c3 5cc :5 5cd :3 5cc
:2 5ce :5 5d0 :11 5d1 :24 5d2
:3 5d1 :2 5cf :6 5ce 5cb
:3 5c1 :5 5d7 :3 5d8 :3 5d7
:9 5db :6 5dc :8 5dd :4 5de
:3 5dd :12 5e0 :3 5e2 5e3
:8 5e4 5e2 :5 5e5 5e1
5e7 :5 5e8 :3 5e7 :2 5e9
:5 5eb :11 5ec :24 5ed :3 5ec
:2 5ea :6 5e9 5e6 :3 5e0
:17 5f2 5e0 :f 5f4 5f3
:3 5e0 :3 5f6 :1d 5f8 :f 5f9
:d 5fa :17 5fb 5fa :7 5fd
5fc :3 5fa :7 600 :3 601
:3 600 :16 604 :2 605 :5 604
:f 606 :b 607 :2 608 :5 607
:3 60a :8 60b :4 60c :3 60b
:3 5db 5c1 :3 64d :7 64e
:6 64f :4 650 :4 651 :4 652
:3 653 :4 654 :a 655 :3 64f
:7 657 :f 658 :6 65a :5 65b
659 65d :5 65e :3 65d
:2 65f :5 661 :11 662 :24 663
:3 662 :2 660 :6 65f 65c
:3 60e :a 668 :5 669 667
66b :5 66c :3 66b :2 66d
:5 66f :11 670 :24 671 :3 670
:2 66e :6 66d 66a :3 60e
:8 677 :6 678 :3 679 :2 67a
677 :6 67b :5 67c 67b
:5 67e 67d :3 67b 676
681 :5 682 :3 681 :2 683
:5 685 :11 686 :24 687 :3 686
:2 684 :6 683 680 :3 60e
:a 68c :3 68d :8 68e :6 68f
:3 68e :9 691 :3 692 :11 693
:b 694 :3 693 :7 696 :3 691
:3 68c 60e :3 5c0 :7 69b
:3 69c 5bf :16 69e :2 69f
:3 69e :2 69f :5 69e 69d
:3 5bf :7 6a2 :4 6a3 :4 6a4
:4 6a5 :4 6a6 :8 6a7 :2 6a8
:2 6a7 :3 6a2 :3 6aa :11 6ab
:b 6ac :3 6ab :7 6ae 6af
59d :d 6af :16 6b0 :3 6b1
:11 6b2 :b 6b3 :3 6b2 :5 6b5
:3 6b0 :3 6da :6 6db :2 6dc
6da :6 6dd :5 6de 6dd
:5 6e0 6df :3 6dd 6d9
6e3 :5 6e4 :3 6e3 :2 6e5
:5 6e7 :11 6e8 :24 6e9 :3 6e8
:2 6e6 :6 6e5 6e2 :3 6af
:7 6f3 :4 6f4 6f3 :6 6f5
:5 6f6 6f5 :5 6f8 6f7
:3 6f5 6f2 6fb :5 6fc
:3 6fb :2 6fd :5 6ff :11 700
:24 701 :3 700 :2 6fe :6 6fd
6fa :4 6af :3 59d :6 709
:3 70a :11 70b :b 70c :3 70b
:7 70e 2bb d9 :8 711
:2 712 :2 713 :2 714 :4 715
:4 716 717 718 719
:2 71a :5 71b 711 :5 71c
710 71e :5 71f :3 71e
:2 720 :5 722 :11 723 :24 724
:3 723 :2 721 :6 720 71d
:3 70f :d 72a :3 72b :11 72c
:b 72d :3 72c :5 72f :3 72a
:b 732 :5 733 :3 734 :11 735
:b 736 :3 735 :5 738 :3 732
70f :3 d9 :3 b8 :3 73d
:3 73e :3 73f :5 741 :b 742
:3 744 :11 745 :b 746 :3 745
:5 748 :11 74a :19 74b :3 74a
:5 74d :2 81 :7 1 
92d7
4
:3 0 1 :3 0 2
:a 0 2a01 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
9 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
4 :3 0 5 :3 0
9 :3 0 a :5 0
1 19 18 :3 0
c :3 0 b :7 0
1d 1c :3 0 11
be 0 f c
:3 0 d :7 0 21
20 :3 0 c :3 0
e :7 0 25 24
:3 0 15 eb 0
13 c :3 0 f
:7 0 29 28 :3 0
4 :3 0 5 :3 0
6 :3 0 10 :5 0
1 2f 2e :3 0
22 117 0 17
4 :3 0 5 :3 0
6 :3 0 11 :5 0
1 35 34 :3 0
12 :3 0 c :3 0
37 39 0 2a01
2 3a :2 0 26
153 0 24 c
:3 0 3d :7 0 b
:3 0 41 3e 3f
29ff 0 13 :6 0
c :3 0 43 :7 0
d :3 0 47 44
45 29ff 0 14
:6 0 18 :2 0 28
c :3 0 49 :7 0
e :3 0 4d 4a
4b 29ff 0 15
:6 0 c :3 0 4f
:7 0 f :3 0 53
50 51 29ff 0
16 :6 0 18 :2 0
2c 6 :3 0 2a
55 57 :6 0 5a
58 0 29ff 0
17 :6 0 1b :2 0
30 6 :3 0 2e
5c 5e :6 0 61
5f 0 29ff 0
19 :6 0 1b :2 0
34 6 :3 0 32
63 65 :6 0 68
66 0 29ff 0
1a :6 0 18 :2 0
38 6 :3 0 36
6a 6c :6 0 6f
6d 0 29ff 0
1c :6 0 1b :2 0
3c 6 :3 0 3a
71 73 :6 0 76
74 0 29ff 0
1d :6 0 18 :2 0
40 6 :3 0 3e
78 7a :6 0 7d
7b 0 29ff 0
1e :6 0 18 :2 0
44 6 :3 0 42
7f 81 :6 0 84
82 0 29ff 0
1f :6 0 18 :2 0
48 6 :3 0 46
86 88 :6 0 8b
89 0 29ff 0
20 :6 0 18 :2 0
4c 6 :3 0 4a
8d 8f :6 0 92
90 0 29ff 0
21 :6 0 18 :2 0
50 6 :3 0 4e
94 96 :6 0 99
97 0 29ff 0
22 :6 0 18 :2 0
54 6 :3 0 52
9b 9d :6 0 a0
9e 0 29ff 0
23 :6 0 18 :2 0
58 6 :3 0 56
a2 a4 :6 0 a7
a5 0 29ff 0
24 :6 0 5e 308
0 5c 6 :3 0
5a a9 ab :6 0
ae ac 0 29ff
0 25 :6 0 62
33c 0 60 9
:3 0 b0 :7 0 b3
b1 0 29ff 0
26 :6 0 9 :3 0
b5 :7 0 b8 b6
0 29ff 0 27
:6 0 66 370 0
64 9 :3 0 ba
:7 0 bd bb 0
29ff 0 28 :6 0
9 :3 0 bf :7 0
c2 c0 0 29ff
0 29 :6 0 6a
3a4 0 68 9
:3 0 c4 :7 0 c7
c5 0 29ff 0
2a :6 0 9 :3 0
c9 :7 0 cc ca
0 29ff 0 2b
:6 0 6e 3d8 0
6c 9 :3 0 ce
:7 0 d1 cf 0
29ff 0 2c :6 0
9 :3 0 d3 :7 0
d6 d4 0 29ff
0 2d :6 0 72
40c 0 70 9
:3 0 d8 :7 0 db
d9 0 29ff 0
2e :6 0 9 :3 0
dd :7 0 e0 de
0 29ff 0 2f
:6 0 76 440 0
74 31 :3 0 e2
:7 0 e5 e3 0
29ff 0 30 :6 0
31 :3 0 e7 :7 0
ea e8 0 29ff
0 32 :6 0 35
:2 0 7a 31 :3 0
ec :7 0 ef ed
0 29ff 0 33
:6 0 6 :3 0 35
:2 0 78 f1 f3
:6 0 f6 f4 0
29ff 0 34 :6 0
38 :2 0 7e 6
:3 0 7c f8 fa
:6 0 fd fb 0
29ff 0 36 :6 0
38 :2 0 80 c
:3 0 ff :7 0 103
100 101 29ff 0
37 :6 0 38 :2 0
82 c :3 0 105
:7 0 109 106 107
29ff 0 39 :6 0
38 :2 0 84 c
:3 0 10b :7 0 10f
10c 10d 29ff 0
3a :6 0 88 505
0 86 c :3 0
111 :7 0 115 112
113 29ff 0 3b
:6 0 38 :2 0 8a
31 :3 0 117 :7 0
11a 118 0 29ff
0 3c :6 0 31
:3 0 11c :7 0 11f
11d 0 29ff 0
3d :6 0 38 :2 0
8c c :3 0 121
:7 0 125 122 123
29ff 0 3e :6 0
38 :2 0 8e c
:3 0 127 :7 0 12b
128 129 29ff 0
3f :6 0 38 :2 0
90 c :3 0 12d
:7 0 131 12e 12f
29ff 0 40 :6 0
38 :2 0 92 c
:3 0 133 :7 0 137
134 135 29ff 0
41 :6 0 38 :2 0
94 c :3 0 139
:7 0 13d 13a 13b
29ff 0 42 :6 0
38 :2 0 96 c
:3 0 13f :7 0 143
140 141 29ff 0
43 :6 0 38 :2 0
98 c :3 0 145
:7 0 149 146 147
29ff 0 44 :6 0
38 :2 0 9a c
:3 0 14b :7 0 14f
14c 14d 29ff 0
45 :6 0 38 :2 0
9c c :3 0 151
:7 0 155 152 153
29ff 0 46 :6 0
18 :2 0 9e c
:3 0 157 :7 0 15b
158 159 29ff 0
47 :6 0 18 :2 0
a2 6 :3 0 a0
15d 15f :6 0 162
160 0 29ff 0
48 :6 0 18 :2 0
a6 6 :3 0 a4
164 166 :6 0 169
167 0 29ff 0
49 :6 0 38 :2 0
aa 6 :3 0 a8
16b 16d :6 0 170
16e 0 29ff 0
4a :6 0 38 :2 0
ac c :3 0 172
:7 0 176 173 174
29ff 0 4b :6 0
38 :2 0 ae c
:3 0 178 :7 0 17c
179 17a 29ff 0
4c :6 0 38 :2 0
b0 c :3 0 17e
:7 0 182 17f 180
29ff 0 4d :6 0
38 :2 0 b2 c
:3 0 184 :7 0 188
185 186 29ff 0
4e :6 0 38 :2 0
b4 c :3 0 18a
:7 0 18e 18b 18c
29ff 0 4f :6 0
38 :2 0 b6 c
:3 0 190 :7 0 194
191 192 29ff 0
50 :6 0 38 :2 0
b8 c :3 0 196
:7 0 19a 197 198
29ff 0 51 :6 0
38 :2 0 ba c
:3 0 19c :7 0 1a0
19d 19e 29ff 0
52 :6 0 38 :2 0
bc c :3 0 1a2
:7 0 1a6 1a3 1a4
29ff 0 53 :6 0
38 :2 0 be c
:3 0 1a8 :7 0 1ac
1a9 1aa 29ff 0
54 :6 0 38 :2 0
c0 c :3 0 1ae
:7 0 1b2 1af 1b0
29ff 0 55 :6 0
38 :2 0 c2 c
:3 0 1b4 :7 0 1b8
1b5 1b6 29ff 0
56 :6 0 38 :2 0
c4 c :3 0 1ba
:7 0 1be 1bb 1bc
29ff 0 57 :6 0
38 :2 0 c6 c
:3 0 1c0 :7 0 1c4
1c1 1c2 29ff 0
58 :6 0 38 :2 0
c8 c :3 0 1c6
:7 0 1ca 1c7 1c8
29ff 0 59 :6 0
38 :2 0 ca c
:3 0 1cc :7 0 1d0
1cd 1ce 29ff 0
5a :6 0 38 :2 0
cc c :3 0 1d2
:7 0 1d6 1d3 1d4
29ff 0 5b :6 0
38 :2 0 ce c
:3 0 1d8 :7 0 1dc
1d9 1da 29ff 0
5c :6 0 38 :2 0
d0 c :3 0 1de
:7 0 1e2 1df 1e0
29ff 0 5d :6 0
38 :2 0 d2 c
:3 0 1e4 :7 0 1e8
1e5 1e6 29ff 0
5e :6 0 38 :2 0
d4 c :3 0 1ea
:7 0 1ee 1eb 1ec
29ff 0 5f :6 0
38 :2 0 d6 c
:3 0 1f0 :7 0 1f4
1f1 1f2 29ff 0
60 :6 0 38 :2 0
d8 c :3 0 1f6
:7 0 1fa 1f7 1f8
29ff 0 61 :6 0
38 :2 0 da c
:3 0 1fc :7 0 200
1fd 1fe 29ff 0
62 :6 0 38 :2 0
dc c :3 0 202
:7 0 206 203 204
29ff 0 63 :6 0
38 :2 0 de c
:3 0 208 :7 0 20c
209 20a 29ff 0
64 :6 0 38 :2 0
e0 c :3 0 20e
:7 0 212 20f 210
29ff 0 65 :6 0
38 :2 0 e2 c
:3 0 214 :7 0 218
215 216 29ff 0
66 :6 0 38 :2 0
e4 c :3 0 21a
:7 0 21e 21b 21c
29ff 0 67 :6 0
6a :2 0 e6 c
:3 0 220 :7 0 224
221 222 29ff 0
68 :6 0 35 :2 0
ea 6 :3 0 e8
226 228 :6 0 22b
229 0 29ff 0
69 :6 0 38 :2 0
ee 6 :3 0 ec
22d 22f :6 0 232
230 0 29ff 0
6b :6 0 18 :2 0
f0 c :3 0 234
:7 0 238 235 236
29ff 0 6c :6 0
38 :2 0 f4 6
:3 0 f2 23a 23c
:6 0 23f 23d 0
29ff 0 6d :6 0
38 :2 0 f6 c
:3 0 241 :7 0 245
242 243 29ff 0
6e :6 0 38 :2 0
f8 c :3 0 247
:7 0 24b 248 249
29ff 0 6f :6 0
38 :2 0 fa c
:3 0 24d :7 0 251
24e 24f 29ff 0
70 :6 0 38 :2 0
fc 72 :3 0 253
:7 0 257 254 255
29ff 0 71 :6 0
38 :2 0 fe 72
:3 0 259 :7 0 25d
25a 25b 29ff 0
73 :6 0 38 :2 0
100 72 :3 0 25f
:7 0 263 260 261
29ff 0 74 :6 0
38 :2 0 102 72
:3 0 265 :7 0 269
266 267 29ff 0
75 :6 0 38 :2 0
104 72 :3 0 26b
:7 0 26f 26c 26d
29ff 0 76 :6 0
38 :2 0 106 72
:3 0 271 :7 0 275
272 273 29ff 0
77 :6 0 38 :2 0
108 72 :3 0 277
:7 0 27b 278 279
29ff 0 78 :6 0
7b :2 0 10a 72
:3 0 27d :7 0 281
27e 27f 29ff 0
79 :6 0 110 bb4
0 10e 6 :3 0
10c 283 285 :6 0
288 286 0 29ff
0 7a :6 0 114
be8 0 112 c
:3 0 28a :7 0 28d
28b 0 29ff 0
7c :6 0 c :3 0
28f :7 0 292 290
0 29ff 0 7d
:6 0 7f :3 0 c
:3 0 294 :7 0 297
295 0 29ff 0
7e :6 0 80 :a 0
2 2ae :5 0 299
29c 0 29a :3 0
81 :3 0 81 :3 0
82 :3 0 83 :3 0
81 :3 0 84 :3 0
85 :3 0 86 :3 0
11 :3 0 81 :3 0
30 :3 0 81 :3 0
87 :3 0 84 :3 0
4d :3 0 88 :4 0
89 1 :8 0 2af
299 29c 2b0 0
29ff 116 2b0 2b2
2af 2b1 :6 0 2ae
:7 0 2b0 2bb 2bc
0 118 8b :3 0
8c :2 0 4 2b4
2b5 0 2b6 :7 0
2b9 2b7 0 29ff
0 8a :6 0 2c1
2c2 0 11a 8b
:3 0 8c :2 0 4
2bd :7 0 2c0 2be
0 29ff 0 8d
:6 0 8e :3 0 8f
:3 0 8e :3 0 90
:3 0 2c4 2c5 0
2 :4 0 11c 2c6
2c8 2c3 2ca 2c9
:2 0 91 :3 0 92
:3 0 2cc 2cd 0
93 :4 0 8e :3 0
94 :3 0 2d0 2d1
0 2 :4 0 11e
2d2 2d4 95 :4 0
96 :2 0 97 :3 0
120 2d7 2d9 :3 0
98 :4 0 96 :2 0
99 :4 0 123 2dc
2de :3 0 96 :2 0
3 :3 0 126 2e0
2e2 :3 0 96 :2 0
99 :4 0 129 2e4
2e6 :3 0 96 :2 0
9a :4 0 12c 2e8
2ea :3 0 96 :2 0
99 :4 0 12f 2ec
2ee :3 0 96 :2 0
7 :3 0 132 2f0
2f2 :3 0 96 :2 0
99 :4 0 135 2f4
2f6 :3 0 96 :2 0
9a :4 0 138 2f8
2fa :3 0 96 :2 0
9b :3 0 9c :3 0
99 :4 0 96 :2 0
8 :3 0 13b 300
302 :3 0 96 :2 0
99 :4 0 13e 304
306 :3 0 9d :4 0
141 2fe 309 9e
:4 0 144 2fd 30c
147 2fc 30e :3 0
96 :2 0 9a :4 0
14a 310 312 :3 0
96 :2 0 9b :3 0
9c :3 0 99 :4 0
96 :2 0 a :3 0
14d 318 31a :3 0
96 :2 0 99 :4 0
150 31c 31e :3 0
9d :4 0 153 316
321 9e :4 0 156
315 324 159 314
326 :3 0 96 :2 0
9a :4 0 15c 328
32a :3 0 96 :2 0
9b :3 0 9f :3 0
b :3 0 15f 32e
330 9e :4 0 161
32d 333 164 32c
335 :3 0 96 :2 0
9a :4 0 167 337
339 :3 0 96 :2 0
9b :3 0 9f :3 0
d :3 0 16a 33d
33f 9e :4 0 16c
33c 342 16f 33b
344 :3 0 96 :2 0
9a :4 0 172 346
348 :3 0 96 :2 0
9b :3 0 9f :3 0
e :3 0 175 34c
34e 9e :4 0 177
34b 351 17a 34a
353 :3 0 96 :2 0
9a :4 0 17d 355
357 :3 0 96 :2 0
9b :3 0 9f :3 0
f :3 0 180 35b
35d 9e :4 0 182
35a 360 185 359
362 :3 0 96 :2 0
9a :4 0 188 364
366 :3 0 96 :2 0
99 :4 0 18b 368
36a :3 0 96 :2 0
10 :3 0 18e 36c
36e :3 0 96 :2 0
99 :4 0 191 370
372 :3 0 96 :2 0
9a :4 0 194 374
376 :3 0 96 :2 0
99 :4 0 197 378
37a :3 0 96 :2 0
11 :3 0 19a 37c
37e :3 0 96 :2 0
99 :4 0 19d 380
382 :3 0 96 :2 0
a0 :4 0 1a0 384
386 :3 0 1a3 2ce
388 :2 0 38a 1a8
38b 2cb 38a 0
38c 1aa 0 29fd
8e :3 0 8f :3 0
38d 38e 0 8e
:3 0 a1 :3 0 390
391 0 35 :2 0
2 :4 0 a2 :2 0
a3 :2 0 35 :2 0
1ac 396 398 :3 0
1af 392 39a 38f
39c 39b :2 0 91
:3 0 a4 :3 0 39e
39f 0 93 :4 0
a5 :4 0 96 :2 0
97 :3 0 1b3 3a3
3a5 :3 0 1b6 3a0
3a7 :2 0 3a9 1b9
3aa 39d 3a9 0
3ab 1bb 0 29fd
56 :3 0 38 :2 0
3ac 3ad 0 29fd
23 :3 0 a6 :4 0
3af 3b0 0 29fd
4a :3 0 10 :3 0
3b2 3b3 0 29fd
20 :3 0 7 :3 0
3b5 3b6 0 29fd
21 :3 0 3 :3 0
3b8 3b9 0 29fd
a7 :3 0 a8 :3 0
a7 :3 0 a9 :3 0
a7 :3 0 86 :3 0
a7 :3 0 aa :3 0
a7 :3 0 ab :3 0
a7 :3 0 ac :3 0
a7 :3 0 ad :3 0
a7 :3 0 ae :3 0
a7 :3 0 af :3 0
1f :3 0 41 :3 0
19 :3 0 3f :3 0
42 :3 0 47 :3 0
1a :3 0 24 :3 0
46 :3 0 b0 :3 0
a7 :3 0 a7 :3 0
a8 :3 0 21 :4 0
b1 1 :8 0 3e1
8b :3 0 b2 :3 0
3dc 3dd 0 b3
:3 0 3de 3df 0
3e1 1bd 434 b4
:3 0 8b :3 0 b2
:3 0 3e3 3e4 0
b3 :3 0 3e5 3e6
0 3e8 1c0 3ea
1c2 3e9 3e8 :2 0
432 b5 :3 0 8b
:3 0 b2 :3 0 3ed
3ee 0 b3 :3 0
3ef 3f0 0 42a
8e :3 0 8f :3 0
3f2 3f3 0 8e
:3 0 a1 :3 0 3f5
3f6 0 b6 :2 0
2 :4 0 b7 :2 0
a3 :2 0 35 :2 0
1c4 3fb 3fd :3 0
1c7 3f7 3ff 3f4
401 400 :2 0 91
:3 0 a4 :3 0 403
404 0 93 :4 0
b8 :4 0 96 :2 0
97 :3 0 1cb 408
40a :3 0 96 :2 0
b9 :4 0 1ce 40c
40e :3 0 96 :2 0
ba :4 0 1d1 410
412 :3 0 96 :2 0
b3 :3 0 1d4 414
416 :3 0 96 :2 0
bb :4 0 1d7 418
41a :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
1da 41d 421 1de
41c 423 :3 0 1e1
405 425 :2 0 427
1e4 428 402 427
0 429 1e6 0
42a 1e8 42d :3 0
42d 0 42d 42c
42a 42b :6 0 42f
3 :3 0 1eb 431
1ed 430 42f :2 0
432 1ef :2 0 434
0 434 433 3e1
432 :6 0 29fd 1
:3 0 8b :3 0 b2
:3 0 436 437 0
8b :3 0 bf :2 0
c0 :3 0 439 43b
0 1f4 43a 43d
:3 0 43e :2 0 a8
:3 0 c1 :3 0 ae
:3 0 ad :3 0 ab
:3 0 c2 :3 0 c3
:3 0 c4 :3 0 c5
:3 0 c6 :3 0 c7
:3 0 c8 :3 0 c9
:3 0 ca :3 0 c9
:3 0 ca :3 0 cb
:3 0 cc :3 0 cd
:3 0 ce :3 0 c2
:3 0 cf :3 0 d0
:3 0 d1 :3 0 d2
:3 0 d3 :3 0 bc
:3 0 cd :3 0 d3
:3 0 bc :3 0 ce
:3 0 d4 :3 0 d5
:3 0 d6 :3 0 d7
:3 0 d8 :3 0 d9
:3 0 da :3 0 db
:3 0 dc :3 0 dd
:3 0 de :3 0 df
:3 0 e0 :3 0 1f
:3 0 22 :3 0 24
:3 0 49 :3 0 36
:3 0 34 :3 0 3d
:3 0 4c :3 0 52
:3 0 5d :3 0 5e
:3 0 5b :3 0 4e
:3 0 26 :3 0 50
:3 0 27 :3 0 28
:3 0 4b :3 0 4d
:3 0 53 :3 0 30
:3 0 32 :3 0 39
:3 0 3a :3 0 71
:3 0 74 :3 0 73
:3 0 75 :3 0 76
:3 0 78 :3 0 77
:3 0 79 :3 0 4f
:3 0 48 :3 0 61
:3 0 e1 :3 0 e2
:3 0 21 :4 0 e3
1 :8 0 498 8b
:3 0 b2 :3 0 493
494 0 b3 :3 0
495 496 0 498
1f7 4eb b4 :3 0
8b :3 0 b2 :3 0
49a 49b 0 b3
:3 0 49c 49d 0
49f 1fa 4a1 1fc
4a0 49f :2 0 4e9
b5 :3 0 8b :3 0
b2 :3 0 4a4 4a5
0 b3 :3 0 4a6
4a7 0 4e1 8e
:3 0 8f :3 0 4a9
4aa 0 8e :3 0
a1 :3 0 4ac 4ad
0 b6 :2 0 2
:4 0 e4 :2 0 a3
:2 0 35 :2 0 1fe
4b2 4b4 :3 0 201
4ae 4b6 4ab 4b8
4b7 :2 0 91 :3 0
a4 :3 0 4ba 4bb
0 93 :4 0 e5
:4 0 96 :2 0 97
:3 0 205 4bf 4c1
:3 0 96 :2 0 b9
:4 0 208 4c3 4c5
:3 0 96 :2 0 ba
:4 0 20b 4c7 4c9
:3 0 96 :2 0 b3
:3 0 20e 4cb 4cd
:3 0 96 :2 0 bb
:4 0 211 4cf 4d1
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 214
4d4 4d8 218 4d3
4da :3 0 21b 4bc
4dc :2 0 4de 21e
4df 4b9 4de 0
4e0 220 0 4e1
222 4e4 :3 0 4e4
0 4e4 4e3 4e1
4e2 :6 0 4e6 5
:3 0 225 4e8 227
4e7 4e6 :2 0 4e9
229 :2 0 4eb 0
4eb 4ea 498 4e9
:6 0 2988 1 :3 0
8b :3 0 b2 :3 0
4ed 4ee 0 8b
:3 0 bf :2 0 c0
:3 0 4f0 4f2 0
22e 4f1 4f4 :3 0
4f5 :2 0 ae :3 0
e6 :3 0 e7 :3 0
e8 :3 0 e9 :3 0
ea :3 0 eb :3 0
ec :3 0 ed :3 0
ee :3 0 cc :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
9b :3 0 f3 :3 0
f4 :3 0 24 :3 0
56 :3 0 57 :3 0
27 :3 0 28 :3 0
5a :3 0 66 :3 0
68 :3 0 59 :3 0
58 :3 0 50 :3 0
4b :3 0 4f :3 0
60 :3 0 2b :3 0
f5 :3 0 86 :3 0
21 :4 0 f6 1
:8 0 521 8b :3 0
b2 :3 0 51c 51d
0 b3 :3 0 51e
51f 0 521 231
574 b4 :3 0 8b
:3 0 b2 :3 0 523
524 0 b3 :3 0
525 526 0 528
234 52a 236 529
528 :2 0 572 b5
:3 0 8b :3 0 b2
:3 0 52d 52e 0
b3 :3 0 52f 530
0 56a 8e :3 0
8f :3 0 532 533
0 8e :3 0 a1
:3 0 535 536 0
b6 :2 0 2 :4 0
f7 :2 0 a3 :2 0
35 :2 0 238 53b
53d :3 0 23b 537
53f 534 541 540
:2 0 91 :3 0 a4
:3 0 543 544 0
93 :4 0 f8 :4 0
96 :2 0 97 :3 0
23f 548 54a :3 0
96 :2 0 b9 :4 0
242 54c 54e :3 0
96 :2 0 ba :4 0
245 550 552 :3 0
96 :2 0 b3 :3 0
248 554 556 :3 0
96 :2 0 bb :4 0
24b 558 55a :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 24e 55d
561 252 55c 563
:3 0 255 545 565
:2 0 567 258 568
542 567 0 569
25a 0 56a 25c
56d :3 0 56d 0
56d 56c 56a 56b
:6 0 56f 7 :3 0
25f 571 261 570
56f :2 0 572 263
:2 0 574 0 574
573 521 572 :6 0
10b5 1 :3 0 8b
:3 0 b2 :3 0 576
577 0 8b :3 0
bf :2 0 c0 :3 0
579 57b 0 268
57a 57d :3 0 57e
:2 0 11 :3 0 21
:3 0 580 581 0
5a7 8e :3 0 8f
:3 0 583 584 0
8e :3 0 a1 :3 0
586 587 0 35
:2 0 2 :4 0 f9
:2 0 a3 :2 0 35
:2 0 26b 58c 58e
:3 0 26e 588 590
585 592 591 :2 0
91 :3 0 a4 :3 0
594 595 0 93
:4 0 fa :4 0 96
:2 0 97 :3 0 272
599 59b :3 0 275
596 59d :2 0 59f
278 5a0 593 59f
0 5a1 27a 0
5a7 12 :3 0 fb
:3 0 fc :3 0 5a3
5a4 0 5a5 :2 0
5a7 27c 5a8 57f
5a7 0 5a9 280
0 10b5 fd :3 0
9b :3 0 68 :3 0
38 :2 0 282 5ab
5ae fb :3 0 fe
:3 0 5b0 5b1 0
285 5aa 5b3 5b4
:2 0 fb :3 0 bf
:2 0 fe :3 0 5b6
5b8 0 28a 5b7
5ba :3 0 11 :3 0
21 :3 0 5bc 5bd
0 5e3 8e :3 0
8f :3 0 5bf 5c0
0 8e :3 0 a1
:3 0 5c2 5c3 0
35 :2 0 2 :4 0
ff :2 0 a3 :2 0
35 :2 0 28d 5c8
5ca :3 0 290 5c4
5cc 5c1 5ce 5cd
:2 0 91 :3 0 a4
:3 0 5d0 5d1 0
93 :4 0 100 :4 0
96 :2 0 97 :3 0
294 5d5 5d7 :3 0
297 5d2 5d9 :2 0
5db 29a 5dc 5cf
5db 0 5dd 29c
0 5e3 12 :3 0
fb :3 0 101 :3 0
5df 5e0 0 5e1
:2 0 5e3 29e 5e4
5bb 5e3 0 5e5
2a2 0 10b5 29
:3 0 8 :3 0 5e6
5e7 0 10b5 2a
:3 0 a :3 0 5e9
5ea 0 10b5 102
:3 0 103 :3 0 5ec
5ed 0 29 :3 0
2a :3 0 104 :2 0
2a4 5ee 5f2 105
:2 0 38 :2 0 2aa
5f4 5f6 :3 0 5f7
:2 0 102 :3 0 103
:3 0 5f9 5fa 0
2a :3 0 28 :3 0
104 :2 0 2ad 5fb
5ff 106 :2 0 38
:2 0 2b3 601 603
:3 0 604 :2 0 5f8
606 605 :2 0 11
:3 0 21 :3 0 608
609 0 62f 8e
:3 0 8f :3 0 60b
60c 0 8e :3 0
a1 :3 0 60e 60f
0 35 :2 0 2
:4 0 107 :2 0 a3
:2 0 35 :2 0 2b6
614 616 :3 0 2b9
610 618 60d 61a
619 :2 0 91 :3 0
a4 :3 0 61c 61d
0 93 :4 0 108
:4 0 96 :2 0 97
:3 0 2bd 621 623
:3 0 2c0 61e 625
:2 0 627 2c3 628
61b 627 0 629
2c5 0 62f 12
:3 0 fb :3 0 109
:3 0 62b 62c 0
62d :2 0 62f 2c7
630 607 62f 0
631 2cb 0 10b5
2b :3 0 10a :2 0
2cd 633 634 :3 0
635 :2 0 636 :2 0
9b :3 0 4b :3 0
38 :2 0 2cf 638
63b 10b :2 0 9b
:3 0 50 :3 0 38
:2 0 2d2 63e 641
2d5 63d 643 :3 0
644 :2 0 9b :3 0
106 :2 0 60 :3 0
38 :2 0 2d8 646
64a 2dd 647 64c
:3 0 64d :2 0 637
64f 64e :2 0 11
:3 0 21 :3 0 651
652 0 678 8e
:3 0 8f :3 0 654
655 0 8e :3 0
a1 :3 0 657 658
0 35 :2 0 2
:4 0 10c :2 0 a3
:2 0 35 :2 0 2e0
65d 65f :3 0 2e3
659 661 656 663
662 :2 0 91 :3 0
a4 :3 0 665 666
0 93 :4 0 10d
:4 0 96 :2 0 97
:3 0 2e7 66a 66c
:3 0 2ea 667 66e
:2 0 670 2ed 671
664 670 0 672
2ef 0 678 12
:3 0 fb :3 0 10e
:3 0 674 675 0
676 :2 0 678 2f1
679 650 678 0
67a 2f5 0 10b5
102 :3 0 103 :3 0
67b 67c 0 29
:3 0 27 :3 0 104
:2 0 2f7 67d 681
106 :2 0 38 :2 0
2fd 683 685 :3 0
686 :2 0 102 :3 0
103 :3 0 688 689
0 2a :3 0 28
:3 0 104 :2 0 300
68a 68e 106 :2 0
38 :2 0 306 690
692 :3 0 693 :2 0
687 695 694 :2 0
9b :3 0 59 :3 0
38 :2 0 309 697
69a bf :2 0 38
:2 0 30e 69c 69e
:3 0 102 :3 0 103
:3 0 6a0 6a1 0
29 :3 0 27 :3 0
104 :2 0 311 6a2
6a6 106 :2 0 38
:2 0 317 6a8 6aa
:3 0 102 :3 0 10f
:3 0 81 :3 0 102
:3 0 110 :3 0 111
:3 0 112 :3 0 113
:3 0 29 :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 29
:4 0 114 1 :8 0
6c2 8b :3 0 b2
:3 0 6bd 6be 0
b3 :3 0 6bf 6c0
0 6c2 31a 715
b4 :3 0 8b :3 0
b2 :3 0 6c4 6c5
0 b3 :3 0 6c6
6c7 0 6c9 31d
6cb 31f 6ca 6c9
:2 0 713 b5 :3 0
8b :3 0 b2 :3 0
6ce 6cf 0 b3
:3 0 6d0 6d1 0
70b 8e :3 0 8f
:3 0 6d3 6d4 0
8e :3 0 a1 :3 0
6d6 6d7 0 b6
:2 0 2 :4 0 115
:2 0 a3 :2 0 35
:2 0 321 6dc 6de
:3 0 324 6d8 6e0
6d5 6e2 6e1 :2 0
91 :3 0 a4 :3 0
6e4 6e5 0 93
:4 0 116 :4 0 96
:2 0 97 :3 0 328
6e9 6eb :3 0 96
:2 0 b9 :4 0 32b
6ed 6ef :3 0 96
:2 0 ba :4 0 32e
6f1 6f3 :3 0 96
:2 0 b3 :3 0 331
6f5 6f7 :3 0 96
:2 0 bb :4 0 334
6f9 6fb :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 337 6fe 702
33b 6fd 704 :3 0
33e 6e6 706 :2 0
708 341 709 6e3
708 0 70a 343
0 70b 345 70e
:3 0 70e 0 70e
70d 70b 70c :6 0
710 9 :3 0 348
712 34a 711 710
:2 0 713 34c :2 0
715 0 715 714
6c2 713 :6 0 79a
1 :3 0 8b :3 0
b2 :3 0 717 718
0 8b :3 0 bf
:2 0 c0 :3 0 71a
71c 0 351 71b
71e :3 0 71f :2 0
102 :3 0 10f :3 0
d3 :3 0 bc :3 0
29 :3 0 102 :3 0
110 :3 0 29 :3 0
117 :4 0 118 1
:8 0 730 8b :3 0
b2 :3 0 72b 72c
0 b3 :3 0 72d
72e 0 730 354
783 b4 :3 0 8b
:3 0 b2 :3 0 732
733 0 b3 :3 0
734 735 0 737
357 739 359 738
737 :2 0 781 b5
:3 0 8b :3 0 b2
:3 0 73c 73d 0
b3 :3 0 73e 73f
0 779 8e :3 0
8f :3 0 741 742
0 8e :3 0 a1
:3 0 744 745 0
b6 :2 0 2 :4 0
119 :2 0 a3 :2 0
35 :2 0 35b 74a
74c :3 0 35e 746
74e 743 750 74f
:2 0 91 :3 0 a4
:3 0 752 753 0
93 :4 0 11a :4 0
96 :2 0 97 :3 0
362 757 759 :3 0
96 :2 0 b9 :4 0
365 75b 75d :3 0
96 :2 0 ba :4 0
368 75f 761 :3 0
96 :2 0 b3 :3 0
36b 763 765 :3 0
96 :2 0 bb :4 0
36e 767 769 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 371 76c
770 375 76b 772
:3 0 378 754 774
:2 0 776 37b 777
751 776 0 778
37d 0 779 37f
77c :3 0 77c 0
77c 77b 779 77a
:6 0 77e b :3 0
382 780 384 77f
77e :2 0 781 386
:2 0 783 0 783
782 730 781 :6 0
785 1 :3 0 389
786 720 785 0
787 38b 0 79a
102 :3 0 103 :3 0
788 789 0 29
:3 0 2a :3 0 104
:2 0 38d 78a 78e
105 :2 0 38 :2 0
393 790 792 :3 0
2a :4 0 794 795
0 797 396 798
793 797 0 799
398 0 79a 39a
87b 102 :3 0 10f
:3 0 81 :3 0 102
:3 0 110 :3 0 111
:3 0 11b :3 0 113
:3 0 2a :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 2a
:4 0 11c 1 :8 0
7b1 8b :3 0 b2
:3 0 7ac 7ad 0
b3 :3 0 7ae 7af
0 7b1 39e 804
b4 :3 0 8b :3 0
b2 :3 0 7b3 7b4
0 b3 :3 0 7b5
7b6 0 7b8 3a1
7ba 3a3 7b9 7b8
:2 0 802 b5 :3 0
8b :3 0 b2 :3 0
7bd 7be 0 b3
:3 0 7bf 7c0 0
7fa 8e :3 0 8f
:3 0 7c2 7c3 0
8e :3 0 a1 :3 0
7c5 7c6 0 b6
:2 0 2 :4 0 11d
:2 0 a3 :2 0 35
:2 0 3a5 7cb 7cd
:3 0 3a8 7c7 7cf
7c4 7d1 7d0 :2 0
91 :3 0 a4 :3 0
7d3 7d4 0 93
:4 0 11e :4 0 96
:2 0 97 :3 0 3ac
7d8 7da :3 0 96
:2 0 b9 :4 0 3af
7dc 7de :3 0 96
:2 0 ba :4 0 3b2
7e0 7e2 :3 0 96
:2 0 b3 :3 0 3b5
7e4 7e6 :3 0 96
:2 0 bb :4 0 3b8
7e8 7ea :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 3bb 7ed 7f1
3bf 7ec 7f3 :3 0
3c2 7d5 7f5 :2 0
7f7 3c5 7f8 7d2
7f7 0 7f9 3c7
0 7fa 3c9 7fd
:3 0 7fd 0 7fd
7fc 7fa 7fb :6 0
7ff d :3 0 3cc
801 3ce 800 7ff
:2 0 802 3d0 :2 0
804 0 804 803
7b1 802 :6 0 87a
1 :3 0 8b :3 0
b2 :3 0 806 807
0 8b :3 0 bf
:2 0 c0 :3 0 809
80b 0 3d5 80a
80d :3 0 80e :2 0
102 :3 0 10f :3 0
d3 :3 0 bc :3 0
2a :3 0 102 :3 0
110 :3 0 2a :3 0
117 :4 0 11f 1
:8 0 81f 8b :3 0
b2 :3 0 81a 81b
0 b3 :3 0 81c
81d 0 81f 3d8
872 b4 :3 0 8b
:3 0 b2 :3 0 821
822 0 b3 :3 0
823 824 0 826
3db 828 3dd 827
826 :2 0 870 b5
:3 0 8b :3 0 b2
:3 0 82b 82c 0
b3 :3 0 82d 82e
0 868 8e :3 0
8f :3 0 830 831
0 8e :3 0 a1
:3 0 833 834 0
b6 :2 0 2 :4 0
120 :2 0 a3 :2 0
35 :2 0 3df 839
83b :3 0 3e2 835
83d 832 83f 83e
:2 0 91 :3 0 a4
:3 0 841 842 0
93 :4 0 121 :4 0
96 :2 0 97 :3 0
3e6 846 848 :3 0
96 :2 0 b9 :4 0
3e9 84a 84c :3 0
96 :2 0 ba :4 0
3ec 84e 850 :3 0
96 :2 0 b3 :3 0
3ef 852 854 :3 0
96 :2 0 bb :4 0
3f2 856 858 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 3f5 85b
85f 3f9 85a 861
:3 0 3fc 843 863
:2 0 865 3ff 866
840 865 0 867
401 0 868 403
86b :3 0 86b 0
86b 86a 868 869
:6 0 86d f :3 0
406 86f 408 86e
86d :2 0 870 40a
:2 0 872 0 872
871 81f 870 :6 0
874 1 :3 0 40d
875 80f 874 0
876 40f 0 87a
5a :3 0 38 :2 0
877 878 0 87a
411 87c 6ab 79a
0 87d 0 87a
0 87d 415 0
989 9b :3 0 58
:3 0 38 :2 0 418
87e 881 fb :3 0
bf :2 0 122 :3 0
883 885 0 41d
884 887 :3 0 f5
:3 0 123 :3 0 29
:3 0 124 :3 0 2a
:3 0 125 :3 0 5a
:3 0 86 :3 0 21
:4 0 126 1 :8 0
8a8 127 :4 0 893
:3 0 128 :3 0 bf
:2 0 422 896 897
:3 0 8b :3 0 b2
:3 0 899 89a 0
38 :2 0 89b 89c
0 89e 425 8a5
8b :3 0 b2 :3 0
89f 8a0 0 129
:2 0 8a1 8a2 0
8a4 427 8a6 898
89e 0 8a7 0
8a4 0 8a7 429
0 8a8 42c 8fb
b4 :3 0 8b :3 0
b2 :3 0 8aa 8ab
0 b3 :3 0 8ac
8ad 0 8af 42f
8b1 431 8b0 8af
:2 0 8f9 b5 :3 0
8b :3 0 b2 :3 0
8b4 8b5 0 b3
:3 0 8b6 8b7 0
8f1 8e :3 0 8f
:3 0 8b9 8ba 0
8e :3 0 a1 :3 0
8bc 8bd 0 b6
:2 0 2 :4 0 12a
:2 0 a3 :2 0 35
:2 0 433 8c2 8c4
:3 0 436 8be 8c6
8bb 8c8 8c7 :2 0
91 :3 0 a4 :3 0
8ca 8cb 0 93
:4 0 12b :4 0 96
:2 0 97 :3 0 43a
8cf 8d1 :3 0 96
:2 0 b9 :4 0 43d
8d3 8d5 :3 0 96
:2 0 ba :4 0 440
8d7 8d9 :3 0 96
:2 0 b3 :3 0 443
8db 8dd :3 0 96
:2 0 bb :4 0 446
8df 8e1 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 449 8e4 8e8
44d 8e3 8ea :3 0
450 8cc 8ec :2 0
8ee 453 8ef 8c9
8ee 0 8f0 455
0 8f1 457 8f4
:3 0 8f4 0 8f4
8f3 8f1 8f2 :6 0
8f6 11 :3 0 45a
8f8 45c 8f7 8f6
:2 0 8f9 45e :2 0
8fb 0 8fb 8fa
8a8 8f9 :6 0 8fd
1 :3 0 461 973
f5 :3 0 12c :3 0
29 :3 0 12d :3 0
2a :3 0 12e :3 0
5a :3 0 86 :3 0
21 :4 0 12f 1
:8 0 91d 127 :4 0
908 :3 0 128 :3 0
bf :2 0 465 90b
90c :3 0 8b :3 0
b2 :3 0 90e 90f
0 38 :2 0 910
911 0 913 468
91a 8b :3 0 b2
:3 0 914 915 0
129 :2 0 916 917
0 919 46a 91b
90d 913 0 91c
0 919 0 91c
46c 0 91d 46f
970 b4 :3 0 8b
:3 0 b2 :3 0 91f
920 0 b3 :3 0
921 922 0 924
472 926 474 925
924 :2 0 96e b5
:3 0 8b :3 0 b2
:3 0 929 92a 0
b3 :3 0 92b 92c
0 966 8e :3 0
8f :3 0 92e 92f
0 8e :3 0 a1
:3 0 931 932 0
b6 :2 0 2 :4 0
130 :2 0 a3 :2 0
35 :2 0 476 937
939 :3 0 479 933
93b 930 93d 93c
:2 0 91 :3 0 a4
:3 0 93f 940 0
93 :4 0 131 :4 0
96 :2 0 97 :3 0
47d 944 946 :3 0
96 :2 0 b9 :4 0
480 948 94a :3 0
96 :2 0 ba :4 0
483 94c 94e :3 0
96 :2 0 b3 :3 0
486 950 952 :3 0
96 :2 0 bb :4 0
489 954 956 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 48c 959
95d 490 958 95f
:3 0 493 941 961
:2 0 963 496 964
93e 963 0 965
498 0 966 49a
969 :3 0 969 0
969 968 966 967
:6 0 96b 13 :3 0
49d 96d 49f 96c
96b :2 0 96e 4a1
:2 0 970 0 970
96f 91d 96e :6 0
972 1 :3 0 4a4
974 888 8fd 0
975 0 972 0
975 4a6 0 989
8b :3 0 b2 :3 0
976 977 0 8b
:3 0 bf :2 0 132
:3 0 979 97b 0
4ab 97a 97d :3 0
97e :2 0 70 :3 0
133 :3 0 24 :3 0
4ae 981 983 980
984 0 986 4b0
987 97f 986 0
988 4b2 0 989
4b4 e94 7c :3 0
38 :2 0 98a 98b
0 e93 64 :3 0
38 :2 0 98d 98e
0 e93 9b :3 0
56 :3 0 38 :2 0
4b8 990 993 fb
:3 0 bf :2 0 134
:3 0 995 997 0
4bd 996 999 :3 0
9b :3 0 56 :3 0
38 :2 0 4c0 99b
99e fb :3 0 bf
:2 0 135 :3 0 9a0
9a2 0 4c5 9a1
9a4 :3 0 99a 9a6
9a5 :2 0 136 :3 0
81 :3 0 64 :3 0
85 :3 0 86 :3 0
24 :3 0 81 :3 0
d3 :3 0 bc :3 0
27 :3 0 d3 :3 0
bc :3 0 28 :4 0
137 1 :8 0 9bb
8b :3 0 b2 :3 0
9b6 9b7 0 b3
:3 0 9b8 9b9 0
9bb 4c8 a0e b4
:3 0 8b :3 0 b2
:3 0 9bd 9be 0
b3 :3 0 9bf 9c0
0 9c2 4cb 9c4
4cd 9c3 9c2 :2 0
a0c b5 :3 0 8b
:3 0 b2 :3 0 9c7
9c8 0 b3 :3 0
9c9 9ca 0 a04
8e :3 0 8f :3 0
9cc 9cd 0 8e
:3 0 a1 :3 0 9cf
9d0 0 b6 :2 0
2 :4 0 138 :2 0
a3 :2 0 35 :2 0
4cf 9d5 9d7 :3 0
4d2 9d1 9d9 9ce
9db 9da :2 0 91
:3 0 a4 :3 0 9dd
9de 0 93 :4 0
139 :4 0 96 :2 0
97 :3 0 4d6 9e2
9e4 :3 0 96 :2 0
b9 :4 0 4d9 9e6
9e8 :3 0 96 :2 0
ba :4 0 4dc 9ea
9ec :3 0 96 :2 0
b3 :3 0 4df 9ee
9f0 :3 0 96 :2 0
bb :4 0 4e2 9f2
9f4 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
4e5 9f7 9fb 4e9
9f6 9fd :3 0 4ec
9df 9ff :2 0 a01
4ef a02 9dc a01
0 a03 4f1 0
a04 4f3 a07 :3 0
a07 0 a07 a06
a04 a05 :6 0 a09
15 :3 0 4f6 a0b
4f8 a0a a09 :2 0
a0c 4fa :2 0 a0e
0 a0e a0d 9bb
a0c :6 0 a10 1
:3 0 4fd a11 9a7
a10 0 a12 4ff
0 e93 102 :3 0
103 :3 0 a13 a14
0 29 :3 0 27
:3 0 104 :2 0 501
a15 a19 106 :2 0
38 :2 0 507 a1b
a1d :3 0 102 :3 0
10f :3 0 81 :3 0
102 :3 0 110 :3 0
111 :3 0 112 :3 0
113 :3 0 29 :3 0
85 :3 0 86 :3 0
24 :3 0 81 :3 0
d3 :3 0 bc :3 0
29 :4 0 114 1
:8 0 a35 8b :3 0
b2 :3 0 a30 a31
0 b3 :3 0 a32
a33 0 a35 50a
a88 b4 :3 0 8b
:3 0 b2 :3 0 a37
a38 0 b3 :3 0
a39 a3a 0 a3c
50d a3e 50f a3d
a3c :2 0 a86 b5
:3 0 8b :3 0 b2
:3 0 a41 a42 0
b3 :3 0 a43 a44
0 a7e 8e :3 0
8f :3 0 a46 a47
0 8e :3 0 a1
:3 0 a49 a4a 0
b6 :2 0 2 :4 0
13a :2 0 a3 :2 0
35 :2 0 511 a4f
a51 :3 0 514 a4b
a53 a48 a55 a54
:2 0 91 :3 0 a4
:3 0 a57 a58 0
93 :4 0 13b :4 0
96 :2 0 97 :3 0
518 a5c a5e :3 0
96 :2 0 b9 :4 0
51b a60 a62 :3 0
96 :2 0 ba :4 0
51e a64 a66 :3 0
96 :2 0 b3 :3 0
521 a68 a6a :3 0
96 :2 0 bb :4 0
524 a6c a6e :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 527 a71
a75 52b a70 a77
:3 0 52e a59 a79
:2 0 a7b 531 a7c
a56 a7b 0 a7d
533 0 a7e 535
a81 :3 0 a81 0
a81 a80 a7e a7f
:6 0 a83 17 :3 0
538 a85 53a a84
a83 :2 0 a86 53c
:2 0 a88 0 a88
a87 a35 a86 :6 0
b27 1 :3 0 8b
:3 0 b2 :3 0 a8a
a8b 0 8b :3 0
bf :2 0 c0 :3 0
a8d a8f 0 541
a8e a91 :3 0 a92
:2 0 102 :3 0 10f
:3 0 d3 :3 0 bc
:3 0 29 :3 0 102
:3 0 110 :3 0 29
:3 0 117 :4 0 118
1 :8 0 aa3 8b
:3 0 b2 :3 0 a9e
a9f 0 b3 :3 0
aa0 aa1 0 aa3
544 af6 b4 :3 0
8b :3 0 b2 :3 0
aa5 aa6 0 b3
:3 0 aa7 aa8 0
aaa 547 aac 549
aab aaa :2 0 af4
b5 :3 0 8b :3 0
b2 :3 0 aaf ab0
0 b3 :3 0 ab1
ab2 0 aec 8e
:3 0 8f :3 0 ab4
ab5 0 8e :3 0
a1 :3 0 ab7 ab8
0 b6 :2 0 2
:4 0 13c :2 0 a3
:2 0 35 :2 0 54b
abd abf :3 0 54e
ab9 ac1 ab6 ac3
ac2 :2 0 91 :3 0
a4 :3 0 ac5 ac6
0 93 :4 0 13d
:4 0 96 :2 0 97
:3 0 552 aca acc
:3 0 96 :2 0 b9
:4 0 555 ace ad0
:3 0 96 :2 0 ba
:4 0 558 ad2 ad4
:3 0 96 :2 0 b3
:3 0 55b ad6 ad8
:3 0 96 :2 0 bb
:4 0 55e ada adc
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 561
adf ae3 565 ade
ae5 :3 0 568 ac7
ae7 :2 0 ae9 56b
aea ac4 ae9 0
aeb 56d 0 aec
56f aef :3 0 aef
0 aef aee aec
aed :6 0 af1 19
:3 0 572 af3 574
af2 af1 :2 0 af4
576 :2 0 af6 0
af6 af5 aa3 af4
:6 0 b03 1 :3 0
64 :3 0 9b :3 0
64 :3 0 38 :2 0
579 af9 afc 10b
:2 0 35 :2 0 57c
afe b00 :3 0 af8
b01 0 b03 57f
b04 a93 b03 0
b05 582 0 b27
9b :3 0 56 :3 0
38 :2 0 584 b06
b09 fb :3 0 bf
:2 0 134 :3 0 b0b
b0d 0 589 b0c
b0f :3 0 9b :3 0
56 :3 0 38 :2 0
58c b11 b14 fb
:3 0 bf :2 0 135
:3 0 b16 b18 0
591 b17 b1a :3 0
b10 b1c b1b :2 0
2a :3 0 a6 :4 0
b1e b1f 0 b24
7c :3 0 35 :2 0
b21 b22 0 b24
594 b25 b1d b24
0 b26 597 0
b27 599 d51 9b
:3 0 50 :3 0 38
:2 0 59d b28 b2b
105 :2 0 38 :2 0
5a2 b2d b2f :3 0
70 :3 0 38 :2 0
b31 b32 0 c44
136 :3 0 70 :3 0
117 :3 0 13e :3 0
ae :3 0 24 :3 0
df :3 0 21 :3 0
13f :3 0 81 :3 0
d3 :3 0 bc :3 0
2a :4 0 140 1
:8 0 b47 8b :3 0
b2 :3 0 b42 b43
0 b3 :3 0 b44
b45 0 b47 5a5
b9a b4 :3 0 8b
:3 0 b2 :3 0 b49
b4a 0 b3 :3 0
b4b b4c 0 b4e
5a8 b50 5aa b4f
b4e :2 0 b98 b5
:3 0 8b :3 0 b2
:3 0 b53 b54 0
b3 :3 0 b55 b56
0 b90 8e :3 0
8f :3 0 b58 b59
0 8e :3 0 a1
:3 0 b5b b5c 0
b6 :2 0 2 :4 0
141 :2 0 a3 :2 0
35 :2 0 5ac b61
b63 :3 0 5af b5d
b65 b5a b67 b66
:2 0 91 :3 0 a4
:3 0 b69 b6a 0
93 :4 0 142 :4 0
96 :2 0 97 :3 0
5b3 b6e b70 :3 0
96 :2 0 b9 :4 0
5b6 b72 b74 :3 0
96 :2 0 ba :4 0
5b9 b76 b78 :3 0
96 :2 0 b3 :3 0
5bc b7a b7c :3 0
96 :2 0 bb :4 0
5bf b7e b80 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 5c2 b83
b87 5c6 b82 b89
:3 0 5c9 b6b b8b
:2 0 b8d 5cc b8e
b68 b8d 0 b8f
5ce 0 b90 5d0
b93 :3 0 b93 0
b93 b92 b90 b91
:6 0 b95 1b :3 0
5d3 b97 5d5 b96
b95 :2 0 b98 5d7
:2 0 b9a 0 b9a
b99 b47 b98 :6 0
c44 1 :3 0 9b
:3 0 70 :3 0 38
:2 0 5da b9c b9f
bf :2 0 38 :2 0
5df ba1 ba3 :3 0
136 :3 0 70 :3 0
117 :3 0 e1 :3 0
ae :3 0 24 :3 0
df :3 0 21 :3 0
d3 :3 0 bc :3 0
e8 :3 0 d3 :3 0
bc :3 0 2a :4 0
143 1 :8 0 bb9
8b :3 0 b2 :3 0
bb4 bb5 0 b3
:3 0 bb6 bb7 0
bb9 5e2 c0c b4
:3 0 8b :3 0 b2
:3 0 bbb bbc 0
b3 :3 0 bbd bbe
0 bc0 5e5 bc2
5e7 bc1 bc0 :2 0
c0a b5 :3 0 8b
:3 0 b2 :3 0 bc5
bc6 0 b3 :3 0
bc7 bc8 0 c02
8e :3 0 8f :3 0
bca bcb 0 8e
:3 0 a1 :3 0 bcd
bce 0 b6 :2 0
2 :4 0 144 :2 0
a3 :2 0 35 :2 0
5e9 bd3 bd5 :3 0
5ec bcf bd7 bcc
bd9 bd8 :2 0 91
:3 0 a4 :3 0 bdb
bdc 0 93 :4 0
145 :4 0 96 :2 0
97 :3 0 5f0 be0
be2 :3 0 96 :2 0
b9 :4 0 5f3 be4
be6 :3 0 96 :2 0
ba :4 0 5f6 be8
bea :3 0 96 :2 0
b3 :3 0 5f9 bec
bee :3 0 96 :2 0
bb :4 0 5fc bf0
bf2 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
5ff bf5 bf9 603
bf4 bfb :3 0 606
bdd bfd :2 0 bff
609 c00 bda bff
0 c01 60b 0
c02 60d c05 :3 0
c05 0 c05 c04
c02 c03 :6 0 c07
1d :3 0 610 c09
612 c08 c07 :2 0
c0a 614 :2 0 c0c
0 c0c c0b bb9
c0a :6 0 c0e 1
:3 0 617 c0f ba4
c0e 0 c10 619
0 c44 9b :3 0
70 :3 0 38 :2 0
61b c11 c14 105
:2 0 38 :2 0 620
c16 c18 :3 0 11
:3 0 21 :3 0 c1a
c1b 0 c41 8e
:3 0 8f :3 0 c1d
c1e 0 8e :3 0
a1 :3 0 c20 c21
0 35 :2 0 2
:4 0 146 :2 0 a3
:2 0 35 :2 0 623
c26 c28 :3 0 626
c22 c2a c1f c2c
c2b :2 0 91 :3 0
a4 :3 0 c2e c2f
0 93 :4 0 147
:4 0 96 :2 0 97
:3 0 62a c33 c35
:3 0 62d c30 c37
:2 0 c39 630 c3a
c2d c39 0 c3b
632 0 c41 12
:3 0 fb :3 0 148
:3 0 c3d c3e 0
c3f :2 0 c41 634
c42 c19 c41 0
c43 638 0 c44
63a c45 b30 c44
0 c46 63f 0
d50 102 :3 0 10f
:3 0 81 :3 0 102
:3 0 110 :3 0 111
:3 0 11b :3 0 113
:3 0 2a :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 2a
:4 0 11c 1 :8 0
c5d 8b :3 0 b2
:3 0 c58 c59 0
b3 :3 0 c5a c5b
0 c5d 641 cb0
b4 :3 0 8b :3 0
b2 :3 0 c5f c60
0 b3 :3 0 c61
c62 0 c64 644
c66 646 c65 c64
:2 0 cae b5 :3 0
8b :3 0 b2 :3 0
c69 c6a 0 b3
:3 0 c6b c6c 0
ca6 8e :3 0 8f
:3 0 c6e c6f 0
8e :3 0 a1 :3 0
c71 c72 0 b6
:2 0 2 :4 0 149
:2 0 a3 :2 0 35
:2 0 648 c77 c79
:3 0 64b c73 c7b
c70 c7d c7c :2 0
91 :3 0 a4 :3 0
c7f c80 0 93
:4 0 14a :4 0 96
:2 0 97 :3 0 64f
c84 c86 :3 0 96
:2 0 b9 :4 0 652
c88 c8a :3 0 96
:2 0 ba :4 0 655
c8c c8e :3 0 96
:2 0 b3 :3 0 658
c90 c92 :3 0 96
:2 0 bb :4 0 65b
c94 c96 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 65e c99 c9d
662 c98 c9f :3 0
665 c81 ca1 :2 0
ca3 668 ca4 c7e
ca3 0 ca5 66a
0 ca6 66c ca9
:3 0 ca9 0 ca9
ca8 ca6 ca7 :6 0
cab 1f :3 0 66f
cad 671 cac cab
:2 0 cae 673 :2 0
cb0 0 cb0 caf
c5d cae :6 0 d50
1 :3 0 8b :3 0
b2 :3 0 cb2 cb3
0 8b :3 0 bf
:2 0 c0 :3 0 cb5
cb7 0 678 cb6
cb9 :3 0 cba :2 0
102 :3 0 10f :3 0
d3 :3 0 bc :3 0
2a :3 0 102 :3 0
110 :3 0 2a :3 0
117 :4 0 11f 1
:8 0 ccb 8b :3 0
b2 :3 0 cc6 cc7
0 b3 :3 0 cc8
cc9 0 ccb 67b
d1e b4 :3 0 8b
:3 0 b2 :3 0 ccd
cce 0 b3 :3 0
ccf cd0 0 cd2
67e cd4 680 cd3
cd2 :2 0 d1c b5
:3 0 8b :3 0 b2
:3 0 cd7 cd8 0
b3 :3 0 cd9 cda
0 d14 8e :3 0
8f :3 0 cdc cdd
0 8e :3 0 a1
:3 0 cdf ce0 0
b6 :2 0 2 :4 0
14b :2 0 a3 :2 0
35 :2 0 682 ce5
ce7 :3 0 685 ce1
ce9 cde ceb cea
:2 0 91 :3 0 a4
:3 0 ced cee 0
93 :4 0 14c :4 0
96 :2 0 97 :3 0
689 cf2 cf4 :3 0
96 :2 0 b9 :4 0
68c cf6 cf8 :3 0
96 :2 0 ba :4 0
68f cfa cfc :3 0
96 :2 0 b3 :3 0
692 cfe d00 :3 0
96 :2 0 bb :4 0
695 d02 d04 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 698 d07
d0b 69c d06 d0d
:3 0 69f cef d0f
:2 0 d11 6a2 d12
cec d11 0 d13
6a4 0 d14 6a6
d17 :3 0 d17 0
d17 d16 d14 d15
:6 0 d19 21 :3 0
6a9 d1b 6ab d1a
d19 :2 0 d1c 6ad
:2 0 d1e 0 d1e
d1d ccb d1c :6 0
d20 1 :3 0 6b0
d21 cbb d20 0
d22 6b2 0 d50
9b :3 0 50 :3 0
38 :2 0 6b4 d23
d26 bf :2 0 38
:2 0 6b9 d28 d2a
:3 0 9b :3 0 56
:3 0 38 :2 0 6bc
d2c d2f fb :3 0
bf :2 0 134 :3 0
d31 d33 0 6c1
d32 d35 :3 0 9b
:3 0 56 :3 0 38
:2 0 6c4 d37 d3a
fb :3 0 bf :2 0
135 :3 0 d3c d3e
0 6c9 d3d d40
:3 0 d36 d42 d41
:2 0 d43 :2 0 d2b
d45 d44 :2 0 29
:3 0 a6 :4 0 d47
d48 0 d4d 7c
:3 0 35 :2 0 d4a
d4b 0 d4d 6cc
d4e d46 d4d 0
d4f 6cf 0 d50
6d1 d52 a1e b27
0 d53 0 d50
0 d53 6d6 0
e93 9b :3 0 64
:3 0 38 :2 0 6d9
d54 d57 105 :2 0
38 :2 0 6de d59
d5b :3 0 7c :3 0
bf :2 0 35 :2 0
6e3 d5e d60 :3 0
d5c d62 d61 :2 0
d63 :2 0 9b :3 0
56 :3 0 38 :2 0
6e6 d65 d68 fb
:3 0 bf :2 0 134
:3 0 d6a d6c 0
6eb d6b d6e :3 0
9b :3 0 56 :3 0
38 :2 0 6ee d70
d73 fb :3 0 bf
:2 0 135 :3 0 d75
d77 0 6f3 d76
d79 :3 0 d6f d7b
d7a :2 0 d7c :2 0
d64 d7e d7d :2 0
70 :3 0 14d :3 0
24 :3 0 29 :3 0
64 :3 0 2a :3 0
6f6 d81 d86 d80
d87 0 d89 6fb
d8a d7f d89 0
d8b 6fd 0 e93
70 :3 0 38 :2 0
d8c d8d 0 e93
136 :3 0 70 :3 0
117 :3 0 e1 :3 0
14e :3 0 14e :3 0
ae :3 0 24 :3 0
14e :3 0 df :3 0
21 :3 0 14e :3 0
c1 :3 0 e1 :3 0
14f :3 0 14f :3 0
ae :3 0 24 :3 0
14f :3 0 e2 :3 0
14e :3 0 c1 :3 0
d3 :3 0 bc :3 0
29 :3 0 d3 :3 0
bc :3 0 14f :3 0
e8 :3 0 d3 :3 0
bc :3 0 2a :3 0
d3 :3 0 bc :3 0
14f :3 0 e9 :4 0
150 1 :8 0 db9
8b :3 0 b2 :3 0
db4 db5 0 b3
:3 0 db6 db7 0
db9 6ff e0c b4
:3 0 8b :3 0 b2
:3 0 dbb dbc 0
b3 :3 0 dbd dbe
0 dc0 702 dc2
704 dc1 dc0 :2 0
e0a b5 :3 0 8b
:3 0 b2 :3 0 dc5
dc6 0 b3 :3 0
dc7 dc8 0 e02
8e :3 0 8f :3 0
dca dcb 0 8e
:3 0 a1 :3 0 dcd
dce 0 b6 :2 0
2 :4 0 151 :2 0
a3 :2 0 35 :2 0
706 dd3 dd5 :3 0
709 dcf dd7 dcc
dd9 dd8 :2 0 91
:3 0 a4 :3 0 ddb
ddc 0 93 :4 0
152 :4 0 96 :2 0
97 :3 0 70d de0
de2 :3 0 96 :2 0
b9 :4 0 710 de4
de6 :3 0 96 :2 0
ba :4 0 713 de8
dea :3 0 96 :2 0
b3 :3 0 716 dec
dee :3 0 96 :2 0
bb :4 0 719 df0
df2 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
71c df5 df9 720
df4 dfb :3 0 723
ddd dfd :2 0 dff
726 e00 dda dff
0 e01 728 0
e02 72a e05 :3 0
e05 0 e05 e04
e02 e03 :6 0 e07
23 :3 0 72d e09
72f e08 e07 :2 0
e0a 731 :2 0 e0c
0 e0c e0b db9
e0a :6 0 e93 1
:3 0 9b :3 0 70
:3 0 38 :2 0 734
e0e e11 105 :2 0
38 :2 0 739 e13
e15 :3 0 11 :3 0
21 :3 0 e17 e18
0 e3e 8e :3 0
8f :3 0 e1a e1b
0 8e :3 0 a1
:3 0 e1d e1e 0
35 :2 0 2 :4 0
153 :2 0 a3 :2 0
35 :2 0 73c e23
e25 :3 0 73f e1f
e27 e1c e29 e28
:2 0 91 :3 0 a4
:3 0 e2b e2c 0
93 :4 0 154 :4 0
96 :2 0 97 :3 0
743 e30 e32 :3 0
746 e2d e34 :2 0
e36 749 e37 e2a
e36 0 e38 74b
0 e3e 12 :3 0
fb :3 0 155 :3 0
e3a e3b 0 e3c
:2 0 e3e 74d e3f
e16 e3e 0 e40
751 0 e93 70
:3 0 156 :3 0 24
:3 0 21 :3 0 27
:3 0 28 :3 0 29
:3 0 2a :3 0 57
:3 0 66 :3 0 70
:3 0 4a :3 0 9b
:3 0 56 :3 0 38
:2 0 753 e4d e50
38 :2 0 756 e42
e53 e41 e54 0
e93 9b :3 0 70
:3 0 38 :2 0 763
e56 e59 bf :2 0
38 :2 0 768 e5b
e5d :3 0 70 :3 0
133 :3 0 24 :3 0
76b e60 e62 e5f
e63 0 e65 76d
e90 11 :3 0 21
:3 0 e66 e67 0
e8f 8e :3 0 8f
:3 0 e69 e6a 0
8e :3 0 a1 :3 0
e6c e6d 0 35
:2 0 2 :4 0 157
:2 0 a3 :2 0 35
:2 0 76f e72 e74
:3 0 772 e6e e76
e6b e78 e77 :2 0
91 :3 0 a4 :3 0
e7a e7b 0 93
:4 0 158 :4 0 96
:2 0 97 :3 0 776
e7f e81 :3 0 779
e7c e83 :2 0 e85
77c e86 e79 e85
0 e87 77e 0
e8f 12 :3 0 9b
:3 0 70 :3 0 38
:2 0 780 e89 e8c
e8d :2 0 e8f 783
e91 e5e e65 0
e92 0 e8f 0
e92 787 0 e93
78a e95 69f 989
0 e96 0 e93
0 e96 795 0
e98 159 :3 0 798
1077 9b :3 0 16
:3 0 38 :2 0 79a
e99 e9c 9b :3 0
106 :2 0 50 :3 0
38 :2 0 79d e9e
ea2 7a2 e9f ea4
:3 0 ea5 :2 0 9b
:3 0 4b :3 0 38
:2 0 7a5 ea7 eaa
105 :2 0 38 :2 0
7aa eac eae :3 0
eaf :2 0 ea6 eb1
eb0 :2 0 62 :3 0
38 :2 0 eb3 eb4
0 1075 9b :3 0
16 :3 0 38 :2 0
7ad eb6 eb9 9b
:3 0 105 :2 0 4b
:3 0 38 :2 0 7b0
ebb ebf 7b5 ebc
ec1 :3 0 11 :3 0
21 :3 0 ec3 ec4
0 eeb 8e :3 0
8f :3 0 ec6 ec7
0 8e :3 0 a1
:3 0 ec9 eca 0
35 :2 0 2 :4 0
15a :2 0 a3 :2 0
35 :2 0 7b8 ecf
ed1 :3 0 7bb ecb
ed3 ec8 ed5 ed4
:2 0 91 :3 0 a4
:3 0 ed7 ed8 0
93 :4 0 15b :4 0
96 :2 0 97 :3 0
7bf edc ede :3 0
7c2 ed9 ee0 :2 0
ee2 7c5 ee3 ed6
ee2 0 ee4 7c7
0 eeb 12 :3 0
fb :3 0 15c :3 0
ee6 ee7 0 ee8
:2 0 eeb 159 :3 0
7c9 efe 9b :3 0
16 :3 0 38 :2 0
7cd eec eef 9b
:3 0 bf :2 0 4b
:3 0 38 :2 0 7d0
ef1 ef5 7d5 ef2
ef7 :3 0 62 :3 0
35 :2 0 ef9 efa
0 efc 7d8 efd
ef8 efc 0 eff
ec2 eeb 0 eff
7da 0 1075 70
:3 0 38 :2 0 f00
f01 0 1075 136
:3 0 70 :3 0 117
:3 0 15d :3 0 86
:3 0 e1 :3 0 14e
:3 0 15e :3 0 15d
:3 0 14e :3 0 df
:3 0 21 :3 0 14e
:3 0 e2 :3 0 15d
:3 0 e2 :3 0 15d
:3 0 e2 :3 0 15d
:3 0 86 :3 0 15d
:3 0 15f :3 0 fb
:3 0 160 :4 0 161
1 :8 0 f21 8b
:3 0 b2 :3 0 f1c
f1d 0 b3 :3 0
f1e f1f 0 f21
7dd f74 b4 :3 0
8b :3 0 b2 :3 0
f23 f24 0 b3
:3 0 f25 f26 0
f28 7e0 f2a 7e2
f29 f28 :2 0 f72
b5 :3 0 8b :3 0
b2 :3 0 f2d f2e
0 b3 :3 0 f2f
f30 0 f6a 8e
:3 0 8f :3 0 f32
f33 0 8e :3 0
a1 :3 0 f35 f36
0 b6 :2 0 2
:4 0 162 :2 0 a3
:2 0 35 :2 0 7e4
f3b f3d :3 0 7e7
f37 f3f f34 f41
f40 :2 0 91 :3 0
a4 :3 0 f43 f44
0 93 :4 0 163
:4 0 96 :2 0 97
:3 0 7eb f48 f4a
:3 0 96 :2 0 b9
:4 0 7ee f4c f4e
:3 0 96 :2 0 ba
:4 0 7f1 f50 f52
:3 0 96 :2 0 b3
:3 0 7f4 f54 f56
:3 0 96 :2 0 bb
:4 0 7f7 f58 f5a
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 7fa
f5d f61 7fe f5c
f63 :3 0 801 f45
f65 :2 0 f67 804
f68 f42 f67 0
f69 806 0 f6a
808 f6d :3 0 f6d
0 f6d f6c f6a
f6b :6 0 f6f 25
:3 0 80b f71 80d
f70 f6f :2 0 f72
80f :2 0 f74 0
f74 f73 f21 f72
:6 0 1075 1 :3 0
9b :3 0 70 :3 0
38 :2 0 812 f76
f79 105 :2 0 38
:2 0 817 f7b f7d
:3 0 11 :3 0 21
:3 0 f7f f80 0
fa6 8e :3 0 8f
:3 0 f82 f83 0
8e :3 0 a1 :3 0
f85 f86 0 35
:2 0 2 :4 0 164
:2 0 a3 :2 0 35
:2 0 81a f8b f8d
:3 0 81d f87 f8f
f84 f91 f90 :2 0
91 :3 0 a4 :3 0
f93 f94 0 93
:4 0 165 :4 0 96
:2 0 97 :3 0 821
f98 f9a :3 0 824
f95 f9c :2 0 f9e
827 f9f f92 f9e
0 fa0 829 0
fa6 12 :3 0 fb
:3 0 101 :3 0 fa2
fa3 0 fa4 :2 0
fa6 82b fa7 f7e
fa6 0 fa8 82f
0 1075 70 :3 0
38 :2 0 fa9 faa
0 1075 136 :3 0
70 :3 0 117 :3 0
e1 :3 0 14e :3 0
166 :3 0 167 :3 0
168 :3 0 168 :3 0
86 :3 0 14e :3 0
ae :3 0 168 :3 0
ad :3 0 14e :3 0
ad :3 0 14e :3 0
ae :3 0 24 :3 0
14e :3 0 df :3 0
21 :3 0 d3 :3 0
bc :3 0 14e :3 0
cb :3 0 168 :3 0
169 :4 0 16a 1
:8 0 fce 8b :3 0
b2 :3 0 fc9 fca
0 b3 :3 0 fcb
fcc 0 fce 831
1021 b4 :3 0 8b
:3 0 b2 :3 0 fd0
fd1 0 b3 :3 0
fd2 fd3 0 fd5
834 fd7 836 fd6
fd5 :2 0 101f b5
:3 0 8b :3 0 b2
:3 0 fda fdb 0
b3 :3 0 fdc fdd
0 1017 8e :3 0
8f :3 0 fdf fe0
0 8e :3 0 a1
:3 0 fe2 fe3 0
b6 :2 0 2 :4 0
16b :2 0 a3 :2 0
35 :2 0 838 fe8
fea :3 0 83b fe4
fec fe1 fee fed
:2 0 91 :3 0 a4
:3 0 ff0 ff1 0
93 :4 0 16c :4 0
96 :2 0 97 :3 0
83f ff5 ff7 :3 0
96 :2 0 b9 :4 0
842 ff9 ffb :3 0
96 :2 0 ba :4 0
845 ffd fff :3 0
96 :2 0 b3 :3 0
848 1001 1003 :3 0
96 :2 0 bb :4 0
84b 1005 1007 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 84e 100a
100e 852 1009 1010
:3 0 855 ff2 1012
:2 0 1014 858 1015
fef 1014 0 1016
85a 0 1017 85c
101a :3 0 101a 0
101a 1019 1017 1018
:6 0 101c 27 :3 0
85f 101e 861 101d
101c :2 0 101f 863
:2 0 1021 0 1021
1020 fce 101f :6 0
1075 1 :3 0 9b
:3 0 70 :3 0 38
:2 0 866 1023 1026
105 :2 0 38 :2 0
86b 1028 102a :3 0
11 :3 0 21 :3 0
102c 102d 0 1053
8e :3 0 8f :3 0
102f 1030 0 8e
:3 0 a1 :3 0 1032
1033 0 35 :2 0
2 :4 0 16d :2 0
a3 :2 0 35 :2 0
86e 1038 103a :3 0
871 1034 103c 1031
103e 103d :2 0 91
:3 0 a4 :3 0 1040
1041 0 93 :4 0
16e :4 0 96 :2 0
97 :3 0 875 1045
1047 :3 0 878 1042
1049 :2 0 104b 87b
104c 103f 104b 0
104d 87d 0 1053
12 :3 0 fb :3 0
16f :3 0 104f 1050
0 1051 :2 0 1053
87f 1054 102b 1053
0 1055 883 0
1075 51 :3 0 9b
:3 0 16 :3 0 38
:2 0 885 1057 105a
1056 105b 0 1075
70 :3 0 170 :3 0
24 :3 0 21 :3 0
51 :3 0 4a :3 0
9b :3 0 62 :3 0
38 :2 0 888 1063
1066 9b :3 0 57
:3 0 38 :2 0 88b
1068 106b 9b :3 0
56 :3 0 38 :2 0
88e 106d 1070 891
105e 1072 105d 1073
0 1075 899 1076
eb2 1075 0 1078
696 e98 0 1078
8a4 0 10b5 9b
:3 0 70 :3 0 38
:2 0 8a7 1079 107c
bf :2 0 38 :2 0
8ac 107e 1080 :3 0
70 :3 0 133 :3 0
24 :3 0 8af 1083
1085 1082 1086 0
1088 8b1 1089 1081
1088 0 108a 8b3
0 10b5 11 :3 0
21 :3 0 108b 108c
0 10b5 8e :3 0
8f :3 0 108e 108f
0 8e :3 0 a1
:3 0 1091 1092 0
35 :2 0 2 :4 0
171 :2 0 a3 :2 0
35 :2 0 8b5 1097
1099 :3 0 8b8 1093
109b 1090 109d 109c
:2 0 91 :3 0 a4
:3 0 109f 10a0 0
93 :4 0 172 :4 0
96 :2 0 97 :3 0
8bc 10a4 10a6 :3 0
8bf 10a1 10a8 :2 0
10aa 8c2 10ab 109e
10aa 0 10ac 8c4
0 10b5 12 :3 0
9b :3 0 70 :3 0
38 :2 0 8c6 10ae
10b1 10b2 :2 0 10b5
159 :3 0 8c9 2985
8 :3 0 10a :2 0
8d6 10b7 10b8 :3 0
10b9 :2 0 a :3 0
10a :2 0 8d8 10bc
10bd :3 0 10be :2 0
10ba 10c0 10bf :2 0
29 :3 0 8 :3 0
10c2 10c3 0 2896
2a :3 0 a :3 0
10c5 10c6 0 2896
102 :3 0 103 :3 0
10c8 10c9 0 29
:3 0 2a :3 0 104
:2 0 8da 10ca 10ce
105 :2 0 38 :2 0
8e0 10d0 10d2 :3 0
10d3 :2 0 102 :3 0
103 :3 0 10d5 10d6
0 2a :3 0 28
:3 0 104 :2 0 8e3
10d7 10db 106 :2 0
38 :2 0 8e9 10dd
10df :3 0 10e0 :2 0
10d4 10e2 10e1 :2 0
11 :3 0 21 :3 0
10e4 10e5 0 110b
8e :3 0 8f :3 0
10e7 10e8 0 8e
:3 0 a1 :3 0 10ea
10eb 0 35 :2 0
2 :4 0 173 :2 0
a3 :2 0 35 :2 0
8ec 10f0 10f2 :3 0
8ef 10ec 10f4 10e9
10f6 10f5 :2 0 91
:3 0 a4 :3 0 10f8
10f9 0 93 :4 0
174 :4 0 96 :2 0
97 :3 0 8f3 10fd
10ff :3 0 8f6 10fa
1101 :2 0 1103 8f9
1104 10f7 1103 0
1105 8fb 0 110b
12 :3 0 fb :3 0
109 :3 0 1107 1108
0 1109 :2 0 110b
8fd 110c 10e3 110b
0 110d 901 0
2896 22 :3 0 10a
:2 0 903 110f 1110
:3 0 1111 :2 0 cd
:3 0 ce :3 0 ca
:3 0 2c :3 0 2d
:3 0 67 :3 0 e1
:3 0 e2 :3 0 22
:4 0 175 1 :8 0
1122 8b :3 0 b2
:3 0 111d 111e 0
b3 :3 0 111f 1120
0 1122 905 1175
b4 :3 0 8b :3 0
b2 :3 0 1124 1125
0 b3 :3 0 1126
1127 0 1129 908
112b 90a 112a 1129
:2 0 1173 b5 :3 0
8b :3 0 b2 :3 0
112e 112f 0 b3
:3 0 1130 1131 0
116b 8e :3 0 8f
:3 0 1133 1134 0
8e :3 0 a1 :3 0
1136 1137 0 b6
:2 0 2 :4 0 176
:2 0 a3 :2 0 35
:2 0 90c 113c 113e
:3 0 90f 1138 1140
1135 1142 1141 :2 0
91 :3 0 a4 :3 0
1144 1145 0 93
:4 0 177 :4 0 96
:2 0 97 :3 0 913
1149 114b :3 0 96
:2 0 b9 :4 0 916
114d 114f :3 0 96
:2 0 ba :4 0 919
1151 1153 :3 0 96
:2 0 b3 :3 0 91c
1155 1157 :3 0 96
:2 0 bb :4 0 91f
1159 115b :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 922 115e 1162
926 115d 1164 :3 0
929 1146 1166 :2 0
1168 92c 1169 1143
1168 0 116a 92e
0 116b 930 116e
:3 0 116e 0 116e
116d 116b 116c :6 0
1170 29 :3 0 933
1172 935 1171 1170
:2 0 1173 937 :2 0
1175 0 1175 1174
1122 1173 :6 0 1237
1 :3 0 8b :3 0
b2 :3 0 1177 1178
0 8b :3 0 106
:2 0 132 :3 0 117a
117c 0 93c 117b
117e :3 0 117f :2 0
11 :3 0 22 :3 0
1181 1182 0 11a8
8e :3 0 8f :3 0
1184 1185 0 8e
:3 0 a1 :3 0 1187
1188 0 35 :2 0
2 :4 0 178 :2 0
a3 :2 0 35 :2 0
93f 118d 118f :3 0
942 1189 1191 1186
1193 1192 :2 0 91
:3 0 a4 :3 0 1195
1196 0 93 :4 0
179 :4 0 96 :2 0
97 :3 0 946 119a
119c :3 0 949 1197
119e :2 0 11a0 94c
11a1 1194 11a0 0
11a2 94e 0 11a8
12 :3 0 fb :3 0
155 :3 0 11a4 11a5
0 11a6 :2 0 11a8
950 11a9 1180 11a8
0 11aa 954 0
1237 102 :3 0 103
:3 0 11ab 11ac 0
29 :3 0 2c :3 0
104 :2 0 956 11ad
11b1 17a :2 0 38
:2 0 95c 11b3 11b5
:3 0 11b6 :2 0 102
:3 0 103 :3 0 11b8
11b9 0 29 :3 0
2d :3 0 104 :2 0
95f 11ba 11be 105
:2 0 38 :2 0 965
11c0 11c2 :3 0 11c3
:2 0 11b7 11c5 11c4
:2 0 11 :3 0 22
:3 0 11c7 11c8 0
11ef 8e :3 0 8f
:3 0 11ca 11cb 0
8e :3 0 a1 :3 0
11cd 11ce 0 35
:2 0 2 :4 0 17b
:2 0 a3 :2 0 35
:2 0 968 11d3 11d5
:3 0 96b 11cf 11d7
11cc 11d9 11d8 :2 0
91 :3 0 a4 :3 0
11db 11dc 0 93
:4 0 17c :4 0 96
:2 0 97 :3 0 96f
11e0 11e2 :3 0 972
11dd 11e4 :2 0 11e6
975 11e7 11da 11e6
0 11e8 977 0
11ef 12 :3 0 fb
:3 0 155 :3 0 11ea
11eb 0 11ec :2 0
11ef 159 :3 0 979
1235 102 :3 0 103
:3 0 11f0 11f1 0
2a :3 0 2c :3 0
104 :2 0 97d 11f2
11f6 17a :2 0 38
:2 0 983 11f8 11fa
:3 0 11fb :2 0 102
:3 0 103 :3 0 11fd
11fe 0 2a :3 0
2d :3 0 104 :2 0
986 11ff 1203 105
:2 0 38 :2 0 98c
1205 1207 :3 0 1208
:2 0 11fc 120a 1209
:2 0 11 :3 0 22
:3 0 120c 120d 0
1233 8e :3 0 8f
:3 0 120f 1210 0
8e :3 0 a1 :3 0
1212 1213 0 35
:2 0 2 :4 0 17d
:2 0 a3 :2 0 35
:2 0 98f 1218 121a
:3 0 992 1214 121c
1211 121e 121d :2 0
91 :3 0 a4 :3 0
1220 1221 0 93
:4 0 17e :4 0 96
:2 0 97 :3 0 996
1225 1227 :3 0 999
1222 1229 :2 0 122b
99c 122c 121f 122b
0 122d 99e 0
1233 12 :3 0 fb
:3 0 155 :3 0 122f
1230 0 1231 :2 0
1233 9a0 1234 120b
1233 0 1236 11c6
11ef 0 1236 9a4
0 1237 9a7 1238
1112 1237 0 1239
9ab 0 2896 e7
:3 0 e6 :3 0 cc
:3 0 e8 :3 0 e9
:3 0 ec :3 0 57
:3 0 56 :3 0 37
:3 0 2e :3 0 2f
:3 0 68 :3 0 f5
:3 0 ae :3 0 24
:3 0 86 :3 0 48
:4 0 17f 1 :8 0
1251 8b :3 0 b2
:3 0 124c 124d 0
b3 :3 0 124e 124f
0 1251 9ad 12a4
b4 :3 0 8b :3 0
b2 :3 0 1253 1254
0 b3 :3 0 1255
1256 0 1258 9b0
125a 9b2 1259 1258
:2 0 12a2 b5 :3 0
8b :3 0 b2 :3 0
125d 125e 0 b3
:3 0 125f 1260 0
129a 8e :3 0 8f
:3 0 1262 1263 0
8e :3 0 a1 :3 0
1265 1266 0 b6
:2 0 2 :4 0 180
:2 0 a3 :2 0 35
:2 0 9b4 126b 126d
:3 0 9b7 1267 126f
1264 1271 1270 :2 0
91 :3 0 a4 :3 0
1273 1274 0 93
:4 0 181 :4 0 96
:2 0 97 :3 0 9bb
1278 127a :3 0 96
:2 0 b9 :4 0 9be
127c 127e :3 0 96
:2 0 ba :4 0 9c1
1280 1282 :3 0 96
:2 0 b3 :3 0 9c4
1284 1286 :3 0 96
:2 0 bb :4 0 9c7
1288 128a :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 9ca 128d 1291
9ce 128c 1293 :3 0
9d1 1275 1295 :2 0
1297 9d4 1298 1272
1297 0 1299 9d6
0 129a 9d8 129d
:3 0 129d 0 129d
129c 129a 129b :6 0
129f 2b :3 0 9db
12a1 9dd 12a0 129f
:2 0 12a2 9df :2 0
12a4 0 12a4 12a3
1251 12a2 :6 0 2896
1 :3 0 fd :3 0
9b :3 0 68 :3 0
38 :2 0 9e2 12a7
12aa fb :3 0 fe
:3 0 12ac 12ad 0
9e5 12a6 12af 12b0
:2 0 fb :3 0 bf
:2 0 fe :3 0 12b2
12b4 0 9ea 12b3
12b6 :3 0 11 :3 0
48 :3 0 12b8 12b9
0 12df 8e :3 0
8f :3 0 12bb 12bc
0 8e :3 0 a1
:3 0 12be 12bf 0
35 :2 0 2 :4 0
182 :2 0 a3 :2 0
35 :2 0 9ed 12c4
12c6 :3 0 9f0 12c0
12c8 12bd 12ca 12c9
:2 0 91 :3 0 a4
:3 0 12cc 12cd 0
93 :4 0 183 :4 0
96 :2 0 97 :3 0
9f4 12d1 12d3 :3 0
9f7 12ce 12d5 :2 0
12d7 9fa 12d8 12cb
12d7 0 12d9 9fc
0 12df 12 :3 0
fb :3 0 101 :3 0
12db 12dc 0 12dd
:2 0 12df 9fe 12e0
12b7 12df 0 12e1
a02 0 2896 bc
:3 0 36 :3 0 35
:2 0 35 :2 0 a04
12e2 12e6 bf :2 0
35 :4 0 a0a 12e8
12ea :3 0 42 :3 0
35 :2 0 12ec 12ed
0 12ef a0d 12f4
42 :3 0 38 :2 0
12f0 12f1 0 12f3
a0f 12f5 12eb 12ef
0 12f6 0 12f3
0 12f6 a11 0
2896 7d :3 0 38
:2 0 12f7 12f8 0
2896 7e :3 0 38
:2 0 12fa 12fb 0
2896 102 :3 0 103
:3 0 12fd 12fe 0
29 :3 0 27 :3 0
104 :2 0 a14 12ff
1303 106 :2 0 38
:2 0 a1a 1305 1307
:3 0 1308 :2 0 102
:3 0 103 :3 0 130a
130b 0 2a :3 0
28 :3 0 104 :2 0
a1d 130c 1310 106
:2 0 38 :2 0 a23
1312 1314 :3 0 1315
:2 0 1309 1317 1316
:2 0 9b :3 0 13
:3 0 38 :2 0 a26
1319 131c 9b :3 0
106 :2 0 4d :3 0
38 :2 0 a29 131e
1322 a2e 131f 1324
:3 0 1325 :2 0 1318
1327 1326 :2 0 102
:3 0 103 :3 0 1329
132a 0 29 :3 0
27 :3 0 104 :2 0
a31 132b 132f 106
:2 0 38 :2 0 a37
1331 1333 :3 0 9b
:3 0 37 :3 0 38
:2 0 a3a 1335 1338
105 :2 0 38 :2 0
a3f 133a 133c :3 0
102 :3 0 103 :3 0
133e 133f 0 29
:3 0 2e :3 0 104
:2 0 a42 1340 1344
17a :2 0 38 :2 0
a48 1346 1348 :3 0
133d 134a 1349 :2 0
11 :3 0 21 :3 0
134c 134d 0 1373
8e :3 0 8f :3 0
134f 1350 0 8e
:3 0 a1 :3 0 1352
1353 0 35 :2 0
2 :4 0 184 :2 0
a3 :2 0 35 :2 0
a4b 1358 135a :3 0
a4e 1354 135c 1351
135e 135d :2 0 91
:3 0 a4 :3 0 1360
1361 0 93 :4 0
185 :4 0 96 :2 0
97 :3 0 a52 1365
1367 :3 0 a55 1362
1369 :2 0 136b a58
136c 135f 136b 0
136d a5a 0 1373
12 :3 0 fb :3 0
148 :3 0 136f 1370
0 1371 :2 0 1373
a5c 1374 134b 1373
0 1375 a60 0
1484 9b :3 0 56
:3 0 38 :2 0 a62
1376 1379 fb :3 0
bf :2 0 134 :3 0
137b 137d 0 a67
137c 137f :3 0 9b
:3 0 56 :3 0 38
:2 0 a6a 1381 1384
fb :3 0 bf :2 0
135 :3 0 1386 1388
0 a6f 1387 138a
:3 0 1380 138c 138b
:2 0 64 :3 0 38
:2 0 138e 138f 0
1475 136 :3 0 81
:3 0 64 :3 0 85
:3 0 86 :3 0 24
:3 0 81 :3 0 d3
:3 0 bc :3 0 2e
:3 0 d3 :3 0 bc
:3 0 2f :4 0 186
1 :8 0 13a4 8b
:3 0 b2 :3 0 139f
13a0 0 b3 :3 0
13a1 13a2 0 13a4
a72 13f7 b4 :3 0
8b :3 0 b2 :3 0
13a6 13a7 0 b3
:3 0 13a8 13a9 0
13ab a75 13ad a77
13ac 13ab :2 0 13f5
b5 :3 0 8b :3 0
b2 :3 0 13b0 13b1
0 b3 :3 0 13b2
13b3 0 13ed 8e
:3 0 8f :3 0 13b5
13b6 0 8e :3 0
a1 :3 0 13b8 13b9
0 b6 :2 0 2
:4 0 187 :2 0 a3
:2 0 35 :2 0 a79
13be 13c0 :3 0 a7c
13ba 13c2 13b7 13c4
13c3 :2 0 91 :3 0
a4 :3 0 13c6 13c7
0 93 :4 0 188
:4 0 96 :2 0 97
:3 0 a80 13cb 13cd
:3 0 96 :2 0 b9
:4 0 a83 13cf 13d1
:3 0 96 :2 0 ba
:4 0 a86 13d3 13d5
:3 0 96 :2 0 b3
:3 0 a89 13d7 13d9
:3 0 96 :2 0 bb
:4 0 a8c 13db 13dd
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 a8f
13e0 13e4 a93 13df
13e6 :3 0 a96 13c8
13e8 :2 0 13ea a99
13eb 13c5 13ea 0
13ec a9b 0 13ed
a9d 13f0 :3 0 13f0
0 13f0 13ef 13ed
13ee :6 0 13f2 2d
:3 0 aa0 13f4 aa2
13f3 13f2 :2 0 13f5
aa4 :2 0 13f7 0
13f7 13f6 13a4 13f5
:6 0 1475 1 :3 0
102 :3 0 103 :3 0
13f9 13fa 0 29
:3 0 2e :3 0 104
:2 0 aa7 13fb 13ff
17a :2 0 38 :2 0
aad 1401 1403 :3 0
1404 :2 0 102 :3 0
103 :3 0 1406 1407
0 29 :3 0 2f
:3 0 104 :2 0 ab0
1408 140c 105 :2 0
38 :2 0 ab6 140e
1410 :3 0 1411 :2 0
1405 1413 1412 :2 0
28 :3 0 a6 :4 0
1415 1416 0 1421
70 :3 0 14d :3 0
24 :3 0 29 :3 0
64 :3 0 28 :3 0
ab9 1419 141e 1418
141f 0 1421 abe
1422 1414 1421 0
1423 ac1 0 1475
6f :3 0 189 :3 0
29 :3 0 27 :3 0
28 :3 0 22 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 34 :3 0
49 :3 0 36 :3 0
57 :3 0 4e :3 0
71 :3 0 73 :3 0
3a :3 0 39 :3 0
4a :3 0 9b :3 0
4b :3 0 38 :2 0
ac3 1439 143c 9b
:3 0 50 :3 0 38
:2 0 ac6 143e 1441
ac9 1425 1443 1424
1444 0 1475 70
:3 0 133 :3 0 24
:3 0 adf 1447 1449
1446 144a 0 1475
11 :3 0 1f :3 0
144c 144d 0 1475
8e :3 0 8f :3 0
144f 1450 0 8e
:3 0 a1 :3 0 1452
1453 0 35 :2 0
2 :4 0 18a :2 0
a3 :2 0 35 :2 0
ae1 1458 145a :3 0
ae4 1454 145c 1451
145e 145d :2 0 91
:3 0 a4 :3 0 1460
1461 0 93 :4 0
18b :4 0 96 :2 0
97 :3 0 ae8 1465
1467 :3 0 aeb 1462
1469 :2 0 146b aee
146c 145f 146b 0
146d af0 0 1475
12 :3 0 9b :3 0
70 :3 0 38 :2 0
af2 146f 1472 1473
:2 0 1475 af5 1480
27 :3 0 29 :3 0
1476 1477 0 147f
4d :3 0 38 :2 0
1479 147a 0 147f
7d :3 0 35 :2 0
147c 147d 0 147f
afe 1481 138d 1475
0 1482 0 147f
0 1482 b02 0
1484 159 :3 0 b05
1b83 102 :3 0 103
:3 0 1485 1486 0
2a :3 0 28 :3 0
104 :2 0 b08 1487
148b 106 :2 0 38
:2 0 b0e 148d 148f
:3 0 102 :3 0 10f
:3 0 d3 :3 0 bc
:3 0 2a :3 0 102
:3 0 110 :3 0 28
:3 0 2a :3 0 117
:4 0 18c 1 :8 0
14a1 8b :3 0 b2
:3 0 149c 149d 0
b3 :3 0 149e 149f
0 14a1 b11 14f4
b4 :3 0 8b :3 0
b2 :3 0 14a3 14a4
0 b3 :3 0 14a5
14a6 0 14a8 b14
14aa b16 14a9 14a8
:2 0 14f2 b5 :3 0
8b :3 0 b2 :3 0
14ad 14ae 0 b3
:3 0 14af 14b0 0
14ea 8e :3 0 8f
:3 0 14b2 14b3 0
8e :3 0 a1 :3 0
14b5 14b6 0 b6
:2 0 2 :4 0 18d
:2 0 a3 :2 0 35
:2 0 b18 14bb 14bd
:3 0 b1b 14b7 14bf
14b4 14c1 14c0 :2 0
91 :3 0 a4 :3 0
14c3 14c4 0 93
:4 0 18e :4 0 96
:2 0 97 :3 0 b1f
14c8 14ca :3 0 96
:2 0 b9 :4 0 b22
14cc 14ce :3 0 96
:2 0 ba :4 0 b25
14d0 14d2 :3 0 96
:2 0 b3 :3 0 b28
14d4 14d6 :3 0 96
:2 0 bb :4 0 b2b
14d8 14da :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 b2e 14dd 14e1
b32 14dc 14e3 :3 0
b35 14c5 14e5 :2 0
14e7 b38 14e8 14c2
14e7 0 14e9 b3a
0 14ea b3c 14ed
:3 0 14ed 0 14ed
14ec 14ea 14eb :6 0
14ef 2f :3 0 b3f
14f1 b41 14f0 14ef
:2 0 14f2 b43 :2 0
14f4 0 14f4 14f3
14a1 14f2 :6 0 174a
1 :3 0 7e :3 0
102 :3 0 18f :3 0
14f7 14f8 0 2a
:3 0 28 :3 0 b46
14f9 14fc 14f6 14fd
0 174a 3b :3 0
10b :2 0 35 :2 0
b49 1500 1502 :3 0
14ff 1503 0 174a
70 :3 0 190 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 71 :3 0
73 :3 0 3b :3 0
3a :3 0 39 :3 0
b4b 1506 1511 1505
1512 0 174a 9b
:3 0 53 :3 0 38
:2 0 b56 1514 1517
105 :2 0 38 :2 0
b5b 1519 151b :3 0
151c :2 0 3d :3 0
10a :2 0 b5e 151f
1520 :3 0 1521 :2 0
1522 :2 0 151d 1524
1523 :2 0 70 :3 0
191 :3 0 24 :3 0
48 :3 0 49 :3 0
22 :3 0 21 :3 0
3d :3 0 53 :3 0
38 :2 0 b60 1527
1530 1526 1531 0
1533 b69 1534 1525
1533 0 1535 b6b
0 174a bc :3 0
34 :3 0 35 :2 0
35 :2 0 b6d 1536
153a bf :2 0 192
:4 0 b73 153c 153e
:3 0 58 :3 0 192
:2 0 1540 1541 0
1543 b76 1548 58
:3 0 38 :2 0 1544
1545 0 1547 b78
1549 153f 1543 0
154a 0 1547 0
154a b7a 0 174a
65 :3 0 9b :3 0
4b :3 0 38 :2 0
b7d 154c 154f 10b
:2 0 9b :3 0 50
:3 0 38 :2 0 b80
1552 1555 b83 1551
1557 :3 0 154b 1558
0 174a 70 :3 0
193 :3 0 24 :3 0
48 :3 0 21 :3 0
49 :3 0 36 :3 0
30 :3 0 32 :3 0
27 :3 0 2a :3 0
58 :3 0 57 :3 0
4e :3 0 4a :3 0
9b :3 0 65 :3 0
38 :2 0 b86 1569
156c 192 :2 0 7e
:3 0 38 :2 0 b89
155b 1571 155a 1572
0 174a 9b :3 0
70 :3 0 38 :2 0
b9b 1574 1577 bf
:2 0 38 :2 0 ba0
1579 157b :3 0 102
:3 0 103 :3 0 157d
157e 0 3d :3 0
2a :3 0 104 :2 0
ba3 157f 1583 bf
:2 0 38 :2 0 ba9
1585 1587 :3 0 e1
:3 0 194 :3 0 fb
:3 0 195 :3 0 196
:3 0 2a :3 0 f2
:3 0 de :3 0 d0
:3 0 cc :3 0 124
:3 0 2a :3 0 e2
:3 0 21 :4 0 197
1 :8 0 15ad 127
:4 0 1598 :3 0 128
:3 0 bf :2 0 bae
159b 159c :3 0 8b
:3 0 b2 :3 0 159e
159f 0 38 :2 0
15a0 15a1 0 15a3
bb1 15aa 8b :3 0
b2 :3 0 15a4 15a5
0 129 :2 0 15a6
15a7 0 15a9 bb3
15ab 159d 15a3 0
15ac 0 15a9 0
15ac bb5 0 15ad
bb8 1600 b4 :3 0
8b :3 0 b2 :3 0
15af 15b0 0 b3
:3 0 15b1 15b2 0
15b4 bbb 15b6 bbd
15b5 15b4 :2 0 15fe
b5 :3 0 8b :3 0
b2 :3 0 15b9 15ba
0 b3 :3 0 15bb
15bc 0 15f6 8e
:3 0 8f :3 0 15be
15bf 0 8e :3 0
a1 :3 0 15c1 15c2
0 b6 :2 0 2
:4 0 198 :2 0 a3
:2 0 35 :2 0 bbf
15c7 15c9 :3 0 bc2
15c3 15cb 15c0 15cd
15cc :2 0 91 :3 0
a4 :3 0 15cf 15d0
0 93 :4 0 199
:4 0 96 :2 0 97
:3 0 bc6 15d4 15d6
:3 0 96 :2 0 b9
:4 0 bc9 15d8 15da
:3 0 96 :2 0 ba
:4 0 bcc 15dc 15de
:3 0 96 :2 0 b3
:3 0 bcf 15e0 15e2
:3 0 96 :2 0 bb
:4 0 bd2 15e4 15e6
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 bd5
15e9 15ed bd9 15e8
15ef :3 0 bdc 15d1
15f1 :2 0 15f3 bdf
15f4 15ce 15f3 0
15f5 be1 0 15f6
be3 15f9 :3 0 15f9
0 15f9 15f8 15f6
15f7 :6 0 15fb 31
:3 0 be6 15fd be8
15fc 15fb :2 0 15fe
bea :2 0 1600 0
1600 15ff 15ad 15fe
:6 0 1603 1 :3 0
159 :3 0 bed 1692
9b :3 0 65 :3 0
38 :2 0 bef 1604
1607 bf :2 0 38
:2 0 bf4 1609 160b
:3 0 102 :3 0 103
:3 0 160d 160e 0
3d :3 0 2a :3 0
104 :2 0 bf7 160f
1613 17a :2 0 38
:2 0 bfd 1615 1617
:3 0 160c 1619 1618
:2 0 e1 :3 0 194
:3 0 fb :3 0 19a
:3 0 196 :3 0 de
:3 0 cc :3 0 d0
:3 0 e2 :3 0 21
:4 0 19b 1 :8 0
163b 127 :4 0 1626
:3 0 128 :3 0 bf
:2 0 c02 1629 162a
:3 0 8b :3 0 b2
:3 0 162c 162d 0
38 :2 0 162e 162f
0 1631 c05 1638
8b :3 0 b2 :3 0
1632 1633 0 129
:2 0 1634 1635 0
1637 c07 1639 162b
1631 0 163a 0
1637 0 163a c09
0 163b c0c 168e
b4 :3 0 8b :3 0
b2 :3 0 163d 163e
0 b3 :3 0 163f
1640 0 1642 c0f
1644 c11 1643 1642
:2 0 168c b5 :3 0
8b :3 0 b2 :3 0
1647 1648 0 b3
:3 0 1649 164a 0
1684 8e :3 0 8f
:3 0 164c 164d 0
8e :3 0 a1 :3 0
164f 1650 0 b6
:2 0 2 :4 0 19c
:2 0 a3 :2 0 35
:2 0 c13 1655 1657
:3 0 c16 1651 1659
164e 165b 165a :2 0
91 :3 0 a4 :3 0
165d 165e 0 93
:4 0 19d :4 0 96
:2 0 97 :3 0 c1a
1662 1664 :3 0 96
:2 0 b9 :4 0 c1d
1666 1668 :3 0 96
:2 0 ba :4 0 c20
166a 166c :3 0 96
:2 0 b3 :3 0 c23
166e 1670 :3 0 96
:2 0 bb :4 0 c26
1672 1674 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 c29 1677 167b
c2d 1676 167d :3 0
c30 165f 167f :2 0
1681 c33 1682 165c
1681 0 1683 c35
0 1684 c37 1687
:3 0 1687 0 1687
1686 1684 1685 :6 0
1689 33 :3 0 c3a
168b c3c 168a 1689
:2 0 168c c3e :2 0
168e 0 168e 168d
163b 168c :6 0 1690
1 :3 0 c41 1691
161a 1690 0 1693
1588 1603 0 1693
c43 0 1694 c46
1695 157c 1694 0
1696 c48 0 174a
d3 :3 0 bc :3 0
27 :3 0 d3 :3 0
bc :3 0 2a :3 0
d4 :3 0 d5 :3 0
d6 :3 0 d8 :3 0
30 :3 0 32 :3 0
39 :3 0 3a :3 0
71 :3 0 73 :3 0
e1 :3 0 e2 :3 0
21 :4 0 19e 1
:8 0 16b0 8b :3 0
b2 :3 0 16ab 16ac
0 b3 :3 0 16ad
16ae 0 16b0 c4a
1703 b4 :3 0 8b
:3 0 b2 :3 0 16b2
16b3 0 b3 :3 0
16b4 16b5 0 16b7
c4d 16b9 c4f 16b8
16b7 :2 0 1701 b5
:3 0 8b :3 0 b2
:3 0 16bc 16bd 0
b3 :3 0 16be 16bf
0 16f9 8e :3 0
8f :3 0 16c1 16c2
0 8e :3 0 a1
:3 0 16c4 16c5 0
b6 :2 0 2 :4 0
19f :2 0 a3 :2 0
35 :2 0 c51 16ca
16cc :3 0 c54 16c6
16ce 16c3 16d0 16cf
:2 0 91 :3 0 a4
:3 0 16d2 16d3 0
93 :4 0 1a0 :4 0
96 :2 0 97 :3 0
c58 16d7 16d9 :3 0
96 :2 0 b9 :4 0
c5b 16db 16dd :3 0
96 :2 0 ba :4 0
c5e 16df 16e1 :3 0
96 :2 0 b3 :3 0
c61 16e3 16e5 :3 0
96 :2 0 bb :4 0
c64 16e7 16e9 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 c67 16ec
16f0 c6b 16eb 16f2
:3 0 c6e 16d4 16f4
:2 0 16f6 c71 16f7
16d1 16f6 0 16f8
c73 0 16f9 c75
16fc :3 0 16fc 0
16fc 16fb 16f9 16fa
:6 0 16fe 35 :3 0
c78 1700 c7a 16ff
16fe :2 0 1701 c7c
:2 0 1703 0 1703
1702 16b0 1701 :6 0
174a 1 :3 0 3b
:3 0 38 :2 0 1705
1706 0 174a 70
:3 0 190 :3 0 24
:3 0 48 :3 0 21
:3 0 30 :3 0 32
:3 0 71 :3 0 73
:3 0 3b :3 0 3a
:3 0 39 :3 0 c7f
1709 1714 1708 1715
0 174a 70 :3 0
133 :3 0 24 :3 0
c8a 1718 171a 1717
171b 0 174a 8b
:3 0 b2 :3 0 171d
171e 0 38 :2 0
171f 1720 0 174a
11 :3 0 1f :3 0
1722 1723 0 174a
8e :3 0 8f :3 0
1725 1726 0 8e
:3 0 a1 :3 0 1728
1729 0 35 :2 0
2 :4 0 1a1 :2 0
a3 :2 0 35 :2 0
c8c 172e 1730 :3 0
c8f 172a 1732 1727
1734 1733 :2 0 91
:3 0 a4 :3 0 1736
1737 0 93 :4 0
1a2 :4 0 96 :2 0
97 :3 0 c93 173b
173d :3 0 c96 1738
173f :2 0 1741 c99
1742 1735 1741 0
1743 c9b 0 174a
12 :3 0 8b :3 0
b2 :3 0 1745 1746
0 1747 :2 0 174a
159 :3 0 c9d 174b
1490 174a 0 1b84
9b :3 0 4d :3 0
38 :2 0 caf 174c
174f 9b :3 0 17a
:2 0 13 :3 0 38
:2 0 cb2 1751 1755
cb7 1752 1757 :3 0
4d :3 0 9b :3 0
13 :3 0 38 :2 0
cba 175a 175d 10b
:2 0 9b :3 0 4d
:3 0 38 :2 0 cbd
1760 1763 cc0 175f
1765 :3 0 1759 1766
0 18a1 9b :3 0
56 :3 0 38 :2 0
cc3 1768 176b fb
:3 0 bf :2 0 134
:3 0 176d 176f 0
cc8 176e 1771 :3 0
9b :3 0 56 :3 0
38 :2 0 ccb 1773
1776 fb :3 0 bf
:2 0 135 :3 0 1778
177a 0 cd0 1779
177c :3 0 1772 177e
177d :2 0 bc :3 0
36 :3 0 35 :2 0
35 :2 0 cd3 1780
1784 bf :2 0 38
:4 0 cd9 1786 1788
:3 0 1789 :2 0 11
:3 0 49 :3 0 178b
178c 0 178e cdc
1793 11 :3 0 24
:3 0 178f 1790 0
1792 cde 1794 178a
178e 0 1795 0
1792 0 1795 ce0
0 1898 70 :3 0
1a3 :3 0 11 :3 0
29 :3 0 4d :3 0
2c :3 0 ce3 1797
179c 1796 179d 0
1898 2d :4 0 179f
17a0 0 1898 1a4
:3 0 80 :4 0 17a5
:2 0 1898 17a3 17a6
:3 0 80 :3 0 2d
:4 0 17aa :2 0 1898
17a7 17a8 :3 0 80
:3 0 127 :3 0 17ab
17ac :3 0 8b :3 0
b2 :3 0 17ae 17af
0 38 :2 0 17b0
17b1 0 17b3 ce8
17ba 8b :3 0 b2
:3 0 17b4 17b5 0
129 :2 0 17b6 17b7
0 17b9 cea 17bb
17ad 17b3 0 17bc
0 17b9 0 17bc
cec 0 1898 1a5
:3 0 80 :4 0 17c0
:2 0 17c6 17be 0
8b :3 0 b2 :3 0
17c1 17c2 0 b3
:3 0 17c3 17c4 0
17c6 cef 1819 b4
:3 0 8b :3 0 b2
:3 0 17c8 17c9 0
b3 :3 0 17ca 17cb
0 17cd cf2 17cf
cf4 17ce 17cd :2 0
1817 b5 :3 0 8b
:3 0 b2 :3 0 17d2
17d3 0 b3 :3 0
17d4 17d5 0 180f
8e :3 0 8f :3 0
17d7 17d8 0 8e
:3 0 a1 :3 0 17da
17db 0 b6 :2 0
2 :4 0 1a6 :2 0
a3 :2 0 35 :2 0
cf6 17e0 17e2 :3 0
cf9 17dc 17e4 17d9
17e6 17e5 :2 0 91
:3 0 a4 :3 0 17e8
17e9 0 93 :4 0
1a7 :4 0 96 :2 0
97 :3 0 cfd 17ed
17ef :3 0 96 :2 0
b9 :4 0 d00 17f1
17f3 :3 0 96 :2 0
ba :4 0 d03 17f5
17f7 :3 0 96 :2 0
b3 :3 0 d06 17f9
17fb :3 0 96 :2 0
bb :4 0 d09 17fd
17ff :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
d0c 1802 1806 d10
1801 1808 :3 0 d13
17ea 180a :2 0 180c
d16 180d 17e7 180c
0 180e d18 0
180f d1a 1812 :3 0
1812 0 1812 1811
180f 1810 :6 0 1814
37 :3 0 d1d 1816
d1f 1815 1814 :2 0
1817 d21 :2 0 1819
0 1819 1818 17c6
1817 :6 0 1898 1
:3 0 2d :3 0 1a8
:2 0 d24 181c 181d
:3 0 181e :2 0 8e
:3 0 8f :3 0 1820
1821 0 8e :3 0
a1 :3 0 1823 1824
0 35 :2 0 2
:4 0 1a9 :2 0 a3
:2 0 35 :2 0 d26
1829 182b :3 0 d29
1825 182d 1822 182f
182e :2 0 91 :3 0
a4 :3 0 1831 1832
0 93 :4 0 1aa
:4 0 96 :2 0 97
:3 0 d2d 1836 1838
:3 0 d30 1833 183a
:2 0 183c d33 183d
1830 183c 0 183e
d35 0 1844 12
:3 0 fb :3 0 1ab
:3 0 1840 1841 0
1842 :2 0 1844 d37
1845 181f 1844 0
1846 d3a 0 1898
6f :3 0 189 :3 0
2c :3 0 27 :3 0
2d :3 0 22 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 34 :3 0
49 :3 0 36 :3 0
57 :3 0 4e :3 0
71 :3 0 73 :3 0
3a :3 0 39 :3 0
4a :3 0 9b :3 0
4b :3 0 38 :2 0
d3c 185c 185f 9b
:3 0 50 :3 0 38
:2 0 d3f 1861 1864
d42 1848 1866 1847
1867 0 1898 70
:3 0 133 :3 0 24
:3 0 d58 186a 186c
1869 186d 0 1898
11 :3 0 1f :3 0
186f 1870 0 1898
8e :3 0 8f :3 0
1872 1873 0 8e
:3 0 a1 :3 0 1875
1876 0 35 :2 0
2 :4 0 1ac :2 0
a3 :2 0 35 :2 0
d5a 187b 187d :3 0
d5d 1877 187f 1874
1881 1880 :2 0 91
:3 0 a4 :3 0 1883
1884 0 93 :4 0
1ad :4 0 96 :2 0
97 :3 0 d61 1888
188a :3 0 d64 1885
188c :2 0 188e d67
188f 1882 188e 0
1890 d69 0 1898
12 :3 0 9b :3 0
70 :3 0 38 :2 0
d6b 1892 1895 1896
:2 0 1898 d6e 189d
7d :3 0 35 :2 0
1899 189a 0 189c
d7c 189e 177f 1898
0 189f 0 189c
0 189f d7e 0
18a1 159 :3 0 d81
18a2 1758 18a1 0
1b84 9b :3 0 13
:3 0 38 :2 0 d84
18a3 18a6 bf :2 0
38 :2 0 d89 18a8
18aa :3 0 4d :3 0
38 :2 0 18ac 18ad
0 1913 7d :3 0
35 :2 0 18af 18b0
0 1913 e8 :3 0
27 :3 0 f5 :3 0
86 :3 0 48 :4 0
1ae 1 :8 0 18bd
8b :3 0 b2 :3 0
18b8 18b9 0 b3
:3 0 18ba 18bb 0
18bd d8c 1910 b4
:3 0 8b :3 0 b2
:3 0 18bf 18c0 0
b3 :3 0 18c1 18c2
0 18c4 d8f 18c6
d91 18c5 18c4 :2 0
190e b5 :3 0 8b
:3 0 b2 :3 0 18c9
18ca 0 b3 :3 0
18cb 18cc 0 1906
8e :3 0 8f :3 0
18ce 18cf 0 8e
:3 0 a1 :3 0 18d1
18d2 0 b6 :2 0
2 :4 0 1af :2 0
a3 :2 0 35 :2 0
d93 18d7 18d9 :3 0
d96 18d3 18db 18d0
18dd 18dc :2 0 91
:3 0 a4 :3 0 18df
18e0 0 93 :4 0
1b0 :4 0 96 :2 0
97 :3 0 d9a 18e4
18e6 :3 0 96 :2 0
b9 :4 0 d9d 18e8
18ea :3 0 96 :2 0
ba :4 0 da0 18ec
18ee :3 0 96 :2 0
b3 :3 0 da3 18f0
18f2 :3 0 96 :2 0
bb :4 0 da6 18f4
18f6 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
da9 18f9 18fd dad
18f8 18ff :3 0 db0
18e1 1901 :2 0 1903
db3 1904 18de 1903
0 1905 db5 0
1906 db7 1909 :3 0
1909 0 1909 1908
1906 1907 :6 0 190b
39 :3 0 dba 190d
dbc 190c 190b :2 0
190e dbe :2 0 1910
0 1910 190f 18bd
190e :6 0 1913 1
:3 0 159 :3 0 dc1
1914 18ab 1913 0
1b84 9b :3 0 4d
:3 0 38 :2 0 dc5
1915 1918 9b :3 0
105 :2 0 13 :3 0
38 :2 0 dc8 191a
191e dcd 191b 1920
:3 0 4d :3 0 9b
:3 0 4d :3 0 38
:2 0 dd0 1923 1926
10b :2 0 9b :3 0
13 :3 0 38 :2 0
dd3 1929 192c dd6
1928 192e :3 0 1922
192f 0 1b81 3c
:4 0 1931 1932 0
1b81 7a :3 0 a6
:4 0 1934 1935 0
1b81 9b :3 0 42
:3 0 38 :2 0 dd9
1937 193a bf :2 0
35 :2 0 dde 193c
193e :3 0 7a :3 0
1b1 :4 0 96 :2 0
1b2 :4 0 de1 1942
1944 :3 0 96 :2 0
24 :3 0 de4 1946
1948 :3 0 96 :2 0
1b3 :4 0 de7 194a
194c :3 0 96 :2 0
27 :3 0 dea 194e
1950 :3 0 96 :2 0
1b4 :4 0 ded 1952
1954 :3 0 96 :2 0
1b5 :4 0 df0 1956
1958 :3 0 96 :2 0
9f :3 0 9b :3 0
4d :3 0 38 :2 0
df3 195c 195f df6
195b 1961 df8 195a
1963 :3 0 1940 1964
0 196b 1a4 :3 0
8a :3 0 7a :3 0
1967 1968 0 1969
:2 0 196b dfb 1998
7a :3 0 1b1 :4 0
96 :2 0 1b2 :4 0
dfe 196e 1970 :3 0
96 :2 0 49 :3 0
e01 1972 1974 :3 0
96 :2 0 1b3 :4 0
e04 1976 1978 :3 0
96 :2 0 27 :3 0
e07 197a 197c :3 0
96 :2 0 1b4 :4 0
e0a 197e 1980 :3 0
96 :2 0 1b5 :4 0
e0d 1982 1984 :3 0
96 :2 0 9f :3 0
9b :3 0 4d :3 0
38 :2 0 e10 1988
198b e13 1987 198d
e15 1986 198f :3 0
196c 1990 0 1997
1a4 :3 0 8d :3 0
7a :3 0 1993 1994
0 1995 :2 0 1997
e18 1999 193f 196b
0 199a 0 1997
0 199a e1b 0
1b81 1b6 :3 0 9b
:3 0 42 :3 0 38
:2 0 e1e 199c 199f
bf :2 0 35 :2 0
e23 19a1 19a3 :3 0
8a :3 0 3c :4 0
19a8 :2 0 19bb 19a5
19a6 :3 0 8a :3 0
127 :3 0 19a9 19aa
:3 0 8b :3 0 b2
:3 0 19ac 19ad 0
38 :2 0 19ae 19af
0 19b1 e26 19b8
8b :3 0 b2 :3 0
19b2 19b3 0 129
:2 0 19b4 19b5 0
19b7 e28 19b9 19ab
19b1 0 19ba 0
19b7 0 19ba e2a
0 19bb e2d 19d3
8d :3 0 3c :4 0
19bf :2 0 19d2 19bc
19bd :3 0 8d :3 0
127 :3 0 19c0 19c1
:3 0 8b :3 0 b2
:3 0 19c3 19c4 0
38 :2 0 19c5 19c6
0 19c8 e30 19cf
8b :3 0 b2 :3 0
19c9 19ca 0 129
:2 0 19cb 19cc 0
19ce e32 19d0 19c2
19c8 0 19d1 0
19ce 0 19d1 e34
0 19d2 e37 19d4
19a4 19bb 0 19d5
0 19d2 0 19d5
e3a 0 19e5 8b
:3 0 b2 :3 0 19d6
19d7 0 8b :3 0
106 :2 0 132 :3 0
19d9 19db 0 e3f
19da 19dd :3 0 19de
:2 0 1b7 :8 0 19e2
e42 19e3 19df 19e2
0 19e4 e44 0
19e5 e46 19e7 1b6
:4 0 19e5 :4 0 1b81
9b :3 0 42 :3 0
38 :2 0 e49 19e8
19eb bf :2 0 35
:2 0 e4e 19ed 19ef
:3 0 1a5 :3 0 8a
:4 0 19f4 :2 0 19fa
19f2 0 8b :3 0
b2 :3 0 19f5 19f6
0 b3 :3 0 19f7
19f8 0 19fa e51
1a4d b4 :3 0 8b
:3 0 b2 :3 0 19fc
19fd 0 b3 :3 0
19fe 19ff 0 1a01
e54 1a03 e56 1a02
1a01 :2 0 1a4b b5
:3 0 8b :3 0 b2
:3 0 1a06 1a07 0
b3 :3 0 1a08 1a09
0 1a43 8e :3 0
8f :3 0 1a0b 1a0c
0 8e :3 0 a1
:3 0 1a0e 1a0f 0
b6 :2 0 2 :4 0
1b8 :2 0 a3 :2 0
35 :2 0 e58 1a14
1a16 :3 0 e5b 1a10
1a18 1a0d 1a1a 1a19
:2 0 91 :3 0 a4
:3 0 1a1c 1a1d 0
93 :4 0 1b9 :4 0
96 :2 0 97 :3 0
e5f 1a21 1a23 :3 0
96 :2 0 b9 :4 0
e62 1a25 1a27 :3 0
96 :2 0 ba :4 0
e65 1a29 1a2b :3 0
96 :2 0 b3 :3 0
e68 1a2d 1a2f :3 0
96 :2 0 bb :4 0
e6b 1a31 1a33 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 e6e 1a36
1a3a e72 1a35 1a3c
:3 0 e75 1a1e 1a3e
:2 0 1a40 e78 1a41
1a1b 1a40 0 1a42
e7a 0 1a43 e7c
1a46 :3 0 1a46 0
1a46 1a45 1a43 1a44
:6 0 1a48 3c :3 0
e7f 1a4a e81 1a49
1a48 :2 0 1a4b e83
:2 0 1a4d 0 1a4d
1a4c 19fa 1a4b :6 0
1a4f 1 :3 0 e86
1aaf 1a5 :3 0 8d
:4 0 1a53 :2 0 1a59
1a51 0 8b :3 0
b2 :3 0 1a54 1a55
0 b3 :3 0 1a56
1a57 0 1a59 e88
1aac b4 :3 0 8b
:3 0 b2 :3 0 1a5b
1a5c 0 b3 :3 0
1a5d 1a5e 0 1a60
e8b 1a62 e8d 1a61
1a60 :2 0 1aaa b5
:3 0 8b :3 0 b2
:3 0 1a65 1a66 0
b3 :3 0 1a67 1a68
0 1aa2 8e :3 0
8f :3 0 1a6a 1a6b
0 8e :3 0 a1
:3 0 1a6d 1a6e 0
b6 :2 0 2 :4 0
1ba :2 0 a3 :2 0
35 :2 0 e8f 1a73
1a75 :3 0 e92 1a6f
1a77 1a6c 1a79 1a78
:2 0 91 :3 0 a4
:3 0 1a7b 1a7c 0
93 :4 0 1bb :4 0
96 :2 0 97 :3 0
e96 1a80 1a82 :3 0
96 :2 0 b9 :4 0
e99 1a84 1a86 :3 0
96 :2 0 ba :4 0
e9c 1a88 1a8a :3 0
96 :2 0 b3 :3 0
e9f 1a8c 1a8e :3 0
96 :2 0 bb :4 0
ea2 1a90 1a92 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 ea5 1a95
1a99 ea9 1a94 1a9b
:3 0 eac 1a7d 1a9d
:2 0 1a9f eaf 1aa0
1a7a 1a9f 0 1aa1
eb1 0 1aa2 eb3
1aa5 :3 0 1aa5 0
1aa5 1aa4 1aa2 1aa3
:6 0 1aa7 3e :3 0
eb6 1aa9 eb8 1aa8
1aa7 :2 0 1aaa eba
:2 0 1aac 0 1aac
1aab 1a59 1aaa :6 0
1aae 1 :3 0 ebd
1ab0 19f0 1a4f 0
1ab1 0 1aae 0
1ab1 ebf 0 1b81
3c :3 0 1a8 :2 0
ec2 1ab3 1ab4 :3 0
1ab5 :2 0 9b :3 0
42 :3 0 38 :2 0
ec4 1ab7 1aba bf
:2 0 35 :2 0 ec9
1abc 1abe :3 0 11
:3 0 24 :3 0 1ac0
1ac1 0 1ae7 8e
:3 0 8f :3 0 1ac3
1ac4 0 8e :3 0
a1 :3 0 1ac6 1ac7
0 35 :2 0 2
:4 0 1bc :2 0 a3
:2 0 35 :2 0 ecc
1acc 1ace :3 0 ecf
1ac8 1ad0 1ac5 1ad2
1ad1 :2 0 91 :3 0
a4 :3 0 1ad4 1ad5
0 93 :4 0 1bd
:4 0 96 :2 0 97
:3 0 ed3 1ad9 1adb
:3 0 ed6 1ad6 1add
:2 0 1adf ed9 1ae0
1ad3 1adf 0 1ae1
edb 0 1ae7 12
:3 0 fb :3 0 fc
:3 0 1ae3 1ae4 0
1ae5 :2 0 1ae7 edd
1b10 11 :3 0 49
:3 0 1ae8 1ae9 0
1b0f 8e :3 0 8f
:3 0 1aeb 1aec 0
8e :3 0 a1 :3 0
1aee 1aef 0 35
:2 0 2 :4 0 1be
:2 0 a3 :2 0 35
:2 0 ee1 1af4 1af6
:3 0 ee4 1af0 1af8
1aed 1afa 1af9 :2 0
91 :3 0 a4 :3 0
1afc 1afd 0 93
:4 0 1bf :4 0 96
:2 0 97 :3 0 ee8
1b01 1b03 :3 0 eeb
1afe 1b05 :2 0 1b07
eee 1b08 1afb 1b07
0 1b09 ef0 0
1b0f 12 :3 0 fb
:3 0 fc :3 0 1b0b
1b0c 0 1b0d :2 0
1b0f ef2 1b11 1abf
1ae7 0 1b12 0
1b0f 0 1b12 ef6
0 1b13 ef9 1b14
1ab6 1b13 0 1b15
efb 0 1b81 102
:3 0 10f :3 0 d3
:3 0 bc :3 0 3c
:3 0 102 :3 0 110
:3 0 27 :3 0 27
:3 0 117 :4 0 1c0
1 :8 0 1b26 8b
:3 0 b2 :3 0 1b21
1b22 0 b3 :3 0
1b23 1b24 0 1b26
efd 1b79 b4 :3 0
8b :3 0 b2 :3 0
1b28 1b29 0 b3
:3 0 1b2a 1b2b 0
1b2d f00 1b2f f02
1b2e 1b2d :2 0 1b77
b5 :3 0 8b :3 0
b2 :3 0 1b32 1b33
0 b3 :3 0 1b34
1b35 0 1b6f 8e
:3 0 8f :3 0 1b37
1b38 0 8e :3 0
a1 :3 0 1b3a 1b3b
0 b6 :2 0 2
:4 0 1c1 :2 0 a3
:2 0 35 :2 0 f04
1b40 1b42 :3 0 f07
1b3c 1b44 1b39 1b46
1b45 :2 0 91 :3 0
a4 :3 0 1b48 1b49
0 93 :4 0 1c2
:4 0 96 :2 0 97
:3 0 f0b 1b4d 1b4f
:3 0 96 :2 0 b9
:4 0 f0e 1b51 1b53
:3 0 96 :2 0 ba
:4 0 f11 1b55 1b57
:3 0 96 :2 0 b3
:3 0 f14 1b59 1b5b
:3 0 96 :2 0 bb
:4 0 f17 1b5d 1b5f
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 f1a
1b62 1b66 f1e 1b61
1b68 :3 0 f21 1b4a
1b6a :2 0 1b6c f24
1b6d 1b47 1b6c 0
1b6e f26 0 1b6f
f28 1b72 :3 0 1b72
0 1b72 1b71 1b6f
1b70 :6 0 1b74 40
:3 0 f2b 1b76 f2d
1b75 1b74 :2 0 1b77
f2f :2 0 1b79 0
1b79 1b78 1b26 1b77
:6 0 1b81 1 :3 0
4d :3 0 38 :2 0
1b7b 1b7c 0 1b81
7d :3 0 35 :2 0
1b7e 1b7f 0 1b81
f32 1b82 1921 1b81
0 1b84 1334 1484
0 1b84 f3d 0
1b86 159 :3 0 f43
1f79 9b :3 0 14
:3 0 38 :2 0 f45
1b87 1b8a 9b :3 0
106 :2 0 4e :3 0
38 :2 0 f48 1b8c
1b90 f4d 1b8d 1b92
:3 0 9b :3 0 67
:3 0 38 :2 0 f50
1b94 1b97 105 :2 0
38 :2 0 f55 1b99
1b9b :3 0 9b :3 0
14 :3 0 38 :2 0
f58 1b9d 1ba0 9b
:3 0 105 :2 0 67
:3 0 38 :2 0 f5b
1ba2 1ba6 f60 1ba3
1ba8 :3 0 1b9c 1baa
1ba9 :2 0 11 :3 0
22 :3 0 1bac 1bad
0 1bd3 8e :3 0
8f :3 0 1baf 1bb0
0 8e :3 0 a1
:3 0 1bb2 1bb3 0
35 :2 0 2 :4 0
1c3 :2 0 a3 :2 0
35 :2 0 f63 1bb8
1bba :3 0 f66 1bb4
1bbc 1bb1 1bbe 1bbd
:2 0 91 :3 0 a4
:3 0 1bc0 1bc1 0
93 :4 0 1c4 :4 0
96 :2 0 97 :3 0
f6a 1bc5 1bc7 :3 0
f6d 1bc2 1bc9 :2 0
1bcb f70 1bcc 1bbf
1bcb 0 1bcd f72
0 1bd3 12 :3 0
fb :3 0 155 :3 0
1bcf 1bd0 0 1bd1
:2 0 1bd3 f74 1bd4
1bab 1bd3 0 1bd5
f78 0 1f77 9b
:3 0 50 :3 0 38
:2 0 f7a 1bd6 1bd9
9b :3 0 bf :2 0
4b :3 0 38 :2 0
f7d 1bdb 1bdf f82
1bdc 1be1 :3 0 11
:3 0 21 :3 0 1be3
1be4 0 1c0a 8e
:3 0 8f :3 0 1be6
1be7 0 8e :3 0
a1 :3 0 1be9 1bea
0 35 :2 0 2
:4 0 1c5 :2 0 a3
:2 0 35 :2 0 f85
1bef 1bf1 :3 0 f88
1beb 1bf3 1be8 1bf5
1bf4 :2 0 91 :3 0
a4 :3 0 1bf7 1bf8
0 93 :4 0 1c6
:4 0 96 :2 0 97
:3 0 f8c 1bfc 1bfe
:3 0 f8f 1bf9 1c00
:2 0 1c02 f92 1c03
1bf6 1c02 0 1c04
f94 0 1c0a 12
:3 0 8b :3 0 b2
:3 0 1c06 1c07 0
1c08 :2 0 1c0a f96
1c0b 1be2 1c0a 0
1c0c f9a 0 1f77
9b :3 0 14 :3 0
38 :2 0 f9c 1c0d
1c10 bf :2 0 38
:2 0 fa1 1c12 1c14
:3 0 4e :3 0 129
:2 0 1c16 1c17 0
1c19 fa4 1c62 9b
:3 0 14 :3 0 38
:2 0 fa6 1c1a 1c1d
17a :2 0 35 :2 0
fab 1c1f 1c21 :3 0
1c22 :2 0 9b :3 0
14 :3 0 38 :2 0
fae 1c24 1c27 105
:2 0 1c7 :2 0 fb3
1c29 1c2b :3 0 1c2c
:2 0 1c23 1c2e 1c2d
:2 0 11 :3 0 21
:3 0 1c30 1c31 0
1c57 8e :3 0 8f
:3 0 1c33 1c34 0
8e :3 0 a1 :3 0
1c36 1c37 0 35
:2 0 2 :4 0 1c8
:2 0 a3 :2 0 35
:2 0 fb6 1c3c 1c3e
:3 0 fb9 1c38 1c40
1c35 1c42 1c41 :2 0
91 :3 0 a4 :3 0
1c44 1c45 0 93
:4 0 1c9 :4 0 96
:2 0 97 :3 0 fbd
1c49 1c4b :3 0 fc0
1c46 1c4d :2 0 1c4f
fc3 1c50 1c43 1c4f
0 1c51 fc5 0
1c57 12 :3 0 fb
:3 0 1ca :3 0 1c53
1c54 0 1c55 :2 0
1c57 fc7 1c58 1c2f
1c57 0 1c59 fcb
0 1c61 4e :3 0
9b :3 0 14 :3 0
38 :2 0 fcd 1c5b
1c5e 1c5a 1c5f 0
1c61 fd0 1c63 1c15
1c19 0 1c64 0
1c61 0 1c64 fd3
0 1f77 63 :3 0
1cb :3 0 9b :3 0
57 :3 0 38 :2 0
fd6 1c67 1c6a 1cc
:2 0 9b :3 0 4e
:3 0 38 :2 0 fd9
1c6d 1c70 fdc 1c6c
1c72 :3 0 1c73 :2 0
1cd :2 0 1ce :2 0
fdf 1c75 1c77 :3 0
1c78 :2 0 a3 :2 0
1cf :2 0 fe2 1c7a
1c7c :3 0 fe5 1c66
1c7e 1c65 1c7f 0
1f77 9b :3 0 63
:3 0 38 :2 0 fe7
1c81 1c84 9b :3 0
105 :2 0 4b :3 0
38 :2 0 fea 1c86
1c8a fef 1c87 1c8c
:3 0 70 :3 0 38
:2 0 1c8e 1c8f 0
1d24 136 :3 0 70
:3 0 13e :3 0 ae
:3 0 24 :3 0 e2
:3 0 21 :4 0 1d0
1 :8 0 1c9e 8b
:3 0 b2 :3 0 1c99
1c9a 0 b3 :3 0
1c9b 1c9c 0 1c9e
ff2 1cf1 b4 :3 0
8b :3 0 b2 :3 0
1ca0 1ca1 0 b3
:3 0 1ca2 1ca3 0
1ca5 ff5 1ca7 ff7
1ca6 1ca5 :2 0 1cef
b5 :3 0 8b :3 0
b2 :3 0 1caa 1cab
0 b3 :3 0 1cac
1cad 0 1ce7 8e
:3 0 8f :3 0 1caf
1cb0 0 8e :3 0
a1 :3 0 1cb2 1cb3
0 b6 :2 0 2
:4 0 1d1 :2 0 a3
:2 0 35 :2 0 ff9
1cb8 1cba :3 0 ffc
1cb4 1cbc 1cb1 1cbe
1cbd :2 0 91 :3 0
a4 :3 0 1cc0 1cc1
0 93 :4 0 1d2
:4 0 96 :2 0 97
:3 0 1000 1cc5 1cc7
:3 0 96 :2 0 b9
:4 0 1003 1cc9 1ccb
:3 0 96 :2 0 ba
:4 0 1006 1ccd 1ccf
:3 0 96 :2 0 b3
:3 0 1009 1cd1 1cd3
:3 0 96 :2 0 bb
:4 0 100c 1cd5 1cd7
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 100f
1cda 1cde 1013 1cd9
1ce0 :3 0 1016 1cc2
1ce2 :2 0 1ce4 1019
1ce5 1cbf 1ce4 0
1ce6 101b 0 1ce7
101d 1cea :3 0 1cea
0 1cea 1ce9 1ce7
1ce8 :6 0 1cec 42
:3 0 1020 1cee 1022
1ced 1cec :2 0 1cef
1024 :2 0 1cf1 0
1cf1 1cf0 1c9e 1cef
:6 0 1d24 1 :3 0
9b :3 0 70 :3 0
38 :2 0 1027 1cf3
1cf6 bf :2 0 35
:2 0 102c 1cf8 1cfa
:3 0 11 :3 0 21
:3 0 1cfc 1cfd 0
1d21 8e :3 0 8f
:3 0 1cff 1d00 0
8e :3 0 a1 :3 0
1d02 1d03 0 35
:2 0 2 :4 0 1d3
:2 0 a3 :2 0 35
:2 0 102f 1d08 1d0a
:3 0 1032 1d04 1d0c
1d01 1d0e 1d0d :2 0
91 :3 0 a4 :3 0
1d10 1d11 0 93
:4 0 1d4 :4 0 96
:2 0 97 :3 0 1036
1d15 1d17 :3 0 1039
1d12 1d19 :2 0 1d1b
103c 1d1c 1d0f 1d1b
0 1d1d 103e 0
1d21 12 :3 0 38
:2 0 1d1f :2 0 1d21
1040 1d22 1cfb 1d21
0 1d23 1044 0
1d24 1046 1d25 1c8d
1d24 0 1d26 104a
0 1f77 9b :3 0
56 :3 0 38 :2 0
104c 1d27 1d2a fb
:3 0 bf :2 0 134
:3 0 1d2c 1d2e 0
1051 1d2d 1d30 :3 0
9b :3 0 56 :3 0
38 :2 0 1054 1d32
1d35 fb :3 0 bf
:2 0 135 :3 0 1d37
1d39 0 1059 1d38
1d3b :3 0 1d31 1d3d
1d3c :2 0 3b :3 0
10b :2 0 35 :2 0
105c 1d40 1d42 :3 0
1d3f 1d43 0 1ebf
6f :3 0 190 :3 0
24 :3 0 48 :3 0
21 :3 0 30 :3 0
32 :3 0 71 :3 0
73 :3 0 3b :3 0
3a :3 0 39 :3 0
105e 1d46 1d51 1d45
1d52 0 1ebf 9b
:3 0 53 :3 0 38
:2 0 1069 1d54 1d57
105 :2 0 38 :2 0
106e 1d59 1d5b :3 0
1d5c :2 0 3d :3 0
10a :2 0 1071 1d5f
1d60 :3 0 1d61 :2 0
1d62 :2 0 1d5d 1d64
1d63 :2 0 102 :3 0
10f :3 0 d3 :3 0
bc :3 0 3d :3 0
102 :3 0 110 :3 0
27 :3 0 27 :3 0
117 :4 0 1d5 1
:8 0 1d76 8b :3 0
b2 :3 0 1d71 1d72
0 b3 :3 0 1d73
1d74 0 1d76 1073
1dc9 b4 :3 0 8b
:3 0 b2 :3 0 1d78
1d79 0 b3 :3 0
1d7a 1d7b 0 1d7d
1076 1d7f 1078 1d7e
1d7d :2 0 1dc7 b5
:3 0 8b :3 0 b2
:3 0 1d82 1d83 0
b3 :3 0 1d84 1d85
0 1dbf 8e :3 0
8f :3 0 1d87 1d88
0 8e :3 0 a1
:3 0 1d8a 1d8b 0
b6 :2 0 2 :4 0
1d6 :2 0 a3 :2 0
35 :2 0 107a 1d90
1d92 :3 0 107d 1d8c
1d94 1d89 1d96 1d95
:2 0 91 :3 0 a4
:3 0 1d98 1d99 0
93 :4 0 1d7 :4 0
96 :2 0 97 :3 0
1081 1d9d 1d9f :3 0
96 :2 0 b9 :4 0
1084 1da1 1da3 :3 0
96 :2 0 ba :4 0
1087 1da5 1da7 :3 0
96 :2 0 b3 :3 0
108a 1da9 1dab :3 0
96 :2 0 bb :4 0
108d 1dad 1daf :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 1090 1db2
1db6 1094 1db1 1db8
:3 0 1097 1d9a 1dba
:2 0 1dbc 109a 1dbd
1d97 1dbc 0 1dbe
109c 0 1dbf 109e
1dc2 :3 0 1dc2 0
1dc2 1dc1 1dbf 1dc0
:6 0 1dc4 44 :3 0
10a1 1dc6 10a3 1dc5
1dc4 :2 0 1dc7 10a5
:2 0 1dc9 0 1dc9
1dc8 1d76 1dc7 :6 0
1dcb 1 :3 0 10a8
1dcc 1d65 1dcb 0
1dcd 10aa 0 1ebf
54 :3 0 1cb :3 0
9b :3 0 4e :3 0
38 :2 0 10ac 1dd0
1dd3 1cc :2 0 9b
:3 0 57 :3 0 38
:2 0 10af 1dd6 1dd9
10b2 1dd5 1ddb :3 0
1ddc :2 0 1cd :2 0
1ce :2 0 10b5 1dde
1de0 :3 0 1de1 :2 0
a3 :2 0 1d8 :2 0
10b8 1de3 1de5 :3 0
10bb 1dcf 1de7 1dce
1de8 0 1ebf 70
:3 0 1d9 :3 0 24
:3 0 22 :3 0 21
:3 0 27 :3 0 28
:3 0 54 :3 0 54
:3 0 38 :2 0 10bd
1deb 1df4 1dea 1df5
0 1ebf 70 :3 0
1da :3 0 1db :3 0
1df8 1df9 0 9b
:3 0 4e :3 0 38
:2 0 10c6 1dfb 1dfe
fb :3 0 1dc :3 0
1e00 1e01 0 10c9
1dfa 1e03 1df7 1e04
0 1ebf 70 :3 0
1dd :3 0 24 :3 0
21 :3 0 70 :3 0
38 :2 0 38 :2 0
10cc 1e07 1e0d 1e06
1e0e 0 1ebf d3
:3 0 bc :3 0 27
:3 0 d3 :3 0 bc
:3 0 2a :3 0 d4
:3 0 d5 :3 0 d6
:3 0 d8 :3 0 30
:3 0 32 :3 0 39
:3 0 3a :3 0 71
:3 0 73 :3 0 e1
:3 0 e2 :3 0 21
:4 0 19e 1 :8 0
1e29 8b :3 0 b2
:3 0 1e24 1e25 0
b3 :3 0 1e26 1e27
0 1e29 10d2 1e7c
b4 :3 0 8b :3 0
b2 :3 0 1e2b 1e2c
0 b3 :3 0 1e2d
1e2e 0 1e30 10d5
1e32 10d7 1e31 1e30
:2 0 1e7a b5 :3 0
8b :3 0 b2 :3 0
1e35 1e36 0 b3
:3 0 1e37 1e38 0
1e72 8e :3 0 8f
:3 0 1e3a 1e3b 0
8e :3 0 a1 :3 0
1e3d 1e3e 0 b6
:2 0 2 :4 0 1de
:2 0 a3 :2 0 35
:2 0 10d9 1e43 1e45
:3 0 10dc 1e3f 1e47
1e3c 1e49 1e48 :2 0
91 :3 0 a4 :3 0
1e4b 1e4c 0 93
:4 0 1df :4 0 96
:2 0 97 :3 0 10e0
1e50 1e52 :3 0 96
:2 0 b9 :4 0 10e3
1e54 1e56 :3 0 96
:2 0 ba :4 0 10e6
1e58 1e5a :3 0 96
:2 0 b3 :3 0 10e9
1e5c 1e5e :3 0 96
:2 0 bb :4 0 10ec
1e60 1e62 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 10ef 1e65 1e69
10f3 1e64 1e6b :3 0
10f6 1e4d 1e6d :2 0
1e6f 10f9 1e70 1e4a
1e6f 0 1e71 10fb
0 1e72 10fd 1e75
:3 0 1e75 0 1e75
1e74 1e72 1e73 :6 0
1e77 46 :3 0 1100
1e79 1102 1e78 1e77
:2 0 1e7a 1104 :2 0
1e7c 0 1e7c 1e7b
1e29 1e7a :6 0 1ebf
1 :3 0 3b :3 0
38 :2 0 1e7e 1e7f
0 1ebf 70 :3 0
190 :3 0 24 :3 0
48 :3 0 21 :3 0
30 :3 0 32 :3 0
71 :3 0 73 :3 0
3b :3 0 3a :3 0
39 :3 0 1107 1e82
1e8d 1e81 1e8e 0
1ebf 70 :3 0 133
:3 0 24 :3 0 1112
1e91 1e93 1e90 1e94
0 1ebf 11 :3 0
21 :3 0 1e96 1e97
0 1ebf 8e :3 0
8f :3 0 1e99 1e9a
0 8e :3 0 a1
:3 0 1e9c 1e9d 0
35 :2 0 2 :4 0
1e0 :2 0 a3 :2 0
35 :2 0 1114 1ea2
1ea4 :3 0 1117 1e9e
1ea6 1e9b 1ea8 1ea7
:2 0 91 :3 0 a4
:3 0 1eaa 1eab 0
93 :4 0 1e1 :4 0
96 :2 0 97 :3 0
111b 1eaf 1eb1 :3 0
111e 1eac 1eb3 :2 0
1eb5 1121 1eb6 1ea9
1eb5 0 1eb7 1123
0 1ebf 12 :3 0
9b :3 0 70 :3 0
38 :2 0 1125 1eb9
1ebc 1ebd :2 0 1ebf
1128 1f74 4d :3 0
38 :2 0 1ec0 1ec1
0 1f73 7d :3 0
192 :2 0 1ec3 1ec4
0 1f73 9b :3 0
5b :3 0 38 :2 0
1137 1ec6 1ec9 17a
:2 0 1e2 :2 0 113c
1ecb 1ecd :3 0 5b
:3 0 35 :2 0 1ecf
1ed0 0 1ed2 113f
1ed3 1ece 1ed2 0
1ed4 1141 0 1f73
61 :3 0 1da :3 0
1db :3 0 1ed6 1ed7
0 1da :3 0 1db
:3 0 1ed9 1eda 0
fb :3 0 1e3 :3 0
1edc 1edd 0 fb
:3 0 1e4 :3 0 1edf
1ee0 0 1143 1edb
1ee2 fb :3 0 1e5
:3 0 1ee4 1ee5 0
1146 1ed8 1ee7 1ed5
1ee8 0 1f73 e1
:3 0 1e6 :3 0 ca
:3 0 4e :3 0 c5
:3 0 c7 :3 0 c4
:3 0 c8 :3 0 e0
:3 0 111 :3 0 1db
:3 0 e0 :3 0 61
:3 0 e2 :3 0 21
:4 0 1e7 1 :8 0
1f0f 127 :4 0 1efa
:3 0 128 :3 0 bf
:2 0 114b 1efd 1efe
:3 0 8b :3 0 b2
:3 0 1f00 1f01 0
38 :2 0 1f02 1f03
0 1f05 114e 1f0c
8b :3 0 b2 :3 0
1f06 1f07 0 129
:2 0 1f08 1f09 0
1f0b 1150 1f0d 1eff
1f05 0 1f0e 0
1f0b 0 1f0e 1152
0 1f0f 1155 1f62
b4 :3 0 8b :3 0
b2 :3 0 1f11 1f12
0 b3 :3 0 1f13
1f14 0 1f16 1158
1f18 115a 1f17 1f16
:2 0 1f60 b5 :3 0
8b :3 0 b2 :3 0
1f1b 1f1c 0 b3
:3 0 1f1d 1f1e 0
1f58 8e :3 0 8f
:3 0 1f20 1f21 0
8e :3 0 a1 :3 0
1f23 1f24 0 b6
:2 0 2 :4 0 1e8
:2 0 a3 :2 0 35
:2 0 115c 1f29 1f2b
:3 0 115f 1f25 1f2d
1f22 1f2f 1f2e :2 0
91 :3 0 a4 :3 0
1f31 1f32 0 93
:4 0 1e9 :4 0 96
:2 0 97 :3 0 1163
1f36 1f38 :3 0 96
:2 0 b9 :4 0 1166
1f3a 1f3c :3 0 96
:2 0 ba :4 0 1169
1f3e 1f40 :3 0 96
:2 0 b3 :3 0 116c
1f42 1f44 :3 0 96
:2 0 bb :4 0 116f
1f46 1f48 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 1172 1f4b 1f4f
1176 1f4a 1f51 :3 0
1179 1f33 1f53 :2 0
1f55 117c 1f56 1f30
1f55 0 1f57 117e
0 1f58 1180 1f5b
:3 0 1f5b 0 1f5b
1f5a 1f58 1f59 :6 0
1f5d 48 :3 0 1183
1f5f 1185 1f5e 1f5d
:2 0 1f60 1187 :2 0
1f62 0 1f62 1f61
1f0f 1f60 :6 0 1f73
1 :3 0 9b :3 0
4c :3 0 38 :2 0
118a 1f64 1f67 106
:2 0 38 :2 0 118f
1f69 1f6b :3 0 4c
:3 0 38 :2 0 1f6d
1f6e 0 1f70 1192
1f71 1f6c 1f70 0
1f72 1194 0 1f73
1196 1f75 1d3e 1ebf
0 1f76 0 1f73
0 1f76 119d 0
1f77 11a0 1f78 1b93
1f77 0 1f7a 1328
1b86 0 1f7a 11a7
0 2896 7d :3 0
105 :2 0 38 :2 0
11ac 1f7c 1f7e :3 0
3b :3 0 10b :2 0
35 :2 0 11af 1f81
1f83 :3 0 1f80 1f84
0 21ef 6f :3 0
190 :3 0 24 :3 0
48 :3 0 21 :3 0
30 :3 0 32 :3 0
71 :3 0 73 :3 0
3b :3 0 3a :3 0
39 :3 0 11b1 1f87
1f92 1f86 1f93 0
21ef 9b :3 0 53
:3 0 38 :2 0 11bc
1f95 1f98 105 :2 0
38 :2 0 11c1 1f9a
1f9c :3 0 1f9d :2 0
3d :3 0 10a :2 0
11c4 1fa0 1fa1 :3 0
1fa2 :2 0 1fa3 :2 0
1f9e 1fa5 1fa4 :2 0
70 :3 0 191 :3 0
24 :3 0 48 :3 0
49 :3 0 22 :3 0
21 :3 0 3d :3 0
53 :3 0 38 :2 0
11c6 1fa8 1fb1 1fa7
1fb2 0 1fb4 11cf
1fb5 1fa6 1fb4 0
1fb6 11d1 0 21ef
22 :3 0 10a :2 0
11d3 1fb8 1fb9 :3 0
1fba :2 0 6f :3 0
1ea :3 0 24 :3 0
21 :3 0 192 :2 0
11d5 1fbd 1fc1 1fbc
1fc2 0 1fc4 11d9
1fe5 bc :3 0 34
:3 0 35 :2 0 35
:2 0 11db 1fc5 1fc9
bf :2 0 192 :4 0
11e1 1fcb 1fcd :3 0
6f :3 0 1ea :3 0
24 :3 0 21 :3 0
38 :2 0 11e4 1fd0
1fd4 1fcf 1fd5 0
1fd7 11e8 1fe1 6f
:3 0 1ea :3 0 24
:3 0 21 :3 0 35
:2 0 11ea 1fd9 1fdd
1fd8 1fde 0 1fe0
11ee 1fe2 1fce 1fd7
0 1fe3 0 1fe0
0 1fe3 11f0 0
1fe4 11f3 1fe6 1fbb
1fc4 0 1fe7 0
1fe4 0 1fe7 11f5
0 21ef 3d :3 0
10a :2 0 11f8 1fe9
1fea :3 0 1feb :2 0
9b :3 0 4c :3 0
38 :2 0 11fa 1fed
1ff0 105 :2 0 38
:2 0 11ff 1ff2 1ff4
:3 0 4c :3 0 1da
:3 0 1db :3 0 1ff7
1ff8 0 9b :3 0
4c :3 0 38 :2 0
1202 1ffa 1ffd fb
:3 0 1eb :3 0 1fff
2000 0 1205 1ff9
2002 2003 :2 0 1ff6
2004 0 206b 102
:3 0 10f :3 0 d3
:3 0 bc :3 0 3d
:3 0 102 :3 0 110
:3 0 27 :3 0 27
:3 0 117 :4 0 1d5
1 :8 0 2016 8b
:3 0 b2 :3 0 2011
2012 0 b3 :3 0
2013 2014 0 2016
1208 2069 b4 :3 0
8b :3 0 b2 :3 0
2018 2019 0 b3
:3 0 201a 201b 0
201d 120b 201f 120d
201e 201d :2 0 2067
b5 :3 0 8b :3 0
b2 :3 0 2022 2023
0 b3 :3 0 2024
2025 0 205f 8e
:3 0 8f :3 0 2027
2028 0 8e :3 0
a1 :3 0 202a 202b
0 b6 :2 0 2
:4 0 1ec :2 0 a3
:2 0 35 :2 0 120f
2030 2032 :3 0 1212
202c 2034 2029 2036
2035 :2 0 91 :3 0
a4 :3 0 2038 2039
0 93 :4 0 1ed
:4 0 96 :2 0 97
:3 0 1216 203d 203f
:3 0 96 :2 0 b9
:4 0 1219 2041 2043
:3 0 96 :2 0 ba
:4 0 121c 2045 2047
:3 0 96 :2 0 b3
:3 0 121f 2049 204b
:3 0 96 :2 0 bb
:4 0 1222 204d 204f
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 1225
2052 2056 1229 2051
2058 :3 0 122c 203a
205a :2 0 205c 122f
205d 2037 205c 0
205e 1231 0 205f
1233 2062 :3 0 2062
0 2062 2061 205f
2060 :6 0 2064 4a
:3 0 1236 2066 1238
2065 2064 :2 0 2067
123a :2 0 2069 0
2069 2068 2016 2067
:6 0 206b 1 :3 0
123d 20d2 102 :3 0
10f :3 0 d3 :3 0
bc :3 0 3d :3 0
102 :3 0 110 :3 0
27 :3 0 27 :3 0
117 :4 0 1ee 1
:8 0 207c 8b :3 0
b2 :3 0 2077 2078
0 b3 :3 0 2079
207a 0 207c 1240
20cf b4 :3 0 8b
:3 0 b2 :3 0 207e
207f 0 b3 :3 0
2080 2081 0 2083
1243 2085 1245 2084
2083 :2 0 20cd b5
:3 0 8b :3 0 b2
:3 0 2088 2089 0
b3 :3 0 208a 208b
0 20c5 8e :3 0
8f :3 0 208d 208e
0 8e :3 0 a1
:3 0 2090 2091 0
b6 :2 0 2 :4 0
1ef :2 0 a3 :2 0
35 :2 0 1247 2096
2098 :3 0 124a 2092
209a 208f 209c 209b
:2 0 91 :3 0 a4
:3 0 209e 209f 0
93 :4 0 1f0 :4 0
96 :2 0 97 :3 0
124e 20a3 20a5 :3 0
96 :2 0 b9 :4 0
1251 20a7 20a9 :3 0
96 :2 0 ba :4 0
1254 20ab 20ad :3 0
96 :2 0 b3 :3 0
1257 20af 20b1 :3 0
96 :2 0 bb :4 0
125a 20b3 20b5 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 125d 20b8
20bc 1261 20b7 20be
:3 0 1264 20a0 20c0
:2 0 20c2 1267 20c3
209d 20c2 0 20c4
1269 0 20c5 126b
20c8 :3 0 20c8 0
20c8 20c7 20c5 20c6
:6 0 20ca 4c :3 0
126e 20cc 1270 20cb
20ca :2 0 20cd 1272
:2 0 20cf 0 20cf
20ce 207c 20cd :6 0
20d1 1 :3 0 1275
20d3 1ff5 206b 0
20d4 0 20d1 0
20d4 1277 0 20e4
4b :3 0 9b :3 0
4b :3 0 38 :2 0
127a 20d6 20d9 10b
:2 0 9b :3 0 50
:3 0 38 :2 0 127d
20dc 20df 1280 20db
20e1 :3 0 20d5 20e2
0 20e4 1283 20e5
1fec 20e4 0 20e6
1286 0 21ef 6e
:3 0 192 :2 0 20e7
20e8 0 21ef 6f
:3 0 1f1 :3 0 21
:3 0 27 :3 0 4b
:3 0 6e :3 0 4c
:3 0 4a :3 0 9b
:3 0 4d :3 0 38
:2 0 1288 20f2 20f5
9b :3 0 4e :3 0
38 :2 0 128b 20f7
20fa 128e 20eb 20fc
20ea 20fd 0 21ef
9b :3 0 6f :3 0
38 :2 0 1297 20ff
2102 106 :2 0 38
:2 0 129c 2104 2106
:3 0 11 :3 0 21
:3 0 2108 2109 0
2130 8e :3 0 8f
:3 0 210b 210c 0
8e :3 0 a1 :3 0
210e 210f 0 35
:2 0 2 :4 0 1f2
:2 0 a3 :2 0 35
:2 0 129f 2114 2116
:3 0 12a2 2110 2118
210d 211a 2119 :2 0
91 :3 0 a4 :3 0
211c 211d 0 93
:4 0 1f3 :4 0 96
:2 0 97 :3 0 12a6
2121 2123 :3 0 12a9
211e 2125 :2 0 2127
12ac 2128 211b 2127
0 2129 12ae 0
2130 12 :3 0 fb
:3 0 155 :3 0 212b
212c 0 212d :2 0
2130 159 :3 0 12b0
21be 7d :3 0 bf
:2 0 35 :2 0 12b6
2132 2134 :3 0 e1
:3 0 1f4 :3 0 e2
:3 0 21 :4 0 1f5
1 :8 0 21bc e1
:3 0 1e6 :3 0 e0
:3 0 111 :3 0 1db
:3 0 e0 :3 0 fb
:3 0 1e3 :3 0 fb
:3 0 1e4 :3 0 1f6
:3 0 9b :3 0 123
:3 0 12c :3 0 1f7
:3 0 9b :3 0 124
:3 0 12d :3 0 1f4
:3 0 1f8 :3 0 e2
:3 0 21 :4 0 1f9
1 :8 0 2167 127
:4 0 2152 :3 0 128
:3 0 bf :2 0 12bb
2155 2156 :3 0 8b
:3 0 b2 :3 0 2158
2159 0 38 :2 0
215a 215b 0 215d
12be 2164 8b :3 0
b2 :3 0 215e 215f
0 129 :2 0 2160
2161 0 2163 12c0
2165 2157 215d 0
2166 0 2163 0
2166 12c2 0 2167
12c5 21ba b4 :3 0
8b :3 0 b2 :3 0
2169 216a 0 b3
:3 0 216b 216c 0
216e 12c8 2170 12ca
216f 216e :2 0 21b8
b5 :3 0 8b :3 0
b2 :3 0 2173 2174
0 b3 :3 0 2175
2176 0 21b0 8e
:3 0 8f :3 0 2178
2179 0 8e :3 0
a1 :3 0 217b 217c
0 b6 :2 0 2
:4 0 1fa :2 0 a3
:2 0 35 :2 0 12cc
2181 2183 :3 0 12cf
217d 2185 217a 2187
2186 :2 0 91 :3 0
a4 :3 0 2189 218a
0 93 :4 0 1fb
:4 0 96 :2 0 97
:3 0 12d3 218e 2190
:3 0 96 :2 0 b9
:4 0 12d6 2192 2194
:3 0 96 :2 0 ba
:4 0 12d9 2196 2198
:3 0 96 :2 0 b3
:3 0 12dc 219a 219c
:3 0 96 :2 0 bb
:4 0 12df 219e 21a0
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 12e2
21a3 21a7 12e6 21a2
21a9 :3 0 12e9 218b
21ab :2 0 21ad 12ec
21ae 2188 21ad 0
21af 12ee 0 21b0
12f0 21b3 :3 0 21b3
0 21b3 21b2 21b0
21b1 :6 0 21b5 4e
:3 0 12f3 21b7 12f5
21b6 21b5 :2 0 21b8
12f7 :2 0 21ba 0
21ba 21b9 2167 21b8
:6 0 21bc 1 :3 0
12fa 21bd 2135 21bc
0 21bf 2107 2130
0 21bf 12fd 0
21ef 70 :3 0 133
:3 0 24 :3 0 1300
21c1 21c3 21c0 21c4
0 21ef 11 :3 0
21 :3 0 21c6 21c7
0 21ef 8e :3 0
8f :3 0 21c9 21ca
0 8e :3 0 a1
:3 0 21cc 21cd 0
35 :2 0 2 :4 0
1fc :2 0 a3 :2 0
35 :2 0 1302 21d2
21d4 :3 0 1305 21ce
21d6 21cb 21d8 21d7
:2 0 91 :3 0 a4
:3 0 21da 21db 0
93 :4 0 1fd :4 0
96 :2 0 97 :3 0
1309 21df 21e1 :3 0
130c 21dc 21e3 :2 0
21e5 130f 21e6 21d9
21e5 0 21e7 1311
0 21ef 12 :3 0
9b :3 0 70 :3 0
38 :2 0 1313 21e9
21ec 21ed :2 0 21ef
1316 21f0 1f7f 21ef
0 21f1 1323 0
2896 9b :3 0 16
:3 0 38 :2 0 1325
21f2 21f5 9b :3 0
106 :2 0 50 :3 0
38 :2 0 1328 21f7
21fb 132d 21f8 21fd
:3 0 70 :3 0 38
:2 0 21ff 2200 0
2729 136 :3 0 70
:3 0 117 :3 0 86
:3 0 15e :3 0 e2
:3 0 21 :3 0 e2
:3 0 86 :3 0 15f
:3 0 fb :3 0 160
:4 0 1fe 1 :8 0
2214 8b :3 0 b2
:3 0 220f 2210 0
b3 :3 0 2211 2212
0 2214 1330 2267
b4 :3 0 8b :3 0
b2 :3 0 2216 2217
0 b3 :3 0 2218
2219 0 221b 1333
221d 1335 221c 221b
:2 0 2265 b5 :3 0
8b :3 0 b2 :3 0
2220 2221 0 b3
:3 0 2222 2223 0
225d 8e :3 0 8f
:3 0 2225 2226 0
8e :3 0 a1 :3 0
2228 2229 0 b6
:2 0 2 :4 0 1ff
:2 0 a3 :2 0 35
:2 0 1337 222e 2230
:3 0 133a 222a 2232
2227 2234 2233 :2 0
91 :3 0 a4 :3 0
2236 2237 0 93
:4 0 200 :4 0 96
:2 0 97 :3 0 133e
223b 223d :3 0 96
:2 0 b9 :4 0 1341
223f 2241 :3 0 96
:2 0 ba :4 0 1344
2243 2245 :3 0 96
:2 0 b3 :3 0 1347
2247 2249 :3 0 96
:2 0 bb :4 0 134a
224b 224d :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 134d 2250 2254
1351 224f 2256 :3 0
1354 2238 2258 :2 0
225a 1357 225b 2235
225a 0 225c 1359
0 225d 135b 2260
:3 0 2260 0 2260
225f 225d 225e :6 0
2262 50 :3 0 135e
2264 1360 2263 2262
:2 0 2265 1362 :2 0
2267 0 2267 2266
2214 2265 :6 0 2729
1 :3 0 9b :3 0
70 :3 0 38 :2 0
1365 2269 226c 105
:2 0 38 :2 0 136a
226e 2270 :3 0 11
:3 0 21 :3 0 2272
2273 0 2299 8e
:3 0 8f :3 0 2275
2276 0 8e :3 0
a1 :3 0 2278 2279
0 35 :2 0 2
:4 0 201 :2 0 a3
:2 0 35 :2 0 136d
227e 2280 :3 0 1370
227a 2282 2277 2284
2283 :2 0 91 :3 0
a4 :3 0 2286 2287
0 93 :4 0 202
:4 0 96 :2 0 97
:3 0 1374 228b 228d
:3 0 1377 2288 228f
:2 0 2291 137a 2292
2285 2291 0 2293
137c 0 2299 12
:3 0 fb :3 0 101
:3 0 2295 2296 0
2297 :2 0 2299 137e
229a 2271 2299 0
229b 1382 0 2729
51 :3 0 9b :3 0
16 :3 0 38 :2 0
1384 229d 22a0 229c
22a1 0 2729 5f
:3 0 9b :3 0 4b
:3 0 38 :2 0 1387
22a4 22a7 22a3 22a8
0 2729 9b :3 0
51 :3 0 38 :2 0
138a 22aa 22ad 9b
:3 0 105 :2 0 4b
:3 0 38 :2 0 138d
22af 22b3 1392 22b0
22b5 :3 0 9b :3 0
56 :3 0 38 :2 0
1395 22b7 22ba fb
:3 0 bf :2 0 135
:3 0 22bc 22be 0
139a 22bd 22c0 :3 0
9b :3 0 56 :3 0
38 :2 0 139d 22c2
22c5 fb :3 0 bf
:2 0 134 :3 0 22c7
22c9 0 13a2 22c8
22cb :3 0 22c1 22cd
22cc :2 0 3c :4 0
22cf 22d0 0 24c5
136 :3 0 81 :3 0
203 :3 0 81 :3 0
64 :3 0 3c :3 0
13e :3 0 ae :3 0
24 :3 0 e2 :3 0
21 :3 0 13f :4 0
204 1 :8 0 22e4
8b :3 0 b2 :3 0
22df 22e0 0 b3
:3 0 22e1 22e2 0
22e4 13a5 2337 b4
:3 0 8b :3 0 b2
:3 0 22e6 22e7 0
b3 :3 0 22e8 22e9
0 22eb 13a8 22ed
13aa 22ec 22eb :2 0
2335 b5 :3 0 8b
:3 0 b2 :3 0 22f0
22f1 0 b3 :3 0
22f2 22f3 0 232d
8e :3 0 8f :3 0
22f5 22f6 0 8e
:3 0 a1 :3 0 22f8
22f9 0 b6 :2 0
2 :4 0 205 :2 0
a3 :2 0 35 :2 0
13ac 22fe 2300 :3 0
13af 22fa 2302 22f7
2304 2303 :2 0 91
:3 0 a4 :3 0 2306
2307 0 93 :4 0
206 :4 0 96 :2 0
97 :3 0 13b3 230b
230d :3 0 96 :2 0
b9 :4 0 13b6 230f
2311 :3 0 96 :2 0
ba :4 0 13b9 2313
2315 :3 0 96 :2 0
b3 :3 0 13bc 2317
2319 :3 0 96 :2 0
bb :4 0 13bf 231b
231d :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
13c2 2320 2324 13c6
231f 2326 :3 0 13c9
2308 2328 :2 0 232a
13cc 232b 2305 232a
0 232c 13ce 0
232d 13d0 2330 :3 0
2330 0 2330 232f
232d 232e :6 0 2332
52 :3 0 13d3 2334
13d5 2333 2332 :2 0
2335 13d7 :2 0 2337
0 2337 2336 22e4
2335 :6 0 24c5 1
:3 0 3c :3 0 10a
:2 0 13da 233a 233b
:3 0 233c :2 0 27
:3 0 3c :3 0 233e
233f 0 2341 13dc
2342 233d 2341 0
2343 13de 0 24c5
9b :3 0 64 :3 0
38 :2 0 13e0 2344
2347 105 :2 0 38
:2 0 13e5 2349 234b
:3 0 3b :3 0 10b
:2 0 35 :2 0 13e8
234e 2350 :3 0 234d
2351 0 24c2 6f
:3 0 190 :3 0 24
:3 0 48 :3 0 21
:3 0 30 :3 0 32
:3 0 71 :3 0 73
:3 0 3b :3 0 3a
:3 0 39 :3 0 13ea
2354 235f 2353 2360
0 24c2 9b :3 0
53 :3 0 38 :2 0
13f5 2362 2365 105
:2 0 38 :2 0 13fa
2367 2369 :3 0 236a
:2 0 3d :3 0 10a
:2 0 13fd 236d 236e
:3 0 236f :2 0 2370
:2 0 236b 2372 2371
:2 0 207 :3 0 208
:3 0 54 :3 0 13e
:3 0 ae :3 0 24
:3 0 e2 :3 0 21
:3 0 81 :3 0 d3
:3 0 bc :3 0 3d
:4 0 209 1 :8 0
2386 8b :3 0 b2
:3 0 2381 2382 0
b3 :3 0 2383 2384
0 2386 13ff 23d9
b4 :3 0 8b :3 0
b2 :3 0 2388 2389
0 b3 :3 0 238a
238b 0 238d 1402
238f 1404 238e 238d
:2 0 23d7 b5 :3 0
8b :3 0 b2 :3 0
2392 2393 0 b3
:3 0 2394 2395 0
23cf 8e :3 0 8f
:3 0 2397 2398 0
8e :3 0 a1 :3 0
239a 239b 0 b6
:2 0 2 :4 0 20a
:2 0 a3 :2 0 35
:2 0 1406 23a0 23a2
:3 0 1409 239c 23a4
2399 23a6 23a5 :2 0
91 :3 0 a4 :3 0
23a8 23a9 0 93
:4 0 20b :4 0 96
:2 0 97 :3 0 140d
23ad 23af :3 0 96
:2 0 b9 :4 0 1410
23b1 23b3 :3 0 96
:2 0 ba :4 0 1413
23b5 23b7 :3 0 96
:2 0 b3 :3 0 1416
23b9 23bb :3 0 96
:2 0 bb :4 0 1419
23bd 23bf :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 141c 23c2 23c6
1420 23c1 23c8 :3 0
1423 23aa 23ca :2 0
23cc 1426 23cd 23a7
23cc 0 23ce 1428
0 23cf 142a 23d2
:3 0 23d2 0 23d2
23d1 23cf 23d0 :6 0
23d4 54 :3 0 142d
23d6 142f 23d5 23d4
:2 0 23d7 1431 :2 0
23d9 0 23d9 23d8
2386 23d7 :6 0 23f2
1 :3 0 4b :3 0
9b :3 0 51 :3 0
38 :2 0 1434 23dc
23df 10b :2 0 9b
:3 0 50 :3 0 38
:2 0 1437 23e2 23e5
143a 23e1 23e7 :3 0
10b :2 0 9b :3 0
54 :3 0 38 :2 0
143d 23ea 23ed 1440
23e9 23ef :3 0 23db
23f0 0 23f2 1443
2403 4b :3 0 9b
:3 0 51 :3 0 38
:2 0 1446 23f4 23f7
10b :2 0 9b :3 0
50 :3 0 38 :2 0
1449 23fa 23fd 144c
23f9 23ff :3 0 23f3
2400 0 2402 144f
2404 2373 23f2 0
2405 0 2402 0
2405 1451 0 24c2
4f :3 0 20c :2 0
2406 2407 0 24c2
54 :3 0 1cb :3 0
9b :3 0 20d :3 0
4b :3 0 1454 240c
240e 38 :2 0 1456
240b 2411 1cd :2 0
9b :3 0 20d :3 0
64 :3 0 1459 2415
2417 38 :2 0 145b
2414 241a 145e 2413
241c :3 0 241d :2 0
a3 :2 0 1d8 :2 0
1461 241f 2421 :3 0
1464 240a 2423 2409
2424 0 24c2 70
:3 0 9b :3 0 54
:3 0 38 :2 0 1466
2427 242a 1cc :2 0
9b :3 0 64 :3 0
38 :2 0 1469 242d
2430 146c 242c 2432
:3 0 2426 2433 0
24c2 9b :3 0 70
:3 0 38 :2 0 146f
2435 2438 9b :3 0
106 :2 0 4b :3 0
38 :2 0 1472 243a
243e 1477 243b 2440
:3 0 55 :3 0 9b
:3 0 54 :3 0 38
:2 0 147a 2443 2446
a3 :2 0 9b :3 0
70 :3 0 38 :2 0
147d 2449 244c 1480
2448 244e :3 0 10b
:2 0 9b :3 0 4b
:3 0 38 :2 0 1483
2451 2454 1486 2450
2456 :3 0 2442 2457
0 2459 1489 2462
55 :3 0 9b :3 0
54 :3 0 38 :2 0
148b 245b 245e 245a
245f 0 2461 148e
2463 2441 2459 0
2464 0 2461 0
2464 1490 0 24c2
70 :3 0 1d9 :3 0
24 :3 0 22 :3 0
21 :3 0 27 :3 0
28 :3 0 55 :3 0
54 :3 0 38 :2 0
1493 2466 246f 2465
2470 0 24c2 4e
:3 0 1cb :3 0 9b
:3 0 20d :3 0 54
:3 0 149c 2475 2477
38 :2 0 149e 2474
247a 1cd :2 0 9b
:3 0 20d :3 0 57
:3 0 14a1 247e 2480
38 :2 0 14a3 247d
2483 14a6 247c 2485
:3 0 2486 :2 0 1cc
:2 0 1ce :2 0 14a9
2488 248a :3 0 14ac
2473 248c 2472 248d
0 24c2 70 :3 0
1da :3 0 1db :3 0
2490 2491 0 9b
:3 0 4e :3 0 38
:2 0 14ae 2493 2496
fb :3 0 1eb :3 0
2498 2499 0 14b1
2492 249b 248f 249c
0 24c2 70 :3 0
1dd :3 0 24 :3 0
21 :3 0 70 :3 0
9b :3 0 57 :3 0
38 :2 0 14b4 24a3
24a6 9b :3 0 4e
:3 0 38 :2 0 14b7
24a8 24ab 14ba 249f
24ad 249e 24ae 0
24c2 3b :3 0 38
:2 0 24b0 24b1 0
24c2 70 :3 0 190
:3 0 24 :3 0 48
:3 0 21 :3 0 30
:3 0 32 :3 0 71
:3 0 73 :3 0 3b
:3 0 3a :3 0 39
:3 0 14c0 24b4 24bf
24b3 24c0 0 24c2
14cb 24c3 234c 24c2
0 24c4 14d9 0
24c5 14db 26a5 4f
:3 0 20c :2 0 24c6
24c7 0 26a4 70
:3 0 9b :3 0 4b
:3 0 38 :2 0 14e0
24ca 24cd 24c9 24ce
0 26a4 6f :3 0
20e :3 0 24 :3 0
48 :3 0 49 :3 0
21 :3 0 3d :3 0
34 :3 0 4b :3 0
70 :3 0 5f :3 0
50 :3 0 4f :3 0
71 :3 0 74 :3 0
73 :3 0 75 :3 0
76 :3 0 78 :3 0
77 :3 0 79 :3 0
3a :3 0 39 :3 0
53 :3 0 4a :3 0
9b :3 0 57 :3 0
38 :2 0 14e3 24e9
24ec 9b :3 0 56
:3 0 38 :2 0 14e6
24ee 24f1 14e9 24d1
24f3 24d0 24f4 0
26a4 50 :3 0 9b
:3 0 4b :3 0 38
:2 0 1503 24f7 24fa
24f6 24fb 0 26a4
4b :3 0 9b :3 0
51 :3 0 38 :2 0
1506 24fe 2501 10b
:2 0 9b :3 0 50
:3 0 38 :2 0 1509
2504 2507 150c 2503
2509 :3 0 24fd 250a
0 26a4 d3 :3 0
bc :3 0 28 :3 0
3d :3 0 117 :4 0
20f 1 :8 0 2517
8b :3 0 b2 :3 0
2512 2513 0 b3
:3 0 2514 2515 0
2517 150f 256a b4
:3 0 8b :3 0 b2
:3 0 2519 251a 0
b3 :3 0 251b 251c
0 251e 1512 2520
1514 251f 251e :2 0
2568 b5 :3 0 8b
:3 0 b2 :3 0 2523
2524 0 b3 :3 0
2525 2526 0 2560
8e :3 0 8f :3 0
2528 2529 0 8e
:3 0 a1 :3 0 252b
252c 0 b6 :2 0
2 :4 0 210 :2 0
a3 :2 0 35 :2 0
1516 2531 2533 :3 0
1519 252d 2535 252a
2537 2536 :2 0 91
:3 0 a4 :3 0 2539
253a 0 93 :4 0
211 :4 0 96 :2 0
97 :3 0 151d 253e
2540 :3 0 96 :2 0
b9 :4 0 1520 2542
2544 :3 0 96 :2 0
ba :4 0 1523 2546
2548 :3 0 96 :2 0
b3 :3 0 1526 254a
254c :3 0 96 :2 0
bb :4 0 1529 254e
2550 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
152c 2553 2557 1530
2552 2559 :3 0 1533
253b 255b :2 0 255d
1536 255e 2538 255d
0 255f 1538 0
2560 153a 2563 :3 0
2563 0 2563 2562
2560 2561 :6 0 2565
56 :3 0 153d 2567
153f 2566 2565 :2 0
2568 1541 :2 0 256a
0 256a 2569 2517
2568 :6 0 26a4 1
:3 0 102 :3 0 10f
:3 0 d3 :3 0 bc
:3 0 28 :3 0 102
:3 0 110 :3 0 27
:3 0 117 :4 0 212
1 :8 0 257b 8b
:3 0 b2 :3 0 2576
2577 0 b3 :3 0
2578 2579 0 257b
1544 25ce b4 :3 0
8b :3 0 b2 :3 0
257d 257e 0 b3
:3 0 257f 2580 0
2582 1547 2584 1549
2583 2582 :2 0 25cc
b5 :3 0 8b :3 0
b2 :3 0 2587 2588
0 b3 :3 0 2589
258a 0 25c4 8e
:3 0 8f :3 0 258c
258d 0 8e :3 0
a1 :3 0 258f 2590
0 b6 :2 0 2
:4 0 213 :2 0 a3
:2 0 35 :2 0 154b
2595 2597 :3 0 154e
2591 2599 258e 259b
259a :2 0 91 :3 0
a4 :3 0 259d 259e
0 93 :4 0 214
:4 0 96 :2 0 97
:3 0 1552 25a2 25a4
:3 0 96 :2 0 b9
:4 0 1555 25a6 25a8
:3 0 96 :2 0 ba
:4 0 1558 25aa 25ac
:3 0 96 :2 0 b3
:3 0 155b 25ae 25b0
:3 0 96 :2 0 bb
:4 0 155e 25b2 25b4
:3 0 96 :2 0 bc
:3 0 bd :3 0 35
:2 0 be :2 0 1561
25b7 25bb 1565 25b6
25bd :3 0 1568 259f
25bf :2 0 25c1 156b
25c2 259c 25c1 0
25c3 156d 0 25c4
156f 25c7 :3 0 25c7
0 25c7 25c6 25c4
25c5 :6 0 25c9 58
:3 0 1572 25cb 1574
25ca 25c9 :2 0 25cc
1576 :2 0 25ce 0
25ce 25cd 257b 25cc
:6 0 26a4 1 :3 0
e1 :3 0 1e6 :3 0
e0 :3 0 111 :3 0
1db :3 0 e0 :3 0
fb :3 0 1e3 :3 0
d0 :3 0 51 :3 0
cc :3 0 51 :3 0
f2 :3 0 de :3 0
f3 :3 0 f4 :3 0
215 :3 0 e2 :3 0
21 :4 0 216 1
:8 0 25f9 127 :4 0
25e4 :3 0 128 :3 0
bf :2 0 157b 25e7
25e8 :3 0 8b :3 0
b2 :3 0 25ea 25eb
0 38 :2 0 25ec
25ed 0 25ef 157e
25f6 8b :3 0 b2
:3 0 25f0 25f1 0
129 :2 0 25f2 25f3
0 25f5 1580 25f7
25e9 25ef 0 25f8
0 25f5 0 25f8
1582 0 25f9 1585
264c b4 :3 0 8b
:3 0 b2 :3 0 25fb
25fc 0 b3 :3 0
25fd 25fe 0 2600
1588 2602 158a 2601
2600 :2 0 264a b5
:3 0 8b :3 0 b2
:3 0 2605 2606 0
b3 :3 0 2607 2608
0 2642 8e :3 0
8f :3 0 260a 260b
0 8e :3 0 a1
:3 0 260d 260e 0
b6 :2 0 2 :4 0
217 :2 0 a3 :2 0
35 :2 0 158c 2613
2615 :3 0 158f 260f
2617 260c 2619 2618
:2 0 91 :3 0 a4
:3 0 261b 261c 0
93 :4 0 218 :4 0
96 :2 0 97 :3 0
1593 2620 2622 :3 0
96 :2 0 b9 :4 0
1596 2624 2626 :3 0
96 :2 0 ba :4 0
1599 2628 262a :3 0
96 :2 0 b3 :3 0
159c 262c 262e :3 0
96 :2 0 bb :4 0
159f 2630 2632 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 15a2 2635
2639 15a6 2634 263b
:3 0 15a9 261d 263d
:2 0 263f 15ac 2640
261a 263f 0 2641
15ae 0 2642 15b0
2645 :3 0 2645 0
2645 2644 2642 2643
:6 0 2647 5a :3 0
15b3 2649 15b5 2648
2647 :2 0 264a 15b7
:2 0 264c 0 264c
264b 25f9 264a :6 0
26a4 1 :3 0 8b
:3 0 b2 :3 0 264e
264f 0 8b :3 0
bf :2 0 132 :3 0
2651 2653 0 15bc
2652 2655 :3 0 2656
:2 0 6e :3 0 192
:2 0 2658 2659 0
26a1 70 :3 0 1f1
:3 0 21 :3 0 27
:3 0 4b :3 0 6e
:3 0 4c :3 0 4a
:3 0 38 :2 0 9b
:3 0 4e :3 0 38
:2 0 15bf 2664 2667
15c2 265c 2669 265b
266a 0 26a1 9b
:3 0 70 :3 0 38
:2 0 15cb 266c 266f
106 :2 0 38 :2 0
15d0 2671 2673 :3 0
11 :3 0 21 :3 0
2675 2676 0 269e
8e :3 0 8f :3 0
2678 2679 0 8e
:3 0 a1 :3 0 267b
267c 0 35 :2 0
2 :4 0 219 :2 0
a3 :2 0 35 :2 0
15d3 2681 2683 :3 0
15d6 267d 2685 267a
2687 2686 :2 0 91
:3 0 a4 :3 0 2689
268a 0 93 :4 0
21a :4 0 96 :2 0
97 :3 0 15da 268e
2690 :3 0 15dd 268b
2692 :2 0 2694 15e0
2695 2688 2694 0
2696 15e2 0 269e
12 :3 0 9b :3 0
70 :3 0 38 :2 0
15e4 2698 269b 269c
:2 0 269e 15e7 269f
2674 269e 0 26a0
15eb 0 26a1 15ed
26a2 2657 26a1 0
26a3 15f1 0 26a4
15f3 26a6 22ce 24c5
0 26a7 0 26a4
0 26a7 15fd 0
26b2 4b :3 0 9b
:3 0 51 :3 0 38
:2 0 1600 26a9 26ac
26a8 26ad 0 26b2
53 :3 0 38 :2 0
26af 26b0 0 26b2
1603 26d6 4f :3 0
1cb :3 0 9b :3 0
20d :3 0 51 :3 0
1607 26b6 26b8 38
:2 0 1609 26b5 26bb
1cd :2 0 9b :3 0
20d :3 0 4b :3 0
160c 26bf 26c1 38
:2 0 160e 26be 26c4
1611 26bd 26c6 :3 0
26c7 :2 0 1cc :2 0
1ce :2 0 1614 26c9
26cb :3 0 26cc :2 0
a3 :2 0 1d8 :2 0
1617 26ce 26d0 :3 0
161a 26b4 26d2 26b3
26d3 0 26d5 161c
26d7 22b6 26b2 0
26d8 0 26d5 0
26d8 161e 0 2729
70 :3 0 20e :3 0
24 :3 0 48 :3 0
49 :3 0 21 :3 0
3d :3 0 34 :3 0
4b :3 0 51 :3 0
5f :3 0 50 :3 0
4f :3 0 71 :3 0
74 :3 0 73 :3 0
75 :3 0 76 :3 0
78 :3 0 77 :3 0
79 :3 0 3a :3 0
39 :3 0 53 :3 0
4a :3 0 9b :3 0
57 :3 0 38 :2 0
1621 26f2 26f5 9b
:3 0 56 :3 0 38
:2 0 1624 26f7 26fa
1627 26da 26fc 26d9
26fd 0 2729 11
:3 0 21 :3 0 26ff
2700 0 2729 8e
:3 0 8f :3 0 2702
2703 0 8e :3 0
a1 :3 0 2705 2706
0 35 :2 0 2
:4 0 21b :2 0 a3
:2 0 35 :2 0 1641
270b 270d :3 0 1644
2707 270f 2704 2711
2710 :2 0 91 :3 0
a4 :3 0 2713 2714
0 93 :4 0 21c
:4 0 96 :2 0 97
:3 0 1648 2718 271a
:3 0 164b 2715 271c
:2 0 271e 164e 271f
2712 271e 0 2720
1650 0 2729 12
:3 0 9b :3 0 70
:3 0 38 :2 0 1652
2722 2725 2726 :2 0
2729 159 :3 0 1655
2865 9b :3 0 15
:3 0 38 :2 0 1660
272a 272d 9b :3 0
106 :2 0 4f :3 0
38 :2 0 1663 272f
2733 1668 2730 2735
:3 0 9b :3 0 50
:3 0 38 :2 0 166b
2737 273a 105 :2 0
38 :2 0 1670 273c
273e :3 0 273f :2 0
9b :3 0 15 :3 0
38 :2 0 1673 2741
2744 bf :2 0 38
:2 0 1678 2746 2748
:3 0 2749 :2 0 2740
274b 274a :2 0 11
:3 0 21 :3 0 274d
274e 0 2774 8e
:3 0 8f :3 0 2750
2751 0 8e :3 0
a1 :3 0 2753 2754
0 35 :2 0 2
:4 0 21d :2 0 a3
:2 0 35 :2 0 167b
2759 275b :3 0 167e
2755 275d 2752 275f
275e :2 0 91 :3 0
a4 :3 0 2761 2762
0 93 :4 0 21e
:4 0 96 :2 0 97
:3 0 1682 2766 2768
:3 0 1685 2763 276a
:2 0 276c 1688 276d
2760 276c 0 276e
168a 0 2774 12
:3 0 8b :3 0 b2
:3 0 2770 2771 0
2772 :2 0 2774 168c
2775 274c 2774 0
2776 1690 0 2863
e1 :3 0 de :3 0
15 :3 0 e0 :3 0
111 :3 0 1db :3 0
e0 :3 0 fb :3 0
21f :3 0 e2 :3 0
21 :4 0 220 1
:8 0 2798 127 :4 0
2783 :3 0 128 :3 0
bf :2 0 1694 2786
2787 :3 0 8b :3 0
b2 :3 0 2789 278a
0 38 :2 0 278b
278c 0 278e 1697
2795 8b :3 0 b2
:3 0 278f 2790 0
129 :2 0 2791 2792
0 2794 1699 2796
2788 278e 0 2797
0 2794 0 2797
169b 0 2798 169e
27eb b4 :3 0 8b
:3 0 b2 :3 0 279a
279b 0 b3 :3 0
279c 279d 0 279f
16a1 27a1 16a3 27a0
279f :2 0 27e9 b5
:3 0 8b :3 0 b2
:3 0 27a4 27a5 0
b3 :3 0 27a6 27a7
0 27e1 8e :3 0
8f :3 0 27a9 27aa
0 8e :3 0 a1
:3 0 27ac 27ad 0
b6 :2 0 2 :4 0
221 :2 0 a3 :2 0
35 :2 0 16a5 27b2
27b4 :3 0 16a8 27ae
27b6 27ab 27b8 27b7
:2 0 91 :3 0 a4
:3 0 27ba 27bb 0
93 :4 0 222 :4 0
96 :2 0 97 :3 0
16ac 27bf 27c1 :3 0
96 :2 0 b9 :4 0
16af 27c3 27c5 :3 0
96 :2 0 ba :4 0
16b2 27c7 27c9 :3 0
96 :2 0 b3 :3 0
16b5 27cb 27cd :3 0
96 :2 0 bb :4 0
16b8 27cf 27d1 :3 0
96 :2 0 bc :3 0
bd :3 0 35 :2 0
be :2 0 16bb 27d4
27d8 16bf 27d3 27da
:3 0 16c2 27bc 27dc
:2 0 27de 16c5 27df
27b9 27de 0 27e0
16c7 0 27e1 16c9
27e4 :3 0 27e4 0
27e4 27e3 27e1 27e2
:6 0 27e6 5c :3 0
16cc 27e8 16ce 27e7
27e6 :2 0 27e9 16d0
:2 0 27eb 0 27eb
27ea 2798 27e9 :6 0
2863 1 :3 0 f5
:3 0 e0 :3 0 111
:3 0 1db :3 0 e0
:3 0 fb :3 0 21f
:3 0 ae :3 0 24
:3 0 86 :3 0 48
:4 0 223 1 :8 0
280e 127 :4 0 27f9
:3 0 128 :3 0 bf
:2 0 16d5 27fc 27fd
:3 0 8b :3 0 b2
:3 0 27ff 2800 0
38 :2 0 2801 2802
0 2804 16d8 280b
8b :3 0 b2 :3 0
2805 2806 0 129
:2 0 2807 2808 0
280a 16da 280c 27fe
2804 0 280d 0
280a 0 280d 16dc
0 280e 16df 2861
b4 :3 0 8b :3 0
b2 :3 0 2810 2811
0 b3 :3 0 2812
2813 0 2815 16e2
2817 16e4 2816 2815
:2 0 285f b5 :3 0
8b :3 0 b2 :3 0
281a 281b 0 b3
:3 0 281c 281d 0
2857 8e :3 0 8f
:3 0 281f 2820 0
8e :3 0 a1 :3 0
2822 2823 0 b6
:2 0 2 :4 0 224
:2 0 a3 :2 0 35
:2 0 16e6 2828 282a
:3 0 16e9 2824 282c
2821 282e 282d :2 0
91 :3 0 a4 :3 0
2830 2831 0 93
:4 0 225 :4 0 96
:2 0 97 :3 0 16ed
2835 2837 :3 0 96
:2 0 b9 :4 0 16f0
2839 283b :3 0 96
:2 0 ba :4 0 16f3
283d 283f :3 0 96
:2 0 b3 :3 0 16f6
2841 2843 :3 0 96
:2 0 bb :4 0 16f9
2845 2847 :3 0 96
:2 0 bc :3 0 bd
:3 0 35 :2 0 be
:2 0 16fc 284a 284e
1700 2849 2850 :3 0
1703 2832 2852 :2 0
2854 1706 2855 282f
2854 0 2856 1708
0 2857 170a 285a
:3 0 285a 0 285a
2859 2857 2858 :6 0
285c 5e :3 0 170d
285e 170f 285d 285c
:2 0 285f 1711 :2 0
2861 0 2861 2860
280e 285f :6 0 2863
1 :3 0 1714 2864
2736 2863 0 2866
21fe 2729 0 2866
1718 0 2896 70
:3 0 133 :3 0 24
:3 0 171b 2868 286a
2867 286b 0 2896
11 :3 0 21 :3 0
286d 286e 0 2896
8e :3 0 8f :3 0
2870 2871 0 8e
:3 0 a1 :3 0 2873
2874 0 35 :2 0
2 :4 0 226 :2 0
a3 :2 0 35 :2 0
171d 2879 287b :3 0
1720 2875 287d 2872
287f 287e :2 0 91
:3 0 a4 :3 0 2881
2882 0 93 :4 0
227 :4 0 96 :2 0
97 :3 0 1724 2886
2888 :3 0 1727 2883
288a :2 0 288c 172a
288d 2880 288c 0
288e 172c 0 2896
12 :3 0 9b :3 0
70 :3 0 38 :2 0
172e 2890 2893 2894
:2 0 2896 1731 2897
10c1 2896 0 2987
a7 :3 0 228 :3 0
a7 :3 0 a9 :3 0
a7 :3 0 86 :3 0
a7 :3 0 aa :3 0
a7 :3 0 ab :3 0
a7 :3 0 ac :3 0
a7 :3 0 ad :3 0
a7 :3 0 ae :3 0
a7 :3 0 af :3 0
17 :3 0 41 :3 0
19 :3 0 3f :3 0
42 :3 0 47 :3 0
1a :3 0 24 :3 0
46 :3 0 b0 :3 0
a7 :3 0 a7 :3 0
a8 :3 0 1f :4 0
229 1 :8 0 28be
8b :3 0 b2 :3 0
28b9 28ba 0 b3
:3 0 28bb 28bc 0
28be 1742 2911 b4
:3 0 8b :3 0 b2
:3 0 28c0 28c1 0
b3 :3 0 28c2 28c3
0 28c5 1745 28c7
1747 28c6 28c5 :2 0
290f b5 :3 0 8b
:3 0 b2 :3 0 28ca
28cb 0 b3 :3 0
28cc 28cd 0 2907
8e :3 0 8f :3 0
28cf 28d0 0 8e
:3 0 a1 :3 0 28d2
28d3 0 b6 :2 0
2 :4 0 22a :2 0
a3 :2 0 35 :2 0
1749 28d8 28da :3 0
174c 28d4 28dc 28d1
28de 28dd :2 0 91
:3 0 a4 :3 0 28e0
28e1 0 93 :4 0
22b :4 0 96 :2 0
97 :3 0 1750 28e5
28e7 :3 0 96 :2 0
b9 :4 0 1753 28e9
28eb :3 0 96 :2 0
ba :4 0 1756 28ed
28ef :3 0 96 :2 0
b3 :3 0 1759 28f1
28f3 :3 0 96 :2 0
bb :4 0 175c 28f5
28f7 :3 0 96 :2 0
bc :3 0 bd :3 0
35 :2 0 be :2 0
175f 28fa 28fe 1763
28f9 2900 :3 0 1766
28e2 2902 :2 0 2904
1769 2905 28df 2904
0 2906 176b 0
2907 176d 290a :3 0
290a 0 290a 2909
2907 2908 :6 0 290c
60 :3 0 1770 290e
1772 290d 290c :2 0
290f 1774 :2 0 2911
0 2911 2910 28be
290f :6 0 2984 1
:3 0 8b :3 0 b2
:3 0 2913 2914 0
8b :3 0 bf :2 0
132 :3 0 2916 2918
0 1779 2917 291a
:3 0 291b :2 0 22c
:2 0 177c 291d 291e
:3 0 11 :3 0 1f
:3 0 2920 2921 0
2947 8e :3 0 8f
:3 0 2923 2924 0
8e :3 0 a1 :3 0
2926 2927 0 35
:2 0 2 :4 0 22d
:2 0 a3 :2 0 35
:2 0 177e 292c 292e
:3 0 1781 2928 2930
2925 2932 2931 :2 0
91 :3 0 a4 :3 0
2934 2935 0 93
:4 0 22e :4 0 96
:2 0 97 :3 0 1785
2939 293b :3 0 1788
2936 293d :2 0 293f
178b 2940 2933 293f
0 2941 178d 0
2947 12 :3 0 fb
:3 0 fc :3 0 2943
2944 0 2945 :2 0
2947 178f 2948 291f
2947 0 2949 1793
0 2984 102 :3 0
18f :3 0 294a 294b
0 20 :3 0 17
:3 0 1795 294c 294f
bf :2 0 38 :2 0
179a 2951 2953 :3 0
8b :3 0 b2 :3 0
2955 2956 0 38
:2 0 2957 2958 0
2981 11 :3 0 1f
:3 0 295a 295b 0
2981 8e :3 0 8f
:3 0 295d 295e 0
8e :3 0 a1 :3 0
2960 2961 0 35
:2 0 2 :4 0 22f
:2 0 a3 :2 0 35
:2 0 179d 2966 2968
:3 0 17a0 2962 296a
295f 296c 296b :2 0
91 :3 0 a4 :3 0
296e 296f 0 93
:4 0 230 :4 0 96
:2 0 97 :3 0 17a4
2973 2975 :3 0 17a7
2970 2977 :2 0 2979
17aa 297a 296d 2979
0 297b 17ac 0
2981 12 :3 0 8b
:3 0 b2 :3 0 297d
297e 0 297f :2 0
2981 17ae 2982 2954
2981 0 2983 17b3
0 2984 17b5 2986
4f6 10b5 0 2987
0 2984 0 2987
17b9 0 2988 17bd
2989 43f 2988 0
298a 17c0 0 29fd
21 :3 0 3 :3 0
298b 298c 0 29fd
20 :3 0 7 :3 0
298e 298f 0 29fd
4a :3 0 10 :3 0
2991 2992 0 29fd
46 :3 0 fb :3 0
231 :3 0 2995 2996
0 2994 2997 0
29fd 8b :3 0 b2
:3 0 2999 299a 0
232 :3 0 46 :3 0
21 :3 0 20 :3 0
4a :3 0 17c2 299c
29a1 299b 29a2 0
29fd 11 :3 0 21
:3 0 29a4 29a5 0
29fd 8e :3 0 8f
:3 0 29a7 29a8 0
8e :3 0 a1 :3 0
29aa 29ab 0 35
:2 0 2 :4 0 233
:2 0 a3 :2 0 35
:2 0 17c7 29b0 29b2
:3 0 17ca 29ac 29b4
29a9 29b6 29b5 :2 0
91 :3 0 a4 :3 0
29b8 29b9 0 93
:4 0 234 :4 0 96
:2 0 97 :3 0 17ce
29bd 29bf :3 0 17d1
29ba 29c1 :2 0 29c3
17d4 29c4 29b7 29c3
0 29c5 17d6 0
29fd 12 :3 0 8b
:3 0 b2 :3 0 29c7
29c8 0 29c9 :2 0
29fd 8e :3 0 8f
:3 0 29cb 29cc 0
8e :3 0 a1 :3 0
29ce 29cf 0 35
:2 0 2 :4 0 235
:2 0 a3 :2 0 35
:2 0 17d8 29d4 29d6
:3 0 17db 29d0 29d8
29cd 29da 29d9 :2 0
91 :3 0 a4 :3 0
29dc 29dd 0 93
:4 0 236 :4 0 96
:2 0 97 :3 0 17df
29e1 29e3 :3 0 96
:2 0 b9 :4 0 17e2
29e5 29e7 :3 0 96
:2 0 237 :4 0 17e5
29e9 29eb :3 0 96
:2 0 8b :3 0 b2
:3 0 29ee 29ef 0
17e8 29ed 29f1 :3 0
17eb 29de 29f3 :2 0
29f5 17ee 29f6 29db
29f5 0 29f7 17f0
0 29fd 12 :3 0
8b :3 0 b2 :3 0
29f9 29fa 0 29fb
:2 0 29fd 17f2 2a00
:3 0 2a00 1806 2a00
29ff 29fd 29fe :6 0
2a01 :2 0 2 3a
2a00 2a04 :3 0 2a03
2a01 2a05 :8 0 
186e
4
:3 0 1 3 1
9 1 f 1
15 1 1b 1
1f 1 23 1
27 1 2b 1
31 a 8 e
14 1a 1e 22
26 2a 30 36
1 3c 1 42
1 48 1 4e
1 56 1 54
1 5d 1 5b
1 64 1 62
1 6b 1 69
1 72 1 70
1 79 1 77
1 80 1 7e
1 87 1 85
1 8e 1 8c
1 95 1 93
1 9c 1 9a
1 a3 1 a1
1 aa 1 a8
1 af 1 b4
1 b9 1 be
1 c3 1 c8
1 cd 1 d2
1 d7 1 dc
1 e1 1 e6
1 eb 1 f2
1 f0 1 f9
1 f7 1 fe
1 104 1 10a
1 110 1 116
1 11b 1 120
1 126 1 12c
1 132 1 138
1 13e 1 144
1 14a 1 150
1 156 1 15e
1 15c 1 165
1 163 1 16c
1 16a 1 171
1 177 1 17d
1 183 1 189
1 18f 1 195
1 19b 1 1a1
1 1a7 1 1ad
1 1b3 1 1b9
1 1bf 1 1c5
1 1cb 1 1d1
1 1d7 1 1dd
1 1e3 1 1e9
1 1ef 1 1f5
1 1fb 1 201
1 207 1 20d
1 213 1 219
1 21f 1 227
1 225 1 22e
1 22c 1 233
1 23b 1 239
1 240 1 246
1 24c 1 252
1 258 1 25e
1 264 1 26a
1 270 1 276
1 27c 1 284
1 282 1 289
1 28e 1 293
1 2ad 1 2b3
1 2ba 1 2c7
1 2d3 2 2d6
2d8 2 2db 2dd
2 2df 2e1 2
2e3 2e5 2 2e7
2e9 2 2eb 2ed
2 2ef 2f1 2
2f3 2f5 2 2f7
2f9 2 2ff 301
2 303 305 2
307 308 2 30a
30b 2 2fb 30d
2 30f 311 2
317 319 2 31b
31d 2 31f 320
2 322 323 2
313 325 2 327
329 1 32f 2
331 332 2 32b
334 2 336 338
1 33e 2 340
341 2 33a 343
2 345 347 1
34d 2 34f 350
2 349 352 2
354 356 1 35c
2 35e 35f 2
358 361 2 363
365 2 367 369
2 36b 36d 2
36f 371 2 373
375 2 377 379
2 37b 37d 2
37f 381 2 383
385 4 2cf 2d5
2da 387 1 389
1 38b 2 395
397 3 393 394
399 2 3a2 3a4
2 3a1 3a6 1
3a8 1 3aa 2
3db 3e0 1 3e7
1 3e2 2 3fa
3fc 3 3f8 3f9
3fe 2 407 409
2 40b 40d 2
40f 411 2 413
415 2 417 419
3 41e 41f 420
2 41b 422 2
406 424 1 426
1 428 2 3f1
429 1 42d 1
3ec 2 3ea 431
1 43c 2 438
43c 2 492 497
1 49e 1 499
2 4b1 4b3 3
4af 4b0 4b5 2
4be 4c0 2 4c2
4c4 2 4c6 4c8
2 4ca 4cc 2
4ce 4d0 3 4d5
4d6 4d7 2 4d2
4d9 2 4bd 4db
1 4dd 1 4df
2 4a8 4e0 1
4e4 1 4a3 2
4a1 4e8 1 4f3
2 4ef 4f3 2
51b 520 1 527
1 522 2 53a
53c 3 538 539
53e 2 547 549
2 54b 54d 2
54f 551 2 553
555 2 557 559
3 55e 55f 560
2 55b 562 2
546 564 1 566
1 568 2 531
569 1 56d 1
52c 2 52a 571
1 57c 2 578
57c 2 58b 58d
3 589 58a 58f
2 598 59a 2
597 59c 1 59e
1 5a0 3 582
5a1 5a6 1 5a8
2 5ac 5ad 2
5af 5b2 1 5b9
2 5b5 5b9 2
5c7 5c9 3 5c5
5c6 5cb 2 5d4
5d6 2 5d3 5d8
1 5da 1 5dc
3 5be 5dd 5e2
1 5e4 3 5ef
5f0 5f1 1 5f5
2 5f3 5f5 3
5fc 5fd 5fe 1
602 2 600 602
2 613 615 3
611 612 617 2
620 622 2 61f
624 1 626 1
628 3 60a 629
62e 1 630 1
632 2 639 63a
2 63f 640 2
63c 642 2 648
649 1 64b 2
645 64b 2 65c
65e 3 65a 65b
660 2 669 66b
2 668 66d 1
66f 1 671 3
653 672 677 1
679 3 67e 67f
680 1 684 2
682 684 3 68b
68c 68d 1 691
2 68f 691 2
698 699 1 69d
2 69b 69d 3
6a3 6a4 6a5 1
6a9 2 6a7 6a9
2 6bc 6c1 1
6c8 1 6c3 2
6db 6dd 3 6d9
6da 6df 2 6e8
6ea 2 6ec 6ee
2 6f0 6f2 2
6f4 6f6 2 6f8
6fa 3 6ff 700
701 2 6fc 703
2 6e7 705 1
707 1 709 2
6d2 70a 1 70e
1 6cd 2 6cb
712 1 71d 2
719 71d 2 72a
72f 1 736 1
731 2 749 74b
3 747 748 74d
2 756 758 2
75a 75c 2 75e
760 2 762 764
2 766 768 3
76d 76e 76f 2
76a 771 2 755
773 1 775 1
777 2 740 778
1 77c 1 73b
2 739 780 1
783 1 786 3
78b 78c 78d 1
791 2 78f 791
1 796 1 798
3 715 787 799
2 7ab 7b0 1
7b7 1 7b2 2
7ca 7cc 3 7c8
7c9 7ce 2 7d7
7d9 2 7db 7dd
2 7df 7e1 2
7e3 7e5 2 7e7
7e9 3 7ee 7ef
7f0 2 7eb 7f2
2 7d6 7f4 1
7f6 1 7f8 2
7c1 7f9 1 7fd
1 7bc 2 7ba
801 1 80c 2
808 80c 2 819
81e 1 825 1
820 2 838 83a
3 836 837 83c
2 845 847 2
849 84b 2 84d
84f 2 851 853
2 855 857 3
85c 85d 85e 2
859 860 2 844
862 1 864 1
866 2 82f 867
1 86b 1 82a
2 828 86f 1
872 1 875 3
804 876 879 2
87b 87c 2 87f
880 1 886 2
882 886 1 895
2 894 895 1
89d 1 8a3 2
8a5 8a6 2 892
8a7 1 8ae 1
8a9 2 8c1 8c3
3 8bf 8c0 8c5
2 8ce 8d0 2
8d2 8d4 2 8d6
8d8 2 8da 8dc
2 8de 8e0 3
8e5 8e6 8e7 2
8e2 8e9 2 8cd
8eb 1 8ed 1
8ef 2 8b8 8f0
1 8f4 1 8b3
2 8b1 8f8 1
8fb 1 90a 2
909 90a 1 912
1 918 2 91a
91b 2 907 91c
1 923 1 91e
2 936 938 3
934 935 93a 2
943 945 2 947
949 2 94b 94d
2 94f 951 2
953 955 3 95a
95b 95c 2 957
95e 2 942 960
1 962 1 964
2 92d 965 1
969 1 928 2
926 96d 1 970
2 973 974 1
97c 2 978 97c
1 982 1 985
1 987 3 87d
975 988 2 991
992 1 998 2
994 998 2 99c
99d 1 9a3 2
99f 9a3 2 9b5
9ba 1 9c1 1
9bc 2 9d4 9d6
3 9d2 9d3 9d8
2 9e1 9e3 2
9e5 9e7 2 9e9
9eb 2 9ed 9ef
2 9f1 9f3 3
9f8 9f9 9fa 2
9f5 9fc 2 9e0
9fe 1 a00 1
a02 2 9cb a03
1 a07 1 9c6
2 9c4 a0b 1
a0e 1 a11 3
a16 a17 a18 1
a1c 2 a1a a1c
2 a2f a34 1
a3b 1 a36 2
a4e a50 3 a4c
a4d a52 2 a5b
a5d 2 a5f a61
2 a63 a65 2
a67 a69 2 a6b
a6d 3 a72 a73
a74 2 a6f a76
2 a5a a78 1
a7a 1 a7c 2
a45 a7d 1 a81
1 a40 2 a3e
a85 1 a90 2
a8c a90 2 a9d
aa2 1 aa9 1
aa4 2 abc abe
3 aba abb ac0
2 ac9 acb 2
acd acf 2 ad1
ad3 2 ad5 ad7
2 ad9 adb 3
ae0 ae1 ae2 2
add ae4 2 ac8
ae6 1 ae8 1
aea 2 ab3 aeb
1 aef 1 aae
2 aac af3 2
afa afb 2 afd
aff 2 af6 b02
1 b04 2 b07
b08 1 b0e 2
b0a b0e 2 b12
b13 1 b19 2
b15 b19 2 b20
b23 1 b25 3
a88 b05 b26 2
b29 b2a 1 b2e
2 b2c b2e 2
b41 b46 1 b4d
1 b48 2 b60
b62 3 b5e b5f
b64 2 b6d b6f
2 b71 b73 2
b75 b77 2 b79
b7b 2 b7d b7f
3 b84 b85 b86
2 b81 b88 2
b6c b8a 1 b8c
1 b8e 2 b57
b8f 1 b93 1
b52 2 b50 b97
2 b9d b9e 1
ba2 2 ba0 ba2
2 bb3 bb8 1
bbf 1 bba 2
bd2 bd4 3 bd0
bd1 bd6 2 bdf
be1 2 be3 be5
2 be7 be9 2
beb bed 2 bef
bf1 3 bf6 bf7
bf8 2 bf3 bfa
2 bde bfc 1
bfe 1 c00 2
bc9 c01 1 c05
1 bc4 2 bc2
c09 1 c0c 1
c0f 2 c12 c13
1 c17 2 c15
c17 2 c25 c27
3 c23 c24 c29
2 c32 c34 2
c31 c36 1 c38
1 c3a 3 c1c
c3b c40 1 c42
4 b33 b9a c10
c43 1 c45 2
c57 c5c 1 c63
1 c5e 2 c76
c78 3 c74 c75
c7a 2 c83 c85
2 c87 c89 2
c8b c8d 2 c8f
c91 2 c93 c95
3 c9a c9b c9c
2 c97 c9e 2
c82 ca0 1 ca2
1 ca4 2 c6d
ca5 1 ca9 1
c68 2 c66 cad
1 cb8 2 cb4
cb8 2 cc5 cca
1 cd1 1 ccc
2 ce4 ce6 3
ce2 ce3 ce8 2
cf1 cf3 2 cf5
cf7 2 cf9 cfb
2 cfd cff 2
d01 d03 3 d08
d09 d0a 2 d05
d0c 2 cf0 d0e
1 d10 1 d12
2 cdb d13 1
d17 1 cd6 2
cd4 d1b 1 d1e
1 d21 2 d24
d25 1 d29 2
d27 d29 2 d2d
d2e 1 d34 2
d30 d34 2 d38
d39 1 d3f 2
d3b d3f 2 d49
d4c 1 d4e 4
c46 cb0 d22 d4f
2 d51 d52 2
d55 d56 1 d5a
2 d58 d5a 1
d5f 2 d5d d5f
2 d66 d67 1
d6d 2 d69 d6d
2 d71 d72 1
d78 2 d74 d78
4 d82 d83 d84
d85 1 d88 1
d8a 2 db3 db8
1 dbf 1 dba
2 dd2 dd4 3
dd0 dd1 dd6 2
ddf de1 2 de3
de5 2 de7 de9
2 deb ded 2
def df1 3 df6
df7 df8 2 df3
dfa 2 dde dfc
1 dfe 1 e00
2 dc9 e01 1
e05 1 dc4 2
dc2 e09 2 e0f
e10 1 e14 2
e12 e14 2 e22
e24 3 e20 e21
e26 2 e2f e31
2 e2e e33 1
e35 1 e37 3
e19 e38 e3d 1
e3f 2 e4e e4f
c e43 e44 e45
e46 e47 e48 e49
e4a e4b e4c e51
e52 2 e57 e58
1 e5c 2 e5a
e5c 1 e61 1
e64 2 e71 e73
3 e6f e70 e75
2 e7e e80 2
e7d e82 1 e84
1 e86 2 e8a
e8b 3 e68 e87
e8e 2 e90 e91
a 98c 98f a12
d53 d8b d8e e0c
e40 e55 e92 2
e94 e95 1 e96
2 e9a e9b 2
ea0 ea1 1 ea3
2 e9d ea3 2
ea8 ea9 1 ead
2 eab ead 2
eb7 eb8 2 ebd
ebe 1 ec0 2
eba ec0 2 ece
ed0 3 ecc ecd
ed2 2 edb edd
2 eda edf 1
ee1 1 ee3 3
ec5 ee4 ee9 2
eed eee 2 ef3
ef4 1 ef6 2
ef0 ef6 1 efb
2 efe efd 2
f1b f20 1 f27
1 f22 2 f3a
f3c 3 f38 f39
f3e 2 f47 f49
2 f4b f4d 2
f4f f51 2 f53
f55 2 f57 f59
3 f5e f5f f60
2 f5b f62 2
f46 f64 1 f66
1 f68 2 f31
f69 1 f6d 1
f2c 2 f2a f71
2 f77 f78 1
f7c 2 f7a f7c
2 f8a f8c 3
f88 f89 f8e 2
f97 f99 2 f96
f9b 1 f9d 1
f9f 3 f81 fa0
fa5 1 fa7 2
fc8 fcd 1 fd4
1 fcf 2 fe7
fe9 3 fe5 fe6
feb 2 ff4 ff6
2 ff8 ffa 2
ffc ffe 2 1000
1002 2 1004 1006
3 100b 100c 100d
2 1008 100f 2
ff3 1011 1 1013
1 1015 2 fde
1016 1 101a 1
fd9 2 fd7 101e
2 1024 1025 1
1029 2 1027 1029
2 1037 1039 3
1035 1036 103b 2
1044 1046 2 1043
1048 1 104a 1
104c 3 102e 104d
1052 1 1054 2
1058 1059 2 1064
1065 2 1069 106a
2 106e 106f 7
105f 1060 1061 1062
1067 106c 1071 a
eb5 eff f02 f74
fa8 fab 1021 1055
105c 1074 2 1077
1076 2 107a 107b
1 107f 2 107d
107f 1 1084 1
1087 1 1089 2
1096 1098 3 1094
1095 109a 2 10a3
10a5 2 10a2 10a7
1 10a9 1 10ab
2 10af 10b0 c
574 5a9 5e5 5e8
5eb 631 67a 1078
108a 108d 10ac 10b3
1 10b6 1 10bb
3 10cb 10cc 10cd
1 10d1 2 10cf
10d1 3 10d8 10d9
10da 1 10de 2
10dc 10de 2 10ef
10f1 3 10ed 10ee
10f3 2 10fc 10fe
2 10fb 1100 1
1102 1 1104 3
10e6 1105 110a 1
110c 1 110e 2
111c 1121 1 1128
1 1123 2 113b
113d 3 1139 113a
113f 2 1148 114a
2 114c 114e 2
1150 1152 2 1154
1156 2 1158 115a
3 115f 1160 1161
2 115c 1163 2
1147 1165 1 1167
1 1169 2 1132
116a 1 116e 1
112d 2 112b 1172
1 117d 2 1179
117d 2 118c 118e
3 118a 118b 1190
2 1199 119b 2
1198 119d 1 119f
1 11a1 3 1183
11a2 11a7 1 11a9
3 11ae 11af 11b0
1 11b4 2 11b2
11b4 3 11bb 11bc
11bd 1 11c1 2
11bf 11c1 2 11d2
11d4 3 11d0 11d1
11d6 2 11df 11e1
2 11de 11e3 1
11e5 1 11e7 3
11c9 11e8 11ed 3
11f3 11f4 11f5 1
11f9 2 11f7 11f9
3 1200 1201 1202
1 1206 2 1204
1206 2 1217 1219
3 1215 1216 121b
2 1224 1226 2
1223 1228 1 122a
1 122c 3 120e
122d 1232 2 1235
1234 3 1175 11aa
1236 1 1238 2
124b 1250 1 1257
1 1252 2 126a
126c 3 1268 1269
126e 2 1277 1279
2 127b 127d 2
127f 1281 2 1283
1285 2 1287 1289
3 128e 128f 1290
2 128b 1292 2
1276 1294 1 1296
1 1298 2 1261
1299 1 129d 1
125c 2 125a 12a1
2 12a8 12a9 2
12ab 12ae 1 12b5
2 12b1 12b5 2
12c3 12c5 3 12c1
12c2 12c7 2 12d0
12d2 2 12cf 12d4
1 12d6 1 12d8
3 12ba 12d9 12de
1 12e0 3 12e3
12e4 12e5 1 12e9
2 12e7 12e9 1
12ee 1 12f2 2
12f4 12f5 3 1300
1301 1302 1 1306
2 1304 1306 3
130d 130e 130f 1
1313 2 1311 1313
2 131a 131b 2
1320 1321 1 1323
2 131d 1323 3
132c 132d 132e 1
1332 2 1330 1332
2 1336 1337 1
133b 2 1339 133b
3 1341 1342 1343
1 1347 2 1345
1347 2 1357 1359
3 1355 1356 135b
2 1364 1366 2
1363 1368 1 136a
1 136c 3 134e
136d 1372 1 1374
2 1377 1378 1
137e 2 137a 137e
2 1382 1383 1
1389 2 1385 1389
2 139e 13a3 1
13aa 1 13a5 2
13bd 13bf 3 13bb
13bc 13c1 2 13ca
13cc 2 13ce 13d0
2 13d2 13d4 2
13d6 13d8 2 13da
13dc 3 13e1 13e2
13e3 2 13de 13e5
2 13c9 13e7 1
13e9 1 13eb 2
13b4 13ec 1 13f0
1 13af 2 13ad
13f4 3 13fc 13fd
13fe 1 1402 2
1400 1402 3 1409
140a 140b 1 140f
2 140d 140f 4
141a 141b 141c 141d
2 1417 1420 1
1422 2 143a 143b
2 143f 1440 15
1426 1427 1428 1429
142a 142b 142c 142d
142e 142f 1430 1431
1432 1433 1434 1435
1436 1437 1438 143d
1442 1 1448 2
1457 1459 3 1455
1456 145b 2 1464
1466 2 1463 1468
1 146a 1 146c
2 1470 1471 8
1390 13f7 1423 1445
144b 144e 146d 1474
3 1478 147b 147e
2 1480 1481 2
1375 1482 3 1488
1489 148a 1 148e
2 148c 148e 2
149b 14a0 1 14a7
1 14a2 2 14ba
14bc 3 14b8 14b9
14be 2 14c7 14c9
2 14cb 14cd 2
14cf 14d1 2 14d3
14d5 2 14d7 14d9
3 14de 14df 14e0
2 14db 14e2 2
14c6 14e4 1 14e6
1 14e8 2 14b1
14e9 1 14ed 1
14ac 2 14aa 14f1
2 14fa 14fb 1
1501 a 1507 1508
1509 150a 150b 150c
150d 150e 150f 1510
2 1515 1516 1
151a 2 1518 151a
1 151e 8 1528
1529 152a 152b 152c
152d 152e 152f 1
1532 1 1534 3
1537 1538 1539 1
153d 2 153b 153d
1 1542 1 1546
2 1548 1549 2
154d 154e 2 1553
1554 2 1550 1556
2 156a 156b 11
155c 155d 155e 155f
1560 1561 1562 1563
1564 1565 1566 1567
1568 156d 156e 156f
1570 2 1575 1576
1 157a 2 1578
157a 3 1580 1581
1582 1 1586 2
1584 1586 1 159a
2 1599 159a 1
15a2 1 15a8 2
15aa 15ab 2 1597
15ac 1 15b3 1
15ae 2 15c6 15c8
3 15c4 15c5 15ca
2 15d3 15d5 2
15d7 15d9 2 15db
15dd 2 15df 15e1
2 15e3 15e5 3
15ea 15eb 15ec 2
15e7 15ee 2 15d2
15f0 1 15f2 1
15f4 2 15bd 15f5
1 15f9 1 15b8
2 15b6 15fd 1
1600 2 1605 1606
1 160a 2 1608
160a 3 1610 1611
1612 1 1616 2
1614 1616 1 1628
2 1627 1628 1
1630 1 1636 2
1638 1639 2 1625
163a 1 1641 1
163c 2 1654 1656
3 1652 1653 1658
2 1661 1663 2
1665 1667 2 1669
166b 2 166d 166f
2 1671 1673 3
1678 1679 167a 2
1675 167c 2 1660
167e 1 1680 1
1682 2 164b 1683
1 1687 1 1646
2 1644 168b 1
168e 2 1692 1691
1 1693 1 1695
2 16aa 16af 1
16b6 1 16b1 2
16c9 16cb 3 16c7
16c8 16cd 2 16d6
16d8 2 16da 16dc
2 16de 16e0 2
16e2 16e4 2 16e6
16e8 3 16ed 16ee
16ef 2 16ea 16f1
2 16d5 16f3 1
16f5 1 16f7 2
16c0 16f8 1 16fc
1 16bb 2 16b9
1700 a 170a 170b
170c 170d 170e 170f
1710 1711 1712 1713
1 1719 2 172d
172f 3 172b 172c
1731 2 173a 173c
2 1739 173e 1
1740 1 1742 11
14f4 14fe 1504 1513
1535 154a 1559 1573
1696 1703 1707 1716
171c 1721 1724 1743
1748 2 174d 174e
2 1753 1754 1
1756 2 1750 1756
2 175b 175c 2
1761 1762 2 175e
1764 2 1769 176a
1 1770 2 176c
1770 2 1774 1775
1 177b 2 1777
177b 3 1781 1782
1783 1 1787 2
1785 1787 1 178d
1 1791 2 1793
1794 4 1798 1799
179a 179b 1 17b2
1 17b8 2 17ba
17bb 2 17bf 17c5
1 17cc 1 17c7
2 17df 17e1 3
17dd 17de 17e3 2
17ec 17ee 2 17f0
17f2 2 17f4 17f6
2 17f8 17fa 2
17fc 17fe 3 1803
1804 1805 2 1800
1807 2 17eb 1809
1 180b 1 180d
2 17d6 180e 1
1812 1 17d1 2
17cf 1816 1 181b
2 1828 182a 3
1826 1827 182c 2
1835 1837 2 1834
1839 1 183b 1
183d 2 183e 1843
1 1845 2 185d
185e 2 1862 1863
15 1849 184a 184b
184c 184d 184e 184f
1850 1851 1852 1853
1854 1855 1856 1857
1858 1859 185a 185b
1860 1865 1 186b
2 187a 187c 3
1878 1879 187e 2
1887 1889 2 1886
188b 1 188d 1
188f 2 1893 1894
d 1795 179e 17a1
17a4 17a9 17bc 1819
1846 1868 186e 1871
1890 1897 1 189b
2 189d 189e 2
1767 189f 2 18a4
18a5 1 18a9 2
18a7 18a9 2 18b7
18bc 1 18c3 1
18be 2 18d6 18d8
3 18d4 18d5 18da
2 18e3 18e5 2
18e7 18e9 2 18eb
18ed 2 18ef 18f1
2 18f3 18f5 3
18fa 18fb 18fc 2
18f7 18fe 2 18e2
1900 1 1902 1
1904 2 18cd 1905
1 1909 1 18c8
2 18c6 190d 3
18ae 18b1 1910 2
1916 1917 2 191c
191d 1 191f 2
1919 191f 2 1924
1925 2 192a 192b
2 1927 192d 2
1938 1939 1 193d
2 193b 193d 2
1941 1943 2 1945
1947 2 1949 194b
2 194d 194f 2
1951 1953 2 1955
1957 2 195d 195e
1 1960 2 1959
1962 2 1965 196a
2 196d 196f 2
1971 1973 2 1975
1977 2 1979 197b
2 197d 197f 2
1981 1983 2 1989
198a 1 198c 2
1985 198e 2 1991
1996 2 1998 1999
2 199d 199e 1
19a2 2 19a0 19a2
1 19b0 1 19b6
2 19b8 19b9 2
19a7 19ba 1 19c7
1 19cd 2 19cf
19d0 2 19be 19d1
2 19d3 19d4 1
19dc 2 19d8 19dc
1 19e1 1 19e3
2 19d5 19e4 2
19e9 19ea 1 19ee
2 19ec 19ee 2
19f3 19f9 1 1a00
1 19fb 2 1a13
1a15 3 1a11 1a12
1a17 2 1a20 1a22
2 1a24 1a26 2
1a28 1a2a 2 1a2c
1a2e 2 1a30 1a32
3 1a37 1a38 1a39
2 1a34 1a3b 2
1a1f 1a3d 1 1a3f
1 1a41 2 1a0a
1a42 1 1a46 1
1a05 2 1a03 1a4a
1 1a4d 2 1a52
1a58 1 1a5f 1
1a5a 2 1a72 1a74
3 1a70 1a71 1a76
2 1a7f 1a81 2
1a83 1a85 2 1a87
1a89 2 1a8b 1a8d
2 1a8f 1a91 3
1a96 1a97 1a98 2
1a93 1a9a 2 1a7e
1a9c 1 1a9e 1
1aa0 2 1a69 1aa1
1 1aa5 1 1a64
2 1a62 1aa9 1
1aac 2 1aaf 1ab0
1 1ab2 2 1ab8
1ab9 1 1abd 2
1abb 1abd 2 1acb
1acd 3 1ac9 1aca
1acf 2 1ad8 1ada
2 1ad7 1adc 1
1ade 1 1ae0 3
1ac2 1ae1 1ae6 2
1af3 1af5 3 1af1
1af2 1af7 2 1b00
1b02 2 1aff 1b04
1 1b06 1 1b08
3 1aea 1b09 1b0e
2 1b10 1b11 1
1b12 1 1b14 2
1b20 1b25 1 1b2c
1 1b27 2 1b3f
1b41 3 1b3d 1b3e
1b43 2 1b4c 1b4e
2 1b50 1b52 2
1b54 1b56 2 1b58
1b5a 2 1b5c 1b5e
3 1b63 1b64 1b65
2 1b60 1b67 2
1b4b 1b69 1 1b6b
1 1b6d 2 1b36
1b6e 1 1b72 1
1b31 2 1b2f 1b76
a 1930 1933 1936
199a 19e7 1ab1 1b15
1b79 1b7d 1b80 5
1b83 174b 18a2 1914
1b82 1 1b84 2
1b88 1b89 2 1b8e
1b8f 1 1b91 2
1b8b 1b91 2 1b95
1b96 1 1b9a 2
1b98 1b9a 2 1b9e
1b9f 2 1ba4 1ba5
1 1ba7 2 1ba1
1ba7 2 1bb7 1bb9
3 1bb5 1bb6 1bbb
2 1bc4 1bc6 2
1bc3 1bc8 1 1bca
1 1bcc 3 1bae
1bcd 1bd2 1 1bd4
2 1bd7 1bd8 2
1bdd 1bde 1 1be0
2 1bda 1be0 2
1bee 1bf0 3 1bec
1bed 1bf2 2 1bfb
1bfd 2 1bfa 1bff
1 1c01 1 1c03
3 1be5 1c04 1c09
1 1c0b 2 1c0e
1c0f 1 1c13 2
1c11 1c13 1 1c18
2 1c1b 1c1c 1
1c20 2 1c1e 1c20
2 1c25 1c26 1
1c2a 2 1c28 1c2a
2 1c3b 1c3d 3
1c39 1c3a 1c3f 2
1c48 1c4a 2 1c47
1c4c 1 1c4e 1
1c50 3 1c32 1c51
1c56 1 1c58 2
1c5c 1c5d 2 1c59
1c60 2 1c62 1c63
2 1c68 1c69 2
1c6e 1c6f 2 1c6b
1c71 2 1c74 1c76
2 1c79 1c7b 1
1c7d 2 1c82 1c83
2 1c88 1c89 1
1c8b 2 1c85 1c8b
2 1c98 1c9d 1
1ca4 1 1c9f 2
1cb7 1cb9 3 1cb5
1cb6 1cbb 2 1cc4
1cc6 2 1cc8 1cca
2 1ccc 1cce 2
1cd0 1cd2 2 1cd4
1cd6 3 1cdb 1cdc
1cdd 2 1cd8 1cdf
2 1cc3 1ce1 1
1ce3 1 1ce5 2
1cae 1ce6 1 1cea
1 1ca9 2 1ca7
1cee 2 1cf4 1cf5
1 1cf9 2 1cf7
1cf9 2 1d07 1d09
3 1d05 1d06 1d0b
2 1d14 1d16 2
1d13 1d18 1 1d1a
1 1d1c 3 1cfe
1d1d 1d20 1 1d22
3 1c90 1cf1 1d23
1 1d25 2 1d28
1d29 1 1d2f 2
1d2b 1d2f 2 1d33
1d34 1 1d3a 2
1d36 1d3a 1 1d41
a 1d47 1d48 1d49
1d4a 1d4b 1d4c 1d4d
1d4e 1d4f 1d50 2
1d55 1d56 1 1d5a
2 1d58 1d5a 1
1d5e 2 1d70 1d75
1 1d7c 1 1d77
2 1d8f 1d91 3
1d8d 1d8e 1d93 2
1d9c 1d9e 2 1da0
1da2 2 1da4 1da6
2 1da8 1daa 2
1dac 1dae 3 1db3
1db4 1db5 2 1db0
1db7 2 1d9b 1db9
1 1dbb 1 1dbd
2 1d86 1dbe 1
1dc2 1 1d81 2
1d7f 1dc6 1 1dc9
1 1dcc 2 1dd1
1dd2 2 1dd7 1dd8
2 1dd4 1dda 2
1ddd 1ddf 2 1de2
1de4 1 1de6 8
1dec 1ded 1dee 1def
1df0 1df1 1df2 1df3
2 1dfc 1dfd 2
1dff 1e02 5 1e08
1e09 1e0a 1e0b 1e0c
2 1e23 1e28 1
1e2f 1 1e2a 2
1e42 1e44 3 1e40
1e41 1e46 2 1e4f
1e51 2 1e53 1e55
2 1e57 1e59 2
1e5b 1e5d 2 1e5f
1e61 3 1e66 1e67
1e68 2 1e63 1e6a
2 1e4e 1e6c 1
1e6e 1 1e70 2
1e39 1e71 1 1e75
1 1e34 2 1e32
1e79 a 1e83 1e84
1e85 1e86 1e87 1e88
1e89 1e8a 1e8b 1e8c
1 1e92 2 1ea1
1ea3 3 1e9f 1ea0
1ea5 2 1eae 1eb0
2 1ead 1eb2 1
1eb4 1 1eb6 2
1eba 1ebb e 1d44
1d53 1dcd 1de9 1df6
1e05 1e0f 1e7c 1e80
1e8f 1e95 1e98 1eb7
1ebe 2 1ec7 1ec8
1 1ecc 2 1eca
1ecc 1 1ed1 1
1ed3 2 1ede 1ee1
2 1ee3 1ee6 1
1efc 2 1efb 1efc
1 1f04 1 1f0a
2 1f0c 1f0d 2
1ef9 1f0e 1 1f15
1 1f10 2 1f28
1f2a 3 1f26 1f27
1f2c 2 1f35 1f37
2 1f39 1f3b 2
1f3d 1f3f 2 1f41
1f43 2 1f45 1f47
3 1f4c 1f4d 1f4e
2 1f49 1f50 2
1f34 1f52 1 1f54
1 1f56 2 1f1f
1f57 1 1f5b 1
1f1a 2 1f18 1f5f
2 1f65 1f66 1
1f6a 2 1f68 1f6a
1 1f6f 1 1f71
6 1ec2 1ec5 1ed4
1ee9 1f62 1f72 2
1f74 1f75 6 1bd5
1c0c 1c64 1c80 1d26
1f76 2 1f79 1f78
1 1f7d 2 1f7b
1f7d 1 1f82 a
1f88 1f89 1f8a 1f8b
1f8c 1f8d 1f8e 1f8f
1f90 1f91 2 1f96
1f97 1 1f9b 2
1f99 1f9b 1 1f9f
8 1fa9 1faa 1fab
1fac 1fad 1fae 1faf
1fb0 1 1fb3 1
1fb5 1 1fb7 3
1fbe 1fbf 1fc0 1
1fc3 3 1fc6 1fc7
1fc8 1 1fcc 2
1fca 1fcc 3 1fd1
1fd2 1fd3 1 1fd6
3 1fda 1fdb 1fdc
1 1fdf 2 1fe1
1fe2 1 1fe3 2
1fe5 1fe6 1 1fe8
2 1fee 1fef 1
1ff3 2 1ff1 1ff3
2 1ffb 1ffc 2
1ffe 2001 2 2010
2015 1 201c 1
2017 2 202f 2031
3 202d 202e 2033
2 203c 203e 2
2040 2042 2 2044
2046 2 2048 204a
2 204c 204e 3
2053 2054 2055 2
2050 2057 2 203b
2059 1 205b 1
205d 2 2026 205e
1 2062 1 2021
2 201f 2066 2
2005 2069 2 2076
207b 1 2082 1
207d 2 2095 2097
3 2093 2094 2099
2 20a2 20a4 2
20a6 20a8 2 20aa
20ac 2 20ae 20b0
2 20b2 20b4 3
20b9 20ba 20bb 2
20b6 20bd 2 20a1
20bf 1 20c1 1
20c3 2 208c 20c4
1 20c8 1 2087
2 2085 20cc 1
20cf 2 20d2 20d3
2 20d7 20d8 2
20dd 20de 2 20da
20e0 2 20d4 20e3
1 20e5 2 20f3
20f4 2 20f8 20f9
8 20ec 20ed 20ee
20ef 20f0 20f1 20f6
20fb 2 2100 2101
1 2105 2 2103
2105 2 2113 2115
3 2111 2112 2117
2 2120 2122 2
211f 2124 1 2126
1 2128 3 210a
2129 212e 1 2133
2 2131 2133 1
2154 2 2153 2154
1 215c 1 2162
2 2164 2165 2
2151 2166 1 216d
1 2168 2 2180
2182 3 217e 217f
2184 2 218d 218f
2 2191 2193 2
2195 2197 2 2199
219b 2 219d 219f
3 21a4 21a5 21a6
2 21a1 21a8 2
218c 21aa 1 21ac
1 21ae 2 2177
21af 1 21b3 1
2172 2 2170 21b7
2 213a 21ba 2
21be 21bd 1 21c2
2 21d1 21d3 3
21cf 21d0 21d5 2
21de 21e0 2 21dd
21e2 1 21e4 1
21e6 2 21ea 21eb
c 1f85 1f94 1fb6
1fe7 20e6 20e9 20fe
21bf 21c5 21c8 21e7
21ee 1 21f0 2
21f3 21f4 2 21f9
21fa 1 21fc 2
21f6 21fc 2 220e
2213 1 221a 1
2215 2 222d 222f
3 222b 222c 2231
2 223a 223c 2
223e 2240 2 2242
2244 2 2246 2248
2 224a 224c 3
2251 2252 2253 2
224e 2255 2 2239
2257 1 2259 1
225b 2 2224 225c
1 2260 1 221f
2 221d 2264 2
226a 226b 1 226f
2 226d 226f 2
227d 227f 3 227b
227c 2281 2 228a
228c 2 2289 228e
1 2290 1 2292
3 2274 2293 2298
1 229a 2 229e
229f 2 22a5 22a6
2 22ab 22ac 2
22b1 22b2 1 22b4
2 22ae 22b4 2
22b8 22b9 1 22bf
2 22bb 22bf 2
22c3 22c4 1 22ca
2 22c6 22ca 2
22de 22e3 1 22ea
1 22e5 2 22fd
22ff 3 22fb 22fc
2301 2 230a 230c
2 230e 2310 2
2312 2314 2 2316
2318 2 231a 231c
3 2321 2322 2323
2 231e 2325 2
2309 2327 1 2329
1 232b 2 22f4
232c 1 2330 1
22ef 2 22ed 2334
1 2339 1 2340
1 2342 2 2345
2346 1 234a 2
2348 234a 1 234f
a 2355 2356 2357
2358 2359 235a 235b
235c 235d 235e 2
2363 2364 1 2368
2 2366 2368 1
236c 2 2380 2385
1 238c 1 2387
2 239f 23a1 3
239d 239e 23a3 2
23ac 23ae 2 23b0
23b2 2 23b4 23b6
2 23b8 23ba 2
23bc 23be 3 23c3
23c4 23c5 2 23c0
23c7 2 23ab 23c9
1 23cb 1 23cd
2 2396 23ce 1
23d2 1 2391 2
238f 23d6 2 23dd
23de 2 23e3 23e4
2 23e0 23e6 2
23eb 23ec 2 23e8
23ee 2 23d9 23f1
2 23f5 23f6 2
23fb 23fc 2 23f8
23fe 1 2401 2
2403 2404 1 240d
2 240f 2410 1
2416 2 2418 2419
2 2412 241b 2
241e 2420 1 2422
2 2428 2429 2
242e 242f 2 242b
2431 2 2436 2437
2 243c 243d 1
243f 2 2439 243f
2 2444 2445 2
244a 244b 2 2447
244d 2 2452 2453
2 244f 2455 1
2458 2 245c 245d
1 2460 2 2462
2463 8 2467 2468
2469 246a 246b 246c
246d 246e 1 2476
2 2478 2479 1
247f 2 2481 2482
2 247b 2484 2
2487 2489 1 248b
2 2494 2495 2
2497 249a 2 24a4
24a5 2 24a9 24aa
5 24a0 24a1 24a2
24a7 24ac a 24b5
24b6 24b7 24b8 24b9
24ba 24bb 24bc 24bd
24be d 2352 2361
2405 2408 2425 2434
2464 2471 248e 249d
24af 24b2 24c1 1
24c3 4 22d1 2337
2343 24c4 2 24cb
24cc 2 24ea 24eb
2 24ef 24f0 19
24d2 24d3 24d4 24d5
24d6 24d7 24d8 24d9
24da 24db 24dc 24dd
24de 24df 24e0 24e1
24e2 24e3 24e4 24e5
24e6 24e7 24e8 24ed
24f2 2 24f8 24f9
2 24ff 2500 2
2505 2506 2 2502
2508 2 2511 2516
1 251d 1 2518
2 2530 2532 3
252e 252f 2534 2
253d 253f 2 2541
2543 2 2545 2547
2 2549 254b 2
254d 254f 3 2554
2555 2556 2 2551
2558 2 253c 255a
1 255c 1 255e
2 2527 255f 1
2563 1 2522 2
2520 2567 2 2575
257a 1 2581 1
257c 2 2594 2596
3 2592 2593 2598
2 25a1 25a3 2
25a5 25a7 2 25a9
25ab 2 25ad 25af
2 25b1 25b3 3
25b8 25b9 25ba 2
25b5 25bc 2 25a0
25be 1 25c0 1
25c2 2 258b 25c3
1 25c7 1 2586
2 2584 25cb 1
25e6 2 25e5 25e6
1 25ee 1 25f4
2 25f6 25f7 2
25e3 25f8 1 25ff
1 25fa 2 2612
2614 3 2610 2611
2616 2 261f 2621
2 2623 2625 2
2627 2629 2 262b
262d 2 262f 2631
3 2636 2637 2638
2 2633 263a 2
261e 263c 1 263e
1 2640 2 2609
2641 1 2645 1
2604 2 2602 2649
1 2654 2 2650
2654 2 2665 2666
8 265d 265e 265f
2660 2661 2662 2663
2668 2 266d 266e
1 2672 2 2670
2672 2 2680 2682
3 267e 267f 2684
2 268d 268f 2
268c 2691 1 2693
1 2695 2 2699
269a 3 2677 2696
269d 1 269f 3
265a 266b 26a0 1
26a2 9 24c8 24cf
24f5 24fc 250b 256a
25ce 264c 26a3 2
26a5 26a6 2 26aa
26ab 3 26a7 26ae
26b1 1 26b7 2
26b9 26ba 1 26c0
2 26c2 26c3 2
26bc 26c5 2 26c8
26ca 2 26cd 26cf
1 26d1 1 26d4
2 26d6 26d7 2
26f3 26f4 2 26f8
26f9 19 26db 26dc
26dd 26de 26df 26e0
26e1 26e2 26e3 26e4
26e5 26e6 26e7 26e8
26e9 26ea 26eb 26ec
26ed 26ee 26ef 26f0
26f1 26f6 26fb 2
270a 270c 3 2708
2709 270e 2 2717
2719 2 2716 271b
1 271d 1 271f
2 2723 2724 a
2201 2267 229b 22a2
22a9 26d8 26fe 2701
2720 2727 2 272b
272c 2 2731 2732
1 2734 2 272e
2734 2 2738 2739
1 273d 2 273b
273d 2 2742 2743
1 2747 2 2745
2747 2 2758 275a
3 2756 2757 275c
2 2765 2767 2
2764 2769 1 276b
1 276d 3 274f
276e 2773 1 2775
1 2785 2 2784
2785 1 278d 1
2793 2 2795 2796
2 2782 2797 1
279e 1 2799 2
27b1 27b3 3 27af
27b0 27b5 2 27be
27c0 2 27c2 27c4
2 27c6 27c8 2
27ca 27cc 2 27ce
27d0 3 27d5 27d6
27d7 2 27d2 27d9
2 27bd 27db 1
27dd 1 27df 2
27a8 27e0 1 27e4
1 27a3 2 27a1
27e8 1 27fb 2
27fa 27fb 1 2803
1 2809 2 280b
280c 2 27f8 280d
1 2814 1 280f
2 2827 2829 3
2825 2826 282b 2
2834 2836 2 2838
283a 2 283c 283e
2 2840 2842 2
2844 2846 3 284b
284c 284d 2 2848
284f 2 2833 2851
1 2853 1 2855
2 281e 2856 1
285a 1 2819 2
2817 285e 3 2776
27eb 2861 2 2865
2864 1 2869 2
2878 287a 3 2876
2877 287c 2 2885
2887 2 2884 2889
1 288b 1 288d
2 2891 2892 10
10c4 10c7 110d 1239
12a4 12e1 12f6 12f9
12fc 1f7a 21f1 2866
286c 286f 288e 2895
2 28b8 28bd 1
28c4 1 28bf 2
28d7 28d9 3 28d5
28d6 28db 2 28e4
28e6 2 28e8 28ea
2 28ec 28ee 2
28f0 28f2 2 28f4
28f6 3 28fb 28fc
28fd 2 28f8 28ff
2 28e3 2901 1
2903 1 2905 2
28ce 2906 1 290a
1 28c9 2 28c7
290e 1 2919 2
2915 2919 1 291c
2 292b 292d 3
2929 292a 292f 2
2938 293a 2 2937
293c 1 293e 1
2940 3 2922 2941
2946 1 2948 2
294d 294e 1 2952
2 2950 2952 2
2965 2967 3 2963
2964 2969 2 2972
2974 2 2971 2976
1 2978 1 297a
4 2959 295c 297b
2980 1 2982 3
2911 2949 2983 3
2985 2897 2986 2
4eb 2987 1 2989
4 299d 299e 299f
29a0 2 29af 29b1
3 29ad 29ae 29b3
2 29bc 29be 2
29bb 29c0 1 29c2
1 29c4 2 29d3
29d5 3 29d1 29d2
29d7 2 29e0 29e2
2 29e4 29e6 2
29e8 29ea 2 29ec
29f0 2 29df 29f2
1 29f4 1 29f6
13 38c 3ab 3ae
3b1 3b4 3b7 3ba
434 298a 298d 2990
2993 2998 29a3 29a6
29c5 29ca 29f7 29fc
67 40 46 4c
52 59 60 67
6e 75 7c 83
8a 91 98 9f
a6 ad b2 b7
bc c1 c6 cb
d0 d5 da df
e4 e9 ee f5
fc 102 108 10e
114 119 11e 124
12a 130 136 13c
142 148 14e 154
15a 161 168 16f
175 17b 181 187
18d 193 199 19f
1a5 1ab 1b1 1b7
1bd 1c3 1c9 1cf
1d5 1db 1e1 1e7
1ed 1f3 1f9 1ff
205 20b 211 217
21d 223 22a 231
237 23e 244 24a
250 256 25c 262
268 26e 274 27a
280 287 28c 291
296 2ae 2b8 2bf

1
4
0 
2a04
0
1
a0
61
72
0 1 1 3 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1 1b 1 1d 1 1f
1 21 1 23 1 25 1 27
1 29 1 2b 1 2d 1 2f
1 31 1 33 1 35 1 37
1 39 1 1 3c 1 3e 1
40 1 42 1 44 1 46 1
48 1 4a 1 4c 1 4e 1
50 1 52 1 54 1 56 1
58 1 5a 1 5c 1 5e 1
60 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

1e9 1 0
69 1 0
233 1 0
12c 1 0
27c 1 0
c3 1 0
20d 1 0
17d 1 0
24c 1 0
9 1 0
13e 1 0
3c 1 0
1d7 1 0
2 0 1
293 1 0
b9 1 0
15 1 0
23 1 0
1fb 1 0
110 1 0
239 1 0
195 1 0
1ef 1 0
1a1 1 0
f7 1 0
1f 1 0
207 1 0
be 1 0
258 1 0
2b3 1 0
f 1 0
22c 1 0
14a 1 0
282 1 0
25e 1 0
62 1 0
201 1 0
144 1 0
116 1 0
246 1 0
1a7 1 0
183 1 0
1c5 1 0
1e3 1 0
11b 1 0
171 1 0
d7 1 0
c8 1 0
289 1 0
21f 1 0
8c 1 0
219 1 0
189 1 0
cd 1 0
138 1 0
b4 1 0
26a 1 0
156 1 0
104 1 0
7e 1 0
54 1 0
1d1 1 0
1ad 1 0
9a 1 0
28e 1 0
2ba 1 0
1f5 1 0
e6 1 0
dc 1 0
48 1 0
240 1 0
126 1 0
276 1 0
fe 1 0
5b 1 0
10a 1 0
1b 1 0
132 1 0
15c 1 0
31 1 0
d2 1 0
af 1 0
18f 1 0
1dd 1 0
4e 1 0
19b 1 0
213 1 0
1bf 1 0
f0 1 0
a8 1 0
27 1 0
42 1 0
eb 1 0
264 1 0
1b3 1 0
150 1 0
163 1 0
a1 1 0
1b9 1 0
93 1 0
85 1 0
120 1 0
252 1 0
e1 1 0
2b 1 0
77 1 0
1cb 1 0
16a 1 0
225 1 0
70 1 0
177 1 0
299 1 2
270 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_U_PARTICIPANT;
ALTER FUNCTION FC_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION SP_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
58
2 :e:
1FUNCTION:
1SP_U_PARTICIPANT:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_P_ASSIGN_ID:
132:
1H_P_SECURITY_ID:
1H_P_PLANNED_START:
1H_P_PLANNED_FINISH:
1H_P_DELAY:
10:
1H_P_UNITS:
1H_P_WORK_PERCENT:
1H_P_ACTUAL:
1H_P_RES_ID:
1H_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
11:
140:
1+:
1FPUT:
1               ENTER:: SP_U_PARTICIPANT(41) :: cplan.sql(18648) :: :
1SC_STATE:
1FC_U_PARTICIPANT:
14:
160:
1       RETURN_STATUS:: SP_U_PARTICIPANT(61) :: cplan.sql(18668) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
167:
1           EXCEPTION:: SP_U_PARTICIPANT(68) :: cplan.sql(18675) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
179:
1           EXCEPTION:: SP_U_PARTICIPANT(80) :: cplan.sql(18687) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
26f
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 6b :b a0 a5 b
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
26f
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 131 120 124 12c
ff 149 138 13c 144 11f 165 154
158 11c 160 153 181 170 174 150
17c 16f 19d 18c 190 16c 198 18b
1b9 1a8 1ac 188 1b4 1a7 1d6 1c4
1a4 1c8 1c9 1d1 1c3 1f3 1e1 1c0
1e5 1e6 1ee 1e0 213 1fe 202 1dd
206 20e 1fd 21a 21e 1fa 222 226
22a 22d 232 233 1 235 23a 23e
242 245 24a 24e 252 255 25a 25b
25d 262 265 269 26a 26f 274 277
27c 27d 282 285 289 28a 28f 292
297 298 29d 2a0 2a5 2a6 2ab 2ae
2b3 2b4 2b9 2bc 2c0 2c1 2c6 2c9
2ce 2cf 2d4 2d7 2dc 2dd 2e2 2e5
2e9 2ed 2f2 2f5 2f9 2fa 2ff 302
307 308 30d 312 313 315 31a 31b
31d 31e 323 326 32b 32c 331 334
338 33c 341 344 348 349 34e 351
356 357 35c 361 362 364 369 36a
36c 36d 372 375 37a 37b 380 383
387 38b 38f 390 392 397 398 39a
39b 3a0 3a3 3a8 3a9 3ae 3b1 3b5
3b9 3bd 3be 3c0 3c5 3c6 3c8 3c9
3ce 3d1 3d6 3d7 3dc 3df 3e3 3e7
3eb 3ec 3ee 3f3 3f4 3f6 3f7 3fc
3ff 404 405 40a 40d 411 415 419
41a 41c 421 422 424 425 42a 42d
432 433 438 43b 440 441 446 449
44d 44e 453 456 45b 45c 461 464
469 46a 46f 470 475 477 47b 47e
482 486 489 48d 491 494 497 49c
49f 4a2 4a5 4a6 4ab 4ac 1 4ae
4b3 4b7 4bb 4be 4c3 4c8 4cb 4cf
4d0 4d5 4d6 4db 4dd 4e1 4e4 4e8
4ec 4f0 4f4 4f8 4fc 500 504 508
50c 510 514 518 51c 520 524 528
52c 530 534 538 53c 540 544 548
54c 550 554 558 55b 55f 563 567
56b 56f 573 577 57b 57f 583 587
588 58a 58e 592 596 599 59d 5a1
5a4 5a7 5ac 5af 5b2 5b5 5b6 5bb
5bc 1 5be 5c3 5c7 5cb 5ce 5d3
5d8 5db 5df 5e0 5e5 5e8 5ed 5ee
5f3 5f6 5fb 5fc 601 604 608 60c
610 614 617 618 61a 61f 620 622
623 628 62b 630 631 636 639 63e
63f 644 647 64b 64c 651 654 659
65a 65f 660 665 667 66b 66e 672
676 679 67d 681 684 688 68c 68d
692 694 698 69c 69f 6a3 6a7 6aa
6ae 6b2 6b5 6b8 6bd 6c0 6c3 6c6
6c7 6cc 6cd 1 6cf 6d4 6d8 6dc
6df 6e4 6e9 6ec 6f0 6f1 6f6 6f7
6fc 700 704 707 70c 711 714 718
71c 71f 720 725 728 72d 72e 733
736 73a 73e 741 742 747 748 74d
74f 753 756 75a 75e 762 766 76a
76e 772 776 77a 786 78b 78f 793
797 79b 79d 79e 7a3 1 7a7 7ab
7af 7b2 7b6 7ba 7be 7c2 7c5 7c9
7cd 7d0 7d3 7d8 7db 7de 7e1 7e2
7e7 7e8 1 7ea 7ef 7f3 7f7 7fa
7ff 804 807 80b 80c 811 812 817
81b 81f 822 827 82c 82f 833 834
839 83c 841 842 847 84a 84e 852
855 858 859 85b 85c 861 862 867
869 86d 870 874 878 87c 880 884
888 88c 898 89d 8a1 8a5 8a9 8ad
8af 8b3 8b5 8c1 8c3 8c5 8c6 8cb
8cf 8d1 8dd 8e1 8e3 8e4 8ed 
26f
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 12 1b 1a
:2 12 :2 4 14 1d 1c :2 14 :2 4 :3 16
:2 4 :3 17 :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 15 24 15 :2 4 :2 f
1e f :2 4 f 18 17 :2 f :2 4
9 12 11 :2 9 :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 58 5e
61 :2 58 6f 89 8 :2 6f d 10
:2 6f 1a 1d :2 6f b e :2 6f 13
16 :2 6f 1b 1e :2 6f 2d 30 :2 6f
b e :2 6f 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6f b e :2 6f 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6f b e :2 6f 13
16 1f 27 :2 1f 31 :2 16 :2 6f b
e :2 6f 13 16 1f 27 :2 1f 31
:2 16 :2 6f b e :2 6f 13 16 1f
27 :2 1f 38 :2 16 :2 6f b e :2 6f
13 16 1f 27 :2 1f 32 :2 16 :2 6f
b e :2 6f 13 16 :2 6f 1b 1e
:2 6f 28 2b :2 6f 30 33 :2 6f :2 7
4e :2 4 7 :2 11 23 :2 2d 39 3c
50 52 53 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :2 7 56 :3 4 15
:2 4 17 :2 4 19 :2 4 1a :2 4 11
:2 4 11 :2 4 18 :2 4 12 :2 4 12
:2 4 :2 d 19 2a 39 4a 29 3d
48 53 29 35 41 :2 19 4 7
:2 11 23 :2 2d 39 3c 50 52 53
:2 50 :2 23 :3 7 :2 d 12 1e 61 64
:2 1e 71 74 :2 1e 78 7b :2 1e 85
88 91 99 :2 a2 :2 91 ad :2 88 :2 1e
b5 b8 :2 1e c0 c3 :2 1e c8 cb
:2 1e d0 d3 :2 1e :2 7 56 :3 4 :2 f
21 :2 2a 34 3a :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 54
56 57 :2 54 :2 26 :3 a :2 10 15 21
64 67 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 5a :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
61 64 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 57 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

26f
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:5 10 :5 11 :6 12 :6 13
:6 14 :6 15 :7 16 :7 17
:7 19 :b 1b :11 1c 1d
:2 1c :2 1d :2 1c :2 1d
:2 1c :2 1e :2 1c :2 1e
:2 1c :2 1e :2 1c :2 1e
:2 1c :2 1f :2 1c :12 1f
:2 1c :2 20 :2 1c :12 20
:2 1c :2 21 :2 1c :9 21
:2 1c :2 22 :2 1c :9 22
:2 1c :2 23 :2 1c :9 23
:2 1c :2 24 :2 1c :9 24
:2 1c :2 25 :2 1c :2 25
:2 1c :2 25 :2 1c :2 25
:2 1c :2 25 :4 1c :3 1b
:11 28 :b 29 :3 28 :3 2e
:3 2f :3 30 :3 31 :3 32
:3 33 :3 34 :3 35 :3 36
:7 38 :4 39 :3 3a :3 38
:11 3c :30 3d :3 3c :a 3f
1a :3 42 :11 43 :b 44
:17 45 :3 43 :2 47 :3 48
:3 49 4a 48 47
48 :3 4b :3 42 :2 4c
:5 4e :11 4f :b 50 :18 51
:3 4f :2 53 54 :3 55
56 54 53 54
:3 57 :2 4d :6 4c 41
:7 1 
8ef
4
:3 0 1 :3 0 2
:a 0 26a 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 26a
2 2c :2 0 13
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 268 0 12
:6 0 27 11c 0
25 4 :3 0 23
36 38 :6 0 3b
39 0 268 0
14 :6 0 18 :2 0
29 7 :3 0 3d
:7 0 40 3e 0
268 0 15 :6 0
7 :3 0 42 :7 0
45 43 0 268
0 16 :6 0 18
:2 0 2b a :3 0
47 :7 0 4b 48
49 268 0 17
:6 0 18 :2 0 2d
a :3 0 4d :7 0
51 4e 4f 268
0 19 :6 0 18
:2 0 2f a :3 0
53 :7 0 57 54
55 268 0 1a
:6 0 13 :2 0 31
a :3 0 59 :7 0
5d 5a 5b 268
0 1b :6 0 13
:2 0 35 4 :3 0
33 5f 61 :6 0
64 62 0 268
0 1c :6 0 6d
6e 0 39 4
:3 0 37 66 68
:6 0 6b 69 0
268 0 1d :6 0
73 74 0 3b
10 :3 0 11 :2 0
4 6f :7 0 72
70 0 268 0
1e :6 0 1f :3 0
20 :3 0 1f :3 0
21 :3 0 76 77
0 2 :4 0 3d
78 7a 75 7c
7b :2 0 22 :3 0
23 :3 0 7e 7f
0 24 :4 0 1f
:3 0 25 :3 0 82
83 0 2 :4 0
3f 84 86 26
:4 0 27 :2 0 28
:3 0 41 89 8b
:3 0 29 :4 0 27
:2 0 2a :4 0 44
8e 90 :3 0 27
:2 0 3 :3 0 47
92 94 :3 0 27
:2 0 2a :4 0 4a
96 98 :3 0 27
:2 0 2b :4 0 4d
9a 9c :3 0 27
:2 0 2a :4 0 50
9e a0 :3 0 27
:2 0 5 :3 0 53
a2 a4 :3 0 27
:2 0 2a :4 0 56
a6 a8 :3 0 27
:2 0 2b :4 0 59
aa ac :3 0 27
:2 0 2c :3 0 2d
:3 0 2a :4 0 27
:2 0 6 :3 0 5c
b2 b4 :3 0 27
:2 0 2a :4 0 5f
b6 b8 :3 0 2e
:4 0 62 b0 bb
2f :4 0 65 af
be 68 ae c0
:3 0 27 :2 0 2b
:4 0 6b c2 c4
:3 0 27 :2 0 2c
:3 0 2d :3 0 2a
:4 0 27 :2 0 8
:3 0 6e ca cc
:3 0 27 :2 0 2a
:4 0 71 ce d0
:3 0 2e :4 0 74
c8 d3 2f :4 0
77 c7 d6 7a
c6 d8 :3 0 27
:2 0 2b :4 0 7d
da dc :3 0 27
:2 0 2c :3 0 30
:3 0 9 :3 0 80
e0 e2 2f :4 0
82 df e5 85
de e7 :3 0 27
:2 0 2b :4 0 88
e9 eb :3 0 27
:2 0 2c :3 0 30
:3 0 b :3 0 8b
ef f1 2f :4 0
8d ee f4 90
ed f6 :3 0 27
:2 0 2b :4 0 93
f8 fa :3 0 27
:2 0 2c :3 0 30
:3 0 c :3 0 96
fe 100 2f :4 0
98 fd 103 9b
fc 105 :3 0 27
:2 0 2b :4 0 9e
107 109 :3 0 27
:2 0 2c :3 0 30
:3 0 d :3 0 a1
10d 10f 2f :4 0
a3 10c 112 a6
10b 114 :3 0 27
:2 0 2b :4 0 a9
116 118 :3 0 27
:2 0 2a :4 0 ac
11a 11c :3 0 27
:2 0 e :3 0 af
11e 120 :3 0 27
:2 0 2a :4 0 b2
122 124 :3 0 27
:2 0 31 :4 0 b5
126 128 :3 0 b8
80 12a :2 0 12c
bd 12d 7d 12c
0 12e bf 0
1c8 1f :3 0 20
:3 0 12f 130 0
1f :3 0 32 :3 0
132 133 0 33
:2 0 2 :4 0 34
:2 0 35 :2 0 33
:2 0 c1 138 13a
:3 0 c4 134 13c
131 13e 13d :2 0
22 :3 0 36 :3 0
140 141 0 24
:4 0 37 :4 0 27
:2 0 28 :3 0 c8
145 147 :3 0 cb
142 149 :2 0 14b
ce 14c 13f 14b
0 14d d0 0
1c8 12 :3 0 3
:3 0 14e 14f 0
1c8 14 :3 0 5
:3 0 151 152 0
1c8 15 :3 0 6
:3 0 154 155 0
1c8 16 :3 0 8
:3 0 157 158 0
1c8 17 :3 0 9
:3 0 15a 15b 0
1c8 19 :3 0 b
:3 0 15d 15e 0
1c8 1a :3 0 c
:3 0 160 161 0
1c8 1b :3 0 d
:3 0 163 164 0
1c8 1c :3 0 e
:3 0 166 167 0
1c8 10 :3 0 38
:3 0 169 16a 0
39 :3 0 12 :3 0
14 :3 0 15 :3 0
16 :3 0 17 :3 0
19 :3 0 1a :3 0
1b :3 0 1c :3 0
1d :3 0 d2 16c
177 16b 178 0
1c8 1f :3 0 20
:3 0 17a 17b 0
1f :3 0 32 :3 0
17d 17e 0 3a
:2 0 2 :4 0 3b
:2 0 35 :2 0 33
:2 0 dd 183 185
:3 0 e0 17f 187
17c 189 188 :2 0
22 :3 0 36 :3 0
18b 18c 0 24
:4 0 3c :4 0 27
:2 0 28 :3 0 e4
190 192 :3 0 27
:2 0 3d :4 0 e7
194 196 :3 0 27
:2 0 3e :4 0 ea
198 19a :3 0 27
:2 0 2c :3 0 30
:3 0 10 :3 0 38
:3 0 19f 1a0 0
ed 19e 1a2 2f
:4 0 ef 19d 1a5
f2 19c 1a7 :3 0
27 :2 0 3f :4 0
f5 1a9 1ab :3 0
27 :2 0 2a :4 0
f8 1ad 1af :3 0
27 :2 0 1d :3 0
fb 1b1 1b3 :3 0
27 :2 0 2a :4 0
fe 1b5 1b7 :3 0
101 18d 1b9 :2 0
1bb 104 1bc 18a
1bb 0 1bd 106
0 1c8 40 :3 0
41 :3 0 1be 1bf
0 10 :3 0 38
:3 0 1c1 1c2 0
1d :3 0 42 :3 0
108 1c0 1c6 :2 0
1c8 10c 269 10
:3 0 43 :2 0 4
1c9 1ca 0 1f
:3 0 20 :3 0 1cc
1cd 0 1f :3 0
32 :3 0 1cf 1d0
0 44 :2 0 2
:4 0 45 :2 0 35
:2 0 33 :2 0 11b
1d5 1d7 :3 0 11e
1d1 1d9 1ce 1db
1da :2 0 22 :3 0
36 :3 0 1dd 1de
0 24 :4 0 46
:4 0 27 :2 0 28
:3 0 122 1e2 1e4
:3 0 125 1df 1e6
:2 0 1ff 22 :3 0
36 :3 0 1e8 1e9
0 24 :4 0 47
:4 0 27 :2 0 10
:3 0 48 :3 0 1ee
1ef 0 128 1ed
1f1 :3 0 27 :2 0
3f :4 0 12b 1f3
1f5 :3 0 27 :2 0
10 :3 0 49 :3 0
1f8 1f9 0 12e
1f7 1fb :3 0 131
1ea 1fd :2 0 1ff
134 200 1dc 1ff
0 201 137 0
211 4a :3 0 1e
:3 0 10 :3 0 48
:3 0 4b :3 0 10
:3 0 49 :3 0 4c
:3 0 4d :4 0 4e
1 :a 0 20d :2 0
211 203 20b :2 0
f :3 0 1e :3 0
20f :2 0 211 139
213 13d 212 211
:2 0 267 4f :3 0
10 :3 0 38 :3 0
216 217 0 50
:3 0 218 219 0
25f 1f :3 0 20
:3 0 21b 21c 0
1f :3 0 32 :3 0
21e 21f 0 44
:2 0 2 :4 0 51
:2 0 35 :2 0 33
:2 0 13f 224 226
:3 0 142 220 228
21d 22a 229 :2 0
22 :3 0 36 :3 0
22c 22d 0 24
:4 0 52 :4 0 27
:2 0 28 :3 0 146
231 233 :3 0 149
22e 235 :2 0 24f
22 :3 0 36 :3 0
237 238 0 24
:4 0 53 :4 0 27
:2 0 50 :3 0 14c
23c 23e :3 0 27
:2 0 54 :4 0 14f
240 242 :3 0 27
:2 0 55 :3 0 56
:3 0 33 :2 0 57
:2 0 152 245 249
156 244 24b :3 0
159 239 24d :2 0
24f 15c 250 22b
24f 0 251 15f
0 25f 4a :3 0
1e :3 0 4b :3 0
10 :3 0 49 :3 0
4c :3 0 4d :4 0
58 1 :a 0 25b
:2 0 25f 253 259
:2 0 f :3 0 1e
:3 0 25d :2 0 25f
161 262 :3 0 262
0 262 261 25f
260 :6 0 264 1
:3 0 166 266 168
265 264 :2 0 267
16a :2 0 269 16d
269 268 1c8 267
:6 0 26a :2 0 2
2c 269 26d :3 0
26c 26a 26e :8 0

179
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3c 1
41 1 46 1
4c 1 52 1
58 1 60 1
5e 1 67 1
65 1 6c 1
79 1 85 2
88 8a 2 8d
8f 2 91 93
2 95 97 2
99 9b 2 9d
9f 2 a1 a3
2 a5 a7 2
a9 ab 2 b1
b3 2 b5 b7
2 b9 ba 2
bc bd 2 ad
bf 2 c1 c3
2 c9 cb 2
cd cf 2 d1
d2 2 d4 d5
2 c5 d7 2
d9 db 1 e1
2 e3 e4 2
dd e6 2 e8
ea 1 f0 2
f2 f3 2 ec
f5 2 f7 f9
1 ff 2 101
102 2 fb 104
2 106 108 1
10e 2 110 111
2 10a 113 2
115 117 2 119
11b 2 11d 11f
2 121 123 2
125 127 4 81
87 8c 129 1
12b 1 12d 2
137 139 3 135
136 13b 2 144
146 2 143 148
1 14a 1 14c
a 16d 16e 16f
170 171 172 173
174 175 176 2
182 184 3 180
181 186 2 18f
191 2 193 195
2 197 199 1
1a1 2 1a3 1a4
2 19b 1a6 2
1a8 1aa 2 1ac
1ae 2 1b0 1b2
2 1b4 1b6 2
18e 1b8 1 1ba
1 1bc 3 1c3
1c4 1c5 e 12e
14d 150 153 156
159 15c 15f 162
165 168 179 1bd
1c7 2 1d4 1d6
3 1d2 1d3 1d8
2 1e1 1e3 2
1e0 1e5 2 1ec
1f0 2 1f2 1f4
2 1f6 1fa 2
1eb 1fc 2 1e7
1fe 1 200 3
201 20c 210 1
1cb 2 223 225
3 221 222 227
2 230 232 2
22f 234 2 23b
23d 2 23f 241
3 246 247 248
2 243 24a 2
23a 24c 2 236
24e 1 250 4
21a 251 25a 25e
1 262 1 215
2 213 266 b
33 3a 3f 44
4a 50 56 5c
63 6a 71 
1
4
0 
26d
0
1
14
2
15
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
35 1 0
f 1 0
46 1 0
41 1 0
13 1 0
23 1 0
7 1 0
3c 1 0
52 1 0
3 1 0
65 1 0
58 1 0
4c 1 0
b 1 0
17 1 0
1b 1 0
5e 1 0
1f 1 0
2 0 1
6c 1 0
2e 1 0
0

/
SHOW ERRORS FUNCTION SP_U_PARTICIPANT;
ALTER FUNCTION SP_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_CRI_SECURITY ==
CREATE OR REPLACE FUNCTION SP_U_CRI_SECURITY wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_CRI_SECURITY:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1A_ELEMENT_ID:
132:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1A_ASSIGNMENT_COUNT:
10:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
11:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_WBS_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_CRI_TABLE:
1H_CRI_ELEMENT_TYPE:
1H_REC_USER:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_CRI_SECURITY(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_U_CRI_SECURITY(61) :: cplan.sql(18769) :: :
1:
1PMO_CNST:
1SC_TABLE_CRI:
1SC_STATE:
1FC_U_ASSIGNED_SECURITY:
14:
176:
1       RETURN_STATUS:: SP_U_CRI_SECURITY(77) :: cplan.sql(18785) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
183:
1           EXCEPTION:: SP_U_CRI_SECURITY(84) :: cplan.sql(18792) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
195:
1           EXCEPTION:: SP_U_CRI_SECURITY(96) :: cplan.sql(18804) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2e4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d :2 a0 d :2 a0 d :2 a0 d :3 a0
6b d :2 a0 6b :5 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
2e4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 132 120 ff 124
125 12d 11f 14f 13d 11c 141 142
14a 13c 16c 15a 139 15e 15f 167
159 189 177 156 17b 17c 184 176
1a6 194 173 198 199 1a1 193 1c3
1b1 190 1b5 1b6 1be 1b0 1e0 1ce
1ad 1d2 1d3 1db 1cd 1fd 1eb 1ca
1ef 1f0 1f8 1ea 219 208 20c 1e7
214 207 235 224 228 204 230 223
251 240 244 220 24c 23f 26d 25c
260 23c 268 25b 289 278 27c 258
284 277 2a5 294 298 274 2a0 293
2c1 2b0 2b4 290 2bc 2af 2dd 2cc
2d0 2ac 2d8 2cb 2f9 2e8 2ec 2c8
2f4 2e7 316 304 2e4 308 309 311
303 333 321 300 325 326 32e 320
34f 33e 342 31d 34a 33d 36c 35a
33a 35e 35f 367 359 389 377 356
37b 37c 384 376 3a5 394 398 373
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 432 420 400 424 425 42d
41f 452 43d 441 41c 445 44d 43c
459 45d 439 461 465 469 46c 471
472 1 474 479 47d 481 484 489
48d 491 494 499 49a 49c 4a1 4a4
4a8 4a9 4ae 4b3 4b6 4bb 4bc 4c1
4c4 4c8 4c9 4ce 4d1 4d6 4d7 4dc
4df 4e4 4e5 4ea 4ed 4f2 4f3 4f8
4fb 4ff 500 505 508 50d 50e 513
516 51b 51c 521 524 528 52c 531
534 538 539 53e 541 546 547 54c
551 552 554 559 55a 55c 55d 562
565 56a 56b 570 573 577 57b 580
583 587 588 58d 590 595 596 59b
5a0 5a1 5a3 5a8 5a9 5ab 5ac 5b1
5b4 5b9 5ba 5bf 5c2 5c6 5ca 5ce
5cf 5d1 5d6 5d7 5d9 5da 5df 5e2
5e7 5e8 5ed 5f0 5f4 5f8 5fc 5fd
5ff 604 605 607 608 60d 610 615
616 61b 61e 622 626 62a 62b 62d
632 633 635 636 63b 63e 643 644
649 64c 650 654 658 659 65b 660
661 663 664 669 66c 671 672 677
67a 67f 680 685 688 68c 68d 692
695 69a 69b 6a0 6a3 6a8 6a9 6ae
6af 6b4 6b6 6ba 6bd 6c1 6c5 6c8
6cc 6d0 6d3 6d6 6db 6de 6e1 6e4
6e5 6ea 6eb 1 6ed 6f2 6f6 6fa
6fd 702 707 70a 70e 70f 714 715
71a 71c 720 723 727 72c 730 734
738 73c 740 744 748 74c 750 754
758 75c 760 763 767 76b 76f 772
776 77a 77e 782 786 787 789 78d
791 795 798 79c 7a0 7a3 7a6 7ab
7ae 7b1 7b4 7b5 7ba 7bb 1 7bd
7c2 7c6 7ca 7cd 7d2 7d7 7da 7de
7df 7e4 7e7 7ec 7ed 7f2 7f5 7fa
7fb 800 803 807 80b 80f 813 816
817 819 81e 81f 821 822 827 82a
82f 830 835 838 83d 83e 843 846
84a 84b 850 853 858 859 85e 85f
864 866 86a 86d 871 875 878 87c
880 883 887 88b 88c 891 893 897
89b 89e 8a2 8a6 8a9 8ad 8b1 8b4
8b7 8bc 8bf 8c2 8c5 8c6 8cb 8cc
1 8ce 8d3 8d7 8db 8de 8e3 8e8
8eb 8ef 8f0 8f5 8f6 8fb 8ff 903
906 90b 910 913 917 91b 91e 91f
924 927 92c 92d 932 935 939 93d
940 941 946 947 94c 94e 952 955
959 95d 961 965 969 96d 971 975
979 985 98a 98e 992 996 99a 99c
99d 9a2 1 9a6 9aa 9ae 9b1 9b5
9b9 9bd 9c1 9c4 9c8 9cc 9cf 9d2
9d7 9da 9dd 9e0 9e1 9e6 9e7 1
9e9 9ee 9f2 9f6 9f9 9fe a03 a06
a0a a0b a10 a11 a16 a1a a1e a21
a26 a2b a2e a32 a33 a38 a3b a40
a41 a46 a49 a4d a51 a54 a57 a58
a5a a5b a60 a61 a66 a68 a6c a6f
a73 a77 a7b a7f a83 a87 a8b a97
a9c aa0 aa4 aa8 aac aae ab2 ab4
ac0 ac2 ac4 ac5 aca ace ad0 adc
ae0 ae2 ae3 aec 
2e4
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 15 1e 1d :2 15 :2 4 17
20 1f :2 17 :2 4 14 1d 1c :2 14
:2 4 10 19 18 :2 10 :2 4 18 21
20 :2 18 :2 4 12 1b 1a :2 12 :2 4
e 17 16 :2 e :2 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 :2 17
26 17 :2 4 :2 13 22 13 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 14
23 14 :2 4 :2 15 24 15 :2 4 :2 12
21 12 :2 4 :2 d 1c d :2 4 :2 11
20 11 :2 4 14 1d 1c :2 14 :2 4
14 1d 1c :2 14 :2 4 :2 17 26 17
:2 4 17 20 1f :2 17 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 17 26 17 :2 4 f
18 17 :2 f :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 59 5f 62
:2 59 70 8b 8 :2 70 d 10 :2 70
1a 1d :2 70 b e :2 70 13 16
:2 70 1b 1e :2 70 2d 30 :2 70 b
e :2 70 13 16 1f 26 2b 2e
:2 26 3e 41 :2 26 46 :2 1f 4f :2 16
:2 70 b e :2 70 13 16 1f 26
2b 2e :2 26 3f 42 :2 26 47 :2 1f
50 :2 16 :2 70 b e :2 70 13 16
1f 27 :2 1f 31 :2 16 :2 70 b e
:2 70 13 16 1f 27 :2 1f 31 :2 16
:2 70 b e :2 70 13 16 1f 27
:2 1f 38 :2 16 :2 70 b e :2 70 13
16 1f 27 :2 1f 32 :2 16 :2 70 b
e :2 70 13 16 :2 70 1b 1e :2 70
28 2b :2 70 30 33 :2 70 :2 7 4f
:2 4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e :2 7 57 :3 4 14 :2 4
11 :2 4 15 :2 4 12 :2 4 14 :2 1d
:2 4 :2 d 19 30 3e 49 58 :2 19
4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e 72 75 :2 1e 79 7c
:2 1e 86 89 92 9a :2 a3 :2 92 ae
:2 89 :2 1e b6 b9 :2 1e c1 c4 :2 1e
c9 cc :2 1e d6 d9 :2 1e :2 7 57
:3 4 :2 f 21 :2 2a 34 3f :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 55 57 58 :2 55 :2 26 :3 a :2 10
15 21 65 68 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5b :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 52 54 55 :2 52 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 58
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
2e4
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:7 10 :7 11 :7 12 :7 13
:7 14 :7 15 :7 16 :7 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :7 21 :7 22 :6 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :7 2b
:7 2d :b 2f :11 30 31
:2 30 :2 31 :2 30 :2 31
:2 30 :2 32 :2 30 :2 32
:2 30 :2 32 :2 30 :2 32
:2 30 :2 33 :2 30 :12 33
:2 30 :2 34 :2 30 :12 34
:2 30 :2 35 :2 30 :9 35
:2 30 :2 36 :2 30 :9 36
:2 30 :2 37 :2 30 :9 37
:2 30 :2 38 :2 30 :9 38
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :4 30 :3 2f
:11 3c :b 3d :3 3c :3 42
:3 45 :3 46 :3 47 :5 49
:b 4a :11 4c :30 4d :3 4c
:a 4f 2e :3 52 :11 53
:b 54 :17 55 :3 53 :2 57
:3 58 :3 59 5a 58
57 58 :3 5b :3 52
:2 5c :5 5e :11 5f :b 60
:18 61 :3 5f :2 63 64
:3 65 66 64 63
64 :3 67 :2 5d :6 5c
51 :7 1 
aee
4
:3 0 1 :3 0 2
:a 0 2df 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 2df
2 2c :2 0 15
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 2dd 0 12
:6 0 15 :2 0 25
4 :3 0 23 36
38 :6 0 3b 39
0 2dd 0 14
:6 0 13 :2 0 29
4 :3 0 27 3d
3f :6 0 42 40
0 2dd 0 16
:6 0 15 :2 0 2d
4 :3 0 2b 44
46 :6 0 49 47
0 2dd 0 17
:6 0 13 :2 0 31
4 :3 0 2f 4b
4d :6 0 50 4e
0 2dd 0 18
:6 0 13 :2 0 35
4 :3 0 33 52
54 :6 0 57 55
0 2dd 0 19
:6 0 13 :2 0 39
4 :3 0 37 59
5b :6 0 5e 5c
0 2dd 0 1a
:6 0 13 :2 0 3d
4 :3 0 3b 60
62 :6 0 65 63
0 2dd 0 1b
:6 0 13 :2 0 41
4 :3 0 3f 67
69 :6 0 6c 6a
0 2dd 0 1c
:6 0 1f :2 0 45
4 :3 0 43 6e
70 :6 0 73 71
0 2dd 0 1d
:6 0 1f :2 0 47
a :3 0 75 :7 0
79 76 77 2dd
0 1e :6 0 1f
:2 0 49 a :3 0
7b :7 0 7f 7c
7d 2dd 0 20
:6 0 1f :2 0 4b
a :3 0 81 :7 0
85 82 83 2dd
0 21 :6 0 1f
:2 0 4d a :3 0
87 :7 0 8b 88
89 2dd 0 22
:6 0 1f :2 0 4f
a :3 0 8d :7 0
91 8e 8f 2dd
0 23 :6 0 1f
:2 0 51 a :3 0
93 :7 0 97 94
95 2dd 0 24
:6 0 1f :2 0 53
a :3 0 99 :7 0
9d 9a 9b 2dd
0 25 :6 0 1f
:2 0 55 a :3 0
9f :7 0 a3 a0
a1 2dd 0 26
:6 0 29 :2 0 57
a :3 0 a5 :7 0
a9 a6 a7 2dd
0 27 :6 0 2b
:2 0 5b 4 :3 0
59 ab ad :6 0
b0 ae 0 2dd
0 28 :6 0 1f
:2 0 5f 4 :3 0
5d b2 b4 :6 0
b7 b5 0 2dd
0 2a :6 0 13
:2 0 61 a :3 0
b9 :7 0 bd ba
bb 2dd 0 2c
:6 0 13 :2 0 65
4 :3 0 63 bf
c1 :6 0 c4 c2
0 2dd 0 2d
:6 0 1f :2 0 69
4 :3 0 67 c6
c8 :6 0 cb c9
0 2dd 0 2e
:6 0 1f :2 0 6b
a :3 0 cd :7 0
d1 ce cf 2dd
0 2f :6 0 1f
:2 0 6d a :3 0
d3 :7 0 d7 d4
d5 2dd 0 30
:6 0 1f :2 0 6f
a :3 0 d9 :7 0
dd da db 2dd
0 31 :6 0 1f
:2 0 71 a :3 0
df :7 0 e3 e0
e1 2dd 0 32
:6 0 13 :2 0 73
a :3 0 e5 :7 0
e9 e6 e7 2dd
0 33 :6 0 f2
f3 0 77 4
:3 0 75 eb ed
:6 0 f0 ee 0
2dd 0 34 :6 0
f8 f9 0 79
10 :3 0 11 :2 0
4 f4 :7 0 f7
f5 0 2dd 0
35 :6 0 36 :3 0
37 :3 0 36 :3 0
38 :3 0 fb fc
0 2 :4 0 7b
fd ff fa 101
100 :2 0 39 :3 0
3a :3 0 103 104
0 3b :4 0 36
:3 0 3c :3 0 107
108 0 2 :4 0
7d 109 10b 3d
:4 0 3e :2 0 3f
:3 0 7f 10e 110
:3 0 40 :4 0 3e
:2 0 41 :4 0 82
113 115 :3 0 3e
:2 0 3 :3 0 85
117 119 :3 0 3e
:2 0 41 :4 0 88
11b 11d :3 0 3e
:2 0 42 :4 0 8b
11f 121 :3 0 3e
:2 0 41 :4 0 8e
123 125 :3 0 3e
:2 0 5 :3 0 91
127 129 :3 0 3e
:2 0 41 :4 0 94
12b 12d :3 0 3e
:2 0 42 :4 0 97
12f 131 :3 0 3e
:2 0 43 :3 0 44
:3 0 41 :4 0 3e
:2 0 6 :3 0 9a
137 139 :3 0 3e
:2 0 41 :4 0 9d
13b 13d :3 0 45
:4 0 a0 135 140
46 :4 0 a3 134
143 a6 133 145
:3 0 3e :2 0 42
:4 0 a9 147 149
:3 0 3e :2 0 43
:3 0 44 :3 0 41
:4 0 3e :2 0 8
:3 0 ac 14f 151
:3 0 3e :2 0 41
:4 0 af 153 155
:3 0 45 :4 0 b2
14d 158 46 :4 0
b5 14c 15b b8
14b 15d :3 0 3e
:2 0 42 :4 0 bb
15f 161 :3 0 3e
:2 0 43 :3 0 47
:3 0 9 :3 0 be
165 167 46 :4 0
c0 164 16a c3
163 16c :3 0 3e
:2 0 42 :4 0 c6
16e 170 :3 0 3e
:2 0 43 :3 0 47
:3 0 b :3 0 c9
174 176 46 :4 0
cb 173 179 ce
172 17b :3 0 3e
:2 0 42 :4 0 d1
17d 17f :3 0 3e
:2 0 43 :3 0 47
:3 0 c :3 0 d4
183 185 46 :4 0
d6 182 188 d9
181 18a :3 0 3e
:2 0 42 :4 0 dc
18c 18e :3 0 3e
:2 0 43 :3 0 47
:3 0 d :3 0 df
192 194 46 :4 0
e1 191 197 e4
190 199 :3 0 3e
:2 0 42 :4 0 e7
19b 19d :3 0 3e
:2 0 41 :4 0 ea
19f 1a1 :3 0 3e
:2 0 e :3 0 ed
1a3 1a5 :3 0 3e
:2 0 41 :4 0 f0
1a7 1a9 :3 0 3e
:2 0 48 :4 0 f3
1ab 1ad :3 0 f6
105 1af :2 0 1b1
fb 1b2 102 1b1
0 1b3 fd 0
23d 36 :3 0 37
:3 0 1b4 1b5 0
36 :3 0 49 :3 0
1b7 1b8 0 2b
:2 0 2 :4 0 4a
:2 0 4b :2 0 2b
:2 0 ff 1bd 1bf
:3 0 102 1b9 1c1
1b6 1c3 1c2 :2 0
39 :3 0 4c :3 0
1c5 1c6 0 3b
:4 0 4d :4 0 3e
:2 0 3f :3 0 106
1ca 1cc :3 0 109
1c7 1ce :2 0 1d0
10c 1d1 1c4 1d0
0 1d2 10e 0
23d 1c :3 0 4e
:4 0 1d3 1d4 0
23d 1b :3 0 3
:3 0 1d6 1d7 0
23d 1a :3 0 5
:3 0 1d9 1da 0
23d 34 :3 0 e
:3 0 1dc 1dd 0
23d 27 :3 0 4f
:3 0 50 :3 0 1e0
1e1 0 1df 1e2
0 23d 10 :3 0
51 :3 0 1e4 1e5
0 52 :3 0 27
:3 0 1b :3 0 1a
:3 0 34 :3 0 110
1e7 1ec 1e6 1ed
0 23d 36 :3 0
37 :3 0 1ef 1f0
0 36 :3 0 49
:3 0 1f2 1f3 0
53 :2 0 2 :4 0
54 :2 0 4b :2 0
2b :2 0 115 1f8
1fa :3 0 118 1f4
1fc 1f1 1fe 1fd
:2 0 39 :3 0 4c
:3 0 200 201 0
3b :4 0 55 :4 0
3e :2 0 3f :3 0
11c 205 207 :3 0
3e :2 0 56 :4 0
11f 209 20b :3 0
3e :2 0 57 :4 0
122 20d 20f :3 0
3e :2 0 43 :3 0
47 :3 0 10 :3 0
51 :3 0 214 215
0 125 213 217
46 :4 0 127 212
21a 12a 211 21c
:3 0 3e :2 0 58
:4 0 12d 21e 220
:3 0 3e :2 0 41
:4 0 130 222 224
:3 0 3e :2 0 1b
:3 0 133 226 228
:3 0 3e :2 0 41
:4 0 136 22a 22c
:3 0 139 202 22e
:2 0 230 13c 231
1ff 230 0 232
13e 0 23d 59
:3 0 5a :3 0 233
234 0 10 :3 0
51 :3 0 236 237
0 1b :3 0 5b
:3 0 140 235 23b
:2 0 23d 144 2de
10 :3 0 5c :2 0
4 23e 23f 0
36 :3 0 37 :3 0
241 242 0 36
:3 0 49 :3 0 244
245 0 5d :2 0
2 :4 0 5e :2 0
4b :2 0 2b :2 0
14f 24a 24c :3 0
152 246 24e 243
250 24f :2 0 39
:3 0 4c :3 0 252
253 0 3b :4 0
5f :4 0 3e :2 0
3f :3 0 156 257
259 :3 0 159 254
25b :2 0 274 39
:3 0 4c :3 0 25d
25e 0 3b :4 0
60 :4 0 3e :2 0
10 :3 0 61 :3 0
263 264 0 15c
262 266 :3 0 3e
:2 0 58 :4 0 15f
268 26a :3 0 3e
:2 0 10 :3 0 62
:3 0 26d 26e 0
162 26c 270 :3 0
165 25f 272 :2 0
274 168 275 251
274 0 276 16b
0 286 63 :3 0
35 :3 0 10 :3 0
61 :3 0 64 :3 0
10 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 282
:2 0 286 278 280
:2 0 f :3 0 35
:3 0 284 :2 0 286
16d 288 171 287
286 :2 0 2dc 68
:3 0 10 :3 0 51
:3 0 28b 28c 0
69 :3 0 28d 28e
0 2d4 36 :3 0
37 :3 0 290 291
0 36 :3 0 49
:3 0 293 294 0
5d :2 0 2 :4 0
6a :2 0 4b :2 0
2b :2 0 173 299
29b :3 0 176 295
29d 292 29f 29e
:2 0 39 :3 0 4c
:3 0 2a1 2a2 0
3b :4 0 6b :4 0
3e :2 0 3f :3 0
17a 2a6 2a8 :3 0
17d 2a3 2aa :2 0
2c4 39 :3 0 4c
:3 0 2ac 2ad 0
3b :4 0 6c :4 0
3e :2 0 69 :3 0
180 2b1 2b3 :3 0
3e :2 0 6d :4 0
183 2b5 2b7 :3 0
3e :2 0 6e :3 0
6f :3 0 2b :2 0
70 :2 0 186 2ba
2be 18a 2b9 2c0
:3 0 18d 2ae 2c2
:2 0 2c4 190 2c5
2a0 2c4 0 2c6
193 0 2d4 63
:3 0 35 :3 0 64
:3 0 10 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
2d0 :2 0 2d4 2c8
2ce :2 0 f :3 0
35 :3 0 2d2 :2 0
2d4 195 2d7 :3 0
2d7 0 2d7 2d6
2d4 2d5 :6 0 2d9
1 :3 0 19a 2db
19c 2da 2d9 :2 0
2dc 19e :2 0 2de
1a1 2de 2dd 23d
2dc :6 0 2df :2 0
2 2c 2de 2e2
:3 0 2e1 2df 2e3
:8 0 
1c1
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3e 1
3c 1 45 1
43 1 4c 1
4a 1 53 1
51 1 5a 1
58 1 61 1
5f 1 68 1
66 1 6f 1
6d 1 74 1
7a 1 80 1
86 1 8c 1
92 1 98 1
9e 1 a4 1
ac 1 aa 1
b3 1 b1 1
b8 1 c0 1
be 1 c7 1
c5 1 cc 1
d2 1 d8 1
de 1 e4 1
ec 1 ea 1
f1 1 fe 1
10a 2 10d 10f
2 112 114 2
116 118 2 11a
11c 2 11e 120
2 122 124 2
126 128 2 12a
12c 2 12e 130
2 136 138 2
13a 13c 2 13e
13f 2 141 142
2 132 144 2
146 148 2 14e
150 2 152 154
2 156 157 2
159 15a 2 14a
15c 2 15e 160
1 166 2 168
169 2 162 16b
2 16d 16f 1
175 2 177 178
2 171 17a 2
17c 17e 1 184
2 186 187 2
180 189 2 18b
18d 1 193 2
195 196 2 18f
198 2 19a 19c
2 19e 1a0 2
1a2 1a4 2 1a6
1a8 2 1aa 1ac
4 106 10c 111
1ae 1 1b0 1
1b2 2 1bc 1be
3 1ba 1bb 1c0
2 1c9 1cb 2
1c8 1cd 1 1cf
1 1d1 4 1e8
1e9 1ea 1eb 2
1f7 1f9 3 1f5
1f6 1fb 2 204
206 2 208 20a
2 20c 20e 1
216 2 218 219
2 210 21b 2
21d 21f 2 221
223 2 225 227
2 229 22b 2
203 22d 1 22f
1 231 3 238
239 23a a 1b3
1d2 1d5 1d8 1db
1de 1e3 1ee 232
23c 2 249 24b
3 247 248 24d
2 256 258 2
255 25a 2 261
265 2 267 269
2 26b 26f 2
260 271 2 25c
273 1 275 3
276 281 285 1
240 2 298 29a
3 296 297 29c
2 2a5 2a7 2
2a4 2a9 2 2b0
2b2 2 2b4 2b6
3 2bb 2bc 2bd
2 2b8 2bf 2
2af 2c1 2 2ab
2c3 1 2c5 4
28f 2c6 2cf 2d3
1 2d7 1 28a
2 288 2db 1f
33 3a 41 48
4f 56 5d 64
6b 72 78 7e
84 8a 90 96
9c a2 a8 af
b6 bc c3 ca
d0 d6 dc e2
e8 ef f6 
1
4
0 
2e2
0
1
14
2
29
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3c 1 0
b8 1 0
80 1 0
f 1 0
92 1 0
be 1 0
13 1 0
23 1 0
7 1 0
b1 1 0
9e 1 0
35 1 0
98 1 0
d2 1 0
c5 1 0
e4 1 0
5f 1 0
8c 1 0
d8 1 0
51 1 0
66 1 0
cc 1 0
7a 1 0
2e 1 0
3 1 0
86 1 0
de 1 0
2 0 1
a4 1 0
6d 1 0
b 1 0
58 1 0
17 1 0
74 1 0
1b 1 0
1f 1 0
4a 1 0
ea 1 0
aa 1 0
43 1 0
f1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_CRI_SECURITY;
ALTER FUNCTION SP_U_CRI_SECURITY COMPILE DEBUG;
/****************************************************************************************
 id = TSK_ASSIGN_ID
 bitflag:
        1 = Copy Schedule to Baseline (includes budgets)
        2 = Copy Planned to Schedule
        3 = Copy Proposed to Schedule
        4 = Copy Forecast to Schedule (includes budgets)
        5 = Copy Forecast  Scheduled to Planned
        6 = Move Planned to Schedule
        7 = Append Planned to Schedule
 bussiness rules:
    1. Do not copy date for completed tasks (MILESTONE_PERCENT = 100)
    2. If the task has ACTUAL do not change ETC, WORK_TODATE, SD, FD
    3. When copy Forecast Date to ..., ETC is Forecast Effort, and clear Forcast dates after copy
    4. If both Forcast dates exists ignor forcast start, consider only forcast finish and ETC
    5. Calculated Forecast Start should not be in the past (is >= NOW)
    6. When copy Forcast to and assignments exists forcast rollup wins, and clear Forcast dates after copy
    7. Actual Finish date does not rollup from Assignments to Task
    8. When copy Planned to Schedule clear Planned Dates, Duration  Effort
****************************************************************************************/
Prompt == FUNCTION FC_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION FC_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
190
2 :e:
1FUNCTION:
1FC_COMMIT_ASSIGN:
1H_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_BITFLAG:
1PLS_INTEGER:
1SH_H_ROLLUP_FLAG:
11:
1RETURN:
1H_BITFLAG:
1H_ROLLUP_FLAG:
1COALESCE:
10:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_PROJECT_ID:
132:
1H_DAYOFYEAR:
1DATE:
1H_RES_ID:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_SCHED_WORK:
1H_BILLABLE:
1H_TOTAL:
1H_DAY_MIN:
1H_MIN_PER_DAY:
1H_CHANGE_FLAG:
1H_TYPE_ID:
1H_FROM_PRJ:
1H_TSK_PRJ:
1H_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1STMT:
17999:
1H_REC_STATUS:
1CURSOR:
1C270:
1TA:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1TASK_ASSIGNMENTS:
1JOIN:
1TMT_WBS:
1W:
1PROJECT_ID:
1ELEMENT_ID:
1TASK_ID:
1BIT_FLAG:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT TA.TSK_ASSIGNMENT_ID, TA.RESOURCE_ID:n         FROM TASK_ASSIGNMENTS T+
1A JOIN TMT_WBS W:n         ON W.PROJECT_ID = TA.PROJECT_ID AND W.ELEMENT_ID =+
1 TA.TASK_ID:n         WHERE W.PROJECT_ID = h_project_id AND TA.BIT_FLAG = '0'+
1:n         AND TA.RESOURCE_TYPE = '0' AND TA.PROJECT_ASSIGNMENT_ID IS Null:
1CMM1:
1PMO_DB2M:
1REF_CURSOR:
1C27:
1DAY_YEAR:
1SCHED_MIN:
1BIT_SCHED:
1TASK_DAY_OF_YEAR:
1SELECT DAY_YEAR, SCHED_MIN, BIT_SCHED FROM TASK_DAY_OF_YEAR:n         WHERE P+
1ROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND BIT_FLAG = '0':
1C54:
1SELECT TASK_ID, TSK_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         W+
1HERE BIT_FLAG = '0' AND PROJECT_ASSIGNMENT_ID = h_id:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_COMMIT_ASSIGN(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
164:
1+:
1FPUT:
1               ENTER:: FC_COMMIT_ASSIGN(65) :: cplan.sql(18906) :: :
1MINUTE_PER_DAY:
1REC_STATUS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), REC_STATUS:n      INTO h_min_per_day, h+
1_rec_status:n      FROM TMT_WBS :n      WHERE ELEMENT_ID = h_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
182:
1           EXCEPTION:: FC_COMMIT_ASSIGN(83) :: cplan.sql(18924) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1T:
190:
1        RETURN_ERROR:: FC_COMMIT_ASSIGN(91) :: cplan.sql(18932) :: :
1STATE:: :
1CANNOT_UPDATE_LOCKED_RECORD:
1 ID:: :
193:
1                EXIT:: FC_COMMIT_ASSIGN(94) :: cplan.sql(18935) :: :
1PMODEFINES:
1PMO_RETURN_ERROR:
1FALSE:
1SC_SQL_NO_DATA:
1MILESTONE_PERCENT:
1SELECT PROJECT_ID, CASE WHEN PROJECT_ID = TASK_ID THEN 1 ELSE 0 END, CASE WHE+
1N PROJECT_ASSIGNMENT_ID IS NuLL THEN 0 ELSE 1 END:n         INTO h_project_id+
1,h_tsk_prj,h_from_prj:n         FROM TASK_ASSIGNMENTS WHERE MILESTONE_PERCENT+
1 < 10000 AND RESOURCE_TYPE='0' AND TSK_ASSIGNMENT_ID = h_id:
1111:
1           EXCEPTION:: FC_COMMIT_ASSIGN(112) :: cplan.sql(18953) :: :
18:
1118:
1      RETURN_INVALID:: FC_COMMIT_ASSIGN(119) :: cplan.sql(18960) :: :
1RECORD_NOT_FOUND:
1121:
1                EXIT:: FC_COMMIT_ASSIGN(122) :: cplan.sql(18963) :: :
1PMO_RETURN_INVALID:
1ELSIF:
1126:
1        RETURN_ERROR:: FC_COMMIT_ASSIGN(127) :: cplan.sql(18968) :: :
1PROJECT_ASSIGNMENT_EXISTS:
1129:
1                EXIT:: FC_COMMIT_ASSIGN(130) :: cplan.sql(18971) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_min_per_day FROM TMT_WBS WHERE EL+
1EMENT_ID = h_project_id:
1144:
1           EXCEPTION:: FC_COMMIT_ASSIGN(145) :: cplan.sql(18986) :: :
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S :
1WHERE TSK_ASSIGNMENT_ID = ':
1' AND MILESTONE_PERCENT < 10000 AND RESOURCE_TYPE='0' AND BIT_FLAG = '0' :
13:
1TYPE_ID:
1SC_PROPOSAL:
1SC_PROJECT:
1SCHED_START:
1PLANNED_START:
1SCHED_FINISH:
1PLANNED_FINISH:
1SCHED_DURATION:
1PLANNED_DURATION:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_EFFORT:
1ETC:
1FORECAST_DURATION:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1ASSIGN_COUNT:
1WORK_TODATE:
1UPDATE TMT_WBS SET:n            TYPE_ID         = CASE WHEN TYPE_ID = pmo_cns+
1t.SC_PROPOSAL THEN pmo_cnst.SC_PROJECT ELSE TYPE_ID END,:n            SCHED_S+
1TART     = COALESCE(PLANNED_START, SCHED_START),:n            SCHED_FINISH   +
1 = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n            SCHED_DURATION  = CAS+
1E WHEN PLANNED_DURATION = 0 THEN SCHED_DURATION ELSE PLANNED_DURATION END,:n +
1           SCHED_EFFORT    = PLANNED_EFFORT,:n            PLANNED_START   = N+
1ull,:n            PLANNED_FINISH  = Null,:n            PLANNED_DURATION = 0,+
1:n            FORECAST_START  = Null,:n            FORECAST_FINISH = Null,:n +
1           FORECAST_EFFORT = PLANNED_EFFORT,:n            ETC             = P+
1LANNED_EFFORT,:n            FORECAST_DURATION = 0:n            WHERE PROJECT_+
1ID = h_project_id AND TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo+
1_cnst.SC_TASK_TYPE2,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_+
1PERSONAL_TASK,pmo_cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_c+
1nst.SC_WBS_CHANGE_REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_W+
1BS_RISK_TASK,pmo_cnst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_+
1cnst.SC_WBS_DEFECT_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK) AND ASSIGN_COUN+
1T = 0 AND WORK_TODATE = 0 AND SCHED_EFFORT = 0:
1FOUND:
1TRUE:
1100:
1186:
1           EXCEPTION:: FC_COMMIT_ASSIGN(187) :: cplan.sql(19028) :: :
1OPEN:
1LOOP:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1SCHED_WORK:
1PLANNED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1SCHED_LABOR_COST:
1PLANNED_LABOR_COST:
1SCHED_LABOR_REVENUE:
1PLANNED_LABOR_REVENUE:
1FORECAST_LABOR_COST:
1BILLABLE:
1REGULAR_COST:
1ACTUAL_LABOR_COST:
1FORECAST_LABOR_REVENUE:
1REGULAR_RATE:
1ACTUAL_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET:n               BIT_FLAG = '2',:n               S+
1CHED_START = COALESCE(PLANNED_START, SCHED_START),:n               SCHED_FINI+
1SH = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n               SCHED_DURATION =+
1 CASE WHEN PLANNED_DURATION > 0 THEN PLANNED_DURATION ELSE SCHED_DURATION END+
1,:n               SCHED_WORK = PLANNED_WORK,:n               ETC = PLANNED_WO+
1RK,:n               BAK_START_DT = COALESCE(PLANNED_START, SCHED_START),:n   +
1            BAK_FINISH_DT = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n        +
1       BAK_WORK = PLANNED_WORK,:n               SCHED_LABOR_COST = CASE WHEN +
1PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,+
1:n               SCHED_LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00+
1 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_REVENUE END,:n               FOR+
1ECAST_LABOR_COST = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/6+
10.00) * REGULAR_COST) + ACTUAL_LABOR_COST END,:n               FORECAST_LABOR+
1_REVENUE = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * +
1REGULAR_RATE) + ACTUAL_LABOR_REVENUE END,:n               PLANNED_START = Nul+
1l, PLANNED_FINISH = Null, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n          +
1     FORECAST_START = Null, FORECAST_FINISH = Null, FORECAST_DURATION = 0:n  +
1             WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1234:
1           EXCEPTION:: FC_COMMIT_ASSIGN(235) :: cplan.sql(19076) :: :
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2':n               WHERE PROJECT_ID =+
1 h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1254:
1           EXCEPTION:: FC_COMMIT_ASSIGN(255) :: cplan.sql(19096) :: :
1CLOSE:
1271:
1           EXCEPTION:: FC_COMMIT_ASSIGN(272) :: cplan.sql(19113) :: :
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_ASSIGNMENT_BIT:n         WHERE P+
1ROJECT_ID = h_project_id AND ASSIGN_COUNT > 0 AND WORK_TODATE = 0 AND SCHED_E+
1FFORT = 0:
1292:
1           EXCEPTION:: FC_COMMIT_ASSIGN(293) :: cplan.sql(19134) :: :
12:
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S WHERE PROJECT_ID = TASK_ID AND :
1PROJECT_ID = ':
1BUDGETS:
1B:
1ESTIMATED_BASELINE3:
1ESTIMATED_BASELINE2:
1ESTIMATED_BASELINE1:
1ESTIMATED_BUDGET:
1BUDGET_BASELINE3:
1BUDGET_BASELINE2:
1BUDGET_BASELINE1:
1BUDGET:
1UPDATE BUDGETS B SET:n               B.ESTIMATED_BASELINE3 = B.ESTIMATED_BASE+
1LINE2,:n               B.ESTIMATED_BASELINE2 = B.ESTIMATED_BASELINE1,:n      +
1         B.ESTIMATED_BASELINE1 = B.ESTIMATED_BUDGET,:n               B.BUDGET+
1_BASELINE3 = B.BUDGET_BASELINE2,:n               B.BUDGET_BASELINE2 = B.BUDGE+
1T_BASELINE1,:n               B.BUDGET_BASELINE1 = B.BUDGET:n               WH+
1ERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1352:
1           EXCEPTION:: FC_COMMIT_ASSIGN(353) :: cplan.sql(19194) :: :
1BASELINE3_START:
1BASELINE2_START:
1BASELINE3_FINISH:
1BASELINE2_FINISH:
1BASELINE3_DURATION:
1BASELINE2_DURATION:
1BASELINE3_WORK:
1BASELINE2_WORK:
1BASELINE3_LABOR_COST:
1BASELINE2_LABOR_COST:
1BASELINE3_LABOR_REVENUE:
1BASELINE2_LABOR_REVENUE:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_DURATION:
1BASELINE1_WORK:
1BASELINE1_LABOR_COST:
1BASELINE1_LABOR_REVENUE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1UNRESOLVED_DURATION:
1B_REGULAR_COST:
1B_REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS TA SET:n               TA.BASELINE3_START = TA.BASELI+
1NE2_START, TA.BASELINE3_FINISH = TA.BASELINE2_FINISH, TA.BASELINE3_DURATION =+
1 TA.BASELINE2_DURATION, TA.BASELINE3_WORK = TA.BASELINE2_WORK,:n             +
1  TA.BASELINE3_LABOR_COST = TA.BASELINE2_LABOR_COST, TA.BASELINE3_LABOR_REVEN+
1UE = TA.BASELINE2_LABOR_REVENUE,:n               TA.BASELINE2_START = TA.BASE+
1LINE1_START, TA.BASELINE2_FINISH = TA.BASELINE1_FINISH, TA.BASELINE2_DURATION+
1 = TA.BASELINE1_DURATION, TA.BASELINE2_WORK = TA.BASELINE1_WORK,:n           +
1    TA.BASELINE2_LABOR_COST = TA.BASELINE1_LABOR_COST, TA.BASELINE2_LABOR_REV+
1ENUE = TA.BASELINE1_LABOR_REVENUE,:n               TA.BASELINE1_START = TA.UN+
1RESOLVED_START, TA.BASELINE1_FINISH = TA.UNRESOLVED_FINISH, TA.BASELINE1_DURA+
1TION = TA.UNRESOLVED_DURATION, TA.BASELINE1_WORK = TA.SCHED_WORK + TA.PLANNED+
1_WORK,:n               TA.BASELINE1_LABOR_COST = TA.SCHED_LABOR_COST + TA.PLA+
1NNED_LABOR_COST, TA.BASELINE1_LABOR_REVENUE = TA.SCHED_LABOR_REVENUE + TA.PLA+
1NNED_LABOR_REVENUE,:n               TA.B_REGULAR_COST = TA.REGULAR_COST, TA.B+
1_REGULAR_RATE = TA.REGULAR_RATE, TA.B_SPECIAL_COST = TA.SPECIAL_COST, TA.B_SP+
1ECIAL_RATE = TA.SPECIAL_RATE:n               WHERE TSK_ASSIGNMENT_ID = h_id:
1380:
1           EXCEPTION:: FC_COMMIT_ASSIGN(381) :: cplan.sql(19222) :: :
1PROJECT_ASSIGNMENTS:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE2_START:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_SCHED_START:
1ESTIMATED_PLANNED_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE2_FINISH:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_SCHED_FINISH:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1ESTIMATED_BASELINE2_EFFORT:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_SCHED_EFFORT:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_BASELINE3_COST:
1ESTIMATED_BASELINE2_COST:
1ESTIMATED_BASELINE1_COST:
1ESTIMATED_SCHED_COST:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_BASELINE3_REVENUE:
1ESTIMATED_BASELINE2_REVENUE:
1ESTIMATED_BASELINE1_REVENUE:
1ESTIMATED_SCHED_REVENUE:
1ESTIMATED_PLANNED_REVENUE:
1BASELINE_START:
1BASELINE_FINISH:
1BASELINE_DURATION:
1BASELINE_WORK:
1BASELINE_LABOR_COST:
1BASELINE_LABOR_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_BASELINE3_START = ES+
1TIMATED_BASELINE2_START,:n               ESTIMATED_BASELINE2_START = ESTIMATE+
1D_BASELINE1_START,:n               ESTIMATED_BASELINE1_START = CASE WHEN ESTI+
1MATED_SCHED_START IS NOT NULL THEN ESTIMATED_SCHED_START ELSE ESTIMATED_PLANN+
1ED_START END,:n               ESTIMATED_BASELINE3_FINISH = ESTIMATED_BASELINE+
12_FINISH,:n               ESTIMATED_BASELINE2_FINISH = ESTIMATED_BASELINE1_FI+
1NISH,:n               ESTIMATED_BASELINE1_FINISH = CASE WHEN ESTIMATED_SCHED_+
1FINISH IS NOT NULL THEN ESTIMATED_SCHED_FINISH ELSE ESTIMATED_PLANNED_FINISH +
1END,:n               ESTIMATED_BASELINE3_EFFORT = ESTIMATED_BASELINE2_EFFORT,+
1:n               ESTIMATED_BASELINE2_EFFORT = ESTIMATED_BASELINE1_EFFORT,:n  +
1             ESTIMATED_BASELINE1_EFFORT = CASE WHEN ESTIMATED_SCHED_EFFORT > +
10 THEN ESTIMATED_SCHED_EFFORT ELSE ESTIMATED_PLANNED_EFFORT END,:n           +
1    ESTIMATED_BASELINE3_COST = ESTIMATED_BASELINE2_COST,:n               ESTI+
1MATED_BASELINE2_COST = ESTIMATED_BASELINE1_COST,:n               ESTIMATED_BA+
1SELINE1_COST = CASE WHEN ESTIMATED_SCHED_COST > 0.00 THEN ESTIMATED_SCHED_COS+
1T ELSE ESTIMATED_PLANNED_COST END,:n               ESTIMATED_BASELINE3_REVENU+
1E = ESTIMATED_BASELINE2_REVENUE,:n               ESTIMATED_BASELINE2_REVENUE +
1= ESTIMATED_BASELINE1_REVENUE,:n               ESTIMATED_BASELINE1_REVENUE = +
1CASE WHEN ESTIMATED_SCHED_REVENUE > 0.00 THEN ESTIMATED_SCHED_REVENUE ELSE ES+
1TIMATED_PLANNED_REVENUE END,:n               BASELINE_START = UNRESOLVED_STAR+
1T,:n               BASELINE_FINISH = UNRESOLVED_FINISH,:n               BASEL+
1INE_DURATION = UNRESOLVED_DURATION,:n               BASELINE_WORK = SCHED_WOR+
1K + PLANNED_WORK,:n               BASELINE_LABOR_COST = SCHED_LABOR_COST + PL+
1ANNED_LABOR_COST,:n               BASELINE_LABOR_REVENUE = SCHED_LABOR_REVENU+
1E + PLANNED_LABOR_REVENUE:n               WHERE PROJECT_ID = h_project_id:
1421:
1           EXCEPTION:: FC_COMMIT_ASSIGN(422) :: cplan.sql(19263) :: :
1SELECT PLANNED_WORK INTO h_day_min FROM TASK_ASSIGNMENTS WHERE BIT_FLAG = '0'+
1 AND TSK_ASSIGNMENT_ID = h_id:
1442:
1           EXCEPTION:: FC_COMMIT_ASSIGN(443) :: cplan.sql(19284) :: :
1IS NULL:
1CASEEND0000:
1C_EFFORT:
1SELECT TSK_ASSIGNMENT_ID, CASE WHEN C_EFFORT = 0 THEN 0 ELSE C_EFFORT + h_wor+
1k END:n               INTO h_prj_assignment_id, h_work:n               FROM T+
1ASK_ASSIGNMENTS WHERE BIT_FLAG = '2' AND TASK_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1463:
1           EXCEPTION:: FC_COMMIT_ASSIGN(464) :: cplan.sql(19305) :: :
1IS NOT NULL:
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_id:
1488:
1           EXCEPTION:: FC_COMMIT_ASSIGN(489) :: cplan.sql(19330) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_id:
1507:
1           EXCEPTION:: FC_COMMIT_ASSIGN(508) :: cplan.sql(19349) :: :
1RESOURCE_ASSIGN_ROLES:
1RES_ASSIGNMENT_ID:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_id:
1526:
1           EXCEPTION:: FC_COMMIT_ASSIGN(527) :: cplan.sql(19368) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_id:
1545:
1           EXCEPTION:: FC_COMMIT_ASSIGN(546) :: cplan.sql(19387) :: :
1UTL_RAW:
1BIT_OR:
1UPDATE TASK_DAY_OF_YEAR SET SCHED_MIN = SCHED_MIN + h_day_min,:n             +
1        BIT_SCHED = UTL_RAW.BIT_OR(BIT_SCHED, h_bitID):n                     +
1WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_prj_assignment_id A+
1ND DAY_YEAR = h_dayofyear:
1594:
1           EXCEPTION:: FC_COMMIT_ASSIGN(595) :: cplan.sql(19436) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_id AND DAY_YEAR = h_dayofyear:
1615:
1           EXCEPTION:: FC_COMMIT_ASSIGN(616) :: cplan.sql(19457) :: :
1UPDATE TASK_DAY_OF_YEAR SET TSK_ASSIGNMENT_ID = h_prj_assignment_id WHERE PRO+
1JECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = h_dayofyea+
1r:
1634:
1           EXCEPTION:: FC_COMMIT_ASSIGN(635) :: cplan.sql(19476) :: :
1654:
1           EXCEPTION:: FC_COMMIT_ASSIGN(655) :: cplan.sql(19496) :: :
1670:
1           EXCEPTION:: FC_COMMIT_ASSIGN(671) :: cplan.sql(19512) :: :
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2', PARENT_ID = h_prj_assignment_id:n+
1               WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_id:
1690:
1           EXCEPTION:: FC_COMMIT_ASSIGN(691) :: cplan.sql(19532) :: :
1SD:
1SC_SS:
1FD:
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET:n                  BIT_FLAG = '2',:n             +
1     SD = pmo_cnst.SC_SS, FD = pmo_cnst.SC_SF,:n                  SCHED_START+
1 = PLANNED_START,:n                  SCHED_FINISH = PLANNED_FINISH,:n        +
1          SCHED_DURATION = PLANNED_DURATION,:n                  SCHED_WORK = +
1PLANNED_WORK,:n                  BAK_START_DT = PLANNED_START,:n             +
1     BAK_FINISH_DT = PLANNED_FINISH,:n                  BAK_WORK = PLANNED_WO+
1RK,:n                  SCHED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00+
1 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,:n                  SCHED_+
1LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REV+
1ENUE ELSE SCHED_LABOR_REVENUE END,:n                  ETC = PLANNED_WORK,:n  +
1                FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COS+
1T) + ACTUAL_LABOR_COST,:n                  FORECAST_LABOR_REVENUE = CASE WHEN+
1 BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTU+
1AL_LABOR_REVENUE END,:n                  PLANNED_START = NuLL, PLANNED_FINISH+
1 = NuLL, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n                  FORECAST_+
1START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n               +
1   PROJECT_ASSIGNMENT_ID = NuLL:n                  WHERE TSK_ASSIGNMENT_ID = +
1h_id AND SCHED_WORK = 0 AND PLANNED_WORK > 0:
1728:
1           EXCEPTION:: FC_COMMIT_ASSIGN(729) :: cplan.sql(19570) :: :
1U_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                     BIT_FLAG = '2',:n          +
1           SD = pmo_cnst.SC_SS,:n                     FD = pmo_cnst.SC_SF,:n +
1                    SCHED_START = PLANNED_START,:n                     SCHED_+
1FINISH = PLANNED_FINISH,:n                     SCHED_DURATION = PLANNED_DURAT+
1ION,:n                     SCHED_WORK = PLANNED_WORK,:n                     B+
1AK_START_DT = PLANNED_START,:n                     BAK_FINISH_DT = PLANNED_FI+
1NISH,:n                     BAK_WORK = PLANNED_WORK,:n                     SC+
1HED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST +
1ELSE SCHED_LABOR_COST END,:n                     SCHED_LABOR_REVENUE = CASE W+
1HEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_+
1REVENUE END,:n                     ETC = PLANNED_WORK,:n                     +
1FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COST) + ACTUAL_LABO+
1R_COST,:n                     FORECAST_LABOR_REVENUE = CASE WHEN BILLABLE = 0+
1 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTUAL_LABOR_REVE+
1NUE END,:n                     PLANNED_START = NuLL, PLANNED_FINISH = NuLL, P+
1LANNED_DURATION = 0, PLANNED_WORK = 0,:n                     FORECAST_START =+
1 NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n                     P+
1ROJECT_ASSIGNMENT_ID = h_prj_assignment_id:n                     WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1787:
1           EXCEPTION:: FC_COMMIT_ASSIGN(788) :: cplan.sql(19629) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_ASSIGNMENT_BIT WHERE ELEMENT_ID +
1= h_task_id:
1808:
1           EXCEPTION:: FC_COMMIT_ASSIGN(809) :: cplan.sql(19650) :: :
1824:
1           EXCEPTION:: FC_COMMIT_ASSIGN(825) :: cplan.sql(19666) :: :
1>:
1UPDATE TASK_ASSIGNMENTS SET C_EFFORT = h_work WHERE TSK_ASSIGNMENT_ID = h_prj+
1_assignment_id:
1844:
1           EXCEPTION:: FC_COMMIT_ASSIGN(845) :: cplan.sql(19686) :: :
1BEST:
1SELECT PROJECT_ASSIGNMENT_ID, BEST, SCHED_START, SCHED_FINISH, BILLABLE, REGU+
1LAR_COST, REGULAR_RATE:n                  INTO h_prj_assignment_id, h_sched_w+
1ork, h_start_date, h_finish_date, h_billable, h_reg_cost, h_reg_sale:n       +
1           FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID   = h_prj_assignment+
1_id:
1866:
1           EXCEPTION:: FC_COMMIT_ASSIGN(867) :: cplan.sql(19708) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = 0.0+
10:n                     WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_r+
1es_id:
1898:
1           EXCEPTION:: FC_COMMIT_ASSIGN(899) :: cplan.sql(19740) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = (h_+
1sched_work / 60.0) * h_reg_sale:n                     WHERE PROJECT_ID = h_pr+
1oject_id AND RESOURCE_ID = h_res_id:
1928:
1           EXCEPTION:: FC_COMMIT_ASSIGN(929) :: cplan.sql(19770) :: :
1957:
1           EXCEPTION:: FC_COMMIT_ASSIGN(958) :: cplan.sql(19799) :: :
1975:
1           EXCEPTION:: FC_COMMIT_ASSIGN(976) :: cplan.sql(19817) :: :
1FC_ROLLUP:
1SC_NS:
1SC_NF:
1SELECT CASE WHEN (SD <> pmo_cnst.SC_NS) AND (FD <> pmo_cnst.SC_NF) AND (TYPE_+
1ID = pmo_cnst.SC_PROPOSAL) THEN 1 ELSE 0 END:n      INTO h_change_flag:n     +
1 FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1997:
1           EXCEPTION:: FC_COMMIT_ASSIGN(998) :: cplan.sql(19839) :: :
1FC_CHANGE_PROJ_TYPE:
1RESOURCE_ASSIGNMENTS:
1ELEMENT_TYPE:
1UPDATE RESOURCE_ASSIGNMENTS SET:n      ELEMENT_TYPE  = (SELECT TYPE_ID FROM T+
1MT_WBS WHERE ELEMENT_ID = h_project_id):n      WHERE ELEMENT_ID = h_project_i+
1d:
11023:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1024) :: cplan.sql(19865) :: :
11033:
1                EXIT:: FC_COMMIT_ASSIGN(1034) :: cplan.sql(19875) :: :
0

0
0
15cc
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 51 b0 3d
b4 :2 a0 2c 6a a3 a0 1c a0
81 b0 a3 a0 1c :2 a0 51 a5
b 81 b0 a3 a0 51 a5 1c
:2 a0 6b 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a0 f4 b4 bf c8 :1a a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 a0 f4 b4 bf c8
:9 a0 12a bd b7 11 a4 b1 a0
f4 b4 bf c8 :6 a0 12a bd b7
11 a4 b1 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 :2 51
a5 b 7e 6e b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
:2 a0 6b :2 a0 a5 b 65 b7 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a :c a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b :2 a0
6b a0 a5 b 65 a0 b7 :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b :2 a0 6b :2 a0
a5 b 65 b7 :2 19 3c :6 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d b7
:2 a0 d :2 a0 51 a5 b 7e 51
b4 2e :44 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 e9 dd b3 :4 a0 e9
d3 5 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 2b b7 19 3c :39 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a0
47 :2 a0 e9 c1 :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
51 d a0 51 d a0 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 :2 19 3c :3 a0
11c 11d :6 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c a0 51 :1e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :62 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3a a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 51
:6 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
52 10 a0 3b b7 19 3c :c a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
b7 :2 19 3c b7 :2 a0 d a0 51
d b7 :2 19 3c a0 51 d :2 a0
e9 dd b3 :5 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :7 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :37 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e a0 51 d :5 a0 :2 51
a5 b d b7 19 3c b7 :2 a0
e9 dd b3 :4 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :36 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :6 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
a0 51 d :5 a0 :2 51 a5 b d
:11 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :14 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :16 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c 93 4f b0 46 b7 a6 9
4f b7 9 a4 14 :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e 51 b4 2e
:3 a0 a5 b d b7 19 3c :d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b d :2 a0 6b :4 a0 a5
b d b7 19 3c :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b 7e
51 b4 2e :2 a0 6b 51 d b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
15cc
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 53 4c 50
3a 5b 37 60 64 68 6c 89
74 78 80 84 73 b0 94 98
a0 a4 70 a8 a9 ab 93 d8
bb 90 bf c0 c8 cc d0 d3
ba 100 e3 b7 e7 e8 f0 f4
f8 fb e2 11d 10b df 10f 110
118 10a 139 128 12c 134 107 155
140 144 147 148 150 127 172 160
124 164 165 16d 15f 18f 17d 15c
181 182 18a 17c 1ac 19a 179 19e
19f 1a7 199 1c8 1b7 1bb 1c3 196
1e0 1cf 1d3 1db 1b6 1fc 1eb 1ef
1b3 1f7 1ea 218 207 20b 1e7 213
206 234 223 227 203 22f 222 250
23f 243 21f 24b 23e 26c 25b 25f
23b 267 25a 288 277 27b 257 283
276 2a4 293 297 273 29f 292 2c0
2af 2b3 28f 2bb 2ae 2dc 2cb 2cf
2ab 2d7 2ca 2f8 2e7 2eb 2c7 2f3
2e6 314 303 307 2e3 30f 302 330
31f 323 2ff 32b 31e 34c 33b 33f
31b 347 33a 368 357 35b 337 363
356 385 373 353 377 378 380 372
3a2 390 36f 394 395 39d 38f 3a9
3ad 38c 3be 3c1 3c5 3c9 3cd 3d1
3d5 3d9 3dd 3e1 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 405 409 40d 411
415 419 41d 421 425 429 42d 439
43e 440 44c 450 46e 456 45a 45e
461 469 455 475 479 452 48a 48d
491 495 499 49d 4a1 4a5 4a9 4ad
4b1 4b5 4c1 4c6 4c8 4d4 4d8 4da
4de 4ef 4f0 4f3 4f7 4fb 4ff 503
507 50b 50f 51b 520 522 52e 532
534 538 53c 53f 543 547 54a 54f
550 1 552 557 55b 55f 562 567
56b 56f 572 577 578 57a 57f 582
586 587 58c 591 594 599 59a 59f
5a2 5a6 5a7 5ac 5af 5b4 5b5 5ba
5bd 5c2 5c3 5c8 5cb 5cf 5d3 5d7
5d8 5da 5df 5e0 5e2 5e3 5e8 5eb
5f0 5f1 5f6 5f9 5fd 601 605 606
608 60d 60e 610 611 616 619 61e
61f 624 625 62a 62c 630 633 637
63b 63e 642 646 649 64c 651 654
657 65a 65b 660 661 1 663 668
66c 670 673 678 67d 680 684 685
68a 68b 690 692 696 699 69d 6a1
6a5 6a9 6ad 6b1 6b5 6b9 6c5 6c9
6cd 6d0 6d4 6d8 6da 6de 6e2 6e6
6e9 6ed 6f1 6f3 6f4 6f9 1 6fd
701 705 708 70c 710 714 718 71b
71f 723 726 729 72e 731 734 737
738 73d 73e 1 740 745 749 74d
750 755 75a 75d 761 762 767 76a
76f 770 775 778 77d 77e 783 786
78a 78b 790 793 798 799 79e 7a1
7a5 7a9 7ac 7af 7b0 7b2 7b3 7b8
7b9 7be 7c0 7c4 7c7 7c9 7cd 7cf
7db 7dd 7df 7e0 7e5 7e9 7eb 7f7
7f9 7fd 801 804 807 808 80a 80d
812 813 818 81c 820 823 827 82b
82e 831 836 839 83c 83f 840 845
846 1 848 84d 851 855 858 85d
862 865 869 86a 86f 872 877 878
87d 880 885 886 88b 88e 892 896
89a 89e 8a1 8a2 8a4 8a9 8aa 8ac
8ad 8b2 8b5 8ba 8bb 8c0 8c3 8c8
8c9 8ce 8d1 8d5 8d6 8db 8de 8e3
8e4 8e9 8ea 8ef 8f1 8f5 8f8 8fc
900 903 907 90b 90e 911 916 919
91c 91f 920 925 926 1 928 92d
931 935 938 93d 942 945 949 94a
94f 950 955 957 95b 95e 962 966
96a 96d 971 975 978 97c 980 981
983 987 989 98d 990 994 998 99b
99f 9a2 9a6 9a9 9aa 9af 9b2 9b6
9ba 9be 9c2 9c6 9ca 9ce 9d2 9d6
9da 9de 9e2 9ee 9f2 9f6 9f9 9fd
a01 a03 a07 a0b a0f a12 a16 a1a
a1c a1d a22 1 a26 a2a a2e a31
a35 a39 a3d a41 a44 a48 a4c a4f
a52 a57 a5a a5d a60 a61 a66 a67
1 a69 a6e a72 a76 a79 a7e a83
a86 a8a a8b a90 a93 a98 a99 a9e
aa1 aa6 aa7 aac aaf ab3 ab4 ab9
abc ac1 ac2 ac7 aca ace ad2 ad5
ad8 ad9 adb adc ae1 ae2 ae7 ae9
aed af0 af2 af6 af8 b04 b06 b08
b09 b0e b12 b14 b20 b22 b26 b2a
b2d b31 b34 b38 b3b b3c b41 b44
b48 b4c b4f b53 b57 b5a b5d b62
b65 b68 b6b b6c b71 b72 1 b74
b79 b7d b81 b84 b89 b8e b91 b95
b96 b9b b9e ba3 ba4 ba9 bac bb1
bb2 bb7 bba bbe bc2 bc6 bca bcd
bce bd0 bd5 bd6 bd8 bd9 bde bdf
be4 be6 bea bed bf1 bf5 bf8 bfc
c00 c03 c06 c0b c0e c11 c14 c15
c1a c1b 1 c1d c22 c26 c2a c2d
c32 c37 c3a c3e c3f c44 c45 c4a
c4c c50 c53 c57 c5b c5f c62 c66
c6a c6d c71 c72 c74 c78 c7c c7e
c82 c86 c89 c8a c8c c8f c92 c93
c98 c9b c9f ca3 ca6 ca7 ca9 cac
caf cb0 cb5 1 cb8 cbd cc1 cc5
cc8 ccc cd0 cd3 cd6 cdb cde ce1
ce4 ce5 cea ceb 1 ced cf2 cf6
cfa cfd d02 d07 d0a d0e d0f d14
d17 d1c d1d d22 d25 d2a d2b d30
d33 d37 d3b d3f d43 d46 d47 d49
d4e d4f d51 d52 d57 d5a d5f d60
d65 d68 d6d d6e d73 d76 d7a d7b
d80 d83 d88 d89 d8e d8f d94 d96
d9a d9d da1 da5 da8 dac db0 db3
db6 dbb dbe dc1 dc4 dc5 dca dcb
1 dcd dd2 dd6 dda ddd de2 de7
dea dee def df4 df5 dfa dfc e00
e03 e07 e0b e0f e12 e16 e1a e1d
e21 e25 e26 e28 e2c e2e e32 e36
e39 e3d e41 e45 e49 e4d e51 e5d
e61 e65 e68 e6c e70 e72 e76 e7a
e7e e81 e85 e89 e8b e8c e91 1
e95 e99 e9d ea0 ea4 ea8 eac eb0
eb3 eb7 ebb ebe ec1 ec6 ec9 ecc
ecf ed0 ed5 ed6 1 ed8 edd ee1
ee5 ee8 eed ef2 ef5 ef9 efa eff
f02 f07 f08 f0d f10 f15 f16 f1b
f1e f22 f23 f28 f2b f30 f31 f36
f39 f3d f41 f44 f47 f48 f4a f4b
f50 f51 f56 f58 f5c f5f f61 f65
f67 f73 f75 f77 f78 f7d f81 f83
f8f f91 f95 f9a f9d fa2 fa3 fa8
fab faf fb0 fb5 fb8 fbd fbe fc3
fc7 fc9 fcd fd1 fd5 fd9 fdd fe0
fe1 fe3 fe6 fe9 fea fef ff3 ff7
ffb fff 1003 1007 100b 100f 1013 1017
101b 101f 1023 1027 102b 102f 1033 1037
103b 103f 1043 1047 104b 104f 1053 1057
105b 105f 1063 1067 106b 106f 1073 1077
107b 107f 1083 1087 108b 108f 1093 1097
109b 109f 10a3 10a7 10ab 10af 10b3 10b7
10bb 10bf 10c3 10c7 10cb 10cf 10d3 10d7
10db 10df 10e3 10e7 10eb 10ef 10f3 10f7
10fb 10ff 110b 110f 1114 1118 111b 111c
1121 1125 1129 112c 112f 1133 1135 1139
113d 1140 1143 1147 1149 114d 1151 1154
1156 115a 115e 1162 1165 1169 116d 116f
1170 1175 1 1179 117d 1181 1184 1188
118c 1190 1194 1197 119b 119f 11a2 11a5
11aa 11ad 11b0 11b3 11b4 11b9 11ba 1
11bc 11c1 11c5 11c9 11cc 11d1 11d6 11d9
11dd 11de 11e3 11e6 11eb 11ec 11f1 11f4
11f9 11fa 11ff 1202 1206 1207 120c 120f
1214 1215 121a 121d 1221 1225 1228 122b
122c 122e 122f 1234 1235 123a 123c 1240
1243 1245 1249 124b 1257 1259 125b 125c
1261 1265 1267 1273 1275 1279 127d 1282
1286 1287 128b 128f 1293 1297 129c 12a1
12a5 12a9 12ad 12b2 12b6 12ba 12bd 12c0
12c4 12c6 12ca 12ce 12d1 12d4 12d8 12da
12de 12e2 12e5 12e9 12ed 12f0 12f4 12f7
12fb 12fe 12ff 1304 1307 130b 1311 1313
1317 131a 131e 1322 1326 132a 132e 1332
1336 133a 133e 1342 1346 134a 134e 1352
1356 135a 135e 1362 1366 136a 136e 1372
1376 137a 137e 1382 1386 138a 138e 1392
1396 139a 139e 13a2 13a6 13aa 13ae 13b2
13b6 13ba 13be 13c2 13c6 13ca 13ce 13d2
13d6 13da 13de 13e2 13e6 13ea 13ee 13f2
13f6 13fa 13fe 140a 140e 1413 1417 141a
141b 1420 1424 1428 142b 142e 1432 1434
1438 143c 143f 1442 1446 1448 144c 1450
1453 1455 1459 145d 1461 1464 1468 146c
146e 146f 1474 1 1478 147c 1480 1483
1487 148b 148f 1493 1496 149a 149e 14a1
14a4 14a9 14ac 14af 14b2 14b3 14b8 14b9
1 14bb 14c0 14c4 14c8 14cb 14d0 14d5
14d8 14dc 14dd 14e2 14e5 14ea 14eb 14f0
14f3 14f8 14f9 14fe 1501 1505 1506 150b
150e 1513 1514 1519 151c 1520 1524 1527
152a 152b 152d 152e 1533 1534 1539 153b
153f 1542 1544 1548 154a 1556 1558 155a
155b 1560 1564 1566 1572 1574 1578 157c
1580 1584 1588 158c 1598 159c 15a1 15a5
15a8 15a9 15ae 15b2 15b6 15b9 15bc 15c0
15c2 15c6 15ca 15cd 15d0 15d4 15d6 15da
15de 15e1 15e3 15e7 15eb 15ef 15f2 15f6
15fa 15fc 15fd 1602 1 1606 160a 160e
1611 1615 1619 161d 1621 1624 1628 162c
162f 1632 1637 163a 163d 1640 1641 1646
1647 1 1649 164e 1652 1656 1659 165e
1663 1666 166a 166b 1670 1673 1678 1679
167e 1681 1686 1687 168c 168f 1693 1694
1699 169c 16a1 16a2 16a7 16aa 16ae 16b2
16b5 16b8 16b9 16bb 16bc 16c1 16c2 16c7
16c9 16cd 16d0 16d2 16d6 16d8 16e4 16e6
16e8 16e9 16ee 16f2 16f4 1700 1702 1704
1708 170f 1713 1717 171c 171e 1722 1726
1729 172d 1731 1733 1737 173b 173f 1742
1746 174a 174c 174d 1752 1 1756 175a
175e 1761 1765 1769 176d 1771 1774 1778
177c 177f 1782 1787 178a 178d 1790 1791
1796 1797 1 1799 179e 17a2 17a6 17a9
17ae 17b3 17b6 17ba 17bb 17c0 17c3 17c8
17c9 17ce 17d1 17d6 17d7 17dc 17df 17e3
17e4 17e9 17ec 17f1 17f2 17f7 17fa 17fe
1802 1805 1808 1809 180b 180c 1811 1812
1817 1819 181d 1820 1822 1826 1828 1834
1836 1838 1839 183e 1842 1844 1850 1852
1854 1858 185b 185f 1863 1867 186b 186f
1873 1877 187b 187f 188b 188f 1894 1898
189b 189c 18a1 18a5 18a9 18ac 18af 18b3
18b5 18b9 18bd 18c0 18c3 18c7 18c9 18cd
18d1 18d4 18d6 18da 18de 18e2 18e5 18e9
18ed 18ef 18f0 18f5 1 18f9 18fd 1901
1904 1908 190c 1910 1914 1917 191b 191f
1922 1925 192a 192d 1930 1933 1934 1939
193a 1 193c 1941 1945 1949 194c 1951
1956 1959 195d 195e 1963 1966 196b 196c
1971 1974 1979 197a 197f 1982 1986 1987
198c 198f 1994 1995 199a 199d 19a1 19a5
19a8 19ab 19ac 19ae 19af 19b4 19b5 19ba
19bc 19c0 19c3 19c5 19c9 19cb 19d7 19d9
19db 19dc 19e1 19e5 19e7 19f3 19f5 19f9
19fc 1a00 1a04 1a07 1a0b 1a0f 1a14 1a17
1a1c 1a1d 1a22 1a25 1a29 1a2a 1a2f 1a32
1a37 1a38 1a3d 1a41 1a43 1a47 1a4b 1a4e
1a52 1a56 1a5a 1a5d 1a61 1a65 1a69 1a6d
1a71 1a75 1a79 1a7e 1a83 1a87 1a8b 1a8f
1a94 1a98 1a9c 1a9f 1aa2 1aa6 1aa8 1aac
1ab0 1ab3 1ab6 1aba 1abc 1ac0 1ac4 1ac7
1acb 1acf 1ad2 1ad6 1ad9 1add 1ae0 1ae1
1ae6 1ae9 1aed 1af3 1af5 1af9 1afc 1b00
1b03 1b07 1b0b 1b0f 1b13 1b17 1b1b 1b1f
1b23 1b27 1b2b 1b2f 1b33 1b37 1b3b 1b3f
1b43 1b47 1b4b 1b4f 1b53 1b57 1b5b 1b5f
1b63 1b67 1b6b 1b6f 1b73 1b77 1b7b 1b87
1b8b 1b90 1b94 1b97 1b98 1b9d 1ba1 1ba5
1ba8 1bab 1baf 1bb1 1bb5 1bb9 1bbc 1bbf
1bc3 1bc5 1bc9 1bcd 1bd0 1bd2 1bd6 1bda
1bde 1be1 1be5 1be9 1beb 1bec 1bf1 1
1bf5 1bf9 1bfd 1c00 1c04 1c08 1c0c 1c10
1c13 1c17 1c1b 1c1e 1c21 1c26 1c29 1c2c
1c2f 1c30 1c35 1c36 1 1c38 1c3d 1c41
1c45 1c48 1c4d 1c52 1c55 1c59 1c5a 1c5f
1c62 1c67 1c68 1c6d 1c70 1c75 1c76 1c7b
1c7e 1c82 1c83 1c88 1c8b 1c90 1c91 1c96
1c99 1c9d 1ca1 1ca4 1ca7 1ca8 1caa 1cab
1cb0 1cb1 1cb6 1cb8 1cbc 1cbf 1cc1 1cc5
1cc7 1cd3 1cd5 1cd7 1cd8 1cdd 1ce1 1ce3
1cef 1cf1 1cf5 1cf9 1cfd 1d01 1d05 1d09
1d0d 1d11 1d15 1d19 1d1d 1d21 1d25 1d29
1d2d 1d31 1d35 1d39 1d3d 1d41 1d45 1d49
1d4d 1d51 1d55 1d59 1d5d 1d61 1d65 1d69
1d6d 1d71 1d75 1d79 1d7d 1d81 1d85 1d89
1d8d 1d91 1d95 1d99 1d9d 1da1 1da5 1da9
1dad 1db1 1db5 1db9 1dbd 1dc1 1dc5 1dc9
1dcd 1dd1 1dd5 1dd9 1ddd 1de1 1de5 1de9
1ded 1df1 1df5 1df9 1dfd 1e01 1e05 1e09
1e0d 1e11 1e15 1e19 1e1d 1e21 1e25 1e29
1e2d 1e31 1e35 1e39 1e3d 1e41 1e45 1e49
1e4d 1e51 1e55 1e59 1e5d 1e61 1e65 1e69
1e6d 1e71 1e75 1e79 1e85 1e89 1e8e 1e92
1e95 1e96 1e9b 1e9f 1ea3 1ea6 1ea9 1ead
1eaf 1eb3 1eb7 1eba 1ebd 1ec1 1ec3 1ec7
1ecb 1ece 1ed0 1ed4 1ed8 1edc 1edf 1ee3
1ee7 1ee9 1eea 1eef 1 1ef3 1ef7 1efb
1efe 1f02 1f06 1f0a 1f0e 1f11 1f15 1f19
1f1c 1f1f 1f24 1f27 1f2a 1f2d 1f2e 1f33
1f34 1 1f36 1f3b 1f3f 1f43 1f46 1f4b
1f50 1f53 1f57 1f58 1f5d 1f60 1f65 1f66
1f6b 1f6e 1f73 1f74 1f79 1f7c 1f80 1f81
1f86 1f89 1f8e 1f8f 1f94 1f97 1f9b 1f9f
1fa2 1fa5 1fa6 1fa8 1fa9 1fae 1faf 1fb4
1fb6 1fba 1fbd 1fbf 1fc3 1fc5 1fd1 1fd3
1fd5 1fd6 1fdb 1fdf 1fe1 1fed 1fef 1ff3
1ff7 1ffb 1fff 2003 2007 200b 200f 2013
2017 201b 201f 2023 2027 202b 202f 2033
2037 203b 203f 2043 2047 204b 204f 2053
2057 205b 205f 2063 2067 206b 206f 2073
2077 207b 207f 2083 2087 208b 208f 2093
2097 209b 209f 20a3 20a7 20ab 20af 20b3
20b7 20bb 20bf 20c3 20c7 20cb 20cf 20d3
20d7 20e3 20e7 20ec 20f0 20f3 20f4 20f9
20fd 2101 2104 2107 210b 210d 2111 2115
2118 211b 211f 2121 2125 2129 212c 212e
2132 2136 213a 213d 2141 2145 2147 2148
214d 1 2151 2155 2159 215c 2160 2164
2168 216c 216f 2173 2177 217a 217d 2182
2185 2188 218b 218c 2191 2192 1 2194
2199 219d 21a1 21a4 21a9 21ae 21b1 21b5
21b6 21bb 21be 21c3 21c4 21c9 21cc 21d1
21d2 21d7 21da 21de 21df 21e4 21e7 21ec
21ed 21f2 21f5 21f9 21fd 2200 2203 2204
2206 2207 220c 220d 2212 2214 2218 221b
221d 2221 2223 222f 2231 2233 2234 2239
223d 223f 224b 224d 224f 2250 2255 2258
225c 2260 2264 2268 226c 2270 227c 2280
2284 2287 228b 228f 2291 2295 2299 229d
22a0 22a4 22a8 22aa 22ab 22b0 1 22b4
22b8 22bc 22bf 22c3 22c7 22cb 22cf 22d2
22d6 22da 22dd 22e0 22e5 22e8 22eb 22ee
22ef 22f4 22f5 1 22f7 22fc 2300 2304
2307 230c 2311 2314 2318 2319 231e 2321
2326 2327 232c 232f 2334 2335 233a 233d
2341 2342 2347 234a 234f 2350 2355 2358
235c 2360 2363 2366 2367 2369 236a 236f
2370 2375 2377 237b 237e 2380 2384 2386
2392 2394 2396 2397 239c 23a0 23a2 23ae
23b0 23b4 23b8 23bb 23bf 23c2 23c6 23c9
23ca 23cf 23d2 23d6 23d9 23da 23df 23e2
1 23e5 23ea 23ee 23f4 23f6 23fa 23fd
2401 2405 2409 240d 2411 2415 2419 241d
2421 2425 2429 242d 2439 243d 2441 2444
2448 244c 244e 2452 2456 245a 245d 2461
2465 2467 2468 246d 1 2471 2475 2479
247c 2480 2484 2488 248c 248f 2493 2497
249a 249d 24a2 24a5 24a8 24ab 24ac 24b1
24b2 1 24b4 24b9 24bd 24c1 24c4 24c9
24ce 24d1 24d5 24d6 24db 24de 24e3 24e4
24e9 24ec 24f1 24f2 24f7 24fa 24fe 24ff
2504 2507 250c 250d 2512 2515 2519 251d
2520 2523 2524 2526 2527 252c 252d 2532
2534 2538 253b 253d 2541 2543 254f 2551
2553 2554 2559 255d 255f 256b 256d 2571
2575 2578 257c 257f 2583 2586 2587 258c
258f 2593 2596 2597 259c 259f 1 25a2
25a7 25ab 25af 25b2 25b3 25b5 25b8 25bb
25bc 25c1 25c5 25c8 25cc 25ce 25d2 25d6
25da 25e6 25ea 25ef 25f3 25f6 25f7 25fc
2600 2604 2607 260a 260e 2610 2614 2618
261b 261e 2622 2624 2628 262c 262f 2631
2635 2639 263d 2640 2644 2648 264a 264b
2650 1 2654 2658 265c 265f 2663 2667
266b 266f 2672 2676 267a 267d 2680 2685
2688 268b 268e 268f 2694 2695 1 2697
269c 26a0 26a4 26a7 26ac 26b1 26b4 26b8
26b9 26be 26c1 26c6 26c7 26cc 26cf 26d4
26d5 26da 26dd 26e1 26e2 26e7 26ea 26ef
26f0 26f5 26f8 26fc 2700 2703 2706 2707
2709 270a 270f 2710 2715 2717 271b 271e
2720 2724 2726 2732 2734 2736 2737 273c
2740 2742 274e 2750 2754 2758 275c 2768
276c 2771 2775 2778 2779 277e 2782 2786
2789 278c 2790 2792 2796 279a 279d 27a0
27a4 27a6 27aa 27ae 27b1 27b3 27b7 27bb
27bf 27c2 27c6 27ca 27cc 27cd 27d2 1
27d6 27da 27de 27e1 27e5 27e9 27ed 27f1
27f4 27f8 27fc 27ff 2802 2807 280a 280d
2810 2811 2816 2817 1 2819 281e 2822
2826 2829 282e 2833 2836 283a 283b 2840
2843 2848 2849 284e 2851 2856 2857 285c
285f 2863 2864 2869 286c 2871 2872 2877
287a 287e 2882 2885 2888 2889 288b 288c
2891 2892 2897 2899 289d 28a0 28a2 28a6
28a8 28b4 28b6 28b8 28b9 28be 28c2 28c4
28d0 28d2 28d6 28da 28de 28ea 28ee 28f3
28f7 28fa 28fb 2900 2904 2908 290b 290e
2912 2914 2918 291c 291f 2922 2926 2928
292c 2930 2933 2935 2939 293d 2941 2944
2948 294c 294e 294f 2954 1 2958 295c
2960 2963 2967 296b 296f 2973 2976 297a
297e 2981 2984 2989 298c 298f 2992 2993
2998 2999 1 299b 29a0 29a4 29a8 29ab
29b0 29b5 29b8 29bc 29bd 29c2 29c5 29ca
29cb 29d0 29d3 29d8 29d9 29de 29e1 29e5
29e6 29eb 29ee 29f3 29f4 29f9 29fc 2a00
2a04 2a07 2a0a 2a0b 2a0d 2a0e 2a13 2a14
2a19 2a1b 2a1f 2a22 2a24 2a28 2a2a 2a36
2a38 2a3a 2a3b 2a40 2a44 2a46 2a52 2a54
2a58 2a5c 2a60 2a6c 2a70 2a75 2a79 2a7c
2a7d 2a82 2a86 2a8a 2a8d 2a90 2a94 2a96
2a9a 2a9e 2aa1 2aa4 2aa8 2aaa 2aae 2ab2
2ab5 2ab7 2abb 2abf 2ac3 2ac6 2aca 2ace
2ad0 2ad1 2ad6 1 2ada 2ade 2ae2 2ae5
2ae9 2aed 2af1 2af5 2af8 2afc 2b00 2b03
2b06 2b0b 2b0e 2b11 2b14 2b15 2b1a 2b1b
1 2b1d 2b22 2b26 2b2a 2b2d 2b32 2b37
2b3a 2b3e 2b3f 2b44 2b47 2b4c 2b4d 2b52
2b55 2b5a 2b5b 2b60 2b63 2b67 2b68 2b6d
2b70 2b75 2b76 2b7b 2b7e 2b82 2b86 2b89
2b8c 2b8d 2b8f 2b90 2b95 2b96 2b9b 2b9d
2ba1 2ba4 2ba6 2baa 2bac 2bb8 2bba 2bbc
2bbd 2bc2 2bc6 2bc8 2bd4 2bd6 2bda 2bdd
2be1 2be3 2be7 2beb 2bee 2bf0 2bf4 2bf8
2bfc 2c00 2c03 2c07 2c09 2c0d 2c11 2c14
2c18 2c1b 2c1f 2c23 2c27 2c2c 2c30 2c31
2c35 2c39 2c3d 2c41 2c45 2c4a 2c4f 2c53
2c57 2c5b 2c60 2c64 2c68 2c6b 2c6e 2c72
2c74 2c78 2c7c 2c7f 2c82 2c86 2c88 2c8c
2c90 2c93 2c97 2c9b 2c9e 2ca2 2ca5 2ca9
2cac 2cad 2cb2 2cb5 2cb9 2cbf 2cc1 2cc5
2cc8 2ccc 2cd0 2cd3 2cd4 2cd6 2cd9 2cdc
2cdd 2ce2 2ce6 2cea 2cee 2cf2 2cf6 2cfa
2cfe 2d02 2d06 2d0a 2d0e 2d12 2d16 2d1a
2d1e 2d2a 2d2e 2d33 2d37 2d3a 2d3b 2d40
2d44 2d48 2d4b 2d4e 2d52 2d54 2d58 2d5c
2d5f 2d62 2d66 2d68 2d6c 2d70 2d73 2d75
2d79 2d7d 2d81 2d84 2d88 2d8c 2d8e 2d8f
2d94 1 2d98 2d9c 2da0 2da3 2da7 2dab
2daf 2db3 2db6 2dba 2dbe 2dc1 2dc4 2dc9
2dcc 2dcf 2dd2 2dd3 2dd8 2dd9 1 2ddb
2de0 2de4 2de8 2deb 2df0 2df5 2df8 2dfc
2dfd 2e02 2e05 2e0a 2e0b 2e10 2e13 2e18
2e19 2e1e 2e21 2e25 2e26 2e2b 2e2e 2e33
2e34 2e39 2e3c 2e40 2e44 2e47 2e4a 2e4b
2e4d 2e4e 2e53 2e54 2e59 2e5b 2e5f 2e62
2e64 2e68 2e6a 2e76 2e78 2e7a 2e7b 2e80
2e84 2e86 2e92 2e94 2e98 2e9c 2e9f 2ea3
2ea6 2eaa 2ead 2eae 2eb3 2eb6 2eba 2ebe
2ec2 2ec6 2eca 2ece 2ed2 2ede 2ee2 2ee7
2eeb 2eee 2eef 2ef4 2ef8 2efc 2eff 2f02
2f06 2f08 2f0c 2f10 2f13 2f16 2f1a 2f1c
2f20 2f24 2f27 2f29 2f2d 2f31 2f35 2f38
2f3c 2f40 2f42 2f43 2f48 1 2f4c 2f50
2f54 2f57 2f5b 2f5f 2f63 2f67 2f6a 2f6e
2f72 2f75 2f78 2f7d 2f80 2f83 2f86 2f87
2f8c 2f8d 1 2f8f 2f94 2f98 2f9c 2f9f
2fa4 2fa9 2fac 2fb0 2fb1 2fb6 2fb9 2fbe
2fbf 2fc4 2fc7 2fcc 2fcd 2fd2 2fd5 2fd9
2fda 2fdf 2fe2 2fe7 2fe8 2fed 2ff0 2ff4
2ff8 2ffb 2ffe 2fff 3001 3002 3007 3008
300d 300f 3013 3016 3018 301c 301e 302a
302c 302e 302f 3034 3038 303a 3046 3048
304a 304e 3052 3056 305a 305e 3062 3066
306a 306e 307a 307e 3083 3087 308a 308b
3090 3094 3098 309b 309e 30a2 30a4 30a8
30ac 30af 30b2 30b6 30b8 30bc 30c0 30c3
30c5 30c9 30cd 30d1 30d4 30d8 30dc 30de
30df 30e4 1 30e8 30ec 30f0 30f3 30f7
30fb 30ff 3103 3106 310a 310e 3111 3114
3119 311c 311f 3122 3123 3128 3129 1
312b 3130 3134 3138 313b 3140 3145 3148
314c 314d 3152 3155 315a 315b 3160 3163
3168 3169 316e 3171 3175 3176 317b 317e
3183 3184 3189 318c 3190 3194 3197 319a
319b 319d 319e 31a3 31a4 31a9 31ab 31af
31b2 31b4 31b8 31ba 31c6 31c8 31ca 31cb
31d0 31d4 31d6 31e2 31e4 31e6 31ea 31ee
31f1 31f5 31f7 31fb 31ff 3202 3203 3205
3208 320b 320c 3211 3215 3219 321d 3221
3225 3229 322d 3231 3235 3241 3245 324a
324e 3251 3252 3257 325b 325f 3262 3265
3269 326b 326f 3273 3276 3279 327d 327f
3283 3287 328a 328c 3290 3294 3298 329b
329f 32a3 32a5 32a6 32ab 1 32af 32b3
32b7 32ba 32be 32c2 32c6 32ca 32cd 32d1
32d5 32d8 32db 32e0 32e3 32e6 32e9 32ea
32ef 32f0 1 32f2 32f7 32fb 32ff 3302
3307 330c 330f 3313 3314 3319 331c 3321
3322 3327 332a 332f 3330 3335 3338 333c
333d 3342 3345 334a 334b 3350 3353 3357
335b 335e 3361 3362 3364 3365 336a 336b
3370 3372 3376 3379 337b 337f 3381 338d
338f 3391 3392 3397 339b 339d 33a9 33ab
33ad 33b1 33b5 33b8 33ba 33be 33c5 33c9
33cd 33d2 33d4 33d8 33dc 33df 33e3 33e7
33e9 33ed 33f1 33f5 33f8 33fc 3400 3402
3403 3408 1 340c 3410 3414 3417 341b
341f 3423 3427 342a 342e 3432 3435 3438
343d 3440 3443 3446 3447 344c 344d 1
344f 3454 3458 345c 345f 3464 3469 346c
3470 3471 3476 3479 347e 347f 3484 3487
348c 348d 3492 3495 3499 349a 349f 34a2
34a7 34a8 34ad 34b0 34b4 34b8 34bb 34be
34bf 34c1 34c2 34c7 34c8 34cd 34cf 34d3
34d6 34d8 34dc 34de 34ea 34ec 34ee 34ef
34f4 34f8 34fa 3506 3508 350c 3510 3514
3518 351c 3520 3524 3528 3534 3538 353d
3541 3544 3545 354a 354e 3552 3555 3558
355c 355e 3562 3566 3569 356c 3570 3572
3576 357a 357d 357f 3583 3587 358b 358e
3592 3596 3598 3599 359e 1 35a2 35a6
35aa 35ad 35b1 35b5 35b9 35bd 35c0 35c4
35c8 35cb 35ce 35d3 35d6 35d9 35dc 35dd
35e2 35e3 1 35e5 35ea 35ee 35f2 35f5
35fa 35ff 3602 3606 3607 360c 360f 3614
3615 361a 361d 3622 3623 3628 362b 362f
3630 3635 3638 363d 363e 3643 3646 364a
364e 3651 3654 3655 3657 3658 365d 365e
3663 3665 3669 366c 366e 3672 3674 3680
3682 3684 3685 368a 368e 3690 369c 369e
36a2 36a6 36a9 36aa 36ac 36af 36b2 36b3
36b8 36bc 36c0 36c4 36c8 36cc 36d0 36d4
36d8 36dc 36e0 36e4 36e8 36ec 36f0 36f4
36f8 36fc 3700 3704 3708 370c 3710 3714
3718 371c 3720 3724 3728 372c 3730 3734
3738 373c 3740 3744 3748 374c 3750 3754
3758 375c 3760 3764 3768 376c 3770 3774
3778 377c 3780 3784 3788 378c 3790 3794
37a0 37a4 37a9 37ad 37b0 37b1 37b6 37ba
37be 37c1 37c4 37c8 37ca 37ce 37d2 37d5
37d8 37dc 37de 37e2 37e6 37e9 37eb 37ef
37f3 37f7 37fa 37fe 3802 3804 3805 380a
1 380e 3812 3816 3819 381d 3821 3825
3829 382c 3830 3834 3837 383a 383f 3842
3845 3848 3849 384e 384f 1 3851 3856
385a 385e 3861 3866 386b 386e 3872 3873
3878 387b 3880 3881 3886 3889 388e 388f
3894 3897 389b 389c 38a1 38a4 38a9 38aa
38af 38b2 38b6 38ba 38bd 38c0 38c1 38c3
38c4 38c9 38ca 38cf 38d1 38d5 38d8 38da
38de 38e0 38ec 38ee 38f0 38f1 38f6 38fa
38fc 3908 390a 390e 3912 3915 3916 3918
391b 391e 391f 3924 3928 392b 392f 3933
3937 393b 393f 3943 3946 3949 394a 394c
3950 3952 3956 3959 395b 395f 3963 3968
396c 396d 3971 3975 3979 397d 3982 3987
398b 398f 3993 3998 399c 39a0 39a3 39a6
39aa 39ac 39b0 39b4 39b7 39ba 39be 39c0
39c4 39c8 39cb 39cf 39d3 39d6 39da 39dd
39e1 39e4 39e5 39ea 39ed 39f1 39f7 39f9
39fd 3a00 3a04 3a08 3a0c 3a10 3a14 3a18
3a1c 3a20 3a24 3a28 3a2c 3a30 3a34 3a38
3a3c 3a40 3a44 3a48 3a4c 3a50 3a54 3a58
3a5c 3a60 3a64 3a68 3a6c 3a70 3a74 3a78
3a7c 3a80 3a84 3a88 3a8c 3a90 3a94 3a98
3a9c 3aa0 3aa4 3aa8 3aac 3ab0 3ab4 3ab8
3abc 3ac0 3ac4 3ac8 3acc 3ad0 3ad4 3ad8
3ae4 3ae8 3aed 3af1 3af4 3af5 3afa 3afe
3b02 3b05 3b08 3b0c 3b0e 3b12 3b16 3b19
3b1c 3b20 3b22 3b26 3b2a 3b2d 3b2f 3b33
3b37 3b3b 3b3e 3b42 3b46 3b48 3b49 3b4e
1 3b52 3b56 3b5a 3b5d 3b61 3b65 3b69
3b6d 3b70 3b74 3b78 3b7b 3b7e 3b83 3b86
3b89 3b8c 3b8d 3b92 3b93 1 3b95 3b9a
3b9e 3ba2 3ba5 3baa 3baf 3bb2 3bb6 3bb7
3bbc 3bbf 3bc4 3bc5 3bca 3bcd 3bd2 3bd3
3bd8 3bdb 3bdf 3be0 3be5 3be8 3bed 3bee
3bf3 3bf6 3bfa 3bfe 3c01 3c04 3c05 3c07
3c08 3c0d 3c0e 3c13 3c15 3c19 3c1c 3c1e
3c22 3c24 3c30 3c32 3c34 3c35 3c3a 3c3e
3c40 3c4c 3c4e 3c52 3c56 3c5a 3c5e 3c62
3c66 3c72 3c76 3c7b 3c7f 3c82 3c83 3c88
3c8c 3c90 3c93 3c96 3c9a 3c9c 3ca0 3ca4
3ca7 3caa 3cae 3cb0 3cb4 3cb8 3cbb 3cbd
3cc1 3cc5 3cc9 3ccc 3cd0 3cd4 3cd6 3cd7
3cdc 1 3ce0 3ce4 3ce8 3ceb 3cef 3cf3
3cf7 3cfb 3cfe 3d02 3d06 3d09 3d0c 3d11
3d14 3d17 3d1a 3d1b 3d20 3d21 1 3d23
3d28 3d2c 3d30 3d33 3d38 3d3d 3d40 3d44
3d45 3d4a 3d4d 3d52 3d53 3d58 3d5b 3d60
3d61 3d66 3d69 3d6d 3d6e 3d73 3d76 3d7b
3d7c 3d81 3d84 3d88 3d8c 3d8f 3d92 3d93
3d95 3d96 3d9b 3d9c 3da1 3da3 3da7 3daa
3dac 3db0 3db2 3dbe 3dc0 3dc2 3dc3 3dc8
3dcc 3dce 3dda 3ddc 3dde 3de2 3de9 3ded
3df1 3df6 3df8 3dfc 3e00 3e03 3e07 3e0b
3e0d 3e11 3e15 3e19 3e1c 3e20 3e24 3e26
3e27 3e2c 1 3e30 3e34 3e38 3e3b 3e3f
3e43 3e47 3e4b 3e4e 3e52 3e56 3e59 3e5c
3e61 3e64 3e67 3e6a 3e6b 3e70 3e71 1
3e73 3e78 3e7c 3e80 3e83 3e88 3e8d 3e90
3e94 3e95 3e9a 3e9d 3ea2 3ea3 3ea8 3eab
3eb0 3eb1 3eb6 3eb9 3ebd 3ebe 3ec3 3ec6
3ecb 3ecc 3ed1 3ed4 3ed8 3edc 3edf 3ee2
3ee3 3ee5 3ee6 3eeb 3eec 3ef1 3ef3 3ef7
3efa 3efc 3f00 3f02 3f0e 3f10 3f12 3f13
3f18 3f1c 3f1e 3f2a 3f2c 3f30 3f34 3f37
3f38 3f3a 3f3d 3f40 3f41 3f46 3f49 3f4d
3f51 3f54 3f55 3f57 3f5a 3f5d 3f5e 3f63
1 3f66 3f6b 3f6f 3f73 3f77 3f7b 3f7f
3f8b 3f8f 3f94 3f98 3f9b 3f9c 3fa1 3fa5
3fa9 3fac 3faf 3fb3 3fb5 3fb9 3fbd 3fc0
3fc3 3fc7 3fc9 3fcd 3fd1 3fd4 3fd6 3fda
3fde 3fe2 3fe5 3fe9 3fed 3fef 3ff0 3ff5
1 3ff9 3ffd 4001 4004 4008 400c 4010
4014 4017 401b 401f 4022 4025 402a 402d
4030 4033 4034 4039 403a 1 403c 4041
4045 4049 404c 4051 4056 4059 405d 405e
4063 4066 406b 406c 4071 4074 4079 407a
407f 4082 4086 4087 408c 408f 4094 4095
409a 409d 40a1 40a5 40a8 40ab 40ac 40ae
40af 40b4 40b5 40ba 40bc 40c0 40c3 40c5
40c9 40cb 40d7 40d9 40db 40dc 40e1 40e5
40e7 40f3 40f5 40f7 40fb 40fe 4102 4105
4109 410d 4111 4115 4119 411d 4120 4123
4124 4126 412a 412e 4132 4136 413a 413e
4142 4146 414a 414e 4152 4156 415a 415e
4162 4166 416a 416e 417a 417e 4182 4185
4189 418d 418f 4193 4197 419b 419e 41a2
41a6 41a8 41a9 41ae 1 41b2 41b6 41ba
41bd 41c1 41c5 41c9 41cd 41d0 41d4 41d8
41db 41de 41e3 41e6 41e9 41ec 41ed 41f2
41f3 1 41f5 41fa 41fe 4202 4205 420a
420f 4212 4216 4217 421c 421f 4224 4225
422a 422d 4232 4233 4238 423b 423f 4240
4245 4248 424d 424e 4253 4256 425a 425e
4261 4264 4265 4267 4268 426d 426e 4273
4275 4279 427c 427e 4282 4284 4290 4292
4294 4295 429a 429e 42a0 42ac 42ae 42b2
42b6 42b9 42ba 42bc 42bf 42c2 42c3 42c8
42cc 42d0 42d4 42d8 42dc 42e0 42e4 42e8
42ec 42f0 42f4 42f8 42fc 4300 4304 4308
430c 4310 4314 4318 4324 4328 432d 4331
4334 4335 433a 433e 4342 4345 4348 434c
434e 4352 4356 4359 435c 4360 4362 4366
436a 436d 436f 4373 4377 437b 437e 4382
4386 4388 4389 438e 1 4392 4396 439a
439d 43a1 43a5 43a9 43ad 43b0 43b4 43b8
43bb 43be 43c3 43c6 43c9 43cc 43cd 43d2
43d3 1 43d5 43da 43de 43e2 43e5 43ea
43ef 43f2 43f6 43f7 43fc 43ff 4404 4405
440a 440d 4412 4413 4418 441b 441f 4420
4425 4428 442d 442e 4433 4436 443a 443e
4441 4444 4445 4447 4448 444d 444e 4453
4455 4459 445c 445e 4462 4464 4470 4472
4474 4475 447a 447e 4480 448c 448e 4490
4494 4498 449c 44a0 44a4 44a8 44ac 44b0
44b4 44b8 44bc 44c0 44c4 44c8 44cc 44d0
44d4 44d8 44dc 44e0 44e4 44e8 44f4 44f8
44fd 4501 4504 4505 450a 450e 4512 4515
4518 451c 451e 4522 4526 4529 452c 4530
4532 4536 453a 453d 453f 4543 4547 454b
454e 4552 4556 4558 4559 455e 1 4562
4566 456a 456d 4571 4575 4579 457d 4580
4584 4588 458b 458e 4593 4596 4599 459c
459d 45a2 45a3 1 45a5 45aa 45ae 45b2
45b5 45ba 45bf 45c2 45c6 45c7 45cc 45cf
45d4 45d5 45da 45dd 45e2 45e3 45e8 45eb
45ef 45f0 45f5 45f8 45fd 45fe 4603 4606
460a 460e 4611 4614 4615 4617 4618 461d
461e 4623 4625 4629 462c 462e 4632 4634
4640 4642 4644 4645 464a 464e 4650 465c
465e 4660 4664 4668 466b 466d 4671 4675
4678 4680 4682 4683 4686 4688 4689 468e
4690 4692 4697 469b 46a0 46a4 46a8 46ac
46b0 46b4 46b8 46c4 46c8 46cd 46d1 46d4
46d5 46da 46de 46e2 46e5 46e8 46ec 46ee
46f2 46f6 46f9 46fc 4700 4702 4706 470a
470d 470f 4713 4717 471b 471e 4722 4726
4728 4729 472e 1 4732 4736 473a 473d
4741 4745 4749 474d 4750 4754 4758 475b
475e 4763 4766 4769 476c 476d 4772 4773
1 4775 477a 477e 4782 4785 478a 478f
4792 4796 4797 479c 479f 47a4 47a5 47aa
47ad 47b2 47b3 47b8 47bb 47bf 47c0 47c5
47c8 47cd 47ce 47d3 47d6 47da 47de 47e1
47e4 47e5 47e7 47e8 47ed 47ee 47f3 47f5
47f9 47fc 47fe 4802 4804 4810 4812 4814
4815 481a 481e 4820 482c 482e 4830 4834
483b 483f 4843 4848 484a 484e 4852 4855
4859 485d 485f 4863 4867 486b 486e 4872
4876 4878 4879 487e 1 4882 4886 488a
488d 4891 4895 4899 489d 48a0 48a4 48a8
48ab 48ae 48b3 48b6 48b9 48bc 48bd 48c2
48c3 1 48c5 48ca 48ce 48d2 48d5 48da
48df 48e2 48e6 48e7 48ec 48ef 48f4 48f5
48fa 48fd 4902 4903 4908 490b 490f 4910
4915 4918 491d 491e 4923 4926 492a 492e
4931 4934 4935 4937 4938 493d 493e 4943
4945 4949 494c 494e 4952 4954 4960 4962
4964 4965 496a 496e 4970 497c 497e 4982
4985 4988 4989 498e 4992 4996 499a 499b
499d 49a1 49a3 49a7 49aa 49ae 49b2 49b6
49ba 49be 49c2 49c6 49ca 49ce 49d2 49d6
49da 49de 49ea 49ee 49f2 49f5 49f9 49fd
49ff 4a03 4a07 4a0b 4a0e 4a12 4a16 4a18
4a19 4a1e 1 4a22 4a26 4a2a 4a2d 4a31
4a35 4a39 4a3d 4a40 4a44 4a48 4a4b 4a4e
4a53 4a56 4a59 4a5c 4a5d 4a62 4a63 1
4a65 4a6a 4a6e 4a72 4a75 4a7a 4a7f 4a82
4a86 4a87 4a8c 4a8f 4a94 4a95 4a9a 4a9d
4aa2 4aa3 4aa8 4aab 4aaf 4ab0 4ab5 4ab8
4abd 4abe 4ac3 4ac6 4aca 4ace 4ad1 4ad4
4ad5 4ad7 4ad8 4add 4ade 4ae3 4ae5 4ae9
4aec 4aee 4af2 4af4 4b00 4b02 4b04 4b05
4b0a 4b0e 4b10 4b1c 4b1e 4b22 4b26 4b29
4b2a 4b2c 4b2f 4b32 4b33 4b38 4b3c 4b40
4b44 4b47 4b4b 4b4f 4b53 4b56 4b5a 4b5e
4b62 4b66 4b67 4b69 4b6d 4b6f 4b73 4b76
4b7a 4b7e 4b82 4b86 4b8a 4b8e 4b92 4b96
4ba2 4ba6 4bab 4baf 4bb2 4bb3 4bb8 4bbc
4bc0 4bc3 4bc6 4bca 4bcc 4bd0 4bd4 4bd7
4bda 4bde 4be0 4be4 4be8 4beb 4bed 4bf1
4bf5 4bf9 4bfc 4c00 4c04 4c06 4c07 4c0c
1 4c10 4c14 4c18 4c1b 4c1f 4c23 4c27
4c2b 4c2e 4c32 4c36 4c39 4c3c 4c41 4c44
4c47 4c4a 4c4b 4c50 4c51 1 4c53 4c58
4c5c 4c60 4c63 4c68 4c6d 4c70 4c74 4c75
4c7a 4c7d 4c82 4c83 4c88 4c8b 4c90 4c91
4c96 4c99 4c9d 4c9e 4ca3 4ca6 4cab 4cac
4cb1 4cb4 4cb8 4cbc 4cbf 4cc2 4cc3 4cc5
4cc6 4ccb 4ccc 4cd1 4cd3 4cd7 4cda 4cdc
4ce0 4ce2 4cee 4cf0 4cf2 4cf3 4cf8 4cfc
4cfe 4d0a 4d0c 4d10 4d14 4d17 4d1a 4d1d
4d1e 4d23 4d27 4d2b 4d2e 4d31 4d35 4d37
4d3b 4d3e 4d42 4d46 4d49 4d4d 4d51 4d54
4d57 4d5c 4d5f 4d62 4d65 4d66 4d6b 4d6c
1 4d6e 4d73 4d77 4d7b 4d7e 4d83 4d88
4d8b 4d8f 4d90 4d95 4d98 4d9d 4d9e 4da3
4da6 4dab 4dac 4db1 4db4 4db8 4dbc 4dbf
4dc0 4dc5 4dc6 4dcb 4dcd 4dd1 4dd4 4dd8
4ddc 4de0 4de3 4de7 4de9 4ded 4def 4dfb
4dff 4e01 4e02 4e0b 
15cc
2
0 1 a 6 e 12 19 :3 6
13 :3 6 17 26 :2 6 1 3 a
:2 1 4 :2 e 1d e :2 4 :2 12 21
2a 3c :2 21 12 :2 4 c 10 f
c 20 :2 29 c :2 4 d 11 10
d 21 :2 2a d :2 4 11 1a 19
:2 11 :2 4 :3 10 :2 4 d 16 15 :2 d
:2 4 e 17 16 :2 e :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
:3 11 :2 4 :3 12 :2 4 :2 11 20 11 :2 4
:2 f 1e f :2 4 :2 c 1b c :2 4
:2 e 1d e :2 4 :2 12 21 12 :2 4
:2 12 21 12 :2 4 :2 e 1d e :2 4
:2 f 1e f :2 4 :2 e 1d e :2 4
:2 b 1a b :2 4 :2 f 1e f :2 4
:2 14 23 14 :2 4 :2 f 19 f :2 4
:2 f 19 f :2 4 9 12 11 :2 9
:2 4 11 1a 19 :2 11 4 7 e
0 :2 7 11 14 27 2a f 20
23 28 30 d f 1c 1f 2e
30 3d 40 10 12 1f 30 33
e 11 29 2c a :6 7 c 15
:3 c :2 7 e 0 :2 7 11 1b 26
35 10 1d 2e 42 4b a :6 7
e 0 :2 7 11 1a f 10 23
3b a :6 7 :2 11 23 :2 2d 3a :2 23
:3 7 :2 d 19 25 :2 2f 43 :2 25 58
5e 61 :2 58 6f 89 8 :2 6f d
10 :2 6f 15 18 :2 6f b e :2 6f
13 16 1f 27 :2 1f 36 :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
3a :2 16 :2 6f 42 45 :2 6f :2 7 4e
:2 4 7 :2 11 23 :2 2d 39 3c 50
52 53 :2 50 :2 23 :3 7 :2 d 12 1e
61 64 :2 1e :2 7 56 :2 4 e 17
2d c 1b c d 1a :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 57 59 5a
:2 57 :2 29 :3 d :2 13 18 24 67 6a
:2 24 77 7a :2 24 7e 81 :2 24 8d
90 :2 24 98 9b :2 24 a7 aa b1
ba bd :2 aa :2 24 :2 d 5d :2 a :2 7
:4 13 :2 7 4 :3 1 7 e 1c 1f
:2 7 22 24 :2 22 a :2 14 26 :2 30
3c 40 54 56 57 :2 54 :2 26 :3 a
:2 10 15 21 64 67 :2 21 74 77
:2 21 7b 7e :2 21 88 8b 94 9c
:2 a5 :2 94 c3 :2 8b :2 21 cb ce :2 21
d6 d9 :2 21 de e1 :2 21 e6 e9
:2 21 :2 a 5a :2 7 a :2 14 26 :2 30
3c 3f 53 55 56 :2 53 :2 26 :3 a
:2 10 15 21 64 67 :2 21 :2 a 59
:3 7 e :2 19 2a :2 33 50 56 :2 e
7 28 :2 4 8 :2 11 1c 1a :2 25
:2 1a 7 11 27 34 59 f 1c
26 f 26 44 5a 6e :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 5a 5d 5e
:2 5a :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 7b 7e :2 27 82 85 :2 27 91
94 :2 27 9c 9f :2 27 ab ae b5
be c1 :2 ae :2 27 :2 10 61 :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8c 8f 98 a0 :2 a9
:2 98 bc :2 8f :2 24 :2 d 5d :2 a d
:2 17 29 :2 33 3f 42 56 59 5a
:2 56 :2 29 :3 d :2 13 18 24 68 6b
:2 24 :2 d 5d :3 a 11 :2 1c 2f :2 38
4a :2 11 a 7 38 e 17 22
:2 e 25 27 :2 25 d 2f 38 44
:2 2f 47 49 :2 47 2e :3 d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8c 8f 98
a0 :2 a9 :2 98 c5 :2 8f :2 24 cd d0
:2 24 d8 db :2 24 e0 e3 :2 24 e8
eb :2 24 :2 d 5e :2 a d :2 17 29
:2 33 3f 42 56 59 5a :2 56 :2 29
:3 d :2 13 18 24 68 6b :2 24 :2 d
5d :3 a 11 :2 1c 2d :2 36 51 57
:2 11 a 4c 38 :2 7 11 1a 34
47 55 62 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 5a 5d 5e :2 5a :2 2c :3 10
:2 16 1b 27 6b 6e :2 27 7b 7e
:2 27 82 85 :2 27 91 94 :2 27 9c
9f :2 27 ab ae b5 be c1 :2 ae
:2 27 :2 10 61 :2 d :2 a :4 16 :2 a 7
:3 35 7 f e 11 :2 f 30 33
:2 f 13 16 :2 f 7 35 7 17
7 a 13 1e :2 a 21 23 :2 21
14 d 29 33 3c 4d 56 66
d 1f 28 37 d 1f 28 38
d 29 43 57 d 1f :6 d 1f
d 1f d 13 20 31 3d 46
4e 57 65 6e 7c 85 93 9c
a9 b2 c3 cc df e8 fd 106
121 12a 142 14b 15c 165 177 180
198 1a1 1b4 1bd 1de 1f3 207 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5d 60 61 :2 5d :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a 7e 81 :2 2a
85 88 :2 2a 94 97 :2 2a 9f a2
:2 2a ae b1 b8 c1 c4 :2 b1 :2 2a
:2 13 64 :2 10 :2 d :4 19 :2 d a :3 25
a f :4 a 13 1d 32 :3 d 10
15 :2 10 :2 19 25 10 1b 10 :2 19
25 10 :4 d 11 :2 1a 26 23 :2 2f
:2 23 :3 10 3f :2 d 17 :2 10 1e 27
36 10 1f 28 38 10 2b 45
5b 10 1d 10 16 10 1f 28
37 10 20 29 39 10 1b 10
2d 4c 64 10 30 52 6d 10
30 4e 52 68 78 10 33 51
55 6b 7b 10 26 3d 53 10
27 3f 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :3 a 17 2c 16
23 34 48 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :4 a e 25 d 13
:3 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 94 97 :2 2a 9f a2 :2 2a ae
b1 b8 c1 c4 :2 b1 :2 2a :2 13 64
:2 10 :2 d :4 19 :2 d a :4 25 :2 7 11
1d 2b 34 10 1d 2e 43 57
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 5a 5d 5e :2 5a :2 2c :3 10
:2 16 1b 27 6b 6e :2 27 7b 7e
:2 27 82 85 :2 27 91 94 :2 27 9c
9f :2 27 ab ae b5 be c1 :2 ae
:2 27 :2 10 61 :2 d :2 a :4 16 :2 a 7
:3 4 7 14 :2 7 14 :2 7 d e
11 :2 d 23 26 :2 d 13 16 :2 d
7 :5 4 9 :2 12 :2 4 d 17 1d
27 32 :3 7 a f :2 a :2 13 1f
a 15 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
c f 17 1f 10 12 28 2a
10 12 28 2a 10 12 28 2a
10 12 25 27 10 12 25 27
10 12 25 27 16 23 34 41
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:3 11 17 28 10 13 25 28 39
3c 4f 52 64 67 7c 7f 93
96 a7 aa 10 13 2a 2d 43
46 60 63 10 13 25 28 39
3c 4f 52 64 67 7c 7f 93
96 a7 aa 10 13 2a 2d 43
46 60 63 10 13 25 28 3a
3d 50 53 66 69 7e 81 96
99 aa ad ba bd 10 13 2a
2d 40 43 57 5a 74 77 8d
90 10 13 24 27 35 38 49
4c 5a 5d 6e 71 7f 82 93
96 16 2a 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :3 11 17 10 2c 10
2c 10 36 5d 78 10 2d 10
2d 10 37 5f 7b 10 2d 10
2d 10 37 57 73 10 2b 10
2b 10 35 56 70 10 2e 10
2e 10 38 5c 79 10 21 10
22 10 24 10 20 2d 10 26
39 10 29 3f 16 23 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
60 63 64 :2 60 :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d 81 84 :2 2d 88
8b :2 2d 97 9a :2 2d a2 a5 :2 2d
b1 b4 bb c4 c7 :2 b4 :2 2d :2 16
67 :2 13 :2 10 :4 1c :2 10 d :4 11 :2 a
f 17 29 38 4f 62 76 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :4 11 :2 1a 26 23
:2 2f :2 23 10 :4 44 43 42 :2 10 15
10 58 :2 d 17 34 4d 58 15
2a 15 2c 3f 49 5a 68 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 60 63
64 :2 60 :2 32 :3 16 :2 1c 21 2d 71
74 :2 2d 81 84 :2 2d 88 8b :2 2d
97 9a :2 2d a2 a5 :2 2d b1 b4
bb c4 c7 :2 b4 :2 2d :2 16 67 :2 13
:2 10 :4 1c :2 10 d :4 11 :2 1a 25 23
:2 2e :2 23 10 :4 44 43 42 :2 10 13
1c 27 :2 13 2a 2c :2 2a 13 1e
13 2e 22 39 4d 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 10 22 34
48 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 10 22 3e 52 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 10 22 3f
53 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 10 13 1e 13 :4 10 66 10
27 :2 10 1b 10 :5 d 1a :2 d 12
:4 d 16 1f 2c 37 :3 10 13 17
:2 13 :2 1c 28 13 1d 13 :2 1c 28
13 :4 10 14 :2 1d 29 26 :2 32 :2 26
:3 13 42 :2 10 13 1c 25 :2 13 28
2a :2 28 1d 32 3e 4a 16 22
2a 31 3c 1c 29 3a 4e 66
71 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 2c 17 :2 20 2b 29 :2 34 :2 29
16 25 3c 49 5a 6e 77 82
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:4 44 20 35 49 63 70 81 95
9e a9 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6c 6d :2 69
:2 3b :3 1f :2 25 2a 36 7a 7d :2 36
8a 8d :2 36 91 94 :2 36 a0 a3
:2 36 ab ae :2 36 ba bd c4 cd
d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25
:2 19 16 :7 13 10 2c 16 1f 28
:2 16 2b 2d :2 2b 1d 32 46 60
6d 7e 92 9b a6 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 2f 2c :2 10
d :2 11 10 16 :3 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :3 11 17 2c 3c 48 16 23
34 40 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 11 10 19 24 :2 10 27
29 :2 27 1a :2 13 18 21 28 2d
36 13 21 13 22 13 24 13
20 13 22 13 23 13 1e 13
30 4f 67 13 33 55 70 13
19 13 2b 2f 45 55 13 36
54 58 6e 7e 13 29 40 56
13 2a 42 13 19 2d 36 49
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 9a 9d :2 30 a5
a8 :2 30 b4 b7 be c7 ca :2 b7
:2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13 10
:3 2b 13 1c 25 :2 13 28 2a :2 28
13 21 :2 13 26 36 44 59 65
68 :2 26 13 2c :2 10 2b 10 15
:4 10 19 22 2d :3 13 16 1a :2 16
:2 1f 2b 16 20 16 :2 1f 2b 16
:4 13 17 :2 20 2c 29 :2 35 :2 29 :3 16
45 :2 13 1d :2 16 1b 24 16 1b
24 16 24 16 25 16 27 16
23 16 25 16 26 16 21 16
33 52 6a 16 36 58 73 16
1c 16 2e 32 48 58 16 39
57 5b 71 81 16 2c 43 59
16 2d 45 16 2e 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :3 10
1d 29 37 40 58 65 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :4 10 14
d 13 19 :3 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 63 66 67 :2 63 :2 35 :3 19
:2 1f 24 30 74 77 :2 30 84 87
:2 30 8b 8e :2 30 9a 9d :2 30 a5
a8 :2 30 b4 b7 be c7 ca :2 b7
:2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13 10
:3 d 14 1d 28 :2 14 2b 2d :2 2b
13 35 3e 46 :2 35 49 4b :2 49
34 :2 13 1d 32 3d 4a 5e 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :4 4e
:3 10 1e :2 10 23 33 41 56 62
65 :2 23 10 1a 31 37 44 52
5c 6a 18 2d 3b 49 58 64
70 18 2f 45 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 63 66 67 :2 63 :2 35
:3 19 :2 1f 24 30 74 77 :2 30 84
87 :2 30 8b 8e :2 30 9a 9d :2 30
a5 a8 :2 30 b4 b7 be c7 ca
:2 b7 :2 30 :2 19 6a :2 16 :2 13 :4 1f :2 13
10 :3 d 13 1c 28 :2 13 2b 2d
:2 2b 1d :6 16 2e 16 2f 16 2f
16 2e 45 16 1c 29 3a 48
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:4 2f 1d :6 16 2e 16 2f 16 2f
16 2e 45 16 31 48 1c 29
3a 48 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :7 10 :4 d f d :3 11 :2 a
d a :3 7 11 1d 2b 34 4c
59 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 5a 5d 5e :2 5a :2 2c
:3 10 :2 16 1b 27 6b 6e :2 27 7b
7e :2 27 82 85 :2 27 91 94 :2 27
9c 9f :2 27 ab ae b5 be c1
:2 ae :2 27 :2 10 61 :2 d :2 a :4 16 :2 a
7 :4 4 8 1 7 d :3 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 57 5a 5b
:2 57 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 7 15 17 :2 15
7 1a 24 :2 1a 7 19 :2 4 19
1f 28 34 3a 43 4f 59 62
:2 c 1a 27 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 57 5a 5b :2 57 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8e 91 :2 24 99
9c :2 24 a8 ab b2 bb be :2 ab
:2 24 :2 d 5e :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 1f :2 7 22 24 :2 22
7 14 :2 1d :2 7 :2 10 1c 30 3e
4d :2 1c 7 26 :2 4 e 7 1f
2c 3a 47 d 1a 7 e a
16 :3 14 a :2 13 1f a 1b a
:2 13 1f a :4 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 57
5b 5c :2 57 :2 29 :3 d :2 13 18 24
69 6c :2 24 79 7c :2 24 80 83
:2 24 8f 92 :2 24 9a 9d :2 24 a9
ac b3 bc bf :2 ac :2 24 :2 d 5f
:2 a :2 7 :4 13 :2 7 4 :3 1 7 :2 10
19 1b :2 19 7 :2 10 1c 7 1f
:2 4 7 :2 11 23 :2 2d 39 3c 50
54 55 :2 50 :2 23 :3 7 :2 d 12 1e
63 66 :2 1e 73 76 :2 1e 7a 7d
:2 1e 87 8a :2 93 :2 1e :2 7 58 :3 4
b :2 14 4 :9 1 
15cc
4
0 :2 1 :6 3 :4 4
:5 5 2 :2 6 :2 1
:6 8 :a 9 :a a :a b
:7 c :5 d :7 e :7 f
:7 10 :7 11 :5 12 :5 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :7 22 :7 23
:2 25 0 :2 25 :4 26
:5 27 :8 28 :5 29 :4 2a
26 :5 25 :7 2d :2 2f
0 :2 2f :4 30 :5 31
30 :5 2f :2 33 0
:2 33 :2 34 35 :3 36
34 :5 33 :b 39 :11 3a
3b :2 3a :2 3b :2 3a
:2 3b :2 3a :2 3c :2 3a
:9 3c :2 3a :2 3d :2 3a
:9 3d :2 3a :2 3d :4 3a
:3 39 :11 40 :b 41 :3 40
:3 47 :2 48 49 :2 4a
47 :5 4b 46 4d
:5 4e :3 4d :2 4f :5 51
:11 52 :24 53 :3 52 :2 50
:6 4f 4c :3 38 :a 59
:11 5a :30 5b :3 5a :11 5d
:b 5e :3 5d :c 60 :3 59
:a 63 :4 65 :3 66 :5 67
65 :5 68 64 6a
:5 6b :3 6a :2 6c :5 6e
:11 6f :24 70 :3 6f :2 6d
:6 6c 69 :3 63 :a 75
:11 76 :20 77 :3 76 :11 79
:b 7a :3 79 :b 7c 7d
75 :16 7d :11 7e :30 7f
:3 7e :11 81 :b 82 :3 81
:c 84 7d :3 75 :7 88
:5 89 87 8b :5 8c
:3 8b :2 8d :5 8f :11 90
:24 91 :3 90 :2 8e :6 8d
8a :3 63 :2 96 :2 97
:2 96 :2 97 :2 96 :2 98
:3 96 63 :3 9a :9 9d
a0 :7 a1 :4 a2 :4 a3
:4 a4 :2 a5 a6 a7
a8 a9 aa :2 ab
:2 ac ad :24 ae a0
:6 af :5 b0 af :5 b2
b1 :3 af 9f b5
:5 b6 :3 b5 :2 b7 :5 b9
:11 ba :24 bb :3 ba :2 b8
:6 b7 b4 :3 9d :5 c0
c2 :6 c3 :3 c4 :5 c5
c4 :5 c7 c6 :3 c4
:a c9 :2 ca :3 c9 ce
cf :4 d0 :4 d1 :4 d2
:2 d3 :2 d4 :4 d5 :4 d6
:2 d7 :4 d8 :4 d9 :6 da
:6 db :4 dc :3 dd :2 de
ce :6 df :5 e0 df
:5 e2 e1 :3 df cd
e5 :5 e6 :3 e5 :2 e7
:5 e9 :11 ea :24 eb :3 ea
:2 e8 :6 e7 e4 :3 c2
:2 f1 :4 f2 f1 :6 f3
:5 f4 f3 :5 f6 f5
:3 f3 f0 f9 :5 fa
:3 f9 :2 fb :5 fd :11 fe
:24 ff :3 fe :2 fc :6 fb
f8 :4 c2 103 9d
:4 107 :5 108 106 10a
:5 10b :3 10a :2 10c :5 10e
:11 10f :24 110 :3 10f :2 10d
:6 10c 109 :6 9d :4 117
:5 118 117 :6 119 :5 11a
119 :5 11c 11b :3 119
116 11f :5 120 :3 11f
:2 121 :5 123 :11 124 :24 125
:3 124 :2 122 :6 121 11e
:3 99 :3 12a :3 12b 12d
12e :2 12f :2 12e :2 12f
:2 12e :2 130 :2 12e 12d
99 :3 63 :5 137 139
:8 13a :3 13b :5 13c 13b
:5 13e 13d :3 13b :a 141
:2 142 :3 141 146 148
:2 14d :4 14e :4 14f :4 150
:4 151 :4 152 :4 153 :4 154
14d :6 155 :5 156 155
:5 158 157 :3 155 14c
15b :5 15c :3 15b :2 15d
:5 15f :11 160 :24 161 :3 160
:2 15e :6 15d 15a :3 148
:2 168 :10 169 :8 16a :10 16b
:8 16c :12 16d :c 16e :10 16f
:2 170 168 :6 171 :5 172
171 :5 174 173 :3 171
167 177 :5 178 :3 177
:2 179 :5 17b :11 17c :24 17d
:3 17c :2 17a :6 179 176
:3 148 183 :2 184 :2 185
:4 186 :2 187 :2 188 :4 189
:2 18a :2 18b :4 18c :2 18d
:2 18e :4 18f :2 190 :2 191
:4 192 :2 193 :2 194 :2 195
:3 196 :3 197 :3 198 :2 199
183 :6 19a :5 19b 19a
:5 19d 19c :3 19a 182
1a0 :5 1a1 :3 1a0 :2 1a2
:5 1a4 :11 1a5 :24 1a6 :3 1a5
:2 1a3 :6 1a2 19f :6 148
1ad :7 1b2 :5 1b3 1b1
1b5 :5 1b6 :3 1b5 :2 1b7
:5 1b9 :11 1ba :24 1bb :3 1ba
:2 1b8 :6 1b7 1b4 :3 1ad
:12 1c0 :2 1c1 :3 1c0 :4 1c5
:2 1c6 :6 1c7 1c5 :5 1c8
1c4 1ca :5 1cb :3 1ca
:2 1cc :5 1ce :11 1cf :24 1d0
:3 1cf :2 1cd :6 1cc 1c9
:3 1ad :12 1d6 :9 1d7 :3 1d8
1d7 :4 1dc :6 1dd :5 1de
1dd :5 1e0 1df :3 1dd
1db 1e3 :5 1e4 :3 1e3
:2 1e5 :5 1e7 :11 1e8 :24 1e9
:3 1e8 :2 1e6 :6 1e5 1e2
:3 1d9 :4 1ef :6 1f0 :5 1f1
1f0 :5 1f3 1f2 :3 1f0
1ee 1f6 :5 1f7 :3 1f6
:2 1f8 :5 1fa :11 1fb :24 1fc
:3 1fb :2 1f9 :6 1f8 1f5
:3 1d9 :4 202 :6 203 :5 204
203 :5 206 205 :3 203
201 209 :5 20a :3 209
:2 20b :5 20d :11 20e :24 20f
:3 20e :2 20c :6 20b 208
:3 1d9 :4 215 :6 216 :5 217
216 :5 219 218 :3 216
214 21c :5 21d :3 21c
:2 21e :5 220 :11 221 :24 222
:3 221 :2 21f :6 21e 21b
:3 1d9 :3 227 1d9 :3 1d7
1d6 :3 22a :3 22b 229
:3 1d6 :3 22e :5 233 235
:7 236 :3 237 :5 238 237
:5 23a 239 :3 237 :a 23d
:2 23e :3 23d :9 242 :4 244
:5 245 :6 246 244 :6 247
:5 248 247 :5 24a 249
:3 247 243 24d :5 24e
:3 24d :2 24f :5 251 :11 252
:24 253 :3 252 :2 250 :6 24f
24c :3 242 :a 259 :8 25b
:6 25c :5 25d 25c :5 25f
25e :3 25c 25a 262
:5 263 :3 262 :2 264 :5 266
:11 267 :24 268 :3 267 :2 265
:6 264 261 :4 259 :a 26e
:6 26f :5 270 26f :5 272
271 :3 26f 26d 275
:5 276 :3 275 :2 277 :5 279
:11 27a :24 27b :3 27a :2 278
:6 277 274 :4 26c :3 259
280 242 :9 280 :a 282
:6 283 :5 284 283 :5 286
285 :3 283 281 289
:5 28a :3 289 :2 28b :5 28d
:11 28e :24 28f :3 28e :2 28c
:6 28b 288 :4 280 :3 242
235 294 1ad :4 296
:5 297 295 299 :5 29a
:3 299 :2 29b :5 29d :11 29e
:24 29f :3 29e :2 29c :6 29b
298 :3 1ad :4 2a5 :4 2a6
2a5 :6 2a7 :5 2a8 2a7
:5 2aa 2a9 :3 2a7 2a4
2ad :5 2ae :3 2ad :2 2af
:5 2b1 :11 2b2 :24 2b3 :3 2b2
:2 2b0 :6 2af 2ac :3 1ad
:9 2b8 2ba 2bb :6 2bc
:2 2bd :2 2be :2 2bf :2 2c0
:2 2c1 :2 2c2 :2 2c3 :4 2c4
:4 2c5 :2 2c6 :5 2c7 :6 2c8
:4 2c9 :3 2ca 2cb :4 2cc
2ba :6 2cd :5 2ce 2cd
:5 2d0 2cf :3 2cd 2b9
2d3 :5 2d4 :3 2d3 :2 2d5
:5 2d7 :11 2d8 :24 2d9 :3 2d8
:2 2d6 :6 2d5 2d2 :3 2b8
:9 2de :3 2e0 :a 2e1 :3 2de
2b8 :5 2e6 2e8 :6 2e9
:3 2ea :5 2eb 2ea :5 2ed
2ec :3 2ea :a 2ef :2 2f0
:3 2ef 2f4 2f5 :3 2f6
:3 2f7 :2 2f8 :2 2f9 :2 2fa
:2 2fb :2 2fc :2 2fd :2 2fe
:4 2ff :4 300 :2 301 :5 302
:6 303 :4 304 :3 305 :2 306
:2 307 2f4 :6 308 :5 309
308 :5 30b 30a :3 308
2f3 30e :5 30f :3 30e
:2 310 :5 312 :11 313 :24 314
:3 313 :2 311 :6 310 30d
:3 2e8 :7 31c :6 31d :5 31e
31d :5 320 31f :3 31d
31b 323 :5 324 :3 323
:2 325 :5 327 :11 328 :24 329
:3 328 :2 326 :6 325 322
:4 2e8 32d 2e3 :4 330
:5 331 32f 333 :5 334
:3 333 :2 335 :5 337 :11 338
:24 339 :3 338 :2 336 :6 335
332 :3 2e3 :16 33e :6 340
:6 341 :5 342 341 :5 344
343 :3 341 33f 347
:5 348 :3 347 :2 349 :5 34b
:11 34c :24 34d :3 34c :2 34a
:6 349 346 :6 33e :3 354
:a 355 :7 358 :7 359 :3 35a
358 :5 35b 357 35d
:5 35e :3 35d :2 35f :5 361
:11 362 :24 363 :3 362 :2 360
:6 35f 35c :3 2e3 :9 369
36b 36c 36d 36e
36f 370 :2 371 :2 372
:2 373 :3 374 375 :4 376
36b :6 377 :5 378 377
:5 37a 379 :3 377 36a
37d :5 37e :3 37d :2 37f
:5 381 :11 382 :24 383 :3 382
:2 380 :6 37f 37c :4 369
389 38a 38b 38c
38d 38e :2 38f :2 390
:2 391 :3 392 :3 393 :4 394
389 :6 395 :5 396 395
:5 398 397 :3 395 388
39b :5 39c :3 39b :2 39d
:5 39f :11 3a0 :24 3a1 :3 3a0
:2 39e :6 39d 39a :4 387
:3 369 2e3 :3 2b8 3a9
3aa :5 1ad 3ac 3ab
:3 146 :7 3b1 :6 3b2 :5 3b3
3b2 :5 3b5 3b4 :3 3b2
3b0 3b8 :5 3b9 :3 3b8
:2 3ba :5 3bc :11 3bd :24 3be
:3 3bd :2 3bb :6 3ba 3b7
:4 139 3c3 38 :4 3c7
:5 3c8 3c6 3ca :5 3cb
:3 3ca :2 3cc :5 3ce :11 3cf
:24 3d0 :3 3cf :2 3cd :6 3cc
3c9 :3 38 :5 3d5 :6 3d6
:3 3d5 :9 3db 3dc :3 3dd
3db :5 3de 3da 3e0
:5 3e1 :3 3e0 :2 3e2 :5 3e4
:11 3e5 :24 3e6 :3 3e5 :2 3e3
:6 3e2 3df :3 38 :9 3eb
:5 3ec :a 3ed :3 3eb 3f1
:5 3f2 :2 3f3 3f1 :6 3f4
:5 3f5 3f4 :5 3f7 3f6
:3 3f4 3f0 3fa :5 3fb
:3 3fa :2 3fc :5 3fe :11 3ff
:24 400 :3 3ff :2 3fd :6 3fc
3f9 :3 38 :7 405 :5 406
:3 405 :11 409 :19 40a :3 409
:5 40c :2 38 :7 1 
4e0d
4
:3 0 1 :3 0 2
:a 0 15c7 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 :2 0 7 8
:3 0 7 :7 0 b
a :3 0 8 :3 0
a :2 0 9 :7 0
10 e f :2 0
b :3 0 8 :3 0
12 14 0 15c7
2 15 :2 0 f
:2 0 d 8 :3 0
18 :7 0 7 :3 0
1c 19 1a 15c5
0 c :6 0 12
:2 0 12 8 :3 0
1e :7 0 e :3 0
9 :3 0 f 20
23 26 1f 24
15c5 0 d :6 0
12 :2 0 16 11
:3 0 14 28 2a
2 :5 0 13 :3 0
14 :3 0 2c 2d
0 30 2b 2e
15c5 0 10 :6 0
17 :2 0 1a 11
:3 0 18 32 34
2 :5 0 13 :3 0
14 :3 0 36 37
0 3a 35 38
15c5 0 15 :6 0
20 124 0 1e
6 :3 0 1c 3c
3e :6 0 41 3f
0 15c5 0 16
:6 0 17 :2 0 24
19 :3 0 43 :7 0
46 44 0 15c5
0 18 :6 0 6
:3 0 17 :2 0 22
48 4a :6 0 4d
4b 0 15c5 0
1a :6 0 17 :2 0
28 6 :3 0 26
4f 51 :6 0 54
52 0 15c5 0
1b :6 0 17 :2 0
2c 6 :3 0 2a
56 58 :6 0 5b
59 0 15c5 0
1c :6 0 32 1b3
0 30 6 :3 0
2e 5d 5f :6 0
62 60 0 15c5
0 1d :6 0 f
:2 0 34 1f :3 0
64 :7 0 67 65
0 15c5 0 1e
:6 0 1f :3 0 69
:7 0 6c 6a 0
15c5 0 20 :6 0
f :2 0 36 8
:3 0 6e :7 0 72
6f 70 15c5 0
21 :6 0 f :2 0
38 8 :3 0 74
:7 0 78 75 76
15c5 0 22 :6 0
f :2 0 3a 8
:3 0 7a :7 0 7e
7b 7c 15c5 0
23 :6 0 f :2 0
3c 8 :3 0 80
:7 0 84 81 82
15c5 0 24 :6 0
f :2 0 3e 8
:3 0 86 :7 0 8a
87 88 15c5 0
25 :6 0 f :2 0
40 8 :3 0 8c
:7 0 90 8d 8e
15c5 0 26 :6 0
f :2 0 42 8
:3 0 92 :7 0 96
93 94 15c5 0
27 :6 0 f :2 0
44 8 :3 0 98
:7 0 9c 99 9a
15c5 0 28 :6 0
f :2 0 46 8
:3 0 9e :7 0 a2
9f a0 15c5 0
29 :6 0 f :2 0
48 8 :3 0 a4
:7 0 a8 a5 a6
15c5 0 2a :6 0
f :2 0 4a 8
:3 0 aa :7 0 ae
ab ac 15c5 0
2b :6 0 2f :2 0
4c 8 :3 0 b0
:7 0 b4 b1 b2
15c5 0 2c :6 0
2f :2 0 4e 2e
:3 0 b6 :7 0 ba
b7 b8 15c5 0
2d :6 0 32 :2 0
50 2e :3 0 bc
:7 0 c0 bd be
15c5 0 30 :6 0
a :2 0 54 6
:3 0 52 c2 c4
:6 0 c7 c5 0
15c5 0 31 :9 0
58 6 :3 0 56
c9 cb :6 0 ce
cc 0 15c5 0
33 :6 0 34 :3 0
35 :a 0 2 ef
:4 0 d0 d3 0
d1 :3 0 36 :3 0
37 :3 0 36 :3 0
38 :3 0 39 :3 0
36 :3 0 3a :3 0
3b :3 0 3c :3 0
3c :3 0 3d :3 0
36 :3 0 3d :3 0
3c :3 0 3e :3 0
36 :3 0 3f :3 0
3c :3 0 3d :3 0
16 :3 0 36 :3 0
40 :3 0 36 :3 0
41 :3 0 36 :3 0
42 :4 0 43 1
:8 0 f0 d0 d3
f1 0 15c5 5a
f1 f3 f0 f2
:6 0 ef :7 0 f1
:3 0 5c 45 :3 0
46 :2 0 4 f5
f6 0 f7 :7 0
fa f8 0 15c5
0 44 :6 0 34
:3 0 47 :a 0 3
10a :4 0 fc ff
0 fd :3 0 48
:3 0 49 :3 0 4a
:3 0 4b :3 0 3d
:3 0 16 :3 0 37
:3 0 3 :3 0 40
:4 0 4c 1 :8 0
10b fc ff 10c
0 15c5 5e 10c
10e 10b 10d :6 0
10a :7 0 10c 34
:3 0 4d :a 0 4
11b :5 0 110 113
0 111 :3 0 3f
:3 0 37 :3 0 39
:3 0 40 :3 0 42
:3 0 3 :4 0 4e
1 :8 0 11c 110
113 11d 0 15c5
60 11d 11f 11c
11e :6 0 11b :7 0
11d 4f :3 0 50
:3 0 120 121 0
4f :3 0 51 :3 0
123 124 0 2
:4 0 62 125 127
122 129 128 :2 0
52 :3 0 53 :3 0
12b 12c 0 54
:4 0 4f :3 0 55
:3 0 12f 130 0
2 :4 0 64 131
133 56 :4 0 57
:2 0 58 :3 0 66
136 138 :3 0 59
:4 0 57 :2 0 5a
:4 0 69 13b 13d
:3 0 57 :2 0 3
:3 0 6c 13f 141
:3 0 57 :2 0 5a
:4 0 6f 143 145
:3 0 57 :2 0 5b
:4 0 72 147 149
:3 0 57 :2 0 e
:3 0 5c :3 0 7
:3 0 75 14d 14f
5d :4 0 77 14c
152 7a 14b 154
:3 0 57 :2 0 5b
:4 0 7d 156 158
:3 0 57 :2 0 e
:3 0 5c :3 0 9
:3 0 80 15c 15e
5d :4 0 82 15b
161 85 15a 163
:3 0 57 :2 0 5e
:4 0 88 165 167
:3 0 8b 12d 169
:2 0 16b 90 16c
12a 16b 0 16d
92 0 15c3 4f
:3 0 50 :3 0 16e
16f 0 4f :3 0
5f :3 0 171 172
0 a :2 0 2
:4 0 60 :2 0 61
:2 0 a :2 0 94
177 179 :3 0 97
173 17b 170 17d
17c :2 0 52 :3 0
62 :3 0 17f 180
0 54 :4 0 63
:4 0 57 :2 0 58
:3 0 9b 184 186
:3 0 9e 181 188
:2 0 18a a1 18b
17e 18a 0 18c
a3 0 15c3 e
:3 0 64 :3 0 65
:3 0 25 :3 0 33
:3 0 3b :3 0 3e
:3 0 3 :4 0 66
1 :8 0 19b 45
:3 0 67 :3 0 196
197 0 68 :3 0
198 199 0 19b
a5 1ee 69 :3 0
45 :3 0 67 :3 0
19d 19e 0 68
:3 0 19f 1a0 0
1a2 a8 1a4 aa
1a3 1a2 :2 0 1ec
6a :3 0 45 :3 0
67 :3 0 1a7 1a8
0 68 :3 0 1a9
1aa 0 1e4 4f
:3 0 50 :3 0 1ac
1ad 0 4f :3 0
5f :3 0 1af 1b0
0 6b :2 0 2
:4 0 6c :2 0 61
:2 0 a :2 0 ac
1b5 1b7 :3 0 af
1b1 1b9 1ae 1bb
1ba :2 0 52 :3 0
62 :3 0 1bd 1be
0 54 :4 0 6d
:4 0 57 :2 0 58
:3 0 b3 1c2 1c4
:3 0 57 :2 0 6e
:4 0 b6 1c6 1c8
:3 0 57 :2 0 6f
:4 0 b9 1ca 1cc
:3 0 57 :2 0 68
:3 0 bc 1ce 1d0
:3 0 57 :2 0 70
:4 0 bf 1d2 1d4
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 c2
1d7 1db c6 1d6
1dd :3 0 c9 1bf
1df :2 0 1e1 cc
1e2 1bc 1e1 0
1e3 ce 0 1e4
d0 1e7 :3 0 1e7
0 1e7 1e6 1e4
1e5 :6 0 1e9 5
:3 0 d3 1eb d5
1ea 1e9 :2 0 1ec
d7 :2 0 1ee 0
1ee 1ed 19b 1ec
:6 0 15c3 1 :3 0
71 :3 0 33 :3 0
a :2 0 a :2 0
da 1f0 1f4 74
:2 0 75 :4 0 e0
1f6 1f8 :3 0 4f
:3 0 50 :3 0 1fa
1fb 0 4f :3 0
5f :3 0 1fd 1fe
0 17 :2 0 2
:4 0 76 :2 0 61
:2 0 a :2 0 e3
203 205 :3 0 e6
1ff 207 1fc 209
208 :2 0 52 :3 0
62 :3 0 20b 20c
0 54 :4 0 77
:4 0 57 :2 0 58
:3 0 ea 210 212
:3 0 57 :2 0 6e
:4 0 ed 214 216
:3 0 57 :2 0 78
:4 0 f0 218 21a
:3 0 57 :2 0 e
:3 0 5c :3 0 13
:3 0 79 :3 0 21f
220 0 f3 21e
222 5d :4 0 f5
21d 225 f8 21c
227 :3 0 57 :2 0
7a :4 0 fb 229
22b :3 0 57 :2 0
5a :4 0 fe 22d
22f :3 0 57 :2 0
3 :3 0 101 231
233 :3 0 57 :2 0
5a :4 0 104 235
237 :3 0 107 20d
239 :2 0 23b 10a
23c 20a 23b 0
23d 10c 0 269
4f :3 0 50 :3 0
23e 23f 0 4f
:3 0 5f :3 0 241
242 0 a :2 0
2 :4 0 7b :2 0
61 :2 0 a :2 0
10e 247 249 :3 0
111 243 24b 240
24d 24c :2 0 52
:3 0 62 :3 0 24f
250 0 54 :4 0
7c :4 0 57 :2 0
58 :3 0 115 254
256 :3 0 118 251
258 :2 0 25a 11b
25b 24e 25a 0
25c 11d 0 269
b :3 0 7d :3 0
7e :3 0 25e 25f
0 13 :3 0 79
:3 0 261 262 0
3 :3 0 7f :3 0
11f 260 266 267
:2 0 269 123 26a
1f9 269 0 26b
127 0 15c3 45
:3 0 67 :3 0 26c
26d 0 45 :3 0
74 :2 0 80 :3 0
26f 271 0 12b
270 273 :3 0 274
:2 0 3d :3 0 3d
:3 0 3f :3 0 42
:3 0 16 :3 0 29
:3 0 28 :3 0 39
:3 0 81 :3 0 41
:3 0 37 :3 0 3
:4 0 82 1 :8 0
288 45 :3 0 67
:3 0 283 284 0
68 :3 0 285 286
0 288 12e 2db
69 :3 0 45 :3 0
67 :3 0 28a 28b
0 68 :3 0 28c
28d 0 28f 131
291 133 290 28f
:2 0 2d9 6a :3 0
45 :3 0 67 :3 0
294 295 0 68
:3 0 296 297 0
2d1 4f :3 0 50
:3 0 299 29a 0
4f :3 0 5f :3 0
29c 29d 0 6b
:2 0 2 :4 0 83
:2 0 61 :2 0 a
:2 0 135 2a2 2a4
:3 0 138 29e 2a6
29b 2a8 2a7 :2 0
52 :3 0 62 :3 0
2aa 2ab 0 54
:4 0 84 :4 0 57
:2 0 58 :3 0 13c
2af 2b1 :3 0 57
:2 0 6e :4 0 13f
2b3 2b5 :3 0 57
:2 0 6f :4 0 142
2b7 2b9 :3 0 57
:2 0 68 :3 0 145
2bb 2bd :3 0 57
:2 0 70 :4 0 148
2bf 2c1 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 14b 2c4 2c8
14f 2c3 2ca :3 0
152 2ac 2cc :2 0
2ce 155 2cf 2a9
2ce 0 2d0 157
0 2d1 159 2d4
:3 0 2d4 0 2d4
2d3 2d1 2d2 :6 0
2d6 7 :3 0 15c
2d8 15e 2d7 2d6
:2 0 2d9 160 :2 0
2db 0 2db 2da
288 2d9 :6 0 440
1 :3 0 45 :3 0
67 :3 0 2dd 2de
0 45 :3 0 74
:2 0 80 :3 0 2e0
2e2 0 165 2e1
2e4 :3 0 2e5 :2 0
4f :3 0 50 :3 0
2e7 2e8 0 4f
:3 0 5f :3 0 2ea
2eb 0 85 :2 0
2 :4 0 86 :2 0
61 :2 0 a :2 0
168 2f0 2f2 :3 0
16b 2ec 2f4 2e9
2f6 2f5 :2 0 52
:3 0 62 :3 0 2f8
2f9 0 54 :4 0
87 :4 0 57 :2 0
58 :3 0 16f 2fd
2ff :3 0 57 :2 0
6e :4 0 172 301
303 :3 0 57 :2 0
78 :4 0 175 305
307 :3 0 57 :2 0
e :3 0 5c :3 0
13 :3 0 88 :3 0
30c 30d 0 178
30b 30f 5d :4 0
17a 30a 312 17d
309 314 :3 0 180
2fa 316 :2 0 318
183 319 2f7 318
0 31a 185 0
346 4f :3 0 50
:3 0 31b 31c 0
4f :3 0 5f :3 0
31e 31f 0 a
:2 0 2 :4 0 89
:2 0 61 :2 0 a
:2 0 187 324 326
:3 0 18a 320 328
31d 32a 329 :2 0
52 :3 0 62 :3 0
32c 32d 0 54
:4 0 8a :4 0 57
:2 0 58 :3 0 18e
331 333 :3 0 191
32e 335 :2 0 337
194 338 32b 337
0 339 196 0
346 b :3 0 7d
:3 0 8b :3 0 33b
33c 0 13 :3 0
88 :3 0 33e 33f
0 7f :3 0 198
33d 342 343 :2 0
346 8c :3 0 19b
3ce e :3 0 29
:3 0 f :2 0 19f
347 34a 74 :2 0
f :2 0 1a4 34c
34e :3 0 34f :2 0
e :3 0 28 :3 0
f :2 0 1a7 351
354 74 :2 0 a
:2 0 1ac 356 358
:3 0 359 :2 0 350
35b 35a :2 0 4f
:3 0 50 :3 0 35d
35e 0 4f :3 0
5f :3 0 360 361
0 17 :2 0 2
:4 0 8d :2 0 61
:2 0 a :2 0 1af
366 368 :3 0 1b2
362 36a 35f 36c
36b :2 0 52 :3 0
62 :3 0 36e 36f
0 54 :4 0 8e
:4 0 57 :2 0 58
:3 0 1b6 373 375
:3 0 57 :2 0 6e
:4 0 1b9 377 379
:3 0 57 :2 0 78
:4 0 1bc 37b 37d
:3 0 57 :2 0 e
:3 0 5c :3 0 13
:3 0 8f :3 0 382
383 0 1bf 381
385 5d :4 0 1c1
380 388 1c4 37f
38a :3 0 57 :2 0
7a :4 0 1c7 38c
38e :3 0 57 :2 0
5a :4 0 1ca 390
392 :3 0 57 :2 0
3 :3 0 1cd 394
396 :3 0 57 :2 0
5a :4 0 1d0 398
39a :3 0 1d3 370
39c :2 0 39e 1d6
39f 36d 39e 0
3a0 1d8 0 3cc
4f :3 0 50 :3 0
3a1 3a2 0 4f
:3 0 5f :3 0 3a4
3a5 0 a :2 0
2 :4 0 90 :2 0
61 :2 0 a :2 0
1da 3aa 3ac :3 0
1dd 3a6 3ae 3a3
3b0 3af :2 0 52
:3 0 62 :3 0 3b2
3b3 0 54 :4 0
91 :4 0 57 :2 0
58 :3 0 1e1 3b7
3b9 :3 0 1e4 3b4
3bb :2 0 3bd 1e7
3be 3b1 3bd 0
3bf 1e9 0 3cc
b :3 0 7d :3 0
7e :3 0 3c1 3c2
0 13 :3 0 8f
:3 0 3c4 3c5 0
3 :3 0 7f :3 0
1eb 3c3 3c9 3ca
:2 0 3cc 1ef 3cd
35c 3cc 0 3cf
2e6 346 0 3cf
1f3 0 440 e
:3 0 64 :3 0 25
:3 0 3b :3 0 3e
:3 0 16 :4 0 92
1 :8 0 3dc 45
:3 0 67 :3 0 3d7
3d8 0 68 :3 0
3d9 3da 0 3dc
1f6 42f 69 :3 0
45 :3 0 67 :3 0
3de 3df 0 68
:3 0 3e0 3e1 0
3e3 1f9 3e5 1fb
3e4 3e3 :2 0 42d
6a :3 0 45 :3 0
67 :3 0 3e8 3e9
0 68 :3 0 3ea
3eb 0 425 4f
:3 0 50 :3 0 3ed
3ee 0 4f :3 0
5f :3 0 3f0 3f1
0 6b :2 0 2
:4 0 93 :2 0 61
:2 0 a :2 0 1fd
3f6 3f8 :3 0 200
3f2 3fa 3ef 3fc
3fb :2 0 52 :3 0
62 :3 0 3fe 3ff
0 54 :4 0 94
:4 0 57 :2 0 58
:3 0 204 403 405
:3 0 57 :2 0 6e
:4 0 207 407 409
:3 0 57 :2 0 6f
:4 0 20a 40b 40d
:3 0 57 :2 0 68
:3 0 20d 40f 411
:3 0 57 :2 0 70
:4 0 210 413 415
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 213
418 41c 217 417
41e :3 0 21a 400
420 :2 0 422 21d
423 3fd 422 0
424 21f 0 425
221 428 :3 0 428
0 428 427 425
426 :6 0 42a 9
:3 0 224 42c 226
42b 42a :2 0 42d
228 :2 0 42f 0
42f 42e 3dc 42d
:6 0 440 1 :3 0
31 :3 0 95 :4 0
57 :2 0 96 :4 0
22b 433 435 :3 0
57 :2 0 3 :3 0
22e 437 439 :3 0
57 :2 0 97 :4 0
231 43b 43d :3 0
431 43e 0 440
234 72c 16 :3 0
3 :3 0 441 442
0 72b e :3 0
c :3 0 f :2 0
239 444 447 74
:2 0 98 :2 0 23e
449 44b :3 0 3b
:3 0 99 :3 0 99
:3 0 13 :3 0 9a
:3 0 13 :3 0 9b
:3 0 99 :3 0 9c
:3 0 e :3 0 9d
:3 0 9c :3 0 9e
:3 0 e :3 0 9f
:3 0 9e :3 0 a0
:3 0 a1 :3 0 a0
:3 0 a1 :3 0 a2
:3 0 a3 :3 0 9d
:3 0 9f :3 0 a1
:3 0 a4 :3 0 a5
:3 0 a6 :3 0 a3
:3 0 a7 :3 0 a3
:3 0 a8 :3 0 3d
:3 0 16 :3 0 99
:3 0 13 :3 0 a9
:3 0 13 :3 0 aa
:3 0 13 :3 0 ab
:3 0 13 :3 0 ac
:3 0 13 :3 0 ad
:3 0 13 :3 0 ae
:3 0 13 :3 0 af
:3 0 13 :3 0 b0
:3 0 13 :3 0 b1
:3 0 13 :3 0 b2
:3 0 13 :3 0 b3
:3 0 13 :3 0 b4
:3 0 13 :3 0 b5
:3 0 13 :3 0 b6
:3 0 13 :3 0 b7
:3 0 b8 :3 0 b9
:3 0 a2 :4 0 ba
1 :8 0 4a7 bb
:4 0 492 :3 0 bc
:3 0 74 :2 0 243
495 496 :3 0 45
:3 0 67 :3 0 498
499 0 f :2 0
49a 49b 0 49d
246 4a4 45 :3 0
67 :3 0 49e 49f
0 bd :2 0 4a0
4a1 0 4a3 248
4a5 497 49d 0
4a6 0 4a3 0
4a6 24a 0 4a7
24d 4fa 69 :3 0
45 :3 0 67 :3 0
4a9 4aa 0 68
:3 0 4ab 4ac 0
4ae 250 4b0 252
4af 4ae :2 0 4f8
6a :3 0 45 :3 0
67 :3 0 4b3 4b4
0 68 :3 0 4b5
4b6 0 4f0 4f
:3 0 50 :3 0 4b8
4b9 0 4f :3 0
5f :3 0 4bb 4bc
0 6b :2 0 2
:4 0 be :2 0 61
:2 0 a :2 0 254
4c1 4c3 :3 0 257
4bd 4c5 4ba 4c7
4c6 :2 0 52 :3 0
62 :3 0 4c9 4ca
0 54 :4 0 bf
:4 0 57 :2 0 58
:3 0 25b 4ce 4d0
:3 0 57 :2 0 6e
:4 0 25e 4d2 4d4
:3 0 57 :2 0 6f
:4 0 261 4d6 4d8
:3 0 57 :2 0 68
:3 0 264 4da 4dc
:3 0 57 :2 0 70
:4 0 267 4de 4e0
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 26a
4e3 4e7 26e 4e2
4e9 :3 0 271 4cb
4eb :2 0 4ed 274
4ee 4c8 4ed 0
4ef 276 0 4f0
278 4f3 :3 0 4f3
0 4f3 4f2 4f0
4f1 :6 0 4f5 b
:3 0 27b 4f7 27d
4f6 4f5 :2 0 4f8
27f :2 0 4fa 0
4fa 4f9 4a7 4f8
:6 0 69f 1 :3 0
c0 :3 0 35 :4 0
4ff :2 0 69f 4fd
500 :3 0 c1 :3 0
35 :3 0 1c :3 0
1a :4 0 506 :2 0
63e 502 507 :3 0
282 :3 0 35 :3 0
bb :3 0 508 509
:3 0 45 :3 0 67
:3 0 50b 50c 0
f :2 0 50d 50e
0 510 285 517
45 :3 0 67 :3 0
511 512 0 bd
:2 0 513 514 0
516 287 518 50a
510 0 519 0
516 0 519 289
0 63e 45 :3 0
67 :3 0 51a 51b
0 45 :3 0 c2
:2 0 c3 :3 0 51d
51f 0 28e 51e
521 :3 0 522 :2 0
c4 :8 0 526 291
527 523 526 0
528 293 0 63e
39 :3 0 40 :3 0
9c :3 0 e :3 0
9d :3 0 9c :3 0
9e :3 0 e :3 0
9f :3 0 9e :3 0
a0 :3 0 a1 :3 0
a1 :3 0 a0 :3 0
c5 :3 0 c6 :3 0
a7 :3 0 c6 :3 0
c7 :3 0 e :3 0
9d :3 0 9c :3 0
c8 :3 0 e :3 0
9f :3 0 9e :3 0
c9 :3 0 c6 :3 0
ca :3 0 cb :3 0
cb :3 0 ca :3 0
cc :3 0 cd :3 0
cd :3 0 cc :3 0
ce :3 0 cf :3 0
a7 :3 0 c6 :3 0
d0 :3 0 d1 :3 0
d2 :3 0 cf :3 0
a7 :3 0 c6 :3 0
d3 :3 0 d4 :3 0
9d :3 0 9f :3 0
a1 :3 0 c6 :3 0
a4 :3 0 a5 :3 0
a8 :3 0 37 :3 0
1c :4 0 d5 1
:8 0 578 bb :4 0
563 :3 0 bc :3 0
74 :2 0 297 566
567 :3 0 45 :3 0
67 :3 0 569 56a
0 f :2 0 56b
56c 0 56e 29a
575 45 :3 0 67
:3 0 56f 570 0
bd :2 0 571 572
0 574 29c 576
568 56e 0 577
0 574 0 577
29e 0 578 2a1
5cb 69 :3 0 45
:3 0 67 :3 0 57a
57b 0 68 :3 0
57c 57d 0 57f
2a4 581 2a6 580
57f :2 0 5c9 6a
:3 0 45 :3 0 67
:3 0 584 585 0
68 :3 0 586 587
0 5c1 4f :3 0
50 :3 0 589 58a
0 4f :3 0 5f
:3 0 58c 58d 0
6b :2 0 2 :4 0
d6 :2 0 61 :2 0
a :2 0 2a8 592
594 :3 0 2ab 58e
596 58b 598 597
:2 0 52 :3 0 62
:3 0 59a 59b 0
54 :4 0 d7 :4 0
57 :2 0 58 :3 0
2af 59f 5a1 :3 0
57 :2 0 6e :4 0
2b2 5a3 5a5 :3 0
57 :2 0 6f :4 0
2b5 5a7 5a9 :3 0
57 :2 0 68 :3 0
2b8 5ab 5ad :3 0
57 :2 0 70 :4 0
2bb 5af 5b1 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 2be 5b4
5b8 2c2 5b3 5ba
:3 0 2c5 59c 5bc
:2 0 5be 2c8 5bf
599 5be 0 5c0
2ca 0 5c1 2cc
5c4 :3 0 5c4 0
5c4 5c3 5c1 5c2
:6 0 5c6 e :3 0
2cf 5c8 2d1 5c7
5c6 :2 0 5c9 2d3
:2 0 5cb 0 5cb
5ca 578 5c9 :6 0
63e d :3 0 4b
:3 0 40 :3 0 3d
:3 0 16 :3 0 37
:3 0 1c :4 0 d8
1 :8 0 5e9 bb
:4 0 5d4 :3 0 bc
:3 0 74 :2 0 2d8
5d7 5d8 :3 0 45
:3 0 67 :3 0 5da
5db 0 f :2 0
5dc 5dd 0 5df
2db 5e6 45 :3 0
67 :3 0 5e0 5e1
0 bd :2 0 5e2
5e3 0 5e5 2dd
5e7 5d9 5df 0
5e8 0 5e5 0
5e8 2df 0 5e9
2e2 63c 69 :3 0
45 :3 0 67 :3 0
5eb 5ec 0 68
:3 0 5ed 5ee 0
5f0 2e5 5f2 2e7
5f1 5f0 :2 0 63a
6a :3 0 45 :3 0
67 :3 0 5f5 5f6
0 68 :3 0 5f7
5f8 0 632 4f
:3 0 50 :3 0 5fa
5fb 0 4f :3 0
5f :3 0 5fd 5fe
0 6b :2 0 2
:4 0 d9 :2 0 61
:2 0 a :2 0 2e9
603 605 :3 0 2ec
5ff 607 5fc 609
608 :2 0 52 :3 0
62 :3 0 60b 60c
0 54 :4 0 da
:4 0 57 :2 0 58
:3 0 2f0 610 612
:3 0 57 :2 0 6e
:4 0 2f3 614 616
:3 0 57 :2 0 6f
:4 0 2f6 618 61a
:3 0 57 :2 0 68
:3 0 2f9 61c 61e
:3 0 57 :2 0 70
:4 0 2fc 620 622
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 2ff
625 629 303 624
62b :3 0 306 60d
62d :2 0 62f 309
630 60a 62f 0
631 30b 0 632
30d 635 :3 0 635
0 635 634 632
633 :6 0 637 10
:3 0 310 639 312
638 637 :2 0 63a
314 :2 0 63c 0
63c 63b 5e9 63a
:6 0 63e d :3 0
317 640 c1 :4 0
63e :4 0 69f db
:3 0 35 :4 0 644
:2 0 64a 642 0
45 :3 0 67 :3 0
645 646 0 68
:3 0 647 648 0
64a 31d 69d 69
:3 0 45 :3 0 67
:3 0 64c 64d 0
68 :3 0 64e 64f
0 651 320 653
322 652 651 :2 0
69b 6a :3 0 45
:3 0 67 :3 0 656
657 0 68 :3 0
658 659 0 693
4f :3 0 50 :3 0
65b 65c 0 4f
:3 0 5f :3 0 65e
65f 0 6b :2 0
2 :4 0 dc :2 0
61 :2 0 a :2 0
324 664 666 :3 0
327 660 668 65d
66a 669 :2 0 52
:3 0 62 :3 0 66c
66d 0 54 :4 0
dd :4 0 57 :2 0
58 :3 0 32b 671
673 :3 0 57 :2 0
6e :4 0 32e 675
677 :3 0 57 :2 0
6f :4 0 331 679
67b :3 0 57 :2 0
68 :3 0 334 67d
67f :3 0 57 :2 0
70 :4 0 337 681
683 :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
33a 686 68a 33e
685 68c :3 0 341
66e 68e :2 0 690
344 691 66b 690
0 692 346 0
693 348 696 :3 0
696 0 696 695
693 694 :6 0 698
12 :3 0 34b 69a
34d 699 698 :2 0
69b 34f :2 0 69d
0 69d 69c 64a
69b :6 0 69f 1
:3 0 352 6a0 44c
69f 0 6a1 357
0 72b 3b :3 0
de :3 0 13 :3 0
df :3 0 3d :3 0
16 :3 0 b8 :3 0
b9 :3 0 a2 :4 0
e0 1 :8 0 6c1
bb :4 0 6ac :3 0
bc :3 0 74 :2 0
35b 6af 6b0 :3 0
45 :3 0 67 :3 0
6b2 6b3 0 f
:2 0 6b4 6b5 0
6b7 35e 6be 45
:3 0 67 :3 0 6b8
6b9 0 bd :2 0
6ba 6bb 0 6bd
360 6bf 6b1 6b7
0 6c0 0 6bd
0 6c0 362 0
6c1 365 714 69
:3 0 45 :3 0 67
:3 0 6c3 6c4 0
68 :3 0 6c5 6c6
0 6c8 368 6ca
36a 6c9 6c8 :2 0
712 6a :3 0 45
:3 0 67 :3 0 6cd
6ce 0 68 :3 0
6cf 6d0 0 70a
4f :3 0 50 :3 0
6d2 6d3 0 4f
:3 0 5f :3 0 6d5
6d6 0 6b :2 0
2 :4 0 e1 :2 0
61 :2 0 a :2 0
36c 6db 6dd :3 0
36f 6d7 6df 6d4
6e1 6e0 :2 0 52
:3 0 62 :3 0 6e3
6e4 0 54 :4 0
e2 :4 0 57 :2 0
58 :3 0 373 6e8
6ea :3 0 57 :2 0
6e :4 0 376 6ec
6ee :3 0 57 :2 0
6f :4 0 379 6f0
6f2 :3 0 57 :2 0
68 :3 0 37c 6f4
6f6 :3 0 57 :2 0
70 :4 0 37f 6f8
6fa :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
382 6fd 701 386
6fc 703 :3 0 389
6e5 705 :2 0 707
38c 708 6e2 707
0 709 38e 0
70a 390 70d :3 0
70d 0 70d 70c
70a 70b :6 0 70f
14 :3 0 393 711
395 710 70f :2 0
712 397 :2 0 714
0 714 713 6c1
712 :6 0 72b 1
:3 0 29 :3 0 a
:2 0 716 717 0
72b c :3 0 e3
:2 0 719 71a 0
72b 31 :3 0 e4
:4 0 57 :2 0 e5
:4 0 39a 71e 720
:3 0 57 :2 0 3
:3 0 39d 722 724
:3 0 57 :2 0 97
:4 0 3a0 726 728
:3 0 71c 729 0
72b 3a3 72d 275
440 0 72e 0
72b 0 72e 3aa
0 15c3 c0 :3 0
44 :3 0 31 :3 0
730 731 0 732
:2 0 15c3 c1 :3 0
44 :3 0 3 :3 0
1a :3 0 1b :3 0
2a :4 0 73b :2 0
141d 735 73c :3 0
3ad :3 0 44 :3 0
bb :3 0 73d 73e
:3 0 45 :3 0 67
:3 0 740 741 0
f :2 0 742 743
0 745 3b2 74c
45 :3 0 67 :3 0
746 747 0 bd
:2 0 748 749 0
74b 3b4 74d 73f
745 0 74e 0
74b 0 74e 3b6
0 141d 45 :3 0
67 :3 0 74f 750
0 45 :3 0 c2
:2 0 c3 :3 0 752
754 0 3bb 753
756 :3 0 757 :2 0
c4 :8 0 75b 3be
75c 758 75b 0
75d 3c0 0 141d
c :3 0 a :2 0
e6 :3 0 e7 :3 0
e7 :3 0 e8 :3 0
e7 :3 0 e9 :3 0
e7 :3 0 e9 :3 0
e7 :3 0 ea :3 0
e7 :3 0 ea :3 0
e7 :3 0 eb :3 0
e7 :3 0 ec :3 0
e7 :3 0 ed :3 0
e7 :3 0 ed :3 0
e7 :3 0 ee :3 0
e7 :3 0 ee :3 0
e7 :3 0 ef :3 0
3d :3 0 16 :3 0
3e :3 0 1b :4 0
f0 1 :8 0 794
bb :4 0 77f :3 0
bc :3 0 74 :2 0
3c4 782 783 :3 0
45 :3 0 67 :3 0
785 786 0 f
:2 0 787 788 0
78a 3c7 791 45
:3 0 67 :3 0 78b
78c 0 bd :2 0
78d 78e 0 790
3c9 792 784 78a
0 793 0 790
0 793 3cb 0
794 3ce 7e7 69
:3 0 45 :3 0 67
:3 0 796 797 0
68 :3 0 798 799
0 79b 3d1 79d
3d3 79c 79b :2 0
7e5 6a :3 0 45
:3 0 67 :3 0 7a0
7a1 0 68 :3 0
7a2 7a3 0 7dd
4f :3 0 50 :3 0
7a5 7a6 0 4f
:3 0 5f :3 0 7a8
7a9 0 6b :2 0
2 :4 0 f1 :2 0
61 :2 0 a :2 0
3d5 7ae 7b0 :3 0
3d8 7aa 7b2 7a7
7b4 7b3 :2 0 52
:3 0 62 :3 0 7b6
7b7 0 54 :4 0
f2 :4 0 57 :2 0
58 :3 0 3dc 7bb
7bd :3 0 57 :2 0
6e :4 0 3df 7bf
7c1 :3 0 57 :2 0
6f :4 0 3e2 7c3
7c5 :3 0 57 :2 0
68 :3 0 3e5 7c7
7c9 :3 0 57 :2 0
70 :4 0 3e8 7cb
7cd :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
3eb 7d0 7d4 3ef
7cf 7d6 :3 0 3f2
7b8 7d8 :2 0 7da
3f5 7db 7b5 7da
0 7dc 3f7 0
7dd 3f9 7e0 :3 0
7e0 0 7e0 7df
7dd 7de :6 0 7e2
17 :3 0 3fc 7e4
3fe 7e3 7e2 :2 0
7e5 400 :2 0 7e7
0 7e7 7e6 794
7e5 :6 0 95b 16
:3 0 39 :3 0 36
:3 0 36 :3 0 f3
:3 0 36 :3 0 f4
:3 0 36 :3 0 f5
:3 0 36 :3 0 f6
:3 0 36 :3 0 f7
:3 0 36 :3 0 f8
:3 0 36 :3 0 f9
:3 0 36 :3 0 fa
:3 0 36 :3 0 fb
:3 0 36 :3 0 fc
:3 0 36 :3 0 fd
:3 0 36 :3 0 fe
:3 0 36 :3 0 f4
:3 0 36 :3 0 ff
:3 0 36 :3 0 f6
:3 0 36 :3 0 100
:3 0 36 :3 0 f8
:3 0 36 :3 0 101
:3 0 36 :3 0 fa
:3 0 36 :3 0 102
:3 0 36 :3 0 fc
:3 0 36 :3 0 103
:3 0 36 :3 0 fe
:3 0 36 :3 0 104
:3 0 36 :3 0 ff
:3 0 36 :3 0 105
:3 0 36 :3 0 100
:3 0 36 :3 0 106
:3 0 36 :3 0 101
:3 0 36 :3 0 107
:3 0 36 :3 0 102
:3 0 36 :3 0 c5
:3 0 36 :3 0 c6
:3 0 36 :3 0 103
:3 0 36 :3 0 ca
:3 0 36 :3 0 cb
:3 0 36 :3 0 104
:3 0 36 :3 0 cc
:3 0 36 :3 0 cd
:3 0 36 :3 0 108
:3 0 36 :3 0 d0
:3 0 36 :3 0 109
:3 0 36 :3 0 d3
:3 0 36 :3 0 10a
:3 0 36 :3 0 10b
:3 0 36 :3 0 10c
:3 0 36 :3 0 10d
:3 0 37 :3 0 3
:4 0 10e 1 :8 0
861 bb :4 0 84c
:3 0 bc :3 0 74
:2 0 405 84f 850
:3 0 45 :3 0 67
:3 0 852 853 0
f :2 0 854 855
0 857 408 85e
45 :3 0 67 :3 0
858 859 0 bd
:2 0 85a 85b 0
85d 40a 85f 851
857 0 860 0
85d 0 860 40c
0 861 40f 8b4
69 :3 0 45 :3 0
67 :3 0 863 864
0 68 :3 0 865
866 0 868 412
86a 414 869 868
:2 0 8b2 6a :3 0
45 :3 0 67 :3 0
86d 86e 0 68
:3 0 86f 870 0
8aa 4f :3 0 50
:3 0 872 873 0
4f :3 0 5f :3 0
875 876 0 6b
:2 0 2 :4 0 10f
:2 0 61 :2 0 a
:2 0 416 87b 87d
:3 0 419 877 87f
874 881 880 :2 0
52 :3 0 62 :3 0
883 884 0 54
:4 0 110 :4 0 57
:2 0 58 :3 0 41d
888 88a :3 0 57
:2 0 6e :4 0 420
88c 88e :3 0 57
:2 0 6f :4 0 423
890 892 :3 0 57
:2 0 68 :3 0 426
894 896 :3 0 57
:2 0 70 :4 0 429
898 89a :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 42c 89d 8a1
430 89c 8a3 :3 0
433 885 8a5 :2 0
8a7 436 8a8 882
8a7 0 8a9 438
0 8aa 43a 8ad
:3 0 8ad 0 8ad
8ac 8aa 8ab :6 0
8af 19 :3 0 43d
8b1 43f 8b0 8af
:2 0 8b2 441 :2 0
8b4 0 8b4 8b3
861 8b2 :6 0 95b
16 :3 0 111 :3 0
112 :3 0 113 :3 0
113 :3 0 114 :3 0
114 :3 0 115 :3 0
115 :3 0 116 :3 0
117 :3 0 118 :3 0
118 :3 0 119 :3 0
119 :3 0 11a :3 0
11a :3 0 11b :3 0
11c :3 0 11d :3 0
11d :3 0 11e :3 0
11e :3 0 11f :3 0
11f :3 0 120 :3 0
121 :3 0 122 :3 0
122 :3 0 123 :3 0
123 :3 0 124 :3 0
124 :3 0 125 :3 0
126 :3 0 127 :3 0
127 :3 0 128 :3 0
128 :3 0 129 :3 0
129 :3 0 12a :3 0
12b :3 0 105 :3 0
12c :3 0 106 :3 0
12d :3 0 107 :3 0
12e :3 0 c5 :3 0
c6 :3 0 12f :3 0
ca :3 0 cb :3 0
130 :3 0 cc :3 0
cd :3 0 3d :3 0
16 :4 0 131 1
:8 0 906 bb :4 0
8f1 :3 0 bc :3 0
74 :2 0 446 8f4
8f5 :3 0 45 :3 0
67 :3 0 8f7 8f8
0 f :2 0 8f9
8fa 0 8fc 449
903 45 :3 0 67
:3 0 8fd 8fe 0
bd :2 0 8ff 900
0 902 44b 904
8f6 8fc 0 905
0 902 0 905
44d 0 906 450
959 69 :3 0 45
:3 0 67 :3 0 908
909 0 68 :3 0
90a 90b 0 90d
453 90f 455 90e
90d :2 0 957 6a
:3 0 45 :3 0 67
:3 0 912 913 0
68 :3 0 914 915
0 94f 4f :3 0
50 :3 0 917 918
0 4f :3 0 5f
:3 0 91a 91b 0
6b :2 0 2 :4 0
132 :2 0 61 :2 0
a :2 0 457 920
922 :3 0 45a 91c
924 919 926 925
:2 0 52 :3 0 62
:3 0 928 929 0
54 :4 0 133 :4 0
57 :2 0 58 :3 0
45e 92d 92f :3 0
57 :2 0 6e :4 0
461 931 933 :3 0
57 :2 0 6f :4 0
464 935 937 :3 0
57 :2 0 68 :3 0
467 939 93b :3 0
57 :2 0 70 :4 0
46a 93d 93f :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 46d 942
946 471 941 948
:3 0 474 92a 94a
:2 0 94c 477 94d
927 94c 0 94e
479 0 94f 47b
952 :3 0 952 0
952 951 94f 950
:6 0 954 1b :3 0
47e 956 480 955
954 :2 0 957 482
:2 0 959 0 959
958 906 957 :6 0
95b 16 :3 0 485
95d 489 95c 95b
:2 0 13aa e3 :2 0
c6 :3 0 24 :3 0
39 :3 0 40 :3 0
37 :3 0 3 :4 0
134 1 :8 0 96b
45 :3 0 67 :3 0
966 967 0 68
:3 0 968 969 0
96b 48b 9be 69
:3 0 45 :3 0 67
:3 0 96d 96e 0
68 :3 0 96f 970
0 972 48e 974
490 973 972 :2 0
9bc 6a :3 0 45
:3 0 67 :3 0 977
978 0 68 :3 0
979 97a 0 9b4
4f :3 0 50 :3 0
97c 97d 0 4f
:3 0 5f :3 0 97f
980 0 6b :2 0
2 :4 0 135 :2 0
61 :2 0 a :2 0
492 985 987 :3 0
495 981 989 97e
98b 98a :2 0 52
:3 0 62 :3 0 98d
98e 0 54 :4 0
136 :4 0 57 :2 0
58 :3 0 499 992
994 :3 0 57 :2 0
6e :4 0 49c 996
998 :3 0 57 :2 0
6f :4 0 49f 99a
99c :3 0 57 :2 0
68 :3 0 4a2 99e
9a0 :3 0 57 :2 0
70 :4 0 4a5 9a2
9a4 :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
4a8 9a7 9ab 4ac
9a6 9ad :3 0 4af
98f 9af :2 0 9b1
4b2 9b2 98c 9b1
0 9b3 4b4 0
9b4 4b6 9b7 :3 0
9b7 0 9b7 9b6
9b4 9b5 :6 0 9b9
1d :3 0 4b9 9bb
4bb 9ba 9b9 :2 0
9bc 4bd :2 0 9be
0 9be 9bd 96b
9bc :6 0 13a4 16
:3 0 45 :3 0 67
:3 0 9c0 9c1 0
45 :3 0 c2 :2 0
c3 :3 0 9c3 9c5
0 4c2 9c4 9c7
:3 0 9c8 :2 0 24
:3 0 137 :2 0 4c5
9cb 9cc :3 0 9cd
:2 0 9ce :2 0 9c9
9d0 9cf :2 0 138
:3 0 9d2 :4 0 9d4
4c7 9d5 9d1 9d4
0 9d6 4c9 0
13a4 37 :3 0 139
:3 0 139 :3 0 2a
:3 0 1d :3 0 2a
:3 0 39 :3 0 40
:3 0 3f :3 0 16
:3 0 38 :3 0 1a
:4 0 13a 1 :8 0
9e9 45 :3 0 67
:3 0 9e4 9e5 0
68 :3 0 9e6 9e7
0 9e9 4cb a3c
69 :3 0 45 :3 0
67 :3 0 9eb 9ec
0 68 :3 0 9ed
9ee 0 9f0 4ce
9f2 4d0 9f1 9f0
:2 0 a3a 6a :3 0
45 :3 0 67 :3 0
9f5 9f6 0 68
:3 0 9f7 9f8 0
a32 4f :3 0 50
:3 0 9fa 9fb 0
4f :3 0 5f :3 0
9fd 9fe 0 6b
:2 0 2 :4 0 13b
:2 0 61 :2 0 a
:2 0 4d2 a03 a05
:3 0 4d5 9ff a07
9fc a09 a08 :2 0
52 :3 0 62 :3 0
a0b a0c 0 54
:4 0 13c :4 0 57
:2 0 58 :3 0 4d9
a10 a12 :3 0 57
:2 0 6e :4 0 4dc
a14 a16 :3 0 57
:2 0 6f :4 0 4df
a18 a1a :3 0 57
:2 0 68 :3 0 4e2
a1c a1e :3 0 57
:2 0 70 :4 0 4e5
a20 a22 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 4e8 a25 a29
4ec a24 a2b :3 0
4ef a0d a2d :2 0
a2f 4f2 a30 a0a
a2f 0 a31 4f4
0 a32 4f6 a35
:3 0 a35 0 a35
a34 a32 a33 :6 0
a37 1f :3 0 4f9
a39 4fb a38 a37
:2 0 a3a 4fd :2 0
a3c 0 a3c a3b
9e9 a3a :6 0 13a4
16 :3 0 45 :3 0
67 :3 0 a3e a3f
0 45 :3 0 74
:2 0 c3 :3 0 a41
a43 0 502 a42
a45 :3 0 a46 :2 0
1d :3 0 13d :2 0
505 a49 a4a :3 0
a4b :2 0 a4c :2 0
a47 a4e a4d :2 0
e :3 0 29 :3 0
f :2 0 507 a50
a53 74 :2 0 f
:2 0 50c a55 a57
:3 0 23 :3 0 e3
:2 0 a59 a5a 0
a5c 50f c19 39
:3 0 37 :3 0 3
:4 0 13e 1 :8 0
a76 bb :4 0 a61
:3 0 bc :3 0 74
:2 0 513 a64 a65
:3 0 45 :3 0 67
:3 0 a67 a68 0
f :2 0 a69 a6a
0 a6c 516 a73
45 :3 0 67 :3 0
a6d a6e 0 bd
:2 0 a6f a70 0
a72 518 a74 a66
a6c 0 a75 0
a72 0 a75 51a
0 a76 51d ac9
69 :3 0 45 :3 0
67 :3 0 a78 a79
0 68 :3 0 a7a
a7b 0 a7d 520
a7f 522 a7e a7d
:2 0 ac7 6a :3 0
45 :3 0 67 :3 0
a82 a83 0 68
:3 0 a84 a85 0
abf 4f :3 0 50
:3 0 a87 a88 0
4f :3 0 5f :3 0
a8a a8b 0 6b
:2 0 2 :4 0 13f
:2 0 61 :2 0 a
:2 0 524 a90 a92
:3 0 527 a8c a94
a89 a96 a95 :2 0
52 :3 0 62 :3 0
a98 a99 0 54
:4 0 140 :4 0 57
:2 0 58 :3 0 52b
a9d a9f :3 0 57
:2 0 6e :4 0 52e
aa1 aa3 :3 0 57
:2 0 6f :4 0 531
aa5 aa7 :3 0 57
:2 0 68 :3 0 534
aa9 aab :3 0 57
:2 0 70 :4 0 537
aad aaf :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 53a ab2 ab6
53e ab1 ab8 :3 0
541 a9a aba :2 0
abc 544 abd a97
abc 0 abe 546
0 abf 548 ac2
:3 0 ac2 0 ac2
ac1 abf ac0 :6 0
ac4 21 :3 0 54b
ac6 54d ac5 ac4
:2 0 ac7 54f :2 0
ac9 0 ac9 ac8
a76 ac7 :6 0 c18
16 :3 0 141 :3 0
37 :3 0 3 :4 0
142 1 :8 0 ae4
bb :4 0 acf :3 0
bc :3 0 74 :2 0
554 ad2 ad3 :3 0
45 :3 0 67 :3 0
ad5 ad6 0 f
:2 0 ad7 ad8 0
ada 557 ae1 45
:3 0 67 :3 0 adb
adc 0 bd :2 0
add ade 0 ae0
559 ae2 ad4 ada
0 ae3 0 ae0
0 ae3 55b 0
ae4 55e b37 69
:3 0 45 :3 0 67
:3 0 ae6 ae7 0
68 :3 0 ae8 ae9
0 aeb 561 aed
563 aec aeb :2 0
b35 6a :3 0 45
:3 0 67 :3 0 af0
af1 0 68 :3 0
af2 af3 0 b2d
4f :3 0 50 :3 0
af5 af6 0 4f
:3 0 5f :3 0 af8
af9 0 6b :2 0
2 :4 0 143 :2 0
61 :2 0 a :2 0
565 afe b00 :3 0
568 afa b02 af7
b04 b03 :2 0 52
:3 0 62 :3 0 b06
b07 0 54 :4 0
144 :4 0 57 :2 0
58 :3 0 56c b0b
b0d :3 0 57 :2 0
6e :4 0 56f b0f
b11 :3 0 57 :2 0
6f :4 0 572 b13
b15 :3 0 57 :2 0
68 :3 0 575 b17
b19 :3 0 57 :2 0
70 :4 0 578 b1b
b1d :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
57b b20 b24 57f
b1f b26 :3 0 582
b08 b28 :2 0 b2a
585 b2b b05 b2a
0 b2c 587 0
b2d 589 b30 :3 0
b30 0 b30 b2f
b2d b2e :6 0 b32
23 :3 0 58c b34
58e b33 b32 :2 0
b35 590 :2 0 b37
0 b37 b36 ae4
b35 :6 0 c18 16
:3 0 145 :3 0 146
:3 0 3 :4 0 147
1 :8 0 b52 bb
:4 0 b3d :3 0 bc
:3 0 74 :2 0 595
b40 b41 :3 0 45
:3 0 67 :3 0 b43
b44 0 f :2 0
b45 b46 0 b48
598 b4f 45 :3 0
67 :3 0 b49 b4a
0 bd :2 0 b4b
b4c 0 b4e 59a
b50 b42 b48 0
b51 0 b4e 0
b51 59c 0 b52
59f ba5 69 :3 0
45 :3 0 67 :3 0
b54 b55 0 68
:3 0 b56 b57 0
b59 5a2 b5b 5a4
b5a b59 :2 0 ba3
6a :3 0 45 :3 0
67 :3 0 b5e b5f
0 68 :3 0 b60
b61 0 b9b 4f
:3 0 50 :3 0 b63
b64 0 4f :3 0
5f :3 0 b66 b67
0 6b :2 0 2
:4 0 148 :2 0 61
:2 0 a :2 0 5a6
b6c b6e :3 0 5a9
b68 b70 b65 b72
b71 :2 0 52 :3 0
62 :3 0 b74 b75
0 54 :4 0 149
:4 0 57 :2 0 58
:3 0 5ad b79 b7b
:3 0 57 :2 0 6e
:4 0 5b0 b7d b7f
:3 0 57 :2 0 6f
:4 0 5b3 b81 b83
:3 0 57 :2 0 68
:3 0 5b6 b85 b87
:3 0 57 :2 0 70
:4 0 5b9 b89 b8b
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 5bc
b8e b92 5c0 b8d
b94 :3 0 5c3 b76
b96 :2 0 b98 5c6
b99 b73 b98 0
b9a 5c8 0 b9b
5ca b9e :3 0 b9e
0 b9e b9d b9b
b9c :6 0 ba0 25
:3 0 5cd ba2 5cf
ba1 ba0 :2 0 ba3
5d1 :2 0 ba5 0
ba5 ba4 b52 ba3
:6 0 c18 16 :3 0
14a :3 0 146 :3 0
3 :4 0 14b 1
:8 0 bc0 bb :4 0
bab :3 0 bc :3 0
74 :2 0 5d6 bae
baf :3 0 45 :3 0
67 :3 0 bb1 bb2
0 f :2 0 bb3
bb4 0 bb6 5d9
bbd 45 :3 0 67
:3 0 bb7 bb8 0
bd :2 0 bb9 bba
0 bbc 5db bbe
bb0 bb6 0 bbf
0 bbc 0 bbf
5dd 0 bc0 5e0
c13 69 :3 0 45
:3 0 67 :3 0 bc2
bc3 0 68 :3 0
bc4 bc5 0 bc7
5e3 bc9 5e5 bc8
bc7 :2 0 c11 6a
:3 0 45 :3 0 67
:3 0 bcc bcd 0
68 :3 0 bce bcf
0 c09 4f :3 0
50 :3 0 bd1 bd2
0 4f :3 0 5f
:3 0 bd4 bd5 0
6b :2 0 2 :4 0
14c :2 0 61 :2 0
a :2 0 5e7 bda
bdc :3 0 5ea bd6
bde bd3 be0 bdf
:2 0 52 :3 0 62
:3 0 be2 be3 0
54 :4 0 14d :4 0
57 :2 0 58 :3 0
5ee be7 be9 :3 0
57 :2 0 6e :4 0
5f1 beb bed :3 0
57 :2 0 6f :4 0
5f4 bef bf1 :3 0
57 :2 0 68 :3 0
5f7 bf3 bf5 :3 0
57 :2 0 70 :4 0
5fa bf7 bf9 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 5fd bfc
c00 601 bfb c02
:3 0 604 be4 c04
:2 0 c06 607 c07
be1 c06 0 c08
609 0 c09 60b
c0c :3 0 c0c 0
c0c c0b c09 c0a
:6 0 c0e 27 :3 0
60e c10 610 c0f
c0e :2 0 c11 612
:2 0 c13 0 c13
c12 bc0 c11 :6 0
c18 16 :3 0 23
:3 0 a :2 0 c15
c16 0 c18 615
c1a a58 a5c 0
c1b 0 c18 0
c1b 61b 0 c1c
61e c24 1d :3 0
3 :3 0 c1d c1e
0 c23 23 :3 0
f :2 0 c20 c21
0 c23 620 c25
a4f c1c 0 c26
0 c23 0 c26
623 0 13a4 24
:3 0 f :2 0 c27
c28 0 13a4 c0
:3 0 47 :4 0 c2d
:2 0 13a4 c2b c2e
:3 0 c1 :3 0 47
:3 0 18 :3 0 24
:3 0 10 :4 0 c35
:2 0 e53 c30 c36
:3 0 626 :3 0 47
:3 0 bb :3 0 c37
c38 :3 0 45 :3 0
67 :3 0 c3a c3b
0 f :2 0 c3c
c3d 0 c3f 62a
c46 45 :3 0 67
:3 0 c40 c41 0
bd :2 0 c42 c43
0 c45 62c c47
c39 c3f 0 c48
0 c45 0 c48
62e 0 e53 45
:3 0 67 :3 0 c49
c4a 0 45 :3 0
c2 :2 0 c3 :3 0
c4c c4e 0 633
c4d c50 :3 0 c51
:2 0 c4 :8 0 c55
636 c56 c52 c55
0 c57 638 0
e53 e :3 0 23
:3 0 f :2 0 63a
c58 c5b 74 :2 0
a :2 0 63f c5d
c5f :3 0 4b :3 0
49 :3 0 49 :3 0
24 :3 0 4a :3 0
14e :3 0 14f :3 0
4a :3 0 10 :3 0
3d :3 0 16 :3 0
37 :3 0 1d :3 0
48 :3 0 18 :4 0
150 1 :8 0 c86
bb :4 0 c71 :3 0
bc :3 0 74 :2 0
644 c74 c75 :3 0
45 :3 0 67 :3 0
c77 c78 0 f
:2 0 c79 c7a 0
c7c 647 c83 45
:3 0 67 :3 0 c7d
c7e 0 bd :2 0
c7f c80 0 c82
649 c84 c76 c7c
0 c85 0 c82
0 c85 64b 0
c86 64e cd9 69
:3 0 45 :3 0 67
:3 0 c88 c89 0
68 :3 0 c8a c8b
0 c8d 651 c8f
653 c8e c8d :2 0
cd7 6a :3 0 45
:3 0 67 :3 0 c92
c93 0 68 :3 0
c94 c95 0 ccf
4f :3 0 50 :3 0
c97 c98 0 4f
:3 0 5f :3 0 c9a
c9b 0 6b :2 0
2 :4 0 151 :2 0
61 :2 0 a :2 0
655 ca0 ca2 :3 0
658 c9c ca4 c99
ca6 ca5 :2 0 52
:3 0 62 :3 0 ca8
ca9 0 54 :4 0
152 :4 0 57 :2 0
58 :3 0 65c cad
caf :3 0 57 :2 0
6e :4 0 65f cb1
cb3 :3 0 57 :2 0
6f :4 0 662 cb5
cb7 :3 0 57 :2 0
68 :3 0 665 cb9
cbb :3 0 57 :2 0
70 :4 0 668 cbd
cbf :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
66b cc2 cc6 66f
cc1 cc8 :3 0 672
caa cca :2 0 ccc
675 ccd ca7 ccc
0 cce 677 0
ccf 679 cd2 :3 0
cd2 0 cd2 cd1
ccf cd0 :6 0 cd4
2a :3 0 67c cd6
67e cd5 cd4 :2 0
cd7 680 :2 0 cd9
0 cd9 cd8 c86
cd7 :6 0 dd1 29
:3 0 45 :3 0 67
:3 0 cdb cdc 0
45 :3 0 74 :2 0
c3 :3 0 cde ce0
0 685 cdf ce2
:3 0 ce3 :2 0 4b
:3 0 3d :3 0 16
:3 0 37 :3 0 3
:3 0 48 :3 0 18
:4 0 153 1 :8 0
d02 bb :4 0 ced
:3 0 bc :3 0 74
:2 0 68a cf0 cf1
:3 0 45 :3 0 67
:3 0 cf3 cf4 0
f :2 0 cf5 cf6
0 cf8 68d cff
45 :3 0 67 :3 0
cf9 cfa 0 bd
:2 0 cfb cfc 0
cfe 68f d00 cf2
cf8 0 d01 0
cfe 0 d01 691
0 d02 694 d55
69 :3 0 45 :3 0
67 :3 0 d04 d05
0 68 :3 0 d06
d07 0 d09 697
d0b 699 d0a d09
:2 0 d53 6a :3 0
45 :3 0 67 :3 0
d0e d0f 0 68
:3 0 d10 d11 0
d4b 4f :3 0 50
:3 0 d13 d14 0
4f :3 0 5f :3 0
d16 d17 0 6b
:2 0 2 :4 0 154
:2 0 61 :2 0 a
:2 0 69b d1c d1e
:3 0 69e d18 d20
d15 d22 d21 :2 0
52 :3 0 62 :3 0
d24 d25 0 54
:4 0 155 :4 0 57
:2 0 58 :3 0 6a2
d29 d2b :3 0 57
:2 0 6e :4 0 6a5
d2d d2f :3 0 57
:2 0 6f :4 0 6a8
d31 d33 :3 0 57
:2 0 68 :3 0 6ab
d35 d37 :3 0 57
:2 0 70 :4 0 6ae
d39 d3b :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 6b1 d3e d42
6b5 d3d d44 :3 0
6b8 d26 d46 :2 0
d48 6bb d49 d23
d48 0 d4a 6bd
0 d4b 6bf d4e
:3 0 d4e 0 d4e
d4d d4b d4c :6 0
d50 2c :3 0 6c2
d52 6c4 d51 d50
:2 0 d53 6c6 :2 0
d55 0 d55 d54
d02 d53 :6 0 d57
29 :3 0 6c9 dcd
4b :3 0 37 :3 0
1d :3 0 3d :3 0
16 :3 0 37 :3 0
3 :3 0 48 :3 0
18 :4 0 156 1
:8 0 d77 bb :4 0
d62 :3 0 bc :3 0
74 :2 0 6cd d65
d66 :3 0 45 :3 0
67 :3 0 d68 d69
0 f :2 0 d6a
d6b 0 d6d 6d0
d74 45 :3 0 67
:3 0 d6e d6f 0
bd :2 0 d70 d71
0 d73 6d2 d75
d67 d6d 0 d76
0 d73 0 d76
6d4 0 d77 6d7
dca 69 :3 0 45
:3 0 67 :3 0 d79
d7a 0 68 :3 0
d7b d7c 0 d7e
6da d80 6dc d7f
d7e :2 0 dc8 6a
:3 0 45 :3 0 67
:3 0 d83 d84 0
68 :3 0 d85 d86
0 dc0 4f :3 0
50 :3 0 d88 d89
0 4f :3 0 5f
:3 0 d8b d8c 0
6b :2 0 2 :4 0
157 :2 0 61 :2 0
a :2 0 6de d91
d93 :3 0 6e1 d8d
d95 d8a d97 d96
:2 0 52 :3 0 62
:3 0 d99 d9a 0
54 :4 0 158 :4 0
57 :2 0 58 :3 0
6e5 d9e da0 :3 0
57 :2 0 6e :4 0
6e8 da2 da4 :3 0
57 :2 0 6f :4 0
6eb da6 da8 :3 0
57 :2 0 68 :3 0
6ee daa dac :3 0
57 :2 0 70 :4 0
6f1 dae db0 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 6f4 db3
db7 6f8 db2 db9
:3 0 6fb d9b dbb
:2 0 dbd 6fe dbe
d98 dbd 0 dbf
700 0 dc0 702
dc3 :3 0 dc3 0
dc3 dc2 dc0 dc1
:6 0 dc5 2e :3 0
705 dc7 707 dc6
dc5 :2 0 dc8 709
:2 0 dca 0 dca
dc9 d77 dc8 :6 0
dcc 29 :3 0 70c
dce ce4 d57 0
dcf 0 dcc 0
dcf 70e 0 dd1
8c :3 0 711 e51
e :3 0 23 :3 0
f :2 0 714 dd2
dd5 74 :2 0 e3
:2 0 719 dd7 dd9
:3 0 4b :3 0 37
:3 0 1d :3 0 3d
:3 0 16 :3 0 37
:3 0 3 :3 0 48
:3 0 18 :4 0 156
1 :8 0 dfa bb
:4 0 de5 :3 0 bc
:3 0 74 :2 0 71e
de8 de9 :3 0 45
:3 0 67 :3 0 deb
dec 0 f :2 0
ded dee 0 df0
721 df7 45 :3 0
67 :3 0 df1 df2
0 bd :2 0 df3
df4 0 df6 723
df8 dea df0 0
df9 0 df6 0
df9 725 0 dfa
728 e4d 69 :3 0
45 :3 0 67 :3 0
dfc dfd 0 68
:3 0 dfe dff 0
e01 72b e03 72d
e02 e01 :2 0 e4b
6a :3 0 45 :3 0
67 :3 0 e06 e07
0 68 :3 0 e08
e09 0 e43 4f
:3 0 50 :3 0 e0b
e0c 0 4f :3 0
5f :3 0 e0e e0f
0 6b :2 0 2
:4 0 159 :2 0 61
:2 0 a :2 0 72f
e14 e16 :3 0 732
e10 e18 e0d e1a
e19 :2 0 52 :3 0
62 :3 0 e1c e1d
0 54 :4 0 15a
:4 0 57 :2 0 58
:3 0 736 e21 e23
:3 0 57 :2 0 6e
:4 0 739 e25 e27
:3 0 57 :2 0 6f
:4 0 73c e29 e2b
:3 0 57 :2 0 68
:3 0 73f e2d e2f
:3 0 57 :2 0 70
:4 0 742 e31 e33
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 745
e36 e3a 749 e35
e3c :3 0 74c e1e
e3e :2 0 e40 74f
e41 e1b e40 0
e42 751 0 e43
753 e46 :3 0 e46
0 e46 e45 e43
e44 :6 0 e48 30
:3 0 756 e4a 758
e49 e48 :2 0 e4b
75a :2 0 e4d 0
e4d e4c dfa e4b
:6 0 e4f 29 :3 0
75d e50 dda e4f
0 e52 c60 dd1
0 e52 75f 0
e53 762 e55 c1
:4 0 e53 :4 0 13a4
db :3 0 47 :4 0
e59 :2 0 e5f e57
0 45 :3 0 67
:3 0 e5a e5b 0
68 :3 0 e5c e5d
0 e5f 767 eb2
69 :3 0 45 :3 0
67 :3 0 e61 e62
0 68 :3 0 e63
e64 0 e66 76a
e68 76c e67 e66
:2 0 eb0 6a :3 0
45 :3 0 67 :3 0
e6b e6c 0 68
:3 0 e6d e6e 0
ea8 4f :3 0 50
:3 0 e70 e71 0
4f :3 0 5f :3 0
e73 e74 0 6b
:2 0 2 :4 0 15b
:2 0 61 :2 0 a
:2 0 76e e79 e7b
:3 0 771 e75 e7d
e72 e7f e7e :2 0
52 :3 0 62 :3 0
e81 e82 0 54
:4 0 15c :4 0 57
:2 0 58 :3 0 775
e86 e88 :3 0 57
:2 0 6e :4 0 778
e8a e8c :3 0 57
:2 0 6f :4 0 77b
e8e e90 :3 0 57
:2 0 68 :3 0 77e
e92 e94 :3 0 57
:2 0 70 :4 0 781
e96 e98 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 784 e9b e9f
788 e9a ea1 :3 0
78b e83 ea3 :2 0
ea5 78e ea6 e80
ea5 0 ea7 790
0 ea8 792 eab
:3 0 eab 0 eab
eaa ea8 ea9 :6 0
ead 32 :3 0 795
eaf 797 eae ead
:2 0 eb0 799 :2 0
eb2 0 eb2 eb1
e5f eb0 :6 0 13a4
16 :3 0 4b :3 0
40 :3 0 15d :3 0
1d :3 0 3d :3 0
16 :3 0 15d :3 0
3 :4 0 15e 1
:8 0 ed2 bb :4 0
ebd :3 0 bc :3 0
74 :2 0 79e ec0
ec1 :3 0 45 :3 0
67 :3 0 ec3 ec4
0 f :2 0 ec5
ec6 0 ec8 7a1
ecf 45 :3 0 67
:3 0 ec9 eca 0
bd :2 0 ecb ecc
0 ece 7a3 ed0
ec2 ec8 0 ed1
0 ece 0 ed1
7a5 0 ed2 7a8
f25 69 :3 0 45
:3 0 67 :3 0 ed4
ed5 0 68 :3 0
ed6 ed7 0 ed9
7ab edb 7ad eda
ed9 :2 0 f23 6a
:3 0 45 :3 0 67
:3 0 ede edf 0
68 :3 0 ee0 ee1
0 f1b 4f :3 0
50 :3 0 ee3 ee4
0 4f :3 0 5f
:3 0 ee6 ee7 0
6b :2 0 2 :4 0
15f :2 0 61 :2 0
a :2 0 7af eec
eee :3 0 7b2 ee8
ef0 ee5 ef2 ef1
:2 0 52 :3 0 62
:3 0 ef4 ef5 0
54 :4 0 160 :4 0
57 :2 0 58 :3 0
7b6 ef9 efb :3 0
57 :2 0 6e :4 0
7b9 efd eff :3 0
57 :2 0 6f :4 0
7bc f01 f03 :3 0
57 :2 0 68 :3 0
7bf f05 f07 :3 0
57 :2 0 70 :4 0
7c2 f09 f0b :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 7c5 f0e
f12 7c9 f0d f14
:3 0 7cc ef6 f16
:2 0 f18 7cf f19
ef3 f18 0 f1a
7d1 0 f1b 7d3
f1e :3 0 f1e 0
f1e f1d f1b f1c
:6 0 f20 34 :3 0
7d6 f22 7d8 f21
f20 :2 0 f23 7da
:2 0 f25 0 f25
f24 ed2 f23 :6 0
13a4 16 :3 0 e
:3 0 29 :3 0 f
:2 0 7dd f27 f2a
74 :2 0 f :2 0
7e2 f2c f2e :3 0
39 :3 0 40 :3 0
161 :3 0 13 :3 0
162 :3 0 163 :3 0
13 :3 0 164 :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 a1 :3 0
c5 :3 0 c6 :3 0
c7 :3 0 9d :3 0
c8 :3 0 9f :3 0
c9 :3 0 c6 :3 0
ca :3 0 cb :3 0
cb :3 0 ca :3 0
cc :3 0 cd :3 0
cd :3 0 cc :3 0
a7 :3 0 c6 :3 0
ce :3 0 a7 :3 0
c6 :3 0 d0 :3 0
d1 :3 0 d2 :3 0
cf :3 0 a7 :3 0
c6 :3 0 d3 :3 0
d4 :3 0 9d :3 0
9f :3 0 a1 :3 0
c6 :3 0 a4 :3 0
a5 :3 0 a8 :3 0
42 :3 0 37 :3 0
3 :3 0 c5 :3 0
c6 :4 0 165 1
:8 0 f7d bb :4 0
f68 :3 0 bc :3 0
74 :2 0 7e7 f6b
f6c :3 0 45 :3 0
67 :3 0 f6e f6f
0 f :2 0 f70
f71 0 f73 7ea
f7a 45 :3 0 67
:3 0 f74 f75 0
bd :2 0 f76 f77
0 f79 7ec f7b
f6d f73 0 f7c
0 f79 0 f7c
7ee 0 f7d 7f1
fd0 69 :3 0 45
:3 0 67 :3 0 f7f
f80 0 68 :3 0
f81 f82 0 f84
7f4 f86 7f6 f85
f84 :2 0 fce 6a
:3 0 45 :3 0 67
:3 0 f89 f8a 0
68 :3 0 f8b f8c
0 fc6 4f :3 0
50 :3 0 f8e f8f
0 4f :3 0 5f
:3 0 f91 f92 0
6b :2 0 2 :4 0
166 :2 0 61 :2 0
a :2 0 7f8 f97
f99 :3 0 7fb f93
f9b f90 f9d f9c
:2 0 52 :3 0 62
:3 0 f9f fa0 0
54 :4 0 167 :4 0
57 :2 0 58 :3 0
7ff fa4 fa6 :3 0
57 :2 0 6e :4 0
802 fa8 faa :3 0
57 :2 0 6f :4 0
805 fac fae :3 0
57 :2 0 68 :3 0
808 fb0 fb2 :3 0
57 :2 0 70 :4 0
80b fb4 fb6 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 80e fb9
fbd 812 fb8 fbf
:3 0 815 fa1 fc1
:2 0 fc3 818 fc4
f9e fc3 0 fc5
81a 0 fc6 81c
fc9 :3 0 fc9 0
fc9 fc8 fc6 fc7
:6 0 fcb 36 :3 0
81f fcd 821 fcc
fcb :2 0 fce 823
:2 0 fd0 0 fd0
fcf f7d fce :6 0
feb 16 :3 0 e
:3 0 23 :3 0 f
:2 0 826 fd2 fd5
74 :2 0 e3 :2 0
82b fd7 fd9 :3 0
2b :3 0 98 :2 0
fdb fdc 0 fe8
2c :3 0 168 :3 0
16 :3 0 1d :3 0
2b :3 0 f :2 0
f :2 0 82e fdf
fe5 fde fe6 0
fe8 834 fe9 fda
fe8 0 fea 837
0 feb 839 139d
c0 :3 0 4d :4 0
fef :2 0 139c fed
ff0 :3 0 c1 :3 0
4d :3 0 1b :3 0
1c :4 0 ff6 :2 0
112b ff2 ff7 :3 0
83c :3 0 4d :3 0
bb :3 0 ff8 ff9
:3 0 45 :3 0 67
:3 0 ffb ffc 0
f :2 0 ffd ffe
0 1000 83f 1007
45 :3 0 67 :3 0
1001 1002 0 bd
:2 0 1003 1004 0
1006 841 1008 ffa
1000 0 1009 0
1006 0 1009 843
0 112b 45 :3 0
67 :3 0 100a 100b
0 45 :3 0 c2
:2 0 c3 :3 0 100d
100f 0 848 100e
1011 :3 0 1012 :2 0
c4 :8 0 1016 84b
1017 1013 1016 0
1018 84d 0 112b
39 :3 0 40 :3 0
161 :3 0 13 :3 0
162 :3 0 163 :3 0
13 :3 0 164 :3 0
9c :3 0 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 a1 :3 0
c5 :3 0 c6 :3 0
c7 :3 0 9d :3 0
c8 :3 0 9f :3 0
c9 :3 0 c6 :3 0
ca :3 0 cb :3 0
cb :3 0 ca :3 0
cc :3 0 cd :3 0
cd :3 0 cc :3 0
a7 :3 0 c6 :3 0
ce :3 0 a7 :3 0
c6 :3 0 d0 :3 0
d1 :3 0 d2 :3 0
cf :3 0 a7 :3 0
c6 :3 0 d3 :3 0
d4 :3 0 9d :3 0
9f :3 0 a1 :3 0
c6 :3 0 a4 :3 0
a5 :3 0 a8 :3 0
42 :3 0 1d :3 0
37 :3 0 1c :4 0
169 1 :8 0 1065
bb :4 0 1050 :3 0
bc :3 0 74 :2 0
851 1053 1054 :3 0
45 :3 0 67 :3 0
1056 1057 0 f
:2 0 1058 1059 0
105b 854 1062 45
:3 0 67 :3 0 105c
105d 0 bd :2 0
105e 105f 0 1061
856 1063 1055 105b
0 1064 0 1061
0 1064 858 0
1065 85b 10b8 69
:3 0 45 :3 0 67
:3 0 1067 1068 0
68 :3 0 1069 106a
0 106c 85e 106e
860 106d 106c :2 0
10b6 6a :3 0 45
:3 0 67 :3 0 1071
1072 0 68 :3 0
1073 1074 0 10ae
4f :3 0 50 :3 0
1076 1077 0 4f
:3 0 5f :3 0 1079
107a 0 6b :2 0
2 :4 0 16a :2 0
61 :2 0 a :2 0
862 107f 1081 :3 0
865 107b 1083 1078
1085 1084 :2 0 52
:3 0 62 :3 0 1087
1088 0 54 :4 0
16b :4 0 57 :2 0
58 :3 0 869 108c
108e :3 0 57 :2 0
6e :4 0 86c 1090
1092 :3 0 57 :2 0
6f :4 0 86f 1094
1096 :3 0 57 :2 0
68 :3 0 872 1098
109a :3 0 57 :2 0
70 :4 0 875 109c
109e :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
878 10a1 10a5 87c
10a0 10a7 :3 0 87f
1089 10a9 :2 0 10ab
882 10ac 1086 10ab
0 10ad 884 0
10ae 886 10b1 :3 0
10b1 0 10b1 10b0
10ae 10af :6 0 10b3
39 :3 0 889 10b5
88b 10b4 10b3 :2 0
10b6 88d :2 0 10b8
0 10b8 10b7 1065
10b6 :6 0 112b 38
:3 0 3b :3 0 de
:3 0 13 :3 0 df
:3 0 3e :3 0 1b
:4 0 16c 1 :8 0
10d6 bb :4 0 10c1
:3 0 bc :3 0 74
:2 0 892 10c4 10c5
:3 0 45 :3 0 67
:3 0 10c7 10c8 0
f :2 0 10c9 10ca
0 10cc 895 10d3
45 :3 0 67 :3 0
10cd 10ce 0 bd
:2 0 10cf 10d0 0
10d2 897 10d4 10c6
10cc 0 10d5 0
10d2 0 10d5 899
0 10d6 89c 1129
69 :3 0 45 :3 0
67 :3 0 10d8 10d9
0 68 :3 0 10da
10db 0 10dd 89f
10df 8a1 10de 10dd
:2 0 1127 6a :3 0
45 :3 0 67 :3 0
10e2 10e3 0 68
:3 0 10e4 10e5 0
111f 4f :3 0 50
:3 0 10e7 10e8 0
4f :3 0 5f :3 0
10ea 10eb 0 6b
:2 0 2 :4 0 16d
:2 0 61 :2 0 a
:2 0 8a3 10f0 10f2
:3 0 8a6 10ec 10f4
10e9 10f6 10f5 :2 0
52 :3 0 62 :3 0
10f8 10f9 0 54
:4 0 16e :4 0 57
:2 0 58 :3 0 8aa
10fd 10ff :3 0 57
:2 0 6e :4 0 8ad
1101 1103 :3 0 57
:2 0 6f :4 0 8b0
1105 1107 :3 0 57
:2 0 68 :3 0 8b3
1109 110b :3 0 57
:2 0 70 :4 0 8b6
110d 110f :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 8b9 1112 1116
8bd 1111 1118 :3 0
8c0 10fa 111a :2 0
111c 8c3 111d 10f7
111c 0 111e 8c5
0 111f 8c7 1122
:3 0 1122 0 1122
1121 111f 1120 :6 0
1124 3b :3 0 8ca
1126 8cc 1125 1124
:2 0 1127 8ce :2 0
1129 0 1129 1128
10d6 1127 :6 0 112b
38 :3 0 8d1 112d
c1 :4 0 112b :4 0
139c db :3 0 4d
:4 0 1131 :2 0 1137
112f 0 45 :3 0
67 :3 0 1132 1133
0 68 :3 0 1134
1135 0 1137 8d7
118a 69 :3 0 45
:3 0 67 :3 0 1139
113a 0 68 :3 0
113b 113c 0 113e
8da 1140 8dc 113f
113e :2 0 1188 6a
:3 0 45 :3 0 67
:3 0 1143 1144 0
68 :3 0 1145 1146
0 1180 4f :3 0
50 :3 0 1148 1149
0 4f :3 0 5f
:3 0 114b 114c 0
6b :2 0 2 :4 0
16f :2 0 61 :2 0
a :2 0 8de 1151
1153 :3 0 8e1 114d
1155 114a 1157 1156
:2 0 52 :3 0 62
:3 0 1159 115a 0
54 :4 0 170 :4 0
57 :2 0 58 :3 0
8e5 115e 1160 :3 0
57 :2 0 6e :4 0
8e8 1162 1164 :3 0
57 :2 0 6f :4 0
8eb 1166 1168 :3 0
57 :2 0 68 :3 0
8ee 116a 116c :3 0
57 :2 0 70 :4 0
8f1 116e 1170 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 8f4 1173
1177 8f8 1172 1179
:3 0 8fb 115b 117b
:2 0 117d 8fe 117e
1158 117d 0 117f
900 0 1180 902
1183 :3 0 1183 0
1183 1182 1180 1181
:6 0 1185 3d :3 0
905 1187 907 1186
1185 :2 0 1188 909
:2 0 118a 0 118a
1189 1137 1188 :6 0
139c 16 :3 0 e
:3 0 29 :3 0 f
:2 0 90c 118c 118f
74 :2 0 a :2 0
911 1191 1193 :3 0
1194 :2 0 e :3 0
2a :3 0 f :2 0
914 1196 1199 171
:2 0 f :2 0 919
119b 119d :3 0 119e
:2 0 1195 11a0 119f
:2 0 39 :3 0 139
:3 0 2a :3 0 37
:3 0 1d :4 0 172
1 :8 0 11bd bb
:4 0 11a8 :3 0 bc
:3 0 74 :2 0 91e
11ab 11ac :3 0 45
:3 0 67 :3 0 11ae
11af 0 f :2 0
11b0 11b1 0 11b3
921 11ba 45 :3 0
67 :3 0 11b4 11b5
0 bd :2 0 11b6
11b7 0 11b9 923
11bb 11ad 11b3 0
11bc 0 11b9 0
11bc 925 0 11bd
928 1210 69 :3 0
45 :3 0 67 :3 0
11bf 11c0 0 68
:3 0 11c1 11c2 0
11c4 92b 11c6 92d
11c5 11c4 :2 0 120e
6a :3 0 45 :3 0
67 :3 0 11c9 11ca
0 68 :3 0 11cb
11cc 0 1206 4f
:3 0 50 :3 0 11ce
11cf 0 4f :3 0
5f :3 0 11d1 11d2
0 6b :2 0 2
:4 0 173 :2 0 61
:2 0 a :2 0 92f
11d7 11d9 :3 0 932
11d3 11db 11d0 11dd
11dc :2 0 52 :3 0
62 :3 0 11df 11e0
0 54 :4 0 174
:4 0 57 :2 0 58
:3 0 936 11e4 11e6
:3 0 57 :2 0 6e
:4 0 939 11e8 11ea
:3 0 57 :2 0 6f
:4 0 93c 11ec 11ee
:3 0 57 :2 0 68
:3 0 93f 11f0 11f2
:3 0 57 :2 0 70
:4 0 942 11f4 11f6
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 945
11f9 11fd 949 11f8
11ff :3 0 94c 11e1
1201 :2 0 1203 94f
1204 11de 1203 0
1205 951 0 1206
953 1209 :3 0 1209
0 1209 1208 1206
1207 :6 0 120b 3f
:3 0 956 120d 958
120c 120b :2 0 120e
95a :2 0 1210 0
1210 120f 11bd 120e
:6 0 1212 16 :3 0
95d 1213 11a1 1212
0 1214 95f 0
139c 2b :3 0 98
:2 0 1215 1216 0
139c 2c :3 0 168
:3 0 16 :3 0 1d
:3 0 2b :3 0 f
:2 0 f :2 0 961
1219 121f 1218 1220
0 139c 42 :3 0
175 :3 0 9c :3 0
9e :3 0 cf :3 0
d0 :3 0 d3 :3 0
1d :3 0 21 :3 0
1e :3 0 20 :3 0
22 :3 0 2d :3 0
30 :3 0 39 :3 0
37 :3 0 1d :4 0
176 1 :8 0 1239
45 :3 0 67 :3 0
1234 1235 0 68
:3 0 1236 1237 0
1239 967 128c 69
:3 0 45 :3 0 67
:3 0 123b 123c 0
68 :3 0 123d 123e
0 1240 96a 1242
96c 1241 1240 :2 0
128a 6a :3 0 45
:3 0 67 :3 0 1245
1246 0 68 :3 0
1247 1248 0 1282
4f :3 0 50 :3 0
124a 124b 0 4f
:3 0 5f :3 0 124d
124e 0 6b :2 0
2 :4 0 177 :2 0
61 :2 0 a :2 0
96e 1253 1255 :3 0
971 124f 1257 124c
1259 1258 :2 0 52
:3 0 62 :3 0 125b
125c 0 54 :4 0
178 :4 0 57 :2 0
58 :3 0 975 1260
1262 :3 0 57 :2 0
6e :4 0 978 1264
1266 :3 0 57 :2 0
6f :4 0 97b 1268
126a :3 0 57 :2 0
68 :3 0 97e 126c
126e :3 0 57 :2 0
70 :4 0 981 1270
1272 :3 0 57 :2 0
71 :3 0 72 :3 0
a :2 0 73 :2 0
984 1275 1279 988
1274 127b :3 0 98b
125d 127d :2 0 127f
98e 1280 125a 127f
0 1281 990 0
1282 992 1285 :3 0
1285 0 1285 1284
1282 1283 :6 0 1287
41 :3 0 995 1289
997 1288 1287 :2 0
128a 999 :2 0 128c
0 128c 128b 1239
128a :6 0 139c 16
:3 0 e :3 0 22
:3 0 f :2 0 99c
128e 1291 74 :2 0
f :2 0 9a1 1293
1295 :3 0 111 :3 0
116 :3 0 11b :3 0
120 :3 0 125 :3 0
12a :3 0 115 :3 0
1e :3 0 11a :3 0
20 :3 0 11f :3 0
21 :3 0 124 :3 0
21 :3 0 2d :3 0
129 :3 0 3d :3 0
16 :3 0 38 :3 0
1a :4 0 179 1
:8 0 12c1 bb :4 0
12ac :3 0 bc :3 0
74 :2 0 9a6 12af
12b0 :3 0 45 :3 0
67 :3 0 12b2 12b3
0 f :2 0 12b4
12b5 0 12b7 9a9
12be 45 :3 0 67
:3 0 12b8 12b9 0
bd :2 0 12ba 12bb
0 12bd 9ab 12bf
12b1 12b7 0 12c0
0 12bd 0 12c0
9ad 0 12c1 9b0
1314 69 :3 0 45
:3 0 67 :3 0 12c3
12c4 0 68 :3 0
12c5 12c6 0 12c8
9b3 12ca 9b5 12c9
12c8 :2 0 1312 6a
:3 0 45 :3 0 67
:3 0 12cd 12ce 0
68 :3 0 12cf 12d0
0 130a 4f :3 0
50 :3 0 12d2 12d3
0 4f :3 0 5f
:3 0 12d5 12d6 0
6b :2 0 2 :4 0
17a :2 0 61 :2 0
a :2 0 9b7 12db
12dd :3 0 9ba 12d7
12df 12d4 12e1 12e0
:2 0 52 :3 0 62
:3 0 12e3 12e4 0
54 :4 0 17b :4 0
57 :2 0 58 :3 0
9be 12e8 12ea :3 0
57 :2 0 6e :4 0
9c1 12ec 12ee :3 0
57 :2 0 6f :4 0
9c4 12f0 12f2 :3 0
57 :2 0 68 :3 0
9c7 12f4 12f6 :3 0
57 :2 0 70 :4 0
9ca 12f8 12fa :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 9cd 12fd
1301 9d1 12fc 1303
:3 0 9d4 12e5 1305
:2 0 1307 9d7 1308
12e2 1307 0 1309
9d9 0 130a 9db
130d :3 0 130d 0
130d 130c 130a 130b
:6 0 130f 43 :3 0
9de 1311 9e0 1310
130f :2 0 1312 9e2
:2 0 1314 0 1314
1313 12c1 1312 :6 0
1316 16 :3 0 9e5
1399 111 :3 0 116
:3 0 11b :3 0 120
:3 0 125 :3 0 12a
:3 0 115 :3 0 1e
:3 0 11a :3 0 20
:3 0 11f :3 0 21
:3 0 124 :3 0 21
:3 0 2d :3 0 129
:3 0 21 :3 0 30
:3 0 3d :3 0 16
:3 0 38 :3 0 1a
:4 0 17c 1 :8 0
1343 bb :4 0 132e
:3 0 bc :3 0 74
:2 0 9e9 1331 1332
:3 0 45 :3 0 67
:3 0 1334 1335 0
f :2 0 1336 1337
0 1339 9ec 1340
45 :3 0 67 :3 0
133a 133b 0 bd
:2 0 133c 133d 0
133f 9ee 1341 1333
1339 0 1342 0
133f 0 1342 9f0
0 1343 9f3 1396
69 :3 0 45 :3 0
67 :3 0 1345 1346
0 68 :3 0 1347
1348 0 134a 9f6
134c 9f8 134b 134a
:2 0 1394 6a :3 0
45 :3 0 67 :3 0
134f 1350 0 68
:3 0 1351 1352 0
138c 4f :3 0 50
:3 0 1354 1355 0
4f :3 0 5f :3 0
1357 1358 0 6b
:2 0 2 :4 0 17d
:2 0 61 :2 0 a
:2 0 9fa 135d 135f
:3 0 9fd 1359 1361
1356 1363 1362 :2 0
52 :3 0 62 :3 0
1365 1366 0 54
:4 0 17e :4 0 57
:2 0 58 :3 0 a01
136a 136c :3 0 57
:2 0 6e :4 0 a04
136e 1370 :3 0 57
:2 0 6f :4 0 a07
1372 1374 :3 0 57
:2 0 68 :3 0 a0a
1376 1378 :3 0 57
:2 0 70 :4 0 a0d
137a 137c :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 a10 137f 1383
a14 137e 1385 :3 0
a17 1367 1387 :2 0
1389 a1a 138a 1364
1389 0 138b a1c
0 138c a1e 138f
:3 0 138f 0 138f
138e 138c 138d :6 0
1391 45 :3 0 a21
1393 a23 1392 1391
:2 0 1394 a25 :2 0
1396 0 1396 1395
1343 1394 :6 0 1398
16 :3 0 a28 139a
1296 1316 0 139b
0 1398 0 139b
a2a 0 139c a2d
139e f2f feb 0
139f 0 139c 0
139f a36 0 13a4
138 :5 0 13a2 47
0 13a3 a39 13a2
13a1 13a4 a3b 13a6
a47 13a5 13a4 :2 0
13aa 0 13a8 a49
13a9 0 13a8 :2 0
13aa a4b :2 0 13ab
75e 13aa 0 141d
0 3b :3 0 de
:3 0 13 :3 0 df
:3 0 3e :3 0 1b
:4 0 16c 1 :8 0
13c8 bb :4 0 13b3
:3 0 bc :3 0 74
:2 0 a51 13b6 13b7
:3 0 45 :3 0 67
:3 0 13b9 13ba 0
f :2 0 13bb 13bc
0 13be a54 13c5
45 :3 0 67 :3 0
13bf 13c0 0 bd
:2 0 13c1 13c2 0
13c4 a56 13c6 13b8
13be 0 13c7 0
13c4 0 13c7 a58
0 13c8 a5b 141b
69 :3 0 45 :3 0
67 :3 0 13ca 13cb
0 68 :3 0 13cc
13cd 0 13cf a5e
13d1 a60 13d0 13cf
:2 0 1419 6a :3 0
45 :3 0 67 :3 0
13d4 13d5 0 68
:3 0 13d6 13d7 0
1411 4f :3 0 50
:3 0 13d9 13da 0
4f :3 0 5f :3 0
13dc 13dd 0 6b
:2 0 2 :4 0 17f
:2 0 61 :2 0 a
:2 0 a62 13e2 13e4
:3 0 a65 13de 13e6
13db 13e8 13e7 :2 0
52 :3 0 62 :3 0
13ea 13eb 0 54
:4 0 180 :4 0 57
:2 0 58 :3 0 a69
13ef 13f1 :3 0 57
:2 0 6e :4 0 a6c
13f3 13f5 :3 0 57
:2 0 6f :4 0 a6f
13f7 13f9 :3 0 57
:2 0 68 :3 0 a72
13fb 13fd :3 0 57
:2 0 70 :4 0 a75
13ff 1401 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 a78 1404 1408
a7c 1403 140a :3 0
a7f 13ec 140c :2 0
140e a82 140f 13e9
140e 0 1410 a84
0 1411 a86 1414
:3 0 1414 0 1414
1413 1411 1412 :6 0
1416 47 :3 0 a89
1418 a8b 1417 1416
:2 0 1419 a8d :2 0
141b 0 141b 141a
13c8 1419 :6 0 141d
16 :3 0 a90 141f
c1 :4 0 141d :4 0
15c3 db :3 0 44
:4 0 1423 :2 0 1429
1421 0 45 :3 0
67 :3 0 1424 1425
0 68 :3 0 1426
1427 0 1429 a96
147c 69 :3 0 45
:3 0 67 :3 0 142b
142c 0 68 :3 0
142d 142e 0 1430
a99 1432 a9b 1431
1430 :2 0 147a 6a
:3 0 45 :3 0 67
:3 0 1435 1436 0
68 :3 0 1437 1438
0 1472 4f :3 0
50 :3 0 143a 143b
0 4f :3 0 5f
:3 0 143d 143e 0
6b :2 0 2 :4 0
181 :2 0 61 :2 0
a :2 0 a9d 1443
1445 :3 0 aa0 143f
1447 143c 1449 1448
:2 0 52 :3 0 62
:3 0 144b 144c 0
54 :4 0 182 :4 0
57 :2 0 58 :3 0
aa4 1450 1452 :3 0
57 :2 0 6e :4 0
aa7 1454 1456 :3 0
57 :2 0 6f :4 0
aaa 1458 145a :3 0
57 :2 0 68 :3 0
aad 145c 145e :3 0
57 :2 0 70 :4 0
ab0 1460 1462 :3 0
57 :2 0 71 :3 0
72 :3 0 a :2 0
73 :2 0 ab3 1465
1469 ab7 1464 146b
:3 0 aba 144d 146d
:2 0 146f abd 1470
144a 146f 0 1471
abf 0 1472 ac1
1475 :3 0 1475 0
1475 1474 1472 1473
:6 0 1477 49 :3 0
ac4 1479 ac6 1478
1477 :2 0 147a ac8
:2 0 147c 0 147c
147b 1429 147a :6 0
15c3 1 :3 0 d
:3 0 74 :2 0 a
:2 0 acd 147f 1481
:3 0 2c :3 0 183
:3 0 16 :3 0 ad0
1484 1486 1483 1487
0 1489 ad2 148a
1482 1489 0 148b
ad4 0 15c3 161
:3 0 13 :3 0 184
:3 0 163 :3 0 13
:3 0 185 :3 0 99
:3 0 13 :3 0 9a
:3 0 26 :3 0 3b
:3 0 3e :3 0 16
:4 0 186 1 :8 0
149f 45 :3 0 67
:3 0 149a 149b 0
68 :3 0 149c 149d
0 149f ad6 14f2
69 :3 0 45 :3 0
67 :3 0 14a1 14a2
0 68 :3 0 14a3
14a4 0 14a6 ad9
14a8 adb 14a7 14a6
:2 0 14f0 6a :3 0
45 :3 0 67 :3 0
14ab 14ac 0 68
:3 0 14ad 14ae 0
14e8 4f :3 0 50
:3 0 14b0 14b1 0
4f :3 0 5f :3 0
14b3 14b4 0 6b
:2 0 2 :4 0 187
:2 0 61 :2 0 a
:2 0 add 14b9 14bb
:3 0 ae0 14b5 14bd
14b2 14bf 14be :2 0
52 :3 0 62 :3 0
14c1 14c2 0 54
:4 0 188 :4 0 57
:2 0 58 :3 0 ae4
14c6 14c8 :3 0 57
:2 0 6e :4 0 ae7
14ca 14cc :3 0 57
:2 0 6f :4 0 aea
14ce 14d0 :3 0 57
:2 0 68 :3 0 aed
14d2 14d4 :3 0 57
:2 0 70 :4 0 af0
14d6 14d8 :3 0 57
:2 0 71 :3 0 72
:3 0 a :2 0 73
:2 0 af3 14db 14df
af7 14da 14e1 :3 0
afa 14c3 14e3 :2 0
14e5 afd 14e6 14c0
14e5 0 14e7 aff
0 14e8 b01 14eb
:3 0 14eb 0 14eb
14ea 14e8 14e9 :6 0
14ed 4b :3 0 b04
14ef b06 14ee 14ed
:2 0 14f0 b08 :2 0
14f2 0 14f2 14f1
149f 14f0 :6 0 15c3
1 :3 0 e :3 0
26 :3 0 f :2 0
b0b 14f4 14f7 74
:2 0 a :2 0 b10
14f9 14fb :3 0 27
:3 0 13 :3 0 9a
:3 0 14fe 14ff 0
14fd 1500 0 150c
45 :3 0 67 :3 0
1502 1503 0 189
:3 0 16 :3 0 26
:3 0 27 :3 0 b13
1505 1509 1504 150a
0 150c b17 150d
14fc 150c 0 150e
b1a 0 15c3 18a
:3 0 18b :3 0 99
:3 0 3b :3 0 3e
:3 0 16 :3 0 3e
:3 0 16 :4 0 18c
1 :8 0 152d bb
:4 0 1518 :3 0 bc
:3 0 74 :2 0 b1e
151b 151c :3 0 45
:3 0 67 :3 0 151e
151f 0 f :2 0
1520 1521 0 1523
b21 152a 45 :3 0
67 :3 0 1524 1525
0 bd :2 0 1526
1527 0 1529 b23
152b 151d 1523 0
152c 0 1529 0
152c b25 0 152d
b28 1580 69 :3 0
45 :3 0 67 :3 0
152f 1530 0 68
:3 0 1531 1532 0
1534 b2b 1536 b2d
1535 1534 :2 0 157e
6a :3 0 45 :3 0
67 :3 0 1539 153a
0 68 :3 0 153b
153c 0 1576 4f
:3 0 50 :3 0 153e
153f 0 4f :3 0
5f :3 0 1541 1542
0 6b :2 0 2
:4 0 18d :2 0 61
:2 0 a :2 0 b2f
1547 1549 :3 0 b32
1543 154b 1540 154d
154c :2 0 52 :3 0
62 :3 0 154f 1550
0 54 :4 0 18e
:4 0 57 :2 0 58
:3 0 b36 1554 1556
:3 0 57 :2 0 6e
:4 0 b39 1558 155a
:3 0 57 :2 0 6f
:4 0 b3c 155c 155e
:3 0 57 :2 0 68
:3 0 b3f 1560 1562
:3 0 57 :2 0 70
:4 0 b42 1564 1566
:3 0 57 :2 0 71
:3 0 72 :3 0 a
:2 0 73 :2 0 b45
1569 156d b49 1568
156f :3 0 b4c 1551
1571 :2 0 1573 b4f
1574 154e 1573 0
1575 b51 0 1576
b53 1579 :3 0 1579
0 1579 1578 1576
1577 :6 0 157b 4d
:3 0 b56 157d b58
157c 157b :2 0 157e
b5a :2 0 1580 0
1580 157f 152d 157e
:6 0 15c3 1 :3 0
45 :3 0 67 :3 0
1582 1583 0 74
:2 0 bd :2 0 b5f
1585 1587 :3 0 45
:3 0 67 :3 0 1589
158a 0 f :2 0
158b 158c 0 158e
b62 158f 1588 158e
0 1590 b64 0
15c3 4f :3 0 50
:3 0 1591 1592 0
4f :3 0 5f :3 0
1594 1595 0 a
:2 0 2 :4 0 18f
:2 0 61 :2 0 a
:2 0 b66 159a 159c
:3 0 b69 1596 159e
1593 15a0 159f :2 0
52 :3 0 62 :3 0
15a2 15a3 0 54
:4 0 190 :4 0 57
:2 0 58 :3 0 b6d
15a7 15a9 :3 0 57
:2 0 6e :4 0 b70
15ab 15ad :3 0 57
:2 0 78 :4 0 b73
15af 15b1 :3 0 57
:2 0 45 :3 0 67
:3 0 15b4 15b5 0
b76 15b3 15b7 :3 0
b79 15a4 15b9 :2 0
15bb b7c 15bc 15a1
15bb 0 15bd b7e
0 15c3 b :3 0
45 :3 0 67 :3 0
15bf 15c0 0 15c1
:2 0 15c3 b80 15c6
:3 0 15c6 b90 15c6
15c5 15c3 15c4 :6 0
15c7 :2 0 2 15
15c6 15ca :3 0 15c9
15c7 15cb :8 0 
bb1
4
:3 0 1 3 1
9 1 d 3
8 c 11 1
17 2 21 22
1 1d 1 29
1 27 1 33
1 31 1 3d
1 3b 1 42
1 49 1 47
1 50 1 4e
1 57 1 55
1 5e 1 5c
1 63 1 68
1 6d 1 73
1 79 1 7f
1 85 1 8b
1 91 1 97
1 9d 1 a3
1 a9 1 af
1 b5 1 bb
1 c3 1 c1
1 ca 1 c8
1 ee 1 f4
1 109 1 11a
1 126 1 132
2 135 137 2
13a 13c 2 13e
140 2 142 144
2 146 148 1
14e 2 150 151
2 14a 153 2
155 157 1 15d
2 15f 160 2
159 162 2 164
166 4 12e 134
139 168 1 16a
1 16c 2 176
178 3 174 175
17a 2 183 185
2 182 187 1
189 1 18b 2
195 19a 1 1a1
1 19c 2 1b4
1b6 3 1b2 1b3
1b8 2 1c1 1c3
2 1c5 1c7 2
1c9 1cb 2 1cd
1cf 2 1d1 1d3
3 1d8 1d9 1da
2 1d5 1dc 2
1c0 1de 1 1e0
1 1e2 2 1ab
1e3 1 1e7 1
1a6 2 1a4 1eb
3 1f1 1f2 1f3
1 1f7 2 1f5
1f7 2 202 204
3 200 201 206
2 20f 211 2
213 215 2 217
219 1 221 2
223 224 2 21b
226 2 228 22a
2 22c 22e 2
230 232 2 234
236 2 20e 238
1 23a 1 23c
2 246 248 3
244 245 24a 2
253 255 2 252
257 1 259 1
25b 3 263 264
265 3 23d 25c
268 1 26a 1
272 2 26e 272
2 282 287 1
28e 1 289 2
2a1 2a3 3 29f
2a0 2a5 2 2ae
2b0 2 2b2 2b4
2 2b6 2b8 2
2ba 2bc 2 2be
2c0 3 2c5 2c6
2c7 2 2c2 2c9
2 2ad 2cb 1
2cd 1 2cf 2
298 2d0 1 2d4
1 293 2 291
2d8 1 2e3 2
2df 2e3 2 2ef
2f1 3 2ed 2ee
2f3 2 2fc 2fe
2 300 302 2
304 306 1 30e
2 310 311 2
308 313 2 2fb
315 1 317 1
319 2 323 325
3 321 322 327
2 330 332 2
32f 334 1 336
1 338 2 340
341 3 31a 339
344 2 348 349
1 34d 2 34b
34d 2 352 353
1 357 2 355
357 2 365 367
3 363 364 369
2 372 374 2
376 378 2 37a
37c 1 384 2
386 387 2 37e
389 2 38b 38d
2 38f 391 2
393 395 2 397
399 2 371 39b
1 39d 1 39f
2 3a9 3ab 3
3a7 3a8 3ad 2
3b6 3b8 2 3b5
3ba 1 3bc 1
3be 3 3c6 3c7
3c8 3 3a0 3bf
3cb 2 3ce 3cd
2 3d6 3db 1
3e2 1 3dd 2
3f5 3f7 3 3f3
3f4 3f9 2 402
404 2 406 408
2 40a 40c 2
40e 410 2 412
414 3 419 41a
41b 2 416 41d
2 401 41f 1
421 1 423 2
3ec 424 1 428
1 3e7 2 3e5
42c 2 432 434
2 436 438 2
43a 43c 4 2db
3cf 42f 43f 2
445 446 1 44a
2 448 44a 1
494 2 493 494
1 49c 1 4a2
2 4a4 4a5 2
491 4a6 1 4ad
1 4a8 2 4c0
4c2 3 4be 4bf
4c4 2 4cd 4cf
2 4d1 4d3 2
4d5 4d7 2 4d9
4db 2 4dd 4df
3 4e4 4e5 4e6
2 4e1 4e8 2
4cc 4ea 1 4ec
1 4ee 2 4b7
4ef 1 4f3 1
4b2 2 4b0 4f7
2 503 504 1
50f 1 515 2
517 518 1 520
2 51c 520 1
525 1 527 1
565 2 564 565
1 56d 1 573
2 575 576 2
562 577 1 57e
1 579 2 591
593 3 58f 590
595 2 59e 5a0
2 5a2 5a4 2
5a6 5a8 2 5aa
5ac 2 5ae 5b0
3 5b5 5b6 5b7
2 5b2 5b9 2
59d 5bb 1 5bd
1 5bf 2 588
5c0 1 5c4 1
583 2 581 5c8
1 5d6 2 5d5
5d6 1 5de 1
5e4 2 5e6 5e7
2 5d3 5e8 1
5ef 1 5ea 2
602 604 3 600
601 606 2 60f
611 2 613 615
2 617 619 2
61b 61d 2 61f
621 3 626 627
628 2 623 62a
2 60e 62c 1
62e 1 630 2
5f9 631 1 635
1 5f4 2 5f2
639 5 505 519
528 5cb 63c 2
643 649 1 650
1 64b 2 663
665 3 661 662
667 2 670 672
2 674 676 2
678 67a 2 67c
67e 2 680 682
3 687 688 689
2 684 68b 2
66f 68d 1 68f
1 691 2 65a
692 1 696 1
655 2 653 69a
4 4fa 4fe 640
69d 1 6a0 1
6ae 2 6ad 6ae
1 6b6 1 6bc
2 6be 6bf 2
6ab 6c0 1 6c7
1 6c2 2 6da
6dc 3 6d8 6d9
6de 2 6e7 6e9
2 6eb 6ed 2
6ef 6f1 2 6f3
6f5 2 6f7 6f9
3 6fe 6ff 700
2 6fb 702 2
6e6 704 1 706
1 708 2 6d1
709 1 70d 1
6cc 2 6ca 711
2 71d 71f 2
721 723 2 725
727 6 443 6a1
714 718 71b 72a
2 72c 72d 4
736 737 738 739
1 744 1 74a
2 74c 74d 1
755 2 751 755
1 75a 1 75c
1 781 2 780
781 1 789 1
78f 2 791 792
2 77e 793 1
79a 1 795 2
7ad 7af 3 7ab
7ac 7b1 2 7ba
7bc 2 7be 7c0
2 7c2 7c4 2
7c6 7c8 2 7ca
7cc 3 7d1 7d2
7d3 2 7ce 7d5
2 7b9 7d7 1
7d9 1 7db 2
7a4 7dc 1 7e0
1 79f 2 79d
7e4 1 84e 2
84d 84e 1 856
1 85c 2 85e
85f 2 84b 860
1 867 1 862
2 87a 87c 3
878 879 87e 2
887 889 2 88b
88d 2 88f 891
2 893 895 2
897 899 3 89e
89f 8a0 2 89b
8a2 2 886 8a4
1 8a6 1 8a8
2 871 8a9 1
8ad 1 86c 2
86a 8b1 1 8f3
2 8f2 8f3 1
8fb 1 901 2
903 904 2 8f0
905 1 90c 1
907 2 91f 921
3 91d 91e 923
2 92c 92e 2
930 932 2 934
936 2 938 93a
2 93c 93e 3
943 944 945 2
940 947 2 92b
949 1 94b 1
94d 2 916 94e
1 952 1 911
2 90f 956 3
7e7 8b4 959 1
75f 2 965 96a
1 971 1 96c
2 984 986 3
982 983 988 2
991 993 2 995
997 2 999 99b
2 99d 99f 2
9a1 9a3 3 9a8
9a9 9aa 2 9a5
9ac 2 990 9ae
1 9b0 1 9b2
2 97b 9b3 1
9b7 1 976 2
974 9bb 1 9c6
2 9c2 9c6 1
9ca 1 9d3 1
9d5 2 9e3 9e8
1 9ef 1 9ea
2 a02 a04 3
a00 a01 a06 2
a0f a11 2 a13
a15 2 a17 a19
2 a1b a1d 2
a1f a21 3 a26
a27 a28 2 a23
a2a 2 a0e a2c
1 a2e 1 a30
2 9f9 a31 1
a35 1 9f4 2
9f2 a39 1 a44
2 a40 a44 1
a48 2 a51 a52
1 a56 2 a54
a56 1 a5b 1
a63 2 a62 a63
1 a6b 1 a71
2 a73 a74 2
a60 a75 1 a7c
1 a77 2 a8f
a91 3 a8d a8e
a93 2 a9c a9e
2 aa0 aa2 2
aa4 aa6 2 aa8
aaa 2 aac aae
3 ab3 ab4 ab5
2 ab0 ab7 2
a9b ab9 1 abb
1 abd 2 a86
abe 1 ac2 1
a81 2 a7f ac6
1 ad1 2 ad0
ad1 1 ad9 1
adf 2 ae1 ae2
2 ace ae3 1
aea 1 ae5 2
afd aff 3 afb
afc b01 2 b0a
b0c 2 b0e b10
2 b12 b14 2
b16 b18 2 b1a
b1c 3 b21 b22
b23 2 b1e b25
2 b09 b27 1
b29 1 b2b 2
af4 b2c 1 b30
1 aef 2 aed
b34 1 b3f 2
b3e b3f 1 b47
1 b4d 2 b4f
b50 2 b3c b51
1 b58 1 b53
2 b6b b6d 3
b69 b6a b6f 2
b78 b7a 2 b7c
b7e 2 b80 b82
2 b84 b86 2
b88 b8a 3 b8f
b90 b91 2 b8c
b93 2 b77 b95
1 b97 1 b99
2 b62 b9a 1
b9e 1 b5d 2
b5b ba2 1 bad
2 bac bad 1
bb5 1 bbb 2
bbd bbe 2 baa
bbf 1 bc6 1
bc1 2 bd9 bdb
3 bd7 bd8 bdd
2 be6 be8 2
bea bec 2 bee
bf0 2 bf2 bf4
2 bf6 bf8 3
bfd bfe bff 2
bfa c01 2 be5
c03 1 c05 1
c07 2 bd0 c08
1 c0c 1 bcb
2 bc9 c10 5
ac9 b37 ba5 c13
c17 2 c19 c1a
1 c1b 2 c1f
c22 2 c24 c25
3 c31 c32 c33
1 c3e 1 c44
2 c46 c47 1
c4f 2 c4b c4f
1 c54 1 c56
2 c59 c5a 1
c5e 2 c5c c5e
1 c73 2 c72
c73 1 c7b 1
c81 2 c83 c84
2 c70 c85 1
c8c 1 c87 2
c9f ca1 3 c9d
c9e ca3 2 cac
cae 2 cb0 cb2
2 cb4 cb6 2
cb8 cba 2 cbc
cbe 3 cc3 cc4
cc5 2 cc0 cc7
2 cab cc9 1
ccb 1 ccd 2
c96 cce 1 cd2
1 c91 2 c8f
cd6 1 ce1 2
cdd ce1 1 cef
2 cee cef 1
cf7 1 cfd 2
cff d00 2 cec
d01 1 d08 1
d03 2 d1b d1d
3 d19 d1a d1f
2 d28 d2a 2
d2c d2e 2 d30
d32 2 d34 d36
2 d38 d3a 3
d3f d40 d41 2
d3c d43 2 d27
d45 1 d47 1
d49 2 d12 d4a
1 d4e 1 d0d
2 d0b d52 1
d55 1 d64 2
d63 d64 1 d6c
1 d72 2 d74
d75 2 d61 d76
1 d7d 1 d78
2 d90 d92 3
d8e d8f d94 2
d9d d9f 2 da1
da3 2 da5 da7
2 da9 dab 2
dad daf 3 db4
db5 db6 2 db1
db8 2 d9c dba
1 dbc 1 dbe
2 d87 dbf 1
dc3 1 d82 2
d80 dc7 1 dca
2 dcd dce 2
cd9 dcf 2 dd3
dd4 1 dd8 2
dd6 dd8 1 de7
2 de6 de7 1
def 1 df5 2
df7 df8 2 de4
df9 1 e00 1
dfb 2 e13 e15
3 e11 e12 e17
2 e20 e22 2
e24 e26 2 e28
e2a 2 e2c e2e
2 e30 e32 3
e37 e38 e39 2
e34 e3b 2 e1f
e3d 1 e3f 1
e41 2 e0a e42
1 e46 1 e05
2 e03 e4a 1
e4d 2 e51 e50
4 c34 c48 c57
e52 2 e58 e5e
1 e65 1 e60
2 e78 e7a 3
e76 e77 e7c 2
e85 e87 2 e89
e8b 2 e8d e8f
2 e91 e93 2
e95 e97 3 e9c
e9d e9e 2 e99
ea0 2 e84 ea2
1 ea4 1 ea6
2 e6f ea7 1
eab 1 e6a 2
e68 eaf 1 ebf
2 ebe ebf 1
ec7 1 ecd 2
ecf ed0 2 ebc
ed1 1 ed8 1
ed3 2 eeb eed
3 ee9 eea eef
2 ef8 efa 2
efc efe 2 f00
f02 2 f04 f06
2 f08 f0a 3
f0f f10 f11 2
f0c f13 2 ef7
f15 1 f17 1
f19 2 ee2 f1a
1 f1e 1 edd
2 edb f22 2
f28 f29 1 f2d
2 f2b f2d 1
f6a 2 f69 f6a
1 f72 1 f78
2 f7a f7b 2
f67 f7c 1 f83
1 f7e 2 f96
f98 3 f94 f95
f9a 2 fa3 fa5
2 fa7 fa9 2
fab fad 2 faf
fb1 2 fb3 fb5
3 fba fbb fbc
2 fb7 fbe 2
fa2 fc0 1 fc2
1 fc4 2 f8d
fc5 1 fc9 1
f88 2 f86 fcd
2 fd3 fd4 1
fd8 2 fd6 fd8
5 fe0 fe1 fe2
fe3 fe4 2 fdd
fe7 1 fe9 2
fd0 fea 2 ff3
ff4 1 fff 1
1005 2 1007 1008
1 1010 2 100c
1010 1 1015 1
1017 1 1052 2
1051 1052 1 105a
1 1060 2 1062
1063 2 104f 1064
1 106b 1 1066
2 107e 1080 3
107c 107d 1082 2
108b 108d 2 108f
1091 2 1093 1095
2 1097 1099 2
109b 109d 3 10a2
10a3 10a4 2 109f
10a6 2 108a 10a8
1 10aa 1 10ac
2 1075 10ad 1
10b1 1 1070 2
106e 10b5 1 10c3
2 10c2 10c3 1
10cb 1 10d1 2
10d3 10d4 2 10c0
10d5 1 10dc 1
10d7 2 10ef 10f1
3 10ed 10ee 10f3
2 10fc 10fe 2
1100 1102 2 1104
1106 2 1108 110a
2 110c 110e 3
1113 1114 1115 2
1110 1117 2 10fb
1119 1 111b 1
111d 2 10e6 111e
1 1122 1 10e1
2 10df 1126 5
ff5 1009 1018 10b8
1129 2 1130 1136
1 113d 1 1138
2 1150 1152 3
114e 114f 1154 2
115d 115f 2 1161
1163 2 1165 1167
2 1169 116b 2
116d 116f 3 1174
1175 1176 2 1171
1178 2 115c 117a
1 117c 1 117e
2 1147 117f 1
1183 1 1142 2
1140 1187 2 118d
118e 1 1192 2
1190 1192 2 1197
1198 1 119c 2
119a 119c 1 11aa
2 11a9 11aa 1
11b2 1 11b8 2
11ba 11bb 2 11a7
11bc 1 11c3 1
11be 2 11d6 11d8
3 11d4 11d5 11da
2 11e3 11e5 2
11e7 11e9 2 11eb
11ed 2 11ef 11f1
2 11f3 11f5 3
11fa 11fb 11fc 2
11f7 11fe 2 11e2
1200 1 1202 1
1204 2 11cd 1205
1 1209 1 11c8
2 11c6 120d 1
1210 1 1213 5
121a 121b 121c 121d
121e 2 1233 1238
1 123f 1 123a
2 1252 1254 3
1250 1251 1256 2
125f 1261 2 1263
1265 2 1267 1269
2 126b 126d 2
126f 1271 3 1276
1277 1278 2 1273
127a 2 125e 127c
1 127e 1 1280
2 1249 1281 1
1285 1 1244 2
1242 1289 2 128f
1290 1 1294 2
1292 1294 1 12ae
2 12ad 12ae 1
12b6 1 12bc 2
12be 12bf 2 12ab
12c0 1 12c7 1
12c2 2 12da 12dc
3 12d8 12d9 12de
2 12e7 12e9 2
12eb 12ed 2 12ef
12f1 2 12f3 12f5
2 12f7 12f9 3
12fe 12ff 1300 2
12fb 1302 2 12e6
1304 1 1306 1
1308 2 12d1 1309
1 130d 1 12cc
2 12ca 1311 1
1314 1 1330 2
132f 1330 1 1338
1 133e 2 1340
1341 2 132d 1342
1 1349 1 1344
2 135c 135e 3
135a 135b 1360 2
1369 136b 2 136d
136f 2 1371 1373
2 1375 1377 2
1379 137b 3 1380
1381 1382 2 137d
1384 2 1368 1386
1 1388 1 138a
2 1353 138b 1
138f 1 134e 2
134c 1393 1 1396
2 1399 139a 8
fee 112d 118a 1214
1217 1221 128c 139b
2 139d 139e 1
13a0 b 9be 9d6
a3c c26 c29 c2c
e55 eb2 f25 139f
13a3 1 95e 1
13a7 3 95d 13a6
13a9 1 13b5 2
13b4 13b5 1 13bd
1 13c3 2 13c5
13c6 2 13b2 13c7
1 13ce 1 13c9
2 13e1 13e3 3
13df 13e0 13e5 2
13ee 13f0 2 13f2
13f4 2 13f6 13f8
2 13fa 13fc 2
13fe 1400 3 1405
1406 1407 2 1402
1409 2 13ed 140b
1 140d 1 140f
2 13d8 1410 1
1414 1 13d3 2
13d1 1418 5 73a
74e 75d 13ab 141b
2 1422 1428 1
142f 1 142a 2
1442 1444 3 1440
1441 1446 2 144f
1451 2 1453 1455
2 1457 1459 2
145b 145d 2 145f
1461 3 1466 1467
1468 2 1463 146a
2 144e 146c 1
146e 1 1470 2
1439 1471 1 1475
1 1434 2 1432
1479 1 1480 2
147e 1480 1 1485
1 1488 1 148a
2 1499 149e 1
14a5 1 14a0 2
14b8 14ba 3 14b6
14b7 14bc 2 14c5
14c7 2 14c9 14cb
2 14cd 14cf 2
14d1 14d3 2 14d5
14d7 3 14dc 14dd
14de 2 14d9 14e0
2 14c4 14e2 1
14e4 1 14e6 2
14af 14e7 1 14eb
1 14aa 2 14a8
14ef 2 14f5 14f6
1 14fa 2 14f8
14fa 3 1506 1507
1508 2 1501 150b
1 150d 1 151a
2 1519 151a 1
1522 1 1528 2
152a 152b 2 1517
152c 1 1533 1
152e 2 1546 1548
3 1544 1545 154a
2 1553 1555 2
1557 1559 2 155b
155d 2 155f 1561
2 1563 1565 3
156a 156b 156c 2
1567 156e 2 1552
1570 1 1572 1
1574 2 153d 1575
1 1579 1 1538
2 1536 157d 1
1586 2 1584 1586
1 158d 1 158f
2 1599 159b 3
1597 1598 159d 2
15a6 15a8 2 15aa
15ac 2 15ae 15b0
2 15b2 15b6 2
15a5 15b8 1 15ba
1 15bc f 16d
18c 1ee 26b 72e
733 141f 147c 148b
14f2 150e 1580 1590
15bd 15c2 20 1b
25 2f 39 40
45 4c 53 5a
61 66 6b 71
77 7d 83 89
8f 95 9b a1
a7 ad b3 b9
bf c6 cd ef
f9 10a 11b 
1
4
0 
15ca
0
1
50
4e
25
0 1 1 1 1 5 1 7
1 9 1 b 1 d e d
10 1 12 1 14 1 16 17
16 19 16 1b 16 1d 16 1f
16 21 16 23 16 25 16 27
16 29 2a 29 2c 29 2e 29
30 16 32 16 34 16 36 16
38 39 38 3b 16 3d 16 3f
16 41 16 43 16 45 16 47
1 49 1 4b 1 4d 0 0

8b 1 0
a9 1 0
9 1 0
85 1 0
68 1 0
55 1 0
5c 1 0
fc 1 3
31 1 0
110 1 4
2 0 1
bb 1 0
c1 1 0
27 1 0
7f 1 0
42 1 0
af 1 0
9d 1 0
91 1 0
f4 1 0
c8 1 0
63 1 0
73 1 0
1d 1 0
17 1 0
6d 1 0
79 1 0
97 1 0
4e 1 0
3 1 0
a3 1 0
47 1 0
3b 1 0
13a0 16 47
d 1 0
b5 1 0
d0 1 2
0

/
SHOW ERRORS FUNCTION FC_COMMIT_ASSIGN;
ALTER FUNCTION FC_COMMIT_ASSIGN COMPILE DEBUG;
Prompt == FUNCTION SP_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
45
2 :e:
1FUNCTION:
1SP_COMMIT_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_BITFLAG:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_COMMIT_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
118:
1+:
1FPUT:
1               ENTER:: SP_COMMIT_ASSIGN(19) :: cplan.sql(19902) :: :
1SC_STATE:
1FC_COMMIT_ASSIGN:
14:
129:
1       RETURN_STATUS:: SP_COMMIT_ASSIGN(30) :: cplan.sql(19913) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
136:
1           EXCEPTION:: SP_COMMIT_ASSIGN(37) :: cplan.sql(19920) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
148:
1           EXCEPTION:: SP_COMMIT_ASSIGN(49) :: cplan.sql(19932) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
189
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 6b :3 a0 51 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
189
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8e 7d 81 59 89 7c ae
99 9d 79 a1 a9 98 b5 b9
95 bd c1 c5 c8 cd ce 1
d0 d5 d9 dd e0 e5 e9 ed
f0 f5 f6 f8 fd 100 104 105
10a 10f 112 117 118 11d 120 124
125 12a 12d 132 133 138 13b 140
141 146 149 14d 151 155 156 158
15d 15e 160 161 166 169 16e 16f
174 175 17a 17c 180 183 187 18b
18e 192 196 199 19c 1a1 1a4 1a7
1aa 1ab 1b0 1b1 1 1b3 1b8 1bc
1c0 1c3 1c8 1cd 1d0 1d4 1d5 1da
1db 1e0 1e2 1e6 1e9 1ed 1f1 1f5
1f9 1fd 201 205 209 20c 210 214
218 21b 21c 21e 222 226 22a 22d
231 235 238 23b 240 243 246 249
24a 24f 250 1 252 257 25b 25f
262 267 26c 26f 273 274 279 27c
281 282 287 28a 28f 290 295 298
29c 2a0 2a4 2a8 2ab 2ac 2ae 2b3
2b4 2b6 2b7 2bc 2bf 2c4 2c5 2ca
2cd 2d2 2d3 2d8 2db 2df 2e0 2e5
2e8 2ed 2ee 2f3 2f4 2f9 2fb 2ff
302 306 30a 30d 311 315 318 31c
320 321 326 328 32c 330 333 337
33b 33e 342 346 349 34c 351 354
357 35a 35b 360 361 1 363 368
36c 370 373 378 37d 380 384 385
38a 38b 390 394 398 39b 3a0 3a5
3a8 3ac 3b0 3b3 3b4 3b9 3bc 3c1
3c2 3c7 3ca 3ce 3d2 3d5 3d6 3db
3dc 3e1 3e3 3e7 3ea 3ee 3f2 3f6
3fa 3fe 402 406 40a 40e 41a 41f
423 427 42b 42f 431 432 437 1
43b 43f 443 446 44a 44e 452 456
459 45d 461 464 467 46c 46f 472
475 476 47b 47c 1 47e 483 487
48b 48e 493 498 49b 49f 4a0 4a5
4a6 4ab 4af 4b3 4b6 4bb 4c0 4c3
4c7 4c8 4cd 4d0 4d5 4d6 4db 4de
4e2 4e6 4e9 4ec 4ed 4ef 4f0 4f5
4f6 4fb 4fd 501 504 508 50c 510
514 518 51c 520 52c 531 535 539
53d 541 543 547 549 555 557 559
55a 55f 563 565 571 575 577 578
581 
189
2
0 1 a 6 9 :3 6 11 :2 6
1 3 a 13 a :2 1 4 9
12 11 :2 9 :2 4 :2 e 1d e :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 58 5e 61 :2 58 6f 89 8
:2 6f d 10 :2 6f 13 16 :2 6f b
e :2 6f 13 16 1f 27 :2 1f 34
:2 16 :2 6f 3c 3f :2 6f :2 7 4e :2 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e :2 7 56 :3 4 11 :2 4 c
:2 4 :2 d 19 2a 30 3b :2 19 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e d0 d3 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 3a :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
54 56 57 :2 54 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
51 53 54 :2 51 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
189
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:6 8 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:9 f :2 d :2 f :4 d
:3 c :11 12 :b 13 :3 12
:3 18 :3 19 :a 1b :11 1d
:30 1e :3 1d :a 20 b
:3 23 :11 24 :b 25 :17 26
:3 24 :2 28 :3 29 :3 2a
2b 29 28 29
:3 2c :3 23 :2 2d :5 2f
:11 30 :b 31 :18 32 :3 30
:2 34 35 :3 36 37
35 34 35 :3 38
:2 2e :6 2d 22 :7 1

583
4
:3 0 1 :3 0 2
:a 0 184 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
184 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 182 0
a :6 0 20 21
0 e 6 :3 0
1a :7 0 1e 1b
1c 182 0 c
:6 0 26 27 0
10 8 :3 0 9
:2 0 4 22 :7 0
25 23 0 182
0 e :6 0 f
:3 0 10 :3 0 f
:3 0 11 :3 0 29
2a 0 2 :4 0
12 2b 2d 28
2f 2e :2 0 12
:3 0 13 :3 0 31
32 0 14 :4 0
f :3 0 15 :3 0
35 36 0 2
:4 0 14 37 39
16 :4 0 17 :2 0
18 :3 0 16 3c
3e :3 0 19 :4 0
17 :2 0 1a :4 0
19 41 43 :3 0
17 :2 0 3 :3 0
1c 45 47 :3 0
17 :2 0 1a :4 0
1f 49 4b :3 0
17 :2 0 1b :4 0
22 4d 4f :3 0
17 :2 0 1c :3 0
1d :3 0 5 :3 0
25 53 55 1e
:4 0 27 52 58
2a 51 5a :3 0
17 :2 0 1f :4 0
2d 5c 5e :3 0
30 33 60 :2 0
62 35 63 30
62 0 64 37
0 e2 f :3 0
10 :3 0 65 66
0 f :3 0 20
:3 0 68 69 0
21 :2 0 2 :4 0
22 :2 0 23 :2 0
21 :2 0 39 6e
70 :3 0 3c 6a
72 67 74 73
:2 0 12 :3 0 24
:3 0 76 77 0
14 :4 0 25 :4 0
17 :2 0 18 :3 0
40 7b 7d :3 0
43 78 7f :2 0
81 46 82 75
81 0 83 48
0 e2 c :3 0
5 :3 0 84 85
0 e2 a :3 0
3 :3 0 87 88
0 e2 8 :3 0
26 :3 0 8a 8b
0 27 :3 0 a
:3 0 c :3 0 21
:2 0 4a 8d 91
8c 92 0 e2
f :3 0 10 :3 0
94 95 0 f
:3 0 20 :3 0 97
98 0 28 :2 0
2 :4 0 29 :2 0
23 :2 0 21 :2 0
4e 9d 9f :3 0
51 99 a1 96
a3 a2 :2 0 12
:3 0 24 :3 0 a5
a6 0 14 :4 0
2a :4 0 17 :2 0
18 :3 0 55 aa
ac :3 0 17 :2 0
2b :4 0 58 ae
b0 :3 0 17 :2 0
2c :4 0 5b b2
b4 :3 0 17 :2 0
1c :3 0 1d :3 0
8 :3 0 26 :3 0
b9 ba 0 5e
b8 bc 1e :4 0
60 b7 bf 63
b6 c1 :3 0 17
:2 0 2d :4 0 66
c3 c5 :3 0 17
:2 0 1a :4 0 69
c7 c9 :3 0 17
:2 0 a :3 0 6c
cb cd :3 0 17
:2 0 1a :4 0 6f
cf d1 :3 0 72
a7 d3 :2 0 d5
75 d6 a4 d5
0 d7 77 0
e2 2e :3 0 2f
:3 0 d8 d9 0
8 :3 0 26 :3 0
db dc 0 a
:3 0 30 :3 0 79
da e0 :2 0 e2
7d 183 8 :3 0
31 :2 0 4 e3
e4 0 f :3 0
10 :3 0 e6 e7
0 f :3 0 20
:3 0 e9 ea 0
32 :2 0 2 :4 0
33 :2 0 23 :2 0
21 :2 0 85 ef
f1 :3 0 88 eb
f3 e8 f5 f4
:2 0 12 :3 0 24
:3 0 f7 f8 0
14 :4 0 34 :4 0
17 :2 0 18 :3 0
8c fc fe :3 0
8f f9 100 :2 0
119 12 :3 0 24
:3 0 102 103 0
14 :4 0 35 :4 0
17 :2 0 8 :3 0
36 :3 0 108 109
0 92 107 10b
:3 0 17 :2 0 2d
:4 0 95 10d 10f
:3 0 17 :2 0 8
:3 0 37 :3 0 112
113 0 98 111
115 :3 0 9b 104
117 :2 0 119 9e
11a f6 119 0
11b a1 0 12b
38 :3 0 e :3 0
8 :3 0 36 :3 0
39 :3 0 8 :3 0
37 :3 0 3 :3 0
3a :4 0 3b 1
:a 0 127 :2 0 12b
11d 125 :2 0 7
:3 0 e :3 0 129
:2 0 12b a3 12d
a7 12c 12b :2 0
181 3c :3 0 8
:3 0 26 :3 0 130
131 0 3d :3 0
132 133 0 179
f :3 0 10 :3 0
135 136 0 f
:3 0 20 :3 0 138
139 0 32 :2 0
2 :4 0 3e :2 0
23 :2 0 21 :2 0
a9 13e 140 :3 0
ac 13a 142 137
144 143 :2 0 12
:3 0 24 :3 0 146
147 0 14 :4 0
3f :4 0 17 :2 0
18 :3 0 b0 14b
14d :3 0 b3 148
14f :2 0 169 12
:3 0 24 :3 0 151
152 0 14 :4 0
40 :4 0 17 :2 0
3d :3 0 b6 156
158 :3 0 17 :2 0
41 :4 0 b9 15a
15c :3 0 17 :2 0
42 :3 0 43 :3 0
21 :2 0 44 :2 0
bc 15f 163 c0
15e 165 :3 0 c3
153 167 :2 0 169
c6 16a 145 169
0 16b c9 0
179 38 :3 0 e
:3 0 39 :3 0 8
:3 0 37 :3 0 3
:3 0 3a :4 0 45
1 :a 0 175 :2 0
179 16d 173 :2 0
7 :3 0 e :3 0
177 :2 0 179 cb
17c :3 0 17c 0
17c 17b 179 17a
:6 0 17e 1 :3 0
d0 180 d2 17f
17e :2 0 181 d4
:2 0 183 d7 183
182 e2 181 :6 0
184 :2 0 2 10
183 187 :3 0 186
184 188 :8 0 
db
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 19 1 1f
1 2c 1 38
2 3b 3d 2
40 42 2 44
46 2 48 4a
2 4c 4e 1
54 2 56 57
2 50 59 2
5b 5d 4 34
3a 3f 5f 1
61 1 63 2
6d 6f 3 6b
6c 71 2 7a
7c 2 79 7e
1 80 1 82
3 8e 8f 90
2 9c 9e 3
9a 9b a0 2
a9 ab 2 ad
af 2 b1 b3
1 bb 2 bd
be 2 b5 c0
2 c2 c4 2
c6 c8 2 ca
cc 2 ce d0
2 a8 d2 1
d4 1 d6 3
dd de df 7
64 83 86 89
93 d7 e1 2
ee f0 3 ec
ed f2 2 fb
fd 2 fa ff
2 106 10a 2
10c 10e 2 110
114 2 105 116
2 101 118 1
11a 3 11b 126
12a 1 e5 2
13d 13f 3 13b
13c 141 2 14a
14c 2 149 14e
2 155 157 2
159 15b 3 160
161 162 2 15d
164 2 154 166
2 150 168 1
16a 4 134 16b
174 178 1 17c
1 12f 2 12d
180 3 17 1d
24 
1
4
0 
187
0
1
14
2
6
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
3 1 0
19 1 0
12 1 0
7 1 0
1f 1 0
0

/
SHOW ERRORS FUNCTION SP_COMMIT_ASSIGN;
ALTER FUNCTION SP_COMMIT_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, Assign level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ab
2 :e:
1FUNCTION:
1SP_ACPT_ETC_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGNMENT_ID:
1H_REC_USER:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_FINISH_D:
1DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_EFFORT:
10:
1H_CONTOUR:
1H_BITFLAG:
1H_REMAINING:
1H_TOTAL:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_FF_FLAG:
1H_ETC:
1H_SCHED_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_MLST_PERCENT:
1H_PROJAFFECTED_START:
1H_WORK_TODATE:
1H_PASSED:
1H_NOT_EFFORT_PA:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_ASSIGN(61) :: cplan.sql(20015) :: :
1PROJECT_ID:
1TASK_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1WORK_TODATE:
1C_CONTOUR:
1LAST_SUBMITTED:
1PLANNED_START:
1SCHED_START:
1PLANNED_FINISH:
1SCHED_FINISH:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n      PROJECT_ID,:n      TASK_ID,:n      PROJECT_ASSIGNMENT_ID,:n    +
1  SCHED_WORK+PLANNED_WORK,:n      FORECAST_START,:n      FORECAST_FINISH,:n  +
1    CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE ETC END,:n+
1      SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n      ETC,:n      C_CONTOUR,:n +
1     LAST_SUBMITTED,:n      CASE WHEN FORECAST_FINISH IS NOT NuLL AND FORECAS+
1T_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(PLANNED_START, SCHED_STA+
1RT) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1 ELSE 0 END,:n      UNRE+
1SOLVED_START,:n      UNRESOLVED_FINISH,:n      BILLABLE,:n      CAPITAL_EXPEN+
1SE,:n      REGULAR_COST,:n      REGULAR_RATE,:n      BIT_FLAG,:n      MILESTO+
1NE_PERCENT,:n      RESOURCE_ID,:n      RESOURCE_TYPE,:n      WORK_TODATE:n   +
1   INTO:n      h_project_id,:n      h_task_id,:n      h_prj_assignment_id,:n +
1     h_sched_work,:n      h_start_date,:n      h_finish_date,:n      h_effort+
1,:n      h_remaining,:n      h_etc,:n      h_contour,:n      h_last_submitted+
1,:n      h_FF_flag,:n      h_ta_start_DT,:n      h_ta_finish_DT,:n      h_bil+
1lable,:n      h_capital_expense,:n      h_reg_cost,:n      h_reg_sale,:n     +
1 h_bit_flag,:n      h_mlst_percent,:n      h_res_id,:n      h_res_type,:n    +
1  h_work_todate:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 h_tsk_assignment_id:n      AND (((SCHED_WORK+PLANNED_WORK) > 0:n      AND (S+
1CHED_WORK+PLANNED_WORK - WORK_TODATE) <> ETC):n      OR FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL):
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1140:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(141) :: cplan.sql(20095) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1147:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(148) :: cplan.sql(20102) :: :
1STATE:: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1150:
1                EXIT:: SP_ACPT_ETC_ASSIGN(151) :: cplan.sql(20105) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1FC_ACPT_EFFORT:
1>:
1200000:
1169:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(170) :: cplan.sql(20124) :: :
1172:
1                EXIT:: SP_ACPT_ETC_ASSIGN(173) :: cplan.sql(20127) :: :
1!=:
1SELECT ETC INTO h_total:n            FROM TASK_ASSIGNMENTS:n            WHERE+
1 TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1193:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(194) :: cplan.sql(20148) :: :
1UPDATE TASK_ASSIGNMENTS:n               SET ETC  = h_etc:n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1215:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(216) :: cplan.sql(20170) :: :
1FC_ROLLUP:
14:
1226:
1       RETURN_STATUS:: SP_ACPT_ETC_ASSIGN(227) :: cplan.sql(20181) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1233:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(234) :: cplan.sql(20188) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1245:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(246) :: cplan.sql(20200) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
532
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 d a0 4d d
a0 4d d :46 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:1c a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c :3 a0 a5 b d
b7 :2 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
532
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
134 122 101 126 127 12f 121 150
13f 143 14b 11e 168 157 15b 163
13e 184 173 177 17f 13b 19c 18b
18f 197 172 1b8 1a7 1ab 1b3 16f
1d0 1bf 1c3 1cb 1a6 1ec 1db 1df
1e7 1a3 208 1f3 1f7 1fa 1fb 203
1da 224 213 217 1d7 21f 212 240
22f 233 20f 23b 22e 25c 24b 24f
22b 257 24a 278 267 26b 247 273
266 294 283 287 263 28f 282 2b0
29f 2a3 2ab 27f 2c8 2b7 2bb 2c3
29e 2e5 2d3 29b 2d7 2d8 2e0 2d2
301 2f0 2f4 2cf 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 308
334 327 355 344 348 324 350 343
371 360 364 340 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3f8 3cc 415 404 408 410 3eb
431 420 424 3e8 42c 41f 44d 43c
440 41c 448 43b 469 458 45c 438
464 457 485 474 478 454 480 473
4a1 490 494 49c 470 4bc 4a8 4ac
4b4 4b7 48f 4d8 4c7 4cb 48c 4d3
4c6 4f4 4e3 4e7 4c3 4ef 4e2 514
4ff 503 4df 507 50f 4fe 51b 51f
4fb 523 527 52b 52e 533 534 1
536 53b 53f 543 546 54b 54f 553
556 55b 55c 55e 563 566 56a 56b
570 575 578 57d 57e 583 586 58a
58b 590 593 598 599 59e 5a1 5a6
5a7 5ac 5af 5b3 5b7 5bb 5bc 5be
5c3 5c4 5c6 5c7 5cc 5cf 5d4 5d5
5da 5dd 5e2 5e3 5e8 5eb 5ef 5f0
5f5 5f8 5fd 5fe 603 606 60b 60c
611 612 617 619 61d 620 624 628
62b 62f 633 636 639 63e 641 644
647 648 64d 64e 1 650 655 659
65d 660 665 66a 66d 671 672 677
678 67d 67f 683 686 68a 68e 692
696 69a 69e 6a2 6a6 6aa 6ae 6af
6b3 6b7 6b8 6bc 6c0 6c4 6c8 6cc
6d0 6d4 6d8 6dc 6e0 6e4 6e8 6ec
6f0 6f4 6f8 6fc 700 704 708 70c
710 714 718 71c 720 724 728 72c
730 734 738 73c 740 744 748 74c
750 754 758 75c 760 764 768 76c
770 774 778 77c 780 784 788 78c
790 794 798 79c 7a0 7a4 7a8 7ac
7b0 7b4 7b8 7bc 7c0 7c4 7c8 7cc
7d0 7d4 7e0 7e4 7e8 7eb 7ef 7f3
7f5 7f9 7fd 801 804 808 80c 80e
80f 814 1 818 81c 820 823 827
82b 82f 833 836 83a 83e 841 844
849 84c 84f 852 853 858 859 1
85b 860 864 868 86b 870 875 878
87c 87d 882 885 88a 88b 890 893
898 899 89e 8a1 8a5 8a6 8ab 8ae
8b3 8b4 8b9 8bc 8c0 8c4 8c7 8ca
8cb 8cd 8ce 8d3 8d4 8d9 8db 8df
8e2 8e4 8e8 8ea 8f6 8f8 8fa 8fb
900 904 906 912 914 918 91c 91f
923 926 92a 92d 92e 933 936 93a
93e 941 945 949 94c 94f 954 957
95a 95d 95e 963 964 1 966 96b
96f 973 976 97b 980 983 987 988
98d 990 995 996 99b 99e 9a3 9a4
9a9 9ac 9b0 9b4 9b8 9bc 9bf 9c0
9c2 9c7 9c8 9ca 9cb 9d0 9d3 9d8
9d9 9de 9e1 9e6 9e7 9ec 9ef 9f3
9f4 9f9 9fc a01 a02 a07 a08 a0d
a0f a13 a16 a1a a1e a21 a25 a29
a2c a2f a34 a37 a3a a3d a3e a43
a44 1 a46 a4b a4f a53 a56 a5b
a60 a63 a67 a68 a6d a6e a73 a75
a79 a7c a80 a84 a87 a8b a8f a92
a96 a9a a9b aa0 aa2 aa6 aa9 aad
ab1 ab5 ab9 abd ac1 ac5 ac9 acd
ad1 ad5 ad9 add ae1 ae5 ae9 aed
af1 af5 af9 afd b01 b05 b09 b0d
b11 b15 b19 b1a b1c b20 b24 b28
b2b b2c b2e b31 b34 b35 b3a b3e
b42 b45 b49 b4d b50 b53 b58 b5b
b5e b61 b62 b67 b68 1 b6a b6f
b73 b77 b7a b7f b84 b87 b8b b8c
b91 b94 b99 b9a b9f ba2 ba7 ba8
bad bb0 bb4 bb8 bbc bbd bbf bc4
bc5 bc7 bc8 bcd bd0 bd5 bd6 bdb
bde be3 be4 be9 bec bf0 bf1 bf6
bf9 bfe bff c04 c05 c0a c0c c10
c13 c17 c1b c1e c22 c26 c29 c2c
c31 c34 c37 c3a c3b c40 c41 1
c43 c48 c4c c50 c53 c58 c5d c60
c64 c65 c6a c6b c70 c72 c76 c79
c7d c81 c84 c88 c8c c8f c90 c92
c96 c9a c9b ca0 ca2 ca6 ca9 cad
cb1 cb5 cb8 cb9 cbb cbe cc1 cc2
cc7 ccb ccf cd3 cd7 cdb ce7 ceb
cef cf2 cf6 cfa cfc d00 d04 d08
d0b d0f d13 d15 d16 d1b 1 d1f
d23 d27 d2a d2e d32 d36 d3a d3d
d41 d45 d48 d4b d50 d53 d56 d59
d5a d5f d60 1 d62 d67 d6b d6f
d72 d77 d7c d7f d83 d84 d89 d8c
d91 d92 d97 d9a d9f da0 da5 da8
dac dad db2 db5 dba dbb dc0 dc3
dc7 dcb dce dd1 dd2 dd4 dd5 dda
ddb de0 de2 de6 de9 deb def df1
dfd dff e01 e02 e07 e0b e0d e19
e1b e1f e23 e26 e27 e29 e2d e30
e34 e37 e38 e3a e3b e40 e44 e48
e4c e50 e54 e60 e64 e69 e6d e70
e71 e76 e7a e7e e81 e84 e88 e8a
e8e e92 e95 e98 e9c e9e ea2 ea6
ea9 eab eaf eb3 eb7 eba ebe ec2
ec4 ec5 eca 1 ece ed2 ed6 ed9
edd ee1 ee5 ee9 eec ef0 ef4 ef7
efa eff f02 f05 f08 f09 f0e f0f
1 f11 f16 f1a f1e f21 f26 f2b
f2e f32 f33 f38 f3b f40 f41 f46
f49 f4e f4f f54 f57 f5b f5c f61
f64 f69 f6a f6f f72 f76 f7a f7d
f80 f81 f83 f84 f89 f8a f8f f91
f95 f98 f9a f9e fa0 fac fae fb0
fb1 fb6 fba fbc fc8 fca fcc fd0
fd3 fd5 fd9 fdc fe0 fe4 fe8 fe9
feb fef ff1 ff5 ff9 ffc 1000 1004
1007 100b 100f 1012 1015 101a 101d 1020
1023 1024 1029 102a 1 102c 1031 1035
1039 103c 1041 1046 1049 104d 104e 1053
1056 105b 105c 1061 1064 1069 106a 106f
1072 1076 107a 107e 1082 1085 1086 1088
108d 108e 1090 1091 1096 1099 109e 109f
10a4 10a7 10ac 10ad 10b2 10b5 10b9 10ba
10bf 10c2 10c7 10c8 10cd 10ce 10d3 10d5
10d9 10dc 10e0 10e4 10e7 10eb 10ef 10f2
10f6 10fa 10fb 1100 1102 1106 110a 110d
1111 1115 1118 111c 1120 1123 1126 112b
112e 1131 1134 1135 113a 113b 1 113d
1142 1146 114a 114d 1152 1157 115a 115e
115f 1164 1165 116a 116e 1172 1175 117a
117f 1182 1186 118a 118d 118e 1193 1196
119b 119c 11a1 11a4 11a8 11ac 11af 11b0
11b5 11b6 11bb 11bd 11c1 11c4 11c8 11cc
11d0 11d4 11d8 11dc 11e0 11e4 11e8 11f4
11f9 11fd 1201 1205 1209 120b 120c 1211
1 1215 1219 121d 1220 1224 1228 122c
1230 1233 1237 123b 123e 1241 1246 1249
124c 124f 1250 1255 1256 1 1258 125d
1261 1265 1268 126d 1272 1275 1279 127a
127f 1280 1285 1289 128d 1290 1295 129a
129d 12a1 12a2 12a7 12aa 12af 12b0 12b5
12b8 12bc 12c0 12c3 12c6 12c7 12c9 12ca
12cf 12d0 12d5 12d7 12db 12de 12e2 12e6
12ea 12ee 12f2 12f6 12fa 1306 130b 130f
1313 1317 131b 131d 1321 1323 132f 1331
1333 1334 1339 133d 133f 134b 134f 1351
1352 135b 
532
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 e 17 16
:2 e :2 4 d 16 15 :2 d :2 4 f
18 17 :2 f :2 4 :3 12 :2 4 :3 13 :2 4
:3 11 :2 4 :3 12 :2 4 :3 f :2 4 :3 15 :2 4
:3 e :2 4 f 18 17 :2 f :2 4 :2 d
1c d :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 c
1b c :2 4 :3 10 :2 4 :3 10 :2 4 12
1b 1a :2 12 :2 4 :2 d 1c d :2 4
:2 12 21 12 :2 4 :2 e 1d e :2 4
:2 a 19 a :2 4 :2 11 20 11 :2 4
:2 f 1e f :2 4 :2 14 23 14 :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:3 9 :2 4 :3 9 :2 4 :2 f 1e f :2 4
:2 16 25 16 :2 4 :2 11 20 11 :2 4
:2 13 22 13 :2 4 :3 19 :2 4 :2 12 21
12 :2 4 :2 d 1c d :2 4 :2 14 23
14 :2 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 5a 60 63 :2 5a 71
8d 8 :2 71 d 10 :2 71 13 16
:2 71 b e :2 71 13 16 1f 27
:2 1f 34 :2 16 :2 71 b e :2 71 13
16 :2 71 1b 1e :2 71 2a 2d :2 71
32 35 :2 71 :2 7 50 :2 4 7 :2 11
23 :2 2d 39 3c 52 54 55 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:2 7 58 :3 4 11 :2 4 1b :2 4 12
:2 4 14 :2 4 15 4 :4 7 12 :2 7
11 23 46 7 12 21 :3 7 11
31 4c 64 6d 7c 8d 96 a6
:22 7 c d 21 e 19 c 17
26 36 a 28 fffa 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 59 5c 5d :2 59
:2 29 :3 d :2 13 18 24 6a 6d :2 24
7a 7d :2 24 81 84 :2 24 90 93
:2 24 9b 9e :2 24 aa ad b4 bd
c0 :2 ad :2 24 :2 d 60 :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
56 59 5a :2 56 :2 26 :3 a :2 10 15
21 67 6a :2 21 77 7a :2 21 7e
81 :2 21 8b 8e 97 9f :2 a8 :2 97
bb :2 8e :2 21 c3 c6 :2 21 ce d1
:2 21 d6 d9 :2 21 ed f0 :2 21 :2 a
5d :2 7 a :2 14 26 :2 30 3c 3f
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 67 6a :2 21 :2 a 5c :3 7 :2 12
26 :2 2f 41 f :2 7 35 :3 4 17
26 34 3f 54 25 33 41 50
5a 25 2c 37 49 54 25 35
41 54 25 31 3d 4d 57 25
34 3f :2 17 4 7 10 21 :2 7
24 26 :2 24 a :2 14 26 :2 30 3c
40 56 59 5a :2 56 :2 26 :3 a :2 10
15 21 67 6a :2 21 77 7a :2 21
7e 81 :2 21 8b 8e 97 9f :2 97
b1 :2 8e :2 21 b9 bc :2 21 c4 c7
:2 21 cc cf :2 21 e3 e6 :2 21 :2 a
5d :2 7 a :2 14 26 :2 30 3c 3f
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 67 6a :2 21 :2 a 5c :3 7 :2 12
26 2f 40 :2 26 44 f :2 7 2d
7 12 7 a 13 1e :2 a 21
24 :2 21 14 1d 12 13 27 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5f 62
63 :2 5f :2 2f :3 13 :2 19 1e 2a 70
73 :2 2a 80 83 :2 2a 87 8a :2 2a
96 99 :2 2a a1 a4 :2 2a b0 b3
ba c3 c6 :2 b3 :2 2a :2 13 66 :2 10
:2 d :4 19 :2 d a :3 26 d 16 1d
:2 d 22 20 2b 34 :2 22 :2 20 17
14 1b 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 62 65
66 :2 62 :2 32 :3 16 :2 1c 21 2d 73
76 :2 2d 83 86 :2 2d 8a 8d :2 2d
99 9c :2 2d a4 a7 :2 2d b3 b6
bd c6 c9 :2 b6 :2 2d :2 16 69 :2 13
:2 10 :4 1c :2 10 d :4 37 :2 a 26 :3 7
1a 24 :2 1a 7 :4 4 7 :2 11 23
:2 2d 39 3c 52 55 56 :2 52 :2 23
:3 7 :2 d 12 1e 64 67 :2 1e 74
77 :2 1e 7b 7e :2 1e 88 8b 94
9c :2 a5 :2 94 b0 :2 8b :2 1e b8 bb
:2 1e c3 c6 :2 1e cb ce :2 1e d1
d4 :2 1e :2 7 59 :3 4 :2 f 21 :2 2a
34 38 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 56 59 5a
:2 56 :2 26 :3 a :2 10 15 21 67 6a
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 5d :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 53 56 57
:2 53 :2 23 :3 7 :2 d 12 1e 64 67
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 5a :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
532
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :7 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:5 1c :5 1d :7 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:5 28 :5 29 :6 2a :6 2b
:6 2c :6 2d :5 2e :6 2f
:6 30 :6 31 :7 33 :b 35
:11 36 37 :2 36 :2 37
:2 36 :2 37 :2 36 :2 38
:2 36 :9 38 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:4 36 :3 35 :11 3c :b 3d
:3 3c :3 44 :3 45 :3 46
:3 4a :3 4c 51 52
53 :2 54 55 56
:3 57 :3 58 59 5a
5b :9 5c 5d 5e
5f 60 61 62
63 64 65 66
67 69 6a 6b
6c 6d 6e 6f
70 71 72 73
74 75 76 77
78 79 7a 7b
7c 7d 7e 7f
80 :2 81 :2 82 :4 83
:2 84 51 :5 85 4f
87 :5 88 :3 87 :2 89
:5 8b :11 8c :24 8d :3 8c
:2 8a :6 89 86 :3 34
:a 92 :11 93 :30 94 :3 93
:11 96 :b 97 :3 96 :7 99
9a :2 99 :3 92 :6 9d
:5 9e :5 9f :4 a0 :5 a1
:3 a2 :3 9d :9 a6 :11 a9
:2e aa :3 a9 :11 ac :b ad
:3 ac :9 af b0 :2 af
a6 :3 b2 :9 b5 :2 b7
b8 :2 b9 b7 :5 ba
b6 bc :5 bd :3 bc
:2 be :5 c0 :11 c1 :24 c2
:3 c1 :2 bf :6 be bb
:3 b5 :d c7 c9 :2 ca
:2 cb c9 :6 cc :5 cd
cc :5 cf ce :3 cc
c8 d2 :5 d3 :3 d2
:2 d4 :5 d6 :11 d7 :24 d8
:3 d7 :2 d5 :6 d4 d1
:6 c7 :3 b5 :6 df b1
:3 a6 :11 e2 :30 e3 :3 e2
:a e5 34 :3 e8 :11 e9
:b ea :17 eb :3 e9 :2 ed
:3 ee :3 ef f0 ee
ed ee :3 f1 :3 e8
:2 f2 :5 f4 :11 f5 :b f6
:18 f7 :3 f5 :2 f9 fa
:3 fb fc fa f9
fa :3 fd :2 f3 :6 f2
e7 :7 1 
135d
4
:3 0 1 :3 0 2
:a 0 52d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 52d 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 52b
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 52b
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 52b
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 52b
0 f :6 0 c
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 52b
0 10 :6 0 13
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 52b
0 11 :6 0 29
13b 0 27 4
:3 0 25 41 43
:6 0 46 44 0
52b 0 12 :6 0
2d 16f 0 2b
15 :3 0 48 :7 0
4b 49 0 52b
0 14 :6 0 15
:3 0 4d :7 0 50
4e 0 52b 0
16 :6 0 31 1a3
0 2f 15 :3 0
52 :7 0 55 53
0 52b 0 17
:6 0 15 :3 0 57
:7 0 5a 58 0
52b 0 18 :6 0
35 1d7 0 33
1a :3 0 5c :7 0
5f 5d 0 52b
0 19 :6 0 1a
:3 0 61 :7 0 64
62 0 52b 0
1b :6 0 1f :2 0
39 1a :3 0 66
:7 0 69 67 0
52b 0 1c :6 0
4 :3 0 13 :2 0
37 6b 6d :6 0
70 6e 0 52b
0 1d :6 0 1f
:2 0 3b 6 :3 0
72 :7 0 76 73
74 52b 0 1e
:6 0 1f :2 0 3d
6 :3 0 78 :7 0
7c 79 7a 52b
0 20 :6 0 1f
:2 0 3f 6 :3 0
7e :7 0 82 7f
80 52b 0 21
:6 0 1f :2 0 41
6 :3 0 84 :7 0
88 85 86 52b
0 22 :6 0 45
29b 0 43 6
:3 0 8a :7 0 8e
8b 8c 52b 0
23 :6 0 27 :2 0
47 15 :3 0 90
:7 0 93 91 0
52b 0 24 :6 0
1a :3 0 95 :7 0
98 96 0 52b
0 25 :6 0 1f
:2 0 4b 4 :3 0
49 9a 9c :6 0
9f 9d 0 52b
0 26 :6 0 1f
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 52b 0 28
:6 0 1f :2 0 4f
6 :3 0 a7 :7 0
ab a8 a9 52b
0 29 :6 0 1f
:2 0 51 6 :3 0
ad :7 0 b1 ae
af 52b 0 2a
:6 0 1f :2 0 53
6 :3 0 b3 :7 0
b7 b4 b5 52b
0 2b :6 0 1f
:2 0 55 6 :3 0
b9 :7 0 bd ba
bb 52b 0 2c
:6 0 1f :2 0 57
6 :3 0 bf :7 0
c3 c0 c1 52b
0 2d :6 0 31
:2 0 59 6 :3 0
c5 :7 0 c9 c6
c7 52b 0 2e
:6 0 31 :2 0 5b
30 :3 0 cb :7 0
cf cc cd 52b
0 2f :6 0 5f
3e8 0 5d 30
:3 0 d1 :7 0 d5
d2 d3 52b 0
32 :6 0 1f :2 0
61 1a :3 0 d7
:7 0 da d8 0
52b 0 33 :6 0
1a :3 0 dc :7 0
df dd 0 52b
0 34 :6 0 1f
:2 0 63 6 :3 0
e1 :7 0 e5 e2
e3 52b 0 35
:6 0 1f :2 0 65
6 :3 0 e7 :7 0
eb e8 e9 52b
0 36 :6 0 1f
:2 0 67 6 :3 0
ed :7 0 f1 ee
ef 52b 0 37
:6 0 6b 48c 0
69 6 :3 0 f3
:7 0 f7 f4 f5
52b 0 38 :6 0
1f :2 0 6d 1a
:3 0 f9 :7 0 fc
fa 0 52b 0
39 :6 0 6 :3 0
fe :7 0 1f :2 0
102 ff 100 52b
0 3a :6 0 1f
:2 0 6f 6 :3 0
104 :7 0 108 105
106 52b 0 3b
:6 0 110 111 0
71 6 :3 0 10a
:7 0 10e 10b 10c
52b 0 3c :6 0
116 117 0 73
9 :3 0 a :2 0
4 112 :7 0 115
113 0 52b 0
3d :6 0 3e :3 0
3f :3 0 3e :3 0
40 :3 0 119 11a
0 2 :4 0 75
11b 11d 118 11f
11e :2 0 41 :3 0
42 :3 0 121 122
0 43 :4 0 3e
:3 0 44 :3 0 125
126 0 2 :4 0
77 127 129 45
:4 0 46 :2 0 47
:3 0 79 12c 12e
:3 0 48 :4 0 46
:2 0 49 :4 0 7c
131 133 :3 0 46
:2 0 3 :3 0 7f
135 137 :3 0 46
:2 0 49 :4 0 82
139 13b :3 0 46
:2 0 4a :4 0 85
13d 13f :3 0 46
:2 0 4b :3 0 4c
:3 0 5 :3 0 88
143 145 4d :4 0
8a 142 148 8d
141 14a :3 0 46
:2 0 4a :4 0 90
14c 14e :3 0 46
:2 0 49 :4 0 93
150 152 :3 0 46
:2 0 7 :3 0 96
154 156 :3 0 46
:2 0 49 :4 0 99
158 15a :3 0 46
:2 0 4e :4 0 9c
15c 15e :3 0 9f
123 160 :2 0 162
a4 163 120 162
0 164 a6 0
48b 3e :3 0 3f
:3 0 165 166 0
3e :3 0 4f :3 0
168 169 0 13
:2 0 2 :4 0 50
:2 0 51 :2 0 13
:2 0 a8 16e 170
:3 0 ab 16a 172
167 174 173 :2 0
41 :3 0 52 :3 0
176 177 0 43
:4 0 53 :4 0 46
:2 0 47 :3 0 af
17b 17d :3 0 b2
178 17f :2 0 181
b5 182 175 181
0 183 b7 0
48b 21 :3 0 5
:3 0 184 185 0
48b b :3 0 3
:3 0 187 188 0
48b e :3 0 7
:3 0 18a 18b 0
48b 17 :4 0 18d
18e 0 48b 18
:4 0 190 191 0
48b 54 :3 0 55
:3 0 56 :3 0 57
:3 0 58 :3 0 59
:3 0 5a :3 0 21
:3 0 59 :3 0 5b
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 5d :3 0 5e
:3 0 5a :3 0 59
:3 0 5a :3 0 4b
:3 0 5f :3 0 60
:3 0 4b :3 0 61
:3 0 62 :3 0 63
:3 0 64 :3 0 65
:3 0 66 :3 0 67
:3 0 68 :3 0 69
:3 0 6a :3 0 6b
:3 0 6c :3 0 5c
:3 0 f :3 0 10
:3 0 d :3 0 2c
:3 0 17 :3 0 18
:3 0 1e :3 0 22
:3 0 2b :3 0 20
:3 0 1b :3 0 2a
:3 0 14 :3 0 16
:3 0 35 :3 0 36
:3 0 2f :3 0 32
:3 0 1d :3 0 38
:3 0 11 :3 0 12
:3 0 3a :3 0 6d
:3 0 6e :3 0 b
:3 0 57 :3 0 58
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 59 :3 0 5a
:4 0 6f 1 :8 0
1df 9 :3 0 70
:3 0 1da 1db 0
71 :3 0 1dc 1dd
0 1df b9 232
72 :3 0 9 :3 0
70 :3 0 1e1 1e2
0 71 :3 0 1e3
1e4 0 1e6 bc
1e8 be 1e7 1e6
:2 0 230 73 :3 0
9 :3 0 70 :3 0
1eb 1ec 0 71
:3 0 1ed 1ee 0
228 3e :3 0 3f
:3 0 1f0 1f1 0
3e :3 0 4f :3 0
1f3 1f4 0 74
:2 0 2 :4 0 75
:2 0 51 :2 0 13
:2 0 c0 1f9 1fb
:3 0 c3 1f5 1fd
1f2 1ff 1fe :2 0
41 :3 0 52 :3 0
201 202 0 43
:4 0 76 :4 0 46
:2 0 47 :3 0 c7
206 208 :3 0 46
:2 0 77 :4 0 ca
20a 20c :3 0 46
:2 0 78 :4 0 cd
20e 210 :3 0 46
:2 0 71 :3 0 d0
212 214 :3 0 46
:2 0 79 :4 0 d3
216 218 :3 0 46
:2 0 7a :3 0 7b
:3 0 13 :2 0 7c
:2 0 d6 21b 21f
da 21a 221 :3 0
dd 203 223 :2 0
225 e0 226 200
225 0 227 e2
0 228 e4 22b
:3 0 22b 0 22b
22a 228 229 :6 0
22d 2 :3 0 e7
22f e9 22e 22d
:2 0 230 eb :2 0
232 0 232 231
1df 230 :6 0 48b
1 :3 0 9 :3 0
70 :3 0 234 235
0 9 :3 0 7d
:2 0 7e :3 0 237
239 0 f0 238
23b :3 0 23c :2 0
3e :3 0 3f :3 0
23e 23f 0 3e
:3 0 4f :3 0 241
242 0 c :2 0
2 :4 0 7f :2 0
51 :2 0 13 :2 0
f3 247 249 :3 0
f6 243 24b 240
24d 24c :2 0 41
:3 0 52 :3 0 24f
250 0 43 :4 0
80 :4 0 46 :2 0
47 :3 0 fa 254
256 :3 0 46 :2 0
77 :4 0 fd 258
25a :3 0 46 :2 0
81 :4 0 100 25c
25e :3 0 46 :2 0
4b :3 0 4c :3 0
82 :3 0 83 :3 0
263 264 0 103
262 266 4d :4 0
105 261 269 108
260 26b :3 0 46
:2 0 84 :4 0 10b
26d 26f :3 0 46
:2 0 49 :4 0 10e
271 273 :3 0 46
:2 0 b :3 0 111
275 277 :3 0 46
:2 0 49 :4 0 114
279 27b :3 0 117
251 27d :2 0 27f
11a 280 24e 27f
0 281 11c 0
2ab 3e :3 0 3f
:3 0 282 283 0
3e :3 0 4f :3 0
285 286 0 13
:2 0 2 :4 0 85
:2 0 51 :2 0 13
:2 0 11e 28b 28d
:3 0 121 287 28f
284 291 290 :2 0
41 :3 0 52 :3 0
293 294 0 43
:4 0 86 :4 0 46
:2 0 47 :3 0 125
298 29a :3 0 128
295 29c :2 0 29e
12b 29f 292 29e
0 2a0 12d 0
2ab 87 :3 0 88
:3 0 2a1 2a2 0
82 :3 0 83 :3 0
2a4 2a5 0 b
:3 0 89 :3 0 12f
2a3 2a9 :2 0 2ab
133 2ac 23d 2ab
0 2ad 137 0
48b 2e :3 0 8a
:3 0 f :3 0 10
:3 0 b :3 0 d
:3 0 2c :3 0 17
:3 0 18 :3 0 1e
:3 0 22 :3 0 2b
:3 0 20 :3 0 1b
:3 0 2a :3 0 14
:3 0 16 :3 0 35
:3 0 36 :3 0 2f
:3 0 32 :3 0 1d
:3 0 38 :3 0 11
:3 0 12 :3 0 3a
:3 0 21 :3 0 e
:3 0 139 2af 2ca
2ae 2cb 0 48b
4b :3 0 2e :3 0
1f :2 0 154 2cd
2d0 8b :2 0 8c
:2 0 159 2d2 2d4
:3 0 3e :3 0 3f
:3 0 2d6 2d7 0
3e :3 0 4f :3 0
2d9 2da 0 c
:2 0 2 :4 0 8d
:2 0 51 :2 0 13
:2 0 15c 2df 2e1
:3 0 15f 2db 2e3
2d8 2e5 2e4 :2 0
41 :3 0 52 :3 0
2e7 2e8 0 43
:4 0 8e :4 0 46
:2 0 47 :3 0 163
2ec 2ee :3 0 46
:2 0 77 :4 0 166
2f0 2f2 :3 0 46
:2 0 81 :4 0 169
2f4 2f6 :3 0 46
:2 0 4b :3 0 4c
:3 0 2e :3 0 16c
2fa 2fc 4d :4 0
16e 2f9 2ff 171
2f8 301 :3 0 46
:2 0 84 :4 0 174
303 305 :3 0 46
:2 0 49 :4 0 177
307 309 :3 0 46
:2 0 b :3 0 17a
30b 30d :3 0 46
:2 0 49 :4 0 17d
30f 311 :3 0 180
2e9 313 :2 0 315
183 316 2e6 315
0 317 185 0
343 3e :3 0 3f
:3 0 318 319 0
3e :3 0 4f :3 0
31b 31c 0 13
:2 0 2 :4 0 8f
:2 0 51 :2 0 13
:2 0 187 321 323
:3 0 18a 31d 325
31a 327 326 :2 0
41 :3 0 52 :3 0
329 32a 0 43
:4 0 90 :4 0 46
:2 0 47 :3 0 18e
32e 330 :3 0 191
32b 332 :2 0 334
194 335 328 334
0 336 196 0
343 87 :3 0 88
:3 0 337 338 0
4b :3 0 2e :3 0
1f :2 0 198 33a
33d b :3 0 89
:3 0 19b 339 341
:2 0 343 19f 43a
23 :3 0 1f :2 0
344 345 0 439
4b :3 0 2a :3 0
1f :2 0 1a3 347
34a 91 :2 0 13
:2 0 1a8 34c 34e
:3 0 5b :3 0 23
:3 0 6d :3 0 6e
:3 0 b :4 0 92
1 :8 0 35b 9
:3 0 70 :3 0 356
357 0 71 :3 0
358 359 0 35b
1ab 3ae 72 :3 0
9 :3 0 70 :3 0
35d 35e 0 71
:3 0 35f 360 0
362 1ae 364 1b0
363 362 :2 0 3ac
73 :3 0 9 :3 0
70 :3 0 367 368
0 71 :3 0 369
36a 0 3a4 3e
:3 0 3f :3 0 36c
36d 0 3e :3 0
4f :3 0 36f 370
0 74 :2 0 2
:4 0 93 :2 0 51
:2 0 13 :2 0 1b2
375 377 :3 0 1b5
371 379 36e 37b
37a :2 0 41 :3 0
52 :3 0 37d 37e
0 43 :4 0 94
:4 0 46 :2 0 47
:3 0 1b9 382 384
:3 0 46 :2 0 77
:4 0 1bc 386 388
:3 0 46 :2 0 78
:4 0 1bf 38a 38c
:3 0 46 :2 0 71
:3 0 1c2 38e 390
:3 0 46 :2 0 79
:4 0 1c5 392 394
:3 0 46 :2 0 7a
:3 0 7b :3 0 13
:2 0 7c :2 0 1c8
397 39b 1cc 396
39d :3 0 1cf 37f
39f :2 0 3a1 1d2
3a2 37c 3a1 0
3a3 1d4 0 3a4
1d6 3a7 :3 0 3a7
0 3a7 3a6 3a4
3a5 :6 0 3a9 4
:3 0 1d9 3ab 1db
3aa 3a9 :2 0 3ac
1dd :2 0 3ae 0
3ae 3ad 35b 3ac
:6 0 430 1 :3 0
4b :3 0 2b :3 0
1f :2 0 1e0 3b0
3b3 4b :3 0 8b
:2 0 23 :3 0 1f
:2 0 1e3 3b5 3b9
1e8 3b6 3bb :3 0
6d :3 0 5b :3 0
2b :3 0 6e :3 0
b :4 0 95 1
:8 0 3d8 96 :4 0
3c3 :3 0 89 :3 0
7d :2 0 1ed 3c6
3c7 :3 0 9 :3 0
70 :3 0 3c9 3ca
0 1f :2 0 3cb
3cc 0 3ce 1f0
3d5 9 :3 0 70
:3 0 3cf 3d0 0
97 :2 0 3d1 3d2
0 3d4 1f2 3d6
3c8 3ce 0 3d7
0 3d4 0 3d7
1f4 0 3d8 1f7
42b 72 :3 0 9
:3 0 70 :3 0 3da
3db 0 71 :3 0
3dc 3dd 0 3df
1fa 3e1 1fc 3e0
3df :2 0 429 73
:3 0 9 :3 0 70
:3 0 3e4 3e5 0
71 :3 0 3e6 3e7
0 421 3e :3 0
3f :3 0 3e9 3ea
0 3e :3 0 4f
:3 0 3ec 3ed 0
74 :2 0 2 :4 0
98 :2 0 51 :2 0
13 :2 0 1fe 3f2
3f4 :3 0 201 3ee
3f6 3eb 3f8 3f7
:2 0 41 :3 0 52
:3 0 3fa 3fb 0
43 :4 0 99 :4 0
46 :2 0 47 :3 0
205 3ff 401 :3 0
46 :2 0 77 :4 0
208 403 405 :3 0
46 :2 0 78 :4 0
20b 407 409 :3 0
46 :2 0 71 :3 0
20e 40b 40d :3 0
46 :2 0 79 :4 0
211 40f 411 :3 0
46 :2 0 7a :3 0
7b :3 0 13 :2 0
7c :2 0 214 414
418 218 413 41a
:3 0 21b 3fc 41c
:2 0 41e 21e 41f
3f9 41e 0 420
220 0 421 222
424 :3 0 424 0
424 423 421 422
:6 0 426 6 :3 0
225 428 227 427
426 :2 0 429 229
:2 0 42b 0 42b
42a 3d8 429 :6 0
42d 1 :3 0 22c
42e 3bc 42d 0
42f 22e 0 430
230 431 34f 430
0 432 233 0
439 2e :3 0 9a
:3 0 f :3 0 235
434 436 433 437
0 439 237 43b
2d5 343 0 43c
0 439 0 43c
23b 0 48b 3e
:3 0 3f :3 0 43d
43e 0 3e :3 0
4f :3 0 440 441
0 9b :2 0 2
:4 0 9c :2 0 51
:2 0 13 :2 0 23e
446 448 :3 0 241
442 44a 43f 44c
44b :2 0 41 :3 0
52 :3 0 44e 44f
0 43 :4 0 9d
:4 0 46 :2 0 47
:3 0 245 453 455
:3 0 46 :2 0 77
:4 0 248 457 459
:3 0 46 :2 0 81
:4 0 24b 45b 45d
:3 0 46 :2 0 4b
:3 0 4c :3 0 9
:3 0 70 :3 0 462
463 0 24e 461
465 4d :4 0 250
460 468 253 45f
46a :3 0 46 :2 0
84 :4 0 256 46c
46e :3 0 46 :2 0
49 :4 0 259 470
472 :3 0 46 :2 0
3 :3 0 25c 474
476 :3 0 46 :2 0
49 :4 0 25f 478
47a :3 0 262 450
47c :2 0 47e 265
47f 44d 47e 0
480 267 0 48b
87 :3 0 9e :3 0
481 482 0 9
:3 0 70 :3 0 484
485 0 3 :3 0
89 :3 0 269 483
489 :2 0 48b 26d
52c 9 :3 0 9f
:2 0 4 48c 48d
0 3e :3 0 3f
:3 0 48f 490 0
3e :3 0 4f :3 0
492 493 0 74
:2 0 2 :4 0 a0
:2 0 51 :2 0 13
:2 0 27b 498 49a
:3 0 27e 494 49c
491 49e 49d :2 0
41 :3 0 52 :3 0
4a0 4a1 0 43
:4 0 a1 :4 0 46
:2 0 47 :3 0 282
4a5 4a7 :3 0 285
4a2 4a9 :2 0 4c2
41 :3 0 52 :3 0
4ab 4ac 0 43
:4 0 a2 :4 0 46
:2 0 9 :3 0 a3
:3 0 4b1 4b2 0
288 4b0 4b4 :3 0
46 :2 0 84 :4 0
28b 4b6 4b8 :3 0
46 :2 0 9 :3 0
a4 :3 0 4bb 4bc
0 28e 4ba 4be
:3 0 291 4ad 4c0
:2 0 4c2 294 4c3
49f 4c2 0 4c4
297 0 4d4 a5
:3 0 3d :3 0 9
:3 0 a3 :3 0 a6
:3 0 9 :3 0 a4
:3 0 3 :3 0 a7
:4 0 a8 1 :a 0
4d0 :2 0 4d4 4c6
4ce :2 0 8 :3 0
3d :3 0 4d2 :2 0
4d4 299 4d6 29d
4d5 4d4 :2 0 52a
73 :3 0 9 :3 0
70 :3 0 4d9 4da
0 71 :3 0 4db
4dc 0 522 3e
:3 0 3f :3 0 4de
4df 0 3e :3 0
4f :3 0 4e1 4e2
0 74 :2 0 2
:4 0 a9 :2 0 51
:2 0 13 :2 0 29f
4e7 4e9 :3 0 2a2
4e3 4eb 4e0 4ed
4ec :2 0 41 :3 0
52 :3 0 4ef 4f0
0 43 :4 0 aa
:4 0 46 :2 0 47
:3 0 2a6 4f4 4f6
:3 0 2a9 4f1 4f8
:2 0 512 41 :3 0
52 :3 0 4fa 4fb
0 43 :4 0 78
:4 0 46 :2 0 71
:3 0 2ac 4ff 501
:3 0 46 :2 0 79
:4 0 2af 503 505
:3 0 46 :2 0 7a
:3 0 7b :3 0 13
:2 0 7c :2 0 2b2
508 50c 2b6 507
50e :3 0 2b9 4fc
510 :2 0 512 2bc
513 4ee 512 0
514 2bf 0 522
a5 :3 0 3d :3 0
a6 :3 0 9 :3 0
a4 :3 0 3 :3 0
a7 :4 0 ab 1
:a 0 51e :2 0 522
516 51c :2 0 8
:3 0 3d :3 0 520
:2 0 522 2c1 525
:3 0 525 0 525
524 522 523 :6 0
527 1 :3 0 2c6
529 2c8 528 527
:2 0 52a 2ca :2 0
52c 2cd 52c 52b
48b 52a :6 0 52d
:2 0 2 14 52c
530 :3 0 52f 52d
531 :8 0 
2f9
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
42 1 40 1
47 1 4c 1
51 1 56 1
5b 1 60 1
65 1 6c 1
6a 1 71 1
77 1 7d 1
83 1 89 1
8f 1 94 1
9b 1 99 1
a0 1 a6 1
ac 1 b2 1
b8 1 be 1
c4 1 ca 1
d0 1 d6 1
db 1 e0 1
e6 1 ec 1
f2 1 f8 1
fd 1 103 1
109 1 10f 1
11c 1 128 2
12b 12d 2 130
132 2 134 136
2 138 13a 2
13c 13e 1 144
2 146 147 2
140 149 2 14b
14d 2 14f 151
2 153 155 2
157 159 2 15b
15d 4 124 12a
12f 15f 1 161
1 163 2 16d
16f 3 16b 16c
171 2 17a 17c
2 179 17e 1
180 1 182 2
1d9 1de 1 1e5
1 1e0 2 1f8
1fa 3 1f6 1f7
1fc 2 205 207
2 209 20b 2
20d 20f 2 211
213 2 215 217
3 21c 21d 21e
2 219 220 2
204 222 1 224
1 226 2 1ef
227 1 22b 1
1ea 2 1e8 22f
1 23a 2 236
23a 2 246 248
3 244 245 24a
2 253 255 2
257 259 2 25b
25d 1 265 2
267 268 2 25f
26a 2 26c 26e
2 270 272 2
274 276 2 278
27a 2 252 27c
1 27e 1 280
2 28a 28c 3
288 289 28e 2
297 299 2 296
29b 1 29d 1
29f 3 2a6 2a7
2a8 3 281 2a0
2aa 1 2ac 1a
2b0 2b1 2b2 2b3
2b4 2b5 2b6 2b7
2b8 2b9 2ba 2bb
2bc 2bd 2be 2bf
2c0 2c1 2c2 2c3
2c4 2c5 2c6 2c7
2c8 2c9 2 2ce
2cf 1 2d3 2
2d1 2d3 2 2de
2e0 3 2dc 2dd
2e2 2 2eb 2ed
2 2ef 2f1 2
2f3 2f5 1 2fb
2 2fd 2fe 2
2f7 300 2 302
304 2 306 308
2 30a 30c 2
30e 310 2 2ea
312 1 314 1
316 2 320 322
3 31e 31f 324
2 32d 32f 2
32c 331 1 333
1 335 2 33b
33c 3 33e 33f
340 3 317 336
342 2 348 349
1 34d 2 34b
34d 2 355 35a
1 361 1 35c
2 374 376 3
372 373 378 2
381 383 2 385
387 2 389 38b
2 38d 38f 2
391 393 3 398
399 39a 2 395
39c 2 380 39e
1 3a0 1 3a2
2 36b 3a3 1
3a7 1 366 2
364 3ab 2 3b1
3b2 2 3b7 3b8
1 3ba 2 3b4
3ba 1 3c5 2
3c4 3c5 1 3cd
1 3d3 2 3d5
3d6 2 3c2 3d7
1 3de 1 3d9
2 3f1 3f3 3
3ef 3f0 3f5 2
3fe 400 2 402
404 2 406 408
2 40a 40c 2
40e 410 3 415
416 417 2 412
419 2 3fd 41b
1 41d 1 41f
2 3e8 420 1
424 1 3e3 2
3e1 428 1 42b
1 42e 2 3ae
42f 1 431 1
435 3 346 432
438 2 43a 43b
2 445 447 3
443 444 449 2
452 454 2 456
458 2 45a 45c
1 464 2 466
467 2 45e 469
2 46b 46d 2
46f 471 2 473
475 2 477 479
2 451 47b 1
47d 1 47f 3
486 487 488 d
164 183 186 189
18c 18f 192 232
2ad 2cc 43c 480
48a 2 497 499
3 495 496 49b
2 4a4 4a6 2
4a3 4a8 2 4af
4b3 2 4b5 4b7
2 4b9 4bd 2
4ae 4bf 2 4aa
4c1 1 4c3 3
4c4 4cf 4d3 1
48e 2 4e6 4e8
3 4e4 4e5 4ea
2 4f3 4f5 2
4f2 4f7 2 4fe
500 2 502 504
3 509 50a 50b
2 506 50d 2
4fd 50f 2 4f9
511 1 513 4
4dd 514 51d 521
1 525 1 4d8
2 4d6 529 2b
1b 22 29 30
37 3e 45 4a
4f 54 59 5e
63 68 6f 75
7b 81 87 8d
92 97 9e a4
aa b0 b6 bc
c2 c8 ce d4
d9 de e4 ea
f0 f6 fb 101
107 10d 114 
1
4
0 
530
0
1
14
8
2f
0 1 2 1 4 1 6 1
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
2 0 1
83 1 0
be 1 0
3 1 0
f2 1 0
56 1 0
16 1 0
ec 1 0
1d 1 0
b2 1 0
a0 1 0
40 1 0
d0 1 0
94 1 0
c4 1 0
109 1 0
60 1 0
71 1 0
47 1 0
51 1 0
e0 1 0
7d 1 0
b8 1 0
99 1 0
db 1 0
89 1 0
e6 1 0
32 1 0
f8 1 0
4c 1 0
fd 1 0
6a 1 0
8f 1 0
65 1 0
39 1 0
2b 1 0
7 1 0
d6 1 0
ca 1 0
5b 1 0
24 1 0
77 1 0
ac 1 0
a6 1 0
10f 1 0
103 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_ASSIGN;
ALTER FUNCTION SP_ACPT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST DATES
    3 - ETC + FORECAST DATES
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ec
2 :e:
1FUNCTION:
1SP_ACPT_ETC_WBS:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PRJ_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_RANK:
1200:
1H_REC_USER:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FINISH_D:
1DATE:
1H_WEEK_OF:
1H_LAST_SUBMITTED:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
1H_BITFLAG:
10:
1H_CONTOUR:
1H_EFFORT:
1H_REMAINING:
1H_TOTAL:
1H_TYPE:
1H_PASSED:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_ETC:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_NOT_EFFORT_PA:
1H_FF_FLAG:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1CAWTSK:
1PROJECT_ID:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1COALESCE:
1PLANNED_START:
1SCHED_START:
1FORECAST_FINISH:
1PLANNED_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT PROJECT_ID, ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WH+
1EN FORECAST_START IS NULL THEN COALESCE(PLANNED_START, SCHED_START) ELSE FORE+
1CAST_START END,:n         CASE WHEN FORECAST_FINISH IS NULL THEN COALESCE(PLA+
1NNED_FINISH, SCHED_FINISH) ELSE FORECAST_FINISH END:n         FROM TMT_WBS WH+
1ERE RANK LIKE h_rank AND TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,+
1pmo_cnst.SC_TASK_TYPE2,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.+
1SC_PERSONAL_TASK,pmo_cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pm+
1o_cnst.SC_WBS_CHANGE_REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.S+
1C_WBS_RISK_TASK,pmo_cnst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,p+
1mo_cnst.SC_WBS_DEFECT_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK):n         AN+
1D (((SCHED_EFFORT+PLANNED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_+
1TODATE) <> ETC)) OR:n         (FORECAST_START IS NOT NULL OR FORECAST_FINISH +
1IS NOT NULL)) ORDER BY COALESCE(PLANNED_START, SCHED_START):
1CAWASS:
1TSK_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT:n         TSK_ASSIGNMENT_ID,:n         PROJECT_ASSIGNMENT_ID,:n       +
1  SCHED_WORK+PLANNED_WORK,:n         FORECAST_START,:n         FORECAST_FINIS+
1H,:n         CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE E+
1TC END,:n         SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n         ETC,:n    +
1     C_CONTOUR,:n         LAST_SUBMITTED,:n         CASE WHEN FORECAST_FINISH+
1 IS NOT NuLL AND FORECAST_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(+
1PLANNED_START, SCHED_START) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1+
1 ELSE 0 END,:n         UNRESOLVED_START,:n         UNRESOLVED_FINISH,:n      +
1   BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COST,:n         REG+
1ULAR_RATE,:n         BIT_FLAG,:n         MILESTONE_PERCENT,:n         RESOURC+
1E_ID,:n         RESOURCE_TYPE,:n         WORK_TODATE:n         FROM TASK_ASSI+
1GNMENTS:n         WHERE PROJECT_ID = h_project_id:n         AND TASK_ID = h_t+
1ask_id:n         AND (((SCHED_WORK+PLANNED_WORK) > 0:n         AND ((SCHED_WO+
1RK + PLANNED_WORK - WORK_TODATE) <> ETC)):n         OR (FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_WBS(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1106:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_WBS(107) :: cplan.sql(20329) :: :
1RTRIM:
1SELECT RTRIM(RANK), TYPE_ID INTO h_rank, h_type:n      FROM TMT_WBS WHERE ELE+
1MENT_ID = id/*HOST(h_id)*/:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1125:
1           EXCEPTION:: SP_ACPT_ETC_WBS(126) :: cplan.sql(20348) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FC_ACPT_DURATION:
1FC_ACPT_EFFORT:
1ELSIF:
1CANNOT_ACCEPT_FROM_PROJECT_AFF:
1CLOSE:
1232:
1           EXCEPTION:: SP_ACPT_ETC_WBS(233) :: cplan.sql(20455) :: :
1>:
1CONSTRAINT_DT:
1CONSTRAINT_TYPE:
1SELECT CONSTRAINT_DT, CONSTRAINT_TYPE, FORECAST_START, FORECAST_FINISH:n     +
1             INTO h_constr_DT, h_constr_type, h_start_DT, h_finish_DT:n      +
1            FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_t+
1ask_id:
1256:
1           EXCEPTION:: SP_ACPT_ETC_WBS(257) :: cplan.sql(20479) :: :
1TO_DATE:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (1,2,3,4) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN h+
1_finish_DT:n                        WHEN h_constr_type IN (0,5,6,7) THEN h_fi+
1nish_DT:n                        ELSE h_constr_DT:n                        EN+
1D,:n                        CONSTRAINT_TYPE =:n                        CASE:n+
1                        WHEN h_constr_type IN (1,2,3,4) AND TO_DATE(SubStr(h_+
1constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN 2:n            +
1            WHEN h_constr_type IN (0,5,6,7) THEN 2:n                        E+
1LSE h_constr_type:n                        END:n                        WHERE+
1 PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1292:
1           EXCEPTION:: SP_ACPT_ETC_WBS(293) :: cplan.sql(20515) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_finish_DT, CONSTRAINT_TYPE = 2:n        +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1312:
1           EXCEPTION:: SP_ACPT_ETC_WBS(313) :: cplan.sql(20535) :: :
1IS NULL:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (0,5,6,7) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN h_+
1start_DT:n                        WHEN h_constr_type IN (1,2,3,4) THEN h_star+
1t_DT:n                        ELSE h_constr_DT:n                        END,+
1:n                        CONSTRAINT_TYPE =:n                        CASE:n  +
1                      WHEN h_constr_type IN (0,5,6,7) AND TO_DATE(SubStr(h_co+
1nstr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN 6:n               +
1         WHEN h_constr_type IN (1,2,3,4) THEN 6:n                        ELSE+
1 h_constr_type:n                        END:n                        WHERE PR+
1OJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1347:
1           EXCEPTION:: SP_ACPT_ETC_WBS(348) :: cplan.sql(20570) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_start_DT, CONSTRAINT_TYPE = 6:n         +
1               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1367:
1           EXCEPTION:: SP_ACPT_ETC_WBS(368) :: cplan.sql(20590) :: :
1388:
1           EXCEPTION:: SP_ACPT_ETC_WBS(389) :: cplan.sql(20611) :: :
1NLEN:
1LENGTH:
1NOT:
1MOD:
14:
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1INVALID_RANK_LIKE:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PROPOSED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PROP+
1OSED_BIT):n            WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank:
1425:
1           EXCEPTION:: SP_ACPT_ETC_WBS(426) :: cplan.sql(20648) :: :
1FC_ROLLUP:
1442:
1       RETURN_STATUS:: SP_ACPT_ETC_WBS(443) :: cplan.sql(20665) :: :
1STATE:: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1449:
1           EXCEPTION:: SP_ACPT_ETC_WBS(450) :: cplan.sql(20672) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1461:
1           EXCEPTION:: SP_ACPT_ETC_WBS(462) :: cplan.sql(20684) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
930
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :3b a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :30 a0 12a bd
b7 11 a4 b1 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d a0 51 d :8 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 7e b4 2e :2 5a a 10 :3 a0
7e 6e b4 2e :2 51 a5 b d
a0 7e 51 b4 2e d :2 a0 e9
dd b3 :7 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d :7 a0 a5 b
d :2 a0 6b a0 d :3 a0 51 a5
b 7e 51 b4 2e d b7 19
3c b7 a0 4d d a0 4d d
:2 a0 e9 dd b3 :18 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :1c a0 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e 51 b4 2e
d a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :3 a0 51 a5
b 7e 51 b4 2e d b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 4d d a0 4d
d :d a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
a0 7e b4 2e 5a :1b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :8 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 b7 a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a a 10 a0
7e b4 2e 5a :1b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c b7 19 3c b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e 5a a 10 a3 a0 1c
51 81 b0 a0 7e b4 2e 5a
:4 a0 a5 b 51 a5 b d 51
7e 51 b4 2e a0 7e 51 b4
2e a 10 :2 a0 7e 51 b4 2e
d b7 19 3c b7 19 3c a0
7e 51 b4 2e 7e b4 2e :2 a0
7e 51 b4 2e 5a 7e 51 b4
2e 52 10 :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 a4 b1
11 4f :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 a5 b d b7 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 51 a5
b d b7 :2 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
930
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 12e 101 14b 13a 13e
146 121 167 156 15a 162 11e 17f
16e 172 17a 155 19b 18a 18e 196
152 1b3 1a2 1a6 1ae 189 1cf 1be
1c2 1ca 186 1e7 1d6 1da 1e2 1bd
203 1f2 1f6 1fe 1ba 21f 20a 20e
211 212 21a 1f1 23c 22a 1ee 22e
22f 237 229 259 247 226 24b 24c
254 246 275 264 268 243 270 263
291 280 284 260 28c 27f 2ad 29c
2a0 27c 2a8 29b 2c9 2b8 2bc 298
2c4 2b7 2e5 2d4 2d8 2b4 2e0 2d3
301 2f0 2f4 2d0 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 334
308 351 340 344 34c 327 36e 35c
324 360 361 369 35b 38a 379 37d
358 385 378 3a6 395 399 375 3a1
394 3c2 3b1 3b5 391 3bd 3b0 3de
3cd 3d1 3ad 3d9 3cc 3fa 3e9 3ed
3c9 3f5 3e8 416 405 409 411 3e5
42e 41d 421 429 404 44a 439 43d
401 445 438 466 455 459 435 461
454 482 471 475 451 47d 470 49e
48d 491 46d 499 48c 4ba 4a9 4ad
489 4b5 4a8 4d6 4c5 4c9 4d1 4a5
4ee 4dd 4e1 4e9 4c4 50a 4f9 4fd
4c1 505 4f8 526 515 519 4f5 521
514 542 531 535 511 53d 530 55e
54d 551 52d 559 54c 57a 569 56d
549 575 568 596 585 589 591 565
5b1 59d 5a1 5a9 5ac 584 5b8 5bc
581 5cd 5d0 5d4 5d8 5dc 5e0 5e4
5e8 5ec 5f0 5f4 5f8 5fc 600 604
608 60c 610 614 618 61c 620 624
628 62c 630 634 638 63c 640 644
648 64c 650 654 658 65c 660 664
668 66c 670 674 678 67c 680 684
688 68c 690 694 698 69c 6a0 6a4
6a8 6ac 6b0 6b4 6b8 6bc 6c0 6cc
6d1 6d3 6df 6e3 6e5 6e9 6fa 6fb
6fe 702 706 70a 70e 712 716 71a
71e 722 726 72a 72e 732 736 73a
73e 742 746 74a 74e 752 756 75a
75e 762 766 76a 76e 772 776 77a
77e 782 786 78a 78e 792 796 79a
79e 7a2 7a6 7aa 7ae 7b2 7b6 7ba
7be 7c2 7ce 7d3 7d5 7e1 7e5 803
7eb 7ef 7f3 7f6 7fe 7ea 80a 80e
7e7 812 816 81a 81d 822 823 1
825 82a 82e 832 835 83a 83e 842
845 84a 84b 84d 852 855 859 85a
85f 864 867 86c 86d 872 875 879
87a 87f 882 887 888 88d 890 895
896 89b 89e 8a2 8a6 8aa 8ab 8ad
8b2 8b3 8b5 8b6 8bb 8be 8c3 8c4
8c9 8cc 8d1 8d2 8d7 8da 8de 8df
8e4 8e7 8ec 8ed 8f2 8f5 8fa 8fb
900 901 906 908 90c 90f 913 917
91a 91e 922 925 928 92d 930 933
936 937 93c 93d 1 93f 944 948
94c 94f 954 959 95c 960 961 966
967 96c 96e 972 975 979 97d 981
985 989 98d 991 994 998 99c 9a0
9a4 9a8 9ac 9b0 9b4 9b8 9c4 9c8
9cc 9cf 9d3 9d7 9d9 9dd 9e1 9e5
9e8 9ec 9f0 9f2 9f3 9f8 1 9fc
a00 a04 a07 a0b a0f a13 a17 a1a
a1e a22 a25 a28 a2d a30 a33 a36
a37 a3c a3d 1 a3f a44 a48 a4c
a4f a54 a59 a5c a60 a61 a66 a69
a6e a6f a74 a77 a7c a7d a82 a85
a89 a8a a8f a92 a97 a98 a9d aa0
aa4 aa8 aab aae aaf ab1 ab2 ab7
ab8 abd abf ac3 ac6 ac8 acc ace
ada adc ade adf ae4 ae8 aea af6
af8 afc b00 b03 b07 b0a b0e b11
b12 b17 b1a b1e b21 b22 b27 b2a
1 b2d b32 b36 b3a b3e b41 b46
b47 b4c b4f b52 b53 b55 b59 b5d
b60 b63 b64 b69 b6d b71 b75 b7a
b7e b7f b83 b87 b8b b8f b93 b97
b9b ba0 ba5 ba9 bad bb1 bb6 bba
bbe bc1 bc4 bc8 bca bce bd2 bd5
bd8 bdc bde be2 be6 be9 bed bf1
bf4 bf8 bfb bff c02 c03 c08 c0b
c0f c15 c17 c1b c1e c22 c26 c29
c2a c2c c2f c32 c33 c38 c3c c40
c43 c44 c46 c49 c4c c4d c52 c56
c5a c5e c61 c65 c69 c6d c71 c75
c79 c7d c81 c82 c84 c88 c8c c90
c93 c97 c9b c9f ca3 ca7 caa cab
cad cb0 cb3 cb4 cb9 cbd cbf cc3
cc6 cc8 ccc ccd cd1 cd5 cd6 cda
cde ce2 ce7 ceb cec cf0 cf4 cf8
cfc d00 d04 d08 d0c d10 d14 d18
d1c d20 d24 d28 d2c d30 d34 d38
d3c d40 d44 d48 d4c d51 d56 d5a
d5e d62 d67 d6b d6f d72 d75 d79
d7b d7f d83 d86 d89 d8d d8f d93
d97 d9a d9e da2 da5 da9 dac db0
db3 db4 db9 dbc dc0 dc6 dc8 dcc
dcf dd3 dd7 ddb ddf de3 de7 deb
def df3 df7 dfb dff e03 e07 e0b
e0f e13 e17 e1b e1f e23 e27 e2b
e2f e33 e37 e3b e3f e40 e42 e46
e4a e4e e51 e52 e54 e57 e5a e5b
e60 e64 e68 e6c e6f e70 e72 e75
e78 e79 e7e e82 e86 e88 e8c e90
e93 e94 e96 e9a e9d ea1 ea4 ea5
eaa eae eb2 eb6 eb9 eba ebc ebf
ec2 ec3 ec8 ecc ece ed2 ed6 ed9
edb edf ee6 eea eee ef3 ef5 ef9
efd f00 f04 f08 f0a f0e f12 f16
f19 f1d f21 f23 f24 f29 1 f2d
f31 f35 f38 f3c f40 f44 f48 f4b
f4f f53 f56 f59 f5e f61 f64 f67
f68 f6d f6e 1 f70 f75 f79 f7d
f80 f85 f8a f8d f91 f92 f97 f9a
f9f fa0 fa5 fa8 fad fae fb3 fb6
fba fbb fc0 fc3 fc8 fc9 fce fd1
fd5 fd9 fdc fdf fe0 fe2 fe3 fe8
fe9 fee ff0 ff4 ff7 ff9 ffd fff
100b 100d 100f 1010 1015 1019 101b 1027
1029 102d 1031 1034 1035 1037 103a 103d
103e 1043 1046 104a 104e 1051 1052 1054
1057 105a 105b 1060 1 1063 1068 106c
106d 1071 1075 1076 107a 107e 1082 1086
108a 108e 1092 1096 109a 109e 10a2 10a6
10aa 10ae 10ba 10be 10c2 10c5 10c9 10cd
10cf 10d3 10d7 10db 10de 10e2 10e6 10e8
10e9 10ee 1 10f2 10f6 10fa 10fd 1101
1105 1109 110d 1110 1114 1118 111b 111e
1123 1126 1129 112c 112d 1132 1133 1
1135 113a 113e 1142 1145 114a 114f 1152
1156 1157 115c 115f 1164 1165 116a 116d
1172 1173 1178 117b 117f 1180 1185 1188
118d 118e 1193 1196 119a 119e 11a1 11a4
11a5 11a7 11a8 11ad 11ae 11b3 11b5 11b9
11bc 11be 11c2 11c4 11d0 11d2 11d4 11d5
11da 11de 11e0 11ec 11ee 11f2 11f5 11f6
11fb 11fe 1202 1205 1206 120b 120e 1212
1216 121a 121e 1222 1226 122a 122e 1232
1236 123a 123e 1242 1246 124a 124e 1252
1256 125a 125e 1262 1266 126a 126e 1272
1276 127a 1286 128a 128f 1293 1296 1297
129c 12a0 12a4 12a7 12aa 12ae 12b0 12b4
12b8 12bb 12be 12c2 12c4 12c8 12cc 12cf
12d1 12d5 12d9 12dd 12e0 12e4 12e8 12ea
12eb 12f0 1 12f4 12f8 12fc 12ff 1303
1307 130b 130f 1312 1316 131a 131d 1320
1325 1328 132b 132e 132f 1334 1335 1
1337 133c 1340 1344 1347 134c 1351 1354
1358 1359 135e 1361 1366 1367 136c 136f
1374 1375 137a 137d 1381 1382 1387 138a
138f 1390 1395 1398 139c 13a0 13a3 13a6
13a7 13a9 13aa 13af 13b0 13b5 13b7 13bb
13be 13c0 13c4 13c6 13d2 13d4 13d6 13d7
13dc 13e0 13e2 13ee 13f0 13f2 13f6 13fa
13fe 1402 1406 140a 140e 1412 141e 1422
1427 142b 142e 142f 1434 1438 143c 143f
1442 1446 1448 144c 1450 1453 1456 145a
145c 1460 1464 1467 1469 146d 1471 1475
1478 147c 1480 1482 1483 1488 1 148c
1490 1494 1497 149b 149f 14a3 14a7 14aa
14ae 14b2 14b5 14b8 14bd 14c0 14c3 14c6
14c7 14cc 14cd 1 14cf 14d4 14d8 14dc
14df 14e4 14e9 14ec 14f0 14f1 14f6 14f9
14fe 14ff 1504 1507 150c 150d 1512 1515
1519 151a 151f 1522 1527 1528 152d 1530
1534 1538 153b 153e 153f 1541 1542 1547
1548 154d 154f 1553 1556 1558 155c 155e
156a 156c 156e 156f 1574 1578 157a 1586
1588 158a 158e 1592 1595 1599 159b 159f
15a2 15a3 15a8 15ab 15ae 15b2 15b5 15b6
15bb 15be 1 15c1 15c6 15ca 15cd 15ce
15d3 15d6 15da 15de 15e2 15e6 15ea 15ee
15f2 15f6 15fa 15fe 1602 1606 160a 160e
1612 1616 161a 161e 1622 1626 162a 162e
1632 1636 163a 163e 1642 164e 1652 1657
165b 165e 165f 1664 1668 166c 166f 1672
1676 1678 167c 1680 1683 1686 168a 168c
1690 1694 1697 1699 169d 16a1 16a5 16a8
16ac 16b0 16b2 16b3 16b8 1 16bc 16c0
16c4 16c7 16cb 16cf 16d3 16d7 16da 16de
16e2 16e5 16e8 16ed 16f0 16f3 16f6 16f7
16fc 16fd 1 16ff 1704 1708 170c 170f
1714 1719 171c 1720 1721 1726 1729 172e
172f 1734 1737 173c 173d 1742 1745 1749
174a 174f 1752 1757 1758 175d 1760 1764
1768 176b 176e 176f 1771 1772 1777 1778
177d 177f 1783 1786 1788 178c 178e 179a
179c 179e 179f 17a4 17a8 17aa 17b6 17b8
17ba 17be 17c2 17c6 17ca 17ce 17d2 17d6
17da 17e6 17ea 17ef 17f3 17f6 17f7 17fc
1800 1804 1807 180a 180e 1810 1814 1818
181b 181e 1822 1824 1828 182c 182f 1831
1835 1839 183d 1840 1844 1848 184a 184b
1850 1 1854 1858 185c 185f 1863 1867
186b 186f 1872 1876 187a 187d 1880 1885
1888 188b 188e 188f 1894 1895 1 1897
189c 18a0 18a4 18a7 18ac 18b1 18b4 18b8
18b9 18be 18c1 18c6 18c7 18cc 18cf 18d4
18d5 18da 18dd 18e1 18e2 18e7 18ea 18ef
18f0 18f5 18f8 18fc 1900 1903 1906 1907
1909 190a 190f 1910 1915 1917 191b 191e
1920 1924 1926 1932 1934 1936 1937 193c
1940 1942 194e 1950 1952 1956 195a 195d
195f 1963 1967 196a 196c 1970 1973 1975
1979 197d 1980 1982 1986 198d 1991 1995
199a 199c 19a0 19a4 19a7 19ab 19af 19b1
19b5 19b9 19bd 19c0 19c4 19c8 19ca 19cb
19d0 1 19d4 19d8 19dc 19df 19e3 19e7
19eb 19ef 19f2 19f6 19fa 19fd 1a00 1a05
1a08 1a0b 1a0e 1a0f 1a14 1a15 1 1a17
1a1c 1a20 1a24 1a27 1a2c 1a31 1a34 1a38
1a39 1a3e 1a41 1a46 1a47 1a4c 1a4f 1a54
1a55 1a5a 1a5d 1a61 1a62 1a67 1a6a 1a6f
1a70 1a75 1a78 1a7c 1a80 1a83 1a86 1a87
1a89 1a8a 1a8f 1a90 1a95 1a97 1a9b 1a9e
1aa0 1aa4 1aa6 1ab2 1ab4 1ab6 1ab7 1abc
1ac0 1ac2 1ace 1ad0 1ad4 1ad8 1adb 1adc
1ade 1ae1 1ae4 1ae5 1aea 1aed 1af1 1af5
1af8 1af9 1afb 1afe 1b01 1b04 1b05 1b0a
1b0b 1b10 1 1b13 1b30 1b1c 1b20 1b28
1b2b 1b1b 1b37 1b18 1b3b 1b3c 1b41 1b44
1b48 1b4c 1b50 1b54 1b55 1b57 1b5a 1b5b
1b5d 1b61 1b64 1b67 1b6a 1b6b 1b70 1b74
1b77 1b7a 1b7b 1 1b80 1b85 1b89 1b8d
1b90 1b93 1b94 1b99 1b9d 1b9f 1ba3 1ba6
1ba8 1bac 1baf 1bb3 1bb6 1bb9 1bba 1bbf
1bc2 1bc3 1bc8 1bcc 1bd0 1bd3 1bd6 1bd7
1bdc 1bdf 1be2 1be5 1be6 1 1beb 1bf0
1bf4 1bf8 1bfb 1bff 1c03 1c06 1c0a 1c0e
1c0f 1c14 1c16 1c1a 1c1d 1c1f 1c23 1c25
1c31 1c33 1c37 1c3b 1c3f 1c43 1c47 1c4b
1c4f 1c53 1c57 1c5b 1c5f 1c6b 1c6f 1c74
1c78 1c7b 1c7c 1c81 1c85 1c89 1c8c 1c8f
1c93 1c95 1c99 1c9d 1ca0 1ca3 1ca7 1ca9
1cad 1cb1 1cb4 1cb6 1cba 1cbe 1cc2 1cc5
1cc9 1ccd 1ccf 1cd0 1cd5 1 1cd9 1cdd
1ce1 1ce4 1ce8 1cec 1cf0 1cf4 1cf7 1cfb
1cff 1d02 1d05 1d0a 1d0d 1d10 1d13 1d14
1d19 1d1a 1 1d1c 1d21 1d25 1d29 1d2c
1d31 1d36 1d39 1d3d 1d3e 1d43 1d46 1d4b
1d4c 1d51 1d54 1d59 1d5a 1d5f 1d62 1d66
1d67 1d6c 1d6f 1d74 1d75 1d7a 1d7d 1d81
1d85 1d88 1d8b 1d8c 1d8e 1d8f 1d94 1d95
1d9a 1d9c 1da0 1da3 1da5 1da9 1dab 1db7
1db9 1dbb 1dbc 1dc1 1dc5 1dc7 1dd3 1dd5
1dd9 1ddd 1de1 1de2 1de4 1de8 1dea 1dee
1df1 1df3 1df7 1dfa 1dfe 1e02 1e05 1e06
1e08 1e0b 1e0e 1e0f 1e14 1e18 1e1c 1e1f
1e23 1e27 1e2a 1e2e 1e32 1e34 1e38 1e3c
1e3f 1e40 1e42 1e45 1e48 1e49 1e4e 1e52
1e56 1e59 1e5d 1e61 1e64 1e65 1e67 1e6b
1e6d 1e71 1e75 1e78 1e7c 1e80 1e83 1e87
1e8b 1e8e 1e91 1e96 1e99 1e9c 1e9f 1ea0
1ea5 1ea6 1 1ea8 1ead 1eb1 1eb5 1eb8
1ebd 1ec2 1ec5 1ec9 1eca 1ecf 1ed2 1ed7
1ed8 1edd 1ee0 1ee5 1ee6 1eeb 1eee 1ef2
1ef6 1efa 1efe 1f01 1f02 1f04 1f09 1f0a
1f0c 1f0d 1f12 1f15 1f1a 1f1b 1f20 1f23
1f28 1f29 1f2e 1f31 1f35 1f36 1f3b 1f3e
1f43 1f44 1f49 1f4a 1f4f 1f51 1f55 1f58
1f5c 1f60 1f63 1f67 1f6b 1f6e 1f72 1f76
1f77 1f7c 1f7e 1f82 1f86 1f89 1f8d 1f91
1f94 1f98 1f9c 1f9f 1fa2 1fa7 1faa 1fad
1fb0 1fb1 1fb6 1fb7 1 1fb9 1fbe 1fc2
1fc6 1fc9 1fce 1fd3 1fd6 1fda 1fdb 1fe0
1fe1 1fe6 1fea 1fee 1ff1 1ff6 1ffb 1ffe
2002 2006 2009 200a 200f 2012 2017 2018
201d 2020 2024 2028 202b 202c 2031 2032
2037 2039 203d 2040 2044 2048 204c 2050
2054 2058 205c 2060 2064 2070 2075 2079
207d 2081 2085 2087 2088 208d 1 2091
2095 2099 209c 20a0 20a4 20a8 20ac 20af
20b3 20b7 20ba 20bd 20c2 20c5 20c8 20cb
20cc 20d1 20d2 1 20d4 20d9 20dd 20e1
20e4 20e9 20ee 20f1 20f5 20f6 20fb 20fc
2101 2105 2109 210c 2111 2116 2119 211d
211e 2123 2126 212b 212c 2131 2134 2138
213c 213f 2142 2143 2145 2146 214b 214c
2151 2153 2157 215a 215e 2162 2166 216a
216e 2172 2176 2182 2187 218b 218f 2193
2197 2199 219d 219f 21ab 21ad 21af 21b0
21b5 21b9 21bb 21c7 21cb 21cd 21ce 21d7 
930
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 b 14 13 :2 b :2 4
f 18 17 :2 f :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :3 12
:2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f
:2 4 :3 10 :2 4 :3 f :2 4 :3 e :2 4 :3 15
:2 4 e 17 16 :2 e :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
:2 e 1d e :2 4 :2 e 1d e :2 4
:2 d 1c d :2 4 :2 10 1f 10 :2 4
:2 c 1b c :2 4 :2 b 1a b :2 4
:2 d 1c d :2 4 :3 10 :2 4 :3 10 :2 4
12 1b 1a :2 12 :2 4 :2 d 1c d
:2 4 :2 12 21 12 :2 4 :2 a 19 a
:2 4 :2 f 1e f :2 4 :2 14 23 14
:2 4 :3 12 :2 4 :3 13 :2 4 :2 11 20 11
:2 4 :2 12 21 12 :2 4 :2 13 22 13
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :3 9 :2 4 :3 9 :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 11 20 11
:2 4 :2 14 23 14 :2 4 :2 e 1d e
:2 4 :3 10 :2 4 :2 16 2e 16 4 7
e 0 :2 7 11 1d 29 36 14
30 39 48 5a 14 31 3a 4a
5d f 1d 27 32 3e 47 4f
58 66 6f 7d 86 94 9d aa
b3 c4 cd e0 e9 fe 107 122
12b 143 14c 15d 166 178 181 199
1a2 1b5 1be 11 1e 38 45 54
64 b 29 50 59 68 a :6 7
e 0 :2 7 :3 a 15 :2 a 14 26
49 a 15 24 :3 a 14 34 4f
67 70 7f 90 99 a9 :b a f
10 1d e 18 11 1c 10 1d
2c 3c e 2c fffa :5 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
57 5d 60 :2 57 6e 87 8 :2 6e
d 10 :2 6e 13 16 :2 6e b e
:2 6e 13 16 1f 27 :2 1f 34 :2 16
:2 6e b e :2 6e 13 16 :2 6e 1b
1e :2 6e 2a 2d :2 6e 32 35 :2 6e
:2 7 4d :2 4 7 :2 11 23 :2 2d 39
3c 4f 52 53 :2 4f :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :2 7 56 :3 4
11 :2 4 12 :2 4 17 4 e 14
1b 28 30 c 1a 27 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 56 59 5a
:2 56 :2 29 :3 d :2 13 18 24 67 6a
:2 24 77 7a :2 24 7e 81 :2 24 8d
90 :2 24 98 9b :2 24 a7 aa b1
ba bd :2 aa :2 24 :2 d 5d :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 :4 3b 3a 39 :3 7 11
18 1f 22 :2 18 27 2a :2 11 :2 7
13 14 :2 13 :2 7 c :4 7 10 1c
2a 35 3f 4d :3 a d 14 :2 d
:2 16 22 d 1a d :2 16 22 d
:4 a e :2 17 23 20 :2 2c :2 20 :3 d
3c :2 a d 16 20 :2 d 23 25
:2 23 10 19 24 :2 10 27 29 :2 27
10 25 :2 2e :2 10 1f 30 3e 49
57 66 :2 1f :2 10 :2 19 25 :2 10 1c
25 2f :2 1c 32 34 :2 1c 10 2b
:2 d 27 d 1d :2 d 1e :2 d 12
:4 d 16 :19 10 13 1a :2 13 :2 1c 28
13 20 13 :2 1c 28 13 :4 10 14
:2 1d 29 26 :2 32 :2 26 :3 13 42 :3 10
23 32 40 4b 60 25 33 41
50 5a 25 2c 37 49 54 25
35 41 54 25 31 3d 4d 57
25 34 3f :2 23 10 13 1c 2d
:2 13 30 32 :2 30 13 1f 28 32
:2 1f 35 37 :2 1f 13 10 34 16
1f 30 :2 16 35 33 :2 3e :2 33 13
26 2f 40 :2 26 43 45 :2 26 13
5d 34 :2 10 d 11 a 10 16
:3 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5f
62 63 :2 5f :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :3 a 11 1a
25 :2 11 28 2b :2 28 10 33 3c
46 :2 33 49 4b :2 49 32 :3 10 1e
:2 10 1f 10 1a 29 3a 4a 18
25 34 40 18 26 33 44 51
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 62
65 66 :2 62 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 4e :4 14 13
:4 17 16 20 19 1e 3d 45 4c
63 6b 72 8c 1e 3e 1e 19
1e 3d 45 4c 63 6b 72 :2 1e
1f 2c 3d 4a 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 30 20 2c 3c
49 1f 2c 3d 4a 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 68
6b 6c :2 68 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 10 2d
:4 18 17 16 :4 37 36 35 :2 16 :4 17
16 20 19 1e 3d 45 4c 63
6b 72 8b 1e 3e 1e 19 1e
3d 45 4c 63 6b 72 :2 1e 1f
2c 3d 4a 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 68 6b 6c
:2 68 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :4 30 20 2c 3c 48
1f 2c 3d 4a 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 4d 2d :2 10
4e :2 d :4 a 7 b 50 a 10
:3 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 50 b 14
1e :2 b 21 23 :2 21 a 2b 34
3e :2 2b 41 43 44 :2 43 :2 41 2a
:2 a b :2 10 1e 10 b :4 f e
c 14 1d 24 :2 1d 2d :2 14 c
f 11 14 :2 11 1a 1f 22 :2 1f
:2 f c 14 19 1b :2 14 c 24
:2 c 23 :2 b 12 17 1a :2 17 :3 e
20 :2 25 29 :2 20 1f 2c 2f :2 2c
:2 e c :2 17 2b :2 34 47 4f :2 c
31 :2 b :2 a :3 47 14 20 2e 37
3e 4a 53 13 20 31 3b d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 47
a 1d 27 :2 1d a 47 :2 7 50
:2 4 7 10 21 :2 7 24 26 :2 24
7 :2 10 1c :2 25 7 4 28 a
13 24 :2 a 27 29 :2 27 7 :2 10
1c 25 36 :2 1c 7 2d 28 :2 4
7 :2 11 23 :2 2d 39 3c 4f 52
53 :2 4f :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e ce d1 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 38 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
930
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :5 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :5 16 :7 17
:7 18 :7 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :5 21 :5 22 :7 23
:6 24 :6 25 :6 26 :6 27
:6 28 :5 29 :5 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:5 30 :5 31 :6 32 :6 33
:6 34 :6 35 :6 36 :5 37
:6 38 :2 3a 0 :2 3a
:4 3b :5 3c :5 3d :22 3e
:6 3f :5 40 3b :5 3a
:2 42 0 :2 42 44
45 :2 46 47 48
:3 49 :3 4a 4b 4c
4d :9 4e 4f 50
51 52 53 54
55 56 57 58
59 5a :2 5b :2 5c
:2 5d :4 5e :2 5f 44
:5 42 :7 61 :b 63 :11 64
65 :2 64 :2 65 :2 64
:2 65 :2 64 :2 66 :2 64
:9 66 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :4 64
:3 63 :11 6a :b 6b :3 6a
:3 6f :3 70 :3 71 :5 74
:3 75 74 :5 76 73
78 :5 79 :3 78 :2 7a
:5 7c :11 7d :24 7e :3 7d
:2 7b :6 7a 77 :3 62
:12 83 :c 84 :6 85 :5 89
8b :9 8c :3 8d :5 8e
8d :5 90 8f :3 8d
:a 93 :2 94 :3 93 :9 99
:9 9b :5 9d :a 9e :5 9f
:b a1 :3 9b 99 :3 a5
:3 a7 :5 aa ac ad
ae af b0 b1
b2 b3 b4 b5
b6 b7 b8 b9
ba bb bc bd
be bf c0 c1
c2 c3 :3 ad :3 c4
:5 c5 c4 :5 c7 c6
:3 c4 :a ca :2 cb :3 ca
:6 d0 :5 d1 :5 d2 :4 d3
:5 d4 :3 d5 :3 d0 :9 d7
:b d8 d9 d7 :b d9
:b da d9 :3 d7 ac
dc a3 :4 e0 :5 e1
df e3 :5 e4 :3 e3
:2 e5 :5 e7 :11 e8 :24 e9
:3 e8 :2 e6 :6 e5 e2
:3 a3 :16 f1 :3 f2 :3 f3
:4 f6 :4 f7 :5 f8 f6
:5 f9 f5 fb :5 fc
:3 fb :2 fd :5 ff :11 100
:24 101 :3 100 :2 fe :6 fd
fa :3 f1 :5 107 :5 109
10b 10c :8 10e :2 10f
110 112 :7 114 115
116 :4 118 10b :6 119
:5 11a 119 :5 11c 11b
:3 119 10a 11f :5 120
:3 11f :2 121 :5 123 :11 124
:24 125 :3 124 :2 122 :6 121
11e :4 109 :4 12b :4 12c
12b :6 12d :5 12e 12d
:5 130 12f :3 12d 12a
133 :5 134 :3 133 :2 135
:5 137 :11 138 :24 139 :3 138
:2 136 :6 135 132 :4 129
:3 109 13e 107 :e 13e
:5 140 142 143 :8 145
:2 146 147 149 :7 14b
14c 14d :4 14f 142
:6 150 :5 151 150 :5 153
152 :3 150 141 156
:5 157 :3 156 :2 158 :5 15a
:11 15b :24 15c :3 15b :2 159
:6 158 155 :4 140 :4 162
:4 163 162 :6 164 :5 165
164 :5 167 166 :3 164
161 16a :5 16b :3 16a
:2 16c :5 16e :11 16f :24 170
:3 16f :2 16d :6 16c 169
:4 160 :3 140 13e :3 107
:3 f1 a3 :3 99 8b
178 83 :4 17c :5 17d
17b 17f :5 180 :3 17f
:2 181 :5 183 :11 184 :24 185
:3 184 :2 182 :6 181 17e
:3 83 :19 18c :6 18e :5 190
:a 191 :c 192 :7 193 :3 192
:3 190 :15 196 :a 197 :3 196
:2 18f :3 18c :7 19c :4 19d
19c :6 19e :5 19f 19e
:5 1a1 1a0 :3 19e 19b
1a4 :5 1a5 :3 1a4 :2 1a6
:5 1a8 :11 1a9 :24 1aa :3 1a9
:2 1a7 :6 1a6 1a3 :3 18c
:6 1af :3 18c :3 83 :9 1b4
:7 1b5 1b6 1b4 :9 1b6
:9 1b7 1b6 :3 1b4 :11 1ba
:30 1bb :3 1ba :a 1bd 62
:3 1c0 :11 1c1 :b 1c2 :17 1c3
:3 1c1 :2 1c5 :3 1c6 :3 1c7
1c8 1c6 1c5 1c6
:3 1c9 :3 1c0 :2 1ca :5 1cc
:11 1cd :b 1ce :18 1cf :3 1cd
:2 1d1 1d2 :3 1d3 1d4
1d2 1d1 1d2 :3 1d5
:2 1cb :6 1ca 1bf :7 1

21d9
4
:3 0 1 :3 0 2
:a 0 92b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 92b 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 929
0 b :6 0 f
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 929
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 929
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 929
0 10 :6 0 13
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 929
0 11 :6 0 25
11e 0 23 4
:3 0 21 3a 3c
:6 0 3f 3d 0
929 0 12 :6 0
29 152 0 27
15 :3 0 41 :7 0
44 42 0 929
0 14 :6 0 15
:3 0 46 :7 0 49
47 0 929 0
16 :6 0 2d 186
0 2b 15 :3 0
4b :7 0 4e 4c
0 929 0 17
:6 0 15 :3 0 50
:7 0 53 51 0
929 0 18 :6 0
31 1ba 0 2f
15 :3 0 55 :7 0
58 56 0 929
0 19 :6 0 15
:3 0 5a :7 0 5d
5b 0 929 0
1a :6 0 35 1ee
0 33 1c :3 0
5f :7 0 62 60
0 929 0 1b
:6 0 1c :3 0 64
:7 0 67 65 0
929 0 1d :6 0
c :2 0 39 1c
:3 0 69 :7 0 6c
6a 0 929 0
1e :6 0 4 :3 0
c :2 0 37 6e
70 :6 0 73 71
0 929 0 1f
:6 0 13 :2 0 3d
4 :3 0 3b 75
77 :6 0 7a 78
0 929 0 20
:6 0 23 :2 0 41
4 :3 0 3f 7c
7e :6 0 81 7f
0 929 0 21
:6 0 23 :2 0 43
6 :3 0 83 :7 0
87 84 85 929
0 22 :6 0 23
:2 0 45 6 :3 0
89 :7 0 8d 8a
8b 929 0 24
:6 0 23 :2 0 47
6 :3 0 8f :7 0
93 90 91 929
0 25 :6 0 23
:2 0 49 6 :3 0
95 :7 0 99 96
97 929 0 26
:6 0 23 :2 0 4b
6 :3 0 9b :7 0
9f 9c 9d 929
0 27 :6 0 23
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 929 0 28
:6 0 51 324 0
4f 6 :3 0 a7
:7 0 ab a8 a9
929 0 29 :6 0
2d :2 0 53 15
:3 0 ad :7 0 b0
ae 0 929 0
2a :6 0 1c :3 0
b2 :7 0 b5 b3
0 929 0 2b
:6 0 23 :2 0 57
4 :3 0 55 b7
b9 :6 0 bc ba
0 929 0 2c
:6 0 23 :2 0 59
6 :3 0 be :7 0
c2 bf c0 929
0 2e :6 0 23
:2 0 5b 6 :3 0
c4 :7 0 c8 c5
c6 929 0 2f
:6 0 23 :2 0 5d
6 :3 0 ca :7 0
ce cb cc 929
0 30 :6 0 23
:2 0 5f 6 :3 0
d0 :7 0 d4 d1
d2 929 0 31
:6 0 63 401 0
61 6 :3 0 d6
:7 0 da d7 d8
929 0 32 :6 0
23 :2 0 65 15
:3 0 dc :7 0 df
dd 0 929 0
33 :6 0 15 :3 0
e1 :7 0 e4 e2
0 929 0 34
:6 0 23 :2 0 67
6 :3 0 e6 :7 0
ea e7 e8 929
0 35 :6 0 23
:2 0 69 6 :3 0
ec :7 0 f0 ed
ee 929 0 36
:6 0 3a :2 0 6b
6 :3 0 f2 :7 0
f6 f3 f4 929
0 37 :6 0 3a
:2 0 6d 39 :3 0
f8 :7 0 fc f9
fa 929 0 38
:6 0 71 4c1 0
6f 39 :3 0 fe
:7 0 102 ff 100
929 0 3b :6 0
23 :2 0 73 1c
:3 0 104 :7 0 107
105 0 929 0
3c :6 0 1c :3 0
109 :7 0 10c 10a
0 929 0 3d
:6 0 23 :2 0 75
6 :3 0 10e :7 0
112 10f 110 929
0 3e :6 0 23
:2 0 77 6 :3 0
114 :7 0 118 115
116 929 0 3f
:6 0 23 :2 0 79
6 :3 0 11a :7 0
11e 11b 11c 929
0 40 :6 0 23
:2 0 7b 6 :3 0
120 :7 0 124 121
122 929 0 41
:6 0 7f 581 0
7d 6 :3 0 126
:7 0 12a 127 128
929 0 42 :9 0
81 44 :3 0 12c
:7 0 12f 12d 0
929 0 43 :6 0
6 :3 0 131 0
2 :5 0 23 :2 0
135 132 133 929
0 45 :6 0 46
:3 0 47 :a 0 2
177 :4 0 137 13a
0 138 :3 0 48
:3 0 49 :3 0 4a
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 4c
:3 0 50 :3 0 4d
:3 0 51 :3 0 52
:3 0 50 :3 0 53
:3 0 54 :3 0 e
:3 0 55 :3 0 56
:3 0 57 :3 0 56
:3 0 58 :3 0 56
:3 0 59 :3 0 56
:3 0 5a :3 0 56
:3 0 5b :3 0 56
:3 0 5c :3 0 56
:3 0 5d :3 0 56
:3 0 5e :3 0 56
:3 0 5f :3 0 56
:3 0 60 :3 0 56
:3 0 61 :3 0 56
:3 0 62 :3 0 56
:3 0 63 :3 0 56
:3 0 64 :3 0 56
:3 0 65 :3 0 4a
:3 0 4b :3 0 4a
:3 0 4b :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:4 0 68 1 :8 0
178 137 13a 179
0 929 83 179
17b 178 17a :6 0
177 :7 0 179 46
:3 0 69 :a 0 3
1b2 :5 0 17d 180
0 17e :3 0 6a
:3 0 6b :3 0 6c
:3 0 6d :3 0 4c
:3 0 50 :3 0 22
:3 0 4c :3 0 67
:3 0 6c :3 0 6d
:3 0 66 :3 0 67
:3 0 6e :3 0 6f
:3 0 50 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:3 0 4d :3 0 51
:3 0 52 :3 0 70
:3 0 71 :3 0 72
:3 0 73 :3 0 74
:3 0 75 :3 0 76
:3 0 77 :3 0 78
:3 0 79 :3 0 66
:3 0 7a :3 0 48
:3 0 d :3 0 7b
:3 0 1f :3 0 6c
:3 0 6d :3 0 6c
:3 0 6d :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :4 0 7c
1 :8 0 1b3 17d
180 1b4 0 929
85 1b4 1b6 1b3
1b5 :6 0 1b2 :7 0
1b4 1be 1bf 0
87 9 :3 0 a
:2 0 4 1b8 1b9
0 1ba :7 0 1bd
1bb 0 929 0
7d :6 0 7e :3 0
7f :3 0 7e :3 0
80 :3 0 1c1 1c2
0 2 :4 0 89
1c3 1c5 1c0 1c7
1c6 :2 0 81 :3 0
82 :3 0 1c9 1ca
0 83 :4 0 7e
:3 0 84 :3 0 1cd
1ce 0 2 :4 0
8b 1cf 1d1 85
:4 0 86 :2 0 87
:3 0 8d 1d4 1d6
:3 0 88 :4 0 86
:2 0 89 :4 0 90
1d9 1db :3 0 86
:2 0 3 :3 0 93
1dd 1df :3 0 86
:2 0 89 :4 0 96
1e1 1e3 :3 0 86
:2 0 8a :4 0 99
1e5 1e7 :3 0 86
:2 0 4d :3 0 8b
:3 0 5 :3 0 9c
1eb 1ed 8c :4 0
9e 1ea 1f0 a1
1e9 1f2 :3 0 86
:2 0 8a :4 0 a4
1f4 1f6 :3 0 86
:2 0 89 :4 0 a7
1f8 1fa :3 0 86
:2 0 7 :3 0 aa
1fc 1fe :3 0 86
:2 0 89 :4 0 ad
200 202 :3 0 86
:2 0 8d :4 0 b0
204 206 :3 0 b3
1cb 208 :2 0 20a
b8 20b 1c8 20a
0 20c ba 0
889 7e :3 0 7f
:3 0 20d 20e 0
7e :3 0 8e :3 0
210 211 0 13
:2 0 2 :4 0 8f
:2 0 90 :2 0 13
:2 0 bc 216 218
:3 0 bf 212 21a
20f 21c 21b :2 0
81 :3 0 91 :3 0
21e 21f 0 83
:4 0 92 :4 0 86
:2 0 87 :3 0 c3
223 225 :3 0 c6
220 227 :2 0 229
c9 22a 21d 229
0 22b cb 0
889 22 :3 0 5
:3 0 22c 22d 0
889 10 :3 0 7
:3 0 22f 230 0
889 41 :3 0 23
:2 0 232 233 0
889 93 :3 0 54
:3 0 55 :3 0 e
:3 0 28 :3 0 53
:3 0 49 :3 0 3
:4 0 94 1 :8 0
243 9 :3 0 95
:3 0 23e 23f 0
96 :3 0 240 241
0 243 cd 296
97 :3 0 9 :3 0
95 :3 0 245 246
0 96 :3 0 247
248 0 24a d0
24c d2 24b 24a
:2 0 294 98 :3 0
9 :3 0 95 :3 0
24f 250 0 96
:3 0 251 252 0
28c 7e :3 0 7f
:3 0 254 255 0
7e :3 0 8e :3 0
257 258 0 99
:2 0 2 :4 0 9a
:2 0 90 :2 0 13
:2 0 d4 25d 25f
:3 0 d7 259 261
256 263 262 :2 0
81 :3 0 91 :3 0
265 266 0 83
:4 0 9b :4 0 86
:2 0 87 :3 0 db
26a 26c :3 0 86
:2 0 9c :4 0 de
26e 270 :3 0 86
:2 0 9d :4 0 e1
272 274 :3 0 86
:2 0 96 :3 0 e4
276 278 :3 0 86
:2 0 9e :4 0 e7
27a 27c :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 ea 27f 283
ee 27e 285 :3 0
f1 267 287 :2 0
289 f4 28a 264
289 0 28b f6
0 28c f8 28f
:3 0 28f 0 28f
28e 28c 28d :6 0
291 4 :3 0 fb
293 fd 292 291
:2 0 294 ff :2 0
296 0 296 295
243 294 :6 0 889
1 :3 0 9 :3 0
95 :3 0 298 299
0 9 :3 0 a2
:2 0 a3 :3 0 29b
29d 0 104 29c
29f :3 0 2a0 :2 0
28 :3 0 a4 :2 0
107 2a3 2a4 :3 0
2a5 :2 0 2a6 :2 0
2a1 2a8 2a7 :2 0
e :3 0 9f :3 0
e :3 0 86 :2 0
a5 :4 0 109 2ad
2af :3 0 13 :2 0
f :2 0 10c 2ab
2b3 2aa 2b4 0
810 25 :3 0 a6
:2 0 13 :2 0 110
2b7 2b9 :3 0 2b6
2ba 0 810 a7
:3 0 47 :4 0 2bf
:2 0 810 2bd 2c0
:3 0 a8 :3 0 47
:3 0 d :3 0 1f
:3 0 25 :3 0 17
:3 0 18 :4 0 2c9
:2 0 6c2 2c2 2ca
:3 0 112 :3 0 47
:3 0 a9 :3 0 2cb
2cc :3 0 9 :3 0
95 :3 0 2ce 2cf
0 23 :2 0 2d0
2d1 0 2d3 118
2da 9 :3 0 95
:3 0 2d4 2d5 0
aa :2 0 2d6 2d7
0 2d9 11a 2db
2cd 2d3 0 2dc
0 2d9 0 2dc
11c 0 6c2 9
:3 0 95 :3 0 2dd
2de 0 9 :3 0
ab :2 0 a3 :3 0
2e0 2e2 0 121
2e1 2e4 :3 0 2e5
:2 0 ac :8 0 2e9
124 2ea 2e6 2e9
0 2eb 126 0
6c2 4d :3 0 25
:3 0 23 :2 0 128
2ec 2ef a2 :2 0
23 :2 0 12d 2f1
2f3 :3 0 4d :3 0
22 :3 0 23 :2 0
130 2f5 2f8 a2
:2 0 ad :2 0 135
2fa 2fc :3 0 45
:3 0 9 :3 0 95
:3 0 2ff 300 0
2fe 301 0 31d
43 :3 0 ae :3 0
d :3 0 1f :3 0
17 :3 0 18 :3 0
10 :3 0 138 304
30a 303 30b 0
31d 9 :3 0 95
:3 0 30d 30e 0
45 :3 0 30f 310
0 31d 29 :3 0
4d :3 0 29 :3 0
23 :2 0 13e 313
316 90 :2 0 13
:2 0 141 318 31a
:3 0 312 31b 0
31d 144 31e 2fd
31d 0 31f 149
0 320 14b 6bf
17 :4 0 321 322
0 6be 18 :4 0
324 325 0 6be
a7 :3 0 69 :4 0
32a :2 0 6be 328
32b :3 0 a8 :3 0
69 :3 0 20 :3 0
b :3 0 35 :3 0
17 :3 0 18 :3 0
25 :3 0 26 :3 0
30 :3 0 24 :3 0
1e :3 0 42 :3 0
14 :3 0 16 :3 0
3e :3 0 3f :3 0
38 :3 0 3b :3 0
21 :3 0 37 :3 0
11 :3 0 12 :3 0
36 :4 0 345 :2 0
3b7 32d 346 :3 0
14d :3 0 69 :3 0
a9 :3 0 347 348
:3 0 9 :3 0 95
:3 0 34a 34b 0
23 :2 0 34c 34d
0 34f 164 356
9 :3 0 95 :3 0
350 351 0 aa
:2 0 352 353 0
355 166 357 349
34f 0 358 0
355 0 358 168
0 3b7 9 :3 0
95 :3 0 359 35a
0 9 :3 0 ab
:2 0 a3 :3 0 35c
35e 0 16d 35d
360 :3 0 361 :2 0
ac :8 0 365 170
366 362 365 0
367 172 0 3b7
32 :3 0 af :3 0
d :3 0 1f :3 0
20 :3 0 b :3 0
35 :3 0 17 :3 0
18 :3 0 25 :3 0
26 :3 0 30 :3 0
24 :3 0 1e :3 0
42 :3 0 14 :3 0
16 :3 0 3e :3 0
3f :3 0 38 :3 0
3b :3 0 21 :3 0
37 :3 0 11 :3 0
12 :3 0 36 :3 0
22 :3 0 10 :3 0
174 369 384 368
385 0 3b7 4d
:3 0 32 :3 0 23
:2 0 18f 387 38a
a2 :2 0 23 :2 0
194 38c 38e :3 0
29 :3 0 4d :3 0
29 :3 0 23 :2 0
197 391 394 90
:2 0 13 :2 0 19a
396 398 :3 0 390
399 0 39c b0
:3 0 19d 3b5 4d
:3 0 32 :3 0 23
:2 0 19f 39d 3a0
56 :3 0 a2 :2 0
b1 :3 0 3a2 3a4
0 1a4 3a3 3a6
:3 0 41 :3 0 4d
:3 0 41 :3 0 23
:2 0 1a7 3a9 3ac
90 :2 0 13 :2 0
1aa 3ae 3b0 :3 0
3a8 3b1 0 3b3
1ad 3b4 3a7 3b3
0 3b6 38f 39c
0 3b6 1af 0
3b7 1b2 3b9 a8
:4 0 3b7 :4 0 6be
b2 :3 0 69 :4 0
3bd :2 0 3c3 3bb
0 9 :3 0 95
:3 0 3be 3bf 0
96 :3 0 3c0 3c1
0 3c3 1b8 416
97 :3 0 9 :3 0
95 :3 0 3c5 3c6
0 96 :3 0 3c7
3c8 0 3ca 1bb
3cc 1bd 3cb 3ca
:2 0 414 98 :3 0
9 :3 0 95 :3 0
3cf 3d0 0 96
:3 0 3d1 3d2 0
40c 7e :3 0 7f
:3 0 3d4 3d5 0
7e :3 0 8e :3 0
3d7 3d8 0 99
:2 0 2 :4 0 b3
:2 0 90 :2 0 13
:2 0 1bf 3dd 3df
:3 0 1c2 3d9 3e1
3d6 3e3 3e2 :2 0
81 :3 0 91 :3 0
3e5 3e6 0 83
:4 0 b4 :4 0 86
:2 0 87 :3 0 1c6
3ea 3ec :3 0 86
:2 0 9c :4 0 1c9
3ee 3f0 :3 0 86
:2 0 9d :4 0 1cc
3f2 3f4 :3 0 86
:2 0 96 :3 0 1cf
3f6 3f8 :3 0 86
:2 0 9e :4 0 1d2
3fa 3fc :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 1d5 3ff 403
1d9 3fe 405 :3 0
1dc 3e7 407 :2 0
409 1df 40a 3e4
409 0 40b 1e1
0 40c 1e3 40f
:3 0 40f 0 40f
40e 40c 40d :6 0
411 8 :3 0 1e6
413 1e8 412 411
:2 0 414 1ea :2 0
416 0 416 415
3c3 414 :6 0 6be
6 :3 0 4d :3 0
22 :3 0 23 :2 0
1ed 418 41b ab
:2 0 13 :2 0 1f2
41d 41f :3 0 420
:2 0 4d :3 0 29
:3 0 23 :2 0 1f5
422 425 b5 :2 0
23 :2 0 1fa 427
429 :3 0 42a :2 0
421 42c 42b :2 0
19 :4 0 42e 42f
0 6bb 1a :4 0
431 432 0 6bb
b6 :3 0 b7 :3 0
4c :3 0 50 :3 0
2a :3 0 2f :3 0
19 :3 0 1a :3 0
53 :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 b8 1
:8 0 447 9 :3 0
95 :3 0 442 443
0 96 :3 0 444
445 0 447 1fd
49a 97 :3 0 9
:3 0 95 :3 0 449
44a 0 96 :3 0
44b 44c 0 44e
200 450 202 44f
44e :2 0 498 98
:3 0 9 :3 0 95
:3 0 453 454 0
96 :3 0 455 456
0 490 7e :3 0
7f :3 0 458 459
0 7e :3 0 8e
:3 0 45b 45c 0
99 :2 0 2 :4 0
b9 :2 0 90 :2 0
13 :2 0 204 461
463 :3 0 207 45d
465 45a 467 466
:2 0 81 :3 0 91
:3 0 469 46a 0
83 :4 0 ba :4 0
86 :2 0 87 :3 0
20b 46e 470 :3 0
86 :2 0 9c :4 0
20e 472 474 :3 0
86 :2 0 9d :4 0
211 476 478 :3 0
86 :2 0 96 :3 0
214 47a 47c :3 0
86 :2 0 9e :4 0
217 47e 480 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 21a 483
487 21e 482 489
:3 0 221 46b 48b
:2 0 48d 224 48e
468 48d 0 48f
226 0 490 228
493 :3 0 493 0
493 492 490 491
:6 0 495 a :3 0
22b 497 22d 496
495 :2 0 498 22f
:2 0 49a 0 49a
499 447 498 :6 0
6bb 6 :3 0 1a
:3 0 a4 :2 0 232
49d 49e :3 0 49f
:2 0 2a :3 0 a4
:2 0 234 4a2 4a3
:3 0 4a4 :2 0 53
:3 0 b6 :3 0 2f
:3 0 bb :3 0 9f
:3 0 2a :3 0 bb
:3 0 9f :3 0 1a
:3 0 1a :3 0 2f
:3 0 1a :3 0 2a
:3 0 b7 :3 0 2f
:3 0 bb :3 0 9f
:3 0 2a :3 0 bb
:3 0 9f :3 0 1a
:3 0 2f :3 0 2f
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 bc 1 :8 0
4d7 a9 :4 0 4c2
:3 0 bd :3 0 a2
:2 0 238 4c5 4c6
:3 0 9 :3 0 95
:3 0 4c8 4c9 0
23 :2 0 4ca 4cb
0 4cd 23b 4d4
9 :3 0 95 :3 0
4ce 4cf 0 aa
:2 0 4d0 4d1 0
4d3 23d 4d5 4c7
4cd 0 4d6 0
4d3 0 4d6 23f
0 4d7 242 52a
97 :3 0 9 :3 0
95 :3 0 4d9 4da
0 96 :3 0 4db
4dc 0 4de 245
4e0 247 4df 4de
:2 0 528 98 :3 0
9 :3 0 95 :3 0
4e3 4e4 0 96
:3 0 4e5 4e6 0
520 7e :3 0 7f
:3 0 4e8 4e9 0
7e :3 0 8e :3 0
4eb 4ec 0 99
:2 0 2 :4 0 be
:2 0 90 :2 0 13
:2 0 249 4f1 4f3
:3 0 24c 4ed 4f5
4ea 4f7 4f6 :2 0
81 :3 0 91 :3 0
4f9 4fa 0 83
:4 0 bf :4 0 86
:2 0 87 :3 0 250
4fe 500 :3 0 86
:2 0 9c :4 0 253
502 504 :3 0 86
:2 0 9d :4 0 256
506 508 :3 0 86
:2 0 96 :3 0 259
50a 50c :3 0 86
:2 0 9e :4 0 25c
50e 510 :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 25f 513 517
263 512 519 :3 0
266 4fb 51b :2 0
51d 269 51e 4f8
51d 0 51f 26b
0 520 26d 523
:3 0 523 0 523
522 520 521 :6 0
525 c :3 0 270
527 272 526 525
:2 0 528 274 :2 0
52a 0 52a 529
4d7 528 :6 0 52c
6 :3 0 277 5a1
53 :3 0 b6 :3 0
1a :3 0 b7 :3 0
48 :3 0 d :3 0
49 :3 0 1f :4 0
c0 1 :8 0 54b
a9 :4 0 536 :3 0
bd :3 0 a2 :2 0
27b 539 53a :3 0
9 :3 0 95 :3 0
53c 53d 0 23
:2 0 53e 53f 0
541 27e 548 9
:3 0 95 :3 0 542
543 0 aa :2 0
544 545 0 547
280 549 53b 541
0 54a 0 547
0 54a 282 0
54b 285 59e 97
:3 0 9 :3 0 95
:3 0 54d 54e 0
96 :3 0 54f 550
0 552 288 554
28a 553 552 :2 0
59c 98 :3 0 9
:3 0 95 :3 0 557
558 0 96 :3 0
559 55a 0 594
7e :3 0 7f :3 0
55c 55d 0 7e
:3 0 8e :3 0 55f
560 0 99 :2 0
2 :4 0 c1 :2 0
90 :2 0 13 :2 0
28c 565 567 :3 0
28f 561 569 55e
56b 56a :2 0 81
:3 0 91 :3 0 56d
56e 0 83 :4 0
c2 :4 0 86 :2 0
87 :3 0 293 572
574 :3 0 86 :2 0
9c :4 0 296 576
578 :3 0 86 :2 0
9d :4 0 299 57a
57c :3 0 86 :2 0
96 :3 0 29c 57e
580 :3 0 86 :2 0
9e :4 0 29f 582
584 :3 0 86 :2 0
9f :3 0 a0 :3 0
13 :2 0 a1 :2 0
2a2 587 58b 2a6
586 58d :3 0 2a9
56f 58f :2 0 591
2ac 592 56c 591
0 593 2ae 0
594 2b0 597 :3 0
597 0 597 596
594 595 :6 0 599
e :3 0 2b3 59b
2b5 59a 599 :2 0
59c 2b7 :2 0 59e
0 59e 59d 54b
59c :6 0 5a0 6
:3 0 2ba 5a2 4a5
52c 0 5a3 0
5a0 0 5a3 2bc
0 5a5 b0 :3 0
2bf 6b9 19 :3 0
a4 :2 0 2c1 5a7
5a8 :3 0 5a9 :2 0
5aa :2 0 1a :3 0
c3 :2 0 2c3 5ad
5ae :3 0 5af :2 0
5b0 :2 0 5ab 5b2
5b1 :2 0 2a :3 0
a4 :2 0 2c5 5b5
5b6 :3 0 5b7 :2 0
53 :3 0 b6 :3 0
2f :3 0 bb :3 0
9f :3 0 2a :3 0
bb :3 0 9f :3 0
19 :3 0 19 :3 0
2f :3 0 19 :3 0
2a :3 0 b7 :3 0
2f :3 0 bb :3 0
9f :3 0 2a :3 0
bb :3 0 9f :3 0
19 :3 0 2f :3 0
2f :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 c4 1
:8 0 5ea a9 :4 0
5d5 :3 0 bd :3 0
a2 :2 0 2c9 5d8
5d9 :3 0 9 :3 0
95 :3 0 5db 5dc
0 23 :2 0 5dd
5de 0 5e0 2cc
5e7 9 :3 0 95
:3 0 5e1 5e2 0
aa :2 0 5e3 5e4
0 5e6 2ce 5e8
5da 5e0 0 5e9
0 5e6 0 5e9
2d0 0 5ea 2d3
63d 97 :3 0 9
:3 0 95 :3 0 5ec
5ed 0 96 :3 0
5ee 5ef 0 5f1
2d6 5f3 2d8 5f2
5f1 :2 0 63b 98
:3 0 9 :3 0 95
:3 0 5f6 5f7 0
96 :3 0 5f8 5f9
0 633 7e :3 0
7f :3 0 5fb 5fc
0 7e :3 0 8e
:3 0 5fe 5ff 0
99 :2 0 2 :4 0
c5 :2 0 90 :2 0
13 :2 0 2da 604
606 :3 0 2dd 600
608 5fd 60a 609
:2 0 81 :3 0 91
:3 0 60c 60d 0
83 :4 0 c6 :4 0
86 :2 0 87 :3 0
2e1 611 613 :3 0
86 :2 0 9c :4 0
2e4 615 617 :3 0
86 :2 0 9d :4 0
2e7 619 61b :3 0
86 :2 0 96 :3 0
2ea 61d 61f :3 0
86 :2 0 9e :4 0
2ed 621 623 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 2f0 626
62a 2f4 625 62c
:3 0 2f7 60e 62e
:2 0 630 2fa 631
60b 630 0 632
2fc 0 633 2fe
636 :3 0 636 0
636 635 633 634
:6 0 638 10 :3 0
301 63a 303 639
638 :2 0 63b 305
:2 0 63d 0 63d
63c 5ea 63b :6 0
63f 6 :3 0 308
6b4 53 :3 0 b6
:3 0 19 :3 0 b7
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 c7 1 :8 0
65e a9 :4 0 649
:3 0 bd :3 0 a2
:2 0 30c 64c 64d
:3 0 9 :3 0 95
:3 0 64f 650 0
23 :2 0 651 652
0 654 30f 65b
9 :3 0 95 :3 0
655 656 0 aa
:2 0 657 658 0
65a 311 65c 64e
654 0 65d 0
65a 0 65d 313
0 65e 316 6b1
97 :3 0 9 :3 0
95 :3 0 660 661
0 96 :3 0 662
663 0 665 319
667 31b 666 665
:2 0 6af 98 :3 0
9 :3 0 95 :3 0
66a 66b 0 96
:3 0 66c 66d 0
6a7 7e :3 0 7f
:3 0 66f 670 0
7e :3 0 8e :3 0
672 673 0 99
:2 0 2 :4 0 c8
:2 0 90 :2 0 13
:2 0 31d 678 67a
:3 0 320 674 67c
671 67e 67d :2 0
81 :3 0 91 :3 0
680 681 0 83
:4 0 c9 :4 0 86
:2 0 87 :3 0 324
685 687 :3 0 86
:2 0 9c :4 0 327
689 68b :3 0 86
:2 0 9d :4 0 32a
68d 68f :3 0 86
:2 0 96 :3 0 32d
691 693 :3 0 86
:2 0 9e :4 0 330
695 697 :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 333 69a 69e
337 699 6a0 :3 0
33a 682 6a2 :2 0
6a4 33d 6a5 67f
6a4 0 6a6 33f
0 6a7 341 6aa
:3 0 6aa 0 6aa
6a9 6a7 6a8 :6 0
6ac 12 :3 0 344
6ae 346 6ad 6ac
:2 0 6af 348 :2 0
6b1 0 6b1 6b0
65e 6af :6 0 6b3
6 :3 0 34b 6b5
5b8 63f 0 6b6
0 6b3 0 6b6
34d 0 6b7 350
6b8 5b3 6b7 0
6ba 4a0 5a5 0
6ba 352 0 6bb
355 6bc 42d 6bb
0 6bd 35a 0
6be 35c 6c0 2f4
320 0 6c1 0
6be 0 6c1 363
0 6c2 366 6c4
a8 :4 0 6c2 :4 0
810 b2 :3 0 47
:4 0 6c8 :2 0 6ce
6c6 0 9 :3 0
95 :3 0 6c9 6ca
0 96 :3 0 6cb
6cc 0 6ce 36b
721 97 :3 0 9
:3 0 95 :3 0 6d0
6d1 0 96 :3 0
6d2 6d3 0 6d5
36e 6d7 370 6d6
6d5 :2 0 71f 98
:3 0 9 :3 0 95
:3 0 6da 6db 0
96 :3 0 6dc 6dd
0 717 7e :3 0
7f :3 0 6df 6e0
0 7e :3 0 8e
:3 0 6e2 6e3 0
99 :2 0 2 :4 0
ca :2 0 90 :2 0
13 :2 0 372 6e8
6ea :3 0 375 6e4
6ec 6e1 6ee 6ed
:2 0 81 :3 0 91
:3 0 6f0 6f1 0
83 :4 0 cb :4 0
86 :2 0 87 :3 0
379 6f5 6f7 :3 0
86 :2 0 9c :4 0
37c 6f9 6fb :3 0
86 :2 0 9d :4 0
37f 6fd 6ff :3 0
86 :2 0 96 :3 0
382 701 703 :3 0
86 :2 0 9e :4 0
385 705 707 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 388 70a
70e 38c 709 710
:3 0 38f 6f2 712
:2 0 714 392 715
6ef 714 0 716
394 0 717 396
71a :3 0 71a 0
71a 719 717 718
:6 0 71c 14 :3 0
399 71e 39b 71d
71c :2 0 71f 39d
:2 0 721 0 721
720 6ce 71f :6 0
810 1 :3 0 4d
:3 0 29 :3 0 23
:2 0 3a0 723 726
b5 :2 0 23 :2 0
3a5 728 72a :3 0
72b :2 0 4d :3 0
25 :3 0 23 :2 0
3a8 72d 730 b5
:2 0 a6 :2 0 13
:2 0 3ab 733 735
:3 0 3af 732 737
:3 0 738 :2 0 72c
73a 739 :2 0 a4
:2 0 3b2 6 :3 0
73d :7 0 23 :2 0
741 73e 73f 78e
0 cc :6 0 e
:3 0 3b4 743 744
:3 0 745 :2 0 cc
:3 0 4d :3 0 cd
:3 0 e :3 0 3b6
749 74b 23 :2 0
3b8 748 74e 747
74f 0 767 13
:2 0 ab :2 0 23
:2 0 3bd 752 754
:3 0 cc :3 0 ab
:2 0 23 :2 0 3c2
757 759 :3 0 755
75b 75a :2 0 cc
:3 0 cc :3 0 a6
:2 0 13 :2 0 3c5
75f 761 :3 0 75d
762 0 764 3c8
765 75c 764 0
766 3ca 0 767
3cc 768 746 767
0 769 3cf 0
78c cc :3 0 ab
:2 0 23 :2 0 3d3
76b 76d :3 0 ce
:2 0 3d6 76f 770
:3 0 cc :3 0 cf
:3 0 cf :2 0 d0
:2 0 3d8 774 776
:3 0 777 :2 0 ab
:2 0 23 :2 0 3dd
779 77b :3 0 771
77d 77c :2 0 d1
:3 0 d2 :3 0 77f
780 0 56 :3 0
d3 :3 0 782 783
0 e :3 0 bd
:3 0 3e0 781 787
:2 0 789 3e4 78a
77e 789 0 78b
3e6 0 78c 3e8
78f :3 0 78f 3eb
78f 78e 78c 78d
:6 0 80d 1 :3 0
53 :3 0 d4 :3 0
d5 :3 0 d6 :3 0
d4 :3 0 56 :3 0
d7 :3 0 48 :3 0
d :3 0 54 :3 0
e :4 0 d8 1
:8 0 7b2 a9 :4 0
79d :3 0 bd :3 0
a2 :2 0 3ef 7a0
7a1 :3 0 9 :3 0
95 :3 0 7a3 7a4
0 23 :2 0 7a5
7a6 0 7a8 3f2
7af 9 :3 0 95
:3 0 7a9 7aa 0
aa :2 0 7ab 7ac
0 7ae 3f4 7b0
7a2 7a8 0 7b1
0 7ae 0 7b1
3f6 0 7b2 3f9
805 97 :3 0 9
:3 0 95 :3 0 7b4
7b5 0 96 :3 0
7b6 7b7 0 7b9
3fc 7bb 3fe 7ba
7b9 :2 0 803 98
:3 0 9 :3 0 95
:3 0 7be 7bf 0
96 :3 0 7c0 7c1
0 7fb 7e :3 0
7f :3 0 7c3 7c4
0 7e :3 0 8e
:3 0 7c6 7c7 0
99 :2 0 2 :4 0
d9 :2 0 90 :2 0
13 :2 0 400 7cc
7ce :3 0 403 7c8
7d0 7c5 7d2 7d1
:2 0 81 :3 0 91
:3 0 7d4 7d5 0
83 :4 0 da :4 0
86 :2 0 87 :3 0
407 7d9 7db :3 0
86 :2 0 9c :4 0
40a 7dd 7df :3 0
86 :2 0 9d :4 0
40d 7e1 7e3 :3 0
86 :2 0 96 :3 0
410 7e5 7e7 :3 0
86 :2 0 9e :4 0
413 7e9 7eb :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 416 7ee
7f2 41a 7ed 7f4
:3 0 41d 7d6 7f6
:2 0 7f8 420 7f9
7d3 7f8 0 7fa
422 0 7fb 424
7fe :3 0 7fe 0
7fe 7fd 7fb 7fc
:6 0 800 17 :3 0
427 802 429 801
800 :2 0 803 42b
:2 0 805 0 805
804 7b2 803 :6 0
80d 1 :3 0 32
:3 0 db :3 0 d
:3 0 42e 808 80a
807 80b 0 80d
430 80e 73b 80d
0 80f 434 0
810 436 811 2a9
810 0 812 43d
0 889 4d :3 0
41 :3 0 23 :2 0
43f 813 816 b5
:2 0 23 :2 0 444
818 81a :3 0 9
:3 0 95 :3 0 81c
81d 0 56 :3 0
b1 :3 0 81f 820
0 81e 821 0
824 b0 :3 0 447
839 4d :3 0 32
:3 0 23 :2 0 449
825 828 b5 :2 0
aa :2 0 44e 82a
82c :3 0 9 :3 0
95 :3 0 82e 82f
0 4d :3 0 32
:3 0 23 :2 0 451
831 834 830 835
0 837 454 838
82d 837 0 83a
81b 824 0 83a
456 0 889 7e
:3 0 7f :3 0 83b
83c 0 7e :3 0
8e :3 0 83e 83f
0 d0 :2 0 2
:4 0 dc :2 0 90
:2 0 13 :2 0 459
844 846 :3 0 45c
840 848 83d 84a
849 :2 0 81 :3 0
91 :3 0 84c 84d
0 83 :4 0 dd
:4 0 86 :2 0 87
:3 0 460 851 853
:3 0 86 :2 0 9c
:4 0 463 855 857
:3 0 86 :2 0 de
:4 0 466 859 85b
:3 0 86 :2 0 4d
:3 0 8b :3 0 9
:3 0 95 :3 0 860
861 0 469 85f
863 8c :4 0 46b
85e 866 46e 85d
868 :3 0 86 :2 0
df :4 0 471 86a
86c :3 0 86 :2 0
89 :4 0 474 86e
870 :3 0 86 :2 0
3 :3 0 477 872
874 :3 0 86 :2 0
89 :4 0 47a 876
878 :3 0 47d 84e
87a :2 0 87c 480
87d 84b 87c 0
87e 482 0 889
d1 :3 0 e0 :3 0
87f 880 0 9
:3 0 95 :3 0 882
883 0 3 :3 0
bd :3 0 484 881
887 :2 0 889 488
92a 9 :3 0 e1
:2 0 4 88a 88b
0 7e :3 0 7f
:3 0 88d 88e 0
7e :3 0 8e :3 0
890 891 0 99
:2 0 2 :4 0 e2
:2 0 90 :2 0 13
:2 0 493 896 898
:3 0 496 892 89a
88f 89c 89b :2 0
81 :3 0 91 :3 0
89e 89f 0 83
:4 0 e3 :4 0 86
:2 0 87 :3 0 49a
8a3 8a5 :3 0 49d
8a0 8a7 :2 0 8c0
81 :3 0 91 :3 0
8a9 8aa 0 83
:4 0 e4 :4 0 86
:2 0 9 :3 0 e5
:3 0 8af 8b0 0
4a0 8ae 8b2 :3 0
86 :2 0 df :4 0
4a3 8b4 8b6 :3 0
86 :2 0 9 :3 0
e6 :3 0 8b9 8ba
0 4a6 8b8 8bc
:3 0 4a9 8ab 8be
:2 0 8c0 4ac 8c1
89d 8c0 0 8c2
4af 0 8d2 a7
:3 0 7d :3 0 9
:3 0 e5 :3 0 e7
:3 0 9 :3 0 e6
:3 0 3 :3 0 e8
:4 0 e9 1 :a 0
8ce :2 0 8d2 8c4
8cc :2 0 8 :3 0
7d :3 0 8d0 :2 0
8d2 4b1 8d4 4b5
8d3 8d2 :2 0 928
98 :3 0 9 :3 0
95 :3 0 8d7 8d8
0 96 :3 0 8d9
8da 0 920 7e
:3 0 7f :3 0 8dc
8dd 0 7e :3 0
8e :3 0 8df 8e0
0 99 :2 0 2
:4 0 ea :2 0 90
:2 0 13 :2 0 4b7
8e5 8e7 :3 0 4ba
8e1 8e9 8de 8eb
8ea :2 0 81 :3 0
91 :3 0 8ed 8ee
0 83 :4 0 eb
:4 0 86 :2 0 87
:3 0 4be 8f2 8f4
:3 0 4c1 8ef 8f6
:2 0 910 81 :3 0
91 :3 0 8f8 8f9
0 83 :4 0 9d
:4 0 86 :2 0 96
:3 0 4c4 8fd 8ff
:3 0 86 :2 0 9e
:4 0 4c7 901 903
:3 0 86 :2 0 9f
:3 0 a0 :3 0 13
:2 0 a1 :2 0 4ca
906 90a 4ce 905
90c :3 0 4d1 8fa
90e :2 0 910 4d4
911 8ec 910 0
912 4d7 0 920
a7 :3 0 7d :3 0
e7 :3 0 9 :3 0
e6 :3 0 3 :3 0
e8 :4 0 ec 1
:a 0 91c :2 0 920
914 91a :2 0 8
:3 0 7d :3 0 91e
:2 0 920 4d9 923
:3 0 923 0 923
922 920 921 :6 0
925 1 :3 0 4de
927 4e0 926 925
:2 0 928 4e2 :2 0
92a 4e5 92a 929
889 928 :6 0 92b
:2 0 2 14 92a
92e :3 0 92d 92b
92f :8 0 
51a
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 45 1
4a 1 4f 1
54 1 59 1
5e 1 63 1
68 1 6f 1
6d 1 76 1
74 1 7d 1
7b 1 82 1
88 1 8e 1
94 1 9a 1
a0 1 a6 1
ac 1 b1 1
b8 1 b6 1
bd 1 c3 1
c9 1 cf 1
d5 1 db 1
e0 1 e5 1
eb 1 f1 1
f7 1 fd 1
103 1 108 1
10d 1 113 1
119 1 11f 1
125 1 12b 1
130 1 176 1
1b1 1 1b7 1
1c4 1 1d0 2
1d3 1d5 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 1 1ec
2 1ee 1ef 2
1e8 1f1 2 1f3
1f5 2 1f7 1f9
2 1fb 1fd 2
1ff 201 2 203
205 4 1cc 1d2
1d7 207 1 209
1 20b 2 215
217 3 213 214
219 2 222 224
2 221 226 1
228 1 22a 2
23d 242 1 249
1 244 2 25c
25e 3 25a 25b
260 2 269 26b
2 26d 26f 2
271 273 2 275
277 2 279 27b
3 280 281 282
2 27d 284 2
268 286 1 288
1 28a 2 253
28b 1 28f 1
24e 2 24c 293
1 29e 2 29a
29e 1 2a2 2
2ac 2ae 3 2b0
2b1 2b2 1 2b8
5 2c3 2c4 2c5
2c6 2c7 1 2d2
1 2d8 2 2da
2db 1 2e3 2
2df 2e3 1 2e8
1 2ea 2 2ed
2ee 1 2f2 2
2f0 2f2 2 2f6
2f7 1 2fb 2
2f9 2fb 5 305
306 307 308 309
2 314 315 2
317 319 4 302
30c 311 31c 1
31e 1 31f 16
32e 32f 330 331
332 333 334 335
336 337 338 339
33a 33b 33c 33d
33e 33f 340 341
342 343 1 34e
1 354 2 356
357 1 35f 2
35b 35f 1 364
1 366 1a 36a
36b 36c 36d 36e
36f 370 371 372
373 374 375 376
377 378 379 37a
37b 37c 37d 37e
37f 380 381 382
383 2 388 389
1 38d 2 38b
38d 2 392 393
2 395 397 1
39a 2 39e 39f
1 3a5 2 3a1
3a5 2 3aa 3ab
2 3ad 3af 1
3b2 2 3b5 3b4
5 344 358 367
386 3b6 2 3bc
3c2 1 3c9 1
3c4 2 3dc 3de
3 3da 3db 3e0
2 3e9 3eb 2
3ed 3ef 2 3f1
3f3 2 3f5 3f7
2 3f9 3fb 3
400 401 402 2
3fd 404 2 3e8
406 1 408 1
40a 2 3d3 40b
1 40f 1 3ce
2 3cc 413 2
419 41a 1 41e
2 41c 41e 2
423 424 1 428
2 426 428 2
441 446 1 44d
1 448 2 460
462 3 45e 45f
464 2 46d 46f
2 471 473 2
475 477 2 479
47b 2 47d 47f
3 484 485 486
2 481 488 2
46c 48a 1 48c
1 48e 2 457
48f 1 493 1
452 2 450 497
1 49c 1 4a1
1 4c4 2 4c3
4c4 1 4cc 1
4d2 2 4d4 4d5
2 4c1 4d6 1
4dd 1 4d8 2
4f0 4f2 3 4ee
4ef 4f4 2 4fd
4ff 2 501 503
2 505 507 2
509 50b 2 50d
50f 3 514 515
516 2 511 518
2 4fc 51a 1
51c 1 51e 2
4e7 51f 1 523
1 4e2 2 4e0
527 1 52a 1
538 2 537 538
1 540 1 546
2 548 549 2
535 54a 1 551
1 54c 2 564
566 3 562 563
568 2 571 573
2 575 577 2
579 57b 2 57d
57f 2 581 583
3 588 589 58a
2 585 58c 2
570 58e 1 590
1 592 2 55b
593 1 597 1
556 2 554 59b
1 59e 2 5a1
5a2 1 5a3 1
5a6 1 5ac 1
5b4 1 5d7 2
5d6 5d7 1 5df
1 5e5 2 5e7
5e8 2 5d4 5e9
1 5f0 1 5eb
2 603 605 3
601 602 607 2
610 612 2 614
616 2 618 61a
2 61c 61e 2
620 622 3 627
628 629 2 624
62b 2 60f 62d
1 62f 1 631
2 5fa 632 1
636 1 5f5 2
5f3 63a 1 63d
1 64b 2 64a
64b 1 653 1
659 2 65b 65c
2 648 65d 1
664 1 65f 2
677 679 3 675
676 67b 2 684
686 2 688 68a
2 68c 68e 2
690 692 2 694
696 3 69b 69c
69d 2 698 69f
2 683 6a1 1
6a3 1 6a5 2
66e 6a6 1 6aa
1 669 2 667
6ae 1 6b1 2
6b4 6b5 1 6b6
2 6b9 6b8 4
430 433 49a 6ba
1 6bc 6 323
326 329 3b9 416
6bd 2 6bf 6c0
4 2c8 2dc 2eb
6c1 2 6c7 6cd
1 6d4 1 6cf
2 6e7 6e9 3
6e5 6e6 6eb 2
6f4 6f6 2 6f8
6fa 2 6fc 6fe
2 700 702 2
704 706 3 70b
70c 70d 2 708
70f 2 6f3 711
1 713 1 715
2 6de 716 1
71a 1 6d9 2
6d7 71e 2 724
725 1 729 2
727 729 2 72e
72f 1 734 1
736 2 731 736
1 73c 1 742
1 74a 2 74c
74d 1 753 2
751 753 1 758
2 756 758 2
75e 760 1 763
1 765 2 750
766 1 768 1
76c 2 76a 76c
1 76e 2 772
775 1 77a 2
778 77a 3 784
785 786 1 788
1 78a 2 769
78b 1 740 1
79f 2 79e 79f
1 7a7 1 7ad
2 7af 7b0 2
79c 7b1 1 7b8
1 7b3 2 7cb
7cd 3 7c9 7ca
7cf 2 7d8 7da
2 7dc 7de 2
7e0 7e2 2 7e4
7e6 2 7e8 7ea
3 7ef 7f0 7f1
2 7ec 7f3 2
7d7 7f5 1 7f7
1 7f9 2 7c2
7fa 1 7fe 1
7bd 2 7bb 802
1 809 3 78f
805 80c 1 80e
6 2b5 2bb 2be
6c4 721 80f 1
811 2 814 815
1 819 2 817
819 1 822 2
826 827 1 82b
2 829 82b 2
832 833 1 836
2 839 838 2
843 845 3 841
842 847 2 850
852 2 854 856
2 858 85a 1
862 2 864 865
2 85c 867 2
869 86b 2 86d
86f 2 871 873
2 875 877 2
84f 879 1 87b
1 87d 3 884
885 886 a 20c
22b 22e 231 234
296 812 83a 87e
888 2 895 897
3 893 894 899
2 8a2 8a4 2
8a1 8a6 2 8ad
8b1 2 8b3 8b5
2 8b7 8bb 2
8ac 8bd 2 8a8
8bf 1 8c1 3
8c2 8cd 8d1 1
88c 2 8e4 8e6
3 8e2 8e3 8e8
2 8f1 8f3 2
8f0 8f5 2 8fc
8fe 2 900 902
3 907 908 909
2 904 90b 2
8fb 90d 2 8f7
90f 1 911 4
8db 912 91b 91f
1 923 1 8d6
2 8d4 927 34
1b 22 29 30
37 3e 43 48
4d 52 57 5c
61 66 6b 72
79 80 86 8c
92 98 9e a4
aa af b4 bb
c1 c7 cd d3
d9 de e3 e9
ef f5 fb 101
106 10b 111 117
11d 123 129 12e
134 177 1b2 1bc

1
4
0 
92e
0
1
28
19
39
0 1 1 1 4 1 6 6
8 6 a 6 c 6 e 6
10 6 12 1 14 1 1 17
1 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
2 0 1
e0 1 0
94 1 0
cf 1 0
3 1 0
f1 1 0
4f 1 0
74 1 0
119 1 0
16 1 0
c9 1 0
bd 1 0
39 1 0
db 1 0
fd 1 0
12b 1 0
b1 1 0
d5 1 0
73c 16 0
11f 1 0
68 1 0
8e 1 0
54 1 0
40 1 0
4a 1 0
137 1 2
10d 1 0
82 1 0
e5 1 0
b6 1 0
108 1 0
59 1 0
9a 1 0
113 1 0
6d 1 0
24 1 0
45 1 0
130 1 0
eb 1 0
7b 1 0
ac 1 0
63 1 0
a0 1 0
32 1 0
1d 1 0
17d 1 3
7 1 0
103 1 0
f7 1 0
5e 1 0
2b 1 0
88 1 0
125 1 0
c3 1 0
1b7 1 0
a6 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_WBS;
ALTER FUNCTION SP_ACPT_ETC_WBS COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
a2
2 :e:
1FUNCTION:
1SP_RJCT_ETC_ASSIGN:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_START_DATE:
1TIMESTAMP:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_TEMP_SC_STATE:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1I_PERCENT_COMPLETE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
130:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_ASSIGN(31) :: cplan.sql(20737) :: :
1PROJECT_ID:
1TASK_ID:
1BIT_FLAG:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, TASK_ID, BIT_FLAG, SCHED_WORK+PLANNED_WORK, WORK_TODATE, M+
1ILESTONE_PERCENT:n      INTO h_project_id, h_task_id, h_bit_flag, h_sched_wor+
1k, h_work_todate, h_mlst_percent:n      FROM TASK_ASSIGNMENTS WHERE TSK_ASSIG+
1NMENT_ID = h_tsk_assignment_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
149:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(50) :: cplan.sql(20756) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
12:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = SCHED_WORK - WORK_TODATE--, MILESTONE_PERCE+
1NT = (WORK_TODATE * 10000) / SCHED_WORK:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1FOUND:
1TRUE:
1100:
171:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(72) :: cplan.sql(20778) :: :
1ACTIVITIES:
1ETC_MODIFIED:
1ELEMENT_ID:
1TYPE_ID:
1PMO_CNST:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n            SET ETC_MODIFIED = 'N':n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id:n            AND TSK_ASSIGNMENT_ID <> ELE+
1MENT_ID:n            AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
194:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(95) :: cplan.sql(20801) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = PLANNED_WORK, WORK_TODATE = 0, MILESTONE_PE+
1RCENT = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1114:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(115) :: cplan.sql(20821) :: :
1TMT_WBS:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SCH+
1ED_BIT) WHERE ELEMENT_ID = h_task_id:
1134:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(135) :: cplan.sql(20841) :: :
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1155:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(156) :: cplan.sql(20862) :: :
1174:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(175) :: cplan.sql(20881) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = SCHED_WORK - WORK_TODATE--, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000) / SCHED_WORK:n               WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1196:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(197) :: cplan.sql(20903) :: :
1UPDATE ACTIVITIES:n               SET ETC_MODIFIED = 'N':n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n               AND TSK_ASSIGNMENT_+
1ID <> ELEMENT_ID:n               AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1219:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(220) :: cplan.sql(20926) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = PLANNED_WORK, WORK_TODATE = 0, MIL+
1ESTONE_PERCENT = 0:n               WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
1240:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(241) :: cplan.sql(20947) :: :
1260:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(261) :: cplan.sql(20967) :: :
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1-:
1<:
1SC_PERCENT_COMPLETE_BIT:
1ACTUAL_FINISH:
1SCHED_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP+
1_BITS,pmo_cnst.SC_PERCENT_COMPLETE_BIT),:n            ACTUAL_FINISH = CASE:n +
1           WHEN ACTUAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n        +
1    ELSE ACTUAL_FINISH:n            END:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1292:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(293) :: cplan.sql(20999) :: :
1UPDATE TASK_ASSIGNMENTS SET:n         ACTUAL_FINISH = CASE:n         WHEN ACT+
1UAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n         ELSE ACTUAL_FINISH+
1:n         END:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1317:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(318) :: cplan.sql(21024) :: :
1SC_SQL_SUCCESS:
1!=:
1FC_FIX_SUMMARY_TS:
1FC_ROLLUP:
14:
1332:
1       RETURN_STATUS:: SP_RJCT_ETC_ASSIGN(333) :: cplan.sql(21039) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1339:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(340) :: cplan.sql(21046) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1351:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(352) :: cplan.sql(21058) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
862
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :10 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 :2 51
a5 b 7e 6e b4 2e :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 51 a5 b 7e
51 b4 2e :6 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :a a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e a5 b d a0 7e 51
b4 2e 5a a0 :2 7e 51 b4 2e
b4 2e 52 10 :e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :5 a0
a5 b d b7 19 3c :3 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
862
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dc cb cf d7 aa
f8 e3 e7 ea eb f3 ca 114
103 107 c7 10f 102 130 11f 123
ff 12b 11e 14c 13b 13f 11b 147
13a 168 157 15b 137 163 156 184
173 177 153 17f 172 1a0 18f 193
16f 19b 18e 1bc 1ab 1af 1b7 18b
1db 1c3 1c7 1cb 1ce 1d6 1aa 1e2
1e6 1a7 1ea 1ee 1f2 1f5 1fa 1fb
1 1fd 202 206 20a 20d 212 216
21a 21d 222 223 225 22a 22d 231
232 237 23c 23f 244 245 24a 24d
251 252 257 25a 25f 260 265 268
26d 26e 273 276 27a 27e 282 283
285 28a 28b 28d 28e 293 296 29b
29c 2a1 2a4 2a9 2aa 2af 2b2 2b6
2b7 2bc 2bf 2c4 2c5 2ca 2cd 2d2
2d3 2d8 2d9 2de 2e0 2e4 2e7 2eb
2ef 2f2 2f6 2fa 2fd 300 305 308
30b 30e 30f 314 315 1 317 31c
320 324 327 32c 331 334 338 339
33e 33f 344 346 34a 34d 351 355
359 35d 361 365 369 36d 371 375
379 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3b1 3b5 3b9 3bc
3c0 3c4 3c6 3ca 3ce 3d2 3d5 3d9
3dd 3df 3e0 3e5 1 3e9 3ed 3f1
3f4 3f8 3fc 400 404 407 40b 40f
412 415 41a 41d 420 423 424 429
42a 1 42c 431 435 439 43c 441
446 449 44d 44e 453 456 45b 45c
461 464 469 46a 46f 472 476 477
47c 47f 484 485 48a 48d 491 495
498 49b 49c 49e 49f 4a4 4a5 4aa
4ac 4b0 4b3 4b5 4b9 4bb 4c7 4c9
4cb 4cc 4d1 4d5 4d7 4e3 4e5 4e9
4ed 4f0 4f1 4f3 4f6 4f9 4fa 4ff
503 507 50a 50d 50e 510 513 518
519 51e 522 526 52a 52e 532 536
542 546 54b 54f 552 553 558 55c
560 563 566 56a 56c 570 574 577
57a 57e 580 584 588 58b 58d 591
595 599 59c 5a0 5a4 5a6 5a7 5ac
1 5b0 5b4 5b8 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5d9 5dc 5e1 5e4
5e7 5ea 5eb 5f0 5f1 1 5f3 5f8
5fc 600 603 608 60d 610 614 615
61a 61d 622 623 628 62b 630 631
636 639 63d 63e 643 646 64b 64c
651 654 658 65c 65f 662 663 665
666 66b 66c 671 673 677 67a 67c
680 682 68e 690 692 693 698 69c
69e 6aa 6ac 6b0 6b4 6b8 6bc 6c0
6c4 6c8 6cc 6d0 6dc 6e0 6e5 6e9
6ec 6ed 6f2 6f6 6fa 6fd 700 704
706 70a 70e 711 714 718 71a 71e
722 725 727 72b 72f 733 736 73a
73e 740 741 746 1 74a 74e 752
755 759 75d 761 765 768 76c 770
773 776 77b 77e 781 784 785 78a
78b 1 78d 792 796 79a 79d 7a2
7a7 7aa 7ae 7af 7b4 7b7 7bc 7bd
7c2 7c5 7ca 7cb 7d0 7d3 7d7 7d8
7dd 7e0 7e5 7e6 7eb 7ee 7f2 7f6
7f9 7fc 7fd 7ff 800 805 806 80b
80d 811 814 816 81a 81c 828 82a
82c 82d 832 836 838 844 846 848
84c 850 854 858 85c 860 864 870
874 879 87d 880 881 886 88a 88e
891 894 898 89a 89e 8a2 8a5 8a8
8ac 8ae 8b2 8b6 8b9 8bb 8bf 8c3
8c7 8ca 8ce 8d2 8d4 8d5 8da 1
8de 8e2 8e6 8e9 8ed 8f1 8f5 8f9
8fc 900 904 907 90a 90f 912 915
918 919 91e 91f 1 921 926 92a
92e 931 936 93b 93e 942 943 948
94b 950 951 956 959 95e 95f 964
967 96b 96c 971 974 979 97a 97f
982 986 98a 98d 990 991 993 994
999 99a 99f 9a1 9a5 9a8 9aa 9ae
9b0 9bc 9be 9c0 9c1 9c6 9ca 9cc
9d8 9da 9dc 9e0 9e4 9e7 9eb 9ef
9f3 9f7 9fb 9ff a03 a07 a0b a17
a1b a20 a24 a27 a28 a2d a31 a35
a38 a3b a3f a41 a45 a49 a4c a4f
a53 a55 a59 a5d a60 a62 a66 a6a
a6e a71 a75 a79 a7b a7c a81 1
a85 a89 a8d a90 a94 a98 a9c aa0
aa3 aa7 aab aae ab1 ab6 ab9 abc
abf ac0 ac5 ac6 1 ac8 acd ad1
ad5 ad8 add ae2 ae5 ae9 aea aef
af2 af7 af8 afd b00 b05 b06 b0b
b0e b12 b13 b18 b1b b20 b21 b26
b29 b2d b31 b34 b37 b38 b3a b3b
b40 b41 b46 b48 b4c b4f b51 b55
b57 b63 b65 b67 b68 b6d b71 b73
b7f b81 b83 b87 b8b b8e b8f b91
b94 b97 b98 b9d ba1 ba5 ba9 bad
bb1 bb5 bc1 bc5 bca bce bd1 bd2
bd7 bdb bdf be2 be5 be9 beb bef
bf3 bf6 bf9 bfd bff c03 c07 c0a
c0c c10 c14 c18 c1b c1f c23 c25
c26 c2b 1 c2f c33 c37 c3a c3e
c42 c46 c4a c4d c51 c55 c58 c5b
c60 c63 c66 c69 c6a c6f c70 1
c72 c77 c7b c7f c82 c87 c8c c8f
c93 c94 c99 c9c ca1 ca2 ca7 caa
caf cb0 cb5 cb8 cbc cbd cc2 cc5
cca ccb cd0 cd3 cd7 cdb cde ce1
ce2 ce4 ce5 cea ceb cf0 cf2 cf6
cf9 cfb cff d01 d0d d0f d11 d12
d17 d1b d1d d29 d2b d2f d33 d37
d3b d3f d43 d47 d4b d4f d5b d5f
d64 d68 d6b d6c d71 d75 d79 d7c
d7f d83 d85 d89 d8d d90 d93 d97
d99 d9d da1 da4 da6 daa dae db2
db5 db9 dbd dbf dc0 dc5 1 dc9
dcd dd1 dd4 dd8 ddc de0 de4 de7
deb def df2 df5 dfa dfd e00 e03
e04 e09 e0a 1 e0c e11 e15 e19
e1c e21 e26 e29 e2d e2e e33 e36
e3b e3c e41 e44 e49 e4a e4f e52
e56 e57 e5c e5f e64 e65 e6a e6d
e71 e75 e78 e7b e7c e7e e7f e84
e85 e8a e8c e90 e93 e95 e99 e9b
ea7 ea9 eab eac eb1 eb5 eb7 ec3
ec5 ec7 ecb ecf ed2 ed5 ed6 ed8
edb ee0 ee1 ee6 eea eee ef2 ef6
efa efe f02 f06 f0a f16 f1a f1f
f23 f26 f27 f2c f30 f34 f37 f3a
f3e f40 f44 f48 f4b f4e f52 f54
f58 f5c f5f f61 f65 f69 f6d f70
f74 f78 f7a f7b f80 1 f84 f88
f8c f8f f93 f97 f9b f9f fa2 fa6
faa fad fb0 fb5 fb8 fbb fbe fbf
fc4 fc5 1 fc7 fcc fd0 fd4 fd7
fdc fe1 fe4 fe8 fe9 fee ff1 ff6
ff7 ffc fff 1004 1005 100a 100d 1011
1012 1017 101a 101f 1020 1025 1028 102c
1030 1033 1036 1037 1039 103a 103f 1040
1045 1047 104b 104e 1050 1054 1056 1062
1064 1066 1067 106c 1070 1072 107e 1080
1084 1088 108c 1090 1094 1098 109c 10a0
10a4 10b0 10b4 10b9 10bd 10c0 10c1 10c6
10ca 10ce 10d1 10d4 10d8 10da 10de 10e2
10e5 10e8 10ec 10ee 10f2 10f6 10f9 10fb
10ff 1103 1107 110a 110e 1112 1114 1115
111a 1 111e 1122 1126 1129 112d 1131
1135 1139 113c 1140 1144 1147 114a 114f
1152 1155 1158 1159 115e 115f 1 1161
1166 116a 116e 1171 1176 117b 117e 1182
1183 1188 118b 1190 1191 1196 1199 119e
119f 11a4 11a7 11ab 11ac 11b1 11b4 11b9
11ba 11bf 11c2 11c6 11ca 11cd 11d0 11d1
11d3 11d4 11d9 11da 11df 11e1 11e5 11e8
11ea 11ee 11f0 11fc 11fe 1200 1201 1206
120a 120c 1218 121a 121c 1220 1224 1228
122c 1230 1234 1238 123c 1240 1244 1250
1254 1259 125d 1260 1261 1266 126a 126e
1271 1274 1278 127a 127e 1282 1285 1288
128c 128e 1292 1296 1299 129b 129f 12a3
12a7 12aa 12ae 12b2 12b4 12b5 12ba 1
12be 12c2 12c6 12c9 12cd 12d1 12d5 12d9
12dc 12e0 12e4 12e7 12ea 12ef 12f2 12f5
12f8 12f9 12fe 12ff 1 1301 1306 130a
130e 1311 1316 131b 131e 1322 1323 1328
132b 1330 1331 1336 1339 133e 133f 1344
1347 134b 134c 1351 1354 1359 135a 135f
1362 1366 136a 136d 1370 1371 1373 1374
1379 137a 137f 1381 1385 1388 138a 138e
1390 139c 139e 13a0 13a1 13a6 13aa 13ac
13b8 13ba 13bc 13c0 13c4 13c7 13cb 13cf
13d3 13d7 13db 13df 13e3 13e7 13eb 13f7
13fb 1400 1404 1407 1408 140d 1411 1415
1418 141b 141f 1421 1425 1429 142c 142f
1433 1435 1439 143d 1440 1442 1446 144a
144e 1451 1455 1459 145b 145c 1461 1
1465 1469 146d 1470 1474 1478 147c 1480
1483 1487 148b 148e 1491 1496 1499 149c
149f 14a0 14a5 14a6 1 14a8 14ad 14b1
14b5 14b8 14bd 14c2 14c5 14c9 14ca 14cf
14d2 14d7 14d8 14dd 14e0 14e5 14e6 14eb
14ee 14f2 14f3 14f8 14fb 1500 1501 1506
1509 150d 1511 1514 1517 1518 151a 151b
1520 1521 1526 1528 152c 152f 1531 1535
1537 1543 1545 1547 1548 154d 1551 1553
155f 1561 1563 1567 156b 156e 1570 1574
1578 157b 157f 1583 1587 158a 158b 158d
1590 1591 1593 1596 1599 159c 159d 15a2
15a5 15a9 15ad 15b0 15b1 15b3 15b6 15b9
15ba 15bf 1 15c2 15c7 15cb 15cf 15d3
15d7 15db 15dc 15de 15e1 15e2 15e4 15e7
15eb 15ef 15f3 15f4 15f6 15f9 15fa 15fc
15fd 1602 1605 1608 160b 160c 1611 1614
1617 161b 161f 1622 1623 1625 1626 162b
162c 162e 1632 1636 1639 163c 163d 1642
1645 1649 164c 164f 1652 1653 1658 1659
1 165e 1663 1667 166b 166f 1673 1677
167b 167f 1683 1687 168b 168f 1693 1697
169b 16a7 16ab 16b0 16b4 16b7 16b8 16bd
16c1 16c5 16c8 16cb 16cf 16d1 16d5 16d9
16dc 16df 16e3 16e5 16e9 16ed 16f0 16f2
16f6 16fa 16fe 1701 1705 1709 170b 170c
1711 1 1715 1719 171d 1720 1724 1728
172c 1730 1733 1737 173b 173e 1741 1746
1749 174c 174f 1750 1755 1756 1 1758
175d 1761 1765 1768 176d 1772 1775 1779
177a 177f 1782 1787 1788 178d 1790 1795
1796 179b 179e 17a2 17a3 17a8 17ab 17b0
17b1 17b6 17b9 17bd 17c1 17c4 17c7 17c8
17ca 17cb 17d0 17d1 17d6 17d8 17dc 17df
17e1 17e5 17e7 17f3 17f5 17f7 17f8 17fd
1801 1803 180f 1811 1813 1817 181a 181c
1820 1824 1828 182c 1830 1834 1838 183c
1848 184c 1851 1855 1858 1859 185e 1862
1866 1869 186c 1870 1872 1876 187a 187d
1880 1884 1886 188a 188e 1891 1893 1897
189b 189f 18a2 18a6 18aa 18ac 18ad 18b2
1 18b6 18ba 18be 18c1 18c5 18c9 18cd
18d1 18d4 18d8 18dc 18df 18e2 18e7 18ea
18ed 18f0 18f1 18f6 18f7 1 18f9 18fe
1902 1906 1909 190e 1913 1916 191a 191b
1920 1923 1928 1929 192e 1931 1936 1937
193c 193f 1943 1944 1949 194c 1951 1952
1957 195a 195e 1962 1965 1968 1969 196b
196c 1971 1972 1977 1979 197d 1980 1982
1986 1988 1994 1996 1998 1999 199e 19a2
19a4 19b0 19b2 19b4 19b8 19bc 19bf 19c3
19c7 19ca 19ce 19d1 19d5 19d8 19d9 19de
19e1 19e5 19e9 19ec 19ed 19ef 19f2 19f5
19f6 19fb 1 19fe 1a03 1a07 1a0b 1a0f
1a13 1a17 1a18 1a1a 1a1e 1a20 1a24 1a27
1a2b 1a2f 1a33 1a34 1a36 1a3a 1a3e 1a42
1a45 1a49 1a4d 1a50 1a53 1a58 1a5b 1a5e
1a61 1a62 1a67 1a68 1 1a6a 1a6f 1a73
1a77 1a7a 1a7f 1a84 1a87 1a8b 1a8c 1a91
1a94 1a99 1a9a 1a9f 1aa2 1aa7 1aa8 1aad
1ab0 1ab4 1ab8 1abc 1ac0 1ac3 1ac4 1ac6
1acb 1acc 1ace 1acf 1ad4 1ad7 1adc 1add
1ae2 1ae5 1aea 1aeb 1af0 1af3 1af7 1af8
1afd 1b00 1b05 1b06 1b0b 1b0c 1b11 1b13
1b17 1b1a 1b1e 1b22 1b25 1b29 1b2d 1b30
1b34 1b38 1b39 1b3e 1b40 1b44 1b48 1b4b
1b4f 1b53 1b56 1b5a 1b5e 1b61 1b64 1b69
1b6c 1b6f 1b72 1b73 1b78 1b79 1 1b7b
1b80 1b84 1b88 1b8b 1b90 1b95 1b98 1b9c
1b9d 1ba2 1ba3 1ba8 1bac 1bb0 1bb3 1bb8
1bbd 1bc0 1bc4 1bc8 1bcb 1bcc 1bd1 1bd4
1bd9 1bda 1bdf 1be2 1be6 1bea 1bed 1bee
1bf3 1bf4 1bf9 1bfb 1bff 1c02 1c06 1c0a
1c0e 1c12 1c16 1c1a 1c1e 1c22 1c26 1c32
1c37 1c3b 1c3f 1c43 1c47 1c49 1c4a 1c4f
1 1c53 1c57 1c5b 1c5e 1c62 1c66 1c6a
1c6e 1c71 1c75 1c79 1c7c 1c7f 1c84 1c87
1c8a 1c8d 1c8e 1c93 1c94 1 1c96 1c9b
1c9f 1ca3 1ca6 1cab 1cb0 1cb3 1cb7 1cb8
1cbd 1cbe 1cc3 1cc7 1ccb 1cce 1cd3 1cd8
1cdb 1cdf 1ce0 1ce5 1ce8 1ced 1cee 1cf3
1cf6 1cfa 1cfe 1d01 1d04 1d05 1d07 1d08
1d0d 1d0e 1d13 1d15 1d19 1d1c 1d20 1d24
1d28 1d2c 1d30 1d34 1d38 1d44 1d49 1d4d
1d51 1d55 1d59 1d5b 1d5f 1d61 1d6d 1d6f
1d71 1d72 1d77 1d7b 1d7d 1d89 1d8d 1d8f
1d90 1d99 
862
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
:3 11 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 14 23 14 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 13 22 13 :2 4 :3 17
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 5a 60 63 :2 5a 71 8d
8 :2 71 d 10 :2 71 13 16 :2 71
b e :2 71 13 16 1f 27 :2 1f
34 :2 16 :2 71 b e :2 71 13 16
:2 71 1b 1e :2 71 2a 2d :2 71 32
35 :2 71 :2 7 50 :2 4 7 :2 11 23
:2 2d 39 3c 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e :2 7
58 :3 4 11 :2 4 1b 4 e 1a
23 2d 38 46 53 c 1a 25
31 3f 4e c 23 37 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 59 5b 5c
:2 59 :2 29 :3 d :2 13 18 24 69 6c
:2 24 79 7c :2 24 80 83 :2 24 8f
92 :2 24 9a 9d :2 24 a9 ac b3
bc bf :2 ac :2 24 :2 d 5f :2 a :2 7
:4 13 :2 7 4 :3 1 7 10 1b :2 7
1e 20 :2 1e a 11 1d 20 :2 a
23 25 :2 23 14 29 2f 3c 13
27 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5f 61 62 :2 5f :2 2f
:3 13 :2 19 1e 2a 6f 72 :2 2a 7f
82 :2 2a 86 89 :2 2a 95 98 :2 2a
a0 a3 :2 2a af b2 b9 c2 c5
:2 b2 :2 2a :2 13 65 :2 10 :2 d :4 19 :2 d
a :3 29 14 11 13 27 11 26
11 1b 24 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 61 62
:2 5f :2 2f :3 13 :2 19 1e 2a 6f 72
:2 2a 7f 82 :2 2a 86 89 :2 2a 95
98 :2 2a a0 a3 :2 2a af b2 b9
c2 c5 :2 b2 :2 2a :2 13 65 :2 10 :2 d
:4 19 :2 d a :4 29 14 29 2f 3d
4e 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :7 7 11 1d 2b 34
3b 48 51 65 72 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 5c
5f 60 :2 5c :2 2c :3 10 :2 16 1b 27
6d 70 :2 27 7d 80 :2 27 84 87
:2 27 93 96 :2 27 9e a1 :2 27 ad
b0 b7 c0 c3 :2 b0 :2 27 :2 10 63
:2 d :2 a :4 16 :2 a 7 :4 22 a 13
1e :2 a 21 23 :2 21 14 29 40
58 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :3 25 14 20 2e 37
3e 4b 54 68 75 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5f
62 63 :2 5f :2 2f :3 13 :2 19 1e 2a
70 73 :2 2a 80 83 :2 2a 87 8a
:2 2a 96 99 :2 2a a1 a4 :2 2a b0
b3 ba c3 c6 :2 b3 :2 2a :2 13 66
:2 10 :2 d :4 19 :2 d a :4 25 d 14
20 23 :2 d 26 28 :2 26 17 2c
43 5b 10 16 23 16 2a 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 62 65 66 :2 62 :2 32 :3 16 :2 1c
21 2d 73 76 :2 2d 83 86 :2 2d
8a 8d :2 2d 99 9c :2 2d a4 a7
:2 2d b3 b6 bd c6 c9 :2 b6 :2 2d
:2 16 69 :2 13 :2 10 :4 1c :2 10 d :3 2c
17 14 16 2a 14 29 14 1e
27 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 62 65 66 :2 62 :2 32
:3 16 :2 1c 21 2d 73 76 :2 2d 83
86 :2 2d 8a 8d :2 2d 99 9c :2 2d
a4 a7 :2 2d b3 b6 bd c6 c9
:2 b6 :2 2d :2 16 69 :2 13 :2 10 :4 1c :2 10
d :4 2c 17 2c 43 5b 10 16
24 35 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 62 65
66 :2 62 :2 32 :3 16 :2 1c 21 2d 73
76 :2 2d 83 86 :2 2d 8a 8d :2 2d
99 9c :2 2d a4 a7 :2 2d b3 b6
bd c6 c9 :2 b6 :2 2d :2 16 69 :2 13
:2 10 :4 1c :2 10 d :7 a 14 20 2e
37 3e 4b 54 68 75 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5f 62 63 :2 5f :2 2f :3 13 :2 19 1e
2a 70 73 :2 2a 80 83 :2 2a 87
8a :2 2a 96 99 :2 2a a1 a4 :2 2a
b0 b3 ba c3 c6 :2 b3 :2 2a :2 13
66 :2 10 :2 d :4 19 :2 d a :7 7 :4 4
9 10 19 24 :2 10 28 :2 9 8
2c 2e :2 2c 7 36 3f 4f :2 36
52 54 :2 52 35 :3 7 1d 25 2e
38 :2 2e 48 :2 25 4b 4d 28 32
:2 28 41 :2 4d :2 25 24 45 47 :2 24
23 51 53 28 38 :2 53 :2 23 :2 1d
7 b 1e 20 :2 1e a 26 39
3b 3c :2 3b :2 39 :2 a 14 d 1b
24 2b 37 40 d 12 2c 39
12 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :4 3e :2 7 57 11 a
f 29 36 f 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5c 5f 60 :2 5c :2 2c :3 10 :2 16 1b
27 6d 70 :2 27 7d 80 :2 27 84
87 :2 27 93 96 :2 27 9e a1 :2 27
ad b0 b7 c0 c3 :2 b0 :2 27 :2 10
63 :2 d :2 a :4 16 :2 a 7 :7 4 8
:2 11 1c 1a :2 25 :2 1a 7 3a 43
4e :2 3a 51 54 :2 51 39 :3 7 1a
2c 3a 4f :2 1a 7 57 :3 4 17
21 :2 17 4 7 :2 11 23 :2 2d 39
3c 52 55 56 :2 52 :2 23 :3 7 :2 d
12 1e 64 67 :2 1e 74 77 :2 1e
7b 7e :2 1e 88 8b 94 9c :2 a5
:2 94 b0 :2 8b :2 1e b8 bb :2 1e c3
c6 :2 1e cb ce :2 1e d1 d4 :2 1e
:2 7 59 :3 4 :2 f 21 :2 2a 34 38
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 56 59 5a :2 56 :2 26
:3 a :2 10 15 21 67 6a :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5d
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 53 56 57 :2 53 :2 23
:3 7 :2 d 12 1e 64 67 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 5a :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
862
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :5 b
:7 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :5 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :4 18 :3 17
:11 1e :b 1f :3 1e :3 23
:3 24 :7 27 :6 28 :3 29
27 :5 2a 26 2c
:5 2d :3 2c :2 2e :5 30
:11 31 :24 32 :3 31 :2 2f
:6 2e 2b :3 16 :9 37
:a 38 :4 3a :2 3b 3a
:6 3c :5 3d 3c :5 3f
3e :3 3c 39 42
:5 43 :3 42 :2 44 :5 46
:11 47 :24 48 :3 47 :2 45
:6 44 41 :3 38 4e
4f :2 50 :2 51 :3 52
4e :6 53 :5 54 53
:5 56 55 :3 53 4d
59 :5 5a :3 59 :2 5b
:5 5d :11 5e :24 5f :3 5e
:2 5c :6 5b 58 :4 38
:5 65 :2 66 65 :6 67
:5 68 67 :5 6a 69
:3 67 64 6d :5 6e
:3 6d :2 6f :5 71 :11 72
:24 73 :3 72 :2 70 :6 6f
6c :4 63 :3 38 :a 7a
:6 7b :5 7c 7b :5 7e
7d :3 7b 79 81
:5 82 :3 81 :2 83 :5 85
:11 86 :24 87 :3 86 :2 84
:6 83 80 :4 37 :9 8c
:4 8e :2 8f 8e :6 90
:5 91 90 :5 93 92
:3 90 8d 96 :5 97
:3 96 :2 98 :5 9a :11 9b
:24 9c :3 9b :2 99 :6 98
95 :3 8c :a a2 :6 a3
:5 a4 a3 :5 a6 a5
:3 a3 a1 a9 :5 aa
:3 a9 :2 ab :5 ad :11 ae
:24 af :3 ae :2 ac :6 ab
a8 :4 8c :a b4 :4 b6
:3 b7 :2 b8 b6 :6 b9
:5 ba b9 :5 bc bb
:3 b9 b5 bf :5 c0
:3 bf :2 c1 :5 c3 :11 c4
:24 c5 :3 c4 :2 c2 :6 c1
be :3 b4 cb cc
:2 cd :2 ce :3 cf cb
:6 d0 :5 d1 d0 :5 d3
d2 :3 d0 ca d6
:5 d7 :3 d6 :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d5 :4 b4 :4 e2
:4 e3 :2 e4 e2 :6 e5
:5 e6 e5 :5 e8 e7
:3 e5 e1 eb :5 ec
:3 eb :2 ed :5 ef :11 f0
:24 f1 :3 f0 :2 ee :6 ed
ea :4 e0 :3 b4 :a f8
:6 f9 :5 fa f9 :5 fc
fb :3 f9 f7 ff
:5 100 :3 ff :2 101 :5 103
:11 104 :24 105 :3 104 :2 102
:6 101 fe :4 b3 :3 8c
8b :3 37 :1b 10c :c 10d
:5 10e :5 10d :2 10e :3 10d
:2 10e :2 10f :2 10e :5 10d
:10 110 112 :6 113 114
:3 115 116 :2 118 112
:6 119 :5 11a 119 :5 11c
11b :3 119 111 11f
:5 120 :3 11f :2 121 :5 123
:11 124 :24 125 :3 124 :2 122
:6 121 11e :6 110 10c
12c 12d :3 12e 12f
:2 131 12c :6 132 :5 133
132 :5 135 134 :3 132
12b 138 :5 139 :3 138
:2 13a :5 13c :11 13d :24 13e
:3 13d :2 13b :6 13a 137
:4 12a :3 10c :16 144 :8 146
:3 144 :6 149 :11 14c :30 14d
:3 14c :a 14f 16 :3 152
:11 153 :b 154 :17 155 :3 153
:2 157 :3 158 :3 159 15a
158 157 158 :3 15b
:3 152 :2 15c :5 15e :11 15f
:b 160 :18 161 :3 15f :2 163
164 :3 165 166 164
163 164 :3 167 :2 15d
:6 15c 151 :7 1 
1d9b
4
:3 0 1 :3 0 2
:a 0 85d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 85d 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 85b
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 85b
0 d :6 0 19
c7 0 17 4
:3 0 15 25 27
:6 0 2a 28 0
85b 0 e :6 0
14 :2 0 1d 10
:3 0 2c :7 0 2f
2d 0 85b 0
f :6 0 4 :3 0
12 :2 0 1b 31
33 :6 0 36 34
0 85b 0 11
:6 0 14 :2 0 1f
6 :3 0 38 :7 0
3c 39 3a 85b
0 13 :6 0 14
:2 0 21 6 :3 0
3e :7 0 42 3f
40 85b 0 15
:6 0 14 :2 0 23
6 :3 0 44 :7 0
48 45 46 85b
0 16 :6 0 14
:2 0 25 6 :3 0
4a :7 0 4e 4b
4c 85b 0 17
:6 0 14 :2 0 27
6 :3 0 50 :7 0
54 51 52 85b
0 18 :6 0 2b
1a7 0 29 6
:3 0 56 :7 0 5a
57 58 85b 0
19 :6 0 67 68
0 2d 6 :3 0
5c :7 0 5f 5d
0 85b 0 1a
:6 0 9 :3 0 a
:2 0 4 61 62
0 63 :7 0 66
64 0 85b 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 6a 6b
0 2 :4 0 2f
6c 6e 69 70
6f :2 0 1f :3 0
20 :3 0 72 73
0 21 :4 0 1c
:3 0 22 :3 0 76
77 0 2 :4 0
31 78 7a 23
:4 0 24 :2 0 25
:3 0 33 7d 7f
:3 0 26 :4 0 24
:2 0 27 :4 0 36
82 84 :3 0 24
:2 0 3 :3 0 39
86 88 :3 0 24
:2 0 27 :4 0 3c
8a 8c :3 0 24
:2 0 28 :4 0 3f
8e 90 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
94 96 2b :4 0
44 93 99 47
92 9b :3 0 24
:2 0 28 :4 0 4a
9d 9f :3 0 24
:2 0 27 :4 0 4d
a1 a3 :3 0 24
:2 0 7 :3 0 50
a5 a7 :3 0 24
:2 0 27 :4 0 53
a9 ab :3 0 24
:2 0 2c :4 0 56
ad af :3 0 59
74 b1 :2 0 b3
5e b4 71 b3
0 b5 60 0
7bb 1c :3 0 1d
:3 0 b6 b7 0
1c :3 0 2d :3 0
b9 ba 0 12
:2 0 2 :4 0 2e
:2 0 2f :2 0 12
:2 0 62 bf c1
:3 0 65 bb c3
b8 c5 c4 :2 0
1f :3 0 30 :3 0
c7 c8 0 21
:4 0 31 :4 0 24
:2 0 25 :3 0 69
cc ce :3 0 6c
c9 d0 :2 0 d2
6f d3 c6 d2
0 d4 71 0
7bb 13 :3 0 5
:3 0 d5 d6 0
7bb b :3 0 3
:3 0 d8 d9 0
7bb 32 :3 0 33
:3 0 34 :3 0 35
:3 0 36 :3 0 37
:3 0 38 :3 0 d
:3 0 e :3 0 11
:3 0 17 :3 0 18
:3 0 19 :3 0 39
:3 0 3a :3 0 b
:4 0 3b 1 :8 0
f1 9 :3 0 3c
:3 0 ec ed 0
3d :3 0 ee ef
0 f1 73 144
3e :3 0 9 :3 0
3c :3 0 f3 f4
0 3d :3 0 f5
f6 0 f8 76
fa 78 f9 f8
:2 0 142 3f :3 0
9 :3 0 3c :3 0
fd fe 0 3d
:3 0 ff 100 0
13a 1c :3 0 1d
:3 0 102 103 0
1c :3 0 2d :3 0
105 106 0 40
:2 0 2 :4 0 41
:2 0 2f :2 0 12
:2 0 7a 10b 10d
:3 0 7d 107 10f
104 111 110 :2 0
1f :3 0 30 :3 0
113 114 0 21
:4 0 42 :4 0 24
:2 0 25 :3 0 81
118 11a :3 0 24
:2 0 43 :4 0 84
11c 11e :3 0 24
:2 0 44 :4 0 87
120 122 :3 0 24
:2 0 3d :3 0 8a
124 126 :3 0 24
:2 0 45 :4 0 8d
128 12a :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 90 12d 131
94 12c 133 :3 0
97 115 135 :2 0
137 9a 138 112
137 0 139 9c
0 13a 9e 13d
:3 0 13d 0 13d
13c 13a 13b :6 0
13f 2 :3 0 a1
141 a3 140 13f
:2 0 142 a5 :2 0
144 0 144 143
f1 142 :6 0 7bb
1 :3 0 29 :3 0
13 :3 0 14 :2 0
a8 146 149 49
:2 0 12 :2 0 ad
14b 14d :3 0 46
:3 0 11 :3 0 12
:2 0 12 :2 0 b0
14f 153 49 :2 0
4a :4 0 b6 155
157 :3 0 39 :3 0
4b :3 0 35 :3 0
37 :3 0 3a :3 0
b :4 0 4c 1
:8 0 175 4d :4 0
160 :3 0 4e :3 0
49 :2 0 bb 163
164 :3 0 9 :3 0
3c :3 0 166 167
0 14 :2 0 168
169 0 16b be
172 9 :3 0 3c
:3 0 16c 16d 0
4f :2 0 16e 16f
0 171 c0 173
165 16b 0 174
0 171 0 174
c2 0 175 c5
1c8 3e :3 0 9
:3 0 3c :3 0 177
178 0 3d :3 0
179 17a 0 17c
c8 17e ca 17d
17c :2 0 1c6 3f
:3 0 9 :3 0 3c
:3 0 181 182 0
3d :3 0 183 184
0 1be 1c :3 0
1d :3 0 186 187
0 1c :3 0 2d
:3 0 189 18a 0
40 :2 0 2 :4 0
50 :2 0 2f :2 0
12 :2 0 cc 18f
191 :3 0 cf 18b
193 188 195 194
:2 0 1f :3 0 30
:3 0 197 198 0
21 :4 0 51 :4 0
24 :2 0 25 :3 0
d3 19c 19e :3 0
24 :2 0 43 :4 0
d6 1a0 1a2 :3 0
24 :2 0 44 :4 0
d9 1a4 1a6 :3 0
24 :2 0 3d :3 0
dc 1a8 1aa :3 0
24 :2 0 45 :4 0
df 1ac 1ae :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 e2 1b1
1b5 e6 1b0 1b7
:3 0 e9 199 1b9
:2 0 1bb ec 1bc
196 1bb 0 1bd
ee 0 1be f0
1c1 :3 0 1c1 0
1c1 1c0 1be 1bf
:6 0 1c3 4 :3 0
f3 1c5 f5 1c4
1c3 :2 0 1c6 f7
:2 0 1c8 0 1c8
1c7 175 1c6 :6 0
23e 1 :3 0 52
:3 0 53 :3 0 3a
:3 0 b :3 0 3a
:3 0 54 :3 0 55
:3 0 56 :3 0 57
:4 0 58 1 :8 0
1e9 4d :4 0 1d4
:3 0 4e :3 0 49
:2 0 fc 1d7 1d8
:3 0 9 :3 0 3c
:3 0 1da 1db 0
14 :2 0 1dc 1dd
0 1df ff 1e6
9 :3 0 3c :3 0
1e0 1e1 0 4f
:2 0 1e2 1e3 0
1e5 101 1e7 1d9
1df 0 1e8 0
1e5 0 1e8 103
0 1e9 106 23c
3e :3 0 9 :3 0
3c :3 0 1eb 1ec
0 3d :3 0 1ed
1ee 0 1f0 109
1f2 10b 1f1 1f0
:2 0 23a 3f :3 0
9 :3 0 3c :3 0
1f5 1f6 0 3d
:3 0 1f7 1f8 0
232 1c :3 0 1d
:3 0 1fa 1fb 0
1c :3 0 2d :3 0
1fd 1fe 0 40
:2 0 2 :4 0 59
:2 0 2f :2 0 12
:2 0 10d 203 205
:3 0 110 1ff 207
1fc 209 208 :2 0
1f :3 0 30 :3 0
20b 20c 0 21
:4 0 5a :4 0 24
:2 0 25 :3 0 114
210 212 :3 0 24
:2 0 43 :4 0 117
214 216 :3 0 24
:2 0 44 :4 0 11a
218 21a :3 0 24
:2 0 3d :3 0 11d
21c 21e :3 0 24
:2 0 45 :4 0 120
220 222 :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 123 225 229
127 224 22b :3 0
12a 20d 22d :2 0
22f 12d 230 20a
22f 0 231 12f
0 232 131 235
:3 0 235 0 235
234 232 233 :6 0
237 6 :3 0 134
239 136 238 237
:2 0 23a 138 :2 0
23c 0 23c 23b
1e9 23a :6 0 23e
1 :3 0 13b 2b2
39 :3 0 4b :3 0
36 :3 0 37 :3 0
38 :3 0 3a :3 0
b :4 0 5b 1
:8 0 25c 4d :4 0
247 :3 0 4e :3 0
49 :2 0 140 24a
24b :3 0 9 :3 0
3c :3 0 24d 24e
0 14 :2 0 24f
250 0 252 143
259 9 :3 0 3c
:3 0 253 254 0
4f :2 0 255 256
0 258 145 25a
24c 252 0 25b
0 258 0 25b
147 0 25c 14a
2af 3e :3 0 9
:3 0 3c :3 0 25e
25f 0 3d :3 0
260 261 0 263
14d 265 14f 264
263 :2 0 2ad 3f
:3 0 9 :3 0 3c
:3 0 268 269 0
3d :3 0 26a 26b
0 2a5 1c :3 0
1d :3 0 26d 26e
0 1c :3 0 2d
:3 0 270 271 0
40 :2 0 2 :4 0
5c :2 0 2f :2 0
12 :2 0 151 276
278 :3 0 154 272
27a 26f 27c 27b
:2 0 1f :3 0 30
:3 0 27e 27f 0
21 :4 0 5d :4 0
24 :2 0 25 :3 0
158 283 285 :3 0
24 :2 0 43 :4 0
15b 287 289 :3 0
24 :2 0 44 :4 0
15e 28b 28d :3 0
24 :2 0 3d :3 0
161 28f 291 :3 0
24 :2 0 45 :4 0
164 293 295 :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 167 298
29c 16b 297 29e
:3 0 16e 280 2a0
:2 0 2a2 171 2a3
27d 2a2 0 2a4
173 0 2a5 175
2a8 :3 0 2a8 0
2a8 2a7 2a5 2a6
:6 0 2aa 8 :3 0
178 2ac 17a 2ab
2aa :2 0 2ad 17c
:2 0 2af 0 2af
2ae 25c 2ad :6 0
2b1 1 :3 0 17f
2b3 158 23e 0
2b4 0 2b1 0
2b4 181 0 329
5e :3 0 5f :3 0
60 :3 0 61 :3 0
5f :3 0 56 :3 0
62 :3 0 54 :3 0
e :4 0 63 1
:8 0 2d4 4d :4 0
2bf :3 0 4e :3 0
49 :2 0 186 2c2
2c3 :3 0 9 :3 0
3c :3 0 2c5 2c6
0 14 :2 0 2c7
2c8 0 2ca 189
2d1 9 :3 0 3c
:3 0 2cb 2cc 0
4f :2 0 2cd 2ce
0 2d0 18b 2d2
2c4 2ca 0 2d3
0 2d0 0 2d3
18d 0 2d4 190
327 3e :3 0 9
:3 0 3c :3 0 2d6
2d7 0 3d :3 0
2d8 2d9 0 2db
193 2dd 195 2dc
2db :2 0 325 3f
:3 0 9 :3 0 3c
:3 0 2e0 2e1 0
3d :3 0 2e2 2e3
0 31d 1c :3 0
1d :3 0 2e5 2e6
0 1c :3 0 2d
:3 0 2e8 2e9 0
40 :2 0 2 :4 0
64 :2 0 2f :2 0
12 :2 0 197 2ee
2f0 :3 0 19a 2ea
2f2 2e7 2f4 2f3
:2 0 1f :3 0 30
:3 0 2f6 2f7 0
21 :4 0 65 :4 0
24 :2 0 25 :3 0
19e 2fb 2fd :3 0
24 :2 0 43 :4 0
1a1 2ff 301 :3 0
24 :2 0 44 :4 0
1a4 303 305 :3 0
24 :2 0 3d :3 0
1a7 307 309 :3 0
24 :2 0 45 :4 0
1aa 30b 30d :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 1ad 310
314 1b1 30f 316
:3 0 1b4 2f8 318
:2 0 31a 1b7 31b
2f5 31a 0 31c
1b9 0 31d 1bb
320 :3 0 320 0
320 31f 31d 31e
:6 0 322 a :3 0
1be 324 1c0 323
322 :2 0 325 1c2
:2 0 327 0 327
326 2d4 325 :6 0
329 1 :3 0 1c5
5fe 29 :3 0 13
:3 0 14 :2 0 1c8
32a 32d 49 :2 0
4a :2 0 1cd 32f
331 :3 0 39 :3 0
66 :3 0 67 :3 0
68 :3 0 3a :3 0
b :4 0 69 1
:8 0 34f 4d :4 0
33a :3 0 4e :3 0
49 :2 0 1d2 33d
33e :3 0 9 :3 0
3c :3 0 340 341
0 14 :2 0 342
343 0 345 1d5
34c 9 :3 0 3c
:3 0 346 347 0
4f :2 0 348 349
0 34b 1d7 34d
33f 345 0 34e
0 34b 0 34e
1d9 0 34f 1dc
3a2 3e :3 0 9
:3 0 3c :3 0 351
352 0 3d :3 0
353 354 0 356
1df 358 1e1 357
356 :2 0 3a0 3f
:3 0 9 :3 0 3c
:3 0 35b 35c 0
3d :3 0 35d 35e
0 398 1c :3 0
1d :3 0 360 361
0 1c :3 0 2d
:3 0 363 364 0
40 :2 0 2 :4 0
6a :2 0 2f :2 0
12 :2 0 1e3 369
36b :3 0 1e6 365
36d 362 36f 36e
:2 0 1f :3 0 30
:3 0 371 372 0
21 :4 0 6b :4 0
24 :2 0 25 :3 0
1ea 376 378 :3 0
24 :2 0 43 :4 0
1ed 37a 37c :3 0
24 :2 0 44 :4 0
1f0 37e 380 :3 0
24 :2 0 3d :3 0
1f3 382 384 :3 0
24 :2 0 45 :4 0
1f6 386 388 :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 1f9 38b
38f 1fd 38a 391
:3 0 200 373 393
:2 0 395 203 396
370 395 0 397
205 0 398 207
39b :3 0 39b 0
39b 39a 398 399
:6 0 39d c :3 0
20a 39f 20c 39e
39d :2 0 3a0 20e
:2 0 3a2 0 3a2
3a1 34f 3a0 :6 0
418 1 :3 0 5e
:3 0 5f :3 0 60
:3 0 61 :3 0 5f
:3 0 56 :3 0 62
:3 0 54 :3 0 e
:4 0 63 1 :8 0
3c3 4d :4 0 3ae
:3 0 4e :3 0 49
:2 0 213 3b1 3b2
:3 0 9 :3 0 3c
:3 0 3b4 3b5 0
14 :2 0 3b6 3b7
0 3b9 216 3c0
9 :3 0 3c :3 0
3ba 3bb 0 4f
:2 0 3bc 3bd 0
3bf 218 3c1 3b3
3b9 0 3c2 0
3bf 0 3c2 21a
0 3c3 21d 416
3e :3 0 9 :3 0
3c :3 0 3c5 3c6
0 3d :3 0 3c7
3c8 0 3ca 220
3cc 222 3cb 3ca
:2 0 414 3f :3 0
9 :3 0 3c :3 0
3cf 3d0 0 3d
:3 0 3d1 3d2 0
40c 1c :3 0 1d
:3 0 3d4 3d5 0
1c :3 0 2d :3 0
3d7 3d8 0 40
:2 0 2 :4 0 6c
:2 0 2f :2 0 12
:2 0 224 3dd 3df
:3 0 227 3d9 3e1
3d6 3e3 3e2 :2 0
1f :3 0 30 :3 0
3e5 3e6 0 21
:4 0 6d :4 0 24
:2 0 25 :3 0 22b
3ea 3ec :3 0 24
:2 0 43 :4 0 22e
3ee 3f0 :3 0 24
:2 0 44 :4 0 231
3f2 3f4 :3 0 24
:2 0 3d :3 0 234
3f6 3f8 :3 0 24
:2 0 45 :4 0 237
3fa 3fc :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 23a 3ff 403
23e 3fe 405 :3 0
241 3e7 407 :2 0
409 244 40a 3e4
409 0 40b 246
0 40c 248 40f
:3 0 40f 0 40f
40e 40c 40d :6 0
411 e :3 0 24b
413 24d 412 411
:2 0 414 24f :2 0
416 0 416 415
3c3 414 :6 0 418
1 :3 0 252 5fa
46 :3 0 11 :3 0
12 :2 0 12 :2 0
255 419 41d 49
:2 0 4a :4 0 25b
41f 421 :3 0 39
:3 0 66 :3 0 67
:3 0 68 :3 0 4b
:3 0 35 :3 0 37
:3 0 3a :3 0 b
:4 0 6e 1 :8 0
442 4d :4 0 42d
:3 0 4e :3 0 49
:2 0 260 430 431
:3 0 9 :3 0 3c
:3 0 433 434 0
14 :2 0 435 436
0 438 263 43f
9 :3 0 3c :3 0
439 43a 0 4f
:2 0 43b 43c 0
43e 265 440 432
438 0 441 0
43e 0 441 267
0 442 26a 495
3e :3 0 9 :3 0
3c :3 0 444 445
0 3d :3 0 446
447 0 449 26d
44b 26f 44a 449
:2 0 493 3f :3 0
9 :3 0 3c :3 0
44e 44f 0 3d
:3 0 450 451 0
48b 1c :3 0 1d
:3 0 453 454 0
1c :3 0 2d :3 0
456 457 0 40
:2 0 2 :4 0 6f
:2 0 2f :2 0 12
:2 0 271 45c 45e
:3 0 274 458 460
455 462 461 :2 0
1f :3 0 30 :3 0
464 465 0 21
:4 0 70 :4 0 24
:2 0 25 :3 0 278
469 46b :3 0 24
:2 0 43 :4 0 27b
46d 46f :3 0 24
:2 0 44 :4 0 27e
471 473 :3 0 24
:2 0 3d :3 0 281
475 477 :3 0 24
:2 0 45 :4 0 284
479 47b :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 287 47e 482
28b 47d 484 :3 0
28e 466 486 :2 0
488 291 489 463
488 0 48a 293
0 48b 295 48e
:3 0 48e 0 48e
48d 48b 48c :6 0
490 10 :3 0 298
492 29a 491 490
:2 0 493 29c :2 0
495 0 495 494
442 493 :6 0 50b
1 :3 0 52 :3 0
53 :3 0 3a :3 0
b :3 0 3a :3 0
54 :3 0 55 :3 0
56 :3 0 57 :4 0
71 1 :8 0 4b6
4d :4 0 4a1 :3 0
4e :3 0 49 :2 0
2a1 4a4 4a5 :3 0
9 :3 0 3c :3 0
4a7 4a8 0 14
:2 0 4a9 4aa 0
4ac 2a4 4b3 9
:3 0 3c :3 0 4ad
4ae 0 4f :2 0
4af 4b0 0 4b2
2a6 4b4 4a6 4ac
0 4b5 0 4b2
0 4b5 2a8 0
4b6 2ab 509 3e
:3 0 9 :3 0 3c
:3 0 4b8 4b9 0
3d :3 0 4ba 4bb
0 4bd 2ae 4bf
2b0 4be 4bd :2 0
507 3f :3 0 9
:3 0 3c :3 0 4c2
4c3 0 3d :3 0
4c4 4c5 0 4ff
1c :3 0 1d :3 0
4c7 4c8 0 1c
:3 0 2d :3 0 4ca
4cb 0 40 :2 0
2 :4 0 72 :2 0
2f :2 0 12 :2 0
2b2 4d0 4d2 :3 0
2b5 4cc 4d4 4c9
4d6 4d5 :2 0 1f
:3 0 30 :3 0 4d8
4d9 0 21 :4 0
73 :4 0 24 :2 0
25 :3 0 2b9 4dd
4df :3 0 24 :2 0
43 :4 0 2bc 4e1
4e3 :3 0 24 :2 0
44 :4 0 2bf 4e5
4e7 :3 0 24 :2 0
3d :3 0 2c2 4e9
4eb :3 0 24 :2 0
45 :4 0 2c5 4ed
4ef :3 0 24 :2 0
46 :3 0 47 :3 0
12 :2 0 48 :2 0
2c8 4f2 4f6 2cc
4f1 4f8 :3 0 2cf
4da 4fa :2 0 4fc
2d2 4fd 4d7 4fc
0 4fe 2d4 0
4ff 2d6 502 :3 0
502 0 502 501
4ff 500 :6 0 504
12 :3 0 2d9 506
2db 505 504 :2 0
507 2dd :2 0 509
0 509 508 4b6
507 :6 0 50b 1
:3 0 2e0 582 39
:3 0 66 :3 0 67
:3 0 68 :3 0 4b
:3 0 36 :3 0 37
:3 0 38 :3 0 3a
:3 0 b :4 0 74
1 :8 0 52c 4d
:4 0 517 :3 0 4e
:3 0 49 :2 0 2e5
51a 51b :3 0 9
:3 0 3c :3 0 51d
51e 0 14 :2 0
51f 520 0 522
2e8 529 9 :3 0
3c :3 0 523 524
0 4f :2 0 525
526 0 528 2ea
52a 51c 522 0
52b 0 528 0
52b 2ec 0 52c
2ef 57f 3e :3 0
9 :3 0 3c :3 0
52e 52f 0 3d
:3 0 530 531 0
533 2f2 535 2f4
534 533 :2 0 57d
3f :3 0 9 :3 0
3c :3 0 538 539
0 3d :3 0 53a
53b 0 575 1c
:3 0 1d :3 0 53d
53e 0 1c :3 0
2d :3 0 540 541
0 40 :2 0 2
:4 0 75 :2 0 2f
:2 0 12 :2 0 2f6
546 548 :3 0 2f9
542 54a 53f 54c
54b :2 0 1f :3 0
30 :3 0 54e 54f
0 21 :4 0 76
:4 0 24 :2 0 25
:3 0 2fd 553 555
:3 0 24 :2 0 43
:4 0 300 557 559
:3 0 24 :2 0 44
:4 0 303 55b 55d
:3 0 24 :2 0 3d
:3 0 306 55f 561
:3 0 24 :2 0 45
:4 0 309 563 565
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 30c
568 56c 310 567
56e :3 0 313 550
570 :2 0 572 316
573 54d 572 0
574 318 0 575
31a 578 :3 0 578
0 578 577 575
576 :6 0 57a 14
:3 0 31d 57c 31f
57b 57a :2 0 57d
321 :2 0 57f 0
57f 57e 52c 57d
:6 0 581 1 :3 0
324 583 422 50b
0 584 0 581
0 584 326 0
5f9 5e :3 0 5f
:3 0 60 :3 0 61
:3 0 5f :3 0 56
:3 0 62 :3 0 54
:3 0 e :4 0 63
1 :8 0 5a4 4d
:4 0 58f :3 0 4e
:3 0 49 :2 0 32b
592 593 :3 0 9
:3 0 3c :3 0 595
596 0 14 :2 0
597 598 0 59a
32e 5a1 9 :3 0
3c :3 0 59b 59c
0 4f :2 0 59d
59e 0 5a0 330
5a2 594 59a 0
5a3 0 5a0 0
5a3 332 0 5a4
335 5f7 3e :3 0
9 :3 0 3c :3 0
5a6 5a7 0 3d
:3 0 5a8 5a9 0
5ab 338 5ad 33a
5ac 5ab :2 0 5f5
3f :3 0 9 :3 0
3c :3 0 5b0 5b1
0 3d :3 0 5b2
5b3 0 5ed 1c
:3 0 1d :3 0 5b5
5b6 0 1c :3 0
2d :3 0 5b8 5b9
0 40 :2 0 2
:4 0 77 :2 0 2f
:2 0 12 :2 0 33c
5be 5c0 :3 0 33f
5ba 5c2 5b7 5c4
5c3 :2 0 1f :3 0
30 :3 0 5c6 5c7
0 21 :4 0 78
:4 0 24 :2 0 25
:3 0 343 5cb 5cd
:3 0 24 :2 0 43
:4 0 346 5cf 5d1
:3 0 24 :2 0 44
:4 0 349 5d3 5d5
:3 0 24 :2 0 3d
:3 0 34c 5d7 5d9
:3 0 24 :2 0 45
:4 0 34f 5db 5dd
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 352
5e0 5e4 356 5df
5e6 :3 0 359 5c8
5e8 :2 0 5ea 35c
5eb 5c5 5ea 0
5ec 35e 0 5ed
360 5f0 :3 0 5f0
0 5f0 5ef 5ed
5ee :6 0 5f2 16
:3 0 363 5f4 365
5f3 5f2 :2 0 5f5
367 :2 0 5f7 0
5f7 5f6 5a4 5f5
:6 0 5f9 1 :3 0
36a 5fb 332 418
0 5fc 0 5f9
0 5fc 36d 0
5fd 370 5ff 14e
329 0 600 0
5fd 0 600 372
0 7bb 79 :3 0
29 :3 0 13 :3 0
14 :2 0 375 602
605 12 :2 0 378
601 608 609 :2 0
49 :2 0 12 :2 0
37d 60b 60d :3 0
60e :2 0 29 :3 0
19 :3 0 14 :2 0
380 610 613 7a
:2 0 14 :2 0 385
615 617 :3 0 618
:2 0 60f 61a 619
:2 0 1a :3 0 7b
:3 0 29 :3 0 7c
:3 0 18 :3 0 388
61f 621 14 :2 0
38a 61e 624 7d
:2 0 29 :3 0 7c
:3 0 17 :3 0 38d
628 62a 14 :2 0
38f 627 62d 392
626 62f :3 0 630
:2 0 7e :2 0 7f
:2 0 395 632 634
:3 0 635 :2 0 80
:2 0 29 :3 0 19
:3 0 14 :2 0 398
638 63b 39b 637
63d :3 0 39e 61d
63f 61c 640 0
6ce 1a :3 0 7a
:2 0 12 :2 0 3a2
643 645 :3 0 646
:2 0 1a :3 0 81
:2 0 80 :2 0 12
:2 0 3a5 64a 64c
:3 0 3a9 649 64e
:3 0 647 650 64f
:2 0 39 :3 0 5f
:3 0 60 :3 0 61
:3 0 5f :3 0 56
:3 0 82 :3 0 83
:3 0 83 :3 0 4b
:3 0 84 :3 0 83
:3 0 3a :3 0 b
:4 0 85 1 :8 0
676 4d :4 0 661
:3 0 4e :3 0 49
:2 0 3ae 664 665
:3 0 9 :3 0 3c
:3 0 667 668 0
14 :2 0 669 66a
0 66c 3b1 673
9 :3 0 3c :3 0
66d 66e 0 4f
:2 0 66f 670 0
672 3b3 674 666
66c 0 675 0
672 0 675 3b5
0 676 3b8 6c9
3e :3 0 9 :3 0
3c :3 0 678 679
0 3d :3 0 67a
67b 0 67d 3bb
67f 3bd 67e 67d
:2 0 6c7 3f :3 0
9 :3 0 3c :3 0
682 683 0 3d
:3 0 684 685 0
6bf 1c :3 0 1d
:3 0 687 688 0
1c :3 0 2d :3 0
68a 68b 0 40
:2 0 2 :4 0 86
:2 0 2f :2 0 12
:2 0 3bf 690 692
:3 0 3c2 68c 694
689 696 695 :2 0
1f :3 0 30 :3 0
698 699 0 21
:4 0 87 :4 0 24
:2 0 25 :3 0 3c6
69d 69f :3 0 24
:2 0 43 :4 0 3c9
6a1 6a3 :3 0 24
:2 0 44 :4 0 3cc
6a5 6a7 :3 0 24
:2 0 3d :3 0 3cf
6a9 6ab :3 0 24
:2 0 45 :4 0 3d2
6ad 6af :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 3d5 6b2 6b6
3d9 6b1 6b8 :3 0
3dc 69a 6ba :2 0
6bc 3df 6bd 697
6bc 0 6be 3e1
0 6bf 3e3 6c2
:3 0 6c2 0 6c2
6c1 6bf 6c0 :6 0
6c4 18 :3 0 3e6
6c6 3e8 6c5 6c4
:2 0 6c7 3ea :2 0
6c9 0 6c9 6c8
676 6c7 :6 0 6cb
1 :3 0 3ed 6cc
651 6cb 0 6cd
3ef 0 6ce 3f1
743 39 :3 0 83
:3 0 83 :3 0 4b
:3 0 84 :3 0 83
:3 0 3a :3 0 b
:4 0 88 1 :8 0
6ed 4d :4 0 6d8
:3 0 4e :3 0 49
:2 0 3f6 6db 6dc
:3 0 9 :3 0 3c
:3 0 6de 6df 0
14 :2 0 6e0 6e1
0 6e3 3f9 6ea
9 :3 0 3c :3 0
6e4 6e5 0 4f
:2 0 6e6 6e7 0
6e9 3fb 6eb 6dd
6e3 0 6ec 0
6e9 0 6ec 3fd
0 6ed 400 740
3e :3 0 9 :3 0
3c :3 0 6ef 6f0
0 3d :3 0 6f1
6f2 0 6f4 403
6f6 405 6f5 6f4
:2 0 73e 3f :3 0
9 :3 0 3c :3 0
6f9 6fa 0 3d
:3 0 6fb 6fc 0
736 1c :3 0 1d
:3 0 6fe 6ff 0
1c :3 0 2d :3 0
701 702 0 40
:2 0 2 :4 0 89
:2 0 2f :2 0 12
:2 0 407 707 709
:3 0 40a 703 70b
700 70d 70c :2 0
1f :3 0 30 :3 0
70f 710 0 21
:4 0 8a :4 0 24
:2 0 25 :3 0 40e
714 716 :3 0 24
:2 0 43 :4 0 411
718 71a :3 0 24
:2 0 44 :4 0 414
71c 71e :3 0 24
:2 0 3d :3 0 417
720 722 :3 0 24
:2 0 45 :4 0 41a
724 726 :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 41d 729 72d
421 728 72f :3 0
424 711 731 :2 0
733 427 734 70e
733 0 735 429
0 736 42b 739
:3 0 739 0 739
738 736 737 :6 0
73b 1a :3 0 42e
73d 430 73c 73b
:2 0 73e 432 :2 0
740 0 740 73f
6ed 73e :6 0 742
1 :3 0 435 744
61b 6ce 0 745
0 742 0 745
437 0 7bb 9
:3 0 3c :3 0 746
747 0 9 :3 0
49 :2 0 8b :3 0
749 74b 0 43c
74a 74d :3 0 74e
:2 0 29 :3 0 13
:3 0 14 :2 0 43f
750 753 8c :2 0
4a :2 0 444 755
757 :3 0 758 :2 0
74f 75a 759 :2 0
15 :3 0 8d :3 0
d :3 0 b :3 0
13 :3 0 447 75d
761 75c 762 0
764 44b 765 75b
764 0 766 44d
0 7bb 15 :3 0
8e :3 0 d :3 0
44f 768 76a 767
76b 0 7bb 1c
:3 0 1d :3 0 76d
76e 0 1c :3 0
2d :3 0 770 771
0 8f :2 0 2
:4 0 90 :2 0 2f
:2 0 12 :2 0 451
776 778 :3 0 454
772 77a 76f 77c
77b :2 0 1f :3 0
30 :3 0 77e 77f
0 21 :4 0 91
:4 0 24 :2 0 25
:3 0 458 783 785
:3 0 24 :2 0 43
:4 0 45b 787 789
:3 0 24 :2 0 92
:4 0 45e 78b 78d
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3c :3 0 792
793 0 461 791
795 2b :4 0 463
790 798 466 78f
79a :3 0 24 :2 0
93 :4 0 469 79c
79e :3 0 24 :2 0
27 :4 0 46c 7a0
7a2 :3 0 24 :2 0
3 :3 0 46f 7a4
7a6 :3 0 24 :2 0
27 :4 0 472 7a8
7aa :3 0 475 780
7ac :2 0 7ae 478
7af 77d 7ae 0
7b0 47a 0 7bb
94 :3 0 95 :3 0
7b1 7b2 0 9
:3 0 3c :3 0 7b4
7b5 0 3 :3 0
4e :3 0 47c 7b3
7b9 :2 0 7bb 480
85c 9 :3 0 96
:2 0 4 7bc 7bd
0 1c :3 0 1d
:3 0 7bf 7c0 0
1c :3 0 2d :3 0
7c2 7c3 0 40
:2 0 2 :4 0 97
:2 0 2f :2 0 12
:2 0 48c 7c8 7ca
:3 0 48f 7c4 7cc
7c1 7ce 7cd :2 0
1f :3 0 30 :3 0
7d0 7d1 0 21
:4 0 98 :4 0 24
:2 0 25 :3 0 493
7d5 7d7 :3 0 496
7d2 7d9 :2 0 7f2
1f :3 0 30 :3 0
7db 7dc 0 21
:4 0 99 :4 0 24
:2 0 9 :3 0 9a
:3 0 7e1 7e2 0
499 7e0 7e4 :3 0
24 :2 0 93 :4 0
49c 7e6 7e8 :3 0
24 :2 0 9 :3 0
9b :3 0 7eb 7ec
0 49f 7ea 7ee
:3 0 4a2 7dd 7f0
:2 0 7f2 4a5 7f3
7cf 7f2 0 7f4
4a8 0 804 9c
:3 0 1b :3 0 9
:3 0 9a :3 0 9d
:3 0 9 :3 0 9b
:3 0 3 :3 0 9e
:4 0 9f 1 :a 0
800 :2 0 804 7f6
7fe :2 0 8 :3 0
1b :3 0 802 :2 0
804 4aa 806 4ae
805 804 :2 0 85a
3f :3 0 9 :3 0
3c :3 0 809 80a
0 3d :3 0 80b
80c 0 852 1c
:3 0 1d :3 0 80e
80f 0 1c :3 0
2d :3 0 811 812
0 40 :2 0 2
:4 0 a0 :2 0 2f
:2 0 12 :2 0 4b0
817 819 :3 0 4b3
813 81b 810 81d
81c :2 0 1f :3 0
30 :3 0 81f 820
0 21 :4 0 a1
:4 0 24 :2 0 25
:3 0 4b7 824 826
:3 0 4ba 821 828
:2 0 842 1f :3 0
30 :3 0 82a 82b
0 21 :4 0 44
:4 0 24 :2 0 3d
:3 0 4bd 82f 831
:3 0 24 :2 0 45
:4 0 4c0 833 835
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 4c3
838 83c 4c7 837
83e :3 0 4ca 82c
840 :2 0 842 4cd
843 81e 842 0
844 4d0 0 852
9c :3 0 1b :3 0
9d :3 0 9 :3 0
9b :3 0 3 :3 0
9e :4 0 a2 1
:a 0 84e :2 0 852
846 84c :2 0 8
:3 0 1b :3 0 850
:2 0 852 4d2 855
:3 0 855 0 855
854 852 853 :6 0
857 1 :3 0 4d7
859 4d9 858 857
:2 0 85a 4db :2 0
85c 4de 85c 85b
7bb 85a :6 0 85d
:2 0 2 14 85c
860 :3 0 85f 85d
861 :8 0 
4ec
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2b 1 32 1
30 1 37 1
3d 1 43 1
49 1 4f 1
55 1 5b 1
60 1 6d 1
79 2 7c 7e
2 81 83 2
85 87 2 89
8b 2 8d 8f
1 95 2 97
98 2 91 9a
2 9c 9e 2
a0 a2 2 a4
a6 2 a8 aa
2 ac ae 4
75 7b 80 b0
1 b2 1 b4
2 be c0 3
bc bd c2 2
cb cd 2 ca
cf 1 d1 1
d3 2 eb f0
1 f7 1 f2
2 10a 10c 3
108 109 10e 2
117 119 2 11b
11d 2 11f 121
2 123 125 2
127 129 3 12e
12f 130 2 12b
132 2 116 134
1 136 1 138
2 101 139 1
13d 1 fc 2
fa 141 2 147
148 1 14c 2
14a 14c 3 150
151 152 1 156
2 154 156 1
162 2 161 162
1 16a 1 170
2 172 173 2
15f 174 1 17b
1 176 2 18e
190 3 18c 18d
192 2 19b 19d
2 19f 1a1 2
1a3 1a5 2 1a7
1a9 2 1ab 1ad
3 1b2 1b3 1b4
2 1af 1b6 2
19a 1b8 1 1ba
1 1bc 2 185
1bd 1 1c1 1
180 2 17e 1c5
1 1d6 2 1d5
1d6 1 1de 1
1e4 2 1e6 1e7
2 1d3 1e8 1
1ef 1 1ea 2
202 204 3 200
201 206 2 20f
211 2 213 215
2 217 219 2
21b 21d 2 21f
221 3 226 227
228 2 223 22a
2 20e 22c 1
22e 1 230 2
1f9 231 1 235
1 1f4 2 1f2
239 2 1c8 23c
1 249 2 248
249 1 251 1
257 2 259 25a
2 246 25b 1
262 1 25d 2
275 277 3 273
274 279 2 282
284 2 286 288
2 28a 28c 2
28e 290 2 292
294 3 299 29a
29b 2 296 29d
2 281 29f 1
2a1 1 2a3 2
26c 2a4 1 2a8
1 267 2 265
2ac 1 2af 2
2b2 2b3 1 2c1
2 2c0 2c1 1
2c9 1 2cf 2
2d1 2d2 2 2be
2d3 1 2da 1
2d5 2 2ed 2ef
3 2eb 2ec 2f1
2 2fa 2fc 2
2fe 300 2 302
304 2 306 308
2 30a 30c 3
311 312 313 2
30e 315 2 2f9
317 1 319 1
31b 2 2e4 31c
1 320 1 2df
2 2dd 324 2
2b4 327 2 32b
32c 1 330 2
32e 330 1 33c
2 33b 33c 1
344 1 34a 2
34c 34d 2 339
34e 1 355 1
350 2 368 36a
3 366 367 36c
2 375 377 2
379 37b 2 37d
37f 2 381 383
2 385 387 3
38c 38d 38e 2
389 390 2 374
392 1 394 1
396 2 35f 397
1 39b 1 35a
2 358 39f 1
3b0 2 3af 3b0
1 3b8 1 3be
2 3c0 3c1 2
3ad 3c2 1 3c9
1 3c4 2 3dc
3de 3 3da 3db
3e0 2 3e9 3eb
2 3ed 3ef 2
3f1 3f3 2 3f5
3f7 2 3f9 3fb
3 400 401 402
2 3fd 404 2
3e8 406 1 408
1 40a 2 3d3
40b 1 40f 1
3ce 2 3cc 413
2 3a2 416 3
41a 41b 41c 1
420 2 41e 420
1 42f 2 42e
42f 1 437 1
43d 2 43f 440
2 42c 441 1
448 1 443 2
45b 45d 3 459
45a 45f 2 468
46a 2 46c 46e
2 470 472 2
474 476 2 478
47a 3 47f 480
481 2 47c 483
2 467 485 1
487 1 489 2
452 48a 1 48e
1 44d 2 44b
492 1 4a3 2
4a2 4a3 1 4ab
1 4b1 2 4b3
4b4 2 4a0 4b5
1 4bc 1 4b7
2 4cf 4d1 3
4cd 4ce 4d3 2
4dc 4de 2 4e0
4e2 2 4e4 4e6
2 4e8 4ea 2
4ec 4ee 3 4f3
4f4 4f5 2 4f0
4f7 2 4db 4f9
1 4fb 1 4fd
2 4c6 4fe 1
502 1 4c1 2
4bf 506 2 495
509 1 519 2
518 519 1 521
1 527 2 529
52a 2 516 52b
1 532 1 52d
2 545 547 3
543 544 549 2
552 554 2 556
558 2 55a 55c
2 55e 560 2
562 564 3 569
56a 56b 2 566
56d 2 551 56f
1 571 1 573
2 53c 574 1
578 1 537 2
535 57c 1 57f
2 582 583 1
591 2 590 591
1 599 1 59f
2 5a1 5a2 2
58e 5a3 1 5aa
1 5a5 2 5bd
5bf 3 5bb 5bc
5c1 2 5ca 5cc
2 5ce 5d0 2
5d2 5d4 2 5d6
5d8 2 5da 5dc
3 5e1 5e2 5e3
2 5de 5e5 2
5c9 5e7 1 5e9
1 5eb 2 5b4
5ec 1 5f0 1
5af 2 5ad 5f4
2 584 5f7 2
5fa 5fb 1 5fc
2 5fe 5ff 2
603 604 2 606
607 1 60c 2
60a 60c 2 611
612 1 616 2
614 616 1 620
2 622 623 1
629 2 62b 62c
2 625 62e 2
631 633 2 639
63a 2 636 63c
1 63e 1 644
2 642 644 1
64b 1 64d 2
648 64d 1 663
2 662 663 1
66b 1 671 2
673 674 2 660
675 1 67c 1
677 2 68f 691
3 68d 68e 693
2 69c 69e 2
6a0 6a2 2 6a4
6a6 2 6a8 6aa
2 6ac 6ae 3
6b3 6b4 6b5 2
6b0 6b7 2 69b
6b9 1 6bb 1
6bd 2 686 6be
1 6c2 1 681
2 67f 6c6 1
6c9 1 6cc 2
641 6cd 1 6da
2 6d9 6da 1
6e2 1 6e8 2
6ea 6eb 2 6d7
6ec 1 6f3 1
6ee 2 706 708
3 704 705 70a
2 713 715 2
717 719 2 71b
71d 2 71f 721
2 723 725 3
72a 72b 72c 2
727 72e 2 712
730 1 732 1
734 2 6fd 735
1 739 1 6f8
2 6f6 73d 1
740 2 743 744
1 74c 2 748
74c 2 751 752
1 756 2 754
756 3 75e 75f
760 1 763 1
765 1 769 2
775 777 3 773
774 779 2 782
784 2 786 788
2 78a 78c 1
794 2 796 797
2 78e 799 2
79b 79d 2 79f
7a1 2 7a3 7a5
2 7a7 7a9 2
781 7ab 1 7ad
1 7af 3 7b6
7b7 7b8 b b5
d4 d7 da 144
600 745 766 76c
7b0 7ba 2 7c7
7c9 3 7c5 7c6
7cb 2 7d4 7d6
2 7d3 7d8 2
7df 7e3 2 7e5
7e7 2 7e9 7ed
2 7de 7ef 2
7da 7f1 1 7f3
3 7f4 7ff 803
1 7be 2 816
818 3 814 815
81a 2 823 825
2 822 827 2
82e 830 2 832
834 3 839 83a
83b 2 836 83d
2 82d 83f 2
829 841 1 843
4 80d 844 84d
851 1 855 1
808 2 806 859
d 1b 22 29
2e 35 3b 41
47 4d 53 59
5e 65 
1
4
0 
860
0
1
28
1c
11
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
3 1 0
55 1 0
16 1 0
2 0 1
3d 1 0
2b 1 0
37 1 0
49 1 0
24 1 0
4f 1 0
30 1 0
43 1 0
1d 1 0
7 1 0
5b 1 0
60 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_ASSIGN;
ALTER FUNCTION SP_RJCT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
eb
2 :e:
1FUNCTION:
1SP_RJCT_ETC_WBS:
1ID:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_FINISH_DATE:
1TIMESTAMP:
1H_PROJECT_ID:
132:
1H_RANK:
1200:
1H_START_DATE:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_EFFORT:
1H_TYPE:
1H_START_D:
1DATE:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_TEMP_SC_NODATA:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_TEMP_SC_STATE_ALERT:
1H_ALERT_ID:
1H_REC_USER:
1H_CALLTYPE:
1H_TABLE_TYPE:
1I_STEPS_EXIST:
1I_PERCENT_COMPLETE:
1CURSOR:
1CAWTSKR:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1PROJECT_ID:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WHEN FORECAST_+
1START IS NULL THEN SCHED_START ELSE FORECAST_START END,:n         CASE WHEN F+
1ORECAST_FINISH IS NULL THEN SCHED_FINISH ELSE FORECAST_FINISH END:n         F+
1ROM TMT_WBS:n         WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank AN+
1D TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE2,+
1pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_cn+
1st.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_RE+
1QUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_cns+
1t.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT_T+
1ASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK):n         AND (((SCHED_EFFORT+PLANN+
1ED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_TODATE) <> ETC)):n     +
1    OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1CAWASSR:
1TSK_ASSIGNMENT_ID:
1BIT_FLAG:
1BEST:
1SCHED_WORK:
1PLANNED_WORK:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG, BEST, SCHED_WORK+PLANNED_WORK, WORK_TODAT+
1E, MILESTONE_PERCENT:n         FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_+
1ID = h_project_id:n         AND TASK_ID = h_task_id:n         AND (((SCHED_WO+
1RK+PLANNED_WORK) > 0 AND ((SCHED_WORK+PLANNED_WORK-WORK_TODATE) <> ETC)):n   +
1      OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_WBS(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_WBS(61) :: cplan.sql(21141) :: :
13:
1SCETCFORCASTREJECTED:
1RTRIM:
1SELECT PROJECT_ID, RTRIM(RANK), TYPE_ID:n      INTO h_project_id, h_rank, h_t+
1ype:n      FROM TMT_WBS WHERE ELEMENT_ID = id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
185:
1           EXCEPTION:: SP_RJCT_ETC_WBS(86) :: cplan.sql(21166) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1START_FINISH_DATE:
1SELECT START_FINISH_DATE INTO h_start_D FROM TMT_WBS WHERE ELEMENT_ID = h_pro+
1ject_id:
1105:
1           EXCEPTION:: SP_RJCT_ETC_WBS(106) :: cplan.sql(21186) :: :
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FORECAST_DURATION:
1UPDATE TMT_WBS SET:n                  FORECAST_START = NULL,:n               +
1   FORECAST_FINISH = NULL,:n                  FORECAST_DURATION = 0:n        +
1          WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1147:
1           EXCEPTION:: SP_RJCT_ETC_WBS(148) :: cplan.sql(21228) :: :
1FC_ISSUE_ALERT:
1CONTINUE0000:
1ACTIVITIES:
1ETC_MODIFIED:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n                        SET ETC_MODIFIED = 'N':n          +
1              WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n                +
1        AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                        AND TYPE+
1_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1198:
1           EXCEPTION:: SP_RJCT_ETC_WBS(199) :: cplan.sql(21279) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                                BAK_ASSIGN_STRIN+
1G = NULL:n                           WHERE TSK_ASSIGNMENT_ID = H_TSK_ASSIGNME+
1NT_ID:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1ASSIGN_STRING:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n                           PROPOSED_START      =+
1 SCHED_START,:n                           PROPOSED_FINISH     = SCHED_FINISH,+
1:n                           PROPOSED_WORK       = SCHED_WORK,:n             +
1              BAK_START_DT        = SCHED_START,:n                           +
1BAK_FINISH_DT       = SCHED_FINISH,:n                           BAK_WORK     +
1       = SCHED_WORK,:n                           BAK_ASSIGN_STRING   = ASSIGN+
1_STRING,:n                           BEST                = SCHED_WORK,:n     +
1                      ETC                 = SCHED_WORK - WORK_TODATE,:n      +
1                     ACTUAL_FINISH       = NULL:n                           W+
1HERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1233:
1           EXCEPTION:: SP_RJCT_ETC_WBS(234) :: cplan.sql(21314) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           SCHED_WORK	= SCHED_WO+
1RK,:n                           ETC			= SCHED_WORK - WORK_TODATE:n           +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1263:
1           EXCEPTION:: SP_RJCT_ETC_WBS(264) :: cplan.sql(21344) :: :
1ACTUAL_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n                        ETC					= PLANNED_WORK, +
1:n                        MILESTONE_PERCENT	= 0 ,:n                        AC+
1TUAL_FINISH		= NULL, :n                        ACTUAL_DURATION		= 0:n        +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1288:
1           EXCEPTION:: SP_RJCT_ETC_WBS(289) :: cplan.sql(21369) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        FORECAST_START = NULL,:n+
1                        FORECAST_FINISH = NULL,:n                        FORE+
1CAST_DURATION = 0:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
1315:
1           EXCEPTION:: SP_RJCT_ETC_WBS(316) :: cplan.sql(21396) :: :
1UPDATE ACTIVITIES:n                           SET ETC_MODIFIED = 'N':n       +
1                    WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n          +
1                 AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                       +
1    AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1340:
1           EXCEPTION:: SP_RJCT_ETC_WBS(341) :: cplan.sql(21421) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           SCHED_WORK = CASE WHE+
1N PROPOSED_WORK > WORK_TODATE THEN PROPOSED_WORK ELSE SCHED_WORK END,:n      +
1                     ETC = CASE WHEN PROPOSED_WORK > WORK_TODATE THEN PROPOSE+
1D_WORK - WORK_TODATE ELSE 0 END/*,:n                           MILESTONE_PERC+
1ENT = (WORK_TODATE * 10000) / SCHED_WORK*/:n                           WHERE +
1TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1366:
1           EXCEPTION:: SP_RJCT_ETC_WBS(367) :: cplan.sql(21447) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           ETC = PLANNED_WORK, M+
1ILESTONE_PERCENT = 0:n                           WHERE TSK_ASSIGNMENT_ID = h_+
1tsk_assignment_id:
1390:
1           EXCEPTION:: SP_RJCT_ETC_WBS(391) :: cplan.sql(21471) :: :
1SC_SQL_NO_DATA:
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1<:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET:n                           ROLLUP_BITS = PMO_STP+
1U.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCENT_COMPLETE_BIT),:n                    +
1       ACTUAL_FINISH = CASE:n                           WHEN ACTUAL_FINISH IS+
1 NULL AND ETC = 0 THEN SCHED_FINISH:n                           ELSE ACTUAL_F+
1INISH:n                           END:n                           WHERE TSK_A+
1SSIGNMENT_ID = h_tsk_assignment_id:
1434:
1           EXCEPTION:: SP_RJCT_ETC_WBS(435) :: cplan.sql(21515) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           ACTUAL_FINISH = CASE +
1WHEN (ACTUAL_FINISH IS NULL) AND ETC = 0 THEN SCHED_FINISH ELSE ACTUAL_FINISH+
1 END:n                           WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1455:
1           EXCEPTION:: SP_RJCT_ETC_WBS(456) :: cplan.sql(21536) :: :
1FC_FIX_SUMMARY_TS:
1CLOSE:
1480:
1           EXCEPTION:: SP_RJCT_ETC_WBS(481) :: cplan.sql(21561) :: :
1CONSTRAINT_TYPE:
1TO_DATE:
1CONSTRAINT_DT:
1UPDATE TMT_WBS SET:n            CONSTRAINT_TYPE =:n            CASE:n        +
1    WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> TO_DATE(SubStr(h_start_D, 1, +
110)) THEN 6:n            ELSE 0:n            END,:n            CONSTRAINT_DT +
1=:n            CASE:n            WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> +
1TO_DATE(SubStr(h_start_D, 1, 10)) THEN SCHED_START:n            ELSE NULL:n  +
1          END:n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h+
1_task_id:
1512:
1           EXCEPTION:: SP_RJCT_ETC_WBS(513) :: cplan.sql(21593) :: :
1531:
1           EXCEPTION:: SP_RJCT_ETC_WBS(532) :: cplan.sql(21612) :: :
1FC_ROLLUP:
14:
1543:
1       RETURN_STATUS:: SP_RJCT_ETC_WBS(544) :: cplan.sql(21624) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1550:
1           EXCEPTION:: SP_RJCT_ETC_WBS(551) :: cplan.sql(21631) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1562:
1           EXCEPTION:: SP_RJCT_ETC_WBS(563) :: cplan.sql(21643) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
b49
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a0 f4 b4
bf c8 :35 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :14 a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d a0 51 d a0 6e
d :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 7e b4 2e
:2 5a a 10 :3 a0 7e 6e b4 2e
:2 51 a5 b d a0 7e 51 b4
2e d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 e9 dd b3
:6 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :8 a0 51 a5 b a5
b d b7 a0 3b b7 :2 19 3c
b7 :2 a0 e9 dd b3 :8 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 :2 51 a5 b 7e 6e b4 2e
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e :4 a0 12a :17 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 a0 51 a5
b 7e 51 b4 2e :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d b7 19 3c a0
51 d :8 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 51 a5 b
5a 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :5 a0 a5 b 51 a5 b 7e
:3 a0 a5 b 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e :2 a0
51 a5 b b4 2e a5 b d
a0 7e 51 b4 2e 5a a0 :2 7e
51 b4 2e b4 2e 52 10 :e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :5 a0 a5 b d b7
19 3c b7 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :14 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f 93 4f
b0 46 b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e :3 a0 a5 b d b7 19
3c b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
b49
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 82 71
75 7d 70 9f 8d 6d 91 92
9a 8c bc aa 89 ae af b7
a9 d8 c7 cb d3 a6 f4 df
e3 e6 e7 ef c6 111 ff c3
103 104 10c fe 12e 11c fb 120
121 129 11b 14a 139 13d 118 145
138 166 155 159 135 161 154 182
171 175 151 17d 170 19e 18d 191
199 16d 1b9 1a5 1a9 1b1 1b4 18c
1d5 1c4 1c8 189 1d0 1c3 1f1 1e0
1e4 1c0 1ec 1df 20d 1fc 200 1dc
208 1fb 229 218 21c 1f8 224 217
245 234 238 214 240 233 261 250
254 230 25c 24f 27d 26c 270 24c
278 26b 29a 288 268 28c 28d 295
287 2b7 2a5 284 2a9 2aa 2b2 2a4
2d3 2c2 2c6 2a1 2ce 2c1 2ef 2de
2e2 2be 2ea 2dd 30b 2fa 2fe 2da
306 2f9 327 316 31a 322 2f6 312
32e 33f 340 343 347 34b 34f 353
357 35b 35f 363 367 36b 36f 373
377 37b 37f 383 387 38b 38f 393
397 39b 39f 3a3 3a7 3ab 3af 3b3
3b7 3bb 3bf 3c3 3c7 3cb 3cf 3d3
3d7 3db 3df 3e3 3e7 3eb 3ef 3f3
3f7 3fb 3ff 403 407 40b 40f 413
417 41b 427 42c 42e 43a 43e 440
444 455 456 459 45d 461 465 469
46d 471 475 479 47d 481 485 489
48d 491 495 499 49d 4a1 4a5 4a9
4ad 4b9 4be 4c0 4cc 4d0 4ee 4d6
4da 4de 4e1 4e9 4d5 4f5 4f9 4d2
4fd 501 505 508 50d 50e 1 510
515 519 51d 520 525 529 52d 530
535 536 538 53d 540 544 545 54a
54f 552 557 558 55d 560 564 565
56a 56d 572 573 578 57b 580 581
586 589 58d 591 595 596 598 59d
59e 5a0 5a1 5a6 5a9 5ae 5af 5b4
5b7 5bc 5bd 5c2 5c5 5c9 5ca 5cf
5d2 5d7 5d8 5dd 5e0 5e5 5e6 5eb
5ec 5f1 5f3 5f7 5fa 5fe 602 605
609 60d 610 613 618 61b 61e 621
622 627 628 1 62a 62f 633 637
63a 63f 644 647 64b 64c 651 652
657 659 65d 660 664 668 66c 670
674 678 67c 67f 683 687 68c 690
694 698 69c 6a0 6a4 6a8 6ac 6b0
6b4 6b8 6c4 6c8 6cc 6cf 6d3 6d7
6d9 6dd 6e1 6e5 6e8 6ec 6f0 6f2
6f3 6f8 1 6fc 700 704 707 70b
70f 713 717 71a 71e 722 725 728
72d 730 733 736 737 73c 73d 1
73f 744 748 74c 74f 754 759 75c
760 761 766 769 76e 76f 774 777
77c 77d 782 785 789 78a 78f 792
797 798 79d 7a0 7a4 7a8 7ab 7ae
7af 7b1 7b2 7b7 7b8 7bd 7bf 7c3
7c6 7c8 7cc 7ce 7da 7dc 7de 7df
7e4 7e8 7ea 7f6 7f8 7fc 800 803
807 80a 80e 811 812 817 81a 81e
821 822 827 82a 1 82d 832 836
83a 83e 841 846 847 84c 84f 852
853 855 859 85d 860 863 864 869
86d 871 875 879 87d 881 88d 891
895 898 89c 8a0 8a2 8a6 8aa 8ae
8b1 8b5 8b9 8bb 8bc 8c1 1 8c5
8c9 8cd 8d0 8d4 8d8 8dc 8e0 8e3
8e7 8eb 8ee 8f1 8f6 8f9 8fc 8ff
900 905 906 1 908 90d 911 915
918 91d 922 925 929 92a 92f 932
937 938 93d 940 945 946 94b 94e
952 953 958 95b 960 961 966 969
96d 971 974 977 978 97a 97b 980
981 986 988 98c 98f 991 995 997
9a3 9a5 9a7 9a8 9ad 9b1 9b3 9bf
9c1 9c5 9c9 9ce 9d2 9d3 9d7 9db
9df 9e3 9e7 9eb 9f0 9f5 9f9 9fd
a01 a06 a0a a0e a11 a14 a18 a1a
a1e a22 a25 a28 a2c a2e a32 a36
a39 a3d a41 a44 a48 a4b a4f a52
a53 a58 a5b a5f a65 a67 a6b a6e
a72 a76 a79 a7a a7c a7f a82 a83
a88 a8c a90 a93 a94 a96 a99 a9c
a9d aa2 aa6 aaa aae ab2 ab6 aba
abe ac2 ace ad2 ad7 adb ade adf
ae4 ae8 aec aef af2 af6 af8 afc
b00 b03 b06 b0a b0c b10 b14 b17
b19 b1d b21 b25 b28 b2c b30 b32
b33 b38 1 b3c b40 b44 b47 b4b
b4f b53 b57 b5a b5e b62 b65 b68
b6d b70 b73 b76 b77 b7c b7d 1
b7f b84 b88 b8c b8f b94 b99 b9c
ba0 ba1 ba6 ba9 bae baf bb4 bb7
bbc bbd bc2 bc5 bc9 bca bcf bd2
bd7 bd8 bdd be0 be4 be8 beb bee
bef bf1 bf2 bf7 bf8 bfd bff c03
c06 c08 c0c c0e c1a c1c c1e c1f
c24 c28 c2a c36 c38 c3c c3f c43
c47 c4b c4f c53 c57 c5b c5f c63
c66 c67 c69 c6a c6c c70 c72 c76
c7c c7e c82 c86 c89 c8b c8f c93
c98 c9c c9d ca1 ca5 ca9 cad cb1
cb5 cb9 cbd cc2 cc7 ccb ccf cd3
cd8 cdc ce0 ce3 ce6 cea cec cf0
cf4 cf7 cfa cfe d00 d04 d08 d0b
d0f d13 d16 d1a d1d d21 d24 d25
d2a d2d d31 d37 d39 d3d d40 d44
d47 d4b d4f d53 d56 d57 d59 d5c
d5f d60 d65 d69 d6d d70 d73 d74
d76 d79 d7e d7f d84 d88 d8c d90
d94 d98 d9c da0 da4 da8 db4 db8
dbd dc1 dc4 dc5 dca dce dd2 dd5
dd8 ddc dde de2 de6 de9 dec df0
df2 df6 dfa dfd dff e03 e07 e0b
e0e e12 e16 e18 e19 e1e 1 e22
e26 e2a e2d e31 e35 e39 e3d e40
e44 e48 e4b e4e e53 e56 e59 e5c
e5d e62 e63 1 e65 e6a e6e e72
e75 e7a e7f e82 e86 e87 e8c e8f
e94 e95 e9a e9d ea2 ea3 ea8 eab
eaf eb0 eb5 eb8 ebd ebe ec3 ec6
eca ece ed1 ed4 ed5 ed7 ed8 edd
ede ee3 ee5 ee9 eec eee ef2 ef4
f00 f02 f04 f05 f0a f0e f10 f1c
f1e f22 f26 f29 f2a f2c f2f f32
f35 f36 f3b f3c f41 f45 f49 f4d
f51 f5d f61 f65 f69 f6d f71 f75
f79 f7d f81 f85 f89 f8d f91 f95
f99 f9d fa1 fa5 fa9 fad fb1 fb5
fb9 fc5 fc9 fce fd2 fd5 fd6 fdb
fdf fe3 fe6 fe9 fed fef ff3 ff7
ffa ffd 1001 1003 1007 100b 100e 1010
1014 1018 101c 101f 1023 1027 1029 102a
102f 1 1033 1037 103b 103e 1042 1046
104a 104e 1051 1055 1059 105c 105f 1064
1067 106a 106d 106e 1073 1074 1 1076
107b 107f 1083 1086 108b 1090 1093 1097
1098 109d 10a0 10a5 10a6 10ab 10ae 10b3
10b4 10b9 10bc 10c0 10c1 10c6 10c9 10ce
10cf 10d4 10d7 10db 10df 10e2 10e5 10e6
10e8 10e9 10ee 10ef 10f4 10f6 10fa 10fd
10ff 1103 1105 1111 1113 1115 1116 111b
111f 1121 112d 112f 1131 1135 1139 113d
1141 1145 1149 114d 1151 115d 1161 1166
116a 116d 116e 1173 1177 117b 117e 1181
1185 1187 118b 118f 1192 1195 1199 119b
119f 11a3 11a6 11a8 11ac 11b0 11b4 11b7
11bb 11bf 11c1 11c2 11c7 1 11cb 11cf
11d3 11d6 11da 11de 11e2 11e6 11e9 11ed
11f1 11f4 11f7 11fc 11ff 1202 1205 1206
120b 120c 1 120e 1213 1217 121b 121e
1223 1228 122b 122f 1230 1235 1238 123d
123e 1243 1246 124b 124c 1251 1254 1258
1259 125e 1261 1266 1267 126c 126f 1273
1277 127a 127d 127e 1280 1281 1286 1287
128c 128e 1292 1295 1297 129b 129d 12a9
12ab 12ad 12ae 12b3 12b7 12b9 12c5 12c7
12c9 12cd 12d1 12d4 12d6 12da 12de 12e2
12e6 12ea 12ee 12f2 12f6 1302 1306 130b
130f 1312 1313 1318 131c 1320 1323 1326
132a 132c 1330 1334 1337 133a 133e 1340
1344 1348 134b 134d 1351 1355 1359 135c
1360 1364 1366 1367 136c 1 1370 1374
1378 137b 137f 1383 1387 138b 138e 1392
1396 1399 139c 13a1 13a4 13a7 13aa 13ab
13b0 13b1 1 13b3 13b8 13bc 13c0 13c3
13c8 13cd 13d0 13d4 13d5 13da 13dd 13e2
13e3 13e8 13eb 13f0 13f1 13f6 13f9 13fd
13fe 1403 1406 140b 140c 1411 1414 1418
141c 141f 1422 1423 1425 1426 142b 142c
1431 1433 1437 143a 143c 1440 1442 144e
1450 1452 1453 1458 145c 145e 146a 146c
146e 1472 1476 1479 147b 147f 1483 1486
1487 1489 148c 148f 1490 1495 1499 149d
14a1 14a5 14a9 14ad 14b9 14bd 14c2 14c6
14c9 14ca 14cf 14d3 14d7 14da 14dd 14e1
14e3 14e7 14eb 14ee 14f1 14f5 14f7 14fb
14ff 1502 1504 1508 150c 1510 1513 1517
151b 151d 151e 1523 1 1527 152b 152f
1532 1536 153a 153e 1542 1545 1549 154d
1550 1553 1558 155b 155e 1561 1562 1567
1568 1 156a 156f 1573 1577 157a 157f
1584 1587 158b 158c 1591 1594 1599 159a
159f 15a2 15a7 15a8 15ad 15b0 15b4 15b5
15ba 15bd 15c2 15c3 15c8 15cb 15cf 15d3
15d6 15d9 15da 15dc 15dd 15e2 15e3 15e8
15ea 15ee 15f1 15f3 15f7 15f9 1605 1607
1609 160a 160f 1613 1615 1621 1623 1625
1629 162d 1630 1633 1634 1636 1639 163e
163f 1644 1648 164c 1650 1654 1658 165c
1660 1664 1668 1674 1678 167d 1681 1684
1685 168a 168e 1692 1695 1698 169c 169e
16a2 16a6 16a9 16ac 16b0 16b2 16b6 16ba
16bd 16bf 16c3 16c7 16cb 16ce 16d2 16d6
16d8 16d9 16de 1 16e2 16e6 16ea 16ed
16f1 16f5 16f9 16fd 1700 1704 1708 170b
170e 1713 1716 1719 171c 171d 1722 1723
1 1725 172a 172e 1732 1735 173a 173f
1742 1746 1747 174c 174f 1754 1755 175a
175d 1762 1763 1768 176b 176f 1770 1775
1778 177d 177e 1783 1786 178a 178e 1791
1794 1795 1797 1798 179d 179e 17a3 17a5
17a9 17ac 17ae 17b2 17b4 17c0 17c2 17c4
17c5 17ca 17ce 17d0 17dc 17de 17e2 17e6
17ea 17ee 17f2 17f6 17fa 17fe 1802 1806
180a 180e 1812 1816 181a 181e 182a 182e
1833 1837 183a 183b 1840 1844 1848 184b
184e 1852 1854 1858 185c 185f 1862 1866
1868 186c 1870 1873 1875 1879 187d 1881
1884 1888 188c 188e 188f 1894 1 1898
189c 18a0 18a3 18a7 18ab 18af 18b3 18b6
18ba 18be 18c1 18c4 18c9 18cc 18cf 18d2
18d3 18d8 18d9 1 18db 18e0 18e4 18e8
18eb 18f0 18f5 18f8 18fc 18fd 1902 1905
190a 190b 1910 1913 1918 1919 191e 1921
1925 1926 192b 192e 1933 1934 1939 193c
1940 1944 1947 194a 194b 194d 194e 1953
1954 1959 195b 195f 1962 1964 1968 196a
1976 1978 197a 197b 1980 1984 1986 1992
1994 1996 199a 199e 19a2 19a6 19aa 19ae
19b2 19b6 19ba 19c6 19ca 19cf 19d3 19d6
19d7 19dc 19e0 19e4 19e7 19ea 19ee 19f0
19f4 19f8 19fb 19fe 1a02 1a04 1a08 1a0c
1a0f 1a11 1a15 1a19 1a1d 1a20 1a24 1a28
1a2a 1a2b 1a30 1 1a34 1a38 1a3c 1a3f
1a43 1a47 1a4b 1a4f 1a52 1a56 1a5a 1a5d
1a60 1a65 1a68 1a6b 1a6e 1a6f 1a74 1a75
1 1a77 1a7c 1a80 1a84 1a87 1a8c 1a91
1a94 1a98 1a99 1a9e 1aa1 1aa6 1aa7 1aac
1aaf 1ab4 1ab5 1aba 1abd 1ac1 1ac2 1ac7
1aca 1acf 1ad0 1ad5 1ad8 1adc 1ae0 1ae3
1ae6 1ae7 1ae9 1aea 1aef 1af0 1af5 1af7
1afb 1afe 1b00 1b04 1b06 1b12 1b14 1b16
1b17 1b1c 1b20 1b22 1b2e 1b30 1b32 1b36
1b3a 1b3d 1b3f 1b43 1b47 1b4a 1b4c 1b50
1b54 1b57 1b5b 1b5f 1b62 1b66 1b69 1b6d
1b70 1b71 1b76 1b79 1b7d 1b80 1b84 1b86
1b8a 1b8d 1b91 1b94 1b98 1b9c 1ba0 1ba4
1ba8 1bac 1bb0 1bb4 1bb8 1bbb 1bbc 1bbe
1bbf 1bc1 1bc5 1bc9 1bcd 1bd0 1bd1 1bd3
1bd6 1bd9 1bda 1bdf 1be3 1be7 1beb 1bee
1bef 1bf1 1bf4 1bf5 1bf7 1bfa 1bfd 1c00
1c01 1c06 1c09 1c0d 1c11 1c14 1c15 1c17
1c1a 1c1d 1c1e 1c23 1 1c26 1c2b 1c2f
1c33 1c37 1c3b 1c3f 1c40 1c42 1c45 1c46
1c48 1c4b 1c4f 1c53 1c57 1c58 1c5a 1c5d
1c5e 1c60 1c61 1c66 1c69 1c6c 1c6f 1c70
1c75 1c78 1c7b 1c7f 1c83 1c86 1c87 1c89
1c8a 1c8f 1c90 1c92 1c96 1c9a 1c9d 1ca0
1ca1 1ca6 1ca9 1cad 1cb0 1cb3 1cb6 1cb7
1cbc 1cbd 1 1cc2 1cc7 1ccb 1ccf 1cd3
1cd7 1cdb 1cdf 1ce3 1ce7 1ceb 1cef 1cf3
1cf7 1cfb 1cff 1d0b 1d0f 1d14 1d18 1d1b
1d1c 1d21 1d25 1d29 1d2c 1d2f 1d33 1d35
1d39 1d3d 1d40 1d43 1d47 1d49 1d4d 1d51
1d54 1d56 1d5a 1d5e 1d62 1d65 1d69 1d6d
1d6f 1d70 1d75 1 1d79 1d7d 1d81 1d84
1d88 1d8c 1d90 1d94 1d97 1d9b 1d9f 1da2
1da5 1daa 1dad 1db0 1db3 1db4 1db9 1dba
1 1dbc 1dc1 1dc5 1dc9 1dcc 1dd1 1dd6
1dd9 1ddd 1dde 1de3 1de6 1deb 1dec 1df1
1df4 1df9 1dfa 1dff 1e02 1e06 1e07 1e0c
1e0f 1e14 1e15 1e1a 1e1d 1e21 1e25 1e28
1e2b 1e2c 1e2e 1e2f 1e34 1e35 1e3a 1e3c
1e40 1e43 1e45 1e49 1e4b 1e57 1e59 1e5b
1e5c 1e61 1e65 1e67 1e73 1e75 1e77 1e7b
1e7f 1e83 1e87 1e8b 1e8f 1e93 1e97 1ea3
1ea7 1eac 1eb0 1eb3 1eb4 1eb9 1ebd 1ec1
1ec4 1ec7 1ecb 1ecd 1ed1 1ed5 1ed8 1edb
1edf 1ee1 1ee5 1ee9 1eec 1eee 1ef2 1ef6
1efa 1efd 1f01 1f05 1f07 1f08 1f0d 1
1f11 1f15 1f19 1f1c 1f20 1f24 1f28 1f2c
1f2f 1f33 1f37 1f3a 1f3d 1f42 1f45 1f48
1f4b 1f4c 1f51 1f52 1 1f54 1f59 1f5d
1f61 1f64 1f69 1f6e 1f71 1f75 1f76 1f7b
1f7e 1f83 1f84 1f89 1f8c 1f91 1f92 1f97
1f9a 1f9e 1f9f 1fa4 1fa7 1fac 1fad 1fb2
1fb5 1fb9 1fbd 1fc0 1fc3 1fc4 1fc6 1fc7
1fcc 1fcd 1fd2 1fd4 1fd8 1fdb 1fdd 1fe1
1fe3 1fef 1ff1 1ff3 1ff4 1ff9 1ffd 1fff
200b 200d 200f 2013 2017 201a 201e 2022
2026 202a 202e 202f 2031 2035 2037 203b
203e 2040 2044 2047 2049 204d 2054 2058
205c 2061 2063 2067 206b 206e 2072 2076
2078 207c 2080 2084 2087 208b 208f 2091
2092 2097 1 209b 209f 20a3 20a6 20aa
20ae 20b2 20b6 20b9 20bd 20c1 20c4 20c7
20cc 20cf 20d2 20d5 20d6 20db 20dc 1
20de 20e3 20e7 20eb 20ee 20f3 20f8 20fb
20ff 2100 2105 2108 210d 210e 2113 2116
211b 211c 2121 2124 2128 2129 212e 2131
2136 2137 213c 213f 2143 2147 214a 214d
214e 2150 2151 2156 2157 215c 215e 2162
2165 2167 216b 216d 2179 217b 217d 217e
2183 2187 2189 2195 2197 2199 219d 21a1
21a4 21a8 21ac 21b0 21b4 21b8 21bc 21c0
21c4 21c8 21cc 21d0 21d4 21d8 21dc 21e0
21e4 21e8 21ec 21f0 21f4 2200 2204 2209
220d 2210 2211 2216 221a 221e 2221 2224
2228 222a 222e 2232 2235 2238 223c 223e
2242 2246 2249 224b 224f 2253 2257 225a
225e 2262 2264 2265 226a 1 226e 2272
2276 2279 227d 2281 2285 2289 228c 2290
2294 2297 229a 229f 22a2 22a5 22a8 22a9
22ae 22af 1 22b1 22b6 22ba 22be 22c1
22c6 22cb 22ce 22d2 22d3 22d8 22db 22e0
22e1 22e6 22e9 22ee 22ef 22f4 22f7 22fb
22fc 2301 2304 2309 230a 230f 2312 2316
231a 231d 2320 2321 2323 2324 2329 232a
232f 2331 2335 2338 233a 233e 2340 234c
234e 2350 2351 2356 235a 235c 2368 236a
2372 2374 2375 2378 237a 237e 2385 2389
238d 2392 2394 2398 239c 239f 23a3 23a7
23a9 23ad 23b1 23b5 23b8 23bc 23c0 23c2
23c3 23c8 1 23cc 23d0 23d4 23d7 23db
23df 23e3 23e7 23ea 23ee 23f2 23f5 23f8
23fd 2400 2403 2406 2407 240c 240d 1
240f 2414 2418 241c 241f 2424 2429 242c
2430 2431 2436 2439 243e 243f 2444 2447
244c 244d 2452 2455 2459 245a 245f 2462
2467 2468 246d 2470 2474 2478 247b 247e
247f 2481 2482 2487 2488 248d 248f 2493
2496 2498 249c 249e 24aa 24ac 24ae 24af
24b4 24b8 24ba 24c6 24c8 24cc 24d0 24d3
24d4 24d6 24d9 24dc 24df 24e0 24e5 24e6
24eb 24ef 24f3 24f7 24f8 24fa 24fe 2500
2504 2507 2509 250d 2510 2514 2518 251b
251f 2523 2526 2529 252e 2531 2534 2537
2538 253d 253e 1 2540 2545 2549 254d
2550 2555 255a 255d 2561 2562 2567 256a
256f 2570 2575 2578 257d 257e 2583 2586
258a 258e 2592 2596 2599 259a 259c 25a1
25a2 25a4 25a5 25aa 25ad 25b2 25b3 25b8
25bb 25c0 25c1 25c6 25c9 25cd 25ce 25d3
25d6 25db 25dc 25e1 25e2 25e7 25e9 25ed
25f0 25f4 25f8 25fb 25ff 2603 2606 260a
260e 260f 2614 2616 261a 261e 2621 2625
2629 262c 2630 2634 2637 263a 263f 2642
2645 2648 2649 264e 264f 1 2651 2656
265a 265e 2661 2666 266b 266e 2672 2673
2678 2679 267e 2682 2686 2689 268e 2693
2696 269a 269e 26a1 26a2 26a7 26aa 26af
26b0 26b5 26b8 26bc 26c0 26c3 26c4 26c9
26ca 26cf 26d1 26d5 26d8 26dc 26e0 26e4
26e8 26ec 26f0 26f4 26f8 26fc 2708 270d
2711 2715 2719 271d 271f 2720 2725 1
2729 272d 2731 2734 2738 273c 2740 2744
2747 274b 274f 2752 2755 275a 275d 2760
2763 2764 2769 276a 1 276c 2771 2775
2779 277c 2781 2786 2789 278d 278e 2793
2794 2799 279d 27a1 27a4 27a9 27ae 27b1
27b5 27b6 27bb 27be 27c3 27c4 27c9 27cc
27d0 27d4 27d7 27da 27db 27dd 27de 27e3
27e4 27e9 27eb 27ef 27f2 27f6 27fa 27fe
2802 2806 280a 280e 281a 281f 2823 2827
282b 282f 2831 2835 2837 2843 2845 2847
2848 284d 2851 2853 285f 2863 2865 2866
286f 
b49
2
0 1 a 6 9 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 :3 12 :2 4 11 1a 19 :2 11 :2 4
b 14 13 :2 b :2 4 :3 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :3 e :2 4 :2 14 23 14 :2 4
:2 f 1e f :2 4 :2 15 24 15 :2 4
:2 12 21 12 :2 4 :2 11 20 11 :2 4
:2 12 21 12 :2 4 :2 13 22 13 :2 4
:2 1a 29 1a :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 11 20 11 :2 4 :2 12 2a
12 :2 4 :3 17 4 7 e 0 :2 7
11 1d 2a 14 30 41 14 31
43 f 10 1d 2e 38 43 4f
58 60 69 77 80 8e 97 a5
ae bb c4 d5 de f1 fa 10f
118 133 13c 154 15d 16e 177 189
192 1aa 1b3 1c6 1cf 11 1e 38
45 54 64 e 2c a :6 7 e
0 :2 7 11 24 2e 34 3f 4d
5a f 10 1d e 18 11 1c
34 3f 4c 5c e 2c a :5 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 57 5d 60 :2 57 6e 87
8 :2 6e d 10 :2 6e 13 16 :2 6e
b e :2 6e 13 16 1f 27 :2 1f
34 :2 16 :2 6e b e :2 6e 13 16
:2 6e 1b 1e :2 6e 2a 2d :2 6e 32
35 :2 6e :2 7 4d :2 4 7 :2 11 23
:2 2d 39 3c 4f 51 52 :2 4f :2 23
:3 7 :2 d 12 1e 60 63 :2 1e :2 7
55 :3 4 11 :2 4 12 :2 4 12 :2 4
12 4 e 1a 20 27 c 1a
22 c 1a 27 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 56 58 59 :2 56 :2 29
:3 d :2 13 18 24 66 69 :2 24 76
79 :2 24 7d 80 :2 24 8c 8f :2 24
97 9a :2 24 a6 a9 b0 b9 bc
:2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 :4 3b 3a 39 :3 7 11 18 1f
22 :2 18 27 2a :2 11 :2 7 13 14
:2 13 7 11 28 37 45 52 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6a
6d :2 27 7a 7d :2 27 81 84 :2 27
90 93 :2 27 9b 9e :2 27 aa ad
b4 bd c0 :2 ad :2 27 :2 10 60 :2 d
:2 a :4 16 :2 a 7 :3 50 7 c :4 7
10 1d 28 32 40 :3 a d 15
:2 d :2 16 22 d 1b d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a d 16 20 :2 d 23
25 :2 23 10 19 24 :2 10 27 29
:2 27 1a :3 13 19 26 37 44 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 2b
10 20 :2 10 29 38 44 4f 5b
67 29 37 :2 67 :2 29 10 2b 15
10 :4 d 27 d 12 :4 d 16 23
38 44 50 5e 6d :3 10 13 1b
:2 13 :2 1c 28 13 21 13 :2 1c 28
13 :4 10 14 :2 1d 29 26 :2 32 :2 26
:3 13 42 :3 10 24 10 13 1c 27
:2 13 2a 2c :2 2a 16 1d 29 2c
:2 16 2f 31 :2 2f 20 1d 1f 33
1d 32 1d 27 30 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 68
6b 6c :2 68 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :3 35 19 22
2e :2 19 31 33 34 :2 33 :2 31 20
21 22 36 19 23 1c 32 1c
32 1c 32 1c 32 1c 32 1c
32 1c 32 1c 32 1c 32 3f
1c 22 36 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :4 36 23 1c 29 1c
24 31 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6b 6e
6f :2 6b :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :7 16 35 20 19
23 :3 19 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 2e 16 1f
2a :2 16 2d 2f :2 2d 20 :3 19 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 68 6b 6c :2 68 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 31 19 20 2c 2f :2 19 32
34 :2 32 23 20 22 36 20 35
20 2a 33 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :3 38 23 :4 1c 33 43
54 67 1c 2c 3c 4d 5d 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6b 6e 6f :2 6b :2 3e
:3 22 :2 28 2d 39 7c 7f :2 39 8c
8f :2 39 93 96 :2 39 a2 a5 :2 39
ad b0 :2 39 bc bf c6 cf d2
:2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c
19 :4 38 23 :4 1c 22 30 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6b 6e 6f :2 6b :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:7 16 :4 13 :4 10 14 :2 1d 28 26 :2 31
:2 26 :2 13 27 13 41 :3 10 20 :2 10
29 38 44 59 65 2b 34 42
:2 2b :2 29 10 13 1c 2e :2 13 31
33 :2 31 18 1f 28 33 :2 1f 37
:2 18 17 3b 3d :2 3b 16 45 4e
5e :2 45 61 63 :2 61 44 :3 16 2c
34 3d 47 :2 3d 57 :2 34 5a 5c
28 32 :2 28 41 :2 5c :2 34 33 45
47 :2 33 32 51 53 28 38 :2 53
:2 32 :2 2c 16 1a 2d 2f :2 2d 19
35 48 4a 4b :2 4a :2 48 :2 19 23
1c 2a 33 3a 46 4f 1c 21
3b 48 21 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6b
6e 6f :2 6b :2 3e :3 22 :2 28 2d 39
7c 7f :2 39 8c 8f :2 39 93 96
:2 39 a2 a5 :2 39 ad b0 :2 39 bc
bf c6 cf d2 :2 bf :2 39 :2 22 72
:2 1f :2 1c :4 28 :2 1c 19 :4 4d 23 1c
37 52 5f 71 22 36 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :8 16 29
3b 49 5e :2 29 16 66 :2 13 35
:2 10 d 11 a 10 16 :3 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5f 62 63
:2 5f :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :7 a 14 d 12 1a
21 39 41 48 d 12 1a 21
39 41 48 60 13 20 31 3e
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 7 c a :3 7 b 50 a 10
:3 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 50 a 13
1d :2 a 20 22 23 :2 22 :2 20 a
1d 27 :2 1d a 25 :2 7 50 :2 4
7 :2 11 23 :2 2d 39 3c 4f 52
53 :2 4f :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e ce d1 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 38 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
b49
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:5 8 :7 9 :7 a :5 b
:7 c :7 d :7 e :6 f
:6 10 :6 11 :5 12 :6 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:5 20 :2 22 0 :2 22
:3 23 :3 24 :3 25 26
:23 27 :6 28 :2 29 23
:5 22 :2 2b 0 :2 2b
:7 2c 2d :2 2e :2 2f
:6 30 :2 31 2c :5 2b
:7 33 :b 35 :11 36 37
:2 36 :2 37 :2 36 :2 37
:2 36 :2 38 :2 36 :9 38
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :4 36 :3 35
:11 3c :b 3d :3 3c :3 43
:3 46 :3 47 :3 48 :4 4b
:3 4c :3 4d 4b :5 4e
4a 50 :5 51 :3 50
:2 52 :5 54 :11 55 :24 56
:3 55 :2 53 :6 52 4f
:3 34 :12 5c :c 5d :6 5e
:6 61 :5 62 60 64
:5 65 :3 64 :2 66 :5 68
:11 69 :24 6a :3 69 :2 67
:6 66 63 :3 5c :5 6f
71 :8 72 :3 73 :5 74
73 :5 76 75 :3 73
:a 79 :2 7a :3 79 :9 7e
:9 80 83 84 85
86 :4 87 83 :6 88
:5 89 88 :5 8b 8a
:3 88 82 8e :5 8f
:3 8e :2 90 :5 92 :11 93
:24 94 :3 93 :2 91 :6 90
8d :3 80 :3 9a :7 9b
:2 9c :5 9b 80 :2 9e
9d :3 80 7e :5 a3
a5 :a a6 :3 a7 :5 a8
a7 :5 aa a9 :3 a7
:a ad :2 ae :3 ad :3 b2
:9 b3 :a b4 b6 b7
:2 b8 :2 b9 :3 ba b6
:6 bb :5 bc bb :5 be
bd :3 bb b5 c1
:5 c2 :3 c1 :2 c3 :5 c5
:11 c6 :24 c7 :3 c6 :2 c4
:6 c3 c0 :3 b4 :c cc
cd ce :2 cf cd
d2 :2 d3 :2 d4 :2 d5
:2 d6 :2 d7 :2 d8 :2 d9
:2 da :3 db dc :2 dd
d2 :6 de :5 df de
:5 e1 e0 :3 de d1
e4 :5 e5 :3 e4 :2 e6
:5 e8 :11 e9 :24 ea :3 e9
:2 e7 :6 e6 e3 :4 cc
f8 :2 f9 :3 fa :2 fb
f8 :6 fc :5 fd fc
:5 ff fe :3 fc f7
102 :5 103 :3 102 :2 104
:5 106 :11 107 :24 108 :3 107
:2 105 :6 104 101 :4 ee
:3 cc b4 10f :2 110
111 112 113 :2 114
10f :6 115 :5 116 115
:5 118 117 :3 115 10e
11b :5 11c :3 11b :2 11d
:5 11f :11 120 :24 121 :3 120
:2 11e :6 11d 11a :4 10d
:3 b4 b3 :9 128 12b
12c 12d 12e :2 12f
12b :6 130 :5 131 130
:5 133 132 :3 130 12a
136 :5 137 :3 136 :2 138
:5 13a :11 13b :24 13c :3 13b
:2 139 :6 138 135 :4 128
:a 142 144 145 :2 146
:2 147 :3 148 144 :6 149
:5 14a 149 :5 14c 14b
:3 149 143 14f :5 150
:3 14f :2 151 :5 153 :11 154
:24 155 :3 154 :2 152 :6 151
14e :3 142 15b 15c
15d 15e :5 15f :5 160
:2 162 15b :6 163 :5 164
163 :5 166 165 :3 163
15a 169 :5 16a :3 169
:2 16b :5 16d :11 16e :24 16f
:3 16e :2 16c :6 16b 168
:4 142 175 176 177
178 :3 179 :2 17a 175
:6 17b :5 17c 17b :5 17e
17d :3 17b 174 181
:5 182 :3 181 :2 183 :5 185
:11 186 :24 187 :3 186 :2 184
:6 183 180 :4 173 :3 142
140 :3 128 127 :3 b3
:a 18f :3 190 :3 18f :3 194
:6 195 :5 196 :3 195 :9 199
:1b 19a :c 19b :5 19c :5 19b
:2 19c :3 19b :2 19c :2 19d
:2 19c :5 19b :10 19e 1a0
:6 1a1 1a2 :3 1a3 1a4
:2 1a6 1a0 :6 1a7 :5 1a8
1a7 :5 1aa 1a9 :3 1a7
19f 1ad :5 1ae :3 1ad
:2 1af :5 1b1 :11 1b2 :24 1b3
:3 1b2 :2 1b0 :6 1af 1ac
:4 19e 1b9 :5 1ba :2 1bb
1b9 :6 1bc :5 1bd 1bc
:5 1bf 1be :3 1bc 1b8
1c2 :5 1c3 :3 1c2 :2 1c4
:5 1c6 :11 1c7 :24 1c8 :3 1c7
:2 1c5 :6 1c4 1c1 :4 1b7
:3 19e :8 1d1 :3 19a :3 199
a5 1d4 a0 :4 1d8
:5 1d9 1d7 1db :5 1dc
:3 1db :2 1dd :5 1df :11 1e0
:24 1e1 :3 1e0 :2 1de :6 1dd
1da :4 a0 :3 7e 1e9
1ea :6 1ec 1ef :7 1f1
:4 1f4 1e9 :6 1f5 :5 1f6
1f5 :5 1f8 1f7 :3 1f5
1e8 1fb :5 1fc :3 1fb
:2 1fd :5 1ff :11 200 :24 201
:3 200 :2 1fe :6 1fd 1fa
:3 71 205 206 :3 71
207 5c :4 20b :5 20c
20a 20e :5 20f :3 20e
:2 210 :5 212 :11 213 :24 214
:3 213 :2 211 :6 210 20d
:3 5c :c 219 :6 21a :3 219
:3 5c :11 21f :30 220 :3 21f
:a 222 34 :3 225 :11 226
:b 227 :17 228 :3 226 :2 22a
:3 22b :3 22c 22d 22b
22a 22b :3 22e :3 225
:2 22f :5 231 :11 232 :b 233
:18 234 :3 232 :2 236 237
:3 238 239 237 236
237 :3 23a :2 230 :6 22f
224 :7 1 
2871
4
:3 0 1 :3 0 2
:a 0 b44 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 b44 2 14
:2 0 e :2 0 d
c :3 0 17 :7 0
1a 18 0 b42
0 b :6 0 10
:2 0 11 4 :3 0
f 1c 1e :6 0
21 1f 0 b42
0 d :6 0 17
c3 0 15 4
:3 0 13 23 25
:6 0 28 26 0
b42 0 f :6 0
e :2 0 1b c
:3 0 2a :7 0 2d
2b 0 b42 0
11 :6 0 4 :3 0
e :2 0 19 2f
31 :6 0 34 32
0 b42 0 12
:6 0 15 :2 0 1f
4 :3 0 1d 36
38 :6 0 3b 39
0 b42 0 13
:6 0 17 :2 0 23
4 :3 0 21 3d
3f :6 0 42 40
0 b42 0 14
:6 0 17 :2 0 25
6 :3 0 44 :7 0
48 45 46 b42
0 16 :6 0 17
:2 0 27 6 :3 0
4a :7 0 4e 4b
4c b42 0 18
:6 0 2b 189 0
29 6 :3 0 50
:7 0 54 51 52
b42 0 19 :6 0
17 :2 0 2d 1b
:3 0 56 :7 0 59
57 0 b42 0
1a :6 0 6 :3 0
5b :7 0 17 :2 0
5f 5c 5d b42
0 1c :6 0 17
:2 0 2f 6 :3 0
61 :7 0 65 62
63 b42 0 1d
:6 0 17 :2 0 31
6 :3 0 67 :7 0
6b 68 69 b42
0 1e :6 0 17
:2 0 33 6 :3 0
6d :7 0 71 6e
6f b42 0 1f
:6 0 17 :2 0 35
6 :3 0 73 :7 0
77 74 75 b42
0 20 :6 0 17
:2 0 37 6 :3 0
79 :7 0 7d 7a
7b b42 0 21
:6 0 17 :2 0 39
6 :3 0 7f :7 0
83 80 81 b42
0 22 :6 0 e
:2 0 3b 6 :3 0
85 :7 0 89 86
87 b42 0 23
:6 0 e :2 0 3f
4 :3 0 3d 8b
8d :6 0 90 8e
0 b42 0 24
:6 0 17 :2 0 43
4 :3 0 41 92
94 :6 0 97 95
0 b42 0 25
:6 0 17 :2 0 45
6 :3 0 99 :7 0
9d 9a 9b b42
0 26 :6 0 17
:2 0 47 6 :3 0
9f :7 0 a3 a0
a1 b42 0 27
:6 0 4b 312 0
49 6 :3 0 a5
0 2 :5 0 a9
a6 a7 b42 0
28 :6 0 2a :3 0
6 :3 0 ab :7 0
ae ac 0 b42
0 29 :6 0 2b
:a 0 2 ea :5 0
b0 b3 0 b1
:3 0 2c :3 0 2d
:3 0 2e :3 0 2f
:3 0 30 :3 0 2f
:3 0 31 :3 0 32
:3 0 31 :3 0 33
:3 0 34 :3 0 d
:3 0 35 :3 0 f
:3 0 36 :3 0 37
:3 0 38 :3 0 37
:3 0 39 :3 0 37
:3 0 3a :3 0 37
:3 0 3b :3 0 37
:3 0 3c :3 0 37
:3 0 3d :3 0 37
:3 0 3e :3 0 37
:3 0 3f :3 0 37
:3 0 40 :3 0 37
:3 0 41 :3 0 37
:3 0 42 :3 0 37
:3 0 43 :3 0 37
:3 0 44 :3 0 37
:3 0 45 :3 0 37
:3 0 46 :3 0 2d
:3 0 2e :3 0 2d
:3 0 2e :3 0 47
:3 0 48 :3 0 2f
:3 0 31 :4 0 49
1 :8 0 eb b0
b3 ec 0 b42
4d ec ee eb
ed :6 0 ea :7 0
ec 2a :3 0 4a
:a 0 3 109 :5 0
f0 f3 0 f1
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 47
:3 0 50 :3 0 51
:3 0 34 :3 0 d
:3 0 52 :3 0 12
:3 0 4e :3 0 4f
:3 0 4e :3 0 4f
:3 0 47 :3 0 48
:3 0 2f :3 0 31
:4 0 53 1 :8 0
10a f0 f3 10b
0 b42 4f 10b
10d 10a 10c :6 0
109 :7 0 10b 115
116 0 51 9
:3 0 a :2 0 4
10f 110 0 111
:7 0 114 112 0
b42 0 54 :6 0
55 :3 0 56 :3 0
55 :3 0 57 :3 0
118 119 0 2
:4 0 53 11a 11c
117 11e 11d :2 0
58 :3 0 59 :3 0
120 121 0 5a
:4 0 55 :3 0 5b
:3 0 124 125 0
2 :4 0 55 126
128 5c :4 0 5d
:2 0 5e :3 0 57
12b 12d :3 0 5f
:4 0 5d :2 0 60
:4 0 5a 130 132
:3 0 5d :2 0 3
:3 0 5d 134 136
:3 0 5d :2 0 60
:4 0 60 138 13a
:3 0 5d :2 0 61
:4 0 63 13c 13e
:3 0 5d :2 0 62
:3 0 63 :3 0 5
:3 0 66 142 144
64 :4 0 68 141
147 6b 140 149
:3 0 5d :2 0 61
:4 0 6e 14b 14d
:3 0 5d :2 0 60
:4 0 71 14f 151
:3 0 5d :2 0 7
:3 0 74 153 155
:3 0 5d :2 0 60
:4 0 77 157 159
:3 0 5d :2 0 65
:4 0 7a 15b 15d
:3 0 7d 122 15f
:2 0 161 82 162
11f 161 0 163
84 0 aa2 55
:3 0 56 :3 0 164
165 0 55 :3 0
66 :3 0 167 168
0 15 :2 0 2
:4 0 67 :2 0 68
:2 0 15 :2 0 86
16d 16f :3 0 89
169 171 166 173
172 :2 0 58 :3 0
69 :3 0 175 176
0 5a :4 0 6a
:4 0 5d :2 0 5e
:3 0 8d 17a 17c
:3 0 90 177 17e
:2 0 180 93 181
174 180 0 182
95 0 aa2 16
:3 0 5 :3 0 183
184 0 aa2 25
:3 0 7 :3 0 186
187 0 aa2 26
:3 0 6b :2 0 189
18a 0 aa2 24
:3 0 6c :4 0 18c
18d 0 aa2 34
:3 0 6d :3 0 35
:3 0 36 :3 0 d
:3 0 f :3 0 19
:3 0 33 :3 0 2c
:3 0 3 :4 0 6e
1 :8 0 19f 9
:3 0 6f :3 0 19a
19b 0 70 :3 0
19c 19d 0 19f
97 1f2 71 :3 0
9 :3 0 6f :3 0
1a1 1a2 0 70
:3 0 1a3 1a4 0
1a6 9a 1a8 9c
1a7 1a6 :2 0 1f0
72 :3 0 9 :3 0
6f :3 0 1ab 1ac
0 70 :3 0 1ad
1ae 0 1e8 55
:3 0 56 :3 0 1b0
1b1 0 55 :3 0
66 :3 0 1b3 1b4
0 73 :2 0 2
:4 0 74 :2 0 68
:2 0 15 :2 0 9e
1b9 1bb :3 0 a1
1b5 1bd 1b2 1bf
1be :2 0 58 :3 0
69 :3 0 1c1 1c2
0 5a :4 0 75
:4 0 5d :2 0 5e
:3 0 a5 1c6 1c8
:3 0 5d :2 0 76
:4 0 a8 1ca 1cc
:3 0 5d :2 0 77
:4 0 ab 1ce 1d0
:3 0 5d :2 0 70
:3 0 ae 1d2 1d4
:3 0 5d :2 0 78
:4 0 b1 1d6 1d8
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 b4
1db 1df b8 1da
1e1 :3 0 bb 1c3
1e3 :2 0 1e5 be
1e6 1c0 1e5 0
1e7 c0 0 1e8
c2 1eb :3 0 1eb
0 1eb 1ea 1e8
1e9 :6 0 1ed 4
:3 0 c5 1ef c7
1ee 1ed :2 0 1f0
c9 :2 0 1f2 0
1f2 1f1 19f 1f0
:6 0 aa2 1 :3 0
9 :3 0 6f :3 0
1f4 1f5 0 9
:3 0 7c :2 0 7d
:3 0 1f7 1f9 0
ce 1f8 1fb :3 0
1fc :2 0 19 :3 0
7e :2 0 d1 1ff
200 :3 0 201 :2 0
202 :2 0 1fd 204
203 :2 0 f :3 0
79 :3 0 f :3 0
5d :2 0 7f :4 0
d3 209 20b :3 0
15 :2 0 10 :2 0
d6 207 20f 206
210 0 a51 18
:3 0 80 :2 0 15
:2 0 da 213 215
:3 0 212 216 0
a51 81 :3 0 1a
:3 0 33 :3 0 2c
:3 0 d :4 0 82
1 :8 0 223 9
:3 0 6f :3 0 21e
21f 0 70 :3 0
220 221 0 223
dc 276 71 :3 0
9 :3 0 6f :3 0
225 226 0 70
:3 0 227 228 0
22a df 22c e1
22b 22a :2 0 274
72 :3 0 9 :3 0
6f :3 0 22f 230
0 70 :3 0 231
232 0 26c 55
:3 0 56 :3 0 234
235 0 55 :3 0
66 :3 0 237 238
0 73 :2 0 2
:4 0 83 :2 0 68
:2 0 15 :2 0 e3
23d 23f :3 0 e6
239 241 236 243
242 :2 0 58 :3 0
69 :3 0 245 246
0 5a :4 0 84
:4 0 5d :2 0 5e
:3 0 ea 24a 24c
:3 0 5d :2 0 76
:4 0 ed 24e 250
:3 0 5d :2 0 77
:4 0 f0 252 254
:3 0 5d :2 0 70
:3 0 f3 256 258
:3 0 5d :2 0 78
:4 0 f6 25a 25c
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 f9
25f 263 fd 25e
265 :3 0 100 247
267 :2 0 269 103
26a 244 269 0
26b 105 0 26c
107 26f :3 0 26f
0 26f 26e 26c
26d :6 0 271 6
:3 0 10a 273 10c
272 271 :2 0 274
10e :2 0 276 0
276 275 223 274
:6 0 a51 1 :3 0
85 :3 0 2b :4 0
27b :2 0 a51 279
27c :3 0 86 :3 0
2b :3 0 12 :3 0
18 :3 0 11 :3 0
b :4 0 284 :2 0
9db 27e 285 :3 0
111 :3 0 2b :3 0
87 :3 0 286 287
:3 0 9 :3 0 6f
:3 0 289 28a 0
17 :2 0 28b 28c
0 28e 116 295
9 :3 0 6f :3 0
28f 290 0 88
:2 0 291 292 0
294 118 296 288
28e 0 297 0
294 0 297 11a
0 9db 9 :3 0
6f :3 0 298 299
0 9 :3 0 89
:2 0 7d :3 0 29b
29d 0 11f 29c
29f :3 0 2a0 :2 0
8a :8 0 2a4 122
2a5 2a1 2a4 0
2a6 124 0 9db
62 :3 0 18 :3 0
17 :2 0 126 2a7
2aa 7c :2 0 17
:2 0 12b 2ac 2ae
:3 0 62 :3 0 16
:3 0 17 :2 0 12e
2b0 2b3 7c :2 0
8b :2 0 133 2b5
2b7 :3 0 33 :3 0
2f :3 0 31 :3 0
8c :3 0 34 :3 0
d :3 0 2c :3 0
12 :4 0 8d 1
:8 0 2d7 87 :4 0
2c2 :3 0 8e :3 0
7c :2 0 138 2c5
2c6 :3 0 9 :3 0
6f :3 0 2c8 2c9
0 17 :2 0 2ca
2cb 0 2cd 13b
2d4 9 :3 0 6f
:3 0 2ce 2cf 0
88 :2 0 2d0 2d1
0 2d3 13d 2d5
2c7 2cd 0 2d6
0 2d3 0 2d6
13f 0 2d7 142
32a 71 :3 0 9
:3 0 6f :3 0 2d9
2da 0 70 :3 0
2db 2dc 0 2de
145 2e0 147 2df
2de :2 0 328 72
:3 0 9 :3 0 6f
:3 0 2e3 2e4 0
70 :3 0 2e5 2e6
0 320 55 :3 0
56 :3 0 2e8 2e9
0 55 :3 0 66
:3 0 2eb 2ec 0
73 :2 0 2 :4 0
8f :2 0 68 :2 0
15 :2 0 149 2f1
2f3 :3 0 14c 2ed
2f5 2ea 2f7 2f6
:2 0 58 :3 0 69
:3 0 2f9 2fa 0
5a :4 0 90 :4 0
5d :2 0 5e :3 0
150 2fe 300 :3 0
5d :2 0 76 :4 0
153 302 304 :3 0
5d :2 0 77 :4 0
156 306 308 :3 0
5d :2 0 70 :3 0
159 30a 30c :3 0
5d :2 0 78 :4 0
15c 30e 310 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 15f 313
317 163 312 319
:3 0 166 2fb 31b
:2 0 31d 169 31e
2f8 31d 0 31f
16b 0 320 16d
323 :3 0 323 0
323 322 320 321
:6 0 325 9 :3 0
170 327 172 326
325 :2 0 328 174
:2 0 32a 0 32a
329 2d7 328 :6 0
33d 8 :3 0 27
:3 0 15 :2 0 32c
32d 0 33d 23
:3 0 91 :3 0 24
:3 0 12 :3 0 25
:3 0 26 :3 0 62
:3 0 27 :3 0 17
:2 0 177 335 338
17a 330 33a 32f
33b 0 33d 180
341 92 :3 0 33e
:4 0 340 184 342
2b8 33d 0 343
0 340 0 343
186 0 344 189
955 85 :3 0 4a
:4 0 348 :2 0 954
346 349 :3 0 86
:3 0 4a :3 0 13
:3 0 14 :3 0 1d
:3 0 20 :3 0 21
:3 0 22 :4 0 353
:2 0 8f3 34b 354
:3 0 18b :3 0 4a
:3 0 87 :3 0 355
356 :3 0 9 :3 0
6f :3 0 358 359
0 17 :2 0 35a
35b 0 35d 192
364 9 :3 0 6f
:3 0 35e 35f 0
88 :2 0 360 361
0 363 194 365
357 35d 0 366
0 363 0 366
196 0 8f3 9
:3 0 6f :3 0 367
368 0 9 :3 0
89 :2 0 7d :3 0
36a 36c 0 19b
36b 36e :3 0 36f
:2 0 8a :8 0 373
19e 374 370 373
0 375 1a0 0
8f3 1e :3 0 17
:2 0 376 377 0
8f3 62 :3 0 16
:3 0 17 :2 0 1a2
379 37c 7c :2 0
15 :2 0 1a7 37e
380 :3 0 79 :3 0
14 :3 0 15 :2 0
15 :2 0 1aa 382
386 7c :2 0 8b
:4 0 1b0 388 38a
:3 0 93 :3 0 94
:3 0 4b :3 0 13
:3 0 4b :3 0 2c
:3 0 36 :3 0 37
:3 0 95 :4 0 96
1 :8 0 3ab 87
:4 0 396 :3 0 8e
:3 0 7c :2 0 1b5
399 39a :3 0 9
:3 0 6f :3 0 39c
39d 0 17 :2 0
39e 39f 0 3a1
1b8 3a8 9 :3 0
6f :3 0 3a2 3a3
0 88 :2 0 3a4
3a5 0 3a7 1ba
3a9 39b 3a1 0
3aa 0 3a7 0
3aa 1bc 0 3ab
1bf 3fe 71 :3 0
9 :3 0 6f :3 0
3ad 3ae 0 70
:3 0 3af 3b0 0
3b2 1c2 3b4 1c4
3b3 3b2 :2 0 3fc
72 :3 0 9 :3 0
6f :3 0 3b7 3b8
0 70 :3 0 3b9
3ba 0 3f4 55
:3 0 56 :3 0 3bc
3bd 0 55 :3 0
66 :3 0 3bf 3c0
0 73 :2 0 2
:4 0 97 :2 0 68
:2 0 15 :2 0 1c6
3c5 3c7 :3 0 1c9
3c1 3c9 3be 3cb
3ca :2 0 58 :3 0
69 :3 0 3cd 3ce
0 5a :4 0 98
:4 0 5d :2 0 5e
:3 0 1cd 3d2 3d4
:3 0 5d :2 0 76
:4 0 1d0 3d6 3d8
:3 0 5d :2 0 77
:4 0 1d3 3da 3dc
:3 0 5d :2 0 70
:3 0 1d6 3de 3e0
:3 0 5d :2 0 78
:4 0 1d9 3e2 3e4
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 1dc
3e7 3eb 1e0 3e6
3ed :3 0 1e3 3cf
3ef :2 0 3f1 1e6
3f2 3cc 3f1 0
3f3 1e8 0 3f4
1ea 3f7 :3 0 3f7
0 3f7 3f6 3f4
3f5 :6 0 3f9 c
:3 0 1ed 3fb 1ef
3fa 3f9 :2 0 3fc
1f1 :2 0 3fe 0
3fe 3fd 3ab 3fc
:6 0 50b b :3 0
62 :3 0 1d :3 0
17 :2 0 1f4 400
403 7c :2 0 80
:2 0 15 :2 0 1f7
406 408 :3 0 1fb
405 40a :3 0 51
:3 0 99 :3 0 4b
:3 0 13 :4 0 9a
1 :8 0 493 51
:3 0 9b :3 0 30
:3 0 9c :3 0 32
:3 0 9d :3 0 4e
:3 0 9e :3 0 30
:3 0 9f :3 0 32
:3 0 a0 :3 0 4e
:3 0 99 :3 0 a1
:3 0 4d :3 0 4e
:3 0 48 :3 0 4e
:3 0 47 :3 0 a2
:3 0 4b :3 0 13
:4 0 a3 1 :8 0
43e 87 :4 0 429
:3 0 8e :3 0 7c
:2 0 200 42c 42d
:3 0 9 :3 0 6f
:3 0 42f 430 0
17 :2 0 431 432
0 434 203 43b
9 :3 0 6f :3 0
435 436 0 88
:2 0 437 438 0
43a 205 43c 42e
434 0 43d 0
43a 0 43d 207
0 43e 20a 491
71 :3 0 9 :3 0
6f :3 0 440 441
0 70 :3 0 442
443 0 445 20d
447 20f 446 445
:2 0 48f 72 :3 0
9 :3 0 6f :3 0
44a 44b 0 70
:3 0 44c 44d 0
487 55 :3 0 56
:3 0 44f 450 0
55 :3 0 66 :3 0
452 453 0 73
:2 0 2 :4 0 a4
:2 0 68 :2 0 15
:2 0 211 458 45a
:3 0 214 454 45c
451 45e 45d :2 0
58 :3 0 69 :3 0
460 461 0 5a
:4 0 a5 :4 0 5d
:2 0 5e :3 0 218
465 467 :3 0 5d
:2 0 76 :4 0 21b
469 46b :3 0 5d
:2 0 77 :4 0 21e
46d 46f :3 0 5d
:2 0 70 :3 0 221
471 473 :3 0 5d
:2 0 78 :4 0 224
475 477 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 227 47a 47e
22b 479 480 :3 0
22e 462 482 :2 0
484 231 485 45f
484 0 486 233
0 487 235 48a
:3 0 48a 0 48a
489 487 488 :6 0
48c e :3 0 238
48e 23a 48d 48c
:2 0 48f 23c :2 0
491 0 491 490
43e 48f :6 0 493
b :3 0 23f 508
51 :3 0 4e :3 0
4e :3 0 48 :3 0
4e :3 0 47 :3 0
4b :3 0 13 :4 0
a6 1 :8 0 4b2
87 :4 0 49d :3 0
8e :3 0 7c :2 0
244 4a0 4a1 :3 0
9 :3 0 6f :3 0
4a3 4a4 0 17
:2 0 4a5 4a6 0
4a8 247 4af 9
:3 0 6f :3 0 4a9
4aa 0 88 :2 0
4ab 4ac 0 4ae
249 4b0 4a2 4a8
0 4b1 0 4ae
0 4b1 24b 0
4b2 24e 505 71
:3 0 9 :3 0 6f
:3 0 4b4 4b5 0
70 :3 0 4b6 4b7
0 4b9 251 4bb
253 4ba 4b9 :2 0
503 72 :3 0 9
:3 0 6f :3 0 4be
4bf 0 70 :3 0
4c0 4c1 0 4fb
55 :3 0 56 :3 0
4c3 4c4 0 55
:3 0 66 :3 0 4c6
4c7 0 73 :2 0
2 :4 0 a7 :2 0
68 :2 0 15 :2 0
255 4cc 4ce :3 0
258 4c8 4d0 4c5
4d2 4d1 :2 0 58
:3 0 69 :3 0 4d4
4d5 0 5a :4 0
a8 :4 0 5d :2 0
5e :3 0 25c 4d9
4db :3 0 5d :2 0
76 :4 0 25f 4dd
4df :3 0 5d :2 0
77 :4 0 262 4e1
4e3 :3 0 5d :2 0
70 :3 0 265 4e5
4e7 :3 0 5d :2 0
78 :4 0 268 4e9
4eb :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
26b 4ee 4f2 26f
4ed 4f4 :3 0 272
4d6 4f6 :2 0 4f8
275 4f9 4d3 4f8
0 4fa 277 0
4fb 279 4fe :3 0
4fe 0 4fe 4fd
4fb 4fc :6 0 500
10 :3 0 27c 502
27e 501 500 :2 0
503 280 :2 0 505
0 505 504 4b2
503 :6 0 507 b
:3 0 283 509 40b
493 0 50a 0
507 0 50a 285
0 50b 288 580
51 :3 0 48 :3 0
4f :3 0 50 :3 0
a2 :3 0 a9 :3 0
4b :3 0 13 :4 0
aa 1 :8 0 52a
87 :4 0 515 :3 0
8e :3 0 7c :2 0
28d 518 519 :3 0
9 :3 0 6f :3 0
51b 51c 0 17
:2 0 51d 51e 0
520 290 527 9
:3 0 6f :3 0 521
522 0 88 :2 0
523 524 0 526
292 528 51a 520
0 529 0 526
0 529 294 0
52a 297 57d 71
:3 0 9 :3 0 6f
:3 0 52c 52d 0
70 :3 0 52e 52f
0 531 29a 533
29c 532 531 :2 0
57b 72 :3 0 9
:3 0 6f :3 0 536
537 0 70 :3 0
538 539 0 573
55 :3 0 56 :3 0
53b 53c 0 55
:3 0 66 :3 0 53e
53f 0 73 :2 0
2 :4 0 ab :2 0
68 :2 0 15 :2 0
29e 544 546 :3 0
2a1 540 548 53d
54a 549 :2 0 58
:3 0 69 :3 0 54c
54d 0 5a :4 0
ac :4 0 5d :2 0
5e :3 0 2a5 551
553 :3 0 5d :2 0
76 :4 0 2a8 555
557 :3 0 5d :2 0
77 :4 0 2ab 559
55b :3 0 5d :2 0
70 :3 0 2ae 55d
55f :3 0 5d :2 0
78 :4 0 2b1 561
563 :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
2b4 566 56a 2b8
565 56c :3 0 2bb
54e 56e :2 0 570
2be 571 54b 570
0 572 2c0 0
573 2c2 576 :3 0
576 0 576 575
573 574 :6 0 578
12 :3 0 2c5 57a
2c7 579 578 :2 0
57b 2c9 :2 0 57d
0 57d 57c 52a
57b :6 0 57f b
:3 0 2cc 581 38b
50b 0 582 0
57f 0 582 2ce
0 583 2d1 776
62 :3 0 16 :3 0
17 :2 0 2d3 584
587 7c :2 0 8b
:2 0 2d8 589 58b
:3 0 51 :3 0 2f
:3 0 31 :3 0 8c
:3 0 4b :3 0 13
:4 0 ad 1 :8 0
5a9 87 :4 0 594
:3 0 8e :3 0 7c
:2 0 2dd 597 598
:3 0 9 :3 0 6f
:3 0 59a 59b 0
17 :2 0 59c 59d
0 59f 2e0 5a6
9 :3 0 6f :3 0
5a0 5a1 0 88
:2 0 5a2 5a3 0
5a5 2e2 5a7 599
59f 0 5a8 0
5a5 0 5a8 2e4
0 5a9 2e7 5fc
71 :3 0 9 :3 0
6f :3 0 5ab 5ac
0 70 :3 0 5ad
5ae 0 5b0 2ea
5b2 2ec 5b1 5b0
:2 0 5fa 72 :3 0
9 :3 0 6f :3 0
5b5 5b6 0 70
:3 0 5b7 5b8 0
5f2 55 :3 0 56
:3 0 5ba 5bb 0
55 :3 0 66 :3 0
5bd 5be 0 73
:2 0 2 :4 0 ae
:2 0 68 :2 0 15
:2 0 2ee 5c3 5c5
:3 0 2f1 5bf 5c7
5bc 5c9 5c8 :2 0
58 :3 0 69 :3 0
5cb 5cc 0 5a
:4 0 af :4 0 5d
:2 0 5e :3 0 2f5
5d0 5d2 :3 0 5d
:2 0 76 :4 0 2f8
5d4 5d6 :3 0 5d
:2 0 77 :4 0 2fb
5d8 5da :3 0 5d
:2 0 70 :3 0 2fe
5dc 5de :3 0 5d
:2 0 78 :4 0 301
5e0 5e2 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 304 5e5 5e9
308 5e4 5eb :3 0
30b 5cd 5ed :2 0
5ef 30e 5f0 5ca
5ef 0 5f1 310
0 5f2 312 5f5
:3 0 5f5 0 5f5
5f4 5f2 5f3 :6 0
5f7 14 :3 0 315
5f9 317 5f8 5f7
:2 0 5fa 319 :2 0
5fc 0 5fc 5fb
5a9 5fa :6 0 5fe
b :3 0 31c 772
79 :3 0 14 :3 0
15 :2 0 15 :2 0
31e 5ff 603 7c
:2 0 8b :4 0 324
605 607 :3 0 93
:3 0 94 :3 0 4b
:3 0 13 :3 0 4b
:3 0 2c :3 0 36
:3 0 37 :3 0 95
:4 0 b0 1 :8 0
628 87 :4 0 613
:3 0 8e :3 0 7c
:2 0 329 616 617
:3 0 9 :3 0 6f
:3 0 619 61a 0
17 :2 0 61b 61c
0 61e 32c 625
9 :3 0 6f :3 0
61f 620 0 88
:2 0 621 622 0
624 32e 626 618
61e 0 627 0
624 0 627 330
0 628 333 67b
71 :3 0 9 :3 0
6f :3 0 62a 62b
0 70 :3 0 62c
62d 0 62f 336
631 338 630 62f
:2 0 679 72 :3 0
9 :3 0 6f :3 0
634 635 0 70
:3 0 636 637 0
671 55 :3 0 56
:3 0 639 63a 0
55 :3 0 66 :3 0
63c 63d 0 73
:2 0 2 :4 0 b1
:2 0 68 :2 0 15
:2 0 33a 642 644
:3 0 33d 63e 646
63b 648 647 :2 0
58 :3 0 69 :3 0
64a 64b 0 5a
:4 0 b2 :4 0 5d
:2 0 5e :3 0 341
64f 651 :3 0 5d
:2 0 76 :4 0 344
653 655 :3 0 5d
:2 0 77 :4 0 347
657 659 :3 0 5d
:2 0 70 :3 0 34a
65b 65d :3 0 5d
:2 0 78 :4 0 34d
65f 661 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 350 664 668
354 663 66a :3 0
357 64c 66c :2 0
66e 35a 66f 649
66e 0 670 35c
0 671 35e 674
:3 0 674 0 674
673 671 672 :6 0
676 16 :3 0 361
678 363 677 676
:2 0 679 365 :2 0
67b 0 67b 67a
628 679 :6 0 6f8
b :3 0 51 :3 0
2f :3 0 31 :3 0
8c :3 0 4e :3 0
9d :3 0 47 :3 0
9d :3 0 4e :3 0
48 :3 0 9d :3 0
47 :3 0 9d :3 0
47 :3 0 4b :3 0
13 :4 0 b3 1
:8 0 6a3 87 :4 0
68e :3 0 8e :3 0
7c :2 0 36a 691
692 :3 0 9 :3 0
6f :3 0 694 695
0 17 :2 0 696
697 0 699 36d
6a0 9 :3 0 6f
:3 0 69a 69b 0
88 :2 0 69c 69d
0 69f 36f 6a1
693 699 0 6a2
0 69f 0 6a2
371 0 6a3 374
6f6 71 :3 0 9
:3 0 6f :3 0 6a5
6a6 0 70 :3 0
6a7 6a8 0 6aa
377 6ac 379 6ab
6aa :2 0 6f4 72
:3 0 9 :3 0 6f
:3 0 6af 6b0 0
70 :3 0 6b1 6b2
0 6ec 55 :3 0
56 :3 0 6b4 6b5
0 55 :3 0 66
:3 0 6b7 6b8 0
73 :2 0 2 :4 0
b4 :2 0 68 :2 0
15 :2 0 37b 6bd
6bf :3 0 37e 6b9
6c1 6b6 6c3 6c2
:2 0 58 :3 0 69
:3 0 6c5 6c6 0
5a :4 0 b5 :4 0
5d :2 0 5e :3 0
382 6ca 6cc :3 0
5d :2 0 76 :4 0
385 6ce 6d0 :3 0
5d :2 0 77 :4 0
388 6d2 6d4 :3 0
5d :2 0 70 :3 0
38b 6d6 6d8 :3 0
5d :2 0 78 :4 0
38e 6da 6dc :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 391 6df
6e3 395 6de 6e5
:3 0 398 6c7 6e7
:2 0 6e9 39b 6ea
6c4 6e9 0 6eb
39d 0 6ec 39f
6ef :3 0 6ef 0
6ef 6ee 6ec 6ed
:6 0 6f1 18 :3 0
3a2 6f3 3a4 6f2
6f1 :2 0 6f4 3a6
:2 0 6f6 0 6f6
6f5 6a3 6f4 :6 0
6f8 b :3 0 3a9
76e 51 :3 0 2f
:3 0 31 :3 0 8c
:3 0 48 :3 0 4f
:3 0 50 :3 0 4b
:3 0 13 :4 0 b6
1 :8 0 718 87
:4 0 703 :3 0 8e
:3 0 7c :2 0 3ae
706 707 :3 0 9
:3 0 6f :3 0 709
70a 0 17 :2 0
70b 70c 0 70e
3b1 715 9 :3 0
6f :3 0 70f 710
0 88 :2 0 711
712 0 714 3b3
716 708 70e 0
717 0 714 0
717 3b5 0 718
3b8 76b 71 :3 0
9 :3 0 6f :3 0
71a 71b 0 70
:3 0 71c 71d 0
71f 3bb 721 3bd
720 71f :2 0 769
72 :3 0 9 :3 0
6f :3 0 724 725
0 70 :3 0 726
727 0 761 55
:3 0 56 :3 0 729
72a 0 55 :3 0
66 :3 0 72c 72d
0 73 :2 0 2
:4 0 b7 :2 0 68
:2 0 15 :2 0 3bf
732 734 :3 0 3c2
72e 736 72b 738
737 :2 0 58 :3 0
69 :3 0 73a 73b
0 5a :4 0 b8
:4 0 5d :2 0 5e
:3 0 3c6 73f 741
:3 0 5d :2 0 76
:4 0 3c9 743 745
:3 0 5d :2 0 77
:4 0 3cc 747 749
:3 0 5d :2 0 70
:3 0 3cf 74b 74d
:3 0 5d :2 0 78
:4 0 3d2 74f 751
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 3d5
754 758 3d9 753
75a :3 0 3dc 73c
75c :2 0 75e 3df
75f 739 75e 0
760 3e1 0 761
3e3 764 :3 0 764
0 764 763 761
762 :6 0 766 1a
:3 0 3e6 768 3e8
767 766 :2 0 769
3ea :2 0 76b 0
76b 76a 718 769
:6 0 76d b :3 0
3ed 76f 608 6f8
0 770 0 76d
0 770 3ef 0
771 3f2 773 58c
5fe 0 774 0
771 0 774 3f4
0 775 3f7 777
381 583 0 778
0 775 0 778
3f9 0 8f3 9
:3 0 6f :3 0 779
77a 0 9 :3 0
7c :2 0 b9 :3 0
77c 77e 0 3fe
77d 780 :3 0 781
:2 0 1e :3 0 15
:2 0 783 784 0
786 401 787 782
786 0 788 403
0 8f3 27 :3 0
17 :2 0 789 78a
0 8f3 23 :3 0
91 :3 0 24 :3 0
13 :3 0 25 :3 0
26 :3 0 62 :3 0
27 :3 0 17 :2 0
405 792 795 408
78d 797 78c 798
0 8f3 62 :3 0
1e :3 0 17 :2 0
40e 79a 79d 7c
:2 0 17 :2 0 413
79f 7a1 :3 0 ba
:3 0 62 :3 0 16
:3 0 17 :2 0 416
7a4 7a7 15 :2 0
419 7a3 7aa 7ab
:2 0 7c :2 0 15
:2 0 41e 7ad 7af
:3 0 7b0 :2 0 62
:3 0 22 :3 0 17
:2 0 421 7b2 7b5
bb :2 0 17 :2 0
426 7b7 7b9 :3 0
7ba :2 0 7b1 7bc
7bb :2 0 29 :3 0
bc :3 0 62 :3 0
bd :3 0 21 :3 0
429 7c1 7c3 17
:2 0 42b 7c0 7c6
be :2 0 62 :3 0
bd :3 0 20 :3 0
42e 7ca 7cc 17
:2 0 430 7c9 7cf
433 7c8 7d1 :3 0
7d2 :2 0 bf :2 0
c0 :2 0 436 7d4
7d6 :3 0 7d7 :2 0
80 :2 0 62 :3 0
22 :3 0 17 :2 0
439 7da 7dd 43c
7d9 7df :3 0 43f
7bf 7e1 7be 7e2
0 8ed 29 :3 0
bb :2 0 15 :2 0
443 7e5 7e7 :3 0
7e8 :2 0 29 :3 0
c1 :2 0 80 :2 0
15 :2 0 446 7ec
7ee :3 0 44a 7eb
7f0 :3 0 7e9 7f2
7f1 :2 0 51 :3 0
c2 :3 0 c3 :3 0
c4 :3 0 c2 :3 0
37 :3 0 c5 :3 0
a2 :3 0 a2 :3 0
48 :3 0 32 :3 0
a2 :3 0 4b :3 0
13 :4 0 c6 1
:8 0 818 87 :4 0
803 :3 0 8e :3 0
7c :2 0 44f 806
807 :3 0 9 :3 0
6f :3 0 809 80a
0 17 :2 0 80b
80c 0 80e 452
815 9 :3 0 6f
:3 0 80f 810 0
88 :2 0 811 812
0 814 454 816
808 80e 0 817
0 814 0 817
456 0 818 459
86b 71 :3 0 9
:3 0 6f :3 0 81a
81b 0 70 :3 0
81c 81d 0 81f
45c 821 45e 820
81f :2 0 869 72
:3 0 9 :3 0 6f
:3 0 824 825 0
70 :3 0 826 827
0 861 55 :3 0
56 :3 0 829 82a
0 55 :3 0 66
:3 0 82c 82d 0
73 :2 0 2 :4 0
c7 :2 0 68 :2 0
15 :2 0 460 832
834 :3 0 463 82e
836 82b 838 837
:2 0 58 :3 0 69
:3 0 83a 83b 0
5a :4 0 c8 :4 0
5d :2 0 5e :3 0
467 83f 841 :3 0
5d :2 0 76 :4 0
46a 843 845 :3 0
5d :2 0 77 :4 0
46d 847 849 :3 0
5d :2 0 70 :3 0
470 84b 84d :3 0
5d :2 0 78 :4 0
473 84f 851 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 476 854
858 47a 853 85a
:3 0 47d 83c 85c
:2 0 85e 480 85f
839 85e 0 860
482 0 861 484
864 :3 0 864 0
864 863 861 862
:6 0 866 1c :3 0
487 868 489 867
866 :2 0 869 48b
:2 0 86b 0 86b
86a 818 869 :6 0
86d b :3 0 48e
8e2 51 :3 0 a2
:3 0 a2 :3 0 48
:3 0 32 :3 0 a2
:3 0 4b :3 0 13
:4 0 c9 1 :8 0
88c 87 :4 0 877
:3 0 8e :3 0 7c
:2 0 492 87a 87b
:3 0 9 :3 0 6f
:3 0 87d 87e 0
17 :2 0 87f 880
0 882 495 889
9 :3 0 6f :3 0
883 884 0 88
:2 0 885 886 0
888 497 88a 87c
882 0 88b 0
888 0 88b 499
0 88c 49c 8df
71 :3 0 9 :3 0
6f :3 0 88e 88f
0 70 :3 0 890
891 0 893 49f
895 4a1 894 893
:2 0 8dd 72 :3 0
9 :3 0 6f :3 0
898 899 0 70
:3 0 89a 89b 0
8d5 55 :3 0 56
:3 0 89d 89e 0
55 :3 0 66 :3 0
8a0 8a1 0 73
:2 0 2 :4 0 ca
:2 0 68 :2 0 15
:2 0 4a3 8a6 8a8
:3 0 4a6 8a2 8aa
89f 8ac 8ab :2 0
58 :3 0 69 :3 0
8ae 8af 0 5a
:4 0 cb :4 0 5d
:2 0 5e :3 0 4aa
8b3 8b5 :3 0 5d
:2 0 76 :4 0 4ad
8b7 8b9 :3 0 5d
:2 0 77 :4 0 4b0
8bb 8bd :3 0 5d
:2 0 70 :3 0 4b3
8bf 8c1 :3 0 5d
:2 0 78 :4 0 4b6
8c3 8c5 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 4b9 8c8 8cc
4bd 8c7 8ce :3 0
4c0 8b0 8d0 :2 0
8d2 4c3 8d3 8ad
8d2 0 8d4 4c5
0 8d5 4c7 8d8
:3 0 8d8 0 8d8
8d7 8d5 8d6 :6 0
8da 1e :3 0 4ca
8dc 4cc 8db 8da
:2 0 8dd 4ce :2 0
8df 0 8df 8de
88c 8dd :6 0 8e1
b :3 0 4d1 8e3
7f3 86d 0 8e4
0 8e1 0 8e4
4d3 0 8ed 1c
:3 0 cc :3 0 d
:3 0 13 :3 0 16
:3 0 4d6 8e6 8ea
8e5 8eb 0 8ed
4da 8ee 7bd 8ed
0 8ef 4de 0
8f0 4e0 8f1 7a2
8f0 0 8f2 4e2
0 8f3 4e4 8f5
86 :4 0 8f3 :4 0
954 cd :3 0 4a
:4 0 8f9 :2 0 8ff
8f7 0 9 :3 0
6f :3 0 8fa 8fb
0 70 :3 0 8fc
8fd 0 8ff 4ee
952 71 :3 0 9
:3 0 6f :3 0 901
902 0 70 :3 0
903 904 0 906
4f1 908 4f3 907
906 :2 0 950 72
:3 0 9 :3 0 6f
:3 0 90b 90c 0
70 :3 0 90d 90e
0 948 55 :3 0
56 :3 0 910 911
0 55 :3 0 66
:3 0 913 914 0
73 :2 0 2 :4 0
ce :2 0 68 :2 0
15 :2 0 4f5 919
91b :3 0 4f8 915
91d 912 91f 91e
:2 0 58 :3 0 69
:3 0 921 922 0
5a :4 0 cf :4 0
5d :2 0 5e :3 0
4fc 926 928 :3 0
5d :2 0 76 :4 0
4ff 92a 92c :3 0
5d :2 0 77 :4 0
502 92e 930 :3 0
5d :2 0 70 :3 0
505 932 934 :3 0
5d :2 0 78 :4 0
508 936 938 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 50b 93b
93f 50f 93a 941
:3 0 512 923 943
:2 0 945 515 946
920 945 0 947
517 0 948 519
94b :3 0 94b 0
94b 94a 948 949
:6 0 94d 20 :3 0
51c 94f 51e 94e
94d :2 0 950 520
:2 0 952 0 952
951 8ff 950 :6 0
954 8 :3 0 523
956 2af 344 0
957 0 954 0
957 527 0 9db
33 :3 0 d0 :3 0
d1 :3 0 79 :3 0
30 :3 0 d1 :3 0
79 :3 0 1a :3 0
d2 :3 0 d1 :3 0
79 :3 0 30 :3 0
d1 :3 0 79 :3 0
1a :3 0 30 :3 0
34 :3 0 d :3 0
2c :3 0 12 :4 0
d3 1 :8 0 982
87 :4 0 96d :3 0
8e :3 0 7c :2 0
52c 970 971 :3 0
9 :3 0 6f :3 0
973 974 0 17
:2 0 975 976 0
978 52f 97f 9
:3 0 6f :3 0 979
97a 0 88 :2 0
97b 97c 0 97e
531 980 972 978
0 981 0 97e
0 981 533 0
982 536 9d5 71
:3 0 9 :3 0 6f
:3 0 984 985 0
70 :3 0 986 987
0 989 539 98b
53b 98a 989 :2 0
9d3 72 :3 0 9
:3 0 6f :3 0 98e
98f 0 70 :3 0
990 991 0 9cb
55 :3 0 56 :3 0
993 994 0 55
:3 0 66 :3 0 996
997 0 73 :2 0
2 :4 0 d4 :2 0
68 :2 0 15 :2 0
53d 99c 99e :3 0
540 998 9a0 995
9a2 9a1 :2 0 58
:3 0 69 :3 0 9a4
9a5 0 5a :4 0
d5 :4 0 5d :2 0
5e :3 0 544 9a9
9ab :3 0 5d :2 0
76 :4 0 547 9ad
9af :3 0 5d :2 0
77 :4 0 54a 9b1
9b3 :3 0 5d :2 0
70 :3 0 54d 9b5
9b7 :3 0 5d :2 0
78 :4 0 550 9b9
9bb :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
553 9be 9c2 557
9bd 9c4 :3 0 55a
9a6 9c6 :2 0 9c8
55d 9c9 9a3 9c8
0 9ca 55f 0
9cb 561 9ce :3 0
9ce 0 9ce 9cd
9cb 9cc :6 0 9d0
22 :3 0 564 9d2
566 9d1 9d0 :2 0
9d3 568 :2 0 9d5
0 9d5 9d4 982
9d3 :6 0 9db 8
:3 0 92 :5 0 9d9
24 0 9da 56b
9d9 9d8 9db 56d
9dd 86 :4 0 9db
:4 0 a51 cd :3 0
2b :4 0 9e1 :2 0
9e7 9df 0 9
:3 0 6f :3 0 9e2
9e3 0 70 :3 0
9e4 9e5 0 9e7
574 a3a 71 :3 0
9 :3 0 6f :3 0
9e9 9ea 0 70
:3 0 9eb 9ec 0
9ee 577 9f0 579
9ef 9ee :2 0 a38
72 :3 0 9 :3 0
6f :3 0 9f3 9f4
0 70 :3 0 9f5
9f6 0 a30 55
:3 0 56 :3 0 9f8
9f9 0 55 :3 0
66 :3 0 9fb 9fc
0 73 :2 0 2
:4 0 d6 :2 0 68
:2 0 15 :2 0 57b
a01 a03 :3 0 57e
9fd a05 9fa a07
a06 :2 0 58 :3 0
69 :3 0 a09 a0a
0 5a :4 0 d7
:4 0 5d :2 0 5e
:3 0 582 a0e a10
:3 0 5d :2 0 76
:4 0 585 a12 a14
:3 0 5d :2 0 77
:4 0 588 a16 a18
:3 0 5d :2 0 70
:3 0 58b a1a a1c
:3 0 5d :2 0 78
:4 0 58e a1e a20
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 591
a23 a27 595 a22
a29 :3 0 598 a0b
a2b :2 0 a2d 59b
a2e a08 a2d 0
a2f 59d 0 a30
59f a33 :3 0 a33
0 a33 a32 a30
a31 :6 0 a35 24
:3 0 5a2 a37 5a4
a36 a35 :2 0 a38
5a6 :2 0 a3a 0
a3a a39 9e7 a38
:6 0 a51 1 :3 0
62 :3 0 18 :3 0
17 :2 0 5a9 a3c
a3f bb :2 0 80
:2 0 15 :2 0 5ac
a42 a44 :3 0 5b0
a41 a46 :3 0 1c
:3 0 d8 :3 0 d
:3 0 5b3 a49 a4b
a48 a4c 0 a4e
5b5 a4f a47 a4e
0 a50 5b7 0
a51 5b9 a52 205
a51 0 a53 5c1
0 aa2 55 :3 0
56 :3 0 a54 a55
0 55 :3 0 66
:3 0 a57 a58 0
d9 :2 0 2 :4 0
da :2 0 68 :2 0
15 :2 0 5c3 a5d
a5f :3 0 5c6 a59
a61 a56 a63 a62
:2 0 58 :3 0 69
:3 0 a65 a66 0
5a :4 0 db :4 0
5d :2 0 5e :3 0
5ca a6a a6c :3 0
5d :2 0 76 :4 0
5cd a6e a70 :3 0
5d :2 0 dc :4 0
5d0 a72 a74 :3 0
5d :2 0 62 :3 0
63 :3 0 9 :3 0
6f :3 0 a79 a7a
0 5d3 a78 a7c
64 :4 0 5d5 a77
a7f 5d8 a76 a81
:3 0 5d :2 0 dd
:4 0 5db a83 a85
:3 0 5d :2 0 60
:4 0 5de a87 a89
:3 0 5d :2 0 3
:3 0 5e1 a8b a8d
:3 0 5d :2 0 60
:4 0 5e4 a8f a91
:3 0 5e7 a67 a93
:2 0 a95 5ea a96
a64 a95 0 a97
5ec 0 aa2 de
:3 0 df :3 0 a98
a99 0 9 :3 0
6f :3 0 a9b a9c
0 3 :3 0 8e
:3 0 5ee a9a aa0
:2 0 aa2 5f2 b43
9 :3 0 e0 :2 0
4 aa3 aa4 0
55 :3 0 56 :3 0
aa6 aa7 0 55
:3 0 66 :3 0 aa9
aaa 0 73 :2 0
2 :4 0 e1 :2 0
68 :2 0 15 :2 0
5fd aaf ab1 :3 0
600 aab ab3 aa8
ab5 ab4 :2 0 58
:3 0 69 :3 0 ab7
ab8 0 5a :4 0
e2 :4 0 5d :2 0
5e :3 0 604 abc
abe :3 0 607 ab9
ac0 :2 0 ad9 58
:3 0 69 :3 0 ac2
ac3 0 5a :4 0
e3 :4 0 5d :2 0
9 :3 0 e4 :3 0
ac8 ac9 0 60a
ac7 acb :3 0 5d
:2 0 dd :4 0 60d
acd acf :3 0 5d
:2 0 9 :3 0 e5
:3 0 ad2 ad3 0
610 ad1 ad5 :3 0
613 ac4 ad7 :2 0
ad9 616 ada ab6
ad9 0 adb 619
0 aeb 85 :3 0
54 :3 0 9 :3 0
e4 :3 0 e6 :3 0
9 :3 0 e5 :3 0
3 :3 0 e7 :4 0
e8 1 :a 0 ae7
:2 0 aeb add ae5
:2 0 8 :3 0 54
:3 0 ae9 :2 0 aeb
61b aed 61f aec
aeb :2 0 b41 72
:3 0 9 :3 0 6f
:3 0 af0 af1 0
70 :3 0 af2 af3
0 b39 55 :3 0
56 :3 0 af5 af6
0 55 :3 0 66
:3 0 af8 af9 0
73 :2 0 2 :4 0
e9 :2 0 68 :2 0
15 :2 0 621 afe
b00 :3 0 624 afa
b02 af7 b04 b03
:2 0 58 :3 0 69
:3 0 b06 b07 0
5a :4 0 ea :4 0
5d :2 0 5e :3 0
628 b0b b0d :3 0
62b b08 b0f :2 0
b29 58 :3 0 69
:3 0 b11 b12 0
5a :4 0 77 :4 0
5d :2 0 70 :3 0
62e b16 b18 :3 0
5d :2 0 78 :4 0
631 b1a b1c :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 634 b1f
b23 638 b1e b25
:3 0 63b b13 b27
:2 0 b29 63e b2a
b05 b29 0 b2b
641 0 b39 85
:3 0 54 :3 0 e6
:3 0 9 :3 0 e5
:3 0 3 :3 0 e7
:4 0 eb 1 :a 0
b35 :2 0 b39 b2d
b33 :2 0 8 :3 0
54 :3 0 b37 :2 0
b39 643 b3c :3 0
b3c 0 b3c b3b
b39 b3a :6 0 b3e
1 :3 0 648 b40
64a b3f b3e :2 0
b41 64c :2 0 b43
64f b43 b42 aa2
b41 :6 0 b44 :2 0
2 14 b43 b47
:3 0 b46 b44 b48
:8 0 
66c
4
:3 0 1 3 1
7 1 b 3
6 a e 1
16 1 1d 1
1b 1 24 1
22 1 29 1
30 1 2e 1
37 1 35 1
3e 1 3c 1
43 1 49 1
4f 1 55 1
5a 1 60 1
66 1 6c 1
72 1 78 1
7e 1 84 1
8c 1 8a 1
93 1 91 1
98 1 9e 1
a4 1 aa 1
e9 1 108 1
10e 1 11b 1
127 2 12a 12c
2 12f 131 2
133 135 2 137
139 2 13b 13d
1 143 2 145
146 2 13f 148
2 14a 14c 2
14e 150 2 152
154 2 156 158
2 15a 15c 4
123 129 12e 15e
1 160 1 162
2 16c 16e 3
16a 16b 170 2
179 17b 2 178
17d 1 17f 1
181 2 199 19e
1 1a5 1 1a0
2 1b8 1ba 3
1b6 1b7 1bc 2
1c5 1c7 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 2
1d5 1d7 3 1dc
1dd 1de 2 1d9
1e0 2 1c4 1e2
1 1e4 1 1e6
2 1af 1e7 1
1eb 1 1aa 2
1a8 1ef 1 1fa
2 1f6 1fa 1
1fe 2 208 20a
3 20c 20d 20e
1 214 2 21d
222 1 229 1
224 2 23c 23e
3 23a 23b 240
2 249 24b 2
24d 24f 2 251
253 2 255 257
2 259 25b 3
260 261 262 2
25d 264 2 248
266 1 268 1
26a 2 233 26b
1 26f 1 22e
2 22c 273 4
27f 280 281 282
1 28d 1 293
2 295 296 1
29e 2 29a 29e
1 2a3 1 2a5
2 2a8 2a9 1
2ad 2 2ab 2ad
2 2b1 2b2 1
2b6 2 2b4 2b6
1 2c4 2 2c3
2c4 1 2cc 1
2d2 2 2d4 2d5
2 2c1 2d6 1
2dd 1 2d8 2
2f0 2f2 3 2ee
2ef 2f4 2 2fd
2ff 2 301 303
2 305 307 2
309 30b 2 30d
30f 3 314 315
316 2 311 318
2 2fc 31a 1
31c 1 31e 2
2e7 31f 1 323
1 2e2 2 2e0
327 2 336 337
5 331 332 333
334 339 3 32a
32e 33c 1 33f
2 341 342 1
343 6 34c 34d
34e 34f 350 351
1 35c 1 362
2 364 365 1
36d 2 369 36d
1 372 1 374
2 37a 37b 1
37f 2 37d 37f
3 383 384 385
1 389 2 387
389 1 398 2
397 398 1 3a0
1 3a6 2 3a8
3a9 2 395 3aa
1 3b1 1 3ac
2 3c4 3c6 3
3c2 3c3 3c8 2
3d1 3d3 2 3d5
3d7 2 3d9 3db
2 3dd 3df 2
3e1 3e3 3 3e8
3e9 3ea 2 3e5
3ec 2 3d0 3ee
1 3f0 1 3f2
2 3bb 3f3 1
3f7 1 3b6 2
3b4 3fb 2 401
402 1 407 1
409 2 404 409
1 42b 2 42a
42b 1 433 1
439 2 43b 43c
2 428 43d 1
444 1 43f 2
457 459 3 455
456 45b 2 464
466 2 468 46a
2 46c 46e 2
470 472 2 474
476 3 47b 47c
47d 2 478 47f
2 463 481 1
483 1 485 2
44e 486 1 48a
1 449 2 447
48e 2 410 491
1 49f 2 49e
49f 1 4a7 1
4ad 2 4af 4b0
2 49c 4b1 1
4b8 1 4b3 2
4cb 4cd 3 4c9
4ca 4cf 2 4d8
4da 2 4dc 4de
2 4e0 4e2 2
4e4 4e6 2 4e8
4ea 3 4ef 4f0
4f1 2 4ec 4f3
2 4d7 4f5 1
4f7 1 4f9 2
4c2 4fa 1 4fe
1 4bd 2 4bb
502 1 505 2
508 509 2 3fe
50a 1 517 2
516 517 1 51f
1 525 2 527
528 2 514 529
1 530 1 52b
2 543 545 3
541 542 547 2
550 552 2 554
556 2 558 55a
2 55c 55e 2
560 562 3 567
568 569 2 564
56b 2 54f 56d
1 56f 1 571
2 53a 572 1
576 1 535 2
533 57a 1 57d
2 580 581 1
582 2 585 586
1 58a 2 588
58a 1 596 2
595 596 1 59e
1 5a4 2 5a6
5a7 2 593 5a8
1 5af 1 5aa
2 5c2 5c4 3
5c0 5c1 5c6 2
5cf 5d1 2 5d3
5d5 2 5d7 5d9
2 5db 5dd 2
5df 5e1 3 5e6
5e7 5e8 2 5e3
5ea 2 5ce 5ec
1 5ee 1 5f0
2 5b9 5f1 1
5f5 1 5b4 2
5b2 5f9 1 5fc
3 600 601 602
1 606 2 604
606 1 615 2
614 615 1 61d
1 623 2 625
626 2 612 627
1 62e 1 629
2 641 643 3
63f 640 645 2
64e 650 2 652
654 2 656 658
2 65a 65c 2
65e 660 3 665
666 667 2 662
669 2 64d 66b
1 66d 1 66f
2 638 670 1
674 1 633 2
631 678 1 690
2 68f 690 1
698 1 69e 2
6a0 6a1 2 68d
6a2 1 6a9 1
6a4 2 6bc 6be
3 6ba 6bb 6c0
2 6c9 6cb 2
6cd 6cf 2 6d1
6d3 2 6d5 6d7
2 6d9 6db 3
6e0 6e1 6e2 2
6dd 6e4 2 6c8
6e6 1 6e8 1
6ea 2 6b3 6eb
1 6ef 1 6ae
2 6ac 6f3 2
67b 6f6 1 705
2 704 705 1
70d 1 713 2
715 716 2 702
717 1 71e 1
719 2 731 733
3 72f 730 735
2 73e 740 2
742 744 2 746
748 2 74a 74c
2 74e 750 3
755 756 757 2
752 759 2 73d
75b 1 75d 1
75f 2 728 760
1 764 1 723
2 721 768 1
76b 2 76e 76f
1 770 2 772
773 1 774 2
776 777 1 77f
2 77b 77f 1
785 1 787 2
793 794 5 78e
78f 790 791 796
2 79b 79c 1
7a0 2 79e 7a0
2 7a5 7a6 2
7a8 7a9 1 7ae
2 7ac 7ae 2
7b3 7b4 1 7b8
2 7b6 7b8 1
7c2 2 7c4 7c5
1 7cb 2 7cd
7ce 2 7c7 7d0
2 7d3 7d5 2
7db 7dc 2 7d8
7de 1 7e0 1
7e6 2 7e4 7e6
1 7ed 1 7ef
2 7ea 7ef 1
805 2 804 805
1 80d 1 813
2 815 816 2
802 817 1 81e
1 819 2 831
833 3 82f 830
835 2 83e 840
2 842 844 2
846 848 2 84a
84c 2 84e 850
3 855 856 857
2 852 859 2
83d 85b 1 85d
1 85f 2 828
860 1 864 1
823 2 821 868
1 86b 1 879
2 878 879 1
881 1 887 2
889 88a 2 876
88b 1 892 1
88d 2 8a5 8a7
3 8a3 8a4 8a9
2 8b2 8b4 2
8b6 8b8 2 8ba
8bc 2 8be 8c0
2 8c2 8c4 3
8c9 8ca 8cb 2
8c6 8cd 2 8b1
8cf 1 8d1 1
8d3 2 89c 8d4
1 8d8 1 897
2 895 8dc 1
8df 2 8e2 8e3
3 8e7 8e8 8e9
3 7e3 8e4 8ec
1 8ee 1 8ef
1 8f1 9 352
366 375 378 778
788 78b 799 8f2
2 8f8 8fe 1
905 1 900 2
918 91a 3 916
917 91c 2 925
927 2 929 92b
2 92d 92f 2
931 933 2 935
937 3 93c 93d
93e 2 939 940
2 924 942 1
944 1 946 2
90f 947 1 94b
1 90a 2 908
94f 3 347 8f5
952 2 955 956
1 96f 2 96e
96f 1 977 1
97d 2 97f 980
2 96c 981 1
988 1 983 2
99b 99d 3 999
99a 99f 2 9a8
9aa 2 9ac 9ae
2 9b0 9b2 2
9b4 9b6 2 9b8
9ba 3 9bf 9c0
9c1 2 9bc 9c3
2 9a7 9c5 1
9c7 1 9c9 2
992 9ca 1 9ce
1 98d 2 98b
9d2 1 9d7 6
283 297 2a6 957
9d5 9da 2 9e0
9e6 1 9ed 1
9e8 2 a00 a02
3 9fe 9ff a04
2 a0d a0f 2
a11 a13 2 a15
a17 2 a19 a1b
2 a1d a1f 3
a24 a25 a26 2
a21 a28 2 a0c
a2a 1 a2c 1
a2e 2 9f7 a2f
1 a33 1 9f2
2 9f0 a37 2
a3d a3e 1 a43
1 a45 2 a40
a45 1 a4a 1
a4d 1 a4f 7
211 217 276 27a
9dd a3a a50 1
a52 2 a5c a5e
3 a5a a5b a60
2 a69 a6b 2
a6d a6f 2 a71
a73 1 a7b 2
a7d a7e 2 a75
a80 2 a82 a84
2 a86 a88 2
a8a a8c 2 a8e
a90 2 a68 a92
1 a94 1 a96
3 a9d a9e a9f
a 163 182 185
188 18b 18e 1f2
a53 a97 aa1 2
aae ab0 3 aac
aad ab2 2 abb
abd 2 aba abf
2 ac6 aca 2
acc ace 2 ad0
ad4 2 ac5 ad6
2 ac1 ad8 1
ada 3 adb ae6
aea 1 aa5 2
afd aff 3 afb
afc b01 2 b0a
b0c 2 b09 b0e
2 b15 b17 2
b19 b1b 3 b20
b21 b22 2 b1d
b24 2 b14 b26
2 b10 b28 1
b2a 4 af4 b2b
b34 b38 1 b3c
1 aef 2 aed
b40 1c 19 20
27 2c 33 3a
41 47 4d 53
58 5e 64 6a
70 76 7c 82
88 8f 96 9c
a2 a8 ad ea
109 113 
1
4
0 
b47
0
1
28
26
21
0 1 1 1 4 1 6 1
8 9 8 b c b e b
10 b 12 b 14 b 16 b
18 b 1a b 1c b 1e 8
20 8 22 1 24 1 0 0

b 1 0
60 1 0
3 1 0
7e 1 0
16 1 0
35 1 0
98 1 0
2 0 1
9d7 8 24
84 1 0
5a 1 0
49 1 0
29 1 0
8a 1 0
f0 1 3
43 1 0
72 1 0
2e 1 0
22 1 0
78 1 0
a4 1 0
3c 1 0
6c 1 0
9e 1 0
4f 1 0
55 1 0
1b 1 0
66 1 0
7 1 0
91 1 0
b0 1 2
aa 1 0
10e 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_WBS;
ALTER FUNCTION SP_RJCT_ETC_WBS COMPILE DEBUG;
Prompt == FUNCTION SP_U_WP_FORECAST ==
CREATE OR REPLACE FUNCTION SP_U_WP_FORECAST wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
138
2 :e:
1FUNCTION:
1SP_U_WP_FORECAST:
1ID:
1VARCHAR2:
1START_DATE001:
1TIMESTAMP:
1FINISH_DATE001:
1ACC_REJ_BITFLAG:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_REC_STATUS:
11:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_RES_ASSIGNMENT_ID:
1H_RES_ID:
1H_REC_USER:
1H_SECURITY_ID:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FORECAST_START:
1H_FORECAST_FINISH:
1H_ACTUAL_START:
1H_RANK:
1200:
1H_MLST_PERCENT:
10:
1H_TYPE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_LAST_SUBMITTED:
1DATE:
1H_PROJAFFECTED_START:
1H_DAYOFYEAR:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_ETC:
1H_TOTAL:
1H_SCHED_WORK:
1H_CONTINUE:
1H_EFFORT:
1H_CONTOUR:
1H_BITFLAG:
1H_ACC_REJ_BITFLAG:
1H_REMAINING:
1H_FF:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_ALERT_FLAG:
1H_ALERT_ID:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_FORECAST(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
168:
1+:
1FPUT:
1               ENTER:: SP_U_WP_FORECAST(69) :: cplan.sql(21728) :: :
1:
1=:
1PMO_CNST:
1SC_ACCEPT_REJECT_FORECAST:
1PROJECT_ID:
1RES_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1ACTUAL_START:
1MILESTONE_PERCENT:
1BIT_FLAG:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TASK_ID:
1RESOURCE_ID:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1ETC:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, ACTUAL_START, MI+
1LESTONE_PERCENT, BIT_FLAG, :n      COALESCE(FORECAST_START,SCHED_START), COAL+
1ESCE(FORECAST_FINISH,SCHED_FINISH), FORECAST_START, FORECAST_FINISH, TASK_ID,+
1 RESOURCE_ID, SCHED_WORK, (PLANNED_WORK + SCHED_WORK - WORK_TODATE), ETC,:n  +
1    C_CONTOUR, LAST_SUBMITTED, UNRESOLVED_START, UNRESOLVED_FINISH, BILLABLE,+
1 CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n      INTO h_project_id, h_res_+
1assignment_id, h_prj_assignment_id, h_actual_start, h_mlst_percent, h_bit_fla+
1g,:n      h_start_DT, h_finish_DT, h_forecast_start, h_forecast_finish, h_tas+
1k_id, h_res_id, h_sched_work,h_remaining, h_etc,:n      h_contour, h_last_sub+
1mitted, h_ta_start_DT, h_ta_finish_DT, h_billable, h_capital_expense, h_reg_c+
1ost, h_reg_sale:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1104:
1           EXCEPTION:: SP_U_WP_FORECAST(105) :: cplan.sql(21764) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1112:
1        RETURN_ERROR:: SP_U_WP_FORECAST(113) :: cplan.sql(21772) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1115:
1                EXIT:: SP_U_WP_FORECAST(116) :: cplan.sql(21775) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS:n      INTO h_rec_status:n      FROM TMT_WBS:n      WHERE P+
1ROJECT_ID = h_project_id:n      AND ELEMENT_ID = h_task_id:
1134:
1           EXCEPTION:: SP_U_WP_FORECAST(135) :: cplan.sql(21794) :: :
1T:
1141:
1        RETURN_ERROR:: SP_U_WP_FORECAST(142) :: cplan.sql(21801) :: :
1CANNOT_UPDATE_LOCKED_RECORD:
1144:
1                EXIT:: SP_U_WP_FORECAST(145) :: cplan.sql(21804) :: :
110000:
1151:
1        RETURN_ERROR:: SP_U_WP_FORECAST(152) :: cplan.sql(21811) :: :
1ASSIGNMENT_ALREADY_CLOSED:
1154:
1                EXIT:: SP_U_WP_FORECAST(155) :: cplan.sql(21814) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1<:
1162:
1        RETURN_ERROR:: SP_U_WP_FORECAST(163) :: cplan.sql(21822) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1165:
1                EXIT:: SP_U_WP_FORECAST(166) :: cplan.sql(21825) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1CURRENT_STATE:
1SC_APV_STATE_RM_APPROVED:
1SC_APV_STATE_PM_APPROVED:
1SC_APV_STATE_SUBMITTED:
1SELECT MAX(WEEK_OF) + 7      INTO h_week_of FROM TIMESHEET_APPROVAL_STATUS:n +
1     WHERE ELEMENT_ID = h_project_id AND RESOURCE_ID = h_res_id:n      AND CU+
1RRENT_STATE IN (pmo_cnst.SC_APV_STATE_RM_APPROVED,pmo_cnst.SC_APV_STATE_PM_AP+
1PROVED,pmo_cnst.SC_APV_STATE_SUBMITTED):
1184:
1           EXCEPTION:: SP_U_WP_FORECAST(185) :: cplan.sql(21844) :: :
1STRCMP:
1!=:
1SCETCFORCASTCHANGED:
1FC_ISSUE_ALERT:
1SCREDUCEDETC:
1IS NULL:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n         FORECAST_START  = start_date001,:n     +
1    FORECAST_FINISH = finish_date001,:n         FORECAST_DURATION = 0:n      +
1   WHERE TSK_ASSIGNMENT_ID = id:
1FOUND:
1100:
1230:
1           EXCEPTION:: SP_U_WP_FORECAST(231) :: cplan.sql(21890) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_START  = start_date001,:n  +
1          FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id:
1257:
1           EXCEPTION:: SP_U_WP_FORECAST(258) :: cplan.sql(21917) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_FINISH = finish_date001,:n +
1           FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id:
1289:
1           EXCEPTION:: SP_U_WP_FORECAST(290) :: cplan.sql(21949) :: :
1>:
1313:
1        RETURN_ERROR:: SP_U_WP_FORECAST(314) :: cplan.sql(21973) :: :
1FORECAST_APPROVAL_EXISTS:
1316:
1                EXIT:: SP_U_WP_FORECAST(317) :: cplan.sql(21976) :: :
1324:
1        RETURN_ERROR:: SP_U_WP_FORECAST(325) :: cplan.sql(21984) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1327:
1                EXIT:: SP_U_WP_FORECAST(328) :: cplan.sql(21987) :: :
1ELSIF:
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1TO_DATE:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_start_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10)):
1350:
1           EXCEPTION:: SP_U_WP_FORECAST(351) :: cplan.sql(22010) :: :
1DUAL:
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(start_date001, 1, 10)), PMO_O+
1RASTD.TIME('08::00')))  INTO  h_start_date FROM DUAL:
1367:
1           EXCEPTION:: SP_U_WP_FORECAST(368) :: cplan.sql(22027) :: :
1374:
1        RETURN_ERROR:: SP_U_WP_FORECAST(375) :: cplan.sql(22034) :: :
1377:
1                EXIT:: SP_U_WP_FORECAST(378) :: cplan.sql(22037) :: :
1390:
1        RETURN_ERROR:: SP_U_WP_FORECAST(391) :: cplan.sql(22050) :: :
1INVALID_PARAMS:
1393:
1                EXIT:: SP_U_WP_FORECAST(394) :: cplan.sql(22053) :: :
1<=:
18:
1399:
1      RETURN_INVALID:: SP_U_WP_FORECAST(400) :: cplan.sql(22059) :: :
1402:
1                EXIT:: SP_U_WP_FORECAST(403) :: cplan.sql(22062) :: :
1PMO_RETURN_INVALID_SP:
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_finish_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10)):
1431:
1           EXCEPTION:: SP_U_WP_FORECAST(432) :: cplan.sql(22091) :: :
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(finish_date001, 1, 10)), PMO_+
1ORASTD.TIME('17::00')))  INTO  h_finish_date FROM DUAL:
1449:
1           EXCEPTION:: SP_U_WP_FORECAST(450) :: cplan.sql(22109) :: :
1457:
1        RETURN_ERROR:: SP_U_WP_FORECAST(458) :: cplan.sql(22117) :: :
1460:
1                EXIT:: SP_U_WP_FORECAST(461) :: cplan.sql(22120) :: :
1UPDATE TASK_ASSIGNMENTS SET:n               FORECAST_START  = h_start_date,:n+
1               FORECAST_FINISH = h_finish_date,:n               FORECAST_DURA+
1TION = 0:n               WHERE TSK_ASSIGNMENT_ID = id:
1491:
1           EXCEPTION:: SP_U_WP_FORECAST(492) :: cplan.sql(22151) :: :
1COUNT:
1TASK_DAY_OF_YEAR:
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10))):
1516:
1           EXCEPTION:: SP_U_WP_FORECAST(517) :: cplan.sql(22176) :: :
1524:
1        RETURN_ERROR:: SP_U_WP_FORECAST(525) :: cplan.sql(22184) :: :
1PROJECT_ASSIGNMENT_REMAINING:
1527:
1                EXIT:: SP_U_WP_FORECAST(528) :: cplan.sql(22187) :: :
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10))):
1549:
1           EXCEPTION:: SP_U_WP_FORECAST(550) :: cplan.sql(22209) :: :
1557:
1        RETURN_ERROR:: SP_U_WP_FORECAST(558) :: cplan.sql(22217) :: :
1560:
1                EXIT:: SP_U_WP_FORECAST(561) :: cplan.sql(22220) :: :
1SUM:
1SCHED_MIN:
1PARENT_ID:
1SELECT SUM(SCHED_MIN) INTO h_total FROM TASK_DAY_OF_YEAR:n                   +
1     WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_prj_assignment_id AND +
1DAY_YEAR >= TO_DATE(SubStr(start_date001, 1, 10)):
1580:
1           EXCEPTION:: SP_U_WP_FORECAST(581) :: cplan.sql(22240) :: :
1586:
1        RETURN_ERROR:: SP_U_WP_FORECAST(587) :: cplan.sql(22246) :: :
1589:
1                EXIT:: SP_U_WP_FORECAST(590) :: cplan.sql(22249) :: :
1597:
1        RETURN_ERROR:: SP_U_WP_FORECAST(598) :: cplan.sql(22257) :: :
1TASK_ASSIGNMENT_ERROR:
1600:
1                EXIT:: SP_U_WP_FORECAST(601) :: cplan.sql(22260) :: :
12:
1FC_ACPT_ETC_ASSIGN:
1U_ASSIGN_STRING:
13:
1FC_ROLLUP:
14:
1651:
1       RETURN_STATUS:: SP_U_WP_FORECAST(652) :: cplan.sql(22311) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1659:
1           EXCEPTION:: SP_U_WP_FORECAST(660) :: cplan.sql(22319) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_ID:
1OPEN:
1ERROR:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1671:
1           EXCEPTION:: SP_U_WP_FORECAST(672) :: cplan.sql(22331) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1218
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :2 a0 6e 7e a0 b4
2e 7e 6e b4 2e 6e a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d a0 6e d a0 51 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
51 a5 b 7e 51 b4 2e 5a
:3 a0 6b d b7 19 3c :37 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 :2 51 a5
b 7e 6e b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a a 10 :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c a0 4d d :f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 d :2 a0 6b :2 a0 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
a 10 a0 6e d a0 51 d
:3 a0 6b d :6 a0 51 a5 b d
:2 a0 6b a0 d a0 6e d a0
51 d :3 a0 6b d :6 a0 51 a5
b d :2 a0 6b a0 d b7 19
3c a0 7e b4 2e :2 5a :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 d b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a a 10 :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 7e b4
2e 5a a0 7e b4 2e 5a a
10 :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a a 10
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e a0 7e b4 2e :2 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 d b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a a 10 :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 4d d a0
b7 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :10 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c a0 b7 19 a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :2 a0 51 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b 51 :2 a0 a5
57 b7 :2 19 3c b7 a0 51 d
a0 4d d b7 :2 19 3c a0 7e
b4 2e 5a a0 7e b4 2e :2 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 a0 7e
b4 2e :2 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
:2 19 3c a0 7e b4 2e :2 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 a0 51 d b7
a0 51 d b7 :2 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
a0 4d d a0 b7 :2 a0 6b :2 a0
a5 b 7e 51 b4 2e :10 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c a0 b7
19 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :2 a0 51 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b 51 :2 a0 a5
57 b7 :2 19 3c b7 a0 4d d
b7 :2 19 3c :2 a0 d a0 51 d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 7e b4 2e 5a
a0 7e b4 2e 5a a0 51 d
:f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 b7 a0 7e
b4 2e 5a a0 51 d :f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 :2 19 3c b7 19 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c b7
19 3c a0 51 d :2 a0 d a0
7e b4 2e 5a a0 7e b4 2e
:2 5a a 10 :2 a0 d b7 19 3c
:18 a0 51 a5 b d a0 51 d
:5 a0 :2 51 a5 b d a0 7e b4
2e 5a a0 51 d :5 a0 :2 51 a5
b d b7 19 3c b7 :2 19 3c
b7 19 3c b7 :2 19 3c :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 a0 6e d
a0 51 d :3 a0 6b d :6 a0 51
a5 b d :2 a0 6b a0 d a0
6e d a0 51 d :3 a0 6b d
:6 a0 51 a5 b d :2 a0 6b a0
d b7 19 3c :3 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
1218
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c9 b7 93
bb bc c4 b6 e6 d4 b3 d8
d9 e1 d3 103 f1 d0 f5 f6
fe f0 120 10e ed 112 113 11b
10d 13d 12b 10a 12f 130 138 12a
15a 148 127 14c 14d 155 147 177
165 144 169 16a 172 164 194 182
161 186 187 18f 181 1b0 19f 1a3
1ab 17e 1c8 1b7 1bb 1c3 19e 1e4
1d3 1d7 1df 19b 1fc 1eb 1ef 1f7
1d2 218 207 20b 213 1cf 230 21f
223 22b 206 24c 23b 23f 247 203
268 253 257 25a 25b 263 23a 284
273 277 237 27f 272 2a0 28f 293
26f 29b 28e 2bc 2ab 2af 28b 2b7
2aa 2d8 2c7 2cb 2a7 2d3 2c6 2f4
2e3 2e7 2ef 2c3 30c 2fb 2ff 307
2e2 328 317 31b 323 2df 340 32f
333 33b 316 35c 34b 34f 357 313
374 363 367 36f 34a 391 37f 347
383 384 38c 37e 3ad 39c 3a0 37b
3a8 39b 3c9 3b8 3bc 398 3c4 3b7
3e5 3d4 3d8 3b4 3e0 3d3 401 3f0
3f4 3d0 3fc 3ef 41d 40c 410 3ec
418 40b 439 428 42c 408 434 427
455 444 448 424 450 443 471 460
464 440 46c 45f 48d 47c 480 45c
488 47b 4a9 498 49c 478 4a4 497
4c5 4b4 4b8 494 4c0 4b3 4e1 4d0
4d4 4b0 4dc 4cf 4fd 4ec 4f0 4cc
4f8 4eb 519 508 50c 4e8 514 507
535 524 528 504 530 523 552 540
520 544 545 54d 53f 56e 55d 561
569 53c 589 575 579 581 584 55c
5a9 594 598 559 59c 5a4 593 5b0
5b4 590 5b8 5bc 5c0 5c3 5c8 5c9
1 5cb 5d0 5d4 5d8 5db 5e0 5e4
5e8 5eb 5f0 5f1 5f3 5f8 5fb 5ff
600 605 60a 60d 612 613 618 61b
61f 620 625 628 62d 62e 633 636
63b 63c 641 644 648 64c 651 654
658 659 65e 661 666 667 66c 671
672 674 679 67a 67c 67d 682 685
68a 68b 690 693 697 69b 6a0 6a3
6a7 6a8 6ad 6b0 6b5 6b6 6bb 6c0
6c1 6c3 6c8 6c9 6cb 6cc 6d1 6d4
6d9 6da 6df 6e2 6e6 6ea 6ee 6ef
6f1 6f6 6f7 6f9 6fa 6ff 702 707
708 70d 710 715 716 71b 71e 722
723 728 72b 730 731 736 739 73e
73f 744 745 74a 74c 750 753 757
75b 75e 762 766 769 76c 771 774
777 77a 77b 780 781 1 783 788
78c 790 793 798 79d 7a0 7a4 7a5
7aa 7ab 7b0 7b2 7b6 7b9 7bd 7c2
7c6 7ca 7cf 7d3 7d7 7da 7de 7e2
7e6 7ea 7ee 7f2 7f6 7fa 7fe 802
806 80a 80e 812 816 819 81a 81c
81f 822 823 828 82b 82f 833 837
83a 83e 840 844 847 84b 84f 853
857 85b 85f 863 867 86b 86f 873
877 87b 87f 883 887 88b 88f 893
897 89b 89f 8a3 8a7 8ab 8af 8b3
8b7 8bb 8bf 8c3 8c7 8cb 8cf 8d3
8d7 8db 8df 8e3 8e7 8eb 8ef 8f3
8f7 8fb 8ff 903 907 90b 90f 913
917 91b 91f 923 92f 933 937 93a
93e 942 944 948 94c 950 953 957
95b 95d 95e 963 1 967 96b 96f
972 976 97a 97e 982 985 989 98d
990 993 998 99b 99e 9a1 9a2 9a7
9a8 1 9aa 9af 9b3 9b7 9ba 9bf
9c4 9c7 9cb 9cc 9d1 9d4 9d9 9da
9df 9e2 9e7 9e8 9ed 9f0 9f4 9f5
9fa 9fd a02 a03 a08 a0b a0f a13
a16 a19 a1a a1c a1d a22 a23 a28
a2a a2e a31 a33 a37 a39 a45 a47
a49 a4a a4f a53 a55 a61 a63 a67
a6b a6e a72 a75 a79 a7c a7d a82
a85 a89 a8d a90 a94 a98 a9b a9e
aa3 aa6 aa9 aac aad ab2 ab3 1
ab5 aba abe ac2 ac5 aca acf ad2
ad6 ad7 adc adf ae4 ae5 aea aed
af2 af3 af8 afb aff b03 b07 b0b
b0e b0f b11 b16 b17 b19 b1a b1f
b22 b27 b28 b2d b30 b35 b36 b3b
b3e b42 b43 b48 b4b b50 b51 b56
b57 b5c b5e b62 b65 b69 b6d b70
b74 b78 b7b b7e b83 b86 b89 b8c
b8d b92 b93 1 b95 b9a b9e ba2
ba5 baa baf bb2 bb6 bb7 bbc bbd
bc2 bc4 bc8 bcb bcf bd3 bd6 bda
bde be1 be5 be9 bea bef bf1 bf5
bf8 bfc c00 c04 c08 c0c c10 c14
c20 c24 c28 c2b c2f c33 c35 c39
c3d c41 c44 c48 c4c c4e c4f c54
1 c58 c5c c60 c63 c67 c6b c6f
c73 c76 c7a c7e c81 c84 c89 c8c
c8f c92 c93 c98 c99 1 c9b ca0
ca4 ca8 cab cb0 cb5 cb8 cbc cbd
cc2 cc5 cca ccb cd0 cd3 cd8 cd9
cde ce1 ce5 ce6 ceb cee cf3 cf4
cf9 cfc d00 d04 d07 d0a d0b d0d
d0e d13 d14 d19 d1b d1f d22 d24
d28 d2a d36 d38 d3a d3b d40 d44
d46 d52 d54 d58 d5c d5f d62 d63
d65 d68 d6d d6e d73 d77 d7b d7e
d82 d86 d89 d8c d91 d94 d97 d9a
d9b da0 da1 1 da3 da8 dac db0
db3 db8 dbd dc0 dc4 dc5 dca dcd
dd2 dd3 dd8 ddb de0 de1 de6 de9
ded df1 df5 df9 dfc dfd dff e04
e05 e07 e08 e0d e10 e15 e16 e1b
e1e e23 e24 e29 e2c e30 e31 e36
e39 e3e e3f e44 e45 e4a e4c e50
e53 e57 e5b e5e e62 e66 e69 e6c
e71 e74 e77 e7a e7b e80 e81 1
e83 e88 e8c e90 e93 e98 e9d ea0
ea4 ea5 eaa eab eb0 eb2 eb6 eb9
ebd ec1 ec4 ec8 ecc ecf ed3 ed7
ed8 edd edf ee3 ee6 eea eee ef1
ef2 ef4 ef7 efa efb f00 f04 f08
f0b f0f f13 f16 f19 f1e f21 f24
f27 f28 f2d f2e 1 f30 f35 f39
f3d f40 f45 f4a f4d f51 f52 f57
f5a f5f f60 f65 f68 f6d f6e f73
f76 f7a f7e f82 f86 f89 f8a f8c
f91 f92 f94 f95 f9a f9d fa2 fa3
fa8 fab fb0 fb1 fb6 fb9 fbd fbe
fc3 fc6 fcb fcc fd1 fd2 fd7 fd9
fdd fe0 fe4 fe8 feb fef ff3 ff6
ff9 ffe 1001 1004 1007 1008 100d 100e
1 1010 1015 1019 101d 1020 1025 102a
102d 1031 1032 1037 1038 103d 103f 1043
1046 104a 104e 1051 1055 1059 105c 1060
1064 1065 106a 106c 1070 1073 1077 107a
107b 1080 1083 1086 108a 108d 108e 1093
1096 1 1099 109e 10a2 10a6 10a9 10ad
10b1 10b4 10b5 10b7 10ba 10bd 10be 10c3
10c7 10cb 10ce 10d2 10d6 10d9 10dc 10e1
10e4 10e7 10ea 10eb 10f0 10f1 1 10f3
10f8 10fc 1100 1103 1108 110d 1110 1114
1115 111a 111d 1122 1123 1128 112b 1130
1131 1136 1139 113d 1141 1145 1149 114c
114d 114f 1154 1155 1157 1158 115d 1160
1165 1166 116b 116e 1173 1174 1179 117c
1180 1181 1186 1189 118e 118f 1194 1195
119a 119c 11a0 11a3 11a7 11ab 11ae 11b2
11b6 11b9 11bc 11c1 11c4 11c7 11ca 11cb
11d0 11d1 1 11d3 11d8 11dc 11e0 11e3
11e8 11ed 11f0 11f4 11f5 11fa 11fb 1200
1202 1206 1209 120d 1211 1214 1218 121c
121f 1223 1227 1228 122d 122f 1233 1236
1238 123c 123f 1243 1244 1248 124c 1250
1254 1258 125c 1260 1264 1268 126c 1270
1274 1278 127c 1280 1284 1290 1294 1298
129b 129f 12a3 12a5 12a9 12ad 12b1 12b4
12b8 12bc 12be 12bf 12c4 1 12c8 12cc
12d0 12d3 12d7 12db 12df 12e3 12e6 12ea
12ee 12f1 12f4 12f9 12fc 12ff 1302 1303
1308 1309 1 130b 1310 1314 1318 131b
1320 1325 1328 132c 132d 1332 1335 133a
133b 1340 1343 1348 1349 134e 1351 1355
1356 135b 135e 1363 1364 1369 136c 1370
1374 1377 137a 137b 137d 137e 1383 1384
1389 138b 138f 1392 1394 1398 139a 13a6
13a8 13aa 13ab 13b0 13b4 13b6 13c2 13c4
13c8 13cc 13d0 13d4 13d8 13db 13df 13e3
13e4 13e6 13e9 13ec 13ed 13f2 13f5 13f9
13fd 1400 1401 1403 1407 140a 140e 1411
1412 1417 1 141a 141f 1423 1428 142c
1430 1433 1437 143b 143f 1443 1446 144a
144e 1452 1456 145a 145e 1462 1465 1466
1468 146c 1470 1474 1477 147b 147f 1483
1488 148c 1490 1493 1497 149b 149f 14a3
14a6 14aa 14ae 14b2 14b6 14ba 14be 14c2
14c5 14c6 14c8 14cc 14d0 14d4 14d7 14db
14df 14e1 14e5 14e8 14ec 14ef 14f0 14f5
14f8 14fb 14ff 1503 1506 150a 150e 1511
1512 1514 1517 151a 151b 1520 1 1523
1528 152c 1530 1534 1536 153a 153d 1541
1544 1545 154a 154d 1550 1554 1557 1558
155d 1560 1 1563 1568 156c 1570 1574
1578 157c 1580 1584 1588 1594 1598 159d
15a1 15a4 15a5 15aa 15ae 15b2 15b5 15b8
15bc 15be 15c2 15c6 15c9 15cc 15d0 15d2
15d6 15da 15dd 15df 15e3 15e7 15eb 15ee
15f2 15f6 15f8 15f9 15fe 1 1602 1606
160a 160d 1611 1615 1619 161d 1620 1624
1628 162b 162e 1633 1636 1639 163c 163d
1642 1643 1 1645 164a 164e 1652 1655
165a 165f 1662 1666 1667 166c 166f 1674
1675 167a 167d 1682 1683 1688 168b 168f
1690 1695 1698 169d 169e 16a3 16a6 16aa
16ae 16b1 16b4 16b5 16b7 16b8 16bd 16be
16c3 16c5 16c9 16cc 16ce 16d2 16d4 16e0
16e2 16e4 16e5 16ea 16ee 16f0 16fc 16fe
1700 1704 1707 1708 170d 1710 1714 1717
1718 171d 1 1720 1725 1729 172d 1731
1735 1739 173d 1749 174d 1752 1756 1759
175a 175f 1763 1767 176a 176d 1771 1773
1777 177b 177e 1781 1785 1787 178b 178f
1792 1794 1798 179c 17a0 17a3 17a7 17ab
17ad 17ae 17b3 1 17b7 17bb 17bf 17c2
17c6 17ca 17ce 17d2 17d5 17d9 17dd 17e0
17e3 17e8 17eb 17ee 17f1 17f2 17f7 17f8
1 17fa 17ff 1803 1807 180a 180f 1814
1817 181b 181c 1821 1824 1829 182a 182f
1832 1837 1838 183d 1840 1844 1845 184a
184d 1852 1853 1858 185b 185f 1863 1866
1869 186a 186c 186d 1872 1873 1878 187a
187e 1881 1883 1887 1889 1895 1897 1899
189a 189f 18a3 18a5 18b1 18b3 18b7 18bb
18be 18c2 18c6 18c9 18ca 18cc 18cf 18d2
18d3 18d8 18dc 18df 18e3 18e5 18e9 18ec
18ee 18f2 18f5 18f9 18fc 18fd 1902 1905
1909 190c 190d 1912 1 1915 191a 191e
1922 1926 192a 192e 1932 193e 1942 1947
194b 194e 194f 1954 1958 195c 195f 1962
1966 1968 196c 1970 1973 1976 197a 197c
1980 1984 1987 1989 198d 1991 1995 1998
199c 19a0 19a2 19a3 19a8 1 19ac 19b0
19b4 19b7 19bb 19bf 19c3 19c7 19ca 19ce
19d2 19d5 19d8 19dd 19e0 19e3 19e6 19e7
19ec 19ed 1 19ef 19f4 19f8 19fc 19ff
1a04 1a09 1a0c 1a10 1a11 1a16 1a19 1a1e
1a1f 1a24 1a27 1a2c 1a2d 1a32 1a35 1a39
1a3a 1a3f 1a42 1a47 1a48 1a4d 1a50 1a54
1a58 1a5b 1a5e 1a5f 1a61 1a62 1a67 1a68
1a6d 1a6f 1a73 1a76 1a78 1a7c 1a7e 1a8a
1a8c 1a8e 1a8f 1a94 1a98 1a9a 1aa6 1aa8
1aac 1ab0 1ab3 1ab7 1abb 1abe 1abf 1ac1
1ac4 1ac7 1ac8 1acd 1ad1 1ad4 1ad8 1ada
1ade 1ae1 1ae3 1ae7 1aea 1aee 1af2 1af5
1af6 1af8 1afb 1afe 1aff 1b04 1b08 1b0b
1b0c 1b11 1b14 1b17 1b1b 1b1f 1b22 1b26
1b2a 1b2d 1b2e 1b30 1b33 1b36 1b37 1b3c
1 1b3f 1b44 1b48 1b4c 1b50 1b52 1b56
1b59 1b5d 1b60 1b61 1b66 1b69 1b6c 1b70
1b73 1b74 1b79 1b7c 1 1b7f 1b84 1b88
1b8c 1b8f 1b93 1b97 1b98 1b9a 1b9d 1ba0
1ba1 1ba6 1 1ba9 1bae 1bb2 1bb6 1bb9
1bbd 1bc1 1bc4 1bc7 1bcc 1bcf 1bd2 1bd5
1bd6 1bdb 1bdc 1 1bde 1be3 1be7 1beb
1bee 1bf3 1bf8 1bfb 1bff 1c00 1c05 1c08
1c0d 1c0e 1c13 1c16 1c1b 1c1c 1c21 1c24
1c28 1c2c 1c30 1c34 1c37 1c38 1c3a 1c3f
1c40 1c42 1c43 1c48 1c4b 1c50 1c51 1c56
1c59 1c5e 1c5f 1c64 1c67 1c6b 1c6c 1c71
1c74 1c79 1c7a 1c7f 1c80 1c85 1c87 1c8b
1c8e 1c92 1c96 1c99 1c9d 1ca1 1ca4 1ca7
1cac 1caf 1cb2 1cb5 1cb6 1cbb 1cbc 1
1cbe 1cc3 1cc7 1ccb 1cce 1cd3 1cd8 1cdb
1cdf 1ce0 1ce5 1ce6 1ceb 1ced 1cf1 1cf4
1cf8 1cfc 1cff 1d03 1d07 1d0a 1d0e 1d12
1d13 1d18 1d1a 1d1e 1d21 1d25 1d28 1d29
1d2e 1d31 1d35 1d38 1d39 1d3e 1d41 1d45
1d49 1d4c 1d50 1d54 1d57 1d5a 1d5f 1d62
1d65 1d68 1d69 1d6e 1d6f 1 1d71 1d76
1d7a 1d7e 1d81 1d86 1d8b 1d8e 1d92 1d93
1d98 1d9b 1da0 1da1 1da6 1da9 1dae 1daf
1db4 1db7 1dbb 1dbf 1dc3 1dc7 1dca 1dcb
1dcd 1dd2 1dd3 1dd5 1dd6 1ddb 1dde 1de3
1de4 1de9 1dec 1df1 1df2 1df7 1dfa 1dfe
1dff 1e04 1e07 1e0c 1e0d 1e12 1e13 1e18
1e1a 1e1e 1e21 1e25 1e29 1e2c 1e30 1e34
1e37 1e3a 1e3f 1e42 1e45 1e48 1e49 1e4e
1e4f 1 1e51 1e56 1e5a 1e5e 1e61 1e66
1e6b 1e6e 1e72 1e73 1e78 1e79 1e7e 1e80
1e84 1e87 1e8b 1e8f 1e92 1e96 1e9a 1e9d
1ea1 1ea5 1ea6 1eab 1ead 1eb1 1eb4 1eb8
1ebc 1ec0 1ec4 1ec8 1ecb 1ecf 1ed3 1ed6
1ed7 1ed9 1edc 1edf 1ee0 1ee5 1ee9 1eea
1eee 1ef2 1ef4 1ef8 1efc 1eff 1f03 1f07
1f0a 1f0b 1f0d 1f10 1f13 1f14 1f19 1f1d
1f21 1f25 1f29 1f2d 1f31 1f35 1f39 1f3d
1f41 1f45 1f49 1f4d 1f51 1f55 1f59 1f65
1f69 1f6d 1f70 1f74 1f78 1f7a 1f7e 1f82
1f86 1f89 1f8d 1f91 1f93 1f94 1f99 1
1f9d 1fa1 1fa5 1fa8 1fac 1fb0 1fb4 1fb8
1fbb 1fbf 1fc3 1fc6 1fc9 1fce 1fd1 1fd4
1fd7 1fd8 1fdd 1fde 1 1fe0 1fe5 1fe9
1fed 1ff0 1ff5 1ffa 1ffd 2001 2002 2007
200a 200f 2010 2015 2018 201d 201e 2023
2026 202a 202b 2030 2033 2038 2039 203e
2041 2045 2049 204c 204f 2050 2052 2053
2058 2059 205e 2060 2064 2067 2069 206d
206f 207b 207d 207f 2080 2085 2089 208b
2097 2099 209d 20a1 20a4 20a8 20ab 20af
20b2 20b3 20b8 20bb 20bf 20c3 20c7 20cb
20cf 20d3 20d7 20db 20df 20eb 20ef 20f3
20f6 20fa 20fe 2100 2104 2108 210c 210f
2113 2117 2119 211a 211f 1 2123 2127
212b 212e 2132 2136 213a 213e 2141 2145
2149 214c 214f 2154 2157 215a 215d 215e
2163 2164 1 2166 216b 216f 2173 2176
217b 2180 2183 2187 2188 218d 2190 2195
2196 219b 219e 21a3 21a4 21a9 21ac 21b0
21b1 21b6 21b9 21be 21bf 21c4 21c7 21cb
21cf 21d2 21d5 21d6 21d8 21d9 21de 21df
21e4 21e6 21ea 21ed 21ef 21f3 21f5 2201
2203 2205 2206 220b 220f 2211 221d 221f
2221 2225 2228 222c 222e 2232 2236 2239
223a 223f 2242 2246 224a 224d 2251 2255
2258 225b 2260 2263 2266 2269 226a 226f
2270 1 2272 2277 227b 227f 2282 2287
228c 228f 2293 2294 2299 229c 22a1 22a2
22a7 22aa 22af 22b0 22b5 22b8 22bc 22c0
22c3 22c4 22c6 22cb 22cc 22ce 22cf 22d4
22d7 22dc 22dd 22e2 22e5 22ea 22eb 22f0
22f3 22f7 22f8 22fd 2300 2305 2306 230b
230c 2311 2313 2317 231a 231e 2322 2325
2329 232d 2330 2333 2338 233b 233e 2341
2342 2347 2348 1 234a 234f 2353 2357
235a 235f 2364 2367 236b 236c 2371 2372
2377 2379 237d 2380 2384 2388 238b 238e
2392 2396 2397 239c 239e 23a2 23a6 23a9
23ab 23af 23b2 23b6 23ba 23bb 23bf 23c1
23c5 23c9 23cc 23d0 23d3 23d4 23d9 23dc
23e0 23e3 23e4 23e9 23ec 23ef 23f3 23f7
23fa 23fe 2402 2405 2406 2408 240b 240e
240f 2414 1 2417 241c 2420 2424 2427
242b 242f 2432 2435 243a 243d 2440 2443
2444 2449 244a 1 244c 2451 2455 2459
245c 2461 2466 2469 246d 246e 2473 2476
247b 247c 2481 2484 2489 248a 248f 2492
2496 249a 249e 24a2 24a5 24a6 24a8 24ad
24ae 24b0 24b1 24b6 24b9 24be 24bf 24c4
24c7 24cc 24cd 24d2 24d5 24d9 24da 24df
24e2 24e7 24e8 24ed 24ee 24f3 24f5 24f9
24fc 2500 2504 2507 250b 250f 2512 2515
251a 251d 2520 2523 2524 2529 252a 1
252c 2531 2535 2539 253c 2541 2546 2549
254d 254e 2553 2554 2559 255b 255f 2562
2566 256a 256d 2571 2575 2578 257c 2580
2581 2586 258a 258c 2590 2593 2594 2599
259c 259f 25a3 25a7 25aa 25ae 25b2 25b5
25b6 25b8 25bb 25be 25bf 25c4 1 25c7
25cc 25d0 25d4 25d7 25db 25df 25e2 25e5
25ea 25ed 25f0 25f3 25f4 25f9 25fa 1
25fc 2601 2605 2609 260c 2611 2616 2619
261d 261e 2623 2626 262b 262c 2631 2634
2639 263a 263f 2642 2646 264a 264e 2652
2655 2656 2658 265d 265e 2660 2661 2666
2667 266c 266e 2672 2675 2679 267d 2680
2684 2688 268b 268e 2693 2696 2699 269c
269d 26a2 26a3 1 26a5 26aa 26ae 26b2
26b5 26ba 26bf 26c2 26c6 26c7 26cc 26cd
26d2 26d4 26d8 26db 26df 26e3 26e6 26ea
26ee 26f1 26f5 26f6 26fb 26fd 2701 2705
2708 270c 270f 2710 2715 2718 271b 271f
2723 2726 272a 272e 2731 2732 2734 2737
273a 273b 2740 1 2743 2748 274c 274f
2753 2755 2759 275c 2760 2762 2766 276a
276d 2771 2775 2778 277c 2780 2783 2784
2786 2789 278c 278d 2792 2796 2797 279b
279f 27a1 27a5 27a9 27ac 27b0 27b4 27b5
27b7 27ba 27bd 27be 27c3 27c7 27cb 27cf
27d3 27d7 27db 27df 27e3 27e7 27eb 27ef
27f3 27f7 27fb 27ff 2803 280f 2813 2817
281a 281e 2822 2824 2828 282c 2830 2833
2837 283b 283d 283e 2843 1 2847 284b
284f 2852 2856 285a 285e 2862 2865 2869
286d 2870 2873 2878 287b 287e 2881 2882
2887 2888 1 288a 288f 2893 2897 289a
289f 28a4 28a7 28ab 28ac 28b1 28b4 28b9
28ba 28bf 28c2 28c7 28c8 28cd 28d0 28d4
28d5 28da 28dd 28e2 28e3 28e8 28eb 28ef
28f3 28f6 28f9 28fa 28fc 28fd 2902 2903
2908 290a 290e 2911 2913 2917 2919 2925
2927 2929 292a 292f 2933 2935 2941 2943
2947 294b 294e 2952 2955 2959 295c 295d
2962 2965 2969 296d 2971 2975 2979 297d
2981 2985 2989 2995 2999 299d 29a0 29a4
29a8 29aa 29ae 29b2 29b6 29b9 29bd 29c1
29c3 29c4 29c9 1 29cd 29d1 29d5 29d8
29dc 29e0 29e4 29e8 29eb 29ef 29f3 29f6
29f9 29fe 2a01 2a04 2a07 2a08 2a0d 2a0e
1 2a10 2a15 2a19 2a1d 2a20 2a25 2a2a
2a2d 2a31 2a32 2a37 2a3a 2a3f 2a40 2a45
2a48 2a4d 2a4e 2a53 2a56 2a5a 2a5b 2a60
2a63 2a68 2a69 2a6e 2a71 2a75 2a79 2a7c
2a7f 2a80 2a82 2a83 2a88 2a89 2a8e 2a90
2a94 2a97 2a99 2a9d 2a9f 2aab 2aad 2aaf
2ab0 2ab5 2ab9 2abb 2ac7 2ac9 2acb 2acf
2ad2 2ad6 2ad8 2adc 2ae0 2ae4 2ae7 2aeb
2aef 2af2 2af3 2af5 2af8 2afb 2afc 2b01
2b05 2b09 2b0c 2b10 2b14 2b17 2b1a 2b1f
2b22 2b25 2b28 2b29 2b2e 2b2f 1 2b31
2b36 2b3a 2b3e 2b41 2b46 2b4b 2b4e 2b52
2b53 2b58 2b5b 2b60 2b61 2b66 2b69 2b6e
2b6f 2b74 2b77 2b7b 2b7f 2b82 2b83 2b85
2b8a 2b8b 2b8d 2b8e 2b93 2b96 2b9b 2b9c
2ba1 2ba4 2ba9 2baa 2baf 2bb2 2bb6 2bb7
2bbc 2bbf 2bc4 2bc5 2bca 2bcb 2bd0 2bd2
2bd6 2bd9 2bdd 2be1 2be4 2be8 2bec 2bef
2bf2 2bf7 2bfa 2bfd 2c00 2c01 2c06 2c07
1 2c09 2c0e 2c12 2c16 2c19 2c1e 2c23
2c26 2c2a 2c2b 2c30 2c31 2c36 2c38 2c3c
2c3f 2c43 2c47 2c4a 2c4d 2c51 2c55 2c56
2c5b 2c5d 2c61 2c65 2c68 2c6a 2c6e 2c6f
2c73 2c75 2c79 2c7d 2c80 2c84 2c88 2c8c
2c90 2c93 2c97 2c9b 2c9f 2ca2 2ca3 2ca5
2ca9 2cac 2cb0 2cb3 2cb4 2cb9 2cbd 2cc1
2cc5 2cc9 2ccd 2cd1 2cd5 2cd9 2ce5 2ce9
2cee 2cf2 2cf5 2cf6 2cfb 2cff 2d03 2d06
2d09 2d0d 2d0f 2d13 2d17 2d1a 2d1d 2d21
2d23 2d27 2d2b 2d2e 2d30 2d34 2d38 2d3c
2d3f 2d43 2d47 2d49 2d4a 2d4f 1 2d53
2d57 2d5b 2d5e 2d62 2d66 2d6a 2d6e 2d71
2d75 2d79 2d7c 2d7f 2d84 2d87 2d8a 2d8d
2d8e 2d93 2d94 1 2d96 2d9b 2d9f 2da3
2da6 2dab 2db0 2db3 2db7 2db8 2dbd 2dc0
2dc5 2dc6 2dcb 2dce 2dd3 2dd4 2dd9 2ddc
2de0 2de1 2de6 2de9 2dee 2def 2df4 2df7
2dfb 2dff 2e02 2e05 2e06 2e08 2e09 2e0e
2e0f 2e14 2e16 2e1a 2e1d 2e1f 2e23 2e25
2e31 2e33 2e35 2e36 2e3b 2e3f 2e41 2e4d
2e4f 2e51 2e55 2e58 2e59 2e5e 2e61 2e65
2e68 2e69 2e6e 2e71 2e75 2e78 2e7c 2e80
2e84 2e88 2e8c 2e90 2e94 2e98 2e9c 2ea0
2ea4 2ea8 2eac 2eb0 2eb4 2eb8 2ec4 2ec8
2ecc 2ecf 2ed3 2ed7 2ed9 2edd 2ee1 2ee5
2ee8 2eec 2ef0 2ef2 2ef3 2ef8 1 2efc
2f00 2f04 2f07 2f0b 2f0f 2f13 2f17 2f1a
2f1e 2f22 2f25 2f28 2f2d 2f30 2f33 2f36
2f37 2f3c 2f3d 1 2f3f 2f44 2f48 2f4c
2f4f 2f54 2f59 2f5c 2f60 2f61 2f66 2f69
2f6e 2f6f 2f74 2f77 2f7c 2f7d 2f82 2f85
2f89 2f8a 2f8f 2f92 2f97 2f98 2f9d 2fa0
2fa4 2fa8 2fab 2fae 2faf 2fb1 2fb2 2fb7
2fb8 2fbd 2fbf 2fc3 2fc6 2fc8 2fcc 2fce
2fda 2fdc 2fde 2fdf 2fe4 2fe8 2fea 2ff6
2ff8 2ffc 3000 3003 3004 3006 3009 300c
300d 3012 3016 301a 301d 3021 3025 3028
302b 3030 3033 3036 3039 303a 303f 3040
1 3042 3047 304b 304f 3052 3057 305c
305f 3063 3064 3069 306c 3071 3072 3077
307a 307f 3080 3085 3088 308c 3090 3094
3098 309b 309c 309e 30a3 30a4 30a6 30a7
30ac 30af 30b4 30b5 30ba 30bd 30c2 30c3
30c8 30cb 30cf 30d0 30d5 30d8 30dd 30de
30e3 30e4 30e9 30eb 30ef 30f2 30f6 30fa
30fd 3101 3105 3108 310b 3110 3113 3116
3119 311a 311f 3120 1 3122 3127 312b
312f 3132 3137 313c 313f 3143 3144 3149
314a 314f 3151 3155 3158 315c 3160 3163
3167 316b 316e 3172 3176 3177 317c 317e
3182 3185 3189 318b 318f 3192 3193 3198
319b 319f 31a2 31a6 31aa 31ae 31b2 31b6
31ba 31be 31c2 31c6 31ca 31ce 31d2 31d6
31da 31de 31e2 31ee 31f2 31f6 31f9 31fd
3201 3203 3207 320b 320f 3212 3216 321a
321c 321d 3222 1 3226 322a 322e 3231
3235 3239 323d 3241 3244 3248 324c 324f
3252 3257 325a 325d 3260 3261 3266 3267
1 3269 326e 3272 3276 3279 327e 3283
3286 328a 328b 3290 3293 3298 3299 329e
32a1 32a6 32a7 32ac 32af 32b3 32b4 32b9
32bc 32c1 32c2 32c7 32ca 32ce 32d2 32d5
32d8 32d9 32db 32dc 32e1 32e2 32e7 32e9
32ed 32f0 32f2 32f6 32f8 3304 3306 3308
3309 330e 3312 3314 3320 3322 3326 332a
332d 332e 3330 3333 3336 3337 333c 3340
3344 3347 334b 334f 3352 3355 335a 335d
3360 3363 3364 3369 336a 1 336c 3371
3375 3379 337c 3381 3386 3389 338d 338e
3393 3396 339b 339c 33a1 33a4 33a9 33aa
33af 33b2 33b6 33ba 33be 33c2 33c5 33c6
33c8 33cd 33ce 33d0 33d1 33d6 33d9 33de
33df 33e4 33e7 33ec 33ed 33f2 33f5 33f9
33fa 33ff 3402 3407 3408 340d 340e 3413
3415 3419 341c 3420 3424 3427 342b 342f
3432 3435 343a 343d 3440 3443 3444 3449
344a 1 344c 3451 3455 3459 345c 3461
3466 3469 346d 346e 3473 3474 3479 347b
347f 3482 3486 348a 348d 3491 3495 3498
349c 34a0 34a1 34a6 34a8 34ac 34b0 34b4
34b8 34bc 34c0 34c4 34c8 34cc 34d0 34d4
34d8 34e4 34e8 34ec 34ef 34f3 34f7 34f9
34fd 3501 3505 3508 350c 3510 3512 3513
3518 1 351c 3520 3524 3527 352b 352f
3533 3537 353a 353e 3542 3545 3548 354d
3550 3553 3556 3557 355c 355d 1 355f
3564 3568 356c 356f 3574 3579 357c 3580
3581 3586 3589 358e 358f 3594 3597 359c
359d 35a2 35a5 35a9 35aa 35af 35b2 35b7
35b8 35bd 35c0 35c4 35c8 35cb 35ce 35cf
35d1 35d2 35d7 35d8 35dd 35df 35e3 35e6
35e8 35ec 35ee 35fa 35fc 35fe 35ff 3604
3608 360a 3616 3618 361c 3620 3623 3624
3626 362a 362d 3631 3634 3635 3637 3638
363d 3641 3645 3648 364c 3650 3653 3656
365b 365e 3661 3664 3665 366a 366b 1
366d 3672 3676 367a 367d 3682 3687 368a
368e 368f 3694 3697 369c 369d 36a2 36a5
36aa 36ab 36b0 36b3 36b7 36bb 36bf 36c3
36c6 36c7 36c9 36ce 36cf 36d1 36d2 36d7
36da 36df 36e0 36e5 36e8 36ed 36ee 36f3
36f6 36fa 36fb 3700 3703 3708 3709 370e
370f 3714 3716 371a 371d 3721 3725 3728
372c 3730 3733 3736 373b 373e 3741 3744
3745 374a 374b 1 374d 3752 3756 375a
375d 3762 3767 376a 376e 376f 3774 3775
377a 377c 3780 3783 3787 378b 378e 3792
3796 3799 379d 37a1 37a2 37a7 37a9 37ad
37b0 37b2 37b6 37ba 37bd 37bf 37c3 37c7
37cb 37ce 37d2 37d6 37d9 37dc 37e1 37e4
37e7 37ea 37eb 37f0 37f1 1 37f3 37f8
37fc 3800 3803 3808 380d 3810 3814 3815
381a 381d 3822 3823 3828 382b 3830 3831
3836 3839 383d 3841 3845 3849 384c 384d
384f 3854 3855 3857 3858 385d 3860 3865
3866 386b 386e 3873 3874 3879 387c 3880
3881 3886 3889 388e 388f 3894 3895 389a
389c 38a0 38a3 38a7 38ab 38ae 38b2 38b6
38b9 38bc 38c1 38c4 38c7 38ca 38cb 38d0
38d1 1 38d3 38d8 38dc 38e0 38e3 38e8
38ed 38f0 38f4 38f5 38fa 38fb 3900 3902
3906 3909 390d 3911 3914 3918 391c 391f
3923 3927 3928 392d 392f 3933 3937 393a
393c 3940 3943 3947 394a 394e 3952 3956
395a 395e 3961 3962 3967 396a 396e 3971
3972 3977 397a 1 397d 3982 3986 398a
398e 3990 3994 3997 399b 399f 39a3 39a7
39ab 39af 39b3 39b7 39bb 39bf 39c3 39c7
39cb 39cf 39d3 39d7 39db 39df 39e3 39e7
39eb 39ef 39f3 39f7 39fa 39fb 39fd 3a01
3a05 3a08 3a0c 3a10 3a14 3a18 3a1c 3a20
3a23 3a26 3a27 3a29 3a2d 3a31 3a34 3a35
3a3a 3a3d 3a41 3a44 3a48 3a4c 3a50 3a54
3a58 3a5c 3a5f 3a62 3a63 3a65 3a69 3a6b
3a6f 3a72 3a74 3a78 3a7c 3a7f 3a81 3a85
3a88 3a8a 3a8e 3a92 3a95 3a99 3a9d 3aa0
3aa4 3aa8 3aa9 3aab 3aae 3ab1 3ab2 3ab7
3aba 3abe 3ac2 3ac5 3ac6 3ac8 3acc 3acf
3ad3 3ad6 3ad7 3adc 1 3adf 3ae4 3ae8
3aed 3af1 3af5 3af8 3afc 3b00 3b04 3b08
3b0b 3b0f 3b13 3b17 3b1b 3b1f 3b23 3b27
3b2a 3b2b 3b2d 3b31 3b35 3b39 3b3c 3b40
3b44 3b48 3b4d 3b51 3b55 3b58 3b5c 3b60
3b64 3b68 3b6b 3b6f 3b73 3b77 3b7b 3b7f
3b83 3b87 3b8a 3b8b 3b8d 3b91 3b95 3b99
3b9c 3ba0 3ba4 3ba6 3baa 3bad 3bb1 3bb5
3bb9 3bba 3bbc 3bc0 3bc4 3bc8 3bcb 3bcf
3bd3 3bd6 3bd9 3bde 3be1 3be4 3be7 3be8
3bed 3bee 1 3bf0 3bf5 3bf9 3bfd 3c00
3c05 3c0a 3c0d 3c11 3c12 3c17 3c1a 3c1f
3c20 3c25 3c28 3c2d 3c2e 3c33 3c36 3c3a
3c3e 3c42 3c46 3c49 3c4a 3c4c 3c51 3c52
3c54 3c55 3c5a 3c5d 3c62 3c63 3c68 3c6b
3c70 3c71 3c76 3c79 3c7d 3c7e 3c83 3c86
3c8b 3c8c 3c91 3c92 3c97 3c99 3c9d 3ca0
3ca4 3ca8 3cab 3caf 3cb3 3cb6 3cba 3cbe
3cbf 3cc4 3cc6 3cca 3cce 3cd1 3cd5 3cd9
3cdc 3ce0 3ce4 3ce7 3cea 3cef 3cf2 3cf5
3cf8 3cf9 3cfe 3cff 1 3d01 3d06 3d0a
3d0e 3d11 3d16 3d1b 3d1e 3d22 3d23 3d28
3d29 3d2e 3d32 3d36 3d39 3d3e 3d43 3d46
3d4a 3d4e 3d51 3d52 3d57 3d5a 3d5f 3d60
3d65 3d68 3d6c 3d70 3d73 3d74 3d79 3d7a
3d7f 3d81 3d85 3d88 3d8c 3d90 3d94 3d98
3d9c 3da0 3da4 3da8 3dac 3db8 3dbd 3dc1
3dc5 3dc9 3dcd 3dcf 3dd0 3dd5 1 3dd9
3ddd 3de1 3de4 3de8 3dec 3df0 3df4 3df7
3dfb 3dff 3e02 3e05 3e0a 3e0d 3e10 3e13
3e14 3e19 3e1a 1 3e1c 3e21 3e25 3e29
3e2c 3e31 3e36 3e39 3e3d 3e3e 3e43 3e44
3e49 3e4d 3e51 3e54 3e59 3e5e 3e61 3e65
3e66 3e6b 3e6e 3e73 3e74 3e79 3e7c 3e80
3e84 3e87 3e8a 3e8b 3e8d 3e8e 3e93 3e94
3e99 3e9b 3e9f 3ea2 3ea6 3eaa 3eae 3eb2
3eb6 3eba 3ebe 3eca 3ecf 3ed3 3ed7 3edb
3edf 3ee1 3ee5 3ee7 3ef3 3ef5 3ef7 3ef8
3efd 3f01 3f03 3f0f 3f13 3f15 3f16 3f1f 
1218
2
0 1 a 6 9 :3 6 14 :3 6
15 :3 6 16 :3 6 12 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 d 16 15 :2 d :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f :2 4
:3 10 :2 4 :3 15 :2 4 :3 16 :2 4 :3 13 :2 4
b 14 13 :2 b :2 4 :2 13 22 13
:2 4 :2 b 1a b :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :3 12 :2 4 :3 13
:2 4 :3 15 :2 4 :3 19 :2 4 :3 10 :2 4 :3 e
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 16 25 16 :2 4 :2 a 19
a :2 4 :2 c 1b c :2 4 :2 11 20
11 :2 4 :2 f 1e f :2 4 :2 d 1c
d :2 4 :2 e 1d e :2 4 :2 e 1d
e :2 4 :2 16 25 16 :2 4 :2 10 1f
10 :2 4 :2 9 18 9 :2 4 :2 f 1e
f :2 4 :2 14 23 14 :2 4 :2 11 20
11 :2 4 f 18 17 :2 f :2 4 :3 10
:2 4 :2 16 2e 16 :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 58 5e
61 :2 58 6f 89 8 :2 6f d 10
:2 6f 13 16 :2 6f b e :2 6f 13
16 1f 26 2b 2e :2 26 3c 3f
:2 26 44 :2 1f 4d :2 16 :2 6f b e
:2 6f 13 16 1f 26 2b 2e :2 26
3d 40 :2 26 45 :2 1f 4e :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
39 :2 16 :2 6f b e :2 6f 13 16
:2 6f 1b 1e :2 6f 2a 2d :2 6f 32
35 :2 6f :2 7 4e :2 4 7 :2 11 23
:2 2d 39 3c 50 52 53 :2 50 :2 23
:3 7 :2 d 12 1e 61 64 :2 1e :2 7
56 :3 4 14 :2 4 15 :2 4 12 :2 4
14 :2 4 15 :2 4 1b :2 4 19 4
8 11 24 :2 8 27 29 :2 27 :2 7
1c :2 25 7 2c :2 4 e 1a 2d
44 52 65 7 10 1f 2d 36
46 55 65 76 7f 8c 99 a8
b5 c3 7 12 22 34 47 51
62 70 c 1a 2f 44 54 64
7 13 20 32 45 50 5a 67
74 7 12 24 33 43 4f 62
6e c d 21 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8e 91 :2 24
99 9c :2 24 a8 ab b2 bb be
:2 ab :2 24 :2 d 5e :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 54
57 58 :2 54 :2 26 :3 a :2 10 15 21
65 68 :2 21 75 78 :2 21 7c 7f
:2 21 89 8c 95 9d :2 a6 :2 95 b9
:2 8c :2 21 c1 c4 :2 21 cc cf :2 21
d4 d7 :2 21 da dd :2 21 :2 a 5b
:2 7 a :2 14 26 :2 30 3c 3f 53
56 57 :2 53 :2 26 :3 a :2 10 15 21
65 68 :2 21 :2 a 5a :3 7 :2 12 26
:2 2f 41 45 :2 7 35 :2 4 e :2 c
d 1a b 18 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8e 91 :2 24
99 9c :2 24 a8 ab b2 bb be
:2 ab :2 24 :2 d 5e :2 a :2 7 :4 13 :2 7
4 :3 1 7 e 1c 1f :2 7 22
24 :2 22 a :2 14 26 :2 30 3c 40
54 57 58 :2 54 :2 26 :3 a :2 10 15
21 65 68 :2 21 75 78 :2 21 7c
7f :2 21 89 8c 95 9d :2 a6 :2 95
c4 :2 8c :2 21 cc cf :2 21 d7 da
:2 21 df e2 :2 21 e5 e8 :2 21 :2 a
5b :2 7 a :2 14 26 :2 30 3c 3f
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 65 68 :2 21 :2 a 5a :3 7 :2 12
26 :2 2f 4c 50 :2 7 28 :2 4 7
10 20 :2 7 23 25 :2 23 a :2 14
26 :2 30 3c 40 54 57 58 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 c2 :2 8c :2 21 ca
cd :2 21 d5 d8 :2 21 dd e0 :2 21
e3 e6 :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 53 56 57 :2 53
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 4a 4e
:2 7 2b :2 4 :4 9 8 7 :4 2b 2a
29 :2 7 a :2 15 1d 2c 3a :2 a
3e 40 :2 3e d :2 17 29 :2 33 3f
43 57 5a 5b :2 57 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8c 8f 98 a0 :2 a9
:2 98 c6 :2 8f :2 24 ce d1 :2 24 d9
dc :2 24 e1 e4 :2 24 e7 ea :2 24
:2 d 5e :2 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
:2 15 29 :2 32 4e 52 :2 a 42 :2 7
48 :3 4 11 4 e 12 29 38
d 1a 2b 39 b 1d 26 3f
48 61 6a :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 57 5a 5b :2 57 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8e 91 :2 24 99
9c :2 24 a8 ab b2 bb be :2 ab
:2 24 :2 d 5e :2 a :2 7 :4 13 :2 7 4
:3 1 4 12 4 8 :2 13 1a 24
:2 8 30 32 :2 30 7 3a a 1d
:2 3a 23 20 :2 2c :2 20 39 :3 7 15
:2 7 17 :2 7 1c :2 25 :2 7 16 25
31 46 52 60 :2 16 :2 7 :2 10 1c
:2 7 15 :2 7 17 :2 7 1c :2 25 :2 7
16 25 31 46 52 60 :2 16 :2 7
:2 10 1c 7 47 :2 4 :4 9 8 7
29 :2 34 3c 4a 56 :2 29 5a 5c
:2 5a 28 :3 7 17 7 5f :2 4 :4 9
8 7 :4 27 26 25 :2 7 11 a
1c a 1c a 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5a 5d 5e :2 5a :2 2c :3 10 :2 16 1b
27 6b 6e :2 27 7b 7e :2 27 82
85 :2 27 91 94 :2 27 9c 9f :2 27
ab ae b5 be c1 :2 ae :2 27 :2 10
61 :2 d :2 a :4 16 :2 a 7 :4 40 :4 b
a :4 27 26 :2 a 14 d 1f d
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 94 97
:2 2a 9f a2 :2 2a ae b1 b8 c1
c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d :4 19
:2 d a :3 45 d :2 18 20 2f 42
:2 d 46 48 :2 46 d 1b d 4a
:2 a 45 :2 7 :4 b a :4 28 27 :2 a
14 d 1f d 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 94 97 :2 2a 9f a2 :2 2a
ae b1 b8 c1 c4 :2 b1 :2 2a :2 13
64 :2 10 :2 d :4 19 :2 d a :3 47 d
:2 18 20 2e 40 :2 d 44 46 :2 44
d 1b d 48 :2 a 47 :2 7 a
13 1f :2 a 22 24 :2 22 :4 f e
d 30 :2 3b 43 52 5f :2 30 63
65 :2 63 2f :3 d 1e d 68 :2 a
:4 f e d :4 2d 2c 2b :2 d 4e
:2 59 60 12 :2 4e 21 23 :2 21 4d
:2 d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 8f 92 9b a3 :2 ac :2 9b c7
:2 92 :2 27 cf d2 :2 27 da dd :2 27
e2 e5 :2 27 ee f1 :2 27 :2 10 61
:2 d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d :2 18 2c
:2 35 4f 59 :2 d 26 :2 a :4 e d
:4 11 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 af :2 9e
ca :2 95 :2 2a d2 d5 :2 2a dd e0
:2 2a e5 e8 :2 2a eb ee :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f :2 38 52 56 :2 10 2d :3 d 19
d 10 :2 1b 23 31 40 :2 10 44
46 :2 44 10 20 10 d 48 13
:2 1e 26 34 40 :2 13 44 47 :2 44
1a 25 32 3c 47 4c 55 66
78 18 19 26 17 22 2a 31
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 49 14 :2 1d
28 26 :2 31 :2 26 13 1f 2a 37
3f 46 5e 69 80 92 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :4 41 :2 10 d 49 48
:4 14 :2 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 92 95 9e a6 :2 9e aa :2 95
:2 2a b2 b5 :2 2a bd c0 :2 2a c5
c8 :2 2a cb ce :2 2a :2 13 64 :2 10
13 :2 1d 2f :2 39 45 48 5c 5f
60 :2 5c :2 2f :3 13 :2 19 1e 2a 6e
71 :2 2a :2 13 63 :3 10 :2 1b 2f 32
36 :2 10 2c 48 :2 d 29 d 19
:2 d 1d d :4 a :4 e d :4 12 11
10 2f :2 3a 42 51 60 :2 2f 64
66 :2 64 2e :2 10 13 :2 1d 2f :2 39
45 49 5d 60 61 :2 5d :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a 7e 81
:2 2a 85 88 :2 2a 92 95 9e a6
:2 af :2 9e c0 :2 95 :2 2a c8 cb :2 2a
d3 d6 :2 2a db de :2 2a e1 e4
:2 2a :2 13 64 :2 10 13 :2 1d 2f :2 39
45 48 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a :2 13 63
:3 10 :2 1b 2f :2 38 48 4c :2 10 d
69 :4 15 14 13 39 :2 44 4c 5b
15 :2 39 19 1c :2 19 38 :3 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 92 95
9e a6 :2 af :2 9e ca :2 95 :2 2a :2 13
63 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
31 :2 3a 54 :2 10 1f 69 :2 d :4 12
11 10 2f :2 3a 42 51 5e :2 2f
62 64 :2 62 2e :3 10 18 10 67
10 18 10 :4 d 10 :2 1b 23 32
42 :2 10 46 48 :2 46 10 21 10
d 4a 13 :2 1e 25 34 :2 13 41
44 :2 41 1a 25 32 3c 47 4c
55 65 77 18 19 26 17 22
2a 31 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 9a 9d :2 30 a5 a8
:2 30 b4 b7 be c7 ca :2 b7 :2 30
:2 19 6a :2 16 :2 13 :4 1f :2 13 10 :3 46
14 :2 1d 28 26 :2 31 :2 26 13 1f
2a 37 3f 46 5f 6a 81 94
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 41 :2 10 d
46 4a 13 :2 1e 26 35 44 :2 13
48 4a :2 48 13 :2 1d 2f :2 39 45
49 5d 60 61 :2 5d :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a 7e 81 :2 2a
85 88 :2 2a 92 95 9e a6 :2 9e
aa :2 95 :2 2a b2 b5 :2 2a bd c0
:2 2a c5 c8 :2 2a cb ce :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f 32 36 :2 10 4c 4a :2 d 2a
d 1e d :5 a 18 :2 a 18 a
d 16 29 :2 d 2f 2c :2 38 :2 2c
17 10 22 10 22 10 16 2a
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:4 52 :4 11 10 :4 14 :2 13 21 13 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 30 16 1f 2b :2 16
2e 30 :2 2e 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 98 9b a4 ac :2 b5
:2 a4 d4 :2 9b :2 30 dc df :2 30 e7
ea :2 30 ef f2 :2 30 106 109 :2 30
:2 19 6a :2 16 19 :2 23 35 :2 3f 4b
4e 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 :2 19 69 :3 16
:2 21 35 :2 3e 5c 1e :2 16 32 :2 13
10 30 :4 17 16 13 21 13 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 32 16 1f 2b :2 16
2e 30 :2 2e 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 98 9b a4 ac :2 b5
:2 a4 d4 :2 9b :2 30 dc df :2 30 e7
ea :2 30 ef f2 :2 30 106 109 :2 30
:2 19 6a :2 16 19 :2 23 35 :2 3f 4b
4e 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 :2 19 69 :3 16
:2 21 35 :2 3e 5c 1e :2 16 32 20
24 34 41 1f 2c 3d 49 61
6d 75 7c :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:3 13 19 22 2b :2 19 30 2e 39
40 :2 30 :2 2e 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9b 9e a7 af :2 b8
:2 a7 d7 :2 9e :2 33 df e2 :2 33 ea
ed :2 33 f2 f5 :2 33 109 10c :2 33
:2 1c 6d :2 19 1c :2 26 38 :2 42 4e
51 65 68 69 :2 65 :2 38 :3 1c :2 22
27 33 77 7a :2 33 :2 1c 6c :3 19
:2 24 38 :2 41 5f 21 :2 19 43 :2 16
:4 13 32 30 16 :2 20 32 :2 3c 48
4c 60 63 64 :2 60 :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d 81 84 :2 2d
88 8b :2 2d 95 98 a1 a9 :2 b2
:2 a1 ca :2 98 :2 2d d2 d5 :2 2d dd
e0 :2 2d e5 e8 :2 2d fc ff :2 2d
:2 16 67 :2 13 16 :2 20 32 :2 3c 48
4b 5f 62 63 :2 5f :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d :2 16 66 :3 13
:2 1e 32 :2 3b 52 1b :2 13 :4 10 32
:3 d 1a :2 d 24 d :4 11 10 :4 2d
2c 2b :3 10 20 10 4c :3 d 20
33 41 4c 29 3e 4c 29 3b
47 51 29 37 3e 49 4f 29
38 48 54 29 35 48 54 :2 20
:2 d 1b :2 d 20 30 3e 53 5f
62 :2 20 d :4 11 :2 10 1e :2 10 23
33 41 56 62 65 :2 23 10 32
:2 d :4 a 26 :2 7 :4 4 8 :2 13 1a
24 :2 8 30 32 :2 30 7 3a a
1d :2 3a 23 20 :2 2c :2 20 39 :3 7
15 :2 7 17 :2 7 1c :2 25 :2 7 16
25 31 46 52 60 :2 16 :2 7 :2 10
1c :2 7 15 :2 7 17 :2 7 1c :2 25
:2 7 16 25 31 46 52 60 :2 16
:2 7 :2 10 1c 7 47 :3 4 17 21
:2 17 4 7 :2 11 23 :2 2d 39 3c
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 62 65 :2 1e 72 75 :2 1e 79
7c :2 1e 86 89 92 9a :2 a3 :2 92
ae :2 89 :2 1e b6 b9 :2 1e c1 c4
:2 1e c9 cc :2 1e cf d2 :2 1e :2 7
57 :3 4 :2 f 21 :2 2a 34 38 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 54 57 58 :2 54 :2 26 :3 a
:2 10 15 21 65 68 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 5b :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 51 54 55 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
58 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
1218
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :7 b
:7 c :7 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :5 19 :7 1a :6 1b
:6 1c :6 1d :6 1e :5 1f
:5 20 :5 21 :5 22 :5 23
:5 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :7 35 :5 36 :6 37
:7 39 :b 3b :11 3c 3d
:2 3c :2 3d :2 3c :2 3d
:2 3c :2 3e :2 3c :12 3e
:2 3c :2 3f :2 3c :12 3f
:2 3c :2 40 :2 3c :9 40
:2 3c :2 41 :2 3c :2 41
:2 3c :2 41 :2 3c :2 41
:2 3c :2 41 :4 3c :3 3b
:11 44 :b 45 :3 44 :3 4b
:3 4c :3 4e :3 50 :3 51
:3 52 :3 53 :a 54 :5 55
:3 54 :6 59 :f 5a :8 5b
:6 5c :9 5d :8 5e 5f
:2 60 59 :5 61 58
63 :5 64 :3 63 :2 65
:5 67 :11 68 :24 69 :3 68
:2 66 :6 65 62 :3 3a
:a 6f :11 70 :30 71 :3 70
:11 73 :b 74 :3 73 :a 76
:3 6f 7a 7b 7c
:2 7d :2 7e 7a :5 7f
79 81 :5 82 :3 81
:2 83 :5 85 :11 86 :24 87
:3 86 :2 84 :6 83 80
:3 3a :a 8c :11 8d :30 8e
:3 8d :11 90 :b 91 :3 90
:a 93 :3 8c :9 96 :11 97
:30 98 :3 97 :11 9a :b 9b
:3 9a :a 9d :3 96 :e a0
:c a1 :11 a2 :30 a3 :3 a2
:11 a5 :b a6 :3 a5 :a a8
:3 a1 :3 a0 :3 ac :4 ae
:4 af :7 b0 ae :5 b1
ad b3 :5 b4 :3 b3
:2 b5 :5 b7 :11 b8 :24 b9
:3 b8 :2 b6 :6 b5 b2
:3 3a :3 bf :d c0 :2 c1
:2 c0 :6 c1 :3 c0 :3 c2
:3 c3 :5 c4 :a c5 :5 c6
:3 c8 :3 c9 :5 ca :a cb
:5 cc c1 :2 c0 :15 d0
:3 d1 :3 d0 :e d4 d6
:2 d7 :2 d8 d9 :2 da
d6 :6 db :5 dc db
:5 de dd :3 db d5
e1 :5 e2 :3 e1 :2 e3
:5 e5 :11 e6 :24 e7 :3 e6
:2 e4 :6 e3 e0 :4 d4
:c ee f2 :2 f3 f4
:2 f5 f2 :6 f6 :5 f7
f6 :5 f9 f8 :3 f6
f1 fc :5 fd :3 fc
:2 fe :5 100 :11 101 :24 102
:3 101 :2 ff :6 fe fb
:3 ee :c 109 :3 10b :3 109
:3 ee :c 10f 112 :2 113
114 :2 115 112 :6 116
:5 117 116 :5 119 118
:3 116 111 11c :5 11d
:3 11c :2 11e :5 120 :11 121
:24 122 :3 121 :2 11f :6 11e
11b :3 10f :c 12a :3 12c
:3 12a :3 10f :9 130 :15 133
:3 134 :3 133 :12 137 138
:2 137 :4 138 :3 137 :11 139
:30 13a :3 139 :11 13c :b 13d
:3 13c :a 13f 138 :2 137
:5 142 :5 143 :11 144 :30 145
:3 144 :11 147 :b 148 :3 147
:a 14a :3 143 :3 14e :c 14f
:3 150 151 14f :c 151
:9 153 154 :2 155 :4 156
153 :5 157 152 159
:5 15a :3 159 :2 15b :5 15d
:11 15e :24 15f :3 15e :2 15c
:6 15b 158 :3 151 :a 164
:a 167 :5 168 166 16a
:5 16b :3 16a :2 16c :5 16e
:11 16f :24 170 :3 16f :2 16d
:6 16c 169 :6 164 175
151 14f :5 175 :11 176
:2e 177 :3 176 :11 179 :b 17a
:3 179 :8 17c 175 :3 14f
142 :3 17f :3 180 17e
:3 142 :5 183 :15 185 :11 186
:30 187 :3 186 :11 189 :b 18a
:3 189 :a 18c 18d 185
:b 18d 18e :2 18d :4 18e
:3 18d :11 18f :20 190 :3 18f
:11 192 :b 193 :3 192 :9 195
18e :3 185 :15 198 :3 199
198 :3 19b 19a :3 198
:c 19f :3 1a0 1a1 19f
:b 1a1 :9 1a4 1a5 :2 1a6
:4 1a7 1a4 :5 1a8 1a3
1aa :5 1ab :3 1aa :2 1ac
:5 1ae :11 1af :24 1b0 :3 1af
:2 1ad :6 1ac 1a9 :3 1a1
:a 1b6 :a 1b9 :5 1ba 1b8
1bc :5 1bd :3 1bc :2 1be
:5 1c0 :11 1c1 :24 1c2 :3 1c1
:2 1bf :6 1be 1bb :6 1b6
1c7 1a1 19f :c 1c7
:11 1c9 :2e 1ca :3 1c9 :11 1cc
:b 1cd :3 1cc :8 1cf 1c7
:3 19f 183 :3 1d2 1d1
:3 183 :3 1d5 :3 1d6 :b 1d9
1db :2 1dc :2 1dd 1de
:2 1df 1db :6 1e0 :5 1e1
1e0 :5 1e3 1e2 :3 1e0
1da 1e6 :5 1e7 :3 1e6
:2 1e8 :5 1ea :11 1eb :24 1ec
:3 1eb :2 1e9 :6 1e8 1e5
:4 1d9 :5 1f3 :5 1f5 :3 1f6
:2 1f8 1f9 :2 1fa :6 1fb
:4 1fc 1f8 :5 1fd 1f7
1ff :5 200 :3 1ff :2 201
:5 203 :11 204 :24 205 :3 204
:2 202 :6 201 1fe :3 1f5
:9 209 :11 20c :30 20d :3 20c
:11 20f :b 210 :3 20f :7 212
213 :2 212 :3 209 215
1f5 :5 215 :3 217 :2 219
21a :2 21b :6 21c :4 21d
219 :5 21e 218 220
:5 221 :3 220 :2 222 :5 224
:11 225 :24 226 :3 225 :2 223
:6 222 21f :3 215 :9 22b
:11 22d :30 22e :3 22d :11 230
:b 231 :3 230 :7 233 234
:2 233 22b :4 23b :8 23c
23b :5 23d 23a 23f
:5 240 :3 23f :2 241 :5 243
:11 244 :24 245 :3 244 :2 242
:6 241 23e :3 235 :d 249
:11 24a :30 24b :3 24a :11 24d
:b 24e :3 24d :7 250 251
:2 250 :3 249 235 :3 22b
215 1f5 :11 255 :30 256
:3 255 :11 258 :b 259 :3 258
:7 25b 25c :2 25b 254
:3 1f5 :3 1f3 :3 261 :3 262
:d 264 :3 265 :3 264 :5 268
:3 269 :4 26a :5 26b :4 26c
:4 26d :3 268 :3 26f :a 270
:5 272 :3 273 :a 274 :3 272
1f0 :3 1d9 :3 130 ec
:3 d4 :d 27a :2 27b :2 27a
:6 27b :3 27a :3 27c :3 27d
:5 27e :a 27f :5 280 :3 282
:3 283 :5 284 :a 285 :5 286
27b :2 27a :6 289 :11 28b
:30 28c :3 28b :a 28e 3a
:3 292 :11 293 :b 294 :17 295
:3 293 :2 297 :3 298 :3 299
29a 298 297 298
:3 29b :3 292 :2 29c :5 29e
:11 29f :b 2a0 :18 2a1 :3 29f
:2 2a3 2a4 :3 2a5 2a6
2a4 2a3 2a4 :3 2a7
:2 29d :6 29c 291 :7 1

3f21
4
:3 0 1 :3 0 2
:a 0 1213 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
9 :3 0 8 :7 0
11 10 :3 0 4
:3 0 a :7 0 15
14 :3 0 b :3 0
c :3 0 d :2 0
4 19 1a 0
17 1b 0 1213
2 1c :2 0 11
:2 0 15 4 :3 0
f :2 0 13 1f
21 :6 0 24 22
0 1211 0 e
:6 0 11 :2 0 19
4 :3 0 17 26
28 :6 0 2b 29
0 1211 0 10
:6 0 11 :2 0 1d
4 :3 0 1b 2d
2f :6 0 32 30
0 1211 0 12
:6 0 11 :2 0 21
4 :3 0 1f 34
36 :6 0 39 37
0 1211 0 13
:6 0 11 :2 0 25
4 :3 0 23 3b
3d :6 0 40 3e
0 1211 0 14
:6 0 11 :2 0 29
4 :3 0 27 42
44 :6 0 47 45
0 1211 0 15
:6 0 11 :2 0 2d
4 :3 0 2b 49
4b :6 0 4e 4c
0 1211 0 16
:6 0 11 :2 0 31
4 :3 0 2f 50
52 :6 0 55 53
0 1211 0 17
:6 0 37 19b 0
35 4 :3 0 33
57 59 :6 0 5c
5a 0 1211 0
18 :6 0 3b 1cf
0 39 6 :3 0
5e :7 0 61 5f
0 1211 0 19
:6 0 6 :3 0 63
:7 0 66 64 0
1211 0 1a :6 0
3f 203 0 3d
6 :3 0 68 :7 0
6b 69 0 1211
0 1b :6 0 6
:3 0 6d :7 0 70
6e 0 1211 0
1c :6 0 43 237
0 41 6 :3 0
72 :7 0 75 73
0 1211 0 1d
:6 0 6 :3 0 77
:7 0 7a 78 0
1211 0 1e :6 0
23 :2 0 47 6
:3 0 7c :7 0 7f
7d 0 1211 0
1f :6 0 4 :3 0
21 :2 0 45 81
83 :6 0 86 84
0 1211 0 20
:6 0 23 :2 0 49
9 :3 0 88 :7 0
8c 89 8a 1211
0 22 :6 0 27
:2 0 4b 9 :3 0
8e :7 0 92 8f
90 1211 0 24
:6 0 27 :2 0 4d
26 :3 0 94 :7 0
98 95 96 1211
0 25 :6 0 51
2df 0 4f 26
:3 0 9a :7 0 9e
9b 9c 1211 0
28 :6 0 55 313
0 53 6 :3 0
a0 :7 0 a3 a1
0 1211 0 29
:6 0 6 :3 0 a5
:7 0 a8 a6 0
1211 0 2a :6 0
59 347 0 57
2c :3 0 aa :7 0
ad ab 0 1211
0 2b :6 0 2c
:3 0 af :7 0 b2
b0 0 1211 0
2d :6 0 f :2 0
5b 2c :3 0 b4
:7 0 b7 b5 0
1211 0 2e :6 0
2c :3 0 b9 :7 0
bc ba 0 1211
0 2f :6 0 23
:2 0 5f 4 :3 0
5d be c0 :6 0
c3 c1 0 1211
0 30 :6 0 23
:2 0 61 9 :3 0
c5 :7 0 c9 c6
c7 1211 0 31
:6 0 23 :2 0 63
9 :3 0 cb :7 0
cf cc cd 1211
0 32 :6 0 23
:2 0 65 9 :3 0
d1 :7 0 d5 d2
d3 1211 0 33
:6 0 23 :2 0 67
9 :3 0 d7 :7 0
db d8 d9 1211
0 34 :6 0 23
:2 0 69 9 :3 0
dd :7 0 e1 de
df 1211 0 35
:6 0 23 :2 0 6b
9 :3 0 e3 :7 0
e7 e4 e5 1211
0 36 :6 0 23
:2 0 6d 9 :3 0
e9 :7 0 ed ea
eb 1211 0 37
:6 0 23 :2 0 6f
9 :3 0 ef :7 0
f3 f0 f1 1211
0 38 :6 0 23
:2 0 71 9 :3 0
f5 :7 0 f9 f6
f7 1211 0 39
:6 0 23 :2 0 73
9 :3 0 fb :7 0
ff fc fd 1211
0 3a :6 0 23
:2 0 75 9 :3 0
101 :7 0 105 102
103 1211 0 3b
:6 0 23 :2 0 77
9 :3 0 107 :7 0
10b 108 109 1211
0 3c :6 0 23
:2 0 79 9 :3 0
10d :7 0 111 10e
10f 1211 0 3d
:6 0 23 :2 0 7b
9 :3 0 113 :7 0
117 114 115 1211
0 3e :6 0 11
:2 0 7d 9 :3 0
119 :7 0 11d 11a
11b 1211 0 3f
:6 0 83 559 0
81 4 :3 0 7f
11f 121 :6 0 124
122 0 1211 0
40 :6 0 131 132
0 85 42 :3 0
126 :7 0 129 127
0 1211 0 41
:6 0 9 :3 0 12b
0 2 :5 0 23
:2 0 12f 12c 12d
1211 0 43 :6 0
137 138 0 87
c :3 0 d :2 0
4 133 :7 0 136
134 0 1211 0
44 :6 0 45 :3 0
46 :3 0 45 :3 0
47 :3 0 13a 13b
0 2 :4 0 89
13c 13e 139 140
13f :2 0 48 :3 0
49 :3 0 142 143
0 4a :4 0 45
:3 0 4b :3 0 146
147 0 2 :4 0
8b 148 14a 4c
:4 0 4d :2 0 4e
:3 0 8d 14d 14f
:3 0 4f :4 0 4d
:2 0 50 :4 0 90
152 154 :3 0 4d
:2 0 3 :3 0 93
156 158 :3 0 4d
:2 0 50 :4 0 96
15a 15c :3 0 4d
:2 0 51 :4 0 99
15e 160 :3 0 4d
:2 0 52 :3 0 53
:3 0 50 :4 0 4d
:2 0 5 :3 0 9c
166 168 :3 0 4d
:2 0 50 :4 0 9f
16a 16c :3 0 54
:4 0 a2 164 16f
55 :4 0 a5 163
172 a8 162 174
:3 0 4d :2 0 51
:4 0 ab 176 178
:3 0 4d :2 0 52
:3 0 53 :3 0 50
:4 0 4d :2 0 7
:3 0 ae 17e 180
:3 0 4d :2 0 50
:4 0 b1 182 184
:3 0 54 :4 0 b4
17c 187 55 :4 0
b7 17b 18a ba
17a 18c :3 0 4d
:2 0 51 :4 0 bd
18e 190 :3 0 4d
:2 0 52 :3 0 56
:3 0 8 :3 0 c0
194 196 55 :4 0
c2 193 199 c5
192 19b :3 0 4d
:2 0 51 :4 0 c8
19d 19f :3 0 4d
:2 0 50 :4 0 cb
1a1 1a3 :3 0 4d
:2 0 a :3 0 ce
1a5 1a7 :3 0 4d
:2 0 50 :4 0 d1
1a9 1ab :3 0 4d
:2 0 57 :4 0 d4
1ad 1af :3 0 d7
144 1b1 :2 0 1b3
dc 1b4 141 1b3
0 1b5 de 0
1171 45 :3 0 46
:3 0 1b6 1b7 0
45 :3 0 58 :3 0
1b9 1ba 0 f
:2 0 2 :4 0 59
:2 0 5a :2 0 f
:2 0 e0 1bf 1c1
:3 0 e3 1bb 1c3
1b8 1c5 1c4 :2 0
48 :3 0 5b :3 0
1c7 1c8 0 4a
:4 0 5c :4 0 4d
:2 0 4e :3 0 e7
1cc 1ce :3 0 ea
1c9 1d0 :2 0 1d2
ed 1d3 1c6 1d2
0 1d4 ef 0
1171 19 :3 0 5d
:4 0 1d5 1d6 0
1171 1a :3 0 5d
:4 0 1d8 1d9 0
1171 36 :3 0 f
:2 0 1db 1dc 0
1171 19 :3 0 5
:3 0 1de 1df 0
1171 1a :3 0 7
:3 0 1e1 1e2 0
1171 14 :3 0 3
:3 0 1e4 1e5 0
1171 3a :3 0 8
:3 0 1e7 1e8 0
1171 52 :3 0 3a
:3 0 23 :2 0 f1
1ea 1ed 5e :2 0
f :2 0 f6 1ef
1f1 :3 0 1f2 :2 0
3a :3 0 5f :3 0
60 :3 0 1f5 1f6
0 1f4 1f7 0
1f9 f9 1fa 1f3
1f9 0 1fb fb
0 1171 61 :3 0
62 :3 0 63 :3 0
64 :3 0 65 :3 0
66 :3 0 52 :3 0
67 :3 0 68 :3 0
52 :3 0 69 :3 0
6a :3 0 67 :3 0
69 :3 0 6b :3 0
6c :3 0 6d :3 0
6e :3 0 6d :3 0
6f :3 0 70 :3 0
71 :3 0 72 :3 0
73 :3 0 74 :3 0
75 :3 0 76 :3 0
77 :3 0 78 :3 0
10 :3 0 15 :3 0
13 :3 0 1f :3 0
22 :3 0 30 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
12 :3 0 16 :3 0
35 :3 0 3b :3 0
33 :3 0 38 :3 0
2b :3 0 29 :3 0
2a :3 0 31 :3 0
32 :3 0 25 :3 0
28 :3 0 79 :3 0
7a :3 0 3 :4 0
7b 1 :8 0 239
c :3 0 7c :3 0
234 235 0 7d
:3 0 236 237 0
239 fd 28c 7e
:3 0 c :3 0 7c
:3 0 23b 23c 0
7d :3 0 23d 23e
0 240 100 242
102 241 240 :2 0
28a 7f :3 0 c
:3 0 7c :3 0 245
246 0 7d :3 0
247 248 0 282
45 :3 0 46 :3 0
24a 24b 0 45
:3 0 58 :3 0 24d
24e 0 80 :2 0
2 :4 0 81 :2 0
5a :2 0 f :2 0
104 253 255 :3 0
107 24f 257 24c
259 258 :2 0 48
:3 0 5b :3 0 25b
25c 0 4a :4 0
82 :4 0 4d :2 0
4e :3 0 10b 260
262 :3 0 4d :2 0
83 :4 0 10e 264
266 :3 0 4d :2 0
84 :4 0 111 268
26a :3 0 4d :2 0
7d :3 0 114 26c
26e :3 0 4d :2 0
85 :4 0 117 270
272 :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
11a 275 279 11e
274 27b :3 0 121
25d 27d :2 0 27f
124 280 25a 27f
0 281 126 0
282 128 285 :3 0
285 0 285 284
282 283 :6 0 287
2 :3 0 12b 289
12d 288 287 :2 0
28a 12f :2 0 28c
0 28c 28b 239
28a :6 0 1171 1
:3 0 c :3 0 7c
:3 0 28e 28f 0
c :3 0 5e :2 0
89 :3 0 291 293
0 134 292 295
:3 0 296 :2 0 45
:3 0 46 :3 0 298
299 0 45 :3 0
58 :3 0 29b 29c
0 11 :2 0 2
:4 0 8a :2 0 5a
:2 0 f :2 0 137
2a1 2a3 :3 0 13a
29d 2a5 29a 2a7
2a6 :2 0 48 :3 0
5b :3 0 2a9 2aa
0 4a :4 0 8b
:4 0 4d :2 0 4e
:3 0 13e 2ae 2b0
:3 0 4d :2 0 83
:4 0 141 2b2 2b4
:3 0 4d :2 0 8c
:4 0 144 2b6 2b8
:3 0 4d :2 0 52
:3 0 56 :3 0 5f
:3 0 8d :3 0 2bd
2be 0 147 2bc
2c0 55 :4 0 149
2bb 2c3 14c 2ba
2c5 :3 0 4d :2 0
8e :4 0 14f 2c7
2c9 :3 0 4d :2 0
50 :4 0 152 2cb
2cd :3 0 4d :2 0
3 :3 0 155 2cf
2d1 :3 0 4d :2 0
50 :4 0 158 2d3
2d5 :3 0 15b 2ab
2d7 :2 0 2d9 15e
2da 2a8 2d9 0
2db 160 0 305
45 :3 0 46 :3 0
2dc 2dd 0 45
:3 0 58 :3 0 2df
2e0 0 f :2 0
2 :4 0 8f :2 0
5a :2 0 f :2 0
162 2e5 2e7 :3 0
165 2e1 2e9 2de
2eb 2ea :2 0 48
:3 0 5b :3 0 2ed
2ee 0 4a :4 0
90 :4 0 4d :2 0
4e :3 0 169 2f2
2f4 :3 0 16c 2ef
2f6 :2 0 2f8 16f
2f9 2ec 2f8 0
2fa 171 0 305
91 :3 0 92 :3 0
2fb 2fc 0 5f
:3 0 8d :3 0 2fe
2ff 0 3 :3 0
93 :3 0 173 2fd
303 :2 0 305 177
306 297 305 0
307 17b 0 1171
94 :3 0 e :3 0
95 :3 0 61 :3 0
10 :3 0 96 :3 0
12 :4 0 97 1
:8 0 315 c :3 0
7c :3 0 310 311
0 7d :3 0 312
313 0 315 17d
368 7e :3 0 c
:3 0 7c :3 0 317
318 0 7d :3 0
319 31a 0 31c
180 31e 182 31d
31c :2 0 366 7f
:3 0 c :3 0 7c
:3 0 321 322 0
7d :3 0 323 324
0 35e 45 :3 0
46 :3 0 326 327
0 45 :3 0 58
:3 0 329 32a 0
80 :2 0 2 :4 0
98 :2 0 5a :2 0
f :2 0 184 32f
331 :3 0 187 32b
333 328 335 334
:2 0 48 :3 0 5b
:3 0 337 338 0
4a :4 0 99 :4 0
4d :2 0 4e :3 0
18b 33c 33e :3 0
4d :2 0 83 :4 0
18e 340 342 :3 0
4d :2 0 84 :4 0
191 344 346 :3 0
4d :2 0 7d :3 0
194 348 34a :3 0
4d :2 0 85 :4 0
197 34c 34e :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 19a 351
355 19e 350 357
:3 0 1a1 339 359
:2 0 35b 1a4 35c
336 35b 0 35d
1a6 0 35e 1a8
361 :3 0 361 0
361 360 35e 35f
:6 0 363 4 :3 0
1ab 365 1ad 364
363 :2 0 366 1af
:2 0 368 0 368
367 315 366 :6 0
1171 1 :3 0 86
:3 0 e :3 0 f
:2 0 f :2 0 1b2
36a 36e 5e :2 0
9a :4 0 1b8 370
372 :3 0 45 :3 0
46 :3 0 374 375
0 45 :3 0 58
:3 0 377 378 0
11 :2 0 2 :4 0
9b :2 0 5a :2 0
f :2 0 1bb 37d
37f :3 0 1be 379
381 376 383 382
:2 0 48 :3 0 5b
:3 0 385 386 0
4a :4 0 9c :4 0
4d :2 0 4e :3 0
1c2 38a 38c :3 0
4d :2 0 83 :4 0
1c5 38e 390 :3 0
4d :2 0 8c :4 0
1c8 392 394 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
9d :3 0 399 39a
0 1cb 398 39c
55 :4 0 1cd 397
39f 1d0 396 3a1
:3 0 4d :2 0 8e
:4 0 1d3 3a3 3a5
:3 0 4d :2 0 50
:4 0 1d6 3a7 3a9
:3 0 4d :2 0 3
:3 0 1d9 3ab 3ad
:3 0 4d :2 0 50
:4 0 1dc 3af 3b1
:3 0 1df 387 3b3
:2 0 3b5 1e2 3b6
384 3b5 0 3b7
1e4 0 3e1 45
:3 0 46 :3 0 3b8
3b9 0 45 :3 0
58 :3 0 3bb 3bc
0 f :2 0 2
:4 0 9e :2 0 5a
:2 0 f :2 0 1e6
3c1 3c3 :3 0 1e9
3bd 3c5 3ba 3c7
3c6 :2 0 48 :3 0
5b :3 0 3c9 3ca
0 4a :4 0 9f
:4 0 4d :2 0 4e
:3 0 1ed 3ce 3d0
:3 0 1f0 3cb 3d2
:2 0 3d4 1f3 3d5
3c8 3d4 0 3d6
1f5 0 3e1 91
:3 0 92 :3 0 3d7
3d8 0 5f :3 0
9d :3 0 3da 3db
0 3 :3 0 93
:3 0 1f7 3d9 3df
:2 0 3e1 1fb 3e2
373 3e1 0 3e3
1ff 0 1171 52
:3 0 22 :3 0 23
:2 0 201 3e4 3e7
5e :2 0 a0 :2 0
206 3e9 3eb :3 0
45 :3 0 46 :3 0
3ed 3ee 0 45
:3 0 58 :3 0 3f0
3f1 0 11 :2 0
2 :4 0 a1 :2 0
5a :2 0 f :2 0
209 3f6 3f8 :3 0
20c 3f2 3fa 3ef
3fc 3fb :2 0 48
:3 0 5b :3 0 3fe
3ff 0 4a :4 0
a2 :4 0 4d :2 0
4e :3 0 210 403
405 :3 0 4d :2 0
83 :4 0 213 407
409 :3 0 4d :2 0
8c :4 0 216 40b
40d :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 a3 :3 0
412 413 0 219
411 415 55 :4 0
21b 410 418 21e
40f 41a :3 0 4d
:2 0 8e :4 0 221
41c 41e :3 0 4d
:2 0 50 :4 0 224
420 422 :3 0 4d
:2 0 3 :3 0 227
424 426 :3 0 4d
:2 0 50 :4 0 22a
428 42a :3 0 22d
400 42c :2 0 42e
230 42f 3fd 42e
0 430 232 0
45a 45 :3 0 46
:3 0 431 432 0
45 :3 0 58 :3 0
434 435 0 f
:2 0 2 :4 0 a4
:2 0 5a :2 0 f
:2 0 234 43a 43c
:3 0 237 436 43e
433 440 43f :2 0
48 :3 0 5b :3 0
442 443 0 4a
:4 0 a5 :4 0 4d
:2 0 4e :3 0 23b
447 449 :3 0 23e
444 44b :2 0 44d
241 44e 441 44d
0 44f 243 0
45a 91 :3 0 92
:3 0 450 451 0
5f :3 0 a3 :3 0
453 454 0 3
:3 0 93 :3 0 245
452 458 :2 0 45a
249 45b 3ec 45a
0 45c 24d 0
1171 5 :3 0 a6
:2 0 24f 45e 45f
:3 0 460 :2 0 461
:2 0 7 :3 0 a6
:2 0 251 464 465
:3 0 466 :2 0 467
:2 0 462 469 468
:2 0 a7 :3 0 a8
:3 0 46b 46c 0
1a :3 0 19 :3 0
a9 :2 0 253 46d
471 aa :2 0 23
:2 0 259 473 475
:3 0 45 :3 0 46
:3 0 477 478 0
45 :3 0 58 :3 0
47a 47b 0 11
:2 0 2 :4 0 ab
:2 0 5a :2 0 f
:2 0 25c 480 482
:3 0 25f 47c 484
479 486 485 :2 0
48 :3 0 5b :3 0
488 489 0 4a
:4 0 ac :4 0 4d
:2 0 4e :3 0 263
48d 48f :3 0 4d
:2 0 83 :4 0 266
491 493 :3 0 4d
:2 0 8c :4 0 269
495 497 :3 0 4d
:2 0 52 :3 0 56
:3 0 5f :3 0 ad
:3 0 49c 49d 0
26c 49b 49f 55
:4 0 26e 49a 4a2
271 499 4a4 :3 0
4d :2 0 8e :4 0
274 4a6 4a8 :3 0
4d :2 0 50 :4 0
277 4aa 4ac :3 0
4d :2 0 3 :3 0
27a 4ae 4b0 :3 0
4d :2 0 50 :4 0
27d 4b2 4b4 :3 0
280 48a 4b6 :2 0
4b8 283 4b9 487
4b8 0 4ba 285
0 4e4 45 :3 0
46 :3 0 4bb 4bc
0 45 :3 0 58
:3 0 4be 4bf 0
f :2 0 2 :4 0
ae :2 0 5a :2 0
f :2 0 287 4c4
4c6 :3 0 28a 4c0
4c8 4bd 4ca 4c9
:2 0 48 :3 0 5b
:3 0 4cc 4cd 0
4a :4 0 af :4 0
4d :2 0 4e :3 0
28e 4d1 4d3 :3 0
291 4ce 4d5 :2 0
4d7 294 4d8 4cb
4d7 0 4d9 296
0 4e4 91 :3 0
92 :3 0 4da 4db
0 5f :3 0 ad
:3 0 4dd 4de 0
3 :3 0 93 :3 0
298 4dc 4e2 :2 0
4e4 29c 4e5 476
4e4 0 4e6 2a0
0 4e7 2a2 4e8
46a 4e7 0 4e9
2a4 0 1171 2f
:4 0 4ea 4eb 0
1171 b0 :3 0 b1
:3 0 2f :3 0 b2
:3 0 96 :3 0 10
:3 0 6c :3 0 16
:3 0 b3 :3 0 5f
:3 0 b4 :3 0 5f
:3 0 b5 :3 0 5f
:3 0 b6 :4 0 b7
1 :8 0 502 c
:3 0 7c :3 0 4fd
4fe 0 7d :3 0
4ff 500 0 502
2a6 555 7e :3 0
c :3 0 7c :3 0
504 505 0 7d
:3 0 506 507 0
509 2a9 50b 2ab
50a 509 :2 0 553
7f :3 0 c :3 0
7c :3 0 50e 50f
0 7d :3 0 510
511 0 54b 45
:3 0 46 :3 0 513
514 0 45 :3 0
58 :3 0 516 517
0 80 :2 0 2
:4 0 b8 :2 0 5a
:2 0 f :2 0 2ad
51c 51e :3 0 2b0
518 520 515 522
521 :2 0 48 :3 0
5b :3 0 524 525
0 4a :4 0 b9
:4 0 4d :2 0 4e
:3 0 2b4 529 52b
:3 0 4d :2 0 83
:4 0 2b7 52d 52f
:3 0 4d :2 0 84
:4 0 2ba 531 533
:3 0 4d :2 0 7d
:3 0 2bd 535 537
:3 0 4d :2 0 85
:4 0 2c0 539 53b
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 2c3
53e 542 2c7 53d
544 :3 0 2ca 526
546 :2 0 548 2cd
549 523 548 0
54a 2cf 0 54b
2d1 54e :3 0 54e
0 54e 54d 54b
54c :6 0 550 6
:3 0 2d4 552 2d6
551 550 :2 0 553
2d8 :2 0 555 0
555 554 502 553
:6 0 1171 1 :3 0
17 :3 0 a :3 0
557 558 0 1171
a7 :3 0 ba :3 0
55a 55b 0 16
:3 0 17 :3 0 2db
55c 55f 5e :2 0
23 :2 0 2e0 561
563 :3 0 564 :2 0
52 :3 0 3a :3 0
23 :2 0 2e3 566
569 5f :3 0 bb
:2 0 60 :3 0 56b
56d 0 2e8 56c
56f :3 0 570 :2 0
565 572 571 :2 0
40 :3 0 bc :4 0
574 575 0 5a8
3f :3 0 f :2 0
577 578 0 5a8
43 :3 0 c :3 0
7c :3 0 57b 57c
0 57a 57d 0
5a8 41 :3 0 bd
:3 0 40 :3 0 14
:3 0 17 :3 0 3f
:3 0 23 :2 0 2eb
580 586 57f 587
0 5a8 c :3 0
7c :3 0 589 58a
0 43 :3 0 58b
58c 0 5a8 40
:3 0 be :4 0 58e
58f 0 5a8 3f
:3 0 23 :2 0 591
592 0 5a8 43
:3 0 c :3 0 7c
:3 0 595 596 0
594 597 0 5a8
41 :3 0 bd :3 0
40 :3 0 14 :3 0
17 :3 0 3f :3 0
23 :2 0 2f1 59a
5a0 599 5a1 0
5a8 c :3 0 7c
:3 0 5a3 5a4 0
43 :3 0 5a5 5a6
0 5a8 2f7 5a9
573 5a8 0 5aa
302 0 1171 19
:3 0 a6 :2 0 304
5ac 5ad :3 0 5ae
:2 0 5af :2 0 a7
:3 0 a8 :3 0 5b1
5b2 0 19 :3 0
1b :3 0 a9 :2 0
306 5b3 5b7 5e
:2 0 23 :2 0 30c
5b9 5bb :3 0 5bc
:2 0 5b0 5be 5bd
:2 0 19 :3 0 1b
:3 0 5c0 5c1 0
5c3 30f 5c4 5bf
5c3 0 5c5 311
0 1171 5 :3 0
bf :2 0 313 5c7
5c8 :3 0 5c9 :2 0
5ca :2 0 7 :3 0
bf :2 0 315 5cd
5ce :3 0 5cf :2 0
5d0 :2 0 5cb 5d2
5d1 :2 0 79 :3 0
67 :3 0 5 :3 0
69 :3 0 7 :3 0
c0 :3 0 7a :3 0
3 :4 0 c1 1
:8 0 5f2 c2 :4 0
5dd :3 0 93 :3 0
5e :2 0 319 5e0
5e1 :3 0 c :3 0
7c :3 0 5e3 5e4
0 23 :2 0 5e5
5e6 0 5e8 31c
5ef c :3 0 7c
:3 0 5e9 5ea 0
c3 :2 0 5eb 5ec
0 5ee 31e 5f0
5e2 5e8 0 5f1
0 5ee 0 5f1
320 0 5f2 323
645 7e :3 0 c
:3 0 7c :3 0 5f4
5f5 0 7d :3 0
5f6 5f7 0 5f9
326 5fb 328 5fa
5f9 :2 0 643 7f
:3 0 c :3 0 7c
:3 0 5fe 5ff 0
7d :3 0 600 601
0 63b 45 :3 0
46 :3 0 603 604
0 45 :3 0 58
:3 0 606 607 0
80 :2 0 2 :4 0
c4 :2 0 5a :2 0
f :2 0 32a 60c
60e :3 0 32d 608
610 605 612 611
:2 0 48 :3 0 5b
:3 0 614 615 0
4a :4 0 c5 :4 0
4d :2 0 4e :3 0
331 619 61b :3 0
4d :2 0 83 :4 0
334 61d 61f :3 0
4d :2 0 84 :4 0
337 621 623 :3 0
4d :2 0 7d :3 0
33a 625 627 :3 0
4d :2 0 85 :4 0
33d 629 62b :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 340 62e
632 344 62d 634
:3 0 347 616 636
:2 0 638 34a 639
613 638 0 63a
34c 0 63b 34e
63e :3 0 63e 0
63e 63d 63b 63c
:6 0 640 8 :3 0
351 642 353 641
640 :2 0 643 355
:2 0 645 0 645
644 5f2 643 :6 0
647 1 :3 0 358
10c9 5 :3 0 bf
:2 0 35a 649 64a
:3 0 64b :2 0 1d
:3 0 a6 :2 0 35c
64e 64f :3 0 650
:2 0 64c 652 651
:2 0 79 :3 0 67
:3 0 5 :3 0 c0
:3 0 7a :3 0 3
:4 0 c6 1 :8 0
670 c2 :4 0 65b
:3 0 93 :3 0 5e
:2 0 360 65e 65f
:3 0 c :3 0 7c
:3 0 661 662 0
23 :2 0 663 664
0 666 363 66d
c :3 0 7c :3 0
667 668 0 c3
:2 0 669 66a 0
66c 365 66e 660
666 0 66f 0
66c 0 66f 367
0 670 36a 6c3
7e :3 0 c :3 0
7c :3 0 672 673
0 7d :3 0 674
675 0 677 36d
679 36f 678 677
:2 0 6c1 7f :3 0
c :3 0 7c :3 0
67c 67d 0 7d
:3 0 67e 67f 0
6b9 45 :3 0 46
:3 0 681 682 0
45 :3 0 58 :3 0
684 685 0 80
:2 0 2 :4 0 c7
:2 0 5a :2 0 f
:2 0 371 68a 68c
:3 0 374 686 68e
683 690 68f :2 0
48 :3 0 5b :3 0
692 693 0 4a
:4 0 c8 :4 0 4d
:2 0 4e :3 0 378
697 699 :3 0 4d
:2 0 83 :4 0 37b
69b 69d :3 0 4d
:2 0 84 :4 0 37e
69f 6a1 :3 0 4d
:2 0 7d :3 0 381
6a3 6a5 :3 0 4d
:2 0 85 :4 0 384
6a7 6a9 :3 0 4d
:2 0 86 :3 0 87
:3 0 f :2 0 88
:2 0 387 6ac 6b0
38b 6ab 6b2 :3 0
38e 694 6b4 :2 0
6b6 391 6b7 691
6b6 0 6b8 393
0 6b9 395 6bc
:3 0 6bc 0 6bc
6bb 6b9 6ba :6 0
6be a :3 0 398
6c0 39a 6bf 6be
:2 0 6c1 39c :2 0
6c3 0 6c3 6c2
670 6c1 :6 0 6d7
1 :3 0 a7 :3 0
a8 :3 0 6c5 6c6
0 1a :3 0 1e
:3 0 a9 :2 0 39f
6c7 6cb 5e :2 0
23 :2 0 3a5 6cd
6cf :3 0 36 :3 0
23 :2 0 6d1 6d2
0 6d4 3a8 6d5
6d0 6d4 0 6d6
3aa 0 6d7 3ac
6d8 653 6d7 0
6d9 3af 0 10c8
7 :3 0 bf :2 0
3b1 6db 6dc :3 0
6dd :2 0 1e :3 0
a6 :2 0 3b3 6e0
6e1 :3 0 6e2 :2 0
6de 6e4 6e3 :2 0
79 :3 0 69 :3 0
7 :3 0 c0 :3 0
7a :3 0 3 :4 0
c9 1 :8 0 702
c2 :4 0 6ed :3 0
93 :3 0 5e :2 0
3b7 6f0 6f1 :3 0
c :3 0 7c :3 0
6f3 6f4 0 23
:2 0 6f5 6f6 0
6f8 3ba 6ff c
:3 0 7c :3 0 6f9
6fa 0 c3 :2 0
6fb 6fc 0 6fe
3bc 700 6f2 6f8
0 701 0 6fe
0 701 3be 0
702 3c1 755 7e
:3 0 c :3 0 7c
:3 0 704 705 0
7d :3 0 706 707
0 709 3c4 70b
3c6 70a 709 :2 0
753 7f :3 0 c
:3 0 7c :3 0 70e
70f 0 7d :3 0
710 711 0 74b
45 :3 0 46 :3 0
713 714 0 45
:3 0 58 :3 0 716
717 0 80 :2 0
2 :4 0 ca :2 0
5a :2 0 f :2 0
3c8 71c 71e :3 0
3cb 718 720 715
722 721 :2 0 48
:3 0 5b :3 0 724
725 0 4a :4 0
cb :4 0 4d :2 0
4e :3 0 3cf 729
72b :3 0 4d :2 0
83 :4 0 3d2 72d
72f :3 0 4d :2 0
84 :4 0 3d5 731
733 :3 0 4d :2 0
7d :3 0 3d8 735
737 :3 0 4d :2 0
85 :4 0 3db 739
73b :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
3de 73e 742 3e2
73d 744 :3 0 3e5
726 746 :2 0 748
3e8 749 723 748
0 74a 3ea 0
74b 3ec 74e :3 0
74e 0 74e 74d
74b 74c :6 0 750
c :3 0 3ef 752
3f1 751 750 :2 0
753 3f3 :2 0 755
0 755 754 702
753 :6 0 769 1
:3 0 a7 :3 0 a8
:3 0 757 758 0
19 :3 0 1d :3 0
a9 :2 0 3f6 759
75d 5e :2 0 23
:2 0 3fc 75f 761
:3 0 36 :3 0 23
:2 0 763 764 0
766 3ff 767 762
766 0 768 401
0 769 403 76a
6e5 769 0 76b
406 0 10c8 52
:3 0 36 :3 0 23
:2 0 408 76c 76f
5e :2 0 f :2 0
40d 771 773 :3 0
1a :3 0 a6 :2 0
410 776 777 :3 0
778 :2 0 779 :2 0
a7 :3 0 a8 :3 0
77b 77c 0 1a
:3 0 1c :3 0 a9
:2 0 412 77d 781
5e :2 0 23 :2 0
418 783 785 :3 0
786 :2 0 77a 788
787 :2 0 1a :3 0
1c :3 0 78a 78b
0 78d 41b 78e
789 78d 0 78f
41d 0 10c5 2f
:3 0 a6 :2 0 41f
791 792 :3 0 793
:2 0 794 :2 0 1a
:3 0 a6 :2 0 421
797 798 :3 0 799
:2 0 79a :2 0 795
79c 79b :2 0 a7
:3 0 ba :3 0 79e
79f 0 2f :3 0
1a :3 0 423 7a0
7a3 cc :2 0 23
:2 0 428 7a5 7a7
:3 0 7a8 :2 0 79d
7aa 7a9 :2 0 45
:3 0 46 :3 0 7ac
7ad 0 45 :3 0
58 :3 0 7af 7b0
0 11 :2 0 2
:4 0 cd :2 0 5a
:2 0 f :2 0 42b
7b5 7b7 :3 0 42e
7b1 7b9 7ae 7bb
7ba :2 0 48 :3 0
5b :3 0 7bd 7be
0 4a :4 0 ce
:4 0 4d :2 0 4e
:3 0 432 7c2 7c4
:3 0 4d :2 0 83
:4 0 435 7c6 7c8
:3 0 4d :2 0 8c
:4 0 438 7ca 7cc
:3 0 4d :2 0 52
:3 0 56 :3 0 5f
:3 0 cf :3 0 7d1
7d2 0 43b 7d0
7d4 55 :4 0 43d
7cf 7d7 440 7ce
7d9 :3 0 4d :2 0
8e :4 0 443 7db
7dd :3 0 4d :2 0
50 :4 0 446 7df
7e1 :3 0 4d :2 0
16 :3 0 449 7e3
7e5 :3 0 4d :2 0
50 :4 0 44c 7e7
7e9 :3 0 44f 7bf
7eb :2 0 7ed 452
7ee 7bc 7ed 0
7ef 454 0 819
45 :3 0 46 :3 0
7f0 7f1 0 45
:3 0 58 :3 0 7f3
7f4 0 f :2 0
2 :4 0 d0 :2 0
5a :2 0 f :2 0
456 7f9 7fb :3 0
459 7f5 7fd 7f2
7ff 7fe :2 0 48
:3 0 5b :3 0 801
802 0 4a :4 0
d1 :4 0 4d :2 0
4e :3 0 45d 806
808 :3 0 460 803
80a :2 0 80c 463
80d 800 80c 0
80e 465 0 819
91 :3 0 92 :3 0
80f 810 0 5f
:3 0 cf :3 0 812
813 0 16 :3 0
93 :3 0 467 811
817 :2 0 819 46b
81a 7ab 819 0
81b 46f 0 10c5
5 :3 0 a6 :2 0
471 81d 81e :3 0
81f :2 0 1f :3 0
a6 :2 0 473 822
823 :3 0 824 :2 0
45 :3 0 46 :3 0
826 827 0 45
:3 0 58 :3 0 829
82a 0 11 :2 0
2 :4 0 d2 :2 0
5a :2 0 f :2 0
475 82f 831 :3 0
478 82b 833 828
835 834 :2 0 48
:3 0 5b :3 0 837
838 0 4a :4 0
d3 :4 0 4d :2 0
4e :3 0 47c 83c
83e :3 0 4d :2 0
83 :4 0 47f 840
842 :3 0 4d :2 0
8c :4 0 482 844
846 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 d4 :3 0
84b 84c 0 485
84a 84e 55 :4 0
487 849 851 48a
848 853 :3 0 4d
:2 0 8e :4 0 48d
855 857 :3 0 4d
:2 0 50 :4 0 490
859 85b :3 0 4d
:2 0 3 :3 0 493
85d 85f :3 0 4d
:2 0 50 :4 0 496
861 863 :3 0 499
839 865 :2 0 867
49c 868 836 867
0 869 49e 0
893 45 :3 0 46
:3 0 86a 86b 0
45 :3 0 58 :3 0
86d 86e 0 f
:2 0 2 :4 0 d5
:2 0 5a :2 0 f
:2 0 4a0 873 875
:3 0 4a3 86f 877
86c 879 878 :2 0
48 :3 0 5b :3 0
87b 87c 0 4a
:4 0 d6 :4 0 4d
:2 0 4e :3 0 4a7
880 882 :3 0 4aa
87d 884 :2 0 886
4ad 887 87a 886
0 888 4af 0
893 91 :3 0 92
:3 0 889 88a 0
5f :3 0 d4 :3 0
88c 88d 0 3
:3 0 93 :3 0 4b1
88b 891 :2 0 893
4b5 894 825 893
0 895 4b9 0
a07 37 :3 0 33
:3 0 896 897 0
a07 a7 :3 0 a8
:3 0 899 89a 0
19 :3 0 29 :3 0
a9 :2 0 4bb 89b
89f 5e :2 0 23
:2 0 4c1 8a1 8a3
:3 0 19 :4 0 8a5
8a6 0 8a9 d7
:3 0 4c4 a05 a7
:3 0 a8 :3 0 8aa
8ab 0 19 :3 0
1b :3 0 a9 :2 0
4c6 8ac 8b0 bb
:2 0 23 :2 0 4cc
8b2 8b4 :3 0 a7
:3 0 d8 :3 0 d9
:3 0 a7 :3 0 da
:3 0 db :3 0 dc
:3 0 dd :3 0 19
:3 0 de :3 0 96
:3 0 10 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 e0
1 :8 0 8cc c
:3 0 7c :3 0 8c7
8c8 0 7d :3 0
8c9 8ca 0 8cc
4cf 91f 7e :3 0
c :3 0 7c :3 0
8ce 8cf 0 7d
:3 0 8d0 8d1 0
8d3 4d2 8d5 4d4
8d4 8d3 :2 0 91d
7f :3 0 c :3 0
7c :3 0 8d8 8d9
0 7d :3 0 8da
8db 0 915 45
:3 0 46 :3 0 8dd
8de 0 45 :3 0
58 :3 0 8e0 8e1
0 80 :2 0 2
:4 0 e1 :2 0 5a
:2 0 f :2 0 4d6
8e6 8e8 :3 0 4d9
8e2 8ea 8df 8ec
8eb :2 0 48 :3 0
5b :3 0 8ee 8ef
0 4a :4 0 e2
:4 0 4d :2 0 4e
:3 0 4dd 8f3 8f5
:3 0 4d :2 0 83
:4 0 4e0 8f7 8f9
:3 0 4d :2 0 84
:4 0 4e3 8fb 8fd
:3 0 4d :2 0 7d
:3 0 4e6 8ff 901
:3 0 4d :2 0 85
:4 0 4e9 903 905
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 4ec
908 90c 4f0 907
90e :3 0 4f3 8f0
910 :2 0 912 4f6
913 8ed 912 0
914 4f8 0 915
4fa 918 :3 0 918
0 918 917 915
916 :6 0 91a e
:3 0 4fd 91c 4ff
91b 91a :2 0 91d
501 :2 0 91f 0
91f 91e 8cc 91d
:6 0 993 1 :3 0
c :3 0 7c :3 0
921 922 0 c
:3 0 5e :2 0 89
:3 0 924 926 0
506 925 928 :3 0
929 :2 0 a7 :3 0
d8 :3 0 df :3 0
86 :3 0 5 :3 0
a7 :3 0 da :3 0
19 :3 0 e3 :4 0
e4 1 :8 0 93a
c :3 0 7c :3 0
935 936 0 7d
:3 0 937 938 0
93a 509 98d 7e
:3 0 c :3 0 7c
:3 0 93c 93d 0
7d :3 0 93e 93f
0 941 50c 943
50e 942 941 :2 0
98b 7f :3 0 c
:3 0 7c :3 0 946
947 0 7d :3 0
948 949 0 983
45 :3 0 46 :3 0
94b 94c 0 45
:3 0 58 :3 0 94e
94f 0 80 :2 0
2 :4 0 e5 :2 0
5a :2 0 f :2 0
510 954 956 :3 0
513 950 958 94d
95a 959 :2 0 48
:3 0 5b :3 0 95c
95d 0 4a :4 0
e6 :4 0 4d :2 0
4e :3 0 517 961
963 :3 0 4d :2 0
83 :4 0 51a 965
967 :3 0 4d :2 0
84 :4 0 51d 969
96b :3 0 4d :2 0
7d :3 0 520 96d
96f :3 0 4d :2 0
85 :4 0 523 971
973 :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
526 976 97a 52a
975 97c :3 0 52d
95e 97e :2 0 980
530 981 95b 980
0 982 532 0
983 534 986 :3 0
986 0 986 985
983 984 :6 0 988
10 :3 0 537 98a
539 989 988 :2 0
98b 53b :2 0 98d
0 98d 98c 93a
98b :6 0 98f 1
:3 0 53e 990 92a
98f 0 991 540
0 993 d7 :3 0
542 994 8b5 993
0 a06 7 :3 0
bf :2 0 545 996
997 :3 0 998 :2 0
45 :3 0 46 :3 0
99a 99b 0 45
:3 0 58 :3 0 99d
99e 0 11 :2 0
2 :4 0 e7 :2 0
5a :2 0 f :2 0
547 9a3 9a5 :3 0
54a 99f 9a7 99c
9a9 9a8 :2 0 48
:3 0 5b :3 0 9ab
9ac 0 4a :4 0
e8 :4 0 4d :2 0
4e :3 0 54e 9b0
9b2 :3 0 4d :2 0
83 :4 0 551 9b4
9b6 :3 0 4d :2 0
8c :4 0 554 9b8
9ba :3 0 4d :2 0
52 :3 0 56 :3 0
23 :2 0 557 9be
9c0 55 :4 0 559
9bd 9c3 55c 9bc
9c5 :3 0 4d :2 0
8e :4 0 55f 9c7
9c9 :3 0 4d :2 0
50 :4 0 562 9cb
9cd :3 0 4d :2 0
3 :3 0 565 9cf
9d1 :3 0 4d :2 0
50 :4 0 568 9d3
9d5 :3 0 56b 9ad
9d7 :2 0 9d9 56e
9da 9aa 9d9 0
9db 570 0 a03
45 :3 0 46 :3 0
9dc 9dd 0 45
:3 0 58 :3 0 9df
9e0 0 f :2 0
2 :4 0 e9 :2 0
5a :2 0 f :2 0
572 9e5 9e7 :3 0
575 9e1 9e9 9de
9eb 9ea :2 0 48
:3 0 5b :3 0 9ed
9ee 0 4a :4 0
ea :4 0 4d :2 0
4e :3 0 579 9f2
9f4 :3 0 57c 9ef
9f6 :2 0 9f8 57f
9f9 9ec 9f8 0
9fa 581 0 a03
91 :3 0 92 :3 0
9fb 9fc 0 23
:2 0 3 :3 0 93
:3 0 583 9fd a01
:2 0 a03 587 a04
999 a03 0 a06
8a4 8a9 0 a06
58b 0 a07 58f
a0f 37 :3 0 23
:2 0 a08 a09 0
a0e 19 :4 0 a0b
a0c 0 a0e 593
a10 820 a07 0
a11 0 a0e 0
a11 596 0 10c5
7 :3 0 a6 :2 0
599 a13 a14 :3 0
a15 :2 0 5 :3 0
bf :2 0 59b a18
a19 :3 0 a1a :2 0
a1b :2 0 a7 :3 0
a8 :3 0 a1d a1e
0 1a :3 0 29
:3 0 a9 :2 0 59d
a1f a23 aa :2 0
23 :2 0 5a3 a25
a27 :3 0 a28 :2 0
a1c a2a a29 :2 0
45 :3 0 46 :3 0
a2c a2d 0 45
:3 0 58 :3 0 a2f
a30 0 11 :2 0
2 :4 0 eb :2 0
5a :2 0 f :2 0
5a6 a35 a37 :3 0
5a9 a31 a39 a2e
a3b a3a :2 0 48
:3 0 5b :3 0 a3d
a3e 0 4a :4 0
ec :4 0 4d :2 0
4e :3 0 5ad a42
a44 :3 0 4d :2 0
83 :4 0 5b0 a46
a48 :3 0 4d :2 0
8c :4 0 5b3 a4a
a4c :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 ed :3 0
a51 a52 0 5b6
a50 a54 55 :4 0
5b8 a4f a57 5bb
a4e a59 :3 0 4d
:2 0 8e :4 0 5be
a5b a5d :3 0 4d
:2 0 50 :4 0 5c1
a5f a61 :3 0 4d
:2 0 3 :3 0 5c4
a63 a65 :3 0 4d
:2 0 50 :4 0 5c7
a67 a69 :3 0 5ca
a3f a6b :2 0 a6d
5cd a6e a3c a6d
0 a6f 5cf 0
a9a 45 :3 0 46
:3 0 a70 a71 0
45 :3 0 58 :3 0
a73 a74 0 f
:2 0 2 :4 0 ee
:2 0 5a :2 0 f
:2 0 5d1 a79 a7b
:3 0 5d4 a75 a7d
a72 a7f a7e :2 0
48 :3 0 5b :3 0
a81 a82 0 4a
:4 0 ef :4 0 4d
:2 0 4e :3 0 5d8
a86 a88 :3 0 5db
a83 a8a :2 0 a8c
5de a8d a80 a8c
0 a8e 5e0 0
a9a 91 :3 0 92
:3 0 a8f a90 0
5f :3 0 ed :3 0
a92 a93 0 3
:3 0 93 :3 0 5e2
a91 a97 :2 0 a9a
d7 :3 0 5e6 b0e
2b :3 0 a6 :2 0
5ea a9c a9d :3 0
a9e :2 0 a9f :2 0
a7 :3 0 a8 :3 0
aa1 aa2 0 1a
:3 0 2b :3 0 a9
:2 0 5ec aa3 aa7
f0 :2 0 23 :2 0
5f2 aa9 aab :3 0
aac :2 0 aa0 aae
aad :2 0 45 :3 0
46 :3 0 ab0 ab1
0 45 :3 0 58
:3 0 ab3 ab4 0
f1 :2 0 2 :4 0
f2 :2 0 5a :2 0
f :2 0 5f5 ab9
abb :3 0 5f8 ab5
abd ab2 abf abe
:2 0 48 :3 0 5b
:3 0 ac1 ac2 0
4a :4 0 f3 :4 0
4d :2 0 4e :3 0
5fc ac6 ac8 :3 0
4d :2 0 83 :4 0
5ff aca acc :3 0
4d :2 0 8c :4 0
602 ace ad0 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
d4 :3 0 ad5 ad6
0 605 ad4 ad8
55 :4 0 607 ad3
adb 60a ad2 add
:3 0 60d ac3 adf
:2 0 ae1 610 ae2
ac0 ae1 0 ae3
612 0 b0c 45
:3 0 46 :3 0 ae4
ae5 0 45 :3 0
58 :3 0 ae7 ae8
0 f :2 0 2
:4 0 f4 :2 0 5a
:2 0 f :2 0 614
aed aef :3 0 617
ae9 af1 ae6 af3
af2 :2 0 48 :3 0
5b :3 0 af5 af6
0 4a :4 0 f5
:4 0 4d :2 0 4e
:3 0 61b afa afc
:3 0 61e af7 afe
:2 0 b00 621 b01
af4 b00 0 b02
623 0 b0c 91
:3 0 f6 :3 0 b03
b04 0 5f :3 0
d4 :3 0 b06 b07
0 93 :3 0 625
b05 b0a :2 0 b0c
628 b0d aaf b0c
0 b0f a2b a9a
0 b0f 62c 0
ca4 5 :3 0 bf
:2 0 62f b11 b12
:3 0 b13 :2 0 b14
:2 0 a7 :3 0 a8
:3 0 b16 b17 0
1a :3 0 1c :3 0
a9 :2 0 631 b18
b1c aa :2 0 23
:2 0 637 b1e b20
:3 0 b21 :2 0 b15
b23 b22 :2 0 3c
:3 0 f :2 0 b25
b26 0 b28 63a
b2d 3c :3 0 23
:2 0 b29 b2a 0
b2c 63c b2e b24
b28 0 b2f 0
b2c 0 b2f 63e
0 ca4 a7 :3 0
a8 :3 0 b30 b31
0 1a :3 0 2a
:3 0 a9 :2 0 641
b32 b36 5e :2 0
23 :2 0 647 b38
b3a :3 0 1a :4 0
b3c b3d 0 b40
d7 :3 0 64a ca2
a7 :3 0 ba :3 0
b41 b42 0 1a
:3 0 1c :3 0 64c
b43 b46 bb :2 0
23 :2 0 651 b48
b4a :3 0 a7 :3 0
d8 :3 0 d9 :3 0
a7 :3 0 da :3 0
db :3 0 f7 :3 0
dd :3 0 1a :3 0
de :3 0 96 :3 0
10 :3 0 d9 :3 0
df :3 0 86 :3 0
7 :4 0 f8 1
:8 0 b62 c :3 0
7c :3 0 b5d b5e
0 7d :3 0 b5f
b60 0 b62 654
bb5 7e :3 0 c
:3 0 7c :3 0 b64
b65 0 7d :3 0
b66 b67 0 b69
657 b6b 659 b6a
b69 :2 0 bb3 7f
:3 0 c :3 0 7c
:3 0 b6e b6f 0
7d :3 0 b70 b71
0 bab 45 :3 0
46 :3 0 b73 b74
0 45 :3 0 58
:3 0 b76 b77 0
80 :2 0 2 :4 0
f9 :2 0 5a :2 0
f :2 0 65b b7c
b7e :3 0 65e b78
b80 b75 b82 b81
:2 0 48 :3 0 5b
:3 0 b84 b85 0
4a :4 0 fa :4 0
4d :2 0 4e :3 0
662 b89 b8b :3 0
4d :2 0 83 :4 0
665 b8d b8f :3 0
4d :2 0 84 :4 0
668 b91 b93 :3 0
4d :2 0 7d :3 0
66b b95 b97 :3 0
4d :2 0 85 :4 0
66e b99 b9b :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 671 b9e
ba2 675 b9d ba4
:3 0 678 b86 ba6
:2 0 ba8 67b ba9
b83 ba8 0 baa
67d 0 bab 67f
bae :3 0 bae 0
bae bad bab bac
:6 0 bb0 12 :3 0
682 bb2 684 bb1
bb0 :2 0 bb3 686
:2 0 bb5 0 bb5
bb4 b62 bb3 :6 0
c29 1 :3 0 c
:3 0 7c :3 0 bb7
bb8 0 c :3 0
5e :2 0 89 :3 0
bba bbc 0 68b
bbb bbe :3 0 bbf
:2 0 a7 :3 0 d8
:3 0 df :3 0 86
:3 0 7 :3 0 a7
:3 0 da :3 0 1a
:3 0 e3 :4 0 fb
1 :8 0 bd0 c
:3 0 7c :3 0 bcb
bcc 0 7d :3 0
bcd bce 0 bd0
68e c23 7e :3 0
c :3 0 7c :3 0
bd2 bd3 0 7d
:3 0 bd4 bd5 0
bd7 691 bd9 693
bd8 bd7 :2 0 c21
7f :3 0 c :3 0
7c :3 0 bdc bdd
0 7d :3 0 bde
bdf 0 c19 45
:3 0 46 :3 0 be1
be2 0 45 :3 0
58 :3 0 be4 be5
0 80 :2 0 2
:4 0 fc :2 0 5a
:2 0 f :2 0 695
bea bec :3 0 698
be6 bee be3 bf0
bef :2 0 48 :3 0
5b :3 0 bf2 bf3
0 4a :4 0 fd
:4 0 4d :2 0 4e
:3 0 69c bf7 bf9
:3 0 4d :2 0 83
:4 0 69f bfb bfd
:3 0 4d :2 0 84
:4 0 6a2 bff c01
:3 0 4d :2 0 7d
:3 0 6a5 c03 c05
:3 0 4d :2 0 85
:4 0 6a8 c07 c09
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 6ab
c0c c10 6af c0b
c12 :3 0 6b2 bf4
c14 :2 0 c16 6b5
c17 bf1 c16 0
c18 6b7 0 c19
6b9 c1c :3 0 c1c
0 c1c c1b c19
c1a :6 0 c1e 14
:3 0 6bc c20 6be
c1f c1e :2 0 c21
6c0 :2 0 c23 0
c23 c22 bd0 c21
:6 0 c25 1 :3 0
6c3 c26 bc0 c25
0 c27 6c5 0
c29 d7 :3 0 6c7
c2a b4b c29 0
ca3 a7 :3 0 a8
:3 0 c2b c2c 0
1a :3 0 29 :3 0
a9 :2 0 6ca c2d
c31 5e :2 0 23
:2 0 6d0 c33 c35
:3 0 45 :3 0 46
:3 0 c37 c38 0
45 :3 0 58 :3 0
c3a c3b 0 11
:2 0 2 :4 0 fe
:2 0 5a :2 0 f
:2 0 6d3 c40 c42
:3 0 6d6 c3c c44
c39 c46 c45 :2 0
48 :3 0 5b :3 0
c48 c49 0 4a
:4 0 ff :4 0 4d
:2 0 4e :3 0 6da
c4d c4f :3 0 4d
:2 0 83 :4 0 6dd
c51 c53 :3 0 4d
:2 0 8c :4 0 6e0
c55 c57 :3 0 4d
:2 0 52 :3 0 56
:3 0 23 :2 0 6e3
c5b c5d 55 :4 0
6e5 c5a c60 6e8
c59 c62 :3 0 4d
:2 0 8e :4 0 6eb
c64 c66 :3 0 4d
:2 0 50 :4 0 6ee
c68 c6a :3 0 4d
:2 0 3 :3 0 6f1
c6c c6e :3 0 4d
:2 0 50 :4 0 6f4
c70 c72 :3 0 6f7
c4a c74 :2 0 c76
6fa c77 c47 c76
0 c78 6fc 0
ca0 45 :3 0 46
:3 0 c79 c7a 0
45 :3 0 58 :3 0
c7c c7d 0 f
:2 0 2 :4 0 100
:2 0 5a :2 0 f
:2 0 6fe c82 c84
:3 0 701 c7e c86
c7b c88 c87 :2 0
48 :3 0 5b :3 0
c8a c8b 0 4a
:4 0 101 :4 0 4d
:2 0 4e :3 0 705
c8f c91 :3 0 708
c8c c93 :2 0 c95
70b c96 c89 c95
0 c97 70d 0
ca0 91 :3 0 92
:3 0 c98 c99 0
23 :2 0 3 :3 0
93 :3 0 70f c9a
c9e :2 0 ca0 713
ca1 c36 ca0 0
ca3 b3b b40 0
ca3 717 0 ca4
71b ca9 1a :4 0
ca5 ca6 0 ca8
71f caa a16 ca4
0 cab 0 ca8
0 cab 721 0
10c5 17 :3 0 a
:3 0 cac cad 0
10c5 3d :3 0 23
:2 0 caf cb0 0
10c5 52 :3 0 3a
:3 0 23 :2 0 724
cb2 cb5 5f :3 0
bb :2 0 60 :3 0
cb7 cb9 0 729
cb8 cbb :3 0 79
:3 0 67 :3 0 19
:3 0 69 :3 0 1a
:3 0 c0 :3 0 7a
:3 0 3 :4 0 102
1 :8 0 cdb c2
:4 0 cc6 :3 0 93
:3 0 5e :2 0 72e
cc9 cca :3 0 c
:3 0 7c :3 0 ccc
ccd 0 23 :2 0
cce ccf 0 cd1
731 cd8 c :3 0
7c :3 0 cd2 cd3
0 c3 :2 0 cd4
cd5 0 cd7 733
cd9 ccb cd1 0
cda 0 cd7 0
cda 735 0 cdb
738 d2e 7e :3 0
c :3 0 7c :3 0
cdd cde 0 7d
:3 0 cdf ce0 0
ce2 73b ce4 73d
ce3 ce2 :2 0 d2c
7f :3 0 c :3 0
7c :3 0 ce7 ce8
0 7d :3 0 ce9
cea 0 d24 45
:3 0 46 :3 0 cec
ced 0 45 :3 0
58 :3 0 cef cf0
0 80 :2 0 2
:4 0 103 :2 0 5a
:2 0 f :2 0 73f
cf5 cf7 :3 0 742
cf1 cf9 cee cfb
cfa :2 0 48 :3 0
5b :3 0 cfd cfe
0 4a :4 0 104
:4 0 4d :2 0 4e
:3 0 746 d02 d04
:3 0 4d :2 0 83
:4 0 749 d06 d08
:3 0 4d :2 0 84
:4 0 74c d0a d0c
:3 0 4d :2 0 7d
:3 0 74f d0e d10
:3 0 4d :2 0 85
:4 0 752 d12 d14
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 755
d17 d1b 759 d16
d1d :3 0 75c cff
d1f :2 0 d21 75f
d22 cfc d21 0
d23 761 0 d24
763 d27 :3 0 d27
0 d27 d26 d24
d25 :6 0 d29 16
:3 0 766 d2b 768
d2a d29 :2 0 d2c
76a :2 0 d2e 0
d2e d2d cdb d2c
:6 0 d30 1 :3 0
76d 10c2 13 :3 0
a6 :2 0 76f d32
d33 :3 0 d34 :2 0
7 :3 0 a6 :2 0
771 d37 d38 :3 0
d39 :2 0 3d :3 0
23 :2 0 d3b d3c
0 e22 105 :3 0
3d :3 0 e3 :3 0
d9 :3 0 106 :3 0
61 :3 0 10 :3 0
7a :3 0 13 :3 0
7a :3 0 14 :3 0
d9 :3 0 df :3 0
86 :3 0 7 :4 0
107 1 :8 0 d53
c :3 0 7c :3 0
d4e d4f 0 7d
:3 0 d50 d51 0
d53 773 da6 7e
:3 0 c :3 0 7c
:3 0 d55 d56 0
7d :3 0 d57 d58
0 d5a 776 d5c
778 d5b d5a :2 0
da4 7f :3 0 c
:3 0 7c :3 0 d5f
d60 0 7d :3 0
d61 d62 0 d9c
45 :3 0 46 :3 0
d64 d65 0 45
:3 0 58 :3 0 d67
d68 0 80 :2 0
2 :4 0 108 :2 0
5a :2 0 f :2 0
77a d6d d6f :3 0
77d d69 d71 d66
d73 d72 :2 0 48
:3 0 5b :3 0 d75
d76 0 4a :4 0
109 :4 0 4d :2 0
4e :3 0 781 d7a
d7c :3 0 4d :2 0
83 :4 0 784 d7e
d80 :3 0 4d :2 0
84 :4 0 787 d82
d84 :3 0 4d :2 0
7d :3 0 78a d86
d88 :3 0 4d :2 0
85 :4 0 78d d8a
d8c :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
790 d8f d93 794
d8e d95 :3 0 797
d77 d97 :2 0 d99
79a d9a d74 d99
0 d9b 79c 0
d9c 79e d9f :3 0
d9f 0 d9f d9e
d9c d9d :6 0 da1
18 :3 0 7a1 da3
7a3 da2 da1 :2 0
da4 7a5 :2 0 da6
0 da6 da5 d53
da4 :6 0 e22 1
:3 0 52 :3 0 3d
:3 0 23 :2 0 7a8
da8 dab 5e :2 0
23 :2 0 7ad dad
daf :3 0 45 :3 0
46 :3 0 db1 db2
0 45 :3 0 58
:3 0 db4 db5 0
11 :2 0 2 :4 0
10a :2 0 5a :2 0
f :2 0 7b0 dba
dbc :3 0 7b3 db6
dbe db3 dc0 dbf
:2 0 48 :3 0 5b
:3 0 dc2 dc3 0
4a :4 0 10b :4 0
4d :2 0 4e :3 0
7b7 dc7 dc9 :3 0
4d :2 0 83 :4 0
7ba dcb dcd :3 0
4d :2 0 8c :4 0
7bd dcf dd1 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
10c :3 0 dd6 dd7
0 7c0 dd5 dd9
55 :4 0 7c2 dd4
ddc 7c5 dd3 dde
:3 0 4d :2 0 8e
:4 0 7c8 de0 de2
:3 0 4d :2 0 50
:4 0 7cb de4 de6
:3 0 4d :2 0 14
:3 0 7ce de8 dea
:3 0 4d :2 0 50
:4 0 7d1 dec dee
:3 0 7d4 dc4 df0
:2 0 df2 7d7 df3
dc1 df2 0 df4
7d9 0 e1e 45
:3 0 46 :3 0 df5
df6 0 45 :3 0
58 :3 0 df8 df9
0 f :2 0 2
:4 0 10d :2 0 5a
:2 0 f :2 0 7db
dfe e00 :3 0 7de
dfa e02 df7 e04
e03 :2 0 48 :3 0
5b :3 0 e06 e07
0 4a :4 0 10e
:4 0 4d :2 0 4e
:3 0 7e2 e0b e0d
:3 0 7e5 e08 e0f
:2 0 e11 7e8 e12
e05 e11 0 e13
7ea 0 e1e 91
:3 0 92 :3 0 e14
e15 0 5f :3 0
10c :3 0 e17 e18
0 14 :3 0 93
:3 0 7ec e16 e1c
:2 0 e1e 7f0 e1f
db0 e1e 0 e20
7f4 0 e22 d7
:3 0 7f6 1064 5
:3 0 a6 :2 0 7fa
e24 e25 :3 0 e26
:2 0 3d :3 0 23
:2 0 e28 e29 0
ff4 105 :3 0 3d
:3 0 e3 :3 0 d9
:3 0 106 :3 0 61
:3 0 10 :3 0 7a
:3 0 13 :3 0 7a
:3 0 14 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 10f
1 :8 0 e40 c
:3 0 7c :3 0 e3b
e3c 0 7d :3 0
e3d e3e 0 e40
7fc e93 7e :3 0
c :3 0 7c :3 0
e42 e43 0 7d
:3 0 e44 e45 0
e47 7ff e49 801
e48 e47 :2 0 e91
7f :3 0 c :3 0
7c :3 0 e4c e4d
0 7d :3 0 e4e
e4f 0 e89 45
:3 0 46 :3 0 e51
e52 0 45 :3 0
58 :3 0 e54 e55
0 80 :2 0 2
:4 0 110 :2 0 5a
:2 0 f :2 0 803
e5a e5c :3 0 806
e56 e5e e53 e60
e5f :2 0 48 :3 0
5b :3 0 e62 e63
0 4a :4 0 111
:4 0 4d :2 0 4e
:3 0 80a e67 e69
:3 0 4d :2 0 83
:4 0 80d e6b e6d
:3 0 4d :2 0 84
:4 0 810 e6f e71
:3 0 4d :2 0 7d
:3 0 813 e73 e75
:3 0 4d :2 0 85
:4 0 816 e77 e79
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 819
e7c e80 81d e7b
e82 :3 0 820 e64
e84 :2 0 e86 823
e87 e61 e86 0
e88 825 0 e89
827 e8c :3 0 e8c
0 e8c e8b e89
e8a :6 0 e8e 1a
:3 0 82a e90 82c
e8f e8e :2 0 e91
82e :2 0 e93 0
e93 e92 e40 e91
:6 0 ff4 1 :3 0
52 :3 0 3d :3 0
23 :2 0 831 e95
e98 5e :2 0 23
:2 0 836 e9a e9c
:3 0 45 :3 0 46
:3 0 e9e e9f 0
45 :3 0 58 :3 0
ea1 ea2 0 11
:2 0 2 :4 0 112
:2 0 5a :2 0 f
:2 0 839 ea7 ea9
:3 0 83c ea3 eab
ea0 ead eac :2 0
48 :3 0 5b :3 0
eaf eb0 0 4a
:4 0 113 :4 0 4d
:2 0 4e :3 0 840
eb4 eb6 :3 0 4d
:2 0 83 :4 0 843
eb8 eba :3 0 4d
:2 0 8c :4 0 846
ebc ebe :3 0 4d
:2 0 52 :3 0 56
:3 0 5f :3 0 10c
:3 0 ec3 ec4 0
849 ec2 ec6 55
:4 0 84b ec1 ec9
84e ec0 ecb :3 0
4d :2 0 8e :4 0
851 ecd ecf :3 0
4d :2 0 50 :4 0
854 ed1 ed3 :3 0
4d :2 0 14 :3 0
857 ed5 ed7 :3 0
4d :2 0 50 :4 0
85a ed9 edb :3 0
85d eb1 edd :2 0
edf 860 ee0 eae
edf 0 ee1 862
0 f0b 45 :3 0
46 :3 0 ee2 ee3
0 45 :3 0 58
:3 0 ee5 ee6 0
f :2 0 2 :4 0
114 :2 0 5a :2 0
f :2 0 864 eeb
eed :3 0 867 ee7
eef ee4 ef1 ef0
:2 0 48 :3 0 5b
:3 0 ef3 ef4 0
4a :4 0 115 :4 0
4d :2 0 4e :3 0
86b ef8 efa :3 0
86e ef5 efc :2 0
efe 871 eff ef2
efe 0 f00 873
0 f0b 91 :3 0
92 :3 0 f01 f02
0 5f :3 0 10c
:3 0 f04 f05 0
14 :3 0 93 :3 0
875 f03 f09 :2 0
f0b 879 ff1 116
:3 0 117 :3 0 34
:3 0 106 :3 0 61
:3 0 10 :3 0 118
:3 0 13 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 119
1 :8 0 f1e c
:3 0 7c :3 0 f19
f1a 0 7d :3 0
f1b f1c 0 f1e
87d f71 7e :3 0
c :3 0 7c :3 0
f20 f21 0 7d
:3 0 f22 f23 0
f25 880 f27 882
f26 f25 :2 0 f6f
7f :3 0 c :3 0
7c :3 0 f2a f2b
0 7d :3 0 f2c
f2d 0 f67 45
:3 0 46 :3 0 f2f
f30 0 45 :3 0
58 :3 0 f32 f33
0 80 :2 0 2
:4 0 11a :2 0 5a
:2 0 f :2 0 884
f38 f3a :3 0 887
f34 f3c f31 f3e
f3d :2 0 48 :3 0
5b :3 0 f40 f41
0 4a :4 0 11b
:4 0 4d :2 0 4e
:3 0 88b f45 f47
:3 0 4d :2 0 83
:4 0 88e f49 f4b
:3 0 4d :2 0 84
:4 0 891 f4d f4f
:3 0 4d :2 0 7d
:3 0 894 f51 f53
:3 0 4d :2 0 85
:4 0 897 f55 f57
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 89a
f5a f5e 89e f59
f60 :3 0 8a1 f42
f62 :2 0 f64 8a4
f65 f3f f64 0
f66 8a6 0 f67
8a8 f6a :3 0 f6a
0 f6a f69 f67
f68 :6 0 f6c 1c
:3 0 8ab f6e 8ad
f6d f6c :2 0 f6f
8af :2 0 f71 0
f71 f70 f1e f6f
:6 0 ff0 1 :3 0
52 :3 0 34 :3 0
23 :2 0 8b2 f73
f76 52 :3 0 aa
:2 0 33 :3 0 23
:2 0 8b5 f78 f7c
8ba f79 f7e :3 0
45 :3 0 46 :3 0
f80 f81 0 45
:3 0 58 :3 0 f83
f84 0 11 :2 0
2 :4 0 11c :2 0
5a :2 0 f :2 0
8bd f89 f8b :3 0
8c0 f85 f8d f82
f8f f8e :2 0 48
:3 0 5b :3 0 f91
f92 0 4a :4 0
11d :4 0 4d :2 0
4e :3 0 8c4 f96
f98 :3 0 4d :2 0
83 :4 0 8c7 f9a
f9c :3 0 4d :2 0
8c :4 0 8ca f9e
fa0 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 10c :3 0
fa5 fa6 0 8cd
fa4 fa8 55 :4 0
8cf fa3 fab 8d2
fa2 fad :3 0 4d
:2 0 8e :4 0 8d5
faf fb1 :3 0 4d
:2 0 50 :4 0 8d8
fb3 fb5 :3 0 4d
:2 0 14 :3 0 8db
fb7 fb9 :3 0 4d
:2 0 50 :4 0 8de
fbb fbd :3 0 8e1
f93 fbf :2 0 fc1
8e4 fc2 f90 fc1
0 fc3 8e6 0
fed 45 :3 0 46
:3 0 fc4 fc5 0
45 :3 0 58 :3 0
fc7 fc8 0 f
:2 0 2 :4 0 11e
:2 0 5a :2 0 f
:2 0 8e8 fcd fcf
:3 0 8eb fc9 fd1
fc6 fd3 fd2 :2 0
48 :3 0 5b :3 0
fd5 fd6 0 4a
:4 0 11f :4 0 4d
:2 0 4e :3 0 8ef
fda fdc :3 0 8f2
fd7 fde :2 0 fe0
8f5 fe1 fd4 fe0
0 fe2 8f7 0
fed 91 :3 0 92
:3 0 fe3 fe4 0
5f :3 0 10c :3 0
fe6 fe7 0 14
:3 0 93 :3 0 8f9
fe5 feb :2 0 fed
8fd fee f7f fed
0 fef 901 0
ff0 903 ff2 e9d
f0b 0 ff3 0
ff0 0 ff3 906
0 ff4 909 ff5
e27 ff4 0 1066
45 :3 0 46 :3 0
ff6 ff7 0 45
:3 0 58 :3 0 ff9
ffa 0 11 :2 0
2 :4 0 120 :2 0
5a :2 0 f :2 0
90d fff 1001 :3 0
910 ffb 1003 ff8
1005 1004 :2 0 48
:3 0 5b :3 0 1007
1008 0 4a :4 0
121 :4 0 4d :2 0
4e :3 0 914 100c
100e :3 0 4d :2 0
83 :4 0 917 1010
1012 :3 0 4d :2 0
8c :4 0 91a 1014
1016 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 122 :3 0
101b 101c 0 91d
101a 101e 55 :4 0
91f 1019 1021 922
1018 1023 :3 0 4d
:2 0 8e :4 0 925
1025 1027 :3 0 4d
:2 0 50 :4 0 928
1029 102b :3 0 4d
:2 0 14 :3 0 92b
102d 102f :3 0 4d
:2 0 50 :4 0 92e
1031 1033 :3 0 931
1009 1035 :2 0 1037
934 1038 1006 1037
0 1039 936 0
1063 45 :3 0 46
:3 0 103a 103b 0
45 :3 0 58 :3 0
103d 103e 0 f
:2 0 2 :4 0 123
:2 0 5a :2 0 f
:2 0 938 1043 1045
:3 0 93b 103f 1047
103c 1049 1048 :2 0
48 :3 0 5b :3 0
104b 104c 0 4a
:4 0 124 :4 0 4d
:2 0 4e :3 0 93f
1050 1052 :3 0 942
104d 1054 :2 0 1056
945 1057 104a 1056
0 1058 947 0
1063 91 :3 0 92
:3 0 1059 105a 0
5f :3 0 122 :3 0
105c 105d 0 14
:3 0 93 :3 0 949
105b 1061 :2 0 1063
94d 1065 d3a e22
0 1066 0 1063
0 1066 951 0
1067 955 1068 d35
1067 0 1069 957
0 10c1 39 :3 0
125 :2 0 106a 106b
0 10c1 14 :3 0
3 :3 0 106d 106e
0 10c1 19 :3 0
bf :2 0 959 1071
1072 :3 0 1073 :2 0
2b :3 0 a6 :2 0
95b 1076 1077 :3 0
1078 :2 0 1079 :2 0
1074 107b 107a :2 0
19 :3 0 1b :3 0
107d 107e 0 1080
95d 1081 107c 1080
0 1082 95f 0
10c1 3e :3 0 126
:3 0 10 :3 0 12
:3 0 14 :3 0 13
:3 0 19 :3 0 1a
:3 0 2b :3 0 30
:3 0 37 :3 0 3b
:3 0 35 :3 0 33
:3 0 38 :3 0 3c
:3 0 39 :3 0 29
:3 0 2a :3 0 25
:3 0 28 :3 0 31
:3 0 32 :3 0 17
:3 0 23 :2 0 961
1084 109c 1083 109d
0 10c1 3d :3 0
125 :2 0 109f 10a0
0 10c1 3e :3 0
127 :3 0 10 :3 0
14 :3 0 3d :3 0
23 :2 0 23 :2 0
979 10a3 10a9 10a2
10aa 0 10c1 13
:3 0 a6 :2 0 97f
10ad 10ae :3 0 10af
:2 0 3d :3 0 128
:2 0 10b1 10b2 0
10be 3e :3 0 127
:3 0 10 :3 0 13
:3 0 3d :3 0 23
:2 0 23 :2 0 981
10b5 10bb 10b4 10bc
0 10be 987 10bf
10b0 10be 0 10c0
98a 0 10c1 98c
10c3 cbc d30 0
10c4 0 10c1 0
10c4 995 0 10c5
998 10c6 774 10c5
0 10c7 9a0 0
10c8 9a2 10ca 5d3
647 0 10cb 0
10c8 0 10cb 9a6
0 1171 a7 :3 0
ba :3 0 10cc 10cd
0 16 :3 0 17
:3 0 9a9 10ce 10d1
5e :2 0 23 :2 0
9ae 10d3 10d5 :3 0
10d6 :2 0 52 :3 0
3a :3 0 23 :2 0
9b1 10d8 10db 5f
:3 0 bb :2 0 60
:3 0 10dd 10df 0
9b6 10de 10e1 :3 0
10e2 :2 0 10d7 10e4
10e3 :2 0 40 :3 0
bc :4 0 10e6 10e7
0 111a 3f :3 0
125 :2 0 10e9 10ea
0 111a 43 :3 0
c :3 0 7c :3 0
10ed 10ee 0 10ec
10ef 0 111a 41
:3 0 bd :3 0 40
:3 0 14 :3 0 17
:3 0 3f :3 0 23
:2 0 9b9 10f2 10f8
10f1 10f9 0 111a
c :3 0 7c :3 0
10fb 10fc 0 43
:3 0 10fd 10fe 0
111a 40 :3 0 be
:4 0 1100 1101 0
111a 3f :3 0 125
:2 0 1103 1104 0
111a 43 :3 0 c
:3 0 7c :3 0 1107
1108 0 1106 1109
0 111a 41 :3 0
bd :3 0 40 :3 0
14 :3 0 17 :3 0
3f :3 0 23 :2 0
9bf 110c 1112 110b
1113 0 111a c
:3 0 7c :3 0 1115
1116 0 43 :3 0
1117 1118 0 111a
9c5 111b 10e5 111a
0 111c 9d0 0
1171 3e :3 0 129
:3 0 10 :3 0 9d2
111e 1120 111d 1121
0 1171 45 :3 0
46 :3 0 1123 1124
0 45 :3 0 58
:3 0 1126 1127 0
12a :2 0 2 :4 0
12b :2 0 5a :2 0
f :2 0 9d4 112c
112e :3 0 9d7 1128
1130 1125 1132 1131
:2 0 48 :3 0 5b
:3 0 1134 1135 0
4a :4 0 12c :4 0
4d :2 0 4e :3 0
9db 1139 113b :3 0
4d :2 0 83 :4 0
9de 113d 113f :3 0
4d :2 0 8c :4 0
9e1 1141 1143 :3 0
4d :2 0 52 :3 0
56 :3 0 c :3 0
7c :3 0 1148 1149
0 9e4 1147 114b
55 :4 0 9e6 1146
114e 9e9 1145 1150
:3 0 4d :2 0 8e
:4 0 9ec 1152 1154
:3 0 4d :2 0 50
:4 0 9ef 1156 1158
:3 0 4d :2 0 3
:3 0 9f2 115a 115c
:3 0 4d :2 0 50
:4 0 9f5 115e 1160
:3 0 9f8 1136 1162
:2 0 1164 9fb 1165
1133 1164 0 1166
9fd 0 1171 91
:3 0 12d :3 0 1167
1168 0 c :3 0
7c :3 0 116a 116b
0 3 :3 0 93
:3 0 9ff 1169 116f
:2 0 1171 a03 1212
c :3 0 12e :2 0
4 1172 1173 0
45 :3 0 46 :3 0
1175 1176 0 45
:3 0 58 :3 0 1178
1179 0 80 :2 0
2 :4 0 12f :2 0
5a :2 0 f :2 0
a1e 117e 1180 :3 0
a21 117a 1182 1177
1184 1183 :2 0 48
:3 0 5b :3 0 1186
1187 0 4a :4 0
130 :4 0 4d :2 0
4e :3 0 a25 118b
118d :3 0 a28 1188
118f :2 0 11a8 48
:3 0 5b :3 0 1191
1192 0 4a :4 0
131 :4 0 4d :2 0
c :3 0 b3 :3 0
1197 1198 0 a2b
1196 119a :3 0 4d
:2 0 8e :4 0 a2e
119c 119e :3 0 4d
:2 0 c :3 0 132
:3 0 11a1 11a2 0
a31 11a0 11a4 :3 0
a34 1193 11a6 :2 0
11a8 a37 11a9 1185
11a8 0 11aa a3a
0 11ba 133 :3 0
44 :3 0 c :3 0
b3 :3 0 134 :3 0
c :3 0 132 :3 0
3 :3 0 e3 :4 0
135 1 :a 0 11b6
:2 0 11ba 11ac 11b4
:2 0 b :3 0 44
:3 0 11b8 :2 0 11ba
a3c 11bc a40 11bb
11ba :2 0 1210 7f
:3 0 c :3 0 7c
:3 0 11bf 11c0 0
7d :3 0 11c1 11c2
0 1208 45 :3 0
46 :3 0 11c4 11c5
0 45 :3 0 58
:3 0 11c7 11c8 0
80 :2 0 2 :4 0
136 :2 0 5a :2 0
f :2 0 a42 11cd
11cf :3 0 a45 11c9
11d1 11c6 11d3 11d2
:2 0 48 :3 0 5b
:3 0 11d5 11d6 0
4a :4 0 137 :4 0
4d :2 0 4e :3 0
a49 11da 11dc :3 0
a4c 11d7 11de :2 0
11f8 48 :3 0 5b
:3 0 11e0 11e1 0
4a :4 0 84 :4 0
4d :2 0 7d :3 0
a4f 11e5 11e7 :3 0
4d :2 0 85 :4 0
a52 11e9 11eb :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 a55 11ee
11f2 a59 11ed 11f4
:3 0 a5c 11e2 11f6
:2 0 11f8 a5f 11f9
11d4 11f8 0 11fa
a62 0 1208 133
:3 0 44 :3 0 134
:3 0 c :3 0 132
:3 0 3 :3 0 e3
:4 0 138 1 :a 0
1204 :2 0 1208 11fc
1202 :2 0 b :3 0
44 :3 0 1206 :2 0
1208 a64 120b :3 0
120b 0 120b 120a
1208 1209 :6 0 120d
1 :3 0 a69 120f
a6b 120e 120d :2 0
1210 a6d :2 0 1212
a70 1212 1211 1171
1210 :6 0 1213 :2 0
2 1c 1212 1216
:3 0 1215 1213 1217
:8 0 
aa0
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 27 1
25 1 2e 1
2c 1 35 1
33 1 3c 1
3a 1 43 1
41 1 4a 1
48 1 51 1
4f 1 58 1
56 1 5d 1
62 1 67 1
6c 1 71 1
76 1 7b 1
82 1 80 1
87 1 8d 1
93 1 99 1
9f 1 a4 1
a9 1 ae 1
b3 1 b8 1
bf 1 bd 1
c4 1 ca 1
d0 1 d6 1
dc 1 e2 1
e8 1 ee 1
f4 1 fa 1
100 1 106 1
10c 1 112 1
118 1 120 1
11e 1 125 1
12a 1 130 1
13d 1 149 2
14c 14e 2 151
153 2 155 157
2 159 15b 2
15d 15f 2 165
167 2 169 16b
2 16d 16e 2
170 171 2 161
173 2 175 177
2 17d 17f 2
181 183 2 185
186 2 188 189
2 179 18b 2
18d 18f 1 195
2 197 198 2
191 19a 2 19c
19e 2 1a0 1a2
2 1a4 1a6 2
1a8 1aa 2 1ac
1ae 4 145 14b
150 1b0 1 1b2
1 1b4 2 1be
1c0 3 1bc 1bd
1c2 2 1cb 1cd
2 1ca 1cf 1
1d1 1 1d3 2
1eb 1ec 1 1f0
2 1ee 1f0 1
1f8 1 1fa 2
233 238 1 23f
1 23a 2 252
254 3 250 251
256 2 25f 261
2 263 265 2
267 269 2 26b
26d 2 26f 271
3 276 277 278
2 273 27a 2
25e 27c 1 27e
1 280 2 249
281 1 285 1
244 2 242 289
1 294 2 290
294 2 2a0 2a2
3 29e 29f 2a4
2 2ad 2af 2
2b1 2b3 2 2b5
2b7 1 2bf 2
2c1 2c2 2 2b9
2c4 2 2c6 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2ac 2d6
1 2d8 1 2da
2 2e4 2e6 3
2e2 2e3 2e8 2
2f1 2f3 2 2f0
2f5 1 2f7 1
2f9 3 300 301
302 3 2db 2fa
304 1 306 2
30f 314 1 31b
1 316 2 32e
330 3 32c 32d
332 2 33b 33d
2 33f 341 2
343 345 2 347
349 2 34b 34d
3 352 353 354
2 34f 356 2
33a 358 1 35a
1 35c 2 325
35d 1 361 1
320 2 31e 365
3 36b 36c 36d
1 371 2 36f
371 2 37c 37e
3 37a 37b 380
2 389 38b 2
38d 38f 2 391
393 1 39b 2
39d 39e 2 395
3a0 2 3a2 3a4
2 3a6 3a8 2
3aa 3ac 2 3ae
3b0 2 388 3b2
1 3b4 1 3b6
2 3c0 3c2 3
3be 3bf 3c4 2
3cd 3cf 2 3cc
3d1 1 3d3 1
3d5 3 3dc 3dd
3de 3 3b7 3d6
3e0 1 3e2 2
3e5 3e6 1 3ea
2 3e8 3ea 2
3f5 3f7 3 3f3
3f4 3f9 2 402
404 2 406 408
2 40a 40c 1
414 2 416 417
2 40e 419 2
41b 41d 2 41f
421 2 423 425
2 427 429 2
401 42b 1 42d
1 42f 2 439
43b 3 437 438
43d 2 446 448
2 445 44a 1
44c 1 44e 3
455 456 457 3
430 44f 459 1
45b 1 45d 1
463 3 46e 46f
470 1 474 2
472 474 2 47f
481 3 47d 47e
483 2 48c 48e
2 490 492 2
494 496 1 49e
2 4a0 4a1 2
498 4a3 2 4a5
4a7 2 4a9 4ab
2 4ad 4af 2
4b1 4b3 2 48b
4b5 1 4b7 1
4b9 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4cf 4d4 1 4d6
1 4d8 3 4df
4e0 4e1 3 4ba
4d9 4e3 1 4e5
1 4e6 1 4e8
2 4fc 501 1
508 1 503 2
51b 51d 3 519
51a 51f 2 528
52a 2 52c 52e
2 530 532 2
534 536 2 538
53a 3 53f 540
541 2 53c 543
2 527 545 1
547 1 549 2
512 54a 1 54e
1 50d 2 50b
552 2 55d 55e
1 562 2 560
562 2 567 568
1 56e 2 56a
56e 5 581 582
583 584 585 5
59b 59c 59d 59e
59f a 576 579
57e 588 58d 590
593 598 5a2 5a7
1 5a9 1 5ab
3 5b4 5b5 5b6
1 5ba 2 5b8
5ba 1 5c2 1
5c4 1 5c6 1
5cc 1 5df 2
5de 5df 1 5e7
1 5ed 2 5ef
5f0 2 5dc 5f1
1 5f8 1 5f3
2 60b 60d 3
609 60a 60f 2
618 61a 2 61c
61e 2 620 622
2 624 626 2
628 62a 3 62f
630 631 2 62c
633 2 617 635
1 637 1 639
2 602 63a 1
63e 1 5fd 2
5fb 642 1 645
1 648 1 64d
1 65d 2 65c
65d 1 665 1
66b 2 66d 66e
2 65a 66f 1
676 1 671 2
689 68b 3 687
688 68d 2 696
698 2 69a 69c
2 69e 6a0 2
6a2 6a4 2 6a6
6a8 3 6ad 6ae
6af 2 6aa 6b1
2 695 6b3 1
6b5 1 6b7 2
680 6b8 1 6bc
1 67b 2 679
6c0 3 6c8 6c9
6ca 1 6ce 2
6cc 6ce 1 6d3
1 6d5 2 6c3
6d6 1 6d8 1
6da 1 6df 1
6ef 2 6ee 6ef
1 6f7 1 6fd
2 6ff 700 2
6ec 701 1 708
1 703 2 71b
71d 3 719 71a
71f 2 728 72a
2 72c 72e 2
730 732 2 734
736 2 738 73a
3 73f 740 741
2 73c 743 2
727 745 1 747
1 749 2 712
74a 1 74e 1
70d 2 70b 752
3 75a 75b 75c
1 760 2 75e
760 1 765 1
767 2 755 768
1 76a 2 76d
76e 1 772 2
770 772 1 775
3 77e 77f 780
1 784 2 782
784 1 78c 1
78e 1 790 1
796 2 7a1 7a2
1 7a6 2 7a4
7a6 2 7b4 7b6
3 7b2 7b3 7b8
2 7c1 7c3 2
7c5 7c7 2 7c9
7cb 1 7d3 2
7d5 7d6 2 7cd
7d8 2 7da 7dc
2 7de 7e0 2
7e2 7e4 2 7e6
7e8 2 7c0 7ea
1 7ec 1 7ee
2 7f8 7fa 3
7f6 7f7 7fc 2
805 807 2 804
809 1 80b 1
80d 3 814 815
816 3 7ef 80e
818 1 81a 1
81c 1 821 2
82e 830 3 82c
82d 832 2 83b
83d 2 83f 841
2 843 845 1
84d 2 84f 850
2 847 852 2
854 856 2 858
85a 2 85c 85e
2 860 862 2
83a 864 1 866
1 868 2 872
874 3 870 871
876 2 87f 881
2 87e 883 1
885 1 887 3
88e 88f 890 3
869 888 892 1
894 3 89c 89d
89e 1 8a2 2
8a0 8a2 1 8a7
3 8ad 8ae 8af
1 8b3 2 8b1
8b3 2 8c6 8cb
1 8d2 1 8cd
2 8e5 8e7 3
8e3 8e4 8e9 2
8f2 8f4 2 8f6
8f8 2 8fa 8fc
2 8fe 900 2
902 904 3 909
90a 90b 2 906
90d 2 8f1 90f
1 911 1 913
2 8dc 914 1
918 1 8d7 2
8d5 91c 1 927
2 923 927 2
934 939 1 940
1 93b 2 953
955 3 951 952
957 2 960 962
2 964 966 2
968 96a 2 96c
96e 2 970 972
3 977 978 979
2 974 97b 2
95f 97d 1 97f
1 981 2 94a
982 1 986 1
945 2 943 98a
1 98d 1 990
2 91f 991 1
995 2 9a2 9a4
3 9a0 9a1 9a6
2 9af 9b1 2
9b3 9b5 2 9b7
9b9 1 9bf 2
9c1 9c2 2 9bb
9c4 2 9c6 9c8
2 9ca 9cc 2
9ce 9d0 2 9d2
9d4 2 9ae 9d6
1 9d8 1 9da
2 9e4 9e6 3
9e2 9e3 9e8 2
9f1 9f3 2 9f0
9f5 1 9f7 1
9f9 3 9fe 9ff
a00 3 9db 9fa
a02 3 a05 994
a04 3 895 898
a06 2 a0a a0d
2 a0f a10 1
a12 1 a17 3
a20 a21 a22 1
a26 2 a24 a26
2 a34 a36 3
a32 a33 a38 2
a41 a43 2 a45
a47 2 a49 a4b
1 a53 2 a55
a56 2 a4d a58
2 a5a a5c 2
a5e a60 2 a62
a64 2 a66 a68
2 a40 a6a 1
a6c 1 a6e 2
a78 a7a 3 a76
a77 a7c 2 a85
a87 2 a84 a89
1 a8b 1 a8d
3 a94 a95 a96
3 a6f a8e a98
1 a9b 3 aa4
aa5 aa6 1 aaa
2 aa8 aaa 2
ab8 aba 3 ab6
ab7 abc 2 ac5
ac7 2 ac9 acb
2 acd acf 1
ad7 2 ad9 ada
2 ad1 adc 2
ac4 ade 1 ae0
1 ae2 2 aec
aee 3 aea aeb
af0 2 af9 afb
2 af8 afd 1
aff 1 b01 2
b08 b09 3 ae3
b02 b0b 2 b0e
b0d 1 b10 3
b19 b1a b1b 1
b1f 2 b1d b1f
1 b27 1 b2b
2 b2d b2e 3
b33 b34 b35 1
b39 2 b37 b39
1 b3e 2 b44
b45 1 b49 2
b47 b49 2 b5c
b61 1 b68 1
b63 2 b7b b7d
3 b79 b7a b7f
2 b88 b8a 2
b8c b8e 2 b90
b92 2 b94 b96
2 b98 b9a 3
b9f ba0 ba1 2
b9c ba3 2 b87
ba5 1 ba7 1
ba9 2 b72 baa
1 bae 1 b6d
2 b6b bb2 1
bbd 2 bb9 bbd
2 bca bcf 1
bd6 1 bd1 2
be9 beb 3 be7
be8 bed 2 bf6
bf8 2 bfa bfc
2 bfe c00 2
c02 c04 2 c06
c08 3 c0d c0e
c0f 2 c0a c11
2 bf5 c13 1
c15 1 c17 2
be0 c18 1 c1c
1 bdb 2 bd9
c20 1 c23 1
c26 2 bb5 c27
3 c2e c2f c30
1 c34 2 c32
c34 2 c3f c41
3 c3d c3e c43
2 c4c c4e 2
c50 c52 2 c54
c56 1 c5c 2
c5e c5f 2 c58
c61 2 c63 c65
2 c67 c69 2
c6b c6d 2 c6f
c71 2 c4b c73
1 c75 1 c77
2 c81 c83 3
c7f c80 c85 2
c8e c90 2 c8d
c92 1 c94 1
c96 3 c9b c9c
c9d 3 c78 c97
c9f 3 ca2 c2a
ca1 3 b0f b2f
ca3 1 ca7 2
ca9 caa 2 cb3
cb4 1 cba 2
cb6 cba 1 cc8
2 cc7 cc8 1
cd0 1 cd6 2
cd8 cd9 2 cc5
cda 1 ce1 1
cdc 2 cf4 cf6
3 cf2 cf3 cf8
2 d01 d03 2
d05 d07 2 d09
d0b 2 d0d d0f
2 d11 d13 3
d18 d19 d1a 2
d15 d1c 2 d00
d1e 1 d20 1
d22 2 ceb d23
1 d27 1 ce6
2 ce4 d2b 1
d2e 1 d31 1
d36 2 d4d d52
1 d59 1 d54
2 d6c d6e 3
d6a d6b d70 2
d79 d7b 2 d7d
d7f 2 d81 d83
2 d85 d87 2
d89 d8b 3 d90
d91 d92 2 d8d
d94 2 d78 d96
1 d98 1 d9a
2 d63 d9b 1
d9f 1 d5e 2
d5c da3 2 da9
daa 1 dae 2
dac dae 2 db9
dbb 3 db7 db8
dbd 2 dc6 dc8
2 dca dcc 2
dce dd0 1 dd8
2 dda ddb 2
dd2 ddd 2 ddf
de1 2 de3 de5
2 de7 de9 2
deb ded 2 dc5
def 1 df1 1
df3 2 dfd dff
3 dfb dfc e01
2 e0a e0c 2
e09 e0e 1 e10
1 e12 3 e19
e1a e1b 3 df4
e13 e1d 1 e1f
3 d3d da6 e20
1 e23 2 e3a
e3f 1 e46 1
e41 2 e59 e5b
3 e57 e58 e5d
2 e66 e68 2
e6a e6c 2 e6e
e70 2 e72 e74
2 e76 e78 3
e7d e7e e7f 2
e7a e81 2 e65
e83 1 e85 1
e87 2 e50 e88
1 e8c 1 e4b
2 e49 e90 2
e96 e97 1 e9b
2 e99 e9b 2
ea6 ea8 3 ea4
ea5 eaa 2 eb3
eb5 2 eb7 eb9
2 ebb ebd 1
ec5 2 ec7 ec8
2 ebf eca 2
ecc ece 2 ed0
ed2 2 ed4 ed6
2 ed8 eda 2
eb2 edc 1 ede
1 ee0 2 eea
eec 3 ee8 ee9
eee 2 ef7 ef9
2 ef6 efb 1
efd 1 eff 3
f06 f07 f08 3
ee1 f00 f0a 2
f18 f1d 1 f24
1 f1f 2 f37
f39 3 f35 f36
f3b 2 f44 f46
2 f48 f4a 2
f4c f4e 2 f50
f52 2 f54 f56
3 f5b f5c f5d
2 f58 f5f 2
f43 f61 1 f63
1 f65 2 f2e
f66 1 f6a 1
f29 2 f27 f6e
2 f74 f75 2
f7a f7b 1 f7d
2 f77 f7d 2
f88 f8a 3 f86
f87 f8c 2 f95
f97 2 f99 f9b
2 f9d f9f 1
fa7 2 fa9 faa
2 fa1 fac 2
fae fb0 2 fb2
fb4 2 fb6 fb8
2 fba fbc 2
f94 fbe 1 fc0
1 fc2 2 fcc
fce 3 fca fcb
fd0 2 fd9 fdb
2 fd8 fdd 1
fdf 1 fe1 3
fe8 fe9 fea 3
fc3 fe2 fec 1
fee 2 f71 fef
2 ff1 ff2 3
e2a e93 ff3 2
ffe 1000 3 ffc
ffd 1002 2 100b
100d 2 100f 1011
2 1013 1015 1
101d 2 101f 1020
2 1017 1022 2
1024 1026 2 1028
102a 2 102c 102e
2 1030 1032 2
100a 1034 1 1036
1 1038 2 1042
1044 3 1040 1041
1046 2 104f 1051
2 104e 1053 1
1055 1 1057 3
105e 105f 1060 3
1039 1058 1062 3
1064 ff5 1065 1
1066 1 1068 1
1070 1 1075 1
107f 1 1081 17
1085 1086 1087 1088
1089 108a 108b 108c
108d 108e 108f 1090
1091 1092 1093 1094
1095 1096 1097 1098
1099 109a 109b 5
10a4 10a5 10a6 10a7
10a8 1 10ac 5
10b6 10b7 10b8 10b9
10ba 2 10b3 10bd
1 10bf 8 1069
106c 106f 1082 109e
10a1 10ab 10c0 2
10c2 10c3 7 78f
81b a11 cab cae
cb1 10c4 1 10c6
3 6d9 76b 10c7
2 10c9 10ca 2
10cf 10d0 1 10d4
2 10d2 10d4 2
10d9 10da 1 10e0
2 10dc 10e0 5
10f3 10f4 10f5 10f6
10f7 5 110d 110e
110f 1110 1111 a
10e8 10eb 10f0 10fa
10ff 1102 1105 110a
1114 1119 1 111b
1 111f 2 112b
112d 3 1129 112a
112f 2 1138 113a
2 113c 113e 2
1140 1142 1 114a
2 114c 114d 2
1144 114f 2 1151
1153 2 1155 1157
2 1159 115b 2
115d 115f 2 1137
1161 1 1163 1
1165 3 116c 116d
116e 1a 1b5 1d4
1d7 1da 1dd 1e0
1e3 1e6 1e9 1fb
28c 307 368 3e3
45c 4e9 4ec 555
559 5aa 5c5 10cb
111c 1122 1166 1170
2 117d 117f 3
117b 117c 1181 2
118a 118c 2 1189
118e 2 1195 1199
2 119b 119d 2
119f 11a3 2 1194
11a5 2 1190 11a7
1 11a9 3 11aa
11b5 11b9 1 1174
2 11cc 11ce 3
11ca 11cb 11d0 2
11d9 11db 2 11d8
11dd 2 11e4 11e6
2 11e8 11ea 3
11ef 11f0 11f1 2
11ec 11f3 2 11e3
11f5 2 11df 11f7
1 11f9 4 11c3
11fa 1203 1207 1
120b 1 11be 2
11bc 120f 2f 23
2a 31 38 3f
46 4d 54 5b
60 65 6a 6f
74 79 7e 85
8b 91 97 9d
a2 a7 ac b1
b6 bb c2 c8
ce d4 da e0
e6 ec f2 f8
fe 104 10a 110
116 11c 123 128
12e 135 
1
4
0 
1216
0
1
28
1e
35
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 0 0
0 0 0 0 0 0 0 0

13 1 0
100 1 0
10c 1 0
76 1 0
3 1 0
87 1 0
62 1 0
3a 1 0
33 1 0
d0 1 0
118 1 0
99 1 0
fa 1 0
125 1 0
b3 1 0
112 1 0
a9 1 0
e8 1 0
67 1 0
1e 1 0
9f 1 0
5d 1 0
11e 1 0
c4 1 0
56 1 0
f4 1 0
dc 1 0
6c 1 0
106 1 0
d6 1 0
41 1 0
ca 1 0
2c 1 0
80 1 0
ae 1 0
a4 1 0
7b 1 0
12a 1 0
7 1 0
bd 1 0
b8 1 0
8d 1 0
48 1 0
25 1 0
2 0 1
71 1 0
f 1 0
93 1 0
e2 1 0
4f 1 0
ee 1 0
b 1 0
130 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_FORECAST;
ALTER FUNCTION SP_U_WP_FORECAST COMPILE DEBUG;
/*****************************************************************************/
Prompt == FUNCTION SP_U_ASSIGN_DESCR ==
CREATE OR REPLACE FUNCTION SP_U_ASSIGN_DESCR wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
57
2 :e:
1FUNCTION:
1SP_U_ASSIGN_DESCR:
1PRJ_ID:
1VARCHAR2:
1RES_ID001:
1DESCRIPTION001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_ASSIGN_DESCR(:
1':
1, :
1);:
1CHECK_TRACE:
11:
120:
1+:
1FPUT:
1               ENTER:: SP_U_ASSIGN_DESCR(21) :: cplan.sql(22368) :: :
1IS NULL:
132:
125:
1        RETURN_ERROR:: SP_U_ASSIGN_DESCR(26) :: cplan.sql(22373) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1 ID:: :
128:
1                EXIT:: SP_U_ASSIGN_DESCR(29) :: cplan.sql(22376) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1PROJECT_ASSIGNMENTS:
1DESCRIPTION:
1RESOURCE_ID:
1PROJECT_ID:
1UPDATE PROJECT_ASSIGNMENTS:n      SET DESCRIPTION = description001:n      WHE+
1RE RESOURCE_ID = res_id001:n      AND PROJECT_ID = prj_id:
1FOUND:
1=:
1SC_STATE:
10:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
151:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(52) :: cplan.sql(22399) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
157:
1       RETURN_STATUS:: SP_U_ASSIGN_DESCR(58) :: cplan.sql(22405) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
164:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(65) :: cplan.sql(22412) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
176:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(77) :: cplan.sql(22424) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
283
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
283
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 9b 83 87 8b 8e 96
82 a2 a6 7f aa ae b2 b5
ba bb 1 bd c2 c6 ca cd
d2 d6 da dd e2 e3 e5 ea
ed f1 f2 f7 fc ff 104 105
10a 10d 111 112 117 11a 11f 120
125 128 12d 12e 133 136 13b 13c
141 144 148 149 14e 151 156 157
15c 15f 164 165 16a 16d 172 173
178 17b 17f 180 185 188 18d 18e
193 196 19b 19c 1a1 1a4 1a9 1aa
1af 1b2 1b6 1b7 1bc 1bf 1c4 1c5
1ca 1cd 1d2 1d3 1d8 1d9 1de 1e0
1e4 1e7 1eb 1ef 1f2 1f6 1fa 1fd
200 205 208 20b 20e 20f 214 215
1 217 21c 220 224 227 22c 231
234 238 239 23e 23f 244 246 24a
24d 251 254 255 25a 25d 261 264
265 26a 1 26d 272 276 27a 27d
281 285 288 28b 290 293 296 299
29a 29f 2a0 1 2a2 2a7 2ab 2af
2b2 2b7 2bc 2bf 2c3 2c4 2c9 2cc
2d1 2d2 2d7 2da 2df 2e0 2e5 2e8
2ec 2f0 2f4 2f8 2fb 2fc 2fe 303
304 306 307 30c 30f 314 315 31a
31d 322 323 328 32b 32f 330 335
338 33d 33e 343 344 349 34b 34f
352 356 35a 35d 361 365 368 36b
370 373 376 379 37a 37f 380 1
382 387 38b 38f 392 397 39c 39f
3a3 3a4 3a9 3aa 3af 3b1 3b5 3b8
3bc 3c0 3c3 3c7 3cb 3ce 3d2 3d6
3d7 3dc 3de 3e2 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 40d 411 416 41a
41d 41e 423 427 42b 42e 431 435
437 43b 43f 442 445 449 44b 44f
453 456 458 45c 460 464 467 46b
46f 471 472 477 1 47b 47f 483
486 48a 48e 492 496 499 49d 4a1
4a4 4a7 4ac 4af 4b2 4b5 4b6 4bb
4bc 1 4be 4c3 4c7 4cb 4ce 4d3
4d8 4db 4df 4e0 4e5 4e8 4ed 4ee
4f3 4f6 4fb 4fc 501 504 508 509
50e 511 516 517 51c 51f 523 527
52a 52d 52e 530 531 536 537 53c
53e 542 545 547 54b 54d 559 55b
55d 55e 563 567 569 575 577 57b
57f 582 586 58a 58d 590 595 598
59b 59e 59f 5a4 5a5 1 5a7 5ac
5b0 5b4 5b7 5bc 5c1 5c4 5c8 5c9
5ce 5d1 5d6 5d7 5dc 5df 5e4 5e5
5ea 5ed 5f1 5f5 5f9 5fd 600 601
603 608 609 60b 60c 611 614 619
61a 61f 622 627 628 62d 630 634
635 63a 63d 642 643 648 649 64e
650 654 657 65b 65f 662 666 66a
66d 671 675 676 67b 67d 681 685
688 68c 690 693 697 69b 69e 6a1
6a6 6a9 6ac 6af 6b0 6b5 6b6 1
6b8 6bd 6c1 6c5 6c8 6cd 6d2 6d5
6d9 6da 6df 6e0 6e5 6e9 6ed 6f0
6f5 6fa 6fd 701 705 708 709 70e
711 716 717 71c 71f 723 727 72a
72b 730 731 736 738 73c 73f 743
747 74b 74f 753 757 75b 75f 763
76f 774 778 77c 780 784 786 787
78c 1 790 794 798 79b 79f 7a3
7a7 7ab 7ae 7b2 7b6 7b9 7bc 7c1
7c4 7c7 7ca 7cb 7d0 7d1 1 7d3
7d8 7dc 7e0 7e3 7e8 7ed 7f0 7f4
7f5 7fa 7fb 800 804 808 80b 810
815 818 81c 81d 822 825 82a 82b
830 833 837 83b 83e 841 842 844
845 84a 84b 850 852 856 859 85d
861 865 869 86d 871 875 881 886
88a 88e 892 896 898 89c 89e 8aa
8ac 8ae 8af 8b4 8b8 8ba 8c6 8ca
8cc 8cd 8d6 
283
2
0 1 a 6 d :3 6 10 :3 6
15 :3 6 12 :2 6 1 3 a 13
a :2 1 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 59 5f 62 :2 59
70 8b 8 :2 70 d 10 :2 70 17
1a :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 b e
:2 70 13 16 :2 70 1b 1e :2 70 2d
30 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 2a 2d :2 70 32 35
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:2 4 :4 8 7 :4 1c 1b :2 7 a :2 14
26 :2 30 3c 40 55 57 58 :2 55
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 b7 :2 8c :2 21 bf
c2 :2 21 ca cd :2 21 d2 d5 :2 21
dc df :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 54 56 57 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 3f 47
:2 7 2f :2 4 e b 19 d 1b
b 18 7 e a 16 :3 14 a
:2 13 1f a 1b a :2 13 1f a
:4 7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 58 5a 5b :2 58
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 11 23 :2 2d 39
3c 51 53 54 :2 51 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e 72 75 :2 1e
79 7c :2 1e 86 89 92 9a :2 a3
:2 92 ae :2 89 :2 1e b6 b9 :2 1e c1
c4 :2 1e c9 cc :2 1e d3 d6 :2 1e
:2 7 57 :3 4 :2 f 21 :2 2a 34 3c
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 55 57 58 :2 55 :2 26
:3 a :2 10 15 21 65 68 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5b
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 62 65 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 58 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
283
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:2 f :2 d :2 f :2 d
:2 f :2 d :2 10 :2 d
:2 10 :2 d :2 10 :2 d
:2 10 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :4 d
:3 c :11 14 :b 15 :3 14
:c 18 :11 19 :30 1a :3 19
:11 1c :b 1d :3 1c :a 1f
:3 18 24 :2 25 :2 26
:2 27 24 :6 28 :5 29
28 :5 2b 2a :3 28
23 2e :5 2f :3 2e
:2 30 :5 32 :11 33 :24 34
:3 33 :2 31 :6 30 2d
:3 b :11 39 :30 3a :3 39
:a 3c b :3 3f :11 40
:b 41 :17 42 :3 40 :2 44
:3 45 :3 46 47 45
44 45 :3 48 :3 3f
:2 49 :5 4b :11 4c :b 4d
:18 4e :3 4c :2 50 51
:3 52 53 51 50
51 :3 54 :2 4a :6 49
3e :7 1 
8d8
4
:3 0 1 :3 0 2
:a 0 27e 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 27e 2
18 :2 0 21 22
0 10 9 :3 0
a :2 0 4 1b
1c 0 1d :7 0
20 1e 0 27c
0 b :6 0 c
:3 0 d :3 0 c
:3 0 e :3 0 24
25 0 2 :4 0
12 26 28 23
2a 29 :2 0 f
:3 0 10 :3 0 2c
2d 0 11 :4 0
c :3 0 12 :3 0
30 31 0 2
:4 0 14 32 34
13 :4 0 14 :2 0
15 :3 0 16 37
39 :3 0 16 :4 0
14 :2 0 17 :4 0
19 3c 3e :3 0
14 :2 0 3 :3 0
1c 40 42 :3 0
14 :2 0 17 :4 0
1f 44 46 :3 0
14 :2 0 18 :4 0
22 48 4a :3 0
14 :2 0 17 :4 0
25 4c 4e :3 0
14 :2 0 5 :3 0
28 50 52 :3 0
14 :2 0 17 :4 0
2b 54 56 :3 0
14 :2 0 18 :4 0
2e 58 5a :3 0
14 :2 0 17 :4 0
31 5c 5e :3 0
14 :2 0 6 :3 0
34 60 62 :3 0
14 :2 0 17 :4 0
37 64 66 :3 0
14 :2 0 18 :4 0
3a 68 6a :3 0
14 :2 0 17 :4 0
3d 6c 6e :3 0
14 :2 0 7 :3 0
40 70 72 :3 0
14 :2 0 17 :4 0
43 74 76 :3 0
14 :2 0 19 :4 0
46 78 7a :3 0
49 2e 7c :2 0
7e 4e 7f 2b
7e 0 80 50
0 1dc c :3 0
d :3 0 81 82
0 c :3 0 1a
:3 0 84 85 0
1b :2 0 2 :4 0
1c :2 0 1d :2 0
1b :2 0 52 8a
8c :3 0 55 86
8e 83 90 8f
:2 0 f :3 0 1e
:3 0 92 93 0
11 :4 0 1f :4 0
14 :2 0 15 :3 0
59 97 99 :3 0
5c 94 9b :2 0
9d 5f 9e 91
9d 0 9f 61
0 1dc 3 :3 0
20 :2 0 63 a1
a2 :3 0 a3 :2 0
5 :3 0 20 :2 0
65 a6 a7 :3 0
a8 :2 0 a4 aa
a9 :2 0 c :3 0
d :3 0 ac ad
0 c :3 0 1a
:3 0 af b0 0
21 :2 0 2 :4 0
22 :2 0 1d :2 0
1b :2 0 67 b5
b7 :3 0 6a b1
b9 ae bb ba
:2 0 f :3 0 1e
:3 0 bd be 0
11 :4 0 23 :4 0
14 :2 0 15 :3 0
6e c2 c4 :3 0
14 :2 0 24 :4 0
71 c6 c8 :3 0
14 :2 0 25 :4 0
74 ca cc :3 0
14 :2 0 26 :3 0
27 :3 0 28 :3 0
29 :3 0 d1 d2
0 77 d0 d4
2a :4 0 79 cf
d7 7c ce d9
:3 0 14 :2 0 2b
:4 0 7f db dd
:3 0 14 :2 0 17
:4 0 82 df e1
:3 0 14 :2 0 3
:3 0 85 e3 e5
:3 0 14 :2 0 17
:4 0 88 e7 e9
:3 0 8b bf eb
:2 0 ed 8e ee
bc ed 0 ef
90 0 119 c
:3 0 d :3 0 f0
f1 0 c :3 0
1a :3 0 f3 f4
0 1b :2 0 2
:4 0 2c :2 0 1d
:2 0 1b :2 0 92
f9 fb :3 0 95
f5 fd f2 ff
fe :2 0 f :3 0
1e :3 0 101 102
0 11 :4 0 2d
:4 0 14 :2 0 15
:3 0 99 106 108
:3 0 9c 103 10a
:2 0 10c 9f 10d
100 10c 0 10e
a1 0 119 2e
:3 0 2f :3 0 10f
110 0 28 :3 0
29 :3 0 112 113
0 3 :3 0 30
:3 0 a3 111 117
:2 0 119 a7 11a
ab 119 0 11b
ab 0 1dc 31
:3 0 32 :3 0 6
:3 0 33 :3 0 5
:3 0 34 :3 0 3
:4 0 35 1 :8 0
139 36 :4 0 124
:3 0 30 :3 0 37
:2 0 af 127 128
:3 0 9 :3 0 38
:3 0 12a 12b 0
39 :2 0 12c 12d
0 12f b2 136
9 :3 0 38 :3 0
130 131 0 3a
:2 0 132 133 0
135 b4 137 129
12f 0 138 0
135 0 138 b6
0 139 b9 18c
3b :3 0 9 :3 0
38 :3 0 13b 13c
0 3c :3 0 13d
13e 0 140 bc
142 be 141 140
:2 0 18a 3d :3 0
9 :3 0 38 :3 0
145 146 0 3c
:3 0 147 148 0
182 c :3 0 d
:3 0 14a 14b 0
c :3 0 1a :3 0
14d 14e 0 3e
:2 0 2 :4 0 3f
:2 0 1d :2 0 1b
:2 0 c0 153 155
:3 0 c3 14f 157
14c 159 158 :2 0
f :3 0 1e :3 0
15b 15c 0 11
:4 0 40 :4 0 14
:2 0 15 :3 0 c7
160 162 :3 0 14
:2 0 24 :4 0 ca
164 166 :3 0 14
:2 0 41 :4 0 cd
168 16a :3 0 14
:2 0 3c :3 0 d0
16c 16e :3 0 14
:2 0 42 :4 0 d3
170 172 :3 0 14
:2 0 43 :3 0 44
:3 0 1b :2 0 45
:2 0 d6 175 179
da 174 17b :3 0
dd 15d 17d :2 0
17f e0 180 15a
17f 0 181 e2
0 182 e4 185
:3 0 185 0 185
184 182 183 :6 0
187 2 :3 0 e7
189 e9 188 187
:2 0 18a eb :2 0
18c 0 18c 18b
139 18a :6 0 1dc
1 :3 0 c :3 0
d :3 0 18e 18f
0 c :3 0 1a
:3 0 191 192 0
46 :2 0 2 :4 0
47 :2 0 1d :2 0
1b :2 0 ee 197
199 :3 0 f1 193
19b 190 19d 19c
:2 0 f :3 0 1e
:3 0 19f 1a0 0
11 :4 0 48 :4 0
14 :2 0 15 :3 0
f5 1a4 1a6 :3 0
14 :2 0 24 :4 0
f8 1a8 1aa :3 0
14 :2 0 25 :4 0
fb 1ac 1ae :3 0
14 :2 0 26 :3 0
27 :3 0 9 :3 0
38 :3 0 1b3 1b4
0 fe 1b2 1b6
2a :4 0 100 1b1
1b9 103 1b0 1bb
:3 0 14 :2 0 2b
:4 0 106 1bd 1bf
:3 0 14 :2 0 17
:4 0 109 1c1 1c3
:3 0 14 :2 0 3
:3 0 10c 1c5 1c7
:3 0 14 :2 0 17
:4 0 10f 1c9 1cb
:3 0 112 1a1 1cd
:2 0 1cf 115 1d0
19e 1cf 0 1d1
117 0 1dc 2e
:3 0 49 :3 0 1d2
1d3 0 9 :3 0
38 :3 0 1d5 1d6
0 3 :3 0 30
:3 0 119 1d4 1da
:2 0 1dc 11d 27d
9 :3 0 4a :2 0
4 1dd 1de 0
c :3 0 d :3 0
1e0 1e1 0 c
:3 0 1a :3 0 1e3
1e4 0 3e :2 0
2 :4 0 4b :2 0
1d :2 0 1b :2 0
124 1e9 1eb :3 0
127 1e5 1ed 1e2
1ef 1ee :2 0 f
:3 0 1e :3 0 1f1
1f2 0 11 :4 0
4c :4 0 14 :2 0
15 :3 0 12b 1f6
1f8 :3 0 12e 1f3
1fa :2 0 213 f
:3 0 1e :3 0 1fc
1fd 0 11 :4 0
4d :4 0 14 :2 0
9 :3 0 4e :3 0
202 203 0 131
201 205 :3 0 14
:2 0 2b :4 0 134
207 209 :3 0 14
:2 0 9 :3 0 4f
:3 0 20c 20d 0
137 20b 20f :3 0
13a 1fe 211 :2 0
213 13d 214 1f0
213 0 215 140
0 225 50 :3 0
b :3 0 9 :3 0
4e :3 0 51 :3 0
9 :3 0 4f :3 0
52 :3 0 53 :4 0
54 1 :a 0 221
:2 0 225 217 21f
:2 0 8 :3 0 b
:3 0 223 :2 0 225
142 227 146 226
225 :2 0 27b 3d
:3 0 9 :3 0 38
:3 0 22a 22b 0
3c :3 0 22c 22d
0 273 c :3 0
d :3 0 22f 230
0 c :3 0 1a
:3 0 232 233 0
3e :2 0 2 :4 0
55 :2 0 1d :2 0
1b :2 0 148 238
23a :3 0 14b 234
23c 231 23e 23d
:2 0 f :3 0 1e
:3 0 240 241 0
11 :4 0 56 :4 0
14 :2 0 15 :3 0
14f 245 247 :3 0
152 242 249 :2 0
263 f :3 0 1e
:3 0 24b 24c 0
11 :4 0 41 :4 0
14 :2 0 3c :3 0
155 250 252 :3 0
14 :2 0 42 :4 0
158 254 256 :3 0
14 :2 0 43 :3 0
44 :3 0 1b :2 0
45 :2 0 15b 259
25d 15f 258 25f
:3 0 162 24d 261
:2 0 263 165 264
23f 263 0 265
168 0 273 50
:3 0 b :3 0 51
:3 0 9 :3 0 4f
:3 0 52 :3 0 53
:4 0 57 1 :a 0
26f :2 0 273 267
26d :2 0 8 :3 0
b :3 0 271 :2 0
273 16a 276 :3 0
276 0 276 275
273 274 :6 0 278
1 :3 0 16f 27a
171 279 278 :2 0
27b 173 :2 0 27d
176 27d 27c 1dc
27b :6 0 27e :2 0
2 18 27d 281
:3 0 280 27e 282
:8 0 
178
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1a
1 27 1 33
2 36 38 2
3b 3d 2 3f
41 2 43 45
2 47 49 2
4b 4d 2 4f
51 2 53 55
2 57 59 2
5b 5d 2 5f
61 2 63 65
2 67 69 2
6b 6d 2 6f
71 2 73 75
2 77 79 4
2f 35 3a 7b
1 7d 1 7f
2 89 8b 3
87 88 8d 2
96 98 2 95
9a 1 9c 1
9e 1 a0 1
a5 2 b4 b6
3 b2 b3 b8
2 c1 c3 2
c5 c7 2 c9
cb 1 d3 2
d5 d6 2 cd
d8 2 da dc
2 de e0 2
e2 e4 2 e6
e8 2 c0 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 3 114 115
116 3 ef 10e
118 1 11a 1
126 2 125 126
1 12e 1 134
2 136 137 2
123 138 1 13f
1 13a 2 152
154 3 150 151
156 2 15f 161
2 163 165 2
167 169 2 16b
16d 2 16f 171
3 176 177 178
2 173 17a 2
15e 17c 1 17e
1 180 2 149
181 1 185 1
144 2 142 189
2 196 198 3
194 195 19a 2
1a3 1a5 2 1a7
1a9 2 1ab 1ad
1 1b5 2 1b7
1b8 2 1af 1ba
2 1bc 1be 2
1c0 1c2 2 1c4
1c6 2 1c8 1ca
2 1a2 1cc 1
1ce 1 1d0 3
1d7 1d8 1d9 6
80 9f 11b 18c
1d1 1db 2 1e8
1ea 3 1e6 1e7
1ec 2 1f5 1f7
2 1f4 1f9 2
200 204 2 206
208 2 20a 20e
2 1ff 210 2
1fb 212 1 214
3 215 220 224
1 1df 2 237
239 3 235 236
23b 2 244 246
2 243 248 2
24f 251 2 253
255 3 25a 25b
25c 2 257 25e
2 24e 260 2
24a 262 1 264
4 22e 265 26e
272 1 276 1
229 2 227 27a
1 1f 
1
4
0 
281
0
1
14
4
6
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
f 1 0
b 1 0
7 1 0
2 0 1
3 1 0
1a 1 0
0

/
SHOW ERRORS FUNCTION SP_U_ASSIGN_DESCR;
ALTER FUNCTION SP_U_ASSIGN_DESCR COMPILE DEBUG;
/****************************************************************************************/
Prompt == FUNCTION SP_TEST_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_TEST_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bc
2 :e:
1FUNCTION:
1SP_TEST_ASSIGN:
1RANK001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_FULL_NAME:
1255:
1H_PROJECT_ID:
132:
1H_RES_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_SECURITY_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_PARTICIPANT:
10:
1H_BITFLAG:
1CURSOR:
1C_RPA0:
1ELEMENT_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT ELEMENT_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst.SC_PROJEC+
1T,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cnst+
1.SC_PROJ_TYPE3) AND RANK LIKE h_rank || '%':
1C_RPA1:
1RES_ASSIGNMENT_ID:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1SELECT RES_ASSIGNMENT_ID, TSK_ASSIGNMENT_ID, RESOURCE_ID, RESOURCE_TYPE:n    +
1     FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID = h_project_id AND TASK+
1_ID = h_project_id:
1C_FPA1:
1RA:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1PROJECT_ASSIGNMENTS:
1PA:
1SELECT ra.RESOURCE_ID, ra.RESOURCE_TYPE, ra.PARTICIPANT, ra.SECURITY_ID:n    +
1     FROM RESOURCE_ASSIGNMENTS ra:n         WHERE ELEMENT_ID = h_project_id A+
1ND NOT EXISTS (:n         SELECT 'X' FROM PROJECT_ASSIGNMENTS pa WHERE pa.PRO+
1JECT_ID = h_project_id AND pa.RESOURCE_ID = ra.RESOURCE_ID):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_TEST_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
141:
1+:
1FPUT:
1               ENTER:: SP_TEST_ASSIGN(42) :: cplan.sql(22482) :: :
1OPEN:
1LOOP:
1FOUND:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1=:
1COUNT:
1DUAL:
1PROJECT_ASSIGNMENT_ID:
1SELECT COUNT('X') INTO h_bitflag FROM DUAL WHERE EXISTS (SELECT 'X' FROM TASK+
1_ASSIGNMENTS:n               WHERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_i+
1d AND RESOURCE_ID = h_res_id):
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
187:
1           EXCEPTION:: SP_TEST_ASSIGN(88) :: cplan.sql(22528) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1UPDATE TASK_ASSIGNMENTS SET PROJECT_ASSIGNMENT_ID = NuLL:n                  W+
1HERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_id:
1TRUE:
1108:
1           EXCEPTION:: SP_TEST_ASSIGN(109) :: cplan.sql(22549) :: :
1TASK_DAY_OF_YEAR:
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET PARENT_ID = TSK_ASSIGNMENT_ID:n                  +
1WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_tsk_assignment_id:
1128:
1           EXCEPTION:: SP_TEST_ASSIGN(129) :: cplan.sql(22569) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS:n               WHERE RES_ASSIGNMENT_ID = h_+
1res_assignment_id:n               AND SECURITY_ID = 'SCPROJECTASSIGNMENT':
1150:
1           EXCEPTION:: SP_TEST_ASSIGN(151) :: cplan.sql(22591) :: :
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1170:
1           EXCEPTION:: SP_TEST_ASSIGN(171) :: cplan.sql(22611) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME || ';' INTO h_full_name:n                     FROM RESOURCES+
1:n                     WHERE RESOURCE_ID = h_res_id:
1188:
1           EXCEPTION:: SP_TEST_ASSIGN(189) :: cplan.sql(22629) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                     FROM PROFIL+
1ES:n                     WHERE PROFILE_ID = h_res_id:
1205:
1           EXCEPTION:: SP_TEST_ASSIGN(206) :: cplan.sql(22646) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_full_name, ''):n  +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_id:
1226:
1           EXCEPTION:: SP_TEST_ASSIGN(227) :: cplan.sql(22667) :: :
1PMO_STPU:
1BIT_ANDNOT:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_ANDNOT(PARTICIPANT+
1,4096):n                  WHERE RES_ASSIGNMENT_ID = h_res_assignment_id:
1246:
1           EXCEPTION:: SP_TEST_ASSIGN(247) :: cplan.sql(22687) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1266:
1           EXCEPTION:: SP_TEST_ASSIGN(267) :: cplan.sql(22707) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
1285:
1           EXCEPTION:: SP_TEST_ASSIGN(286) :: cplan.sql(22726) :: :
1CLOSE:
1301:
1           EXCEPTION:: SP_TEST_ASSIGN(302) :: cplan.sql(22742) :: :
1COMMIT:
1ELSIF:
1SELECT NICK_NAME || ';' INTO h_full_name:n                  FROM RESOURCES:n +
1                 WHERE RESOURCE_ID = h_res_id:
1334:
1           EXCEPTION:: SP_TEST_ASSIGN(335) :: cplan.sql(22775) :: :
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                  FROM PROFILES+
1:n                  WHERE PROFILE_ID = h_res_id:
1351:
1           EXCEPTION:: SP_TEST_ASSIGN(352) :: cplan.sql(22792) :: :
1INSTR:
1UPDATE TMT_WBS SET ASSIGN_NAMES = CASE:n               WHEN InStr(ASSIGN_NAME+
1S, h_full_name) > 0 THEN ASSIGN_NAMES:n               ELSE ASSIGN_NAMES || h_+
1full_name END:n               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID +
1= h_project_id:
1374:
1           EXCEPTION:: SP_TEST_ASSIGN(375) :: cplan.sql(22815) :: :
1ELEMENT_TYPE_BITS:
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1INSERT INTO PROJECT_ASSIGNMENTS (PROJECT_ID, RESOURCE_ID, PARTICIPANT, SECURI+
1TY_ID, RESOURCE_TYPE, ELEMENT_TYPE_BITS,ROLLUP_BITS):n               VALUES(h+
1_project_id, h_res_id, h_participant, h_security_id, h_res_type, 1, pmo_cnst.+
1SC_ASSIGNMENT_BIT):
1394:
1           EXCEPTION:: SP_TEST_ASSIGN(395) :: cplan.sql(22835) :: :
1411:
1           EXCEPTION:: SP_TEST_ASSIGN(412) :: cplan.sql(22852) :: :
1430:
1           EXCEPTION:: SP_TEST_ASSIGN(431) :: cplan.sql(22871) :: :
14:
1436:
1       RETURN_STATUS:: SP_TEST_ASSIGN(437) :: cplan.sql(22877) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1443:
1           EXCEPTION:: SP_TEST_ASSIGN(444) :: cplan.sql(22884) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1455:
1           EXCEPTION:: SP_TEST_ASSIGN(456) :: cplan.sql(22896) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
a60
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :f a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :9 a0 12a bd
b7 11 a4 b1 a0 f4 b4 bf
c8 :15 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 e9
dd b3 :3 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 e9 dd b3 :6 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 :2 51
a5 b 7e 6e b4 2e :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :3 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 12a a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 e9 dd b3
:6 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:c a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 12a
b7 :2 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
a60
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8f 7d 59 81 82 8a 7c
ac 9a 79 9e 9f a7 99 c9
b7 96 bb bc c4 b6 e6 d4
b3 d8 d9 e1 d3 103 f1 d0
f5 f6 fe f0 120 10e ed 112
113 11b 10d 13d 12b 10a 12f 130
138 12a 159 148 14c 127 154 147
175 164 168 144 170 163 17c 180
160 191 194 198 19c 1a0 1a4 1a8
1ac 1b0 1b4 1b8 1bc 1c0 1c4 1c8
1cc 1d0 1d4 1e0 1e5 1e7 1f3 1f7
1f9 1fd 20e 20f 212 216 21a 21e
222 226 22a 22e 232 236 23a 246
24b 24d 259 25d 25f 263 274 275
278 27c 280 284 288 28c 290 294
298 29c 2a0 2a4 2a8 2ac 2b0 2b4
2b8 2bc 2c0 2c4 2c8 2cc 2d0 2dc
2e1 2e3 2ef 2f3 311 2f9 2fd 301
304 30c 2f8 318 31c 2f5 320 324
328 32b 330 331 1 333 338 33c
340 343 348 34c 350 353 358 359
35b 360 363 367 368 36d 372 375
37a 37b 380 383 387 388 38d 390
395 396 39b 39e 3a3 3a4 3a9 3ac
3b0 3b4 3b8 3b9 3bb 3c0 3c1 3c3
3c4 3c9 3cc 3d1 3d2 3d7 3d8 3dd
3df 3e3 3e6 3ea 3ee 3f1 3f5 3f9
3fc 3ff 404 407 40a 40d 40e 413
414 1 416 41b 41f 423 426 42b
430 433 437 438 43d 43e 443 445
449 44c 450 454 458 45c 460 464
468 46c 471 475 476 47a 47e 482
487 48c 490 494 499 49d 4a1 4a4
4a7 4ab 4ad 4b1 4b5 4b8 4bb 4bf
4c1 4c5 4c9 4cc 4d0 4d4 4d7 4db
4de 4e2 4e5 4e6 4eb 4ee 4f2 4f8
4fa 4fe 501 505 509 50c 50d 50f
512 515 516 51b 51f 523 528 52c
52d 531 535 539 53d 541 545 54a
54f 553 557 55b 560 564 568 56b
56e 572 574 578 57c 57f 582 586
588 58c 590 593 597 59b 59e 5a2
5a5 5a9 5ac 5ad 5b2 5b5 5b9 5bf
5c1 5c5 5c8 5cc 5cf 5d3 5d7 5db
5df 5e3 5e7 5eb 5ef 5f3 5ff 603
607 60a 60e 612 614 618 61c 620
623 627 62b 62d 62e 633 1 637
63b 63f 642 646 64a 64e 652 655
659 65d 660 663 668 66b 66e 671
672 677 678 1 67a 67f 683 687
68a 68f 694 697 69b 69c 6a1 6a4
6a9 6aa 6af 6b2 6b7 6b8 6bd 6c0
6c4 6c5 6ca 6cd 6d2 6d3 6d8 6db
6df 6e3 6e6 6e9 6ea 6ec 6ed 6f2
6f3 6f8 6fa 6fe 701 703 707 709
715 717 719 71a 71f 723 725 731
733 737 73b 73e 73f 741 744 747
748 74d 751 755 759 75d 769 76d
772 776 779 77a 77f 783 787 78a
78d 791 793 797 79b 79e 7a1 7a5
7a7 7ab 7af 7b2 7b4 7b8 7bc 7c0
7c3 7c7 7cb 7cd 7ce 7d3 1 7d7
7db 7df 7e2 7e6 7ea 7ee 7f2 7f5
7f9 7fd 800 803 808 80b 80e 811
812 817 818 1 81a 81f 823 827
82a 82f 834 837 83b 83c 841 844
849 84a 84f 852 857 858 85d 860
864 865 86a 86d 872 873 878 87b
87f 883 886 889 88a 88c 88d 892
893 898 89a 89e 8a1 8a3 8a7 8a9
8b5 8b7 8b9 8ba 8bf 8c3 8c5 8d1
8d3 8d7 8db 8df 8e3 8e7 8eb 8ef
8fb 8ff 904 908 90b 90c 911 915
919 91c 91f 923 925 929 92d 930
933 937 939 93d 941 944 946 94a
94e 952 955 959 95d 95f 960 965
1 969 96d 971 974 978 97c 980
984 987 98b 98f 992 995 99a 99d
9a0 9a3 9a4 9a9 9aa 1 9ac 9b1
9b5 9b9 9bc 9c1 9c6 9c9 9cd 9ce
9d3 9d6 9db 9dc 9e1 9e4 9e9 9ea
9ef 9f2 9f6 9f7 9fc 9ff a04 a05
a0a a0d a11 a15 a18 a1b a1c a1e
a1f a24 a25 a2a a2c a30 a33 a35
a39 a3b a47 a49 a4b a4c a51 a55
a57 a63 a65 a67 a6b a6e a72 a76
a7a a7e a8a a8e a93 a97 a9a a9b
aa0 aa4 aa8 aab aae ab2 ab4 ab8
abc abf ac2 ac6 ac8 acc ad0 ad3
ad5 ad9 add ae1 ae4 ae8 aec aee
aef af4 1 af8 afc b00 b03 b07
b0b b0f b13 b16 b1a b1e b21 b24
b29 b2c b2f b32 b33 b38 b39 1
b3b b40 b44 b48 b4b b50 b55 b58
b5c b5d b62 b65 b6a b6b b70 b73
b78 b79 b7e b81 b85 b86 b8b b8e
b93 b94 b99 b9c ba0 ba4 ba7 baa
bab bad bae bb3 bb4 bb9 bbb bbf
bc2 bc4 bc8 bca bd6 bd8 bda bdb
be0 be4 be6 bf2 bf4 bf8 bfc bff
c03 c06 c0a c0d c0e c13 c16 c1a
c1e c22 c26 c2a c36 c3a c3f c43
c46 c47 c4c c50 c54 c57 c5a c5e
c60 c64 c68 c6b c6e c72 c74 c78
c7c c7f c81 c85 c89 c8d c90 c94
c98 c9a c9b ca0 1 ca4 ca8 cac
caf cb3 cb7 cbb cbf cc2 cc6 cca
ccd cd0 cd5 cd8 cdb cde cdf ce4
ce5 1 ce7 cec cf0 cf4 cf7 cfc
d01 d04 d08 d09 d0e d11 d16 d17
d1c d1f d24 d25 d2a d2d d31 d32
d37 d3a d3f d40 d45 d48 d4c d50
d53 d56 d57 d59 d5a d5f d60 d65
d67 d6b d6e d70 d74 d76 d82 d84
d86 d87 d8c d90 d92 d9e da0 da4
da8 dab dae daf db1 db4 db9 dba
dbf dc3 dc7 dcb dcf dd3 ddf de3
de7 dea dee df2 df4 df8 dfc e00
e03 e07 e0b e0d e0e e13 1 e17
e1b e1f e22 e26 e2a e2e e32 e35
e39 e3d e40 e43 e48 e4b e4e e51
e52 e57 e58 1 e5a e5f e63 e67
e6a e6f e74 e77 e7b e7c e81 e84
e89 e8a e8f e92 e97 e98 e9d ea0
ea4 ea5 eaa ead eb2 eb3 eb8 ebb
ebf ec3 ec6 ec9 eca ecc ecd ed2
ed3 ed8 eda ede ee1 ee3 ee7 ee9
ef5 ef7 ef9 efa eff f03 f05 f11
f13 f15 f19 f1d f21 f25 f29 f35
f39 f3d f40 f44 f48 f4a f4e f52
f56 f59 f5d f61 f63 f64 f69 1
f6d f71 f75 f78 f7c f80 f84 f88
f8b f8f f93 f96 f99 f9e fa1 fa4
fa7 fa8 fad fae 1 fb0 fb5 fb9
fbd fc0 fc5 fca fcd fd1 fd2 fd7
fda fdf fe0 fe5 fe8 fed fee ff3
ff6 ffa ffb 1000 1003 1008 1009 100e
1011 1015 1019 101c 101f 1020 1022 1023
1028 1029 102e 1030 1034 1037 1039 103d
103f 104b 104d 104f 1050 1055 1059 105b
1067 1069 106b 106f 1073 1076 107a 107e
1082 1086 108a 108e 1092 1096 109a 10a6
10aa 10af 10b3 10b6 10b7 10bc 10c0 10c4
10c7 10ca 10ce 10d0 10d4 10d8 10db 10de
10e2 10e4 10e8 10ec 10ef 10f1 10f5 10f9
10fd 1100 1104 1108 110a 110b 1110 1
1114 1118 111c 111f 1123 1127 112b 112f
1132 1136 113a 113d 1140 1145 1148 114b
114e 114f 1154 1155 1 1157 115c 1160
1164 1167 116c 1171 1174 1178 1179 117e
1181 1186 1187 118c 118f 1194 1195 119a
119d 11a1 11a2 11a7 11aa 11af 11b0 11b5
11b8 11bc 11c0 11c3 11c6 11c7 11c9 11ca
11cf 11d0 11d5 11d7 11db 11de 11e0 11e4
11e6 11f2 11f4 11f6 11f7 11fc 1200 1202
120e 1210 1212 1216 121a 121e 1222 1226
122a 122e 123a 123e 1243 1247 124a 124b
1250 1254 1258 125b 125e 1262 1264 1268
126c 126f 1272 1276 1278 127c 1280 1283
1285 1289 128d 1291 1294 1298 129c 129e
129f 12a4 1 12a8 12ac 12b0 12b3 12b7
12bb 12bf 12c3 12c6 12ca 12ce 12d1 12d4
12d9 12dc 12df 12e2 12e3 12e8 12e9 1
12eb 12f0 12f4 12f8 12fb 1300 1305 1308
130c 130d 1312 1315 131a 131b 1320 1323
1328 1329 132e 1331 1335 1336 133b 133e
1343 1344 1349 134c 1350 1354 1357 135a
135b 135d 135e 1363 1364 1369 136b 136f
1372 1374 1378 137a 1386 1388 138a 138b
1390 1394 1396 13a2 13a4 13a6 13aa 13ae
13b1 13b5 13b9 13bd 13c9 13cd 13d2 13d6
13d9 13da 13df 13e3 13e7 13ea 13ed 13f1
13f3 13f7 13fb 13fe 1401 1405 1407 140b
140f 1412 1414 1418 141c 1420 1423 1427
142b 142d 142e 1433 1 1437 143b 143f
1442 1446 144a 144e 1452 1455 1459 145d
1460 1463 1468 146b 146e 1471 1472 1477
1478 1 147a 147f 1483 1487 148a 148f
1494 1497 149b 149c 14a1 14a4 14a9 14aa
14af 14b2 14b7 14b8 14bd 14c0 14c4 14c5
14ca 14cd 14d2 14d3 14d8 14db 14df 14e3
14e6 14e9 14ea 14ec 14ed 14f2 14f3 14f8
14fa 14fe 1501 1503 1507 1509 1515 1517
1519 151a 151f 1523 1525 1531 1533 1537
153b 153f 1543 1547 1553 1557 155c 1560
1563 1564 1569 156d 1571 1574 1577 157b
157d 1581 1585 1588 158b 158f 1591 1595
1599 159c 159e 15a2 15a6 15aa 15ad 15b1
15b5 15b7 15b8 15bd 1 15c1 15c5 15c9
15cc 15d0 15d4 15d8 15dc 15df 15e3 15e7
15ea 15ed 15f2 15f5 15f8 15fb 15fc 1601
1602 1 1604 1609 160d 1611 1614 1619
161e 1621 1625 1626 162b 162e 1633 1634
1639 163c 1641 1642 1647 164a 164e 164f
1654 1657 165c 165d 1662 1665 1669 166d
1670 1673 1674 1676 1677 167c 167d 1682
1684 1688 168b 168d 1691 1693 169f 16a1
16a3 16a4 16a9 16ad 16af 16bb 16bd 16bf
16c3 16ca 16ce 16d2 16d7 16d9 16dd 16e1
16e4 16e8 16ec 16ee 16f2 16f6 16fa 16fd
1701 1705 1707 1708 170d 1 1711 1715
1719 171c 1720 1724 1728 172c 172f 1733
1737 173a 173d 1742 1745 1748 174b 174c
1751 1752 1 1754 1759 175d 1761 1764
1769 176e 1771 1775 1776 177b 177e 1783
1784 1789 178c 1791 1792 1797 179a 179e
179f 17a4 17a7 17ac 17ad 17b2 17b5 17b9
17bd 17c0 17c3 17c4 17c6 17c7 17cc 17cd
17d2 17d4 17d8 17db 17dd 17e1 17e3 17ef
17f1 17f3 17f4 17f9 17fd 17ff 180b 180d
1811 181d 1821 1823 1827 182b 182e 182f
1831 1834 1837 1838 183d 1841 1845 184a
184e 184f 1853 1857 185b 185f 1863 1867
186c 1871 1875 1879 187d 1882 1886 188a
188d 1890 1894 1896 189a 189e 18a1 18a4
18a8 18aa 18ae 18b2 18b5 18b9 18bd 18c0
18c4 18c7 18cb 18ce 18cf 18d4 18d7 18db
18e1 18e3 18e7 18ea 18ee 18f2 18f5 18f8
18f9 18fb 18fe 1903 1904 1909 190d 1911
1915 1919 191d 1929 192d 1931 1934 1938
193c 193e 1942 1946 194a 194d 1951 1955
1957 1958 195d 1 1961 1965 1969 196c
1970 1974 1978 197c 197f 1983 1987 198a
198d 1992 1995 1998 199b 199c 19a1 19a2
1 19a4 19a9 19ad 19b1 19b4 19b9 19be
19c1 19c5 19c6 19cb 19ce 19d3 19d4 19d9
19dc 19e1 19e2 19e7 19ea 19ee 19ef 19f4
19f7 19fc 19fd 1a02 1a05 1a09 1a0d 1a10
1a13 1a14 1a16 1a17 1a1c 1a1d 1a22 1a24
1a28 1a2b 1a2d 1a31 1a33 1a3f 1a41 1a43
1a44 1a49 1a4d 1a4f 1a5b 1a5d 1a5f 1a63
1a67 1a6b 1a6f 1a73 1a7f 1a83 1a87 1a8a
1a8e 1a92 1a94 1a98 1a9c 1aa0 1aa3 1aa7
1aab 1aad 1aae 1ab3 1 1ab7 1abb 1abf
1ac2 1ac6 1aca 1ace 1ad2 1ad5 1ad9 1add
1ae0 1ae3 1ae8 1aeb 1aee 1af1 1af2 1af7
1af8 1 1afa 1aff 1b03 1b07 1b0a 1b0f
1b14 1b17 1b1b 1b1c 1b21 1b24 1b29 1b2a
1b2f 1b32 1b37 1b38 1b3d 1b40 1b44 1b45
1b4a 1b4d 1b52 1b53 1b58 1b5b 1b5f 1b63
1b66 1b69 1b6a 1b6c 1b6d 1b72 1b73 1b78
1b7a 1b7e 1b81 1b83 1b87 1b89 1b95 1b97
1b99 1b9a 1b9f 1ba3 1ba5 1bb1 1bb3 1bb5
1bb9 1bbd 1bc0 1bc4 1bc8 1bcc 1bd0 1bd4
1bd8 1bdc 1be0 1be4 1be8 1bec 1bf0 1bfc
1c00 1c05 1c09 1c0c 1c0d 1c12 1c16 1c1a
1c1d 1c20 1c24 1c26 1c2a 1c2e 1c31 1c34
1c38 1c3a 1c3e 1c42 1c45 1c47 1c4b 1c4f
1c53 1c56 1c5a 1c5e 1c60 1c61 1c66 1
1c6a 1c6e 1c72 1c75 1c79 1c7d 1c81 1c85
1c88 1c8c 1c90 1c93 1c96 1c9b 1c9e 1ca1
1ca4 1ca5 1caa 1cab 1 1cad 1cb2 1cb6
1cba 1cbd 1cc2 1cc7 1cca 1cce 1ccf 1cd4
1cd7 1cdc 1cdd 1ce2 1ce5 1cea 1ceb 1cf0
1cf3 1cf7 1cf8 1cfd 1d00 1d05 1d06 1d0b
1d0e 1d12 1d16 1d19 1d1c 1d1d 1d1f 1d20
1d25 1d26 1d2b 1d2d 1d31 1d34 1d36 1d3a
1d3c 1d48 1d4a 1d4c 1d4d 1d52 1d56 1d58
1d64 1d66 1d6a 1d6e 1d72 1d76 1d7a 1d7e
1d82 1d86 1d8a 1d8e 1d92 1d96 1d9a 1d9e
1da2 1dae 1db2 1db7 1dbb 1dbe 1dbf 1dc4
1dc8 1dcc 1dcf 1dd2 1dd6 1dd8 1ddc 1de0
1de3 1de6 1dea 1dec 1df0 1df4 1df7 1df9
1dfd 1e01 1e05 1e08 1e0c 1e10 1e12 1e13
1e18 1 1e1c 1e20 1e24 1e27 1e2b 1e2f
1e33 1e37 1e3a 1e3e 1e42 1e45 1e48 1e4d
1e50 1e53 1e56 1e57 1e5c 1e5d 1 1e5f
1e64 1e68 1e6c 1e6f 1e74 1e79 1e7c 1e80
1e81 1e86 1e89 1e8e 1e8f 1e94 1e97 1e9c
1e9d 1ea2 1ea5 1ea9 1eaa 1eaf 1eb2 1eb7
1eb8 1ebd 1ec0 1ec4 1ec8 1ecb 1ece 1ecf
1ed1 1ed2 1ed7 1ed8 1edd 1edf 1ee3 1ee6
1ee8 1eec 1eee 1efa 1efc 1efe 1eff 1f04
1f08 1f0a 1f16 1f18 1f1a 1f1e 1f25 1f29
1f2d 1f32 1f34 1f38 1f3c 1f3f 1f43 1f47
1f49 1f4d 1f51 1f55 1f58 1f5c 1f60 1f62
1f63 1f68 1 1f6c 1f70 1f74 1f77 1f7b
1f7f 1f83 1f87 1f8a 1f8e 1f92 1f95 1f98
1f9d 1fa0 1fa3 1fa6 1fa7 1fac 1fad 1
1faf 1fb4 1fb8 1fbc 1fbf 1fc4 1fc9 1fcc
1fd0 1fd1 1fd6 1fd9 1fde 1fdf 1fe4 1fe7
1fec 1fed 1ff2 1ff5 1ff9 1ffa 1fff 2002
2007 2008 200d 2010 2014 2018 201b 201e
201f 2021 2022 2027 2028 202d 202f 2033
2036 2038 203c 203e 204a 204c 204e 204f
2054 2058 205a 2066 2068 206c 2078 207a
207e 2082 2085 2087 208b 2092 2096 209a
209f 20a1 20a5 20a9 20ac 20b0 20b4 20b6
20ba 20be 20c2 20c5 20c9 20cd 20cf 20d0
20d5 1 20d9 20dd 20e1 20e4 20e8 20ec
20f0 20f4 20f7 20fb 20ff 2102 2105 210a
210d 2110 2113 2114 2119 211a 1 211c
2121 2125 2129 212c 2131 2136 2139 213d
213e 2143 2146 214b 214c 2151 2154 2159
215a 215f 2162 2166 2167 216c 216f 2174
2175 217a 217d 2181 2185 2188 218b 218c
218e 218f 2194 2195 219a 219c 21a0 21a3
21a5 21a9 21ab 21b7 21b9 21bb 21bc 21c1
21c5 21c7 21d3 21d5 21d9 21dd 21e0 21e4
21e8 21eb 21ee 21f3 21f6 21f9 21fc 21fd
2202 2203 1 2205 220a 220e 2212 2215
221a 221f 2222 2226 2227 222c 222f 2234
2235 223a 223d 2242 2243 2248 224b 224f
2253 2257 225b 225e 225f 2261 2266 2267
2269 226a 226f 2272 2277 2278 227d 2280
2285 2286 228b 228e 2292 2293 2298 229b
22a0 22a1 22a6 22a7 22ac 22ae 22b2 22b5
22b9 22bd 22c0 22c4 22c8 22cb 22cf 22d3
22d4 22d9 22db 22df 22e3 22e6 22ea 22ee
22f1 22f5 22f9 22fc 22ff 2304 2307 230a
230d 230e 2313 2314 1 2316 231b 231f
2323 2326 232b 2330 2333 2337 2338 233d
233e 2343 2347 234b 234e 2353 2358 235b
235f 2363 2366 2367 236c 236f 2374 2375
237a 237d 2381 2385 2388 2389 238e 238f
2394 2396 239a 239d 23a1 23a5 23a9 23ad
23b1 23b5 23b9 23bd 23c1 23cd 23d2 23d6
23da 23de 23e2 23e4 23e5 23ea 1 23ee
23f2 23f6 23f9 23fd 2401 2405 2409 240c
2410 2414 2417 241a 241f 2422 2425 2428
2429 242e 242f 1 2431 2436 243a 243e
2441 2446 244b 244e 2452 2453 2458 2459
245e 2462 2466 2469 246e 2473 2476 247a
247b 2480 2483 2488 2489 248e 2491 2495
2499 249c 249f 24a0 24a2 24a3 24a8 24a9
24ae 24b0 24b4 24b7 24bb 24bf 24c3 24c7
24cb 24cf 24d3 24df 24e4 24e8 24ec 24f0
24f4 24f6 24fa 24fc 2508 250a 250c 250d
2512 2516 2518 2524 2528 252a 252b 2534 
a60
2
0 1 a 6 e :3 6 11 :2 6
1 3 a 13 a :2 1 4 b
14 13 :2 b :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
12 1b 1a :2 12 :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :2 12
21 12 :2 4 :2 e 1d e 4 7
e 0 :2 7 11 21 10 1c 25
30 39 45 4e 5c 65 73 7c
8f 99 a :6 7 e 0 :2 7 11
24 37 44 f 10 1d 2e 38
a :6 7 e 0 :2 7 11 14 21
24 33 36 43 46 f 24 10
1d 1a 2e 37 3a 47 58 5b
69 6c a :5 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 56 5c
5f :2 56 6d 85 8 :2 6d d 10
:2 6d 18 1b :2 6d b e :2 6d 13
16 1f 27 :2 1f 34 :2 16 :2 6d 3c
3f :2 6d :2 7 4c :2 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e :2 7
54 :3 4 e :2 4 11 :2 4 9 :4 4
d 19 :2 7 a 11 :2 a :2 13 1f
a 17 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
a 13 1e :2 a 21 23 :2 21 a
f :4 a 13 1f 34 49 53 :3 d
10 17 :2 10 :2 19 25 10 1d 10
:2 19 25 10 :4 d 11 :2 1a 26 23
:2 2f :2 23 :3 10 3f :3 d 1a d 17
27 36 59 16 2e 46 54 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 60
61 :2 5e :2 32 :3 16 :2 1c 21 2d 6e
71 :2 2d 7e 81 :2 2d 85 88 :2 2d
94 97 :2 2d 9f a2 :2 2d ae b1
b8 c1 c4 :2 b1 :2 2d :2 16 64 :2 13
:2 10 :4 1c :2 10 d :3 a 10 19 24
:2 10 27 2a :2 27 1a 2f 19 31
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:3 2c 1a 2f 3b 19 26 37 43
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:4 2c :2 d 1c 16 2a 14 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :3 a 11
:2 1a 25 23 :2 2e :2 23 10 1f 39
46 57 65 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :3 3e 13 1a 26 29
:2 13 2c 2e :2 2c 1d 33 1b 1c
2a :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 67 68 :2 64 :2 38 :3 1c :2 22 27
33 75 78 :2 33 85 88 :2 33 8c
8f :2 33 9b 9e :2 33 a6 a9 :2 33
b5 b8 bf c8 cb :2 b8 :2 33 :2 1c
6b :2 19 :2 16 :4 22 :2 16 13 :4 32 1d
36 1b 1c 29 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 67 68 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :7 10 1a 26 35 3e 4c 19
26 37 44 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :4 3e 1a 33 41 4a
55 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :7 d 1c 33 47 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 33 40 51 65 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d 7f 82 :2 2d 86 89
:2 2d 95 98 :2 2d a0 a3 :2 2d af
b2 b9 c2 c5 :2 b2 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :4 a e 25
d 13 :3 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6c 6f :2 2a 7c 7f :2 2a
83 86 :2 2a 92 95 :2 2a 9d a0
:2 2a ac af b6 bf c2 :2 af :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :3 25
:2 a 7 25 d 16 21 :2 d 24
26 :2 24 a f :4 a 13 1f 29
35 44 :3 d 10 17 :2 10 :2 19 25
10 1d 10 :2 19 25 10 :4 d 11
:2 1a 26 23 :2 2f :2 23 :3 10 3f :2 d
10 17 23 26 :2 10 29 2b :2 29
1a 30 18 19 27 :2 13 :2 1c 28
13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 64 65 :2 61
:2 35 :3 19 :2 1f 24 30 72 75 :2 30
82 85 :2 30 89 8c :2 30 98 9b
:2 30 a3 a6 :2 30 b2 b5 bc c5
c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :4 2f 1a 33 18 19 26
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
64 65 :2 61 :2 35 :3 19 :2 1f 24 30
72 75 :2 30 82 85 :2 30 89 8c
:2 30 98 9b :2 30 a3 a6 :2 30 b2
b5 bc c5 c8 :2 b5 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :7 d 17 23
15 1b 29 3f 15 25 16 23
34 41 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :3 a 1c 31 3d 4a 57
64 73 85 17 25 2f 3e 4d
5c 65 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :4 a e 28 d 13 :3 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5e
5f :2 5b :2 2f :3 13 :2 19 1e 2a 6c
6f :2 2a 7c 7f :2 2a 83 86 :2 2a
92 95 :2 2a 9d a0 :2 2a ac af
b6 bf c2 :2 af :2 2a :2 13 62 :2 10
:2 d :4 19 :2 d a :3 28 :2 a 28 25
:2 7 4 8 1 7 d :3 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8c
8f :2 24 97 9a :2 24 a6 a9 b0
b9 bc :2 a9 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 7 :2 11 23 :2 2d
39 3c 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 60 63 :2 1e 70 73
:2 1e 77 7a :2 1e 84 87 90 98
:2 a1 :2 90 ac :2 87 :2 1e b4 b7 :2 1e
bf c2 :2 1e c7 ca :2 1e d1 d4
:2 1e :2 7 55 :3 4 :2 f 21 :2 2a 34
3c :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 63 66 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
59 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4f 52 53 :2 4f
:2 23 :3 7 :2 d 12 1e 60 63 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 56 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
a60
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :6 f
:6 10 :2 12 0 :2 12
:2 13 :d 14 13 :5 12
:2 16 0 :2 16 :4 17
18 :4 19 17 :5 16
:2 1b 0 :2 1b :8 1c
:2 1d :2 1e :9 1f 1c
:5 1b :7 21 :b 23 :11 24
25 :2 24 :2 25 :2 24
:2 25 :2 24 :2 26 :2 24
:9 26 :2 24 :2 26 :4 24
:3 23 :11 29 :b 2a :3 29
:3 2d :3 2e :5 30 32
:4 33 :3 34 :5 35 34
:5 37 36 :3 34 :a 39
:2 3a :3 39 :9 3e :5 3f
41 :8 42 :3 43 :5 44
43 :5 46 45 :3 43
:a 48 :2 49 :3 48 :3 4c
:4 4e :4 4f 4e :5 50
4d 52 :5 53 :3 52
:2 54 :5 56 :11 57 :24 58
:3 57 :2 55 :6 54 51
:3 41 :9 5d :2 5f :2 60
5f :6 61 :5 62 61
:5 64 63 :3 61 5e
67 :5 68 :3 67 :2 69
:5 6b :11 6c :24 6d :3 6c
:2 6a :6 69 66 :3 5d
:3 73 :4 74 73 :6 75
:5 76 75 :5 78 77
:3 75 72 7b :5 7c
:3 7b :2 7d :5 7f :11 80
:24 81 :3 80 :2 7e :6 7d
7a :6 5d 88 :2 89
8a 88 :6 8b :5 8c
8b :5 8e 8d :3 8b
87 91 :5 92 :3 91
:2 93 :5 95 :11 96 :24 97
:3 96 :2 94 :6 93 90
:3 41 :a 9c :6 9e :6 9f
:5 a0 9f :5 a2 a1
:3 9f 9d a5 :5 a6
:3 a5 :2 a7 :5 a9 :11 aa
:24 ab :3 aa :2 a8 :6 a7
a4 :3 9c :a b0 :2 b2
b3 :2 b4 b2 :5 b5
b1 b7 :5 b8 :3 b7
:2 b9 :5 bb :11 bc :24 bd
:3 bc :2 ba :6 b9 b6
:4 b0 :2 c3 c4 :2 c5
c3 :5 c6 c2 c8
:5 c9 :3 c8 :2 ca :5 cc
:11 cd :24 ce :3 cd :2 cb
:6 ca c7 :4 c1 :3 b0
:5 d5 :4 d6 d5 :6 d7
:5 d8 d7 :5 da d9
:3 d7 d4 dd :5 de
:3 dd :2 df :5 e1 :11 e2
:24 e3 :3 e2 :2 e0 :6 df
dc :4 9c :5 e9 :2 ea
e9 :6 eb :5 ec eb
:5 ee ed :3 eb e8
f1 :5 f2 :3 f1 :2 f3
:5 f5 :11 f6 :24 f7 :3 f6
:2 f4 :6 f3 f0 :4 e7
:3 9c :4 fe :6 ff :5 100
ff :5 102 101 :3 ff
fd 105 :5 106 :3 105
:2 107 :5 109 :11 10a :24 10b
:3 10a :2 108 :6 107 104
:3 41 :6 111 :6 112 :5 113
112 :5 115 114 :3 112
110 118 :5 119 :3 118
:2 11a :5 11c :11 11d :24 11e
:3 11d :2 11b :6 11a 117
:4 41 122 3e :4 125
:5 126 124 128 :5 129
:3 128 :2 12a :5 12c :11 12d
:24 12e :3 12d :2 12b :6 12a
127 :3 3e :2 133 134
3e :9 134 :5 135 137
:8 138 :3 139 :5 13a 139
:5 13c 13b :3 139 :a 13e
:2 13f :3 13e :a 142 :2 144
145 :2 146 144 :5 147
143 149 :5 14a :3 149
:2 14b :5 14d :11 14e :24 14f
:3 14e :2 14c :6 14b 148
:4 142 :2 155 156 :2 157
155 :5 158 154 15a
:5 15b :3 15a :2 15c :5 15e
:11 15f :24 160 :3 15f :2 15d
:6 15c 159 :4 153 :3 142
:2 167 :4 168 :2 169 :4 16a
167 :6 16b :5 16c 16b
:5 16e 16d :3 16b 166
171 :5 172 :3 171 :2 173
:5 175 :11 176 :24 177 :3 176
:2 174 :6 173 170 :3 137
:8 17d :7 17e 17d :6 17f
:5 180 17f :5 182 181
:3 17f 17c 185 :5 186
:3 185 :2 187 :5 189 :11 18a
:24 18b :3 18a :2 188 :6 187
184 :4 137 190 134
:4 193 :5 194 192 196
:5 197 :3 196 :2 198 :5 19a
:11 19b :24 19c :3 19b :2 199
:6 198 195 :3 134 :2 1a1
134 :3 3e 32 1a3
22 :4 1a6 :5 1a7 1a5
1a9 :5 1aa :3 1a9 :2 1ab
:5 1ad :11 1ae :24 1af :3 1ae
:2 1ac :6 1ab 1a8 :3 22
:11 1b4 :30 1b5 :3 1b4 :a 1b7
22 :3 1ba :11 1bb :b 1bc
:17 1bd :3 1bb :2 1bf :3 1c0
:3 1c1 1c2 1c0 1bf
1c0 :3 1c3 :3 1ba :2 1c4
:5 1c6 :11 1c7 :b 1c8 :18 1c9
:3 1c7 :2 1cb 1cc :3 1cd
1ce 1cc 1cb 1cc
:3 1cf :2 1c5 :6 1c4 1b9
:7 1 
2536
4
:3 0 1 :3 0 2
:a 0 a5b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
a5b 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 a59 0
a :6 0 f :2 0
10 4 :3 0 e
1a 1c :6 0 1f
1d 0 a59 0
c :6 0 f :2 0
14 4 :3 0 12
21 23 :6 0 26
24 0 a59 0
e :6 0 f :2 0
18 4 :3 0 16
28 2a :6 0 2d
2b 0 a59 0
10 :6 0 f :2 0
1c 4 :3 0 1a
2f 31 :6 0 34
32 0 a59 0
11 :6 0 f :2 0
20 4 :3 0 1e
36 38 :6 0 3b
39 0 a59 0
12 :6 0 15 :2 0
24 4 :3 0 22
3d 3f :6 0 42
40 0 a59 0
13 :6 0 17 :2 0
28 4 :3 0 26
44 46 :6 0 49
47 0 a59 0
14 :6 0 17 :2 0
2a 6 :3 0 4b
:7 0 4f 4c 4d
a59 0 16 :9 0
2c 6 :3 0 51
:7 0 55 52 53
a59 0 18 :6 0
19 :3 0 1a :a 0
2 6b :4 0 57
5a 0 58 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
1f :3 0 1e :3 0
20 :3 0 1e :3 0
21 :3 0 1e :3 0
22 :3 0 1e :3 0
23 :3 0 24 :3 0
a :4 0 25 1
:8 0 6c 57 5a
6d 0 a59 2e
6d 6f 6c 6e
:6 0 6b :7 0 6d
19 :3 0 26 :a 0
3 7f :5 0 71
74 0 72 :3 0
27 :3 0 28 :3 0
29 :3 0 2a :3 0
2b :3 0 2c :3 0
e :3 0 2d :3 0
e :4 0 2e 1
:8 0 80 71 74
81 0 a59 30
81 83 80 82
:6 0 7f :7 0 81
19 :3 0 2f :a 0
4 9f :5 0 85
88 0 86 :3 0
30 :3 0 29 :3 0
30 :3 0 2a :3 0
30 :3 0 31 :3 0
30 :3 0 32 :3 0
33 :3 0 30 :3 0
1b :3 0 e :3 0
34 :3 0 35 :3 0
35 :3 0 2c :3 0
e :3 0 35 :3 0
29 :3 0 30 :3 0
29 :4 0 36 1
:8 0 a0 85 88
a1 0 a59 32
a1 a3 a0 a2
:6 0 9f :7 0 a1
ab ac 0 34
8 :3 0 9 :2 0
4 a5 a6 0
a7 :7 0 aa a8
0 a59 0 37
:6 0 38 :3 0 39
:3 0 38 :3 0 3a
:3 0 ae af 0
2 :4 0 36 b0
b2 ad b4 b3
:2 0 3b :3 0 3c
:3 0 b6 b7 0
3d :4 0 38 :3 0
3e :3 0 ba bb
0 2 :4 0 38
bc be 3f :4 0
40 :2 0 41 :3 0
3a c1 c3 :3 0
42 :4 0 40 :2 0
43 :4 0 3d c6
c8 :3 0 40 :2 0
3 :3 0 40 ca
cc :3 0 40 :2 0
43 :4 0 43 ce
d0 :3 0 40 :2 0
44 :4 0 46 d2
d4 :3 0 40 :2 0
45 :3 0 46 :3 0
5 :3 0 49 d8
da 47 :4 0 4b
d7 dd 4e d6
df :3 0 40 :2 0
48 :4 0 51 e1
e3 :3 0 54 b8
e5 :2 0 e7 59
e8 b5 e7 0
e9 5b 0 9b9
38 :3 0 39 :3 0
ea eb 0 38
:3 0 49 :3 0 ed
ee 0 15 :2 0
2 :4 0 4a :2 0
4b :2 0 15 :2 0
5d f3 f5 :3 0
60 ef f7 ec
f9 f8 :2 0 3b
:3 0 4c :3 0 fb
fc 0 3d :4 0
4d :4 0 40 :2 0
41 :3 0 64 100
102 :3 0 67 fd
104 :2 0 106 6a
107 fa 106 0
108 6c 0 9b9
a :3 0 3 :3 0
109 10a 0 9b9
18 :3 0 5 :3 0
10c 10d 0 9b9
4e :3 0 1a :4 0
112 :2 0 9b9 110
113 :3 0 4f :3 0
1a :3 0 e :4 0
118 :2 0 90a 115
116 :3 0 1a :3 0
50 :3 0 119 11a
:3 0 8 :3 0 51
:3 0 11c 11d 0
17 :2 0 11e 11f
0 121 6e 128
8 :3 0 51 :3 0
122 123 0 52
:2 0 124 125 0
127 70 129 11b
121 0 12a 0
127 0 12a 72
0 90a 8 :3 0
51 :3 0 12b 12c
0 8 :3 0 53
:2 0 54 :3 0 12e
130 0 77 12f
132 :3 0 133 :2 0
55 :8 0 137 7a
138 134 137 0
139 7c 0 90a
45 :3 0 18 :3 0
17 :2 0 7e 13a
13d 56 :2 0 17
:2 0 83 13f 141
:3 0 4e :3 0 26
:4 0 146 :2 0 6aa
144 147 :3 0 4f
:3 0 26 :3 0 10
:3 0 11 :3 0 13
:3 0 14 :4 0 14f
:2 0 646 149 150
:3 0 86 :3 0 26
:3 0 50 :3 0 151
152 :3 0 8 :3 0
51 :3 0 154 155
0 17 :2 0 156
157 0 159 8b
160 8 :3 0 51
:3 0 15a 15b 0
52 :2 0 15c 15d
0 15f 8d 161
153 159 0 162
0 15f 0 162
8f 0 646 8
:3 0 51 :3 0 163
164 0 8 :3 0
53 :2 0 54 :3 0
166 168 0 94
167 16a :3 0 16b
:2 0 55 :8 0 16f
97 170 16c 16f
0 171 99 0
646 18 :3 0 17
:2 0 172 173 0
646 57 :3 0 18
:3 0 58 :3 0 2b
:3 0 59 :3 0 11
:3 0 29 :3 0 13
:4 0 5a 1 :8 0
183 8 :3 0 51
:3 0 17e 17f 0
5b :3 0 180 181
0 183 9b 1d6
5c :3 0 8 :3 0
51 :3 0 185 186
0 5b :3 0 187
188 0 18a 9e
18c a0 18b 18a
:2 0 1d4 5d :3 0
8 :3 0 51 :3 0
18f 190 0 5b
:3 0 191 192 0
1cc 38 :3 0 39
:3 0 194 195 0
38 :3 0 49 :3 0
197 198 0 5e
:2 0 2 :4 0 5f
:2 0 4b :2 0 15
:2 0 a2 19d 19f
:3 0 a5 199 1a1
196 1a3 1a2 :2 0
3b :3 0 4c :3 0
1a5 1a6 0 3d
:4 0 60 :4 0 40
:2 0 41 :3 0 a9
1aa 1ac :3 0 40
:2 0 61 :4 0 ac
1ae 1b0 :3 0 40
:2 0 62 :4 0 af
1b2 1b4 :3 0 40
:2 0 5b :3 0 b2
1b6 1b8 :3 0 40
:2 0 63 :4 0 b5
1ba 1bc :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 b8 1bf 1c3
bc 1be 1c5 :3 0
bf 1a7 1c7 :2 0
1c9 c2 1ca 1a4
1c9 0 1cb c4
0 1cc c6 1cf
:3 0 1cf 0 1cf
1ce 1cc 1cd :6 0
1d1 7 :3 0 c9
1d3 cb 1d2 1d1
:2 0 1d4 cd :2 0
1d6 0 1d6 1d5
183 1d4 :6 0 646
6 :3 0 45 :3 0
18 :3 0 17 :2 0
d0 1d8 1db 53
:2 0 17 :2 0 d5
1dd 1df :3 0 2b
:3 0 59 :3 0 59
:3 0 11 :4 0 67
1 :8 0 1fb 50
:4 0 1e6 :3 0 68
:3 0 56 :2 0 da
1e9 1ea :3 0 8
:3 0 51 :3 0 1ec
1ed 0 17 :2 0
1ee 1ef 0 1f1
dd 1f8 8 :3 0
51 :3 0 1f2 1f3
0 52 :2 0 1f4
1f5 0 1f7 df
1f9 1eb 1f1 0
1fa 0 1f7 0
1fa e1 0 1fb
e4 24e 5c :3 0
8 :3 0 51 :3 0
1fd 1fe 0 5b
:3 0 1ff 200 0
202 e7 204 e9
203 202 :2 0 24c
5d :3 0 8 :3 0
51 :3 0 207 208
0 5b :3 0 209
20a 0 244 38
:3 0 39 :3 0 20c
20d 0 38 :3 0
49 :3 0 20f 210
0 5e :2 0 2
:4 0 69 :2 0 4b
:2 0 15 :2 0 eb
215 217 :3 0 ee
211 219 20e 21b
21a :2 0 3b :3 0
4c :3 0 21d 21e
0 3d :4 0 6a
:4 0 40 :2 0 41
:3 0 f2 222 224
:3 0 40 :2 0 61
:4 0 f5 226 228
:3 0 40 :2 0 62
:4 0 f8 22a 22c
:3 0 40 :2 0 5b
:3 0 fb 22e 230
:3 0 40 :2 0 63
:4 0 fe 232 234
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 101
237 23b 105 236
23d :3 0 108 21f
23f :2 0 241 10b
242 21c 241 0
243 10d 0 244
10f 247 :3 0 247
0 247 246 244
245 :6 0 249 9
:3 0 112 24b 114
24a 249 :2 0 24c
116 :2 0 24e 0
24e 24d 1fb 24c
:6 0 2c2 6 :3 0
6b :3 0 6c :3 0
28 :3 0 2c :3 0
e :3 0 6c :3 0
11 :4 0 6d 1
:8 0 26d 50 :4 0
258 :3 0 68 :3 0
56 :2 0 11b 25b
25c :3 0 8 :3 0
51 :3 0 25e 25f
0 17 :2 0 260
261 0 263 11e
26a 8 :3 0 51
:3 0 264 265 0
52 :2 0 266 267
0 269 120 26b
25d 263 0 26c
0 269 0 26c
122 0 26d 125
2c0 5c :3 0 8
:3 0 51 :3 0 26f
270 0 5b :3 0
271 272 0 274
128 276 12a 275
274 :2 0 2be 5d
:3 0 8 :3 0 51
:3 0 279 27a 0
5b :3 0 27b 27c
0 2b6 38 :3 0
39 :3 0 27e 27f
0 38 :3 0 49
:3 0 281 282 0
5e :2 0 2 :4 0
6e :2 0 4b :2 0
15 :2 0 12c 287
289 :3 0 12f 283
28b 280 28d 28c
:2 0 3b :3 0 4c
:3 0 28f 290 0
3d :4 0 6f :4 0
40 :2 0 41 :3 0
133 294 296 :3 0
40 :2 0 61 :4 0
136 298 29a :3 0
40 :2 0 62 :4 0
139 29c 29e :3 0
40 :2 0 5b :3 0
13c 2a0 2a2 :3 0
40 :2 0 63 :4 0
13f 2a4 2a6 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 142 2a9
2ad 146 2a8 2af
:3 0 149 291 2b1
:2 0 2b3 14c 2b4
28e 2b3 0 2b5
14e 0 2b6 150
2b9 :3 0 2b9 0
2b9 2b8 2b6 2b7
:6 0 2bb b :3 0
153 2bd 155 2bc
2bb :2 0 2be 157
:2 0 2c0 0 2c0
2bf 26d 2be :6 0
2c2 6 :3 0 15a
2c3 1e0 2c2 0
2c4 15d 0 646
33 :3 0 27 :3 0
10 :3 0 32 :4 0
70 1 :8 0 2df
50 :4 0 2ca :3 0
68 :3 0 56 :2 0
161 2cd 2ce :3 0
8 :3 0 51 :3 0
2d0 2d1 0 17
:2 0 2d2 2d3 0
2d5 164 2dc 8
:3 0 51 :3 0 2d6
2d7 0 52 :2 0
2d8 2d9 0 2db
166 2dd 2cf 2d5
0 2de 0 2db
0 2de 168 0
2df 16b 332 5c
:3 0 8 :3 0 51
:3 0 2e1 2e2 0
5b :3 0 2e3 2e4
0 2e6 16e 2e8
170 2e7 2e6 :2 0
330 5d :3 0 8
:3 0 51 :3 0 2eb
2ec 0 5b :3 0
2ed 2ee 0 328
38 :3 0 39 :3 0
2f0 2f1 0 38
:3 0 49 :3 0 2f3
2f4 0 5e :2 0
2 :4 0 71 :2 0
4b :2 0 15 :2 0
172 2f9 2fb :3 0
175 2f5 2fd 2f2
2ff 2fe :2 0 3b
:3 0 4c :3 0 301
302 0 3d :4 0
72 :4 0 40 :2 0
41 :3 0 179 306
308 :3 0 40 :2 0
61 :4 0 17c 30a
30c :3 0 40 :2 0
62 :4 0 17f 30e
310 :3 0 40 :2 0
5b :3 0 182 312
314 :3 0 40 :2 0
63 :4 0 185 316
318 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
188 31b 31f 18c
31a 321 :3 0 18f
303 323 :2 0 325
192 326 300 325
0 327 194 0
328 196 32b :3 0
32b 0 32b 32a
328 329 :6 0 32d
d :3 0 199 32f
19b 32e 32d :2 0
330 19d :2 0 332
0 332 331 2df
330 :6 0 646 6
:3 0 8 :3 0 51
:3 0 334 335 0
8 :3 0 56 :2 0
54 :3 0 337 339
0 1a2 338 33b
:3 0 33c :2 0 34
:3 0 2c :3 0 e
:3 0 29 :3 0 13
:4 0 73 1 :8 0
359 50 :4 0 344
:3 0 68 :3 0 56
:2 0 1a7 347 348
:3 0 8 :3 0 51
:3 0 34a 34b 0
17 :2 0 34c 34d
0 34f 1aa 356
8 :3 0 51 :3 0
350 351 0 52
:2 0 352 353 0
355 1ac 357 349
34f 0 358 0
355 0 358 1ae
0 359 1b1 3ac
5c :3 0 8 :3 0
51 :3 0 35b 35c
0 5b :3 0 35d
35e 0 360 1b4
362 1b6 361 360
:2 0 3aa 5d :3 0
8 :3 0 51 :3 0
365 366 0 5b
:3 0 367 368 0
3a2 38 :3 0 39
:3 0 36a 36b 0
38 :3 0 49 :3 0
36d 36e 0 5e
:2 0 2 :4 0 74
:2 0 4b :2 0 15
:2 0 1b8 373 375
:3 0 1bb 36f 377
36c 379 378 :2 0
3b :3 0 4c :3 0
37b 37c 0 3d
:4 0 75 :4 0 40
:2 0 41 :3 0 1bf
380 382 :3 0 40
:2 0 61 :4 0 1c2
384 386 :3 0 40
:2 0 62 :4 0 1c5
388 38a :3 0 40
:2 0 5b :3 0 1c8
38c 38e :3 0 40
:2 0 63 :4 0 1cb
390 392 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 1ce 395 399
1d2 394 39b :3 0
1d5 37d 39d :2 0
39f 1d8 3a0 37a
39f 0 3a1 1da
0 3a2 1dc 3a5
:3 0 3a5 0 3a5
3a4 3a2 3a3 :6 0
3a7 f :3 0 1df
3a9 1e1 3a8 3a7
:2 0 3aa 1e3 :2 0
3ac 0 3ac 3ab
359 3aa :6 0 4f1
6 :3 0 64 :3 0
14 :3 0 15 :2 0
15 :2 0 1e6 3ae
3b2 56 :2 0 17
:4 0 1ec 3b4 3b6
:3 0 76 :3 0 c
:3 0 77 :3 0 29
:3 0 13 :4 0 78
1 :8 0 3c3 8
:3 0 51 :3 0 3be
3bf 0 5b :3 0
3c0 3c1 0 3c3
1ef 416 5c :3 0
8 :3 0 51 :3 0
3c5 3c6 0 5b
:3 0 3c7 3c8 0
3ca 1f2 3cc 1f4
3cb 3ca :2 0 414
5d :3 0 8 :3 0
51 :3 0 3cf 3d0
0 5b :3 0 3d1
3d2 0 40c 38
:3 0 39 :3 0 3d4
3d5 0 38 :3 0
49 :3 0 3d7 3d8
0 5e :2 0 2
:4 0 79 :2 0 4b
:2 0 15 :2 0 1f6
3dd 3df :3 0 1f9
3d9 3e1 3d6 3e3
3e2 :2 0 3b :3 0
4c :3 0 3e5 3e6
0 3d :4 0 7a
:4 0 40 :2 0 41
:3 0 1fd 3ea 3ec
:3 0 40 :2 0 61
:4 0 200 3ee 3f0
:3 0 40 :2 0 62
:4 0 203 3f2 3f4
:3 0 40 :2 0 5b
:3 0 206 3f6 3f8
:3 0 40 :2 0 63
:4 0 209 3fa 3fc
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 20c
3ff 403 210 3fe
405 :3 0 213 3e7
407 :2 0 409 216
40a 3e4 409 0
40b 218 0 40c
21a 40f :3 0 40f
0 40f 40e 40c
40d :6 0 411 11
:3 0 21d 413 21f
412 411 :2 0 414
221 :2 0 416 0
416 415 3c3 414
:6 0 418 6 :3 0
224 47a 7b :3 0
c :3 0 7c :3 0
7d :3 0 13 :4 0
7e 1 :8 0 424
8 :3 0 51 :3 0
41f 420 0 5b
:3 0 421 422 0
424 226 477 5c
:3 0 8 :3 0 51
:3 0 426 427 0
5b :3 0 428 429
0 42b 229 42d
22b 42c 42b :2 0
475 5d :3 0 8
:3 0 51 :3 0 430
431 0 5b :3 0
432 433 0 46d
38 :3 0 39 :3 0
435 436 0 38
:3 0 49 :3 0 438
439 0 5e :2 0
2 :4 0 7f :2 0
4b :2 0 15 :2 0
22d 43e 440 :3 0
230 43a 442 437
444 443 :2 0 3b
:3 0 4c :3 0 446
447 0 3d :4 0
80 :4 0 40 :2 0
41 :3 0 234 44b
44d :3 0 40 :2 0
61 :4 0 237 44f
451 :3 0 40 :2 0
62 :4 0 23a 453
455 :3 0 40 :2 0
5b :3 0 23d 457
459 :3 0 40 :2 0
63 :4 0 240 45b
45d :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
243 460 464 247
45f 466 :3 0 24a
448 468 :2 0 46a
24d 46b 445 46a
0 46c 24f 0
46d 251 470 :3 0
470 0 470 46f
46d 46e :6 0 472
13 :3 0 254 474
256 473 472 :2 0
475 258 :2 0 477
0 477 476 424
475 :6 0 479 6
:3 0 25b 47b 3b7
418 0 47c 0
479 0 47c 25d
0 4f1 1c :3 0
81 :3 0 82 :3 0
81 :3 0 c :3 0
2c :3 0 e :3 0
1b :3 0 e :4 0
83 1 :8 0 49c
50 :4 0 487 :3 0
68 :3 0 56 :2 0
262 48a 48b :3 0
8 :3 0 51 :3 0
48d 48e 0 17
:2 0 48f 490 0
492 265 499 8
:3 0 51 :3 0 493
494 0 52 :2 0
495 496 0 498
267 49a 48c 492
0 49b 0 498
0 49b 269 0
49c 26c 4ef 5c
:3 0 8 :3 0 51
:3 0 49e 49f 0
5b :3 0 4a0 4a1
0 4a3 26f 4a5
271 4a4 4a3 :2 0
4ed 5d :3 0 8
:3 0 51 :3 0 4a8
4a9 0 5b :3 0
4aa 4ab 0 4e5
38 :3 0 39 :3 0
4ad 4ae 0 38
:3 0 49 :3 0 4b0
4b1 0 5e :2 0
2 :4 0 84 :2 0
4b :2 0 15 :2 0
273 4b6 4b8 :3 0
276 4b2 4ba 4af
4bc 4bb :2 0 3b
:3 0 4c :3 0 4be
4bf 0 3d :4 0
85 :4 0 40 :2 0
41 :3 0 27a 4c3
4c5 :3 0 40 :2 0
61 :4 0 27d 4c7
4c9 :3 0 40 :2 0
62 :4 0 280 4cb
4cd :3 0 40 :2 0
5b :3 0 283 4cf
4d1 :3 0 40 :2 0
63 :4 0 286 4d3
4d5 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
289 4d8 4dc 28d
4d7 4de :3 0 290
4c0 4e0 :2 0 4e2
293 4e3 4bd 4e2
0 4e4 295 0
4e5 297 4e8 :3 0
4e8 0 4e8 4e7
4e5 4e6 :6 0 4ea
15 :3 0 29a 4ec
29c 4eb 4ea :2 0
4ed 29e :2 0 4ef
0 4ef 4ee 49c
4ed :6 0 4f1 6
:3 0 2a1 565 33
:3 0 31 :3 0 86
:3 0 87 :3 0 31
:3 0 27 :3 0 10
:4 0 88 1 :8 0
50f 50 :4 0 4fa
:3 0 68 :3 0 56
:2 0 2a7 4fd 4fe
:3 0 8 :3 0 51
:3 0 500 501 0
17 :2 0 502 503
0 505 2aa 50c
8 :3 0 51 :3 0
506 507 0 52
:2 0 508 509 0
50b 2ac 50d 4ff
505 0 50e 0
50b 0 50e 2ae
0 50f 2b1 562
5c :3 0 8 :3 0
51 :3 0 511 512
0 5b :3 0 513
514 0 516 2b4
518 2b6 517 516
:2 0 560 5d :3 0
8 :3 0 51 :3 0
51b 51c 0 5b
:3 0 51d 51e 0
558 38 :3 0 39
:3 0 520 521 0
38 :3 0 49 :3 0
523 524 0 5e
:2 0 2 :4 0 89
:2 0 4b :2 0 15
:2 0 2b8 529 52b
:3 0 2bb 525 52d
522 52f 52e :2 0
3b :3 0 4c :3 0
531 532 0 3d
:4 0 8a :4 0 40
:2 0 41 :3 0 2bf
536 538 :3 0 40
:2 0 61 :4 0 2c2
53a 53c :3 0 40
:2 0 62 :4 0 2c5
53e 540 :3 0 40
:2 0 5b :3 0 2c8
542 544 :3 0 40
:2 0 63 :4 0 2cb
546 548 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 2ce 54b 54f
2d2 54a 551 :3 0
2d5 533 553 :2 0
555 2d8 556 530
555 0 557 2da
0 558 2dc 55b
:3 0 55b 0 55b
55a 558 559 :6 0
55d 17 :3 0 2df
55f 2e1 55e 55d
:2 0 560 2e3 :2 0
562 0 562 561
50f 560 :6 0 564
6 :3 0 2e6 566
33d 4f1 0 567
0 564 0 567
2e8 0 646 2b
:3 0 28 :3 0 11
:4 0 8b 1 :8 0
581 50 :4 0 56c
:3 0 68 :3 0 56
:2 0 2ed 56f 570
:3 0 8 :3 0 51
:3 0 572 573 0
17 :2 0 574 575
0 577 2f0 57e
8 :3 0 51 :3 0
578 579 0 52
:2 0 57a 57b 0
57d 2f2 57f 571
577 0 580 0
57d 0 580 2f4
0 581 2f7 5d4
5c :3 0 8 :3 0
51 :3 0 583 584
0 5b :3 0 585
586 0 588 2fa
58a 2fc 589 588
:2 0 5d2 5d :3 0
8 :3 0 51 :3 0
58d 58e 0 5b
:3 0 58f 590 0
5ca 38 :3 0 39
:3 0 592 593 0
38 :3 0 49 :3 0
595 596 0 5e
:2 0 2 :4 0 8c
:2 0 4b :2 0 15
:2 0 2fe 59b 59d
:3 0 301 597 59f
594 5a1 5a0 :2 0
3b :3 0 4c :3 0
5a3 5a4 0 3d
:4 0 8d :4 0 40
:2 0 41 :3 0 305
5a8 5aa :3 0 40
:2 0 61 :4 0 308
5ac 5ae :3 0 40
:2 0 62 :4 0 30b
5b0 5b2 :3 0 40
:2 0 5b :3 0 30e
5b4 5b6 :3 0 40
:2 0 63 :4 0 311
5b8 5ba :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 314 5bd 5c1
318 5bc 5c3 :3 0
31b 5a5 5c5 :2 0
5c7 31e 5c8 5a2
5c7 0 5c9 320
0 5ca 322 5cd
:3 0 5cd 0 5cd
5cc 5ca 5cb :6 0
5cf 19 :3 0 325
5d1 327 5d0 5cf
:2 0 5d2 329 :2 0
5d4 0 5d4 5d3
581 5d2 :6 0 646
6 :3 0 6b :3 0
2c :3 0 e :3 0
28 :3 0 11 :4 0
8e 1 :8 0 5f1
50 :4 0 5dc :3 0
68 :3 0 56 :2 0
32e 5df 5e0 :3 0
8 :3 0 51 :3 0
5e2 5e3 0 17
:2 0 5e4 5e5 0
5e7 331 5ee 8
:3 0 51 :3 0 5e8
5e9 0 52 :2 0
5ea 5eb 0 5ed
333 5ef 5e1 5e7
0 5f0 0 5ed
0 5f0 335 0
5f1 338 644 5c
:3 0 8 :3 0 51
:3 0 5f3 5f4 0
5b :3 0 5f5 5f6
0 5f8 33b 5fa
33d 5f9 5f8 :2 0
642 5d :3 0 8
:3 0 51 :3 0 5fd
5fe 0 5b :3 0
5ff 600 0 63a
38 :3 0 39 :3 0
602 603 0 38
:3 0 49 :3 0 605
606 0 5e :2 0
2 :4 0 8f :2 0
4b :2 0 15 :2 0
33f 60b 60d :3 0
342 607 60f 604
611 610 :2 0 3b
:3 0 4c :3 0 613
614 0 3d :4 0
90 :4 0 40 :2 0
41 :3 0 346 618
61a :3 0 40 :2 0
61 :4 0 349 61c
61e :3 0 40 :2 0
62 :4 0 34c 620
622 :3 0 40 :2 0
5b :3 0 34f 624
626 :3 0 40 :2 0
63 :4 0 352 628
62a :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
355 62d 631 359
62c 633 :3 0 35c
615 635 :2 0 637
35f 638 612 637
0 639 361 0
63a 363 63d :3 0
63d 0 63d 63c
63a 63b :6 0 63f
1b :3 0 366 641
368 640 63f :2 0
642 36a :2 0 644
0 644 643 5f1
642 :6 0 646 6
:3 0 36d 648 4f
:4 0 646 :4 0 6aa
91 :3 0 26 :4 0
64c :2 0 652 64a
0 8 :3 0 51
:3 0 64d 64e 0
5b :3 0 64f 650
0 652 378 6a5
5c :3 0 8 :3 0
51 :3 0 654 655
0 5b :3 0 656
657 0 659 37b
65b 37d 65a 659
:2 0 6a3 5d :3 0
8 :3 0 51 :3 0
65e 65f 0 5b
:3 0 660 661 0
69b 38 :3 0 39
:3 0 663 664 0
38 :3 0 49 :3 0
666 667 0 5e
:2 0 2 :4 0 92
:2 0 4b :2 0 15
:2 0 37f 66c 66e
:3 0 382 668 670
665 672 671 :2 0
3b :3 0 4c :3 0
674 675 0 3d
:4 0 93 :4 0 40
:2 0 41 :3 0 386
679 67b :3 0 40
:2 0 61 :4 0 389
67d 67f :3 0 40
:2 0 62 :4 0 38c
681 683 :3 0 40
:2 0 5b :3 0 38f
685 687 :3 0 40
:2 0 63 :4 0 392
689 68b :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 395 68e 692
399 68d 694 :3 0
39c 676 696 :2 0
698 39f 699 673
698 0 69a 3a1
0 69b 3a3 69e
:3 0 69e 0 69e
69d 69b 69c :6 0
6a0 1d :3 0 3a6
6a2 3a8 6a1 6a0
:2 0 6a3 3aa :2 0
6a5 0 6a5 6a4
652 6a3 :6 0 6aa
5 :3 0 94 :4 0
94 1 :8 0 6aa
95 :3 0 3ad 908
45 :3 0 18 :3 0
17 :2 0 3b2 6ab
6ae 56 :2 0 15
:2 0 3b7 6b0 6b2
:3 0 4e :3 0 2f
:4 0 6b7 :2 0 906
6b5 6b8 :3 0 4f
:3 0 2f :3 0 13
:3 0 14 :3 0 16
:3 0 12 :4 0 6c0
:2 0 8a3 6ba 6c1
:3 0 3ba :3 0 2f
:3 0 50 :3 0 6c2
6c3 :3 0 8 :3 0
51 :3 0 6c5 6c6
0 17 :2 0 6c7
6c8 0 6ca 3bf
6d1 8 :3 0 51
:3 0 6cb 6cc 0
52 :2 0 6cd 6ce
0 6d0 3c1 6d2
6c4 6ca 0 6d3
0 6d0 0 6d3
3c3 0 8a3 8
:3 0 51 :3 0 6d4
6d5 0 8 :3 0
53 :2 0 54 :3 0
6d7 6d9 0 3c8
6d8 6db :3 0 6dc
:2 0 55 :8 0 6e0
3cb 6e1 6dd 6e0
0 6e2 3cd 0
8a3 64 :3 0 14
:3 0 15 :2 0 15
:2 0 3cf 6e3 6e7
56 :2 0 17 :4 0
3d5 6e9 6eb :3 0
76 :3 0 c :3 0
77 :3 0 29 :3 0
13 :4 0 96 1
:8 0 6f8 8 :3 0
51 :3 0 6f3 6f4
0 5b :3 0 6f5
6f6 0 6f8 3d8
74b 5c :3 0 8
:3 0 51 :3 0 6fa
6fb 0 5b :3 0
6fc 6fd 0 6ff
3db 701 3dd 700
6ff :2 0 749 5d
:3 0 8 :3 0 51
:3 0 704 705 0
5b :3 0 706 707
0 741 38 :3 0
39 :3 0 709 70a
0 38 :3 0 49
:3 0 70c 70d 0
5e :2 0 2 :4 0
97 :2 0 4b :2 0
15 :2 0 3df 712
714 :3 0 3e2 70e
716 70b 718 717
:2 0 3b :3 0 4c
:3 0 71a 71b 0
3d :4 0 98 :4 0
40 :2 0 41 :3 0
3e6 71f 721 :3 0
40 :2 0 61 :4 0
3e9 723 725 :3 0
40 :2 0 62 :4 0
3ec 727 729 :3 0
40 :2 0 5b :3 0
3ef 72b 72d :3 0
40 :2 0 63 :4 0
3f2 72f 731 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 3f5 734
738 3f9 733 73a
:3 0 3fc 71c 73c
:2 0 73e 3ff 73f
719 73e 0 740
401 0 741 403
744 :3 0 744 0
744 743 741 742
:6 0 746 20 :3 0
406 748 408 747
746 :2 0 749 40a
:2 0 74b 0 74b
74a 6f8 749 :6 0
74d 1f :3 0 40d
7af 7b :3 0 c
:3 0 7c :3 0 7d
:3 0 13 :4 0 99
1 :8 0 759 8
:3 0 51 :3 0 754
755 0 5b :3 0
756 757 0 759
40f 7ac 5c :3 0
8 :3 0 51 :3 0
75b 75c 0 5b
:3 0 75d 75e 0
760 412 762 414
761 760 :2 0 7aa
5d :3 0 8 :3 0
51 :3 0 765 766
0 5b :3 0 767
768 0 7a2 38
:3 0 39 :3 0 76a
76b 0 38 :3 0
49 :3 0 76d 76e
0 5e :2 0 2
:4 0 9a :2 0 4b
:2 0 15 :2 0 416
773 775 :3 0 419
76f 777 76c 779
778 :2 0 3b :3 0
4c :3 0 77b 77c
0 3d :4 0 9b
:4 0 40 :2 0 41
:3 0 41d 780 782
:3 0 40 :2 0 61
:4 0 420 784 786
:3 0 40 :2 0 62
:4 0 423 788 78a
:3 0 40 :2 0 5b
:3 0 426 78c 78e
:3 0 40 :2 0 63
:4 0 429 790 792
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 42c
795 799 430 794
79b :3 0 433 77d
79d :2 0 79f 436
7a0 77a 79f 0
7a1 438 0 7a2
43a 7a5 :3 0 7a5
0 7a5 7a4 7a2
7a3 :6 0 7a7 22
:3 0 43d 7a9 43f
7a8 7a7 :2 0 7aa
441 :2 0 7ac 0
7ac 7ab 759 7aa
:6 0 7ae 1f :3 0
444 7b0 6ec 74d
0 7b1 0 7ae
0 7b1 446 0
8a3 1c :3 0 81
:3 0 9c :3 0 81
:3 0 c :3 0 81
:3 0 81 :3 0 c
:3 0 2c :3 0 e
:3 0 1b :3 0 e
:4 0 9d 1 :8 0
7d4 50 :4 0 7bf
:3 0 68 :3 0 56
:2 0 44b 7c2 7c3
:3 0 8 :3 0 51
:3 0 7c5 7c6 0
17 :2 0 7c7 7c8
0 7ca 44e 7d1
8 :3 0 51 :3 0
7cb 7cc 0 52
:2 0 7cd 7ce 0
7d0 450 7d2 7c4
7ca 0 7d3 0
7d0 0 7d3 452
0 7d4 455 827
5c :3 0 8 :3 0
51 :3 0 7d6 7d7
0 5b :3 0 7d8
7d9 0 7db 458
7dd 45a 7dc 7db
:2 0 825 5d :3 0
8 :3 0 51 :3 0
7e0 7e1 0 5b
:3 0 7e2 7e3 0
81d 38 :3 0 39
:3 0 7e5 7e6 0
38 :3 0 49 :3 0
7e8 7e9 0 5e
:2 0 2 :4 0 9e
:2 0 4b :2 0 15
:2 0 45c 7ee 7f0
:3 0 45f 7ea 7f2
7e7 7f4 7f3 :2 0
3b :3 0 4c :3 0
7f6 7f7 0 3d
:4 0 9f :4 0 40
:2 0 41 :3 0 463
7fb 7fd :3 0 40
:2 0 61 :4 0 466
7ff 801 :3 0 40
:2 0 62 :4 0 469
803 805 :3 0 40
:2 0 5b :3 0 46c
807 809 :3 0 40
:2 0 63 :4 0 46f
80b 80d :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 472 810 814
476 80f 816 :3 0
479 7f8 818 :2 0
81a 47c 81b 7f5
81a 0 81c 47e
0 81d 480 820
:3 0 820 0 820
81f 81d 81e :6 0
822 24 :3 0 483
824 485 823 822
:2 0 825 487 :2 0
827 0 827 826
7d4 825 :6 0 8a3
1f :3 0 34 :3 0
2c :3 0 29 :3 0
31 :3 0 32 :3 0
2a :3 0 a0 :3 0
a1 :3 0 e :3 0
13 :3 0 16 :3 0
12 :3 0 14 :3 0
1e :3 0 a2 :4 0
a3 1 :8 0 84e
50 :4 0 839 :3 0
68 :3 0 56 :2 0
48c 83c 83d :3 0
8 :3 0 51 :3 0
83f 840 0 17
:2 0 841 842 0
844 48f 84b 8
:3 0 51 :3 0 845
846 0 52 :2 0
847 848 0 84a
491 84c 83e 844
0 84d 0 84a
0 84d 493 0
84e 496 8a1 5c
:3 0 8 :3 0 51
:3 0 850 851 0
5b :3 0 852 853
0 855 499 857
49b 856 855 :2 0
89f 5d :3 0 8
:3 0 51 :3 0 85a
85b 0 5b :3 0
85c 85d 0 897
38 :3 0 39 :3 0
85f 860 0 38
:3 0 49 :3 0 862
863 0 5e :2 0
2 :4 0 a4 :2 0
4b :2 0 15 :2 0
49d 868 86a :3 0
4a0 864 86c 861
86e 86d :2 0 3b
:3 0 4c :3 0 870
871 0 3d :4 0
a5 :4 0 40 :2 0
41 :3 0 4a4 875
877 :3 0 40 :2 0
61 :4 0 4a7 879
87b :3 0 40 :2 0
62 :4 0 4aa 87d
87f :3 0 40 :2 0
5b :3 0 4ad 881
883 :3 0 40 :2 0
63 :4 0 4b0 885
887 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
4b3 88a 88e 4b7
889 890 :3 0 4ba
872 892 :2 0 894
4bd 895 86f 894
0 896 4bf 0
897 4c1 89a :3 0
89a 0 89a 899
897 898 :6 0 89c
26 :3 0 4c4 89e
4c6 89d 89c :2 0
89f 4c8 :2 0 8a1
0 8a1 8a0 84e
89f :6 0 8a3 1f
:3 0 4cb 8a5 4f
:4 0 8a3 :4 0 906
91 :3 0 2f :4 0
8a9 :2 0 8af 8a7
0 8 :3 0 51
:3 0 8aa 8ab 0
5b :3 0 8ac 8ad
0 8af 4d2 902
5c :3 0 8 :3 0
51 :3 0 8b1 8b2
0 5b :3 0 8b3
8b4 0 8b6 4d5
8b8 4d7 8b7 8b6
:2 0 900 5d :3 0
8 :3 0 51 :3 0
8bb 8bc 0 5b
:3 0 8bd 8be 0
8f8 38 :3 0 39
:3 0 8c0 8c1 0
38 :3 0 49 :3 0
8c3 8c4 0 5e
:2 0 2 :4 0 a6
:2 0 4b :2 0 15
:2 0 4d9 8c9 8cb
:3 0 4dc 8c5 8cd
8c2 8cf 8ce :2 0
3b :3 0 4c :3 0
8d1 8d2 0 3d
:4 0 a7 :4 0 40
:2 0 41 :3 0 4e0
8d6 8d8 :3 0 40
:2 0 61 :4 0 4e3
8da 8dc :3 0 40
:2 0 62 :4 0 4e6
8de 8e0 :3 0 40
:2 0 5b :3 0 4e9
8e2 8e4 :3 0 40
:2 0 63 :4 0 4ec
8e6 8e8 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 4ef 8eb 8ef
4f3 8ea 8f1 :3 0
4f6 8d3 8f3 :2 0
8f5 4f9 8f6 8d0
8f5 0 8f7 4fb
0 8f8 4fd 8fb
:3 0 8fb 0 8fb
8fa 8f8 8f9 :6 0
8fd 28 :3 0 500
8ff 502 8fe 8fd
:2 0 900 504 :2 0
902 0 902 901
8af 900 :6 0 906
5 :3 0 94 :4 0
94 1 :8 0 906
507 907 6b3 906
0 909 142 6aa
0 909 50c 0
90a 50f 90c 4f
:4 0 90a :4 0 9b9
91 :3 0 1a :4 0
910 :2 0 916 90e
0 8 :3 0 51
:3 0 911 912 0
5b :3 0 913 914
0 916 514 969
5c :3 0 8 :3 0
51 :3 0 918 919
0 5b :3 0 91a
91b 0 91d 517
91f 519 91e 91d
:2 0 967 5d :3 0
8 :3 0 51 :3 0
922 923 0 5b
:3 0 924 925 0
95f 38 :3 0 39
:3 0 927 928 0
38 :3 0 49 :3 0
92a 92b 0 5e
:2 0 2 :4 0 a8
:2 0 4b :2 0 15
:2 0 51b 930 932
:3 0 51e 92c 934
929 936 935 :2 0
3b :3 0 4c :3 0
938 939 0 3d
:4 0 a9 :4 0 40
:2 0 41 :3 0 522
93d 93f :3 0 40
:2 0 61 :4 0 525
941 943 :3 0 40
:2 0 62 :4 0 528
945 947 :3 0 40
:2 0 5b :3 0 52b
949 94b :3 0 40
:2 0 63 :4 0 52e
94d 94f :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 531 952 956
535 951 958 :3 0
538 93a 95a :2 0
95c 53b 95d 937
95c 0 95e 53d
0 95f 53f 962
:3 0 962 0 962
961 95f 960 :6 0
964 2a :3 0 542
966 544 965 964
:2 0 967 546 :2 0
969 0 969 968
916 967 :6 0 9b9
1 :3 0 38 :3 0
39 :3 0 96b 96c
0 38 :3 0 49
:3 0 96e 96f 0
aa :2 0 2 :4 0
ab :2 0 4b :2 0
15 :2 0 549 974
976 :3 0 54c 970
978 96d 97a 979
:2 0 3b :3 0 4c
:3 0 97c 97d 0
3d :4 0 ac :4 0
40 :2 0 41 :3 0
550 981 983 :3 0
40 :2 0 61 :4 0
553 985 987 :3 0
40 :2 0 ad :4 0
556 989 98b :3 0
40 :2 0 45 :3 0
46 :3 0 8 :3 0
51 :3 0 990 991
0 559 98f 993
47 :4 0 55b 98e
996 55e 98d 998
:3 0 40 :2 0 ae
:4 0 561 99a 99c
:3 0 40 :2 0 43
:4 0 564 99e 9a0
:3 0 40 :2 0 a
:3 0 567 9a2 9a4
:3 0 40 :2 0 43
:4 0 56a 9a6 9a8
:3 0 56d 97e 9aa
:2 0 9ac 570 9ad
97b 9ac 0 9ae
572 0 9b9 af
:3 0 b0 :3 0 9af
9b0 0 8 :3 0
51 :3 0 9b2 9b3
0 a :3 0 68
:3 0 574 9b1 9b7
:2 0 9b9 578 a5a
8 :3 0 b1 :2 0
4 9ba 9bb 0
38 :3 0 39 :3 0
9bd 9be 0 38
:3 0 49 :3 0 9c0
9c1 0 5e :2 0
2 :4 0 b2 :2 0
4b :2 0 15 :2 0
582 9c6 9c8 :3 0
585 9c2 9ca 9bf
9cc 9cb :2 0 3b
:3 0 4c :3 0 9ce
9cf 0 3d :4 0
b3 :4 0 40 :2 0
41 :3 0 589 9d3
9d5 :3 0 58c 9d0
9d7 :2 0 9f0 3b
:3 0 4c :3 0 9d9
9da 0 3d :4 0
b4 :4 0 40 :2 0
8 :3 0 b5 :3 0
9df 9e0 0 58f
9de 9e2 :3 0 40
:2 0 ae :4 0 592
9e4 9e6 :3 0 40
:2 0 8 :3 0 b6
:3 0 9e9 9ea 0
595 9e8 9ec :3 0
598 9db 9ee :2 0
9f0 59b 9f1 9cd
9f0 0 9f2 59e
0 a02 4e :3 0
37 :3 0 8 :3 0
b5 :3 0 b7 :3 0
8 :3 0 b6 :3 0
b8 :3 0 58 :4 0
b9 1 :a 0 9fe
:2 0 a02 9f4 9fc
:2 0 7 :3 0 37
:3 0 a00 :2 0 a02
5a0 a04 5a4 a03
a02 :2 0 a58 5d
:3 0 8 :3 0 51
:3 0 a07 a08 0
5b :3 0 a09 a0a
0 a50 38 :3 0
39 :3 0 a0c a0d
0 38 :3 0 49
:3 0 a0f a10 0
5e :2 0 2 :4 0
ba :2 0 4b :2 0
15 :2 0 5a6 a15
a17 :3 0 5a9 a11
a19 a0e a1b a1a
:2 0 3b :3 0 4c
:3 0 a1d a1e 0
3d :4 0 bb :4 0
40 :2 0 41 :3 0
5ad a22 a24 :3 0
5b0 a1f a26 :2 0
a40 3b :3 0 4c
:3 0 a28 a29 0
3d :4 0 62 :4 0
40 :2 0 5b :3 0
5b3 a2d a2f :3 0
40 :2 0 63 :4 0
5b6 a31 a33 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 5b9 a36
a3a 5bd a35 a3c
:3 0 5c0 a2a a3e
:2 0 a40 5c3 a41
a1c a40 0 a42
5c6 0 a50 4e
:3 0 37 :3 0 b7
:3 0 8 :3 0 b6
:3 0 b8 :3 0 58
:4 0 bc 1 :a 0
a4c :2 0 a50 a44
a4a :2 0 7 :3 0
37 :3 0 a4e :2 0
a50 5c8 a53 :3 0
a53 0 a53 a52
a50 a51 :6 0 a55
1 :3 0 5cd a57
5cf a56 a55 :2 0
a58 5d1 :2 0 a5a
5d4 a5a a59 9b9
a58 :6 0 a5b :2 0
2 10 a5a a5e
:3 0 a5d a5b a5f
:8 0 
5e3
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1b 1 19
1 22 1 20
1 29 1 27
1 30 1 2e
1 37 1 35
1 3e 1 3c
1 45 1 43
1 4a 1 50
1 6a 1 7e
1 9e 1 a4
1 b1 1 bd
2 c0 c2 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 1
d9 2 db dc
2 d5 de 2
e0 e2 4 b9
bf c4 e4 1
e6 1 e8 2
f2 f4 3 f0
f1 f6 2 ff
101 2 fe 103
1 105 1 107
1 120 1 126
2 128 129 1
131 2 12d 131
1 136 1 138
2 13b 13c 1
140 2 13e 140
4 14a 14b 14c
14d 1 158 1
15e 2 160 161
1 169 2 165
169 1 16e 1
170 2 17d 182
1 189 1 184
2 19c 19e 3
19a 19b 1a0 2
1a9 1ab 2 1ad
1af 2 1b1 1b3
2 1b5 1b7 2
1b9 1bb 3 1c0
1c1 1c2 2 1bd
1c4 2 1a8 1c6
1 1c8 1 1ca
2 193 1cb 1
1cf 1 18e 2
18c 1d3 2 1d9
1da 1 1de 2
1dc 1de 1 1e8
2 1e7 1e8 1
1f0 1 1f6 2
1f8 1f9 2 1e5
1fa 1 201 1
1fc 2 214 216
3 212 213 218
2 221 223 2
225 227 2 229
22b 2 22d 22f
2 231 233 3
238 239 23a 2
235 23c 2 220
23e 1 240 1
242 2 20b 243
1 247 1 206
2 204 24b 1
25a 2 259 25a
1 262 1 268
2 26a 26b 2
257 26c 1 273
1 26e 2 286
288 3 284 285
28a 2 293 295
2 297 299 2
29b 29d 2 29f
2a1 2 2a3 2a5
3 2aa 2ab 2ac
2 2a7 2ae 2
292 2b0 1 2b2
1 2b4 2 27d
2b5 1 2b9 1
278 2 276 2bd
2 24e 2c0 1
2c3 1 2cc 2
2cb 2cc 1 2d4
1 2da 2 2dc
2dd 2 2c9 2de
1 2e5 1 2e0
2 2f8 2fa 3
2f6 2f7 2fc 2
305 307 2 309
30b 2 30d 30f
2 311 313 2
315 317 3 31c
31d 31e 2 319
320 2 304 322
1 324 1 326
2 2ef 327 1
32b 1 2ea 2
2e8 32f 1 33a
2 336 33a 1
346 2 345 346
1 34e 1 354
2 356 357 2
343 358 1 35f
1 35a 2 372
374 3 370 371
376 2 37f 381
2 383 385 2
387 389 2 38b
38d 2 38f 391
3 396 397 398
2 393 39a 2
37e 39c 1 39e
1 3a0 2 369
3a1 1 3a5 1
364 2 362 3a9
3 3af 3b0 3b1
1 3b5 2 3b3
3b5 2 3bd 3c2
1 3c9 1 3c4
2 3dc 3de 3
3da 3db 3e0 2
3e9 3eb 2 3ed
3ef 2 3f1 3f3
2 3f5 3f7 2
3f9 3fb 3 400
401 402 2 3fd
404 2 3e8 406
1 408 1 40a
2 3d3 40b 1
40f 1 3ce 2
3cc 413 1 416
2 41e 423 1
42a 1 425 2
43d 43f 3 43b
43c 441 2 44a
44c 2 44e 450
2 452 454 2
456 458 2 45a
45c 3 461 462
463 2 45e 465
2 449 467 1
469 1 46b 2
434 46c 1 470
1 42f 2 42d
474 1 477 2
47a 47b 1 489
2 488 489 1
491 1 497 2
499 49a 2 486
49b 1 4a2 1
49d 2 4b5 4b7
3 4b3 4b4 4b9
2 4c2 4c4 2
4c6 4c8 2 4ca
4cc 2 4ce 4d0
2 4d2 4d4 3
4d9 4da 4db 2
4d6 4dd 2 4c1
4df 1 4e1 1
4e3 2 4ac 4e4
1 4e8 1 4a7
2 4a5 4ec 3
3ac 47c 4ef 1
4fc 2 4fb 4fc
1 504 1 50a
2 50c 50d 2
4f9 50e 1 515
1 510 2 528
52a 3 526 527
52c 2 535 537
2 539 53b 2
53d 53f 2 541
543 2 545 547
3 54c 54d 54e
2 549 550 2
534 552 1 554
1 556 2 51f
557 1 55b 1
51a 2 518 55f
1 562 2 565
566 1 56e 2
56d 56e 1 576
1 57c 2 57e
57f 2 56b 580
1 587 1 582
2 59a 59c 3
598 599 59e 2
5a7 5a9 2 5ab
5ad 2 5af 5b1
2 5b3 5b5 2
5b7 5b9 3 5be
5bf 5c0 2 5bb
5c2 2 5a6 5c4
1 5c6 1 5c8
2 591 5c9 1
5cd 1 58c 2
58a 5d1 1 5de
2 5dd 5de 1
5e6 1 5ec 2
5ee 5ef 2 5db
5f0 1 5f7 1
5f2 2 60a 60c
3 608 609 60e
2 617 619 2
61b 61d 2 61f
621 2 623 625
2 627 629 3
62e 62f 630 2
62b 632 2 616
634 1 636 1
638 2 601 639
1 63d 1 5fc
2 5fa 641 a
14e 162 171 174
1d6 2c4 332 567
5d4 644 2 64b
651 1 658 1
653 2 66b 66d
3 669 66a 66f
2 678 67a 2
67c 67e 2 680
682 2 684 686
2 688 68a 3
68f 690 691 2
68c 693 2 677
695 1 697 1
699 2 662 69a
1 69e 1 65d
2 65b 6a2 4
145 648 6a5 6a8
2 6ac 6ad 1
6b1 2 6af 6b1
4 6bb 6bc 6bd
6be 1 6c9 1
6cf 2 6d1 6d2
1 6da 2 6d6
6da 1 6df 1
6e1 3 6e4 6e5
6e6 1 6ea 2
6e8 6ea 2 6f2
6f7 1 6fe 1
6f9 2 711 713
3 70f 710 715
2 71e 720 2
722 724 2 726
728 2 72a 72c
2 72e 730 3
735 736 737 2
732 739 2 71d
73b 1 73d 1
73f 2 708 740
1 744 1 703
2 701 748 1
74b 2 753 758
1 75f 1 75a
2 772 774 3
770 771 776 2
77f 781 2 783
785 2 787 789
2 78b 78d 2
78f 791 3 796
797 798 2 793
79a 2 77e 79c
1 79e 1 7a0
2 769 7a1 1
7a5 1 764 2
762 7a9 1 7ac
2 7af 7b0 1
7c1 2 7c0 7c1
1 7c9 1 7cf
2 7d1 7d2 2
7be 7d3 1 7da
1 7d5 2 7ed
7ef 3 7eb 7ec
7f1 2 7fa 7fc
2 7fe 800 2
802 804 2 806
808 2 80a 80c
3 811 812 813
2 80e 815 2
7f9 817 1 819
1 81b 2 7e4
81c 1 820 1
7df 2 7dd 824
1 83b 2 83a
83b 1 843 1
849 2 84b 84c
2 838 84d 1
854 1 84f 2
867 869 3 865
866 86b 2 874
876 2 878 87a
2 87c 87e 2
880 882 2 884
886 3 88b 88c
88d 2 888 88f
2 873 891 1
893 1 895 2
85e 896 1 89a
1 859 2 857
89e 6 6bf 6d3
6e2 7b1 827 8a1
2 8a8 8ae 1
8b5 1 8b0 2
8c8 8ca 3 8c6
8c7 8cc 2 8d5
8d7 2 8d9 8db
2 8dd 8df 2
8e1 8e3 2 8e5
8e7 3 8ec 8ed
8ee 2 8e9 8f0
2 8d4 8f2 1
8f4 1 8f6 2
8bf 8f7 1 8fb
1 8ba 2 8b8
8ff 4 6b6 8a5
902 905 2 908
907 4 117 12a
139 909 2 90f
915 1 91c 1
917 2 92f 931
3 92d 92e 933
2 93c 93e 2
940 942 2 944
946 2 948 94a
2 94c 94e 3
953 954 955 2
950 957 2 93b
959 1 95b 1
95d 2 926 95e
1 962 1 921
2 91f 966 2
973 975 3 971
972 977 2 980
982 2 984 986
2 988 98a 1
992 2 994 995
2 98c 997 2
999 99b 2 99d
99f 2 9a1 9a3
2 9a5 9a7 2
97f 9a9 1 9ab
1 9ad 3 9b4
9b5 9b6 9 e9
108 10b 10e 111
90c 969 9ae 9b8
2 9c5 9c7 3
9c3 9c4 9c9 2
9d2 9d4 2 9d1
9d6 2 9dd 9e1
2 9e3 9e5 2
9e7 9eb 2 9dc
9ed 2 9d8 9ef
1 9f1 3 9f2
9fd a01 1 9bc
2 a14 a16 3
a12 a13 a18 2
a21 a23 2 a20
a25 2 a2c a2e
2 a30 a32 3
a37 a38 a39 2
a34 a3b 2 a2b
a3d 2 a27 a3f
1 a41 4 a0b
a42 a4b a4f 1
a53 1 a06 2
a04 a57 e 17
1e 25 2c 33
3a 41 48 4e
54 6b 7f 9f
a9 
1
4
0 
a5e
0
1
50
2c
11
0 1 1 1 1 5 6 7
6 9 6 b 6 d 6 f
6 11 6 13 6 15 6 17
6 19 6 1b 5 1d 5 1f
20 1f 22 1f 24 1f 26 5
28 1 2a 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3 1 0
57 1 2
2e 1 0
71 1 3
85 1 4
43 1 0
4a 1 0
35 1 0
50 1 0
27 1 0
12 1 0
3c 1 0
20 1 0
2 0 1
7 1 0
19 1 0
a4 1 0
0

/
SHOW ERRORS FUNCTION SP_TEST_ASSIGN;
ALTER FUNCTION SP_TEST_ASSIGN COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_MIGRATION ==
CREATE OR REPLACE FUNCTION FC_MIGRATION wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
83
2 :e:
1FUNCTION:
1FC_MIGRATION:
1H_PROJECT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1RETURN:
1PLS_INTEGER:
1H_LEVEL:
10:
1H_ROLLUP_BITS:
1H_TEMP_SC_STATE:
1CURSOR:
1C01:
1PROJECT_ID:
1LEVEL_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT PROJECT_ID, LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst+
1.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE+
12,pmo_cnst.SC_PROJ_TYPE3):n         ORDER BY RANK DESC:
1C02:
1C03:
1ELEMENT_ID:
1SELECT LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst.SC_PROJECT,+
1pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cnst.S+
1C_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n         ORDER BY RANK DESC:
1C04:
1SELECT /*PROJECT_ID,*/ LEVEL_ID:n         FROM TMT_WBS:n         WHERE TYPE_I+
1D IN (pmo_cnst.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cns+
1t.SC_PROJ_TYPE2,pmo_cnst.SC_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n      +
1   ORDER BY RANK DESC:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_MIGRATION(:
1':
1);:
1CHECK_TRACE:
11:
137:
1+:
1FPUT:
1               ENTER:: FC_MIGRATION(38) :: cplan.sql(22950) :: :
1IS NULL:
1OPEN:
1LOOP:
1FOUND:
1PMO_DB2M:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
13269638:
1TASK_ASSIGNMENTS:
1ROLLUP_BITS:
1ACTUAL_START:
1SC_SET_ALL_BITS:
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = CASE WHEN ACTUAL_START IS NuLL THEN+
1 pmo_cnst.SC_SET_ALL_BITS ELSE h_rollup_bits END:n            WHERE PROJECT_I+
1D = h_project_id:
1TRUE:
1=:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
174:
1           EXCEPTION:: FC_MIGRATION(75) :: cplan.sql(22987) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1PMO_FUNC:
1BIT_OR:
1SC_PLANNED_BIT:
1SC_SCHED_BIT:
1PLANNED_FINISH:
1SCHED_FINISH:
1ACTUAL_FINISH:
1FORECAST_FINISH:
1FORECAST_START:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL,:n            ACTUAL_FINISH = NuLL,:n            FOR+
1ECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORECAST_FINISH ELSE NuL+
1L END:n            WHERE PROJECT_ID = h_project_id AND (PLANNED_EFFORT + SCHE+
1D_EFFORT > 0):
198:
1           EXCEPTION:: FC_MIGRATION(99) :: cplan.sql(23011) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = h_rollup_bits, PLANNED_FINISH = NuLL, SCHED_+
1FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND ((PLANNED_EFFO+
1RT + SCHED_EFFORT) = 0):
1118:
1           EXCEPTION:: FC_MIGRATION(119) :: cplan.sql(23031) :: :
1TMT_CRI:
1UPDATE TMT_CRI SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND TYP+
1E_ID <> 14:
1138:
1           EXCEPTION:: FC_MIGRATION(139) :: cplan.sql(23051) :: :
1COALESCE:
1FC_ROLLUP:
1COMMIT:
1CLOSE:
1160:
1           EXCEPTION:: FC_MIGRATION(161) :: cplan.sql(23073) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, ACTUAL_FINISH = Nu+
1LL,:n            FORECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORE+
1CAST_FINISH ELSE NuLL END:n            WHERE PROJECT_ID = h_project_id AND ((+
1PLANNED_EFFORT + SCHED_EFFORT) = 0):
1197:
1           EXCEPTION:: FC_MIGRATION(198) :: cplan.sql(23110) :: :
1219:
1           EXCEPTION:: FC_MIGRATION(220) :: cplan.sql(23132) :: :
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS WHERE PROJ+
1ECT_ID = h_project_id:
1256:
1           EXCEPTION:: FC_MIGRATION(257) :: cplan.sql(23169) :: :
1278:
1           EXCEPTION:: FC_MIGRATION(279) :: cplan.sql(23191) :: :
1298:
1           EXCEPTION:: FC_MIGRATION(299) :: cplan.sql(23211) :: :
1318:
1           EXCEPTION:: FC_MIGRATION(319) :: cplan.sql(23231) :: :
1340:
1           EXCEPTION:: FC_MIGRATION(341) :: cplan.sql(23253) :: :
1377:
1           EXCEPTION:: FC_MIGRATION(378) :: cplan.sql(23290) :: :
1399:
1           EXCEPTION:: FC_MIGRATION(400) :: cplan.sql(23312) :: :
1406:
1                EXIT:: FC_MIGRATION(407) :: cplan.sql(23319) :: :
1STATE:: :
0

0
0
853
2
0 a0 8d 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a0 f4 b4
bf c8 :f a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :f a0 12a
bd b7 11 a4 b1 a0 f4 b4
bf c8 :10 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :10 a0 12a
bd b7 11 a4 b1 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 e9 dd b3 :4 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 6b :2 a0 6b :2 a0 6b a5 b
d :e a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :3 a0 a5 b d a0 12a b7
19 3c b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 e9 dd b3 :4 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :3 a0 a5 b d
a0 12a b7 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 e9 dd b3
:3 a0 e9 d3 :2 a0 f :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c :3 a0
6b :2 a0 6b :2 a0 6b a5 b d
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 a5 b d a0 12a b7 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
e9 dd b3 :3 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :c a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :3 a0 a5 b d a0 12a
b7 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
a4 b1 11 68 4f 1d 17 b5 
853
2
0 3 7 2b 1f 23 27 1e
32 1b 37 3b 3f 43 5f 4b
4f 57 5a 4a 7b 6a 6e 47
76 69 97 86 8a 66 92 85
9e a2 82 b3 b6 ba be c2
c6 ca ce d2 d6 da de e2
e6 ea ee f2 f6 102 107 109
115 119 11b 11f 130 131 134 138
13c 140 144 148 14c 150 154 158
15c 160 164 168 16c 170 174 180
185 187 193 197 199 19d 1ae 1af
1b2 1b6 1ba 1be 1c2 1c6 1ca 1ce
1d2 1d6 1da 1de 1e2 1e6 1ea 1ee
1f2 1f6 202 207 209 215 219 21b
21f 230 231 234 238 23c 240 244
248 24c 250 254 258 25c 260 264
268 26c 270 274 278 284 289 28b
297 29b 29d 2a1 2a5 2a8 2ac 2b0
2b3 2b8 2b9 1 2bb 2c0 2c4 2c8
2cb 2d0 2d4 2d8 2db 2e0 2e1 2e3
2e8 2eb 2ef 2f0 2f5 2fa 2fd 302
303 308 30b 30f 310 315 318 31d
31e 323 326 32b 32c 331 332 337
339 33d 340 344 348 34b 34f 353
356 359 35e 361 364 367 368 36d
36e 1 370 375 379 37d 380 385
38a 38d 391 392 397 398 39d 39f
3a3 3a6 3aa 3ad 3ae 3b3 3b6 3ba
3be 3c3 3c7 3c8 3cc 3d0 3d4 3d8
3dd 3e2 3e6 3ea 3ee 3f3 3f7 3fb
3fe 401 405 407 40b 40f 412 415
419 41b 41f 423 426 42a 42e 431
435 438 43c 43f 440 445 448 44c
452 454 458 45b 45f 462 466 46a
46e 472 476 47a 47e 482 486 492
496 49b 49f 4a2 4a3 4a8 4ac 4b0
4b3 4b6 4ba 4bc 4c0 4c4 4c7 4ca
4ce 4d0 4d4 4d8 4db 4dd 4e1 4e5
4e9 4ec 4f0 4f4 4f6 4f7 4fc 1
500 504 508 50b 50f 513 517 51b
51e 522 526 529 52c 531 534 537
53a 53b 540 541 1 543 548 54c
550 553 558 55d 560 564 565 56a
56d 572 573 578 57b 580 581 586
589 58d 58e 593 596 59b 59c 5a1
5a4 5a8 5ac 5af 5b2 5b3 5b5 5b6
5bb 5bc 5c1 5c3 5c7 5ca 5cc 5d0
5d2 5de 5e0 5e2 5e3 5e8 5ec 5ee
5fa 5fc 600 604 608 60b 60f 613
616 61a 61e 621 622 624 628 62c
630 634 638 63c 640 644 648 64c
650 654 658 65c 660 66c 670 675
679 67c 67d 682 686 68a 68d 690
694 696 69a 69e 6a1 6a4 6a8 6aa
6ae 6b2 6b5 6b7 6bb 6bf 6c3 6c6
6ca 6ce 6d0 6d1 6d6 1 6da 6de
6e2 6e5 6e9 6ed 6f1 6f5 6f8 6fc
700 703 706 70b 70e 711 714 715
71a 71b 1 71d 722 726 72a 72d
732 737 73a 73e 73f 744 747 74c
74d 752 755 75a 75b 760 763 767
768 76d 770 775 776 77b 77e 782
786 789 78c 78d 78f 790 795 796
79b 79d 7a1 7a4 7a6 7aa 7ac 7b8
7ba 7bc 7bd 7c2 7c6 7c8 7d4 7d6
7da 7de 7e2 7e6 7ea 7ee 7f2 7f6
7fa 806 80a 80f 813 816 817 81c
820 824 827 82a 82e 830 834 838
83b 83e 842 844 848 84c 84f 851
855 859 85d 860 864 868 86a 86b
870 1 874 878 87c 87f 883 887
88b 88f 892 896 89a 89d 8a0 8a5
8a8 8ab 8ae 8af 8b4 8b5 1 8b7
8bc 8c0 8c4 8c7 8cc 8d1 8d4 8d8
8d9 8de 8e1 8e6 8e7 8ec 8ef 8f4
8f5 8fa 8fd 901 902 907 90a 90f
910 915 918 91c 920 923 926 927
929 92a 92f 930 935 937 93b 93e
940 944 946 952 954 956 957 95c
960 962 96e 970 974 978 97c 980
984 988 98c 990 994 9a0 9a4 9a9
9ad 9b0 9b1 9b6 9ba 9be 9c1 9c4
9c8 9ca 9ce 9d2 9d5 9d8 9dc 9de
9e2 9e6 9e9 9eb 9ef 9f3 9f7 9fa
9fe a02 a04 a05 a0a 1 a0e a12
a16 a19 a1d a21 a25 a29 a2c a30
a34 a37 a3a a3f a42 a45 a48 a49
a4e a4f 1 a51 a56 a5a a5e a61
a66 a6b a6e a72 a73 a78 a7b a80
a81 a86 a89 a8e a8f a94 a97 a9b
a9c aa1 aa4 aa9 aaa aaf ab2 ab6
aba abd ac0 ac1 ac3 ac4 ac9 aca
acf ad1 ad5 ad8 ada ade ae0 aec
aee af0 af1 af6 afa afc b08 b0a
b0e b12 b15 b16 b18 b1b b1e b1f
b24 b28 b2c b30 b31 b33 b37 b3b
b47 b49 b4d b50 b52 b56 b5d b61
b65 b6a b6c b70 b74 b77 b7b b7f
b81 b85 b89 b8d b90 b94 b98 b9a
b9b ba0 1 ba4 ba8 bac baf bb3
bb7 bbb bbf bc2 bc6 bca bcd bd0
bd5 bd8 bdb bde bdf be4 be5 1
be7 bec bf0 bf4 bf7 bfc c01 c04
c08 c09 c0e c11 c16 c17 c1c c1f
c24 c25 c2a c2d c31 c32 c37 c3a
c3f c40 c45 c48 c4c c50 c53 c56
c57 c59 c5a c5f c60 c65 c67 c6b
c6e c70 c74 c76 c82 c84 c86 c87
c8c c90 c92 c9e ca0 ca4 ca8 cad
cb1 cb2 cb6 cba cbe cc2 cc7 ccc
cd0 cd4 cd8 cdd ce1 ce5 ce8 ceb
cef cf1 cf5 cf9 cfc cff d03 d05
d09 d0d d10 d14 d18 d1b d1f d22
d26 d29 d2a d2f d32 d36 d3c d3e
d42 d45 d49 d4d d51 d55 d59 d5d
d61 d65 d69 d6d d71 d75 d81 d85
d8a d8e d91 d92 d97 d9b d9f da2
da5 da9 dab daf db3 db6 db9 dbd
dbf dc3 dc7 dca dcc dd0 dd4 dd8
ddb ddf de3 de5 de6 deb 1 def
df3 df7 dfa dfe e02 e06 e0a e0d
e11 e15 e18 e1b e20 e23 e26 e29
e2a e2f e30 1 e32 e37 e3b e3f
e42 e47 e4c e4f e53 e54 e59 e5c
e61 e62 e67 e6a e6f e70 e75 e78
e7c e7d e82 e85 e8a e8b e90 e93
e97 e9b e9e ea1 ea2 ea4 ea5 eaa
eab eb0 eb2 eb6 eb9 ebb ebf ec1
ecd ecf ed1 ed2 ed7 edb edd ee9
eeb eef ef3 ef6 ef7 ef9 efc eff
f00 f05 f09 f0d f11 f12 f14 f18
f1c f28 f2a f2e f31 f33 f37 f3e
f42 f46 f4b f4d f51 f55 f58 f5c
f60 f62 f66 f6a f6e f71 f75 f79
f7b f7c f81 1 f85 f89 f8d f90
f94 f98 f9c fa0 fa3 fa7 fab fae
fb1 fb6 fb9 fbc fbf fc0 fc5 fc6
1 fc8 fcd fd1 fd5 fd8 fdd fe2
fe5 fe9 fea fef ff2 ff7 ff8 ffd
1000 1005 1006 100b 100e 1012 1013 1018
101b 1020 1021 1026 1029 102d 1031 1034
1037 1038 103a 103b 1040 1041 1046 1048
104c 104f 1051 1055 1057 1063 1065 1067
1068 106d 1071 1073 107f 1081 1083 1087
108b 1090 1094 1095 1099 109d 10a1 10a6
10ab 10af 10b3 10b8 10bc 10c0 10c3 10c6
10ca 10cc 10d0 10d4 10d7 10da 10de 10e0
10e4 10e8 10eb 10ef 10f3 10f6 10fa 10fd
1101 1104 1105 110a 110d 1111 1117 1119
111d 1120 1124 1128 112c 112f 1133 1137
113a 113e 1142 1145 1146 1148 114c 1150
1154 1158 115c 1160 1164 1170 1174 1179
117d 1180 1181 1186 118a 118e 1191 1194
1198 119a 119e 11a2 11a5 11a8 11ac 11ae
11b2 11b6 11b9 11bb 11bf 11c3 11c7 11ca
11ce 11d2 11d4 11d5 11da 1 11de 11e2
11e6 11e9 11ed 11f1 11f5 11f9 11fc 1200
1204 1207 120a 120f 1212 1215 1218 1219
121e 121f 1 1221 1226 122a 122e 1231
1236 123b 123e 1242 1243 1248 124b 1250
1251 1256 1259 125e 125f 1264 1267 126b
126c 1271 1274 1279 127a 127f 1282 1286
128a 128d 1290 1291 1293 1294 1299 129a
129f 12a1 12a5 12a8 12aa 12ae 12b0 12bc
12be 12c0 12c1 12c6 12ca 12cc 12d8 12da
12de 12e2 12e6 12ea 12ee 12f2 12f6 12fa
12fe 1302 1306 130a 130e 1312 131e 1322
1327 132b 132e 132f 1334 1338 133c 133f
1342 1346 1348 134c 1350 1353 1356 135a
135c 1360 1364 1367 1369 136d 1371 1375
1378 137c 1380 1382 1383 1388 1 138c
1390 1394 1397 139b 139f 13a3 13a7 13aa
13ae 13b2 13b5 13b8 13bd 13c0 13c3 13c6
13c7 13cc 13cd 1 13cf 13d4 13d8 13dc
13df 13e4 13e9 13ec 13f0 13f1 13f6 13f9
13fe 13ff 1404 1407 140c 140d 1412 1415
1419 141a 141f 1422 1427 1428 142d 1430
1434 1438 143b 143e 143f 1441 1442 1447
1448 144d 144f 1453 1456 1458 145c 145e
146a 146c 146e 146f 1474 1478 147a 1486
1488 148c 1490 1494 1498 149c 14a0 14a4
14a8 14ac 14b8 14bc 14c1 14c5 14c8 14c9
14ce 14d2 14d6 14d9 14dc 14e0 14e2 14e6
14ea 14ed 14f0 14f4 14f6 14fa 14fe 1501
1503 1507 150b 150f 1512 1516 151a 151c
151d 1522 1 1526 152a 152e 1531 1535
1539 153d 1541 1544 1548 154c 154f 1552
1557 155a 155d 1560 1561 1566 1567 1
1569 156e 1572 1576 1579 157e 1583 1586
158a 158b 1590 1593 1598 1599 159e 15a1
15a6 15a7 15ac 15af 15b3 15b4 15b9 15bc
15c1 15c2 15c7 15ca 15ce 15d2 15d5 15d8
15d9 15db 15dc 15e1 15e2 15e7 15e9 15ed
15f0 15f2 15f6 15f8 1604 1606 1608 1609
160e 1612 1614 1620 1622 1626 162a 162e
1632 1636 163a 163e 1642 1646 1652 1656
165b 165f 1662 1663 1668 166c 1670 1673
1676 167a 167c 1680 1684 1687 168a 168e
1690 1694 1698 169b 169d 16a1 16a5 16a9
16ac 16b0 16b4 16b6 16b7 16bc 1 16c0
16c4 16c8 16cb 16cf 16d3 16d7 16db 16de
16e2 16e6 16e9 16ec 16f1 16f4 16f7 16fa
16fb 1700 1701 1 1703 1708 170c 1710
1713 1718 171d 1720 1724 1725 172a 172d
1732 1733 1738 173b 1740 1741 1746 1749
174d 174e 1753 1756 175b 175c 1761 1764
1768 176c 176f 1772 1773 1775 1776 177b
177c 1781 1783 1787 178a 178c 1790 1792
179e 17a0 17a2 17a3 17a8 17ac 17ae 17ba
17bc 17c0 17c4 17c7 17c8 17ca 17cd 17d0
17d1 17d6 17da 17de 17e2 17e3 17e5 17e9
17ed 17f9 17fb 17ff 1802 1804 1808 180f
1813 1817 181c 181e 1822 1826 1829 182d
1831 1833 1837 183b 183f 1842 1846 184a
184c 184d 1852 1 1856 185a 185e 1861
1865 1869 186d 1871 1874 1878 187c 187f
1882 1887 188a 188d 1890 1891 1896 1897
1 1899 189e 18a2 18a6 18a9 18ae 18b3
18b6 18ba 18bb 18c0 18c3 18c8 18c9 18ce
18d1 18d6 18d7 18dc 18df 18e3 18e4 18e9
18ec 18f1 18f2 18f7 18fa 18fe 1902 1905
1908 1909 190b 190c 1911 1912 1917 1919
191d 1920 1922 1926 1928 1934 1936 1938
1939 193e 1942 1944 1950 1952 1956 195a
195f 1963 1964 1968 196c 1970 1975 197a
197e 1982 1987 198b 198f 1992 1995 1999
199b 199f 19a3 19a6 19a9 19ad 19af 19b3
19b7 19ba 19be 19c2 19c5 19c9 19cc 19d0
19d3 19d4 19d9 19dc 19e0 19e6 19e8 19ec
19ef 19f3 19f7 19fb 19ff 1a03 1a07 1a0b
1a0f 1a13 1a17 1a1b 1a1f 1a2b 1a2f 1a34
1a38 1a3b 1a3c 1a41 1a45 1a49 1a4c 1a4f
1a53 1a55 1a59 1a5d 1a60 1a63 1a67 1a69
1a6d 1a71 1a74 1a76 1a7a 1a7e 1a82 1a85
1a89 1a8d 1a8f 1a90 1a95 1 1a99 1a9d
1aa1 1aa4 1aa8 1aac 1ab0 1ab4 1ab7 1abb
1abf 1ac2 1ac5 1aca 1acd 1ad0 1ad3 1ad4
1ad9 1ada 1 1adc 1ae1 1ae5 1ae9 1aec
1af1 1af6 1af9 1afd 1afe 1b03 1b06 1b0b
1b0c 1b11 1b14 1b19 1b1a 1b1f 1b22 1b26
1b27 1b2c 1b2f 1b34 1b35 1b3a 1b3d 1b41
1b45 1b48 1b4b 1b4c 1b4e 1b4f 1b54 1b55
1b5a 1b5c 1b60 1b63 1b65 1b69 1b6b 1b77
1b79 1b7b 1b7c 1b81 1b85 1b87 1b93 1b95
1b99 1b9d 1ba0 1ba1 1ba3 1ba6 1ba9 1baa
1baf 1bb3 1bb7 1bbb 1bbc 1bbe 1bc2 1bc6
1bd2 1bd4 1bd8 1bdb 1bdd 1be1 1be8 1bec
1bf0 1bf5 1bf7 1bfb 1bff 1c02 1c06 1c0a
1c0c 1c10 1c14 1c18 1c1b 1c1f 1c23 1c25
1c26 1c2b 1 1c2f 1c33 1c37 1c3a 1c3e
1c42 1c46 1c4a 1c4d 1c51 1c55 1c58 1c5b
1c60 1c63 1c66 1c69 1c6a 1c6f 1c70 1
1c72 1c77 1c7b 1c7f 1c82 1c87 1c8c 1c8f
1c93 1c94 1c99 1c9c 1ca1 1ca2 1ca7 1caa
1caf 1cb0 1cb5 1cb8 1cbc 1cbd 1cc2 1cc5
1cca 1ccb 1cd0 1cd3 1cd7 1cdb 1cde 1ce1
1ce2 1ce4 1ce5 1cea 1ceb 1cf0 1cf2 1cf6
1cf9 1cfb 1cff 1d01 1d0d 1d0f 1d11 1d12
1d17 1d1b 1d1d 1d29 1d2b 1d2d 1d31 1d35
1d38 1d3c 1d40 1d43 1d47 1d4b 1d4e 1d51
1d56 1d59 1d5c 1d5f 1d60 1d65 1d66 1
1d68 1d6d 1d71 1d75 1d78 1d7d 1d82 1d85
1d89 1d8a 1d8f 1d92 1d97 1d98 1d9d 1da0
1da5 1da6 1dab 1dae 1db2 1db6 1db9 1dba
1dbf 1dc0 1dc5 1dc7 1dcb 1dce 1dd2 1dd6
1dda 1ddd 1de1 1de3 1de7 1de9 1df5 1df9
1dfb 1dfc 1e05 
853
2
0 1 a 6 16 1a 21 :2 6
1 3 a :2 1 4 :2 c 1b c
:2 4 :2 12 21 12 :2 4 :2 14 23 14
4 7 e 0 :2 7 11 1d 2b
10 1c 25 30 39 45 4e 5c
65 73 7c 13 a :6 7 e 0
:2 7 11 1d 2b 10 1c 25 30
39 45 4e 5c 65 73 7c 13
a :6 7 e 0 :2 7 11 1f 10
1c 25 30 39 45 4e 5c 65
73 7c 8f 9c 13 a :6 7 e
0 :2 7 21 f 10 1c 25 30
39 45 4e 5c 65 73 7c 8f
9c 13 a :6 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
54 5a 5d :2 54 6b 81 8 :2 6b
d 10 :2 6b 1d 20 :2 6b 25 28
:2 6b :2 7 4a :2 4 7 :2 11 23 :2 2d
39 3c 4c 4e 4f :2 4c :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 52
:2 4 :4 8 :2 7 c :4 7 10 19 27
:3 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :3 a 1b a
14 29 41 5b 64 79 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5b 5c :2 59 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 7 a 1b :2 24 2b :2 34 44 :2 4d
:2 1b a 14 20 2e 37 48 5f
:2 d 29 45 13 20 32 43 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5b 5c :2 59 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 7
14 20 2e 3d 54 13 20 33
44 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 6a 6d :2 2a 7a
7d :2 2a 81 84 :2 2a 90 93 :2 2a
9b 9e :2 2a aa ad b4 bd c0
:2 ad :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 7 14 20 2e 37 48 5f
13 20 31 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 1e a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 1e 7 c :4 7
10 19 27 :3 a d 11 :2 d :2 16
22 d 17 d :2 16 22 d :4 a
e :2 17 23 20 :2 2c :2 20 :3 d 3c
:2 a 14 20 2e 37 48 d 29
45 13 20 33 44 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 7 d 16
1f :2 d 22 24 :2 22 d 20 2a
:2 20 :3 d 26 :2 a 7 b 1e a
10 :3 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :4 1e 7
c :4 7 10 19 :2 a d 11 :2 d
:2 16 22 d 17 d :2 16 22 d
:4 a e :2 17 23 20 :2 2c :2 20 :3 d
3c :3 a 1b :2 24 2b :2 34 44 :2 4d
:2 1b a 14 29 37 40 56 63
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f :2 d
29 45 13 20 32 43 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 7 14
20 2e 3d 54 13 20 33 44
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f 13
20 31 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 7 d 16 1f :2 d 22
24 :2 22 d 20 2a :2 20 :3 d 26
:2 a 7 b 4 a 10 :3 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 7 c :4 7 10
19 :2 a d 11 :2 d :2 16 22 d
17 d :2 16 22 d :4 a e :2 17
23 20 :2 2c :2 20 :3 d 3c :2 a 14
20 2e 37 48 d 29 45 13
20 33 44 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 4 a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :7 4 7 :2 11 23
:2 2d 39 3c 4c 4f 50 :2 4c :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e 6e
71 :2 1e 75 78 :2 1e 82 85 :2 8e
:2 1e :2 7 53 :3 4 b :2 14 4 :9 1

853
4
0 :2 1 :6 3 2
:2 4 :2 1 :6 6 :6 7
:6 8 :2 a 0 :2 a
:3 b :b c d b
:5 a :2 f 0 :2 f
:3 10 :b 11 12 10
:5 f :2 14 0 :2 14
:2 15 :d 16 17 15
:5 14 :2 19 0 :2 19
1a 1b :d 1c 1d
1a :5 19 :b 20 :11 21
22 :2 21 :2 22 :2 21
:2 22 :2 21 :2 22 :4 21
:3 20 :11 25 :b 26 :3 25
:5 29 :5 2c 2e :6 2f
:3 30 :5 31 30 :5 33
32 :3 30 :a 35 :2 36
:3 35 :3 39 :6 3d :2 3e
3d :6 3f :5 40 3f
:5 42 41 :3 3f 3c
45 :5 46 :3 45 :2 47
:5 49 :11 4a :24 4b :3 4a
:2 48 :6 47 44 :3 2e
:d 50 :6 53 54 :3 55
:4 56 53 :6 57 :5 58
57 :5 5a 59 :3 57
52 5d :5 5e :3 5d
:2 5f :5 61 :11 62 :24 63
:3 62 :2 60 :6 5f 5c
:3 2e :5 69 :4 6a 69
:6 6b :5 6c 6b :5 6e
6d :3 6b 68 71
:5 72 :3 71 :2 73 :5 75
:11 76 :24 77 :3 76 :2 74
:6 73 70 :3 2e :6 7d
:3 7e 7d :6 7f :5 80
7f :5 82 81 :3 7f
7c 85 :5 86 :3 85
:2 87 :5 89 :11 8a :24 8b
:3 8a :2 88 :6 87 84
:3 2e :9 90 :6 91 :2 93
:3 90 2e 95 29
:4 98 :5 99 97 9b
:5 9c :3 9b :2 9d :5 9f
:11 a0 :24 a1 :3 a0 :2 9e
:6 9d 9a :3 29 :5 a8
aa :6 ab :3 ac :5 ad
ac :5 af ae :3 ac
:a b2 :2 b3 :3 b2 :5 b7
:3 b8 :4 b9 b7 :6 ba
:5 bb ba :5 bd bc
:3 ba b6 c0 :5 c1
:3 c0 :2 c2 :5 c4 :11 c5
:24 c6 :3 c5 :2 c3 :6 c2
bf :3 aa :9 cb :6 cc
:2 ce :3 cb aa d0
29 :4 d3 :5 d4 d2
d6 :5 d7 :3 d6 :2 d8
:5 da :11 db :24 dc :3 db
:2 d9 :6 d8 d5 :4 29
:5 e3 e5 :4 e6 :3 e7
:5 e8 e7 :5 ea e9
:3 e7 :a ed :2 ee :3 ed
:d f1 :7 f4 :6 f5 :5 f6
f5 :5 f8 f7 :3 f5
f3 fb :5 fc :3 fb
:2 fd :5 ff :11 100 :24 101
:3 100 :2 fe :6 fd fa
:3 e5 :6 107 108 :3 109
:4 10a 107 :6 10b :5 10c
10b :5 10e 10d :3 10b
106 111 :5 112 :3 111
:2 113 :5 115 :11 116 :24 117
:3 116 :2 114 :6 113 110
:3 e5 :5 11d :4 11e 11d
:6 11f :5 120 11f :5 122
121 :3 11f 11c 125
:5 126 :3 125 :2 127 :5 129
:11 12a :24 12b :3 12a :2 128
:6 127 124 :3 e5 :6 131
:3 132 131 :6 133 :5 134
133 :5 136 135 :3 133
130 139 :5 13a :3 139
:2 13b :5 13d :11 13e :24 13f
:3 13e :2 13c :6 13b 138
:3 e5 :9 144 :6 145 :2 147
:3 144 e5 149 e0
:4 14c :5 14d 14b 14f
:5 150 :3 14f :2 151 :5 153
:11 154 :24 155 :3 154 :2 152
:6 151 14e :3 e0 :5 15c
15e :4 15f :3 160 :5 161
160 :5 163 162 :3 160
:a 166 :2 167 :3 166 :5 16b
:3 16c :4 16d 16b :6 16e
:5 16f 16e :5 171 170
:3 16e 16a 174 :5 175
:3 174 :2 176 :5 178 :11 179
:24 17a :3 179 :2 177 :6 176
173 :3 15e :9 17f :6 180
:2 182 :3 17f 15e 184
e0 :4 187 :5 188 186
18a :5 18b :3 18a :2 18c
:5 18e :11 18f :24 190 :3 18f
:2 18d :6 18c 189 :4 e0
:3 29 :11 196 :19 197 :3 196
:5 199 :2 1f :7 1 
1e07
4
:3 0 1 :3 0 2
:a 0 84e 1 :7 0
5 :2 0 3 4
:3 0 5 :3 0 6
:3 0 3 :5 0 1
7 6 :3 0 7
:3 0 8 :3 0 9
b 0 84e 2
c :2 0 a :2 0
7 8 :3 0 f
:7 0 a :2 0 13
10 11 84c 0
9 :6 0 a :2 0
9 8 :3 0 15
:7 0 19 16 17
84c 0 b :9 0
b 8 :3 0 1b
:7 0 1f 1c 1d
84c 0 c :6 0
d :3 0 e :a 0
2 35 :4 0 21
24 0 22 :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 36 21 24
37 0 84c d
37 39 36 38
:6 0 35 :7 0 37
d :3 0 1b :a 0
3 4f :5 0 3b
3e 0 3c :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 50 3b 3e
51 0 84c f
51 53 50 52
:6 0 4f :7 0 51
d :3 0 1c :a 0
4 6a :5 0 55
58 0 56 :3 0
10 :3 0 11 :3 0
12 :3 0 13 :3 0
14 :3 0 13 :3 0
15 :3 0 13 :3 0
16 :3 0 13 :3 0
17 :3 0 13 :3 0
18 :3 0 1d :3 0
3 :3 0 19 :4 0
1e 1 :8 0 6b
55 58 6c 0
84c 11 6c 6e
6b 6d :6 0 6a
:7 0 6c d :3 0
1f :a 0 5 85
:5 0 70 73 0
71 :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
1d :3 0 3 :3 0
19 :4 0 20 1
:8 0 86 70 73
87 0 84c 13
87 89 86 88
:6 0 85 :7 0 87
21 :3 0 22 :3 0
8a 8b 0 21
:3 0 23 :3 0 8d
8e 0 2 :4 0
15 8f 91 8c
93 92 :2 0 24
:3 0 25 :3 0 95
96 0 26 :4 0
21 :3 0 27 :3 0
99 9a 0 2
:4 0 17 9b 9d
28 :4 0 29 :2 0
2a :3 0 19 a0
a2 :3 0 2b :4 0
29 :2 0 2c :4 0
1c a5 a7 :3 0
29 :2 0 3 :3 0
1f a9 ab :3 0
29 :2 0 2c :4 0
22 ad af :3 0
29 :2 0 2d :4 0
25 b1 b3 :3 0
28 97 b5 :2 0
b7 2d b8 94
b7 0 b9 2f
0 84a 21 :3 0
22 :3 0 ba bb
0 21 :3 0 2e
:3 0 bd be 0
2f :2 0 2 :4 0
30 :2 0 31 :2 0
2f :2 0 31 c3
c5 :3 0 34 bf
c7 bc c9 c8
:2 0 24 :3 0 32
:3 0 cb cc 0
26 :4 0 33 :4 0
29 :2 0 2a :3 0
38 d0 d2 :3 0
3b cd d4 :2 0
d6 3e d7 ca
d6 0 d8 40
0 84a 3 :3 0
34 :2 0 42 da
db :3 0 dc :2 0
35 :3 0 e :4 0
e1 :2 0 47d df
e2 :3 0 36 :3 0
e :3 0 3 :3 0
9 :4 0 e8 :2 0
303 e4 e9 :3 0
44 :3 0 e :3 0
37 :3 0 ea eb
:3 0 38 :3 0 39
:3 0 ed ee 0
a :2 0 ef f0
0 f2 47 f9
38 :3 0 39 :3 0
f3 f4 0 3a
:2 0 f5 f6 0
f8 49 fa ec
f2 0 fb 0
f8 0 fb 4b
0 303 38 :3 0
39 :3 0 fc fd
0 38 :3 0 3b
:2 0 3c :3 0 ff
101 0 50 100
103 :3 0 104 :2 0
3d :8 0 108 53
109 105 108 0
10a 55 0 303
b :3 0 3e :2 0
10b 10c 0 303
3f :3 0 40 :3 0
41 :3 0 13 :3 0
42 :3 0 b :3 0
f :3 0 3 :4 0
43 1 :8 0 12c
37 :4 0 117 :3 0
44 :3 0 45 :2 0
59 11a 11b :3 0
38 :3 0 39 :3 0
11d 11e 0 a
:2 0 11f 120 0
122 5c 129 38
:3 0 39 :3 0 123
124 0 3a :2 0
125 126 0 128
5e 12a 11c 122
0 12b 0 128
0 12b 60 0
12c 63 17f 46
:3 0 38 :3 0 39
:3 0 12e 12f 0
47 :3 0 130 131
0 133 66 135
68 134 133 :2 0
17d 48 :3 0 38
:3 0 39 :3 0 138
139 0 47 :3 0
13a 13b 0 175
21 :3 0 22 :3 0
13d 13e 0 21
:3 0 2e :3 0 140
141 0 49 :2 0
2 :4 0 4a :2 0
31 :2 0 2f :2 0
6a 146 148 :3 0
6d 142 14a 13f
14c 14b :2 0 24
:3 0 32 :3 0 14e
14f 0 26 :4 0
4b :4 0 29 :2 0
2a :3 0 71 153
155 :3 0 29 :2 0
4c :4 0 74 157
159 :3 0 29 :2 0
4d :4 0 77 15b
15d :3 0 29 :2 0
47 :3 0 7a 15f
161 :3 0 29 :2 0
4e :4 0 7d 163
165 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
80 168 16c 84
167 16e :3 0 87
150 170 :2 0 172
8a 173 14d 172
0 174 8c 0
175 8e 178 :3 0
178 0 178 177
175 176 :6 0 17a
7 :3 0 91 17c
93 17b 17a :2 0
17d 95 :2 0 17f
0 17f 17e 12c
17d :6 0 303 6
:3 0 b :3 0 52
:3 0 53 :3 0 182
183 0 13 :3 0
54 :3 0 185 186
0 13 :3 0 55
:3 0 188 189 0
98 184 18b 181
18c 0 303 11
:3 0 40 :3 0 13
:3 0 42 :3 0 56
:3 0 57 :3 0 58
:3 0 59 :3 0 5a
:3 0 59 :3 0 f
:3 0 3 :3 0 5b
:3 0 5c :4 0 5d
1 :8 0 1b2 37
:4 0 19d :3 0 44
:3 0 45 :2 0 9d
1a0 1a1 :3 0 38
:3 0 39 :3 0 1a3
1a4 0 a :2 0
1a5 1a6 0 1a8
a0 1af 38 :3 0
39 :3 0 1a9 1aa
0 3a :2 0 1ab
1ac 0 1ae a2
1b0 1a2 1a8 0
1b1 0 1ae 0
1b1 a4 0 1b2
a7 205 46 :3 0
38 :3 0 39 :3 0
1b4 1b5 0 47
:3 0 1b6 1b7 0
1b9 aa 1bb ac
1ba 1b9 :2 0 203
48 :3 0 38 :3 0
39 :3 0 1be 1bf
0 47 :3 0 1c0
1c1 0 1fb 21
:3 0 22 :3 0 1c3
1c4 0 21 :3 0
2e :3 0 1c6 1c7
0 49 :2 0 2
:4 0 5e :2 0 31
:2 0 2f :2 0 ae
1cc 1ce :3 0 b1
1c8 1d0 1c5 1d2
1d1 :2 0 24 :3 0
32 :3 0 1d4 1d5
0 26 :4 0 5f
:4 0 29 :2 0 2a
:3 0 b5 1d9 1db
:3 0 29 :2 0 4c
:4 0 b8 1dd 1df
:3 0 29 :2 0 4d
:4 0 bb 1e1 1e3
:3 0 29 :2 0 47
:3 0 be 1e5 1e7
:3 0 29 :2 0 4e
:4 0 c1 1e9 1eb
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 c4
1ee 1f2 c8 1ed
1f4 :3 0 cb 1d6
1f6 :2 0 1f8 ce
1f9 1d3 1f8 0
1fa d0 0 1fb
d2 1fe :3 0 1fe
0 1fe 1fd 1fb
1fc :6 0 200 9
:3 0 d5 202 d7
201 200 :2 0 203
d9 :2 0 205 0
205 204 1b2 203
:6 0 303 6 :3 0
11 :3 0 40 :3 0
b :3 0 56 :3 0
57 :3 0 f :3 0
3 :3 0 5b :3 0
5c :4 0 60 1
:8 0 226 37 :4 0
211 :3 0 44 :3 0
45 :2 0 de 214
215 :3 0 38 :3 0
39 :3 0 217 218
0 a :2 0 219
21a 0 21c e1
223 38 :3 0 39
:3 0 21d 21e 0
3a :2 0 21f 220
0 222 e3 224
216 21c 0 225
0 222 0 225
e5 0 226 e8
279 46 :3 0 38
:3 0 39 :3 0 228
229 0 47 :3 0
22a 22b 0 22d
eb 22f ed 22e
22d :2 0 277 48
:3 0 38 :3 0 39
:3 0 232 233 0
47 :3 0 234 235
0 26f 21 :3 0
22 :3 0 237 238
0 21 :3 0 2e
:3 0 23a 23b 0
49 :2 0 2 :4 0
61 :2 0 31 :2 0
2f :2 0 ef 240
242 :3 0 f2 23c
244 239 246 245
:2 0 24 :3 0 32
:3 0 248 249 0
26 :4 0 62 :4 0
29 :2 0 2a :3 0
f6 24d 24f :3 0
29 :2 0 4c :4 0
f9 251 253 :3 0
29 :2 0 4d :4 0
fc 255 257 :3 0
29 :2 0 47 :3 0
ff 259 25b :3 0
29 :2 0 4e :4 0
102 25d 25f :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 105 262
266 109 261 268
:3 0 10c 24a 26a
:2 0 26c 10f 26d
247 26c 0 26e
111 0 26f 113
272 :3 0 272 0
272 271 26f 270
:6 0 274 b :3 0
116 276 118 275
274 :2 0 277 11a
:2 0 279 0 279
278 226 277 :6 0
303 6 :3 0 63
:3 0 40 :3 0 13
:3 0 42 :3 0 56
:3 0 57 :3 0 f
:3 0 3 :3 0 12
:4 0 64 1 :8 0
29a 37 :4 0 285
:3 0 44 :3 0 45
:2 0 11f 288 289
:3 0 38 :3 0 39
:3 0 28b 28c 0
a :2 0 28d 28e
0 290 122 297
38 :3 0 39 :3 0
291 292 0 3a
:2 0 293 294 0
296 124 298 28a
290 0 299 0
296 0 299 126
0 29a 129 2ed
46 :3 0 38 :3 0
39 :3 0 29c 29d
0 47 :3 0 29e
29f 0 2a1 12c
2a3 12e 2a2 2a1
:2 0 2eb 48 :3 0
38 :3 0 39 :3 0
2a6 2a7 0 47
:3 0 2a8 2a9 0
2e3 21 :3 0 22
:3 0 2ab 2ac 0
21 :3 0 2e :3 0
2ae 2af 0 49
:2 0 2 :4 0 65
:2 0 31 :2 0 2f
:2 0 130 2b4 2b6
:3 0 133 2b0 2b8
2ad 2ba 2b9 :2 0
24 :3 0 32 :3 0
2bc 2bd 0 26
:4 0 66 :4 0 29
:2 0 2a :3 0 137
2c1 2c3 :3 0 29
:2 0 4c :4 0 13a
2c5 2c7 :3 0 29
:2 0 4d :4 0 13d
2c9 2cb :3 0 29
:2 0 47 :3 0 140
2cd 2cf :3 0 29
:2 0 4e :4 0 143
2d1 2d3 :3 0 29
:2 0 4f :3 0 50
:3 0 2f :2 0 51
:2 0 146 2d6 2da
14a 2d5 2dc :3 0
14d 2be 2de :2 0
2e0 150 2e1 2bb
2e0 0 2e2 152
0 2e3 154 2e6
:3 0 2e6 0 2e6
2e5 2e3 2e4 :6 0
2e8 d :3 0 157
2ea 159 2e9 2e8
:2 0 2eb 15b :2 0
2ed 0 2ed 2ec
29a 2eb :6 0 303
6 :3 0 67 :3 0
9 :3 0 a :2 0
15e 2ef 2f2 45
:2 0 a :2 0 163
2f4 2f6 :3 0 c
:3 0 68 :3 0 3
:3 0 166 2f9 2fb
2f8 2fc 0 300
69 :4 0 69 1
:8 0 300 168 301
2f7 300 0 302
16b 0 303 16d
305 36 :4 0 303
:4 0 47d 6a :3 0
e :4 0 309 :2 0
30f 307 0 38
:3 0 39 :3 0 30a
30b 0 47 :3 0
30c 30d 0 30f
178 362 46 :3 0
38 :3 0 39 :3 0
311 312 0 47
:3 0 313 314 0
316 17b 318 17d
317 316 :2 0 360
48 :3 0 38 :3 0
39 :3 0 31b 31c
0 47 :3 0 31d
31e 0 358 21
:3 0 22 :3 0 320
321 0 21 :3 0
2e :3 0 323 324
0 49 :2 0 2
:4 0 6b :2 0 31
:2 0 2f :2 0 17f
329 32b :3 0 182
325 32d 322 32f
32e :2 0 24 :3 0
32 :3 0 331 332
0 26 :4 0 6c
:4 0 29 :2 0 2a
:3 0 186 336 338
:3 0 29 :2 0 4c
:4 0 189 33a 33c
:3 0 29 :2 0 4d
:4 0 18c 33e 340
:3 0 29 :2 0 47
:3 0 18f 342 344
:3 0 29 :2 0 4e
:4 0 192 346 348
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 195
34b 34f 199 34a
351 :3 0 19c 333
353 :2 0 355 19f
356 330 355 0
357 1a1 0 358
1a3 35b :3 0 35b
0 35b 35a 358
359 :6 0 35d f
:3 0 1a6 35f 1a8
35e 35d :2 0 360
1aa :2 0 362 0
362 361 30f 360
:6 0 47d 1 :3 0
35 :3 0 1b :4 0
367 :2 0 47d 365
368 :3 0 36 :3 0
1b :3 0 3 :3 0
9 :4 0 36e :2 0
41c 36a 36f :3 0
1ad :3 0 1b :3 0
37 :3 0 370 371
:3 0 38 :3 0 39
:3 0 373 374 0
a :2 0 375 376
0 378 1b0 37f
38 :3 0 39 :3 0
379 37a 0 3a
:2 0 37b 37c 0
37e 1b2 380 372
378 0 381 0
37e 0 381 1b4
0 41c 38 :3 0
39 :3 0 382 383
0 38 :3 0 3b
:2 0 3c :3 0 385
387 0 1b9 386
389 :3 0 38a :2 0
3d :8 0 38e 1bc
38f 38b 38e 0
390 1be 0 41c
11 :3 0 40 :3 0
13 :3 0 42 :3 0
58 :3 0 59 :3 0
5a :3 0 59 :3 0
f :3 0 3 :3 0
5b :3 0 5c :4 0
6d 1 :8 0 3b3
37 :4 0 39e :3 0
44 :3 0 45 :2 0
1c2 3a1 3a2 :3 0
38 :3 0 39 :3 0
3a4 3a5 0 a
:2 0 3a6 3a7 0
3a9 1c5 3b0 38
:3 0 39 :3 0 3aa
3ab 0 3a :2 0
3ac 3ad 0 3af
1c7 3b1 3a3 3a9
0 3b2 0 3af
0 3b2 1c9 0
3b3 1cc 406 46
:3 0 38 :3 0 39
:3 0 3b5 3b6 0
47 :3 0 3b7 3b8
0 3ba 1cf 3bc
1d1 3bb 3ba :2 0
404 48 :3 0 38
:3 0 39 :3 0 3bf
3c0 0 47 :3 0
3c1 3c2 0 3fc
21 :3 0 22 :3 0
3c4 3c5 0 21
:3 0 2e :3 0 3c7
3c8 0 49 :2 0
2 :4 0 6e :2 0
31 :2 0 2f :2 0
1d3 3cd 3cf :3 0
1d6 3c9 3d1 3c6
3d3 3d2 :2 0 24
:3 0 32 :3 0 3d5
3d6 0 26 :4 0
6f :4 0 29 :2 0
2a :3 0 1da 3da
3dc :3 0 29 :2 0
4c :4 0 1dd 3de
3e0 :3 0 29 :2 0
4d :4 0 1e0 3e2
3e4 :3 0 29 :2 0
47 :3 0 1e3 3e6
3e8 :3 0 29 :2 0
4e :4 0 1e6 3ea
3ec :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
1e9 3ef 3f3 1ed
3ee 3f5 :3 0 1f0
3d7 3f7 :2 0 3f9
1f3 3fa 3d4 3f9
0 3fb 1f5 0
3fc 1f7 3ff :3 0
3ff 0 3ff 3fe
3fc 3fd :6 0 401
12 :3 0 1fa 403
1fc 402 401 :2 0
404 1fe :2 0 406
0 406 405 3b3
404 :6 0 41c 11
:3 0 67 :3 0 9
:3 0 a :2 0 201
408 40b 45 :2 0
a :2 0 206 40d
40f :3 0 c :3 0
68 :3 0 3 :3 0
209 412 414 411
415 0 419 69
:4 0 69 1 :8 0
419 20b 41a 410
419 0 41b 20e
0 41c 210 41e
36 :4 0 41c :4 0
47d 6a :3 0 1b
:4 0 422 :2 0 428
420 0 38 :3 0
39 :3 0 423 424
0 47 :3 0 425
426 0 428 216
47b 46 :3 0 38
:3 0 39 :3 0 42a
42b 0 47 :3 0
42c 42d 0 42f
219 431 21b 430
42f :2 0 479 48
:3 0 38 :3 0 39
:3 0 434 435 0
47 :3 0 436 437
0 471 21 :3 0
22 :3 0 439 43a
0 21 :3 0 2e
:3 0 43c 43d 0
49 :2 0 2 :4 0
70 :2 0 31 :2 0
2f :2 0 21d 442
444 :3 0 220 43e
446 43b 448 447
:2 0 24 :3 0 32
:3 0 44a 44b 0
26 :4 0 71 :4 0
29 :2 0 2a :3 0
224 44f 451 :3 0
29 :2 0 4c :4 0
227 453 455 :3 0
29 :2 0 4d :4 0
22a 457 459 :3 0
29 :2 0 47 :3 0
22d 45b 45d :3 0
29 :2 0 4e :4 0
230 45f 461 :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 233 464
468 237 463 46a
:3 0 23a 44c 46c
:2 0 46e 23d 46f
449 46e 0 470
23f 0 471 241
474 :3 0 474 0
474 473 471 472
:6 0 476 14 :3 0
244 478 246 477
476 :2 0 479 248
:2 0 47b 0 47b
47a 428 479 :6 0
47d 1 :3 0 24b
815 35 :3 0 1c
:4 0 481 :2 0 814
47f 482 :3 0 36
:3 0 1c :3 0 9
:4 0 487 :2 0 69c
484 485 :3 0 1c
:3 0 37 :3 0 488
489 :3 0 38 :3 0
39 :3 0 48b 48c
0 a :2 0 48d
48e 0 490 252
497 38 :3 0 39
:3 0 491 492 0
3a :2 0 493 494
0 496 254 498
48a 490 0 499
0 496 0 499
256 0 69c 38
:3 0 39 :3 0 49a
49b 0 38 :3 0
3b :2 0 3c :3 0
49d 49f 0 25b
49e 4a1 :3 0 4a2
:2 0 3d :8 0 4a6
25e 4a7 4a3 4a6
0 4a8 260 0
69c b :3 0 52
:3 0 53 :3 0 4aa
4ab 0 13 :3 0
54 :3 0 4ad 4ae
0 13 :3 0 55
:3 0 4b0 4b1 0
262 4ac 4b3 4a9
4b4 0 69c 3f
:3 0 40 :3 0 13
:3 0 42 :3 0 f
:3 0 3 :4 0 72
1 :8 0 4d2 37
:4 0 4bd :3 0 44
:3 0 45 :2 0 267
4c0 4c1 :3 0 38
:3 0 39 :3 0 4c3
4c4 0 a :2 0
4c5 4c6 0 4c8
26a 4cf 38 :3 0
39 :3 0 4c9 4ca
0 3a :2 0 4cb
4cc 0 4ce 26c
4d0 4c2 4c8 0
4d1 0 4ce 0
4d1 26e 0 4d2
271 525 46 :3 0
38 :3 0 39 :3 0
4d4 4d5 0 47
:3 0 4d6 4d7 0
4d9 274 4db 276
4da 4d9 :2 0 523
48 :3 0 38 :3 0
39 :3 0 4de 4df
0 47 :3 0 4e0
4e1 0 51b 21
:3 0 22 :3 0 4e3
4e4 0 21 :3 0
2e :3 0 4e6 4e7
0 49 :2 0 2
:4 0 73 :2 0 31
:2 0 2f :2 0 278
4ec 4ee :3 0 27b
4e8 4f0 4e5 4f2
4f1 :2 0 24 :3 0
32 :3 0 4f4 4f5
0 26 :4 0 74
:4 0 29 :2 0 2a
:3 0 27f 4f9 4fb
:3 0 29 :2 0 4c
:4 0 282 4fd 4ff
:3 0 29 :2 0 4d
:4 0 285 501 503
:3 0 29 :2 0 47
:3 0 288 505 507
:3 0 29 :2 0 4e
:4 0 28b 509 50b
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 28e
50e 512 292 50d
514 :3 0 295 4f6
516 :2 0 518 298
519 4f3 518 0
51a 29a 0 51b
29c 51e :3 0 51e
0 51e 51d 51b
51c :6 0 520 17
:3 0 29f 522 2a1
521 520 :2 0 523
2a3 :2 0 525 0
525 524 4d2 523
:6 0 69c 16 :3 0
11 :3 0 40 :3 0
13 :3 0 42 :3 0
56 :3 0 57 :3 0
58 :3 0 59 :3 0
5a :3 0 59 :3 0
f :3 0 3 :3 0
5b :3 0 5c :4 0
5d 1 :8 0 54b
37 :4 0 536 :3 0
44 :3 0 45 :2 0
2a8 539 53a :3 0
38 :3 0 39 :3 0
53c 53d 0 a
:2 0 53e 53f 0
541 2ab 548 38
:3 0 39 :3 0 542
543 0 3a :2 0
544 545 0 547
2ad 549 53b 541
0 54a 0 547
0 54a 2af 0
54b 2b2 59e 46
:3 0 38 :3 0 39
:3 0 54d 54e 0
47 :3 0 54f 550
0 552 2b5 554
2b7 553 552 :2 0
59c 48 :3 0 38
:3 0 39 :3 0 557
558 0 47 :3 0
559 55a 0 594
21 :3 0 22 :3 0
55c 55d 0 21
:3 0 2e :3 0 55f
560 0 49 :2 0
2 :4 0 75 :2 0
31 :2 0 2f :2 0
2b9 565 567 :3 0
2bc 561 569 55e
56b 56a :2 0 24
:3 0 32 :3 0 56d
56e 0 26 :4 0
76 :4 0 29 :2 0
2a :3 0 2c0 572
574 :3 0 29 :2 0
4c :4 0 2c3 576
578 :3 0 29 :2 0
4d :4 0 2c6 57a
57c :3 0 29 :2 0
47 :3 0 2c9 57e
580 :3 0 29 :2 0
4e :4 0 2cc 582
584 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
2cf 587 58b 2d3
586 58d :3 0 2d6
56f 58f :2 0 591
2d9 592 56c 591
0 593 2db 0
594 2dd 597 :3 0
597 0 597 596
594 595 :6 0 599
19 :3 0 2e0 59b
2e2 59a 599 :2 0
59c 2e4 :2 0 59e
0 59e 59d 54b
59c :6 0 69c 16
:3 0 11 :3 0 40
:3 0 b :3 0 56
:3 0 57 :3 0 f
:3 0 3 :3 0 5b
:3 0 5c :4 0 60
1 :8 0 5bf 37
:4 0 5aa :3 0 44
:3 0 45 :2 0 2e9
5ad 5ae :3 0 38
:3 0 39 :3 0 5b0
5b1 0 a :2 0
5b2 5b3 0 5b5
2ec 5bc 38 :3 0
39 :3 0 5b6 5b7
0 3a :2 0 5b8
5b9 0 5bb 2ee
5bd 5af 5b5 0
5be 0 5bb 0
5be 2f0 0 5bf
2f3 612 46 :3 0
38 :3 0 39 :3 0
5c1 5c2 0 47
:3 0 5c3 5c4 0
5c6 2f6 5c8 2f8
5c7 5c6 :2 0 610
48 :3 0 38 :3 0
39 :3 0 5cb 5cc
0 47 :3 0 5cd
5ce 0 608 21
:3 0 22 :3 0 5d0
5d1 0 21 :3 0
2e :3 0 5d3 5d4
0 49 :2 0 2
:4 0 77 :2 0 31
:2 0 2f :2 0 2fa
5d9 5db :3 0 2fd
5d5 5dd 5d2 5df
5de :2 0 24 :3 0
32 :3 0 5e1 5e2
0 26 :4 0 78
:4 0 29 :2 0 2a
:3 0 301 5e6 5e8
:3 0 29 :2 0 4c
:4 0 304 5ea 5ec
:3 0 29 :2 0 4d
:4 0 307 5ee 5f0
:3 0 29 :2 0 47
:3 0 30a 5f2 5f4
:3 0 29 :2 0 4e
:4 0 30d 5f6 5f8
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 310
5fb 5ff 314 5fa
601 :3 0 317 5e3
603 :2 0 605 31a
606 5e0 605 0
607 31c 0 608
31e 60b :3 0 60b
0 60b 60a 608
609 :6 0 60d 1b
:3 0 321 60f 323
60e 60d :2 0 610
325 :2 0 612 0
612 611 5bf 610
:6 0 69c 16 :3 0
63 :3 0 40 :3 0
13 :3 0 42 :3 0
56 :3 0 57 :3 0
f :3 0 3 :3 0
12 :4 0 64 1
:8 0 633 37 :4 0
61e :3 0 44 :3 0
45 :2 0 32a 621
622 :3 0 38 :3 0
39 :3 0 624 625
0 a :2 0 626
627 0 629 32d
630 38 :3 0 39
:3 0 62a 62b 0
3a :2 0 62c 62d
0 62f 32f 631
623 629 0 632
0 62f 0 632
331 0 633 334
686 46 :3 0 38
:3 0 39 :3 0 635
636 0 47 :3 0
637 638 0 63a
337 63c 339 63b
63a :2 0 684 48
:3 0 38 :3 0 39
:3 0 63f 640 0
47 :3 0 641 642
0 67c 21 :3 0
22 :3 0 644 645
0 21 :3 0 2e
:3 0 647 648 0
49 :2 0 2 :4 0
79 :2 0 31 :2 0
2f :2 0 33b 64d
64f :3 0 33e 649
651 646 653 652
:2 0 24 :3 0 32
:3 0 655 656 0
26 :4 0 7a :4 0
29 :2 0 2a :3 0
342 65a 65c :3 0
29 :2 0 4c :4 0
345 65e 660 :3 0
29 :2 0 4d :4 0
348 662 664 :3 0
29 :2 0 47 :3 0
34b 666 668 :3 0
29 :2 0 4e :4 0
34e 66a 66c :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 351 66f
673 355 66e 675
:3 0 358 657 677
:2 0 679 35b 67a
654 679 0 67b
35d 0 67c 35f
67f :3 0 67f 0
67f 67e 67c 67d
:6 0 681 1d :3 0
362 683 364 682
681 :2 0 684 366
:2 0 686 0 686
685 633 684 :6 0
69c 16 :3 0 67
:3 0 9 :3 0 a
:2 0 369 688 68b
45 :2 0 a :2 0
36e 68d 68f :3 0
c :3 0 68 :3 0
3 :3 0 371 692
694 691 695 0
699 69 :4 0 69
1 :8 0 699 373
69a 690 699 0
69b 376 0 69c
378 69e 36 :4 0
69c :4 0 814 6a
:3 0 1c :4 0 6a2
:2 0 6a8 6a0 0
38 :3 0 39 :3 0
6a3 6a4 0 47
:3 0 6a5 6a6 0
6a8 382 6fb 46
:3 0 38 :3 0 39
:3 0 6aa 6ab 0
47 :3 0 6ac 6ad
0 6af 385 6b1
387 6b0 6af :2 0
6f9 48 :3 0 38
:3 0 39 :3 0 6b4
6b5 0 47 :3 0
6b6 6b7 0 6f1
21 :3 0 22 :3 0
6b9 6ba 0 21
:3 0 2e :3 0 6bc
6bd 0 49 :2 0
2 :4 0 7b :2 0
31 :2 0 2f :2 0
389 6c2 6c4 :3 0
38c 6be 6c6 6bb
6c8 6c7 :2 0 24
:3 0 32 :3 0 6ca
6cb 0 26 :4 0
7c :4 0 29 :2 0
2a :3 0 390 6cf
6d1 :3 0 29 :2 0
4c :4 0 393 6d3
6d5 :3 0 29 :2 0
4d :4 0 396 6d7
6d9 :3 0 29 :2 0
47 :3 0 399 6db
6dd :3 0 29 :2 0
4e :4 0 39c 6df
6e1 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
39f 6e4 6e8 3a3
6e3 6ea :3 0 3a6
6cc 6ec :2 0 6ee
3a9 6ef 6c9 6ee
0 6f0 3ab 0
6f1 3ad 6f4 :3 0
6f4 0 6f4 6f3
6f1 6f2 :6 0 6f6
1f :3 0 3b0 6f8
3b2 6f7 6f6 :2 0
6f9 3b4 :2 0 6fb
0 6fb 6fa 6a8
6f9 :6 0 814 1
:3 0 35 :3 0 1f
:4 0 700 :2 0 814
6fe 701 :3 0 36
:3 0 1f :3 0 9
:4 0 706 :2 0 7b3
703 704 :3 0 1f
:3 0 37 :3 0 707
708 :3 0 38 :3 0
39 :3 0 70a 70b
0 a :2 0 70c
70d 0 70f 3b7
716 38 :3 0 39
:3 0 710 711 0
3a :2 0 712 713
0 715 3b9 717
709 70f 0 718
0 715 0 718
3bb 0 7b3 38
:3 0 39 :3 0 719
71a 0 38 :3 0
3b :2 0 3c :3 0
71c 71e 0 3c0
71d 720 :3 0 721
:2 0 3d :8 0 725
3c3 726 722 725
0 727 3c5 0
7b3 11 :3 0 40
:3 0 13 :3 0 42
:3 0 58 :3 0 59
:3 0 5a :3 0 59
:3 0 f :3 0 3
:3 0 5b :3 0 5c
:4 0 6d 1 :8 0
74a 37 :4 0 735
:3 0 44 :3 0 45
:2 0 3c9 738 739
:3 0 38 :3 0 39
:3 0 73b 73c 0
a :2 0 73d 73e
0 740 3cc 747
38 :3 0 39 :3 0
741 742 0 3a
:2 0 743 744 0
746 3ce 748 73a
740 0 749 0
746 0 749 3d0
0 74a 3d3 79d
46 :3 0 38 :3 0
39 :3 0 74c 74d
0 47 :3 0 74e
74f 0 751 3d6
753 3d8 752 751
:2 0 79b 48 :3 0
38 :3 0 39 :3 0
756 757 0 47
:3 0 758 759 0
793 21 :3 0 22
:3 0 75b 75c 0
21 :3 0 2e :3 0
75e 75f 0 49
:2 0 2 :4 0 7d
:2 0 31 :2 0 2f
:2 0 3da 764 766
:3 0 3dd 760 768
75d 76a 769 :2 0
24 :3 0 32 :3 0
76c 76d 0 26
:4 0 7e :4 0 29
:2 0 2a :3 0 3e1
771 773 :3 0 29
:2 0 4c :4 0 3e4
775 777 :3 0 29
:2 0 4d :4 0 3e7
779 77b :3 0 29
:2 0 47 :3 0 3ea
77d 77f :3 0 29
:2 0 4e :4 0 3ed
781 783 :3 0 29
:2 0 4f :3 0 50
:3 0 2f :2 0 51
:2 0 3f0 786 78a
3f4 785 78c :3 0
3f7 76e 78e :2 0
790 3fa 791 76b
790 0 792 3fc
0 793 3fe 796
:3 0 796 0 796
795 793 794 :6 0
798 22 :3 0 401
79a 403 799 798
:2 0 79b 405 :2 0
79d 0 79d 79c
74a 79b :6 0 7b3
21 :3 0 67 :3 0
9 :3 0 a :2 0
408 79f 7a2 45
:2 0 a :2 0 40d
7a4 7a6 :3 0 c
:3 0 68 :3 0 3
:3 0 410 7a9 7ab
7a8 7ac 0 7b0
69 :4 0 69 1
:8 0 7b0 412 7b1
7a7 7b0 0 7b2
415 0 7b3 417
7b5 36 :4 0 7b3
:4 0 814 6a :3 0
1f :4 0 7b9 :2 0
7bf 7b7 0 38
:3 0 39 :3 0 7ba
7bb 0 47 :3 0
7bc 7bd 0 7bf
41d 812 46 :3 0
38 :3 0 39 :3 0
7c1 7c2 0 47
:3 0 7c3 7c4 0
7c6 420 7c8 422
7c7 7c6 :2 0 810
48 :3 0 38 :3 0
39 :3 0 7cb 7cc
0 47 :3 0 7cd
7ce 0 808 21
:3 0 22 :3 0 7d0
7d1 0 21 :3 0
2e :3 0 7d3 7d4
0 49 :2 0 2
:4 0 7f :2 0 31
:2 0 2f :2 0 424
7d9 7db :3 0 427
7d5 7dd 7d2 7df
7de :2 0 24 :3 0
32 :3 0 7e1 7e2
0 26 :4 0 80
:4 0 29 :2 0 2a
:3 0 42b 7e6 7e8
:3 0 29 :2 0 4c
:4 0 42e 7ea 7ec
:3 0 29 :2 0 4d
:4 0 431 7ee 7f0
:3 0 29 :2 0 47
:3 0 434 7f2 7f4
:3 0 29 :2 0 4e
:4 0 437 7f6 7f8
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 43a
7fb 7ff 43e 7fa
801 :3 0 441 7e3
803 :2 0 805 444
806 7e0 805 0
807 446 0 808
448 80b :3 0 80b
0 80b 80a 808
809 :6 0 80d 24
:3 0 44b 80f 44d
80e 80d :2 0 810
44f :2 0 812 0
812 811 7bf 810
:6 0 814 1 :3 0
452 816 dd 47d
0 817 0 814
0 817 459 0
84a 21 :3 0 22
:3 0 818 819 0
21 :3 0 2e :3 0
81b 81c 0 2f
:2 0 2 :4 0 81
:2 0 31 :2 0 2f
:2 0 45c 821 823
:3 0 45f 81d 825
81a 827 826 :2 0
24 :3 0 32 :3 0
829 82a 0 26
:4 0 82 :4 0 29
:2 0 2a :3 0 463
82e 830 :3 0 29
:2 0 4c :4 0 466
832 834 :3 0 29
:2 0 83 :4 0 469
836 838 :3 0 29
:2 0 38 :3 0 39
:3 0 83b 83c 0
46c 83a 83e :3 0
46f 82b 840 :2 0
842 472 843 828
842 0 844 474
0 84a 7 :3 0
38 :3 0 39 :3 0
846 847 0 848
:2 0 84a 476 84d
:3 0 84d 47c 84d
84c 84a 84b :6 0
84e :2 0 2 c
84d 851 :3 0 850
84e 852 :8 0 
484
4
:3 0 1 3 1
8 1 e 1
14 1 1a 1
34 1 4e 1
69 1 84 1
90 1 9c 2
9f a1 2 a4
a6 2 a8 aa
2 ac ae 2
b0 b2 4 98
9e a3 b4 1
b6 1 b8 2
c2 c4 3 c0
c1 c6 2 cf
d1 2 ce d3
1 d5 1 d7
1 d9 2 e5
e6 1 f1 1
f7 2 f9 fa
1 102 2 fe
102 1 107 1
109 1 119 2
118 119 1 121
1 127 2 129
12a 2 116 12b
1 132 1 12d
2 145 147 3
143 144 149 2
152 154 2 156
158 2 15a 15c
2 15e 160 2
162 164 3 169
16a 16b 2 166
16d 2 151 16f
1 171 1 173
2 13c 174 1
178 1 137 2
135 17c 2 187
18a 1 19f 2
19e 19f 1 1a7
1 1ad 2 1af
1b0 2 19c 1b1
1 1b8 1 1b3
2 1cb 1cd 3
1c9 1ca 1cf 2
1d8 1da 2 1dc
1de 2 1e0 1e2
2 1e4 1e6 2
1e8 1ea 3 1ef
1f0 1f1 2 1ec
1f3 2 1d7 1f5
1 1f7 1 1f9
2 1c2 1fa 1
1fe 1 1bd 2
1bb 202 1 213
2 212 213 1
21b 1 221 2
223 224 2 210
225 1 22c 1
227 2 23f 241
3 23d 23e 243
2 24c 24e 2
250 252 2 254
256 2 258 25a
2 25c 25e 3
263 264 265 2
260 267 2 24b
269 1 26b 1
26d 2 236 26e
1 272 1 231
2 22f 276 1
287 2 286 287
1 28f 1 295
2 297 298 2
284 299 1 2a0
1 29b 2 2b3
2b5 3 2b1 2b2
2b7 2 2c0 2c2
2 2c4 2c6 2
2c8 2ca 2 2cc
2ce 2 2d0 2d2
3 2d7 2d8 2d9
2 2d4 2db 2
2bf 2dd 1 2df
1 2e1 2 2aa
2e2 1 2e6 1
2a5 2 2a3 2ea
2 2f0 2f1 1
2f5 2 2f3 2f5
1 2fa 2 2fd
2ff 1 301 a
e7 fb 10a 10d
17f 18d 205 279
2ed 302 2 308
30e 1 315 1
310 2 328 32a
3 326 327 32c
2 335 337 2
339 33b 2 33d
33f 2 341 343
2 345 347 3
34c 34d 34e 2
349 350 2 334
352 1 354 1
356 2 31f 357
1 35b 1 31a
2 318 35f 2
36b 36c 1 377
1 37d 2 37f
380 1 388 2
384 388 1 38d
1 38f 1 3a0
2 39f 3a0 1
3a8 1 3ae 2
3b0 3b1 2 39d
3b2 1 3b9 1
3b4 2 3cc 3ce
3 3ca 3cb 3d0
2 3d9 3db 2
3dd 3df 2 3e1
3e3 2 3e5 3e7
2 3e9 3eb 3
3f0 3f1 3f2 2
3ed 3f4 2 3d8
3f6 1 3f8 1
3fa 2 3c3 3fb
1 3ff 1 3be
2 3bc 403 2
409 40a 1 40e
2 40c 40e 1
413 2 416 418
1 41a 5 36d
381 390 406 41b
2 421 427 1
42e 1 429 2
441 443 3 43f
440 445 2 44e
450 2 452 454
2 456 458 2
45a 45c 2 45e
460 3 465 466
467 2 462 469
2 44d 46b 1
46d 1 46f 2
438 470 1 474
1 433 2 431
478 6 e0 305
362 366 41e 47b
1 48f 1 495
2 497 498 1
4a0 2 49c 4a0
1 4a5 1 4a7
2 4af 4b2 1
4bf 2 4be 4bf
1 4c7 1 4cd
2 4cf 4d0 2
4bc 4d1 1 4d8
1 4d3 2 4eb
4ed 3 4e9 4ea
4ef 2 4f8 4fa
2 4fc 4fe 2
500 502 2 504
506 2 508 50a
3 50f 510 511
2 50c 513 2
4f7 515 1 517
1 519 2 4e2
51a 1 51e 1
4dd 2 4db 522
1 538 2 537
538 1 540 1
546 2 548 549
2 535 54a 1
551 1 54c 2
564 566 3 562
563 568 2 571
573 2 575 577
2 579 57b 2
57d 57f 2 581
583 3 588 589
58a 2 585 58c
2 570 58e 1
590 1 592 2
55b 593 1 597
1 556 2 554
59b 1 5ac 2
5ab 5ac 1 5b4
1 5ba 2 5bc
5bd 2 5a9 5be
1 5c5 1 5c0
2 5d8 5da 3
5d6 5d7 5dc 2
5e5 5e7 2 5e9
5eb 2 5ed 5ef
2 5f1 5f3 2
5f5 5f7 3 5fc
5fd 5fe 2 5f9
600 2 5e4 602
1 604 1 606
2 5cf 607 1
60b 1 5ca 2
5c8 60f 1 620
2 61f 620 1
628 1 62e 2
630 631 2 61d
632 1 639 1
634 2 64c 64e
3 64a 64b 650
2 659 65b 2
65d 65f 2 661
663 2 665 667
2 669 66b 3
670 671 672 2
66d 674 2 658
676 1 678 1
67a 2 643 67b
1 67f 1 63e
2 63c 683 2
689 68a 1 68e
2 68c 68e 1
693 2 696 698
1 69a 9 486
499 4a8 4b5 525
59e 612 686 69b
2 6a1 6a7 1
6ae 1 6a9 2
6c1 6c3 3 6bf
6c0 6c5 2 6ce
6d0 2 6d2 6d4
2 6d6 6d8 2
6da 6dc 2 6de
6e0 3 6e5 6e6
6e7 2 6e2 6e9
2 6cd 6eb 1
6ed 1 6ef 2
6b8 6f0 1 6f4
1 6b3 2 6b1
6f8 1 70e 1
714 2 716 717
1 71f 2 71b
71f 1 724 1
726 1 737 2
736 737 1 73f
1 745 2 747
748 2 734 749
1 750 1 74b
2 763 765 3
761 762 767 2
770 772 2 774
776 2 778 77a
2 77c 77e 2
780 782 3 787
788 789 2 784
78b 2 76f 78d
1 78f 1 791
2 75a 792 1
796 1 755 2
753 79a 2 7a0
7a1 1 7a5 2
7a3 7a5 1 7aa
2 7ad 7af 1
7b1 5 705 718
727 79d 7b2 2
7b8 7be 1 7c5
1 7c0 2 7d8
7da 3 7d6 7d7
7dc 2 7e5 7e7
2 7e9 7eb 2
7ed 7ef 2 7f1
7f3 2 7f5 7f7
3 7fc 7fd 7fe
2 7f9 800 2
7e4 802 1 804
1 806 2 7cf
807 1 80b 1
7ca 2 7c8 80f
6 480 69e 6fb
6ff 7b5 812 2
815 816 2 820
822 3 81e 81f
824 2 82d 82f
2 831 833 2
835 837 2 839
83d 2 82c 83f
1 841 1 843
5 b9 d8 817
844 849 7 12
18 1e 35 4f
6a 85 
1
4
0 
851
0
1
28
25
9
0 1 1 1 1 1 6 7
6 9 6 b 6 d 1 f
1 11 12 1 14 1 16 17
16 19 16 1b 16 1d 1 1f
1 21 22 1 24 0 0 0

21 1 2
3b 1 3
55 1 4
70 1 5
1a 1 0
14 1 0
2 0 1
e 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_MIGRATION;
ALTER FUNCTION FC_MIGRATION COMPILE DEBUG;
